--
-- PostgreSQL database dump
--

SET client_encoding = 'LATIN1';
SET check_function_bodies = false;
SET client_min_messages = warning;

--
-- Name: new_customer(character varying, character varying, character varying, character varying, character varying, character varying, integer, character varying, integer, character varying, character varying, integer, character varying, character varying, character varying, character varying, integer, integer, character varying); Type: FUNCTION; Schema: public; Owner: chriskl
--

CREATE FUNCTION new_customer(firstname_in character varying, lastname_in character varying, address1_in character varying, address2_in character varying, city_in character varying, state_in character varying, zip_in integer, country_in character varying, region_in integer, email_in character varying, phone_in character varying, creditcardtype_in integer, creditcard_in character varying, creditcardexpiration_in character varying, username_in character varying, password_in character varying, age_in integer, income_in integer, gender_in character varying, OUT customerid_out integer) RETURNS integer
    AS '
  DECLARE
    rows_returned INT;
  BEGIN
    SELECT COUNT(*) INTO rows_returned FROM CUSTOMERS WHERE USERNAME = username_in;
    IF rows_returned = 0 THEN
	    INSERT INTO CUSTOMERS
	      (
	      FIRSTNAME,
	      LASTNAME,
	      EMAIL,
	      PHONE,
	      USERNAME,
	      PASSWORD,
	      ADDRESS1,
	      ADDRESS2,
	      CITY,
	      STATE,
	      ZIP,
	      COUNTRY,
	      REGION,
	      CREDITCARDTYPE,
	      CREDITCARD,
	      CREDITCARDEXPIRATION,
	      AGE,
	      INCOME,
	      GENDER
	      )
	    VALUES
	      (
	      firstname_in,
	      lastname_in,
	      email_in,
	      phone_in,
	      username_in,
	      password_in,
	      address1_in,
	      address2_in,
	      city_in,
	      state_in,
	      zip_in,
	      country_in,
	      region_in,
	      creditcardtype_in,
	      creditcard_in,
	      creditcardexpiration_in,
	      age_in,
	      income_in,
	      gender_in
	      )
	     ;
    select currval(pg_get_serial_sequence(''customers'', ''customerid'')) into customerid_out;
  ELSE 
  	customerid_out := 0;
  END IF;
END
'
    LANGUAGE plpgsql;


SET default_tablespace = '';

SET default_with_oids = false;

--
-- Name: categories; Type: TABLE; Schema: public; Owner: chriskl; Tablespace: 
--

CREATE TABLE categories (
    category serial NOT NULL,
    categoryname character varying(50) NOT NULL
);


--
-- Name: categories_category_seq; Type: SEQUENCE SET; Schema: public; Owner: chriskl
--

SELECT pg_catalog.setval(pg_catalog.pg_get_serial_sequence('categories', 'category'), 16, true);


--
-- Name: cust_hist; Type: TABLE; Schema: public; Owner: chriskl; Tablespace: 
--

CREATE TABLE cust_hist (
    customerid integer NOT NULL,
    orderid integer NOT NULL,
    prod_id integer NOT NULL
);


--
-- Name: customers; Type: TABLE; Schema: public; Owner: chriskl; Tablespace: 
--

CREATE TABLE customers (
    customerid serial NOT NULL,
    firstname character varying(50) NOT NULL,
    lastname character varying(50) NOT NULL,
    address1 character varying(50) NOT NULL,
    address2 character varying(50),
    city character varying(50) NOT NULL,
    state character varying(50),
    zip integer,
    country character varying(50) NOT NULL,
    region smallint NOT NULL,
    email character varying(50),
    phone character varying(50),
    creditcardtype integer NOT NULL,
    creditcard character varying(50) NOT NULL,
    creditcardexpiration character varying(50) NOT NULL,
    username character varying(50) NOT NULL,
    "password" character varying(50) NOT NULL,
    age smallint,
    income integer,
    gender character varying(1)
);


--
-- Name: customers_customerid_seq; Type: SEQUENCE SET; Schema: public; Owner: chriskl
--

SELECT pg_catalog.setval(pg_catalog.pg_get_serial_sequence('customers', 'customerid'), 20000, true);


--
-- Name: inventory; Type: TABLE; Schema: public; Owner: chriskl; Tablespace: 
--

CREATE TABLE inventory (
    prod_id integer NOT NULL,
    quan_in_stock integer NOT NULL,
    sales integer NOT NULL
);


--
-- Name: orderlines; Type: TABLE; Schema: public; Owner: chriskl; Tablespace: 
--

CREATE TABLE orderlines (
    orderlineid integer NOT NULL,
    orderid integer NOT NULL,
    prod_id integer NOT NULL,
    quantity smallint NOT NULL,
    orderdate date NOT NULL
);


--
-- Name: orders; Type: TABLE; Schema: public; Owner: chriskl; Tablespace: 
--

CREATE TABLE orders (
    orderid serial NOT NULL,
    orderdate date NOT NULL,
    customerid integer,
    netamount numeric(12,2) NOT NULL,
    tax numeric(12,2) NOT NULL,
    totalamount numeric(12,2) NOT NULL
);


--
-- Name: orders_orderid_seq; Type: SEQUENCE SET; Schema: public; Owner: chriskl
--

SELECT pg_catalog.setval(pg_catalog.pg_get_serial_sequence('orders', 'orderid'), 12000, true);


--
-- Name: products; Type: TABLE; Schema: public; Owner: chriskl; Tablespace: 
--

CREATE TABLE products (
    prod_id serial NOT NULL,
    category integer NOT NULL,
    title character varying(50) NOT NULL,
    actor character varying(50) NOT NULL,
    price numeric(12,2) NOT NULL,
    special smallint,
    common_prod_id integer NOT NULL
);


--
-- Name: products_prod_id_seq; Type: SEQUENCE SET; Schema: public; Owner: chriskl
--

SELECT pg_catalog.setval(pg_catalog.pg_get_serial_sequence('products', 'prod_id'), 10000, true);


--
-- Name: reorder; Type: TABLE; Schema: public; Owner: chriskl; Tablespace: 
--

CREATE TABLE reorder (
    prod_id integer NOT NULL,
    date_low date NOT NULL,
    quan_low integer NOT NULL,
    date_reordered date,
    quan_reordered integer,
    date_expected date
);


--
-- Data for Name: categories; Type: TABLE DATA; Schema: public; Owner: chriskl
--

COPY categories (category, categoryname) FROM stdin;
1	Action
2	Animation
3	Children
4	Classics
5	Comedy
6	Documentary
7	Drama
8	Family
9	Foreign
10	Games
11	Horror
12	Music
13	New
14	Sci-Fi
15	Sports
16	Travel
\.


--
-- Data for Name: cust_hist; Type: TABLE DATA; Schema: public; Owner: chriskl
--

COPY cust_hist (customerid, orderid, prod_id) FROM stdin;
7888	1	9117
7888	1	3353
7888	1	2778
7888	1	4774
7888	1	3648
7888	1	9523
7888	1	6358
7888	1	1417
4858	2	1567
4858	2	1298
4858	2	9990
4858	2	5130
4858	2	6127
4858	2	6376
4858	2	4936
4858	2	2926
15399	3	2834
15399	3	8078
15399	3	698
15399	3	5260
15399	3	1923
15399	3	8903
15399	3	642
15399	3	4578
15399	3	2383
17019	4	3753
17019	4	5126
17019	4	5317
17019	4	4377
17019	4	9309
14771	5	6879
14771	5	4402
14771	5	8293
14771	5	2290
13734	6	6574
13734	6	4396
13734	6	3985
13734	6	6843
13734	6	4825
13734	6	9503
17622	7	6196
17622	7	7861
17622	7	4471
17622	7	1876
8331	8	1032
8331	8	4955
8331	8	9848
8331	8	6845
8331	8	7498
8331	8	2942
8331	8	5845
8331	8	1524
8331	8	1255
14902	9	526
14902	9	1763
14902	9	7978
14902	9	6566
14902	9	6395
14902	9	935
14902	9	5203
14902	9	700
14902	9	4615
15112	10	10000
15112	10	8900
1082	11	42
3608	12	9131
3608	12	3591
3608	12	5795
3608	12	6874
15146	13	5770
15146	13	7479
15146	13	355
15146	13	8333
15146	13	8733
15146	13	9795
15146	13	9034
15146	13	6669
15146	13	1640
1540	14	6295
1540	14	7007
1540	14	3288
12662	15	5107
12662	15	2801
12662	15	7193
12662	15	4715
12662	15	9444
12662	15	3364
65	16	8333
65	16	6755
65	16	4820
65	16	7121
65	16	6219
65	16	4140
12753	17	6092
12753	17	7308
4045	18	6532
4045	18	5325
4045	18	2605
4045	18	6862
4045	18	1113
4045	18	5767
4045	18	6666
5768	19	9844
5768	19	8274
8730	20	7649
8730	20	1212
8730	20	3839
8730	20	9431
8730	20	8620
8730	20	7937
8730	20	2973
8730	20	9097
8730	20	4982
5479	21	4637
5479	21	4960
5479	21	1805
5479	21	7276
5479	21	6032
14486	22	4986
14486	22	1383
18638	23	8369
18638	23	4961
18638	23	3944
18638	23	6089
18638	23	1513
18638	23	1079
5766	24	4274
5310	25	4875
5310	25	8831
5310	25	5178
5310	25	5576
5310	25	8300
5310	25	2444
5310	25	7294
6765	26	4108
6765	26	7833
2294	27	492
2294	27	9865
2294	27	2109
2294	27	8652
2294	27	996
2294	27	3018
2294	27	8091
1069	28	6921
1069	28	1192
1069	28	5787
1069	28	5951
1069	28	3043
1069	28	4766
1069	28	6098
1069	28	6190
16597	29	9238
4510	30	3572
4510	30	3443
4510	30	6592
15566	31	3082
15566	31	1981
15566	31	1098
15566	31	7823
15566	31	2004
15566	31	3157
15566	31	2310
15566	31	5329
292	32	3055
292	32	2605
292	32	5524
292	32	6860
6240	33	5330
12854	34	3622
12854	34	8019
12854	34	1529
12854	34	636
12380	35	12
12380	35	3053
12380	35	6554
12380	35	1812
12380	35	6674
12380	35	6534
3726	36	8290
3726	36	9042
3726	36	3946
3726	36	8690
3726	36	7390
18532	37	4945
18532	37	9392
18532	37	8142
18532	37	6573
18532	37	9359
18532	37	8744
18532	37	6378
18532	37	7755
18532	37	2628
3340	38	8731
3340	38	4125
3340	38	5969
3340	38	5386
3340	38	5791
3340	38	7010
3340	38	8327
3340	38	1127
970	39	6377
970	39	1440
970	39	2471
970	39	175
16259	40	4774
16259	40	588
16259	40	6408
16259	40	2227
16259	40	6303
9258	41	9527
9258	41	8991
9258	41	3336
9258	41	2192
9258	41	9499
9258	41	8844
9258	41	1838
9258	41	7803
5152	42	3319
5152	42	5608
5152	42	6222
5152	42	4780
5152	42	6539
5152	42	2107
5152	42	8655
5152	42	3736
5152	42	6466
11927	43	5637
11927	43	190
11927	43	91
11927	43	6015
11927	43	8872
11927	43	1731
15905	44	1554
15905	44	8823
15905	44	8995
15905	44	4759
15905	44	9467
15905	44	8657
15905	44	7187
15905	44	1841
15905	44	1672
3525	45	9470
3525	45	1609
3525	45	4619
2018	46	3938
5864	47	5662
5864	47	348
5864	47	8140
5864	47	3564
5864	47	357
5864	47	2010
5864	47	6998
5864	47	8894
5864	47	3415
16067	48	9042
16067	48	7525
16067	48	8094
16067	48	5912
16067	48	1015
16067	48	2442
16067	48	5892
18911	49	4691
18911	49	5871
18911	49	5846
18911	49	8156
18911	49	5266
18911	49	7294
18911	49	2642
18911	49	5382
18911	49	9316
10453	50	6800
10453	50	4434
10453	50	7032
15185	51	162
15185	51	8525
15185	51	3215
15185	51	5269
15185	51	2503
15185	51	733
15185	51	8899
16427	52	3440
16427	52	440
16427	52	51
16427	52	2929
16427	52	8202
16427	52	4675
16427	52	1910
868	53	7114
868	53	929
868	53	8675
15146	54	5787
18452	55	9465
18452	55	2749
18452	55	8098
18452	55	7468
18452	55	1734
18452	55	7609
18452	55	9812
18452	55	3416
8688	56	6005
8688	56	813
8688	56	1370
17614	57	6684
17614	57	3124
2442	58	3993
2442	58	4527
2442	58	3083
2442	58	55
2442	58	1263
15606	59	9103
15606	59	627
15606	59	5271
15606	59	9279
15606	59	3880
15606	59	6385
15606	59	5395
11554	60	7893
11554	60	3819
7747	61	8493
7747	61	7145
7747	61	5162
7747	61	5025
7747	61	6719
7747	61	7560
7747	61	1391
7747	61	1959
7747	61	8443
13335	62	8885
5407	63	6577
5407	63	2220
5407	63	7785
5893	64	8735
5893	64	6740
5893	64	8326
5893	64	7734
5893	64	5905
5893	64	7638
1536	65	1790
1536	65	4431
2014	66	6077
2014	66	8058
2014	66	3988
2014	66	3943
2014	66	5997
2014	66	9016
2014	66	8813
2014	66	4607
4489	67	3012
4489	67	7495
4489	67	4859
4489	67	8589
4489	67	2932
4489	67	29
16173	68	1755
16173	68	9598
16173	68	1130
16173	68	2073
16173	68	5362
16173	68	4659
16173	68	8924
3870	69	6737
3870	69	3472
12808	70	5412
12808	70	2687
12808	70	6934
12808	70	2364
12808	70	2192
8529	71	944
19733	72	1802
19733	72	4390
19733	72	6831
2807	73	6005
17382	74	3132
17382	74	4557
17382	74	7451
17382	74	9588
17382	74	206
17382	74	8979
17382	74	398
17382	74	1839
12456	75	4090
12456	75	6019
12456	75	5634
12456	75	8033
12456	75	714
7691	76	9169
7691	76	9009
7691	76	1918
7691	76	9287
7691	76	8210
7691	76	5088
7691	76	1883
7691	76	6276
7691	76	7487
7011	77	5528
7011	77	9578
7011	77	6379
19921	78	993
19921	78	8011
19921	78	1861
19921	78	3808
19921	78	6981
19921	78	117
19921	78	1768
19921	78	1483
19921	78	6757
10955	79	2230
10955	79	4527
10955	79	5458
10955	79	8569
10955	79	3867
10955	79	1742
10955	79	2472
10955	79	9174
12310	80	5019
12310	80	180
12310	80	6195
12310	80	5202
13507	81	7883
13507	81	3252
13507	81	6380
13507	81	2436
13507	81	1382
7706	82	132
7706	82	7452
4940	83	8971
4940	83	2355
4940	83	7395
4940	83	925
4940	83	9413
5329	84	4485
5329	84	3026
5329	84	8760
13076	85	7988
13076	85	5156
13076	85	6367
13076	85	8642
13076	85	5843
13076	85	9509
13076	85	5765
13076	85	7872
13076	85	9242
2777	86	5972
2777	86	8192
2777	86	5228
3345	87	5570
3345	87	2480
3345	87	317
3345	87	7273
3345	87	2118
3345	87	9397
3345	87	7216
3345	87	3060
3345	87	1542
17189	88	8674
17189	88	8547
17189	88	9328
17189	88	5573
2284	89	3078
2284	89	2671
9578	90	2672
9578	90	3141
9578	90	804
9578	90	6633
9578	90	3277
9578	90	2465
2023	91	826
19791	92	1445
19791	92	8008
19791	92	5993
19791	92	8905
19791	92	356
19791	92	7473
19791	92	7307
7879	93	3799
7879	93	3404
18507	94	677
18507	94	1123
5134	95	6683
5134	95	3554
5134	95	8002
5134	95	7162
5134	95	7405
5134	95	3750
5134	95	8409
5134	95	7036
5134	95	65
931	96	1692
931	96	6336
931	96	3610
4986	97	7370
4986	97	7650
9623	98	9281
9623	98	6918
7907	99	4393
7907	99	5798
7907	99	142
7907	99	4453
7907	99	304
11368	100	7747
10792	101	208
10792	101	5632
10792	101	8731
10792	101	7176
14140	102	4248
8779	103	866
8779	103	7493
8779	103	8606
8779	103	5084
8779	103	5970
8779	103	1749
8779	103	9745
8779	103	3401
8779	103	1443
17236	104	5688
17236	104	5323
17236	104	592
17236	104	4325
10381	105	9932
10381	105	5271
10381	105	1091
10381	105	464
10381	105	503
10381	105	4795
10381	105	5586
7022	106	7939
7022	106	7627
16437	107	1429
16437	107	9993
16437	107	517
16437	107	2300
16437	107	4939
10804	108	5611
10804	108	1433
10804	108	7262
10804	108	4707
10804	108	9631
10804	108	2659
10804	108	5907
18937	109	2762
18937	109	4467
18937	109	7854
18937	109	9066
18937	109	157
18937	109	8194
18937	109	3622
10107	110	2520
10107	110	6789
10107	110	2353
10107	110	9409
10107	110	2583
1041	111	8451
12608	112	9096
12608	112	8924
12608	112	9567
13955	113	1651
13955	113	5801
13955	113	2269
13955	113	7886
13955	113	6412
13955	113	6561
16702	114	4607
16702	114	5743
16702	114	1225
16702	114	808
16702	114	2127
16702	114	2693
16702	114	7352
16702	114	9314
16702	114	408
5352	115	4353
5352	115	5795
5352	115	3818
5352	115	9264
5352	115	6223
3929	116	6802
3929	116	8212
3929	116	2681
3929	116	2148
3929	116	1194
3929	116	9034
3929	116	6576
3929	116	4278
17259	117	9543
17259	117	4380
17259	117	1784
17259	117	2677
17259	117	2566
17259	117	6685
17259	117	6482
18326	118	9195
16458	119	4704
16458	119	8323
16458	119	1501
16458	119	4101
16458	119	1182
16458	119	9850
16458	119	9082
16458	119	1586
16542	120	3167
16542	120	2345
16542	120	9754
3318	121	140
3318	121	7427
3318	121	976
3318	121	6305
3318	121	9971
19640	122	2346
19640	122	4284
19640	122	307
6946	123	2440
6946	123	6111
6946	123	6021
6946	123	2954
6946	123	351
2652	124	6402
19913	125	2593
19913	125	897
19913	125	488
19913	125	2173
19913	125	4676
19913	125	7287
19913	125	1143
19913	125	5514
16933	126	8846
16933	126	952
16933	126	8868
16933	126	7430
16933	126	7310
16933	126	6139
16933	126	7968
16933	126	6778
16933	126	8237
5824	127	27
5824	127	1854
5824	127	4036
5824	127	4006
5824	127	757
5824	127	5300
5824	127	1003
5824	127	9062
12742	128	6273
12742	128	4618
12742	128	1381
12742	128	2000
12742	128	5766
12742	128	1008
12742	128	4604
17278	129	5996
17278	129	8188
17278	129	6456
17278	129	5463
17278	129	7622
5159	130	5505
5159	130	1209
5159	130	1961
5159	130	9437
5159	130	938
5159	130	3519
5159	130	3305
5159	130	4180
351	131	1471
351	131	7563
351	131	4014
351	131	3841
351	131	7764
351	131	4060
351	131	7438
351	131	155
19182	132	35
19182	132	4955
19182	132	5493
19182	132	634
19182	132	9309
19182	132	4051
19182	132	1173
19182	132	7713
19182	132	6798
9124	133	7831
9124	133	413
9124	133	6721
9124	133	7576
9124	133	8302
6511	134	2389
6511	134	5660
6511	134	4259
6511	134	2477
6511	134	1325
6511	134	618
6511	134	1743
6511	134	2684
6511	134	6849
14524	135	6150
14524	135	9513
14524	135	3685
14524	135	7706
14524	135	3983
14524	135	6217
952	136	5908
952	136	4459
952	136	8799
952	136	8229
10156	137	2340
10156	137	2441
10156	137	6569
10156	137	2940
10156	137	5955
10156	137	4888
10156	137	741
5066	138	6802
5066	138	9611
5066	138	4013
5066	138	7461
5066	138	9892
5066	138	7320
5066	138	2061
5066	138	2383
5066	138	8148
2176	139	1734
2176	139	2348
2176	139	5197
13554	140	4265
13554	140	3070
1060	141	5817
1060	141	659
1060	141	7497
1060	141	2379
1060	141	1992
1060	141	6733
1060	141	1243
1060	141	5289
971	142	7262
971	142	7757
971	142	6848
971	142	9804
971	142	1356
971	142	4499
10315	143	8198
10315	143	1302
10315	143	6262
10315	143	1387
10315	143	6501
10315	143	1093
13220	144	2987
13220	144	5949
13220	144	1972
13220	144	5563
123	145	5219
123	145	9891
123	145	2977
123	145	3607
9986	146	1669
9986	146	3169
9986	146	4444
9986	146	3253
9986	146	7705
9986	146	7266
5657	147	2890
16216	148	1525
16216	148	6344
16216	148	1266
16216	148	124
16216	148	1298
8933	149	1025
17457	150	8405
17457	150	7810
17457	150	9054
17457	150	4909
17457	150	8808
663	151	5462
663	151	1379
663	151	5261
663	151	7377
663	151	7143
663	151	1387
18206	152	4085
18206	152	2970
18206	152	6707
18206	152	2594
18206	152	6338
11606	153	1612
11606	153	8817
8154	154	5179
13131	155	5669
19505	156	1647
19505	156	9958
19505	156	1491
19505	156	5641
19505	156	2098
19505	156	8628
19505	156	4567
19505	156	6699
4730	157	5174
4730	157	3265
4730	157	5674
4730	157	4019
4730	157	8685
4730	157	8572
4730	157	7064
17109	158	5620
8495	159	1692
8495	159	9496
13993	160	2648
13993	160	1016
13993	160	2109
13993	160	8959
13993	160	2223
18573	161	7841
18573	161	5906
18573	161	7803
18573	161	7707
18573	161	5640
18573	161	5761
10908	162	321
10908	162	5697
10908	162	3100
4117	163	9588
4117	163	7878
4117	163	5415
4117	163	6529
4117	163	9178
4117	163	4809
4117	163	2764
4117	163	6282
17784	164	1413
17784	164	2493
17784	164	5633
17784	164	4913
17784	164	7651
17784	164	593
17784	164	3230
17289	165	9965
17289	165	3745
17289	165	250
17289	165	5222
17289	165	5032
17289	165	5423
17289	165	8518
17289	165	3307
17289	165	3943
17710	166	2364
17710	166	1492
17710	166	5
17710	166	4238
8405	167	8976
8405	167	4042
8405	167	4337
8405	167	5001
8405	167	8082
8405	167	6594
8405	167	4530
2265	168	5386
2265	168	2802
5612	169	6998
5612	169	5789
9528	170	8961
9528	170	5692
9528	170	6457
9528	170	7480
9528	170	5163
9528	170	3588
5957	171	4734
5957	171	5404
5957	171	2366
5957	171	3668
5957	171	1703
5957	171	3918
5957	171	4220
5957	171	900
13183	172	365
13183	172	2484
13183	172	6629
13183	172	1017
13183	172	9050
13183	172	8296
13183	172	7334
13183	172	5865
13183	172	358
4120	173	6340
4120	173	9259
4120	173	6389
7059	174	8150
7059	174	9722
7059	174	223
7059	174	4548
5688	175	6543
5688	175	5544
5688	175	8454
5688	175	8961
5688	175	7585
5688	175	651
14079	176	569
14079	176	565
14079	176	4897
14079	176	3498
14079	176	1025
14079	176	4392
14895	177	6368
14895	177	4333
14895	177	5532
14895	177	2264
14895	177	8594
14895	177	9960
14895	177	9953
1044	178	9241
1044	178	8354
1044	178	9798
1044	178	783
1044	178	8916
1044	178	1637
1044	178	9103
1044	178	5223
1509	179	3871
1509	179	8003
1509	179	6454
1509	179	2866
1509	179	8478
15435	180	455
2474	181	2908
2474	181	2968
2474	181	954
2474	181	5446
2474	181	8944
2474	181	8868
2474	181	7495
2474	181	6644
19018	182	2157
19018	182	1020
19018	182	305
119	183	8730
119	183	867
119	183	7630
119	183	9887
119	183	5600
119	183	5249
119	183	1645
119	183	1337
12324	184	9464
12324	184	4525
12324	184	9435
12324	184	1958
12324	184	4888
7233	185	5313
7233	185	6645
7233	185	993
7233	185	4029
7233	185	6710
16093	186	4208
16093	186	273
16093	186	1709
16093	186	4156
16093	186	9626
16093	186	7184
2282	187	5965
5219	188	4853
5219	188	6221
5219	188	8342
5219	188	9609
5219	188	882
5219	188	4058
5219	188	7489
5219	188	5952
5219	188	6910
8185	189	5233
8185	189	9607
8185	189	1660
8185	189	3807
8185	189	8572
8185	189	2969
8185	189	222
8185	189	9997
1756	190	2032
1756	190	3435
1756	190	2779
1756	190	3560
1756	190	4436
1756	190	9074
1756	190	1866
7051	191	3825
7051	191	3333
7051	191	636
7051	191	8103
7051	191	3385
14063	192	8167
14063	192	1526
14063	192	3161
14063	192	1481
1108	193	9234
13013	194	2351
13013	194	4741
13013	194	9691
13013	194	3619
13013	194	4558
13013	194	107
13013	194	8672
13013	194	6757
19836	195	7515
9560	196	2912
11433	197	1854
11433	197	2330
11433	197	4266
11433	197	4619
11433	197	1078
11433	197	2762
11433	197	2998
11433	197	9946
11433	197	9437
13901	198	1731
13901	198	4654
13901	198	2585
13901	198	359
4424	199	3756
4424	199	9268
4424	199	3776
13076	200	6057
13076	200	8314
13076	200	5265
13076	200	2443
13076	200	5396
13076	200	8354
1876	201	204
1876	201	1386
1876	201	6005
1876	201	5846
1876	201	3516
1876	201	5618
1876	201	6159
1876	201	2713
1876	201	5750
2028	202	5518
7742	203	4809
7742	203	2313
7742	203	2081
16170	204	3358
16170	204	1370
15058	205	9744
15058	205	2709
9924	206	2612
9924	206	836
9924	206	5065
9924	206	9705
9924	206	656
9924	206	1076
9924	206	9870
6453	207	2201
6453	207	7206
6453	207	2921
6453	207	7320
6453	207	4402
6453	207	591
6453	207	5733
6453	207	3930
6453	207	3512
6431	208	5000
6431	208	9428
6431	208	7361
19260	209	868
7578	210	9418
7578	210	3269
7578	210	7974
7578	210	3210
7578	210	5570
15564	211	650
15564	211	4716
15564	211	9804
15564	211	7813
15564	211	1707
15564	211	8195
15564	211	9843
2822	212	7381
2822	212	5788
2822	212	2145
2822	212	7257
2822	212	5718
2822	212	5496
12290	213	6223
8069	214	9259
8069	214	6497
8069	214	1860
8069	214	513
15785	215	3246
15785	215	3424
15785	215	4739
15785	215	8657
8160	216	4219
8160	216	5773
8160	216	6635
8160	216	356
8160	216	547
4814	217	4143
4814	217	3400
4814	217	2777
4814	217	6047
4814	217	7148
11609	218	9884
8205	219	537
8205	219	5349
11791	220	8302
11791	220	3027
11791	220	5804
11791	220	1467
11791	220	3071
11791	220	4780
11791	220	8298
18631	221	6712
18631	221	9
18631	221	7054
18631	221	3339
18631	221	1437
18631	221	8298
13199	222	9044
13199	222	2834
13199	222	1018
13199	222	8023
13199	222	6122
13199	222	5917
12340	223	1937
12340	223	9055
12340	223	8603
78	224	9219
78	224	6289
78	224	8046
78	224	8290
78	224	5842
78	224	6783
78	224	5105
78	224	185
78	224	5048
6196	225	1156
6196	225	8118
6196	225	9615
6196	225	9797
6196	225	9199
6196	225	9508
6196	225	4868
6196	225	819
6196	225	8434
10432	226	8121
10432	226	8589
10432	226	6528
10432	226	6266
10432	226	4906
10432	226	1916
10432	226	7180
13953	227	5992
13953	227	7218
16074	228	4697
16074	228	111
16074	228	4049
16074	228	5929
16074	228	1399
15328	229	5086
15328	229	6346
15328	229	595
19989	230	8902
19989	230	6091
19989	230	5864
19989	230	257
19989	230	6587
1271	231	3273
1271	231	4166
2634	232	383
2634	232	5009
2634	232	235
1686	233	8670
1686	233	5236
1686	233	5680
1686	233	5093
1686	233	5859
1686	233	2902
1686	233	2582
1686	233	4451
1686	233	7864
5751	234	4233
5751	234	9424
5751	234	4113
5751	234	5310
5751	234	268
5751	234	9168
5751	234	8511
5751	234	995
13707	235	1309
11518	236	7868
11518	236	6926
11518	236	317
11518	236	2584
13392	237	291
18916	238	4305
18916	238	7027
18916	238	3755
18916	238	1430
15234	239	1667
15234	239	4235
15234	239	1411
7989	240	691
7989	240	6308
7989	240	4831
7989	240	439
7989	240	4644
3340	241	3173
3340	241	6455
14552	242	5966
14552	242	5464
14552	242	2884
14552	242	1370
14552	242	588
14552	242	1603
14552	242	3041
6958	243	8221
6958	243	4430
6958	243	6201
5311	244	9932
5311	244	4044
5311	244	1762
5311	244	3272
5311	244	4721
5311	244	1821
5311	244	6702
19485	245	3221
2884	246	5821
2884	246	5111
2884	246	692
2884	246	4960
2884	246	7874
2884	246	6519
2884	246	8511
6463	247	8540
6463	247	9524
6463	247	876
6463	247	1065
6463	247	6406
6463	247	5538
2718	248	9147
2718	248	1208
2718	248	7590
2718	248	3110
2718	248	8717
2718	248	3899
2718	248	4851
6782	249	4136
6782	249	8000
6782	249	4437
6782	249	9345
6782	249	2645
6782	249	1334
6782	249	7763
6782	249	5889
6957	250	7587
6957	250	9316
6957	250	9765
6957	250	9817
6957	250	7557
6957	250	7482
6957	250	9622
8116	251	4033
8116	251	7236
8116	251	1452
8116	251	5846
8116	251	3968
8116	251	818
16809	252	9890
16809	252	1610
16809	252	7412
16809	252	8988
16809	252	859
16809	252	374
16809	252	2667
13398	253	2065
13398	253	6220
376	254	2207
376	254	802
376	254	3915
11048	255	4691
11048	255	1849
11048	255	7993
11048	255	3299
11048	255	2481
11048	255	7358
11048	255	8509
9456	256	4916
14245	257	8116
14245	257	4979
14245	257	1583
14245	257	4615
12926	258	8685
12926	258	3413
12926	258	2406
1829	259	5642
1829	259	7031
1829	259	3198
1829	259	7681
1829	259	4804
1829	259	1401
5965	260	9255
5965	260	4533
5965	260	2673
5965	260	6197
5965	260	4383
5965	260	6856
5965	260	9517
5965	260	6760
7581	261	4307
7581	261	3112
7581	261	9192
7581	261	8893
7581	261	7495
7581	261	717
7581	261	3970
13285	262	2728
13285	262	2624
13285	262	3666
13285	262	6631
2405	263	8972
2405	263	6411
2405	263	7632
13048	264	575
13048	264	838
13048	264	4214
13048	264	1188
7830	265	3498
7830	265	7449
7830	265	9619
7830	265	1331
7830	265	7761
8342	266	9773
8342	266	6510
8342	266	3068
8342	266	6986
8342	266	1630
8342	266	2569
8342	266	3880
8342	266	6732
8342	266	563
16022	267	2758
16022	267	2055
16022	267	1990
16022	267	4689
16022	267	4394
16022	267	3353
16022	267	2482
16022	267	7987
19232	268	2433
19232	268	8149
19232	268	3956
5117	269	780
5117	269	1439
5117	269	9997
5117	269	7243
5117	269	7802
5117	269	9146
5117	269	2539
5117	269	7575
5117	269	1094
3521	270	6307
3521	270	1738
3521	270	7657
8757	271	3858
8757	271	6434
8757	271	5747
8757	271	8539
15368	272	9311
15368	272	8375
15368	272	179
15368	272	2164
15368	272	1089
15368	272	9921
15368	272	8733
15368	272	3956
9672	273	7155
9672	273	9666
9672	273	5262
9672	273	6449
9672	273	5889
9672	273	8423
13593	274	5312
13593	274	4581
13593	274	6237
13593	274	9226
6361	275	8017
6361	275	9844
6361	275	3259
6361	275	8071
9038	276	5670
9038	276	8801
9038	276	4312
9038	276	2703
14566	277	1784
14566	277	3373
14566	277	8429
14566	277	7893
14566	277	1566
14566	277	1615
14566	277	7246
14566	277	3345
4875	278	9953
4875	278	8970
4875	278	1764
4875	278	3889
4875	278	8955
4875	278	2336
4875	278	5160
4875	278	4598
4875	278	5601
14331	279	1990
14331	279	1334
11075	280	5411
8761	281	6053
10014	282	5745
10014	282	2093
10014	282	4537
10014	282	2832
10014	282	4859
10014	282	6218
15101	283	3088
15101	283	3953
15101	283	7677
19331	284	5543
19331	284	3938
19331	284	2860
19331	284	2280
19331	284	24
19331	284	2646
19331	284	1386
19331	284	5914
19331	284	4352
13066	285	6486
13066	285	6740
13066	285	5663
13066	285	3827
13066	285	8550
13066	285	4562
13066	285	700
13066	285	2170
4387	286	5049
4387	286	2523
4387	286	8785
4387	286	7404
4387	286	3407
19784	287	4054
19784	287	8537
19784	287	3912
19784	287	7248
19784	287	9574
19784	287	5895
19784	287	927
19784	287	3937
19784	287	3286
11617	288	2682
12178	289	5981
12178	289	5722
12178	289	144
12178	289	7913
12178	289	1345
12178	289	2529
12178	289	3108
8069	290	4757
8069	290	5584
8069	290	5785
8069	290	7347
8069	290	2880
8069	290	4556
1072	291	569
1072	291	8755
1072	291	5556
1072	291	3642
1072	291	1019
7361	292	279
7361	292	3175
7361	292	2201
19095	293	1519
19095	293	1308
19095	293	2517
19095	293	4791
7090	294	3645
7090	294	7802
7090	294	1959
7090	294	8343
7090	294	7507
7090	294	8284
7090	294	4483
7090	294	9641
7090	294	31
3099	295	1843
3099	295	4114
16553	296	7995
16553	296	1424
16553	296	8485
16553	296	106
16553	296	6125
16553	296	5449
19862	297	5804
19862	297	4999
19862	297	6471
19862	297	7398
19862	297	5609
19862	297	4947
19862	297	9788
19862	297	6472
15789	298	1276
15789	298	4259
15789	298	1295
15789	298	1808
15789	298	9638
15789	298	7521
15789	298	1620
16181	299	6404
16181	299	298
16181	299	2430
16181	299	6475
16181	299	7868
16181	299	6796
16181	299	2853
16181	299	5129
12847	300	6012
12847	300	3977
12847	300	1898
12847	300	6052
12847	300	3688
12847	300	2073
12847	300	4790
14440	301	6121
14440	301	3336
14440	301	1770
14440	301	987
14440	301	3299
14440	301	3322
14440	301	3737
14440	301	6573
16940	302	1756
16940	302	1533
16940	302	7089
16940	302	6198
16940	302	3542
16940	302	6445
16940	302	8978
16940	302	2578
16940	302	5969
18535	303	9384
11914	304	4427
11914	304	2078
11914	304	1781
17738	305	7398
17738	305	4861
17738	305	3136
17738	305	3623
17738	305	4585
17738	305	9278
18602	306	3061
18602	306	4198
18602	306	6652
18602	306	9317
18602	306	4807
18602	306	2338
18602	306	9966
18602	306	1024
11769	307	9723
11769	307	4592
11769	307	4419
11769	307	6535
11769	307	3171
11769	307	1517
11769	307	3218
11769	307	764
160	308	1177
160	308	3961
160	308	3206
160	308	8507
160	308	868
160	308	7826
160	308	4541
160	308	4896
160	308	6287
18914	309	5687
18914	309	9465
18914	309	4246
18914	309	6530
15413	310	8849
15413	310	1892
15413	310	5933
15413	310	7068
15413	310	3349
15413	310	6176
15413	310	566
5599	311	6549
12027	312	9816
12027	312	2297
12027	312	8291
12027	312	9672
12027	312	3060
12027	312	4495
12027	312	4322
12027	312	2751
12027	312	3170
7472	313	6535
7472	313	6423
7472	313	913
7472	313	9097
7472	313	1085
7472	313	5553
7687	314	983
7687	314	2911
14465	315	4903
14465	315	3186
14465	315	3946
14465	315	6407
5659	316	4460
5659	316	3762
5659	316	1574
5659	316	8925
5659	316	3158
5659	316	4598
5659	316	897
5659	316	9618
13315	317	6867
13315	317	460
13315	317	4424
13315	317	1292
13315	317	9696
13315	317	1100
13315	317	7516
13315	317	9700
13315	317	4176
14667	318	1474
14667	318	4444
14667	318	306
14667	318	7749
14667	318	8826
14667	318	6819
14667	318	5427
13437	319	1574
13437	319	5
13437	319	9510
13437	319	8178
13437	319	8327
13437	319	1019
4985	320	3584
4985	320	1079
19809	321	9191
19809	321	8567
19809	321	8091
19809	321	1192
19809	321	6764
19809	321	8753
19809	321	899
18452	322	4557
15575	323	1324
15575	323	8384
15575	323	7776
15575	323	9153
15575	323	5703
15575	323	2309
15575	323	9835
13195	324	2870
13195	324	9141
13173	325	1484
13173	325	7165
13173	325	4324
13173	325	6148
13173	325	316
13173	325	7037
13173	325	890
13173	325	7187
13173	325	6533
19981	326	2201
19981	326	6990
3622	327	1188
3622	327	391
3622	327	7688
7671	328	7759
7671	328	6623
7671	328	7198
7671	328	1847
7671	328	830
7671	328	3721
7671	328	9941
13861	329	8741
19857	330	8281
19857	330	8472
19857	330	6122
19857	330	2275
17795	331	2706
17795	331	1278
17795	331	2921
17795	331	7982
17795	331	919
17795	331	9791
17795	331	9165
5064	332	6289
5064	332	255
5064	332	1861
5064	332	653
5064	332	257
5064	332	3033
5064	332	8552
5064	332	7160
160	333	2941
160	333	6172
160	333	3927
160	333	1264
160	333	7869
160	333	5264
160	333	6464
16649	334	2460
16649	334	574
16649	334	4934
16649	334	1231
16649	334	8954
16649	334	2174
16649	334	7761
16649	334	9527
16649	334	7846
18217	335	8832
18217	335	1294
18217	335	1529
18217	335	3620
18217	335	9782
18217	335	5572
18217	335	1572
5606	336	3308
5606	336	2215
5606	336	9887
5606	336	4999
5606	336	5195
5606	336	6840
5606	336	1404
5606	336	1955
6967	337	6906
6967	337	667
6967	337	3044
6967	337	2984
6967	337	5042
16697	338	9416
16697	338	4913
16697	338	7973
9626	339	485
2904	340	6039
2904	340	8379
2904	340	872
2904	340	8944
2904	340	3946
2904	340	9438
19587	341	35
19587	341	6163
9688	342	4929
9688	342	7150
9688	342	4757
9688	342	3400
9688	342	7032
9688	342	7501
9688	342	3201
9688	342	1759
9688	342	430
5526	343	4512
1349	344	5519
1349	344	5349
1349	344	5157
1349	344	8158
1349	344	1136
1349	344	708
16417	345	4653
16417	345	3681
16417	345	9024
16417	345	7845
16417	345	5852
16417	345	1037
136	346	1920
136	346	8996
136	346	3010
136	346	6989
136	346	8711
136	346	2312
136	346	5905
136	346	8580
4522	347	7990
4522	347	5245
4522	347	5841
4522	347	2801
4522	347	6349
16536	348	5344
16536	348	3570
16536	348	5632
16536	348	29
16536	348	4325
16536	348	6325
5066	349	7765
5066	349	5612
2905	350	324
2905	350	7762
2905	350	3907
2905	350	4160
2905	350	7726
2905	350	1583
2905	350	9
2905	350	1301
2905	350	7543
8064	351	6161
8064	351	5557
8064	351	932
444	352	5861
444	352	1292
444	352	6348
444	352	9017
1199	353	2210
1199	353	7523
1199	353	6354
13022	354	4433
13022	354	1716
13022	354	5272
13022	354	5586
13022	354	8488
13022	354	7729
13022	354	1214
13022	354	5230
13022	354	8149
11155	355	4307
11155	355	2791
11155	355	3882
2088	356	3763
2088	356	6969
5109	357	4001
5109	357	1439
13337	358	5078
13337	358	2184
13337	358	9312
13337	358	5798
13337	358	7151
13337	358	8676
10388	359	3427
10388	359	3520
10388	359	5448
10388	359	8261
10388	359	4557
6030	360	9622
3611	361	8296
3611	361	7792
3611	361	3600
3611	361	9768
3611	361	1662
3611	361	8808
4654	362	2501
4654	362	3484
4654	362	9649
4654	362	72
19387	363	1499
19387	363	321
19387	363	9504
19387	363	5241
19387	363	4580
12482	364	1329
12482	364	8559
12482	364	3324
12482	364	2967
12482	364	8116
12482	364	4952
6405	365	7833
6405	365	1676
6405	365	9174
6405	365	6265
6405	365	4283
6405	365	9424
250	366	9414
250	366	1431
250	366	7555
250	366	9543
250	366	7011
250	366	3858
250	366	7697
250	366	1733
6817	367	4588
17740	368	577
17740	368	4255
17740	368	6286
17740	368	5011
5131	369	8236
5131	369	441
5131	369	4765
5131	369	3833
5131	369	3666
5131	369	9906
8987	370	3364
8987	370	4079
8987	370	5951
8987	370	2454
8987	370	2002
8987	370	9953
8987	370	30
8987	370	4353
8987	370	1189
11905	371	2450
11905	371	9142
11905	371	3941
11905	371	6849
424	372	4152
424	372	6746
424	372	7497
424	372	4069
424	372	7153
424	372	9515
424	372	2364
424	372	6299
18458	373	5825
18458	373	1460
18458	373	440
18458	373	996
18458	373	8521
18458	373	3186
18458	373	5565
18458	373	9277
18458	373	8679
11663	374	7337
7270	375	2864
7270	375	6487
7270	375	5499
7270	375	8453
7270	375	6255
7270	375	712
7270	375	9753
10634	376	8378
10634	376	71
10634	376	8338
10634	376	8912
10634	376	7322
10634	376	9309
10634	376	7020
7012	377	1452
7012	377	733
7012	377	8761
7012	377	2482
7012	377	5342
18339	378	1676
18339	378	1095
13	379	9645
13	379	1411
1411	380	5499
1411	380	7340
1411	380	9328
1411	380	7676
1411	380	4614
1411	380	1739
1411	380	2186
1411	380	652
3493	381	1753
3493	381	913
3493	381	4555
3493	381	8061
3493	381	3029
3493	381	9749
3493	381	9851
3493	381	4759
3493	381	3189
15605	382	6246
15605	382	1119
15605	382	1496
10739	383	4929
18966	384	1204
18966	384	8082
18966	384	379
18966	384	8041
18966	384	7111
18966	384	7571
18966	384	9031
18966	384	824
18966	384	657
4305	385	7522
4900	386	1933
4900	386	2857
4900	386	935
2625	387	6450
2625	387	3357
4774	388	7664
4774	388	6844
4774	388	9850
4774	388	655
4774	388	8781
18084	389	8126
18084	389	4889
17953	390	1105
17953	390	3516
17953	390	842
17953	390	6848
17953	390	2496
17953	390	5581
17953	390	4349
10005	391	6870
10005	391	2181
10005	391	4374
18524	392	8239
18524	392	5670
18524	392	6559
18524	392	3803
18524	392	6779
18524	392	5284
18524	392	5162
18524	392	8613
5942	393	6110
5942	393	1715
5942	393	3122
5942	393	8597
5942	393	5350
5942	393	724
5942	393	7701
5942	393	2931
5942	393	5579
4714	394	1631
4714	394	7806
4714	394	2055
4714	394	3214
4714	394	3193
4714	394	7948
4714	394	7614
12422	395	4174
12422	395	9933
12422	395	777
12422	395	6133
12422	395	9596
12422	395	8712
683	396	585
683	396	6639
683	396	8145
12185	397	7163
1644	398	5206
1644	398	2992
18249	399	6916
18249	399	1445
18249	399	1390
18249	399	4189
18249	399	2546
1381	400	6783
1381	400	9629
1381	400	1126
1381	400	4767
1381	400	7693
1381	400	5210
1381	400	5954
1381	400	9809
1381	400	4546
11980	401	6958
19006	402	194
19006	402	7367
19006	402	9439
19006	402	921
19006	402	3568
19006	402	3766
19006	402	5659
19006	402	1945
3507	403	8478
3507	403	9591
3507	403	9969
3507	403	9411
5596	404	6842
5596	404	3220
5596	404	5505
5596	404	6844
5596	404	9827
5596	404	333
4556	405	4031
4556	405	2242
4556	405	6241
4556	405	9358
4556	405	8380
4556	405	8879
4556	405	1567
4556	405	673
7784	406	8032
7784	406	3109
7784	406	2142
7784	406	3342
877	407	7438
877	407	2258
877	407	4441
877	407	9887
877	407	384
877	407	7249
877	407	8788
877	407	359
877	407	1814
19690	408	7703
19690	408	7905
19690	408	446
19690	408	1483
19690	408	3373
11260	409	7246
11260	409	681
11260	409	1250
11260	409	9580
11260	409	5851
11260	409	7357
11260	409	4984
11260	409	7510
10423	410	6256
15476	411	6658
15476	411	3707
15476	411	2822
15476	411	1740
15476	411	8581
15476	411	1431
15476	411	3026
15476	411	8098
6162	412	4643
6162	412	7667
6162	412	3352
16111	413	6132
16111	413	2150
16111	413	7573
16111	413	791
16111	413	8474
16111	413	2301
16111	413	7532
11258	414	8710
11258	414	4588
4508	415	6176
15671	416	6153
15671	416	4452
15671	416	8236
15671	416	3037
15671	416	4613
4289	417	7773
4289	417	5932
4289	417	1178
4289	417	9835
16219	418	2035
16219	418	6784
16219	418	1773
16219	418	6413
16219	418	6661
16219	418	1466
16219	418	1358
16219	418	5034
16219	418	8223
11991	419	2478
11991	419	8220
11991	419	1501
11991	419	421
11991	419	9941
11991	419	7338
11991	419	5605
4034	420	6666
4034	420	6017
4034	420	2878
4034	420	5994
4034	420	6749
4034	420	7096
19147	421	1885
19147	421	4676
19147	421	3748
19147	421	4762
731	422	2383
18096	423	7071
18096	423	4386
18096	423	6305
18096	423	828
12583	424	9975
12583	424	5594
18682	425	426
18682	425	2291
9346	426	3721
9346	426	2258
9346	426	3680
9346	426	3856
9346	426	7779
9346	426	3385
9346	426	974
9346	426	9757
9346	426	1218
16763	427	308
16763	427	5469
16763	427	5737
16763	427	7271
16763	427	5995
16504	428	4895
16504	428	4023
16504	428	321
16504	428	406
326	429	5513
326	429	3365
326	429	2706
326	429	5321
326	429	6270
7080	430	4532
7080	430	9493
8776	431	7061
8776	431	8770
5072	432	7519
5072	432	3652
5072	432	3347
5072	432	4555
5072	432	4532
5072	432	9724
5332	433	5968
5332	433	5210
5332	433	4900
5332	433	4670
5332	433	9434
5332	433	9427
5332	433	5976
5332	433	8811
5332	433	199
7090	434	2212
7090	434	9754
7090	434	3130
7090	434	4602
7090	434	3012
7090	434	4661
7090	434	3876
7090	434	5383
7090	434	1521
1896	435	8005
1896	435	1454
1896	435	9090
1896	435	1748
1896	435	4761
1896	435	1261
1896	435	5895
1896	435	8632
3288	436	9865
3288	436	2760
3288	436	3486
10941	437	3431
10941	437	4508
10941	437	1436
10941	437	715
10941	437	1508
10941	437	7142
10941	437	9990
10941	437	7157
11390	438	8894
11390	438	9535
11390	438	5377
11390	438	5934
11390	438	8491
3841	439	6805
3841	439	1426
3841	439	9013
3841	439	2994
3841	439	5700
3841	439	9191
3841	439	1605
3841	439	8551
14889	440	9098
14889	440	9872
14889	440	2816
14889	440	6194
14889	440	283
14889	440	3962
14889	440	6418
10861	441	1586
10861	441	583
10861	441	6875
10861	441	3498
10861	441	4058
10861	441	2870
10861	441	7667
15076	442	5900
15076	442	2383
15076	442	3779
15076	442	3269
15076	442	1732
15076	442	5627
14423	443	7988
14423	443	8244
14423	443	6368
14423	443	2299
14423	443	8359
14423	443	1204
16402	444	1392
16402	444	9585
16402	444	6766
16402	444	5366
1985	445	8204
1985	445	2258
1985	445	3559
1985	445	7676
1985	445	2804
1985	445	9163
732	446	8567
732	446	845
732	446	1413
732	446	5129
732	446	3283
732	446	6676
732	446	1487
19381	447	5881
19381	447	2972
19381	447	1324
972	448	852
972	448	911
972	448	880
972	448	9377
9010	449	5000
9010	449	9479
9010	449	2369
9010	449	6177
9010	449	2160
10263	450	906
10263	450	3413
10263	450	2612
7046	451	5279
7046	451	901
7046	451	7564
7046	451	2932
7046	451	8517
7046	451	9049
7046	451	2100
7046	451	1093
5393	452	5624
5393	452	2038
5393	452	8138
11735	453	4477
11735	453	40
11735	453	913
11735	453	6749
11735	453	166
11735	453	6254
11735	453	6151
14486	454	9940
14486	454	4615
13304	455	1301
18945	456	2922
7669	457	7679
7669	457	8171
7669	457	1903
12683	458	8062
12683	458	6899
12683	458	7066
12683	458	9329
12683	458	9633
11873	459	6717
11873	459	9362
11873	459	6857
11873	459	5779
7897	460	8270
7897	460	2817
7897	460	5646
7897	460	1337
7897	460	3555
7897	460	1741
2748	461	7311
2748	461	4071
2748	461	6636
2748	461	6900
2748	461	5318
2748	461	8027
2748	461	6626
2748	461	6367
2748	461	7243
5776	462	5432
5776	462	4468
5776	462	6499
5776	462	8546
5776	462	4163
5776	462	3624
517	463	3750
517	463	9459
517	463	6874
517	463	8269
517	463	979
517	463	2424
517	463	8399
7660	464	1003
7660	464	773
7660	464	2610
7660	464	5404
7660	464	3169
7660	464	6491
482	465	2018
482	465	7609
17174	466	4294
17174	466	6841
17174	466	8026
17174	466	2305
6156	467	8014
6156	467	4383
6156	467	9264
6156	467	6018
6156	467	1115
6156	467	2856
6156	467	6529
6156	467	3417
18428	468	3409
18428	468	9410
18428	468	2599
18428	468	462
18073	469	3015
18073	469	3988
18073	469	1545
5317	470	5790
5317	470	6928
5317	470	2831
5317	470	8421
5317	470	9323
5317	470	5306
15807	471	6043
15807	471	2761
15807	471	8046
15807	471	3002
9092	472	7205
9092	472	8127
10109	473	1033
10109	473	2728
10109	473	2450
10109	473	9087
10109	473	5936
10109	473	9438
10109	473	4774
5637	474	4852
5637	474	1856
5637	474	7689
5637	474	6770
5637	474	2055
5637	474	870
5637	474	8099
1652	475	8859
1652	475	3039
1652	475	877
1652	475	6773
1652	475	4673
1652	475	8468
1652	475	8391
493	476	9307
493	476	2175
493	476	7999
493	476	5617
493	476	4947
493	476	6924
11564	477	576
14697	478	8429
14697	478	649
14697	478	6859
14697	478	7066
14697	478	5680
14697	478	4049
14697	478	7734
14697	478	899
11691	479	3048
11691	479	850
11691	479	2514
11691	479	1015
11691	479	8774
14405	480	4022
14405	480	3817
14405	480	3553
14405	480	7459
14405	480	7351
16500	481	4095
16500	481	2861
16500	481	4040
16500	481	8736
16500	481	5136
16500	481	2397
16500	481	5837
16500	481	1112
10265	482	6219
10265	482	4055
10265	482	3100
10265	482	8869
10265	482	9656
7500	483	893
7500	483	7113
7500	483	382
7500	483	9379
10431	484	677
10431	484	2402
10431	484	4324
10431	484	8121
10431	484	2297
10431	484	9784
10431	484	3970
9022	485	7914
9022	485	2192
9022	485	3710
9022	485	7275
9022	485	5352
9022	485	8303
9022	485	702
9022	485	4141
16929	486	6843
16929	486	943
16929	486	5184
16929	486	6065
16929	486	9423
16929	486	2120
16929	486	3334
16929	486	2362
16929	486	6885
4473	487	6612
4473	487	7413
4473	487	6872
4473	487	9216
4473	487	8737
4473	487	2612
4473	487	2684
4473	487	4591
8026	488	1349
8026	488	7982
8026	488	8377
8026	488	3346
12829	489	184
12829	489	4465
12829	489	3366
12829	489	5649
16522	490	6056
16522	490	1171
16522	490	384
3465	491	5442
3465	491	4124
3465	491	7388
3465	491	5202
3465	491	4939
3465	491	8680
3465	491	2441
3465	491	3085
3465	491	4148
11856	492	2300
11856	492	14
11856	492	5587
12183	493	4972
12183	493	8645
12183	493	5900
12183	493	6687
12183	493	9232
12183	493	242
12183	493	7411
12183	493	9763
12183	493	6149
2788	494	7810
2788	494	2468
2788	494	9826
2788	494	9488
2788	494	6740
2788	494	5050
2788	494	6819
2788	494	9231
2788	494	1787
4056	495	5353
4056	495	7841
4056	495	6012
4056	495	2895
4056	495	5112
4056	495	3067
5784	496	3268
5784	496	8048
5784	496	6587
5784	496	9267
2107	497	3082
2107	497	3524
2107	497	4313
2107	497	9936
2107	497	6691
2107	497	4856
2107	497	3534
15268	498	1222
15268	498	5045
15268	498	2399
15268	498	4135
5011	499	9748
5011	499	6141
906	500	777
906	500	6999
906	500	3127
906	500	3554
8735	501	8449
8735	501	8656
8735	501	3025
8735	501	2513
8735	501	5295
8735	501	2199
8735	501	1031
8735	501	8314
8735	501	8792
19136	502	5200
19136	502	6963
19136	502	9908
19136	502	3121
19136	502	4516
19136	502	7651
1350	503	1147
1350	503	160
1350	503	6298
1350	503	1684
1350	503	6454
11774	504	2318
11774	504	9234
18281	505	5397
18281	505	8686
18281	505	2096
18281	505	3723
18281	505	6030
18281	505	9312
18281	505	8214
19795	506	373
19795	506	9718
19795	506	9612
19795	506	5658
19308	507	6770
19308	507	4651
19308	507	6430
19308	507	6556
19308	507	4803
19308	507	5022
6470	508	3132
6470	508	9982
6470	508	7721
6470	508	3919
6470	508	1736
6470	508	6179
8328	509	7547
8328	509	1455
8328	509	176
8328	509	4129
8328	509	596
8328	509	9093
17630	510	8757
17630	510	9020
17630	510	5201
17630	510	3811
17630	510	2515
3490	511	7745
3490	511	2198
3490	511	5675
3490	511	7210
3490	511	7352
3490	511	8953
3490	511	7174
3490	511	5259
8031	512	493
8031	512	8811
8031	512	331
8031	512	4292
8031	512	3071
8031	512	9088
2569	513	3658
2569	513	5620
2569	513	5030
2569	513	7453
2569	513	5909
2569	513	4896
6177	514	6483
6177	514	1523
6177	514	8770
6177	514	7133
6177	514	4257
6177	514	2656
6177	514	7504
2323	515	2171
2323	515	405
2323	515	7128
2323	515	2335
2323	515	9075
2323	515	5111
3187	516	8406
3187	516	3616
3187	516	5763
3187	516	1757
3187	516	2271
3187	516	1089
3187	516	422
3187	516	8318
17446	517	5036
17446	517	5057
17446	517	3611
19783	518	7694
19783	518	891
19783	518	5705
19783	518	9182
19783	518	5070
19783	518	6722
19783	518	3938
4511	519	978
4511	519	6084
4511	519	6501
223	520	3
223	520	8910
19599	521	6452
19599	521	6401
19599	521	9640
19599	521	7680
19599	521	266
19599	521	5833
19599	521	7870
19599	521	1952
19599	521	2825
5896	522	4889
5896	522	9470
5896	522	6261
5896	522	3598
5896	522	1644
5896	522	3454
6187	523	6671
6187	523	4072
6187	523	1433
6187	523	9314
6187	523	5894
6187	523	1836
6187	523	5086
6187	523	7389
6187	523	8963
10448	524	490
10448	524	7418
10448	524	9251
10448	524	7037
10448	524	8239
10448	524	1849
10448	524	6211
11048	525	7662
5494	526	2721
5494	526	5379
5494	526	3084
5494	526	3862
5494	526	6148
5494	526	7517
5494	526	268
5494	526	5816
15328	527	945
15328	527	9995
15328	527	5212
15328	527	6108
15328	527	403
6246	528	9616
6953	529	4756
6953	529	6730
5091	530	209
5091	530	4321
5091	530	9412
5091	530	8761
5091	530	1971
5091	530	967
5091	530	9872
5091	530	5497
5091	530	6072
2509	531	2586
2509	531	5240
2509	531	8367
2509	531	1861
2509	531	6680
2509	531	6241
2509	531	3222
2509	531	5316
14574	532	9661
14574	532	7071
6284	533	4397
6284	533	6345
6284	533	2199
6284	533	6297
6284	533	8414
6284	533	2462
6284	533	226
6284	533	6095
2821	534	8697
2821	534	5871
2821	534	9003
2821	534	3514
2821	534	6083
959	535	7461
959	535	4530
959	535	5402
15725	536	6564
15725	536	5588
2034	537	3297
2034	537	2595
2034	537	4359
2034	537	760
14721	538	306
14721	538	7362
14721	538	2139
8105	539	6192
8105	539	9945
8105	539	8107
8105	539	2796
8105	539	9724
8105	539	5071
18858	540	9870
18858	540	6512
18858	540	842
18858	540	9171
18858	540	1651
18858	540	967
18858	540	5361
18858	540	5243
18858	540	8780
13774	541	541
13774	541	2221
13774	541	2715
13774	541	5041
13774	541	9764
13774	541	9457
595	542	8501
595	542	6179
595	542	4170
595	542	1058
595	542	3092
12847	543	2551
12847	543	5670
12847	543	2876
12847	543	5384
12847	543	9525
17962	544	9279
17962	544	3396
17962	544	9254
17962	544	7246
17962	544	1114
17962	544	2835
17962	544	8141
17962	544	629
6358	545	7951
6358	545	6761
6358	545	2922
6358	545	8482
6358	545	5266
6358	545	4274
6358	545	4415
6358	545	2323
19138	546	7872
19138	546	2562
19138	546	7360
19138	546	879
19138	546	6369
19138	546	8443
19138	546	8014
19138	546	7653
12268	547	6037
12268	547	1297
12268	547	8626
12268	547	4118
12268	547	3189
12268	547	4226
12268	547	1133
16984	548	8558
16984	548	960
16984	548	665
16984	548	2202
16984	548	9909
16984	548	4452
16984	548	442
16984	548	7548
12346	549	2042
12346	549	6264
12346	549	9608
12346	549	3054
12346	549	5888
8890	550	1445
8890	550	4565
8890	550	8358
8890	550	7335
8890	550	1064
8890	550	3296
8467	551	9289
8467	551	3421
8467	551	3093
8467	551	2948
8467	551	9709
8682	552	9932
8682	552	8593
8682	552	8370
8682	552	8969
8682	552	9758
8682	552	3481
8682	552	8643
8682	552	7287
13151	553	2128
13151	553	4317
8051	554	8366
8051	554	7220
8051	554	1913
8051	554	2794
8051	554	2761
8051	554	5985
8051	554	1794
8051	554	5572
5717	555	9434
3122	556	6636
3122	556	9960
3122	556	5616
3122	556	7735
3122	556	6624
3122	556	8647
2815	557	3926
2815	557	5378
2815	557	3409
2815	557	2356
2815	557	8167
2815	557	1386
17689	558	5794
17689	558	531
17689	558	4003
17689	558	4245
17689	558	7911
17689	558	43
17689	558	4299
17689	558	3752
17689	558	4193
15201	559	4872
12514	560	5102
12514	560	5200
12514	560	6311
12514	560	2304
12514	560	3995
3811	561	9745
6991	562	2625
6991	562	3994
6991	562	9759
6991	562	4724
6991	562	5122
6991	562	6839
4075	563	7768
4075	563	6896
4075	563	9969
4075	563	3668
4075	563	8815
4075	563	3145
10212	564	4788
10212	564	9123
10212	564	265
10212	564	6171
10212	564	3486
10212	564	5609
10212	564	5046
10212	564	342
10212	564	147
231	565	9523
231	565	1654
231	565	4901
231	565	7773
231	565	8092
231	565	3709
231	565	7108
231	565	1060
9089	566	8303
9089	566	1694
9089	566	4145
9089	566	5882
9089	566	1956
2956	567	4145
2956	567	7176
2956	567	2047
2956	567	4479
2956	567	2480
2956	567	9729
2956	567	4863
2956	567	8084
12773	568	5031
12773	568	7590
12773	568	5343
12773	568	1865
12773	568	1023
12773	568	920
16189	569	3361
16189	569	4244
16189	569	3148
16189	569	9380
16189	569	3059
16189	569	9158
16189	569	3850
16189	569	2864
905	570	9997
905	570	5908
905	570	8359
905	570	6187
6543	571	4834
6543	571	4123
6543	571	1504
6543	571	5992
6543	571	966
6543	571	1677
6543	571	6787
6543	571	3695
6973	572	5142
6973	572	6009
6973	572	1386
6973	572	8302
6973	572	5467
600	573	8282
600	573	2215
600	573	5190
600	573	9423
600	573	7996
600	573	1406
600	573	1257
600	573	5177
637	574	3820
637	574	9591
637	574	2159
637	574	3712
637	574	5357
637	574	5460
637	574	3462
17302	575	5517
17302	575	3543
17302	575	542
17302	575	3321
17302	575	4708
17302	575	6037
17302	575	2104
3388	576	6751
3388	576	3932
3388	576	8522
3388	576	5745
3388	576	7066
3388	576	634
3388	576	989
9064	577	9332
9064	577	3030
9064	577	1101
9064	577	3212
9064	577	8921
9064	577	4897
9064	577	5421
18703	578	8743
18703	578	7090
18703	578	3154
18703	578	3728
18703	578	3874
13892	579	3339
13892	579	2044
13892	579	9905
13892	579	7642
13892	579	3493
13892	579	9722
13892	579	4186
13892	579	8265
14013	580	2814
14013	580	6225
14013	580	4733
14013	580	7040
14013	580	7044
14013	580	1412
14013	580	5689
14013	580	4821
4925	581	5001
4925	581	1118
18763	582	6388
18763	582	360
13168	583	6682
13168	583	3291
13168	583	7631
13168	583	4108
13168	583	8159
13168	583	8912
13168	583	1391
13168	583	9075
13168	583	7469
15830	584	9773
15830	584	7264
15830	584	5162
1807	585	3685
1807	585	7124
1807	585	293
1807	585	4634
7090	586	6874
7090	586	7942
7036	587	6220
7036	587	121
7036	587	2162
7036	587	5898
16394	588	3787
16394	588	1184
16394	588	629
16394	588	2531
16394	588	9362
16394	588	2338
16394	588	2249
16394	588	579
16394	588	3797
32	589	3499
32	589	6399
5168	590	2453
5168	590	7576
5168	590	5459
5168	590	9455
5168	590	8992
5168	590	5841
5168	590	5052
5168	590	1607
10807	591	5420
10807	591	7039
10807	591	359
10807	591	8313
10807	591	6021
10807	591	4441
4033	592	221
4033	592	731
4033	592	381
10865	593	1063
10865	593	7550
5938	594	1886
5938	594	5984
5938	594	9483
7848	595	5941
7848	595	6130
7848	595	4152
7848	595	5372
11823	596	8058
11823	596	7680
11823	596	557
11823	596	8576
11823	596	5734
11823	596	6638
11823	596	661
11823	596	3721
8395	597	6786
8395	597	2146
8395	597	3143
8395	597	5470
8395	597	3430
8395	597	4668
4695	598	5535
4695	598	436
4695	598	6132
4695	598	2984
4695	598	3194
4695	598	3557
4695	598	902
15373	599	8624
15373	599	8888
4634	600	3804
4634	600	6723
4634	600	3005
4634	600	6567
5396	601	9490
5396	601	3212
5396	601	6946
5396	601	6755
5396	601	1799
5396	601	7539
12853	602	8743
12853	602	3962
12853	602	28
12853	602	3444
12853	602	2942
12853	602	6473
12853	602	2708
12853	602	2974
12853	602	692
15275	603	3807
15275	603	8742
17239	604	8206
17239	604	1073
17239	604	9061
17239	604	2852
17239	604	4133
17239	604	2514
17239	604	2260
10467	605	1419
10467	605	5919
10467	605	4656
10467	605	3812
10467	605	1070
10467	605	2016
10467	605	3362
10467	605	5356
8833	606	6920
8833	606	1034
8833	606	271
8833	606	4654
8833	606	8527
19890	607	1661
19890	607	1785
5708	608	1696
5708	608	5019
5708	608	9598
5708	608	1468
5708	608	2647
7361	609	6974
7361	609	2929
7361	609	4544
7361	609	5445
7361	609	1130
5828	610	5768
5828	610	6236
2507	611	8660
2507	611	4273
2507	611	4368
2507	611	4987
2507	611	4139
2507	611	4661
2507	611	7460
2507	611	6136
2507	611	8477
14267	612	8572
14267	612	6966
14267	612	3410
15847	613	3904
15847	613	6026
15847	613	8992
15847	613	459
15847	613	2972
862	614	3335
862	614	3598
862	614	9933
862	614	5929
862	614	9724
862	614	3311
18741	615	4090
18741	615	4975
18741	615	3232
18741	615	1128
18741	615	7097
14586	616	3626
14586	616	5932
14586	616	1208
14273	617	31
18868	618	4487
18868	618	9870
18868	618	1255
18868	618	3428
18868	618	6791
11201	619	8733
9329	620	529
9796	621	2577
9796	621	6685
9796	621	9151
9796	621	765
9796	621	631
9796	621	2122
9796	621	4402
1766	622	1894
1766	622	3840
1766	622	7909
16876	623	3336
16876	623	5323
16876	623	6791
16876	623	5538
16876	623	3177
16876	623	4961
16876	623	8323
16876	623	7866
4894	624	4845
17368	625	1187
17368	625	98
6866	626	9345
9766	627	1186
9766	627	9508
9766	627	680
9766	627	2232
9766	627	9820
9766	627	7179
1859	628	2589
1859	628	4731
1859	628	7889
1859	628	6119
1859	628	443
1859	628	6488
1859	628	347
3064	629	1040
3064	629	5547
3064	629	6074
3064	629	9109
3064	629	32
3064	629	4182
3064	629	8056
3064	629	7915
11607	630	9597
11607	630	1039
11607	630	6119
11607	630	1208
11607	630	2917
11607	630	2959
17012	631	3873
17012	631	8655
17012	631	6782
17012	631	7284
17012	631	9606
18124	632	4637
11351	633	7060
11351	633	4391
11351	633	7819
11351	633	3932
11351	633	5856
11351	633	2550
11351	633	7493
11351	633	3633
11351	633	4040
7290	634	2707
7290	634	7068
7290	634	7716
7290	634	3020
7290	634	160
7290	634	2288
7290	634	55
7973	635	5144
7973	635	7485
7973	635	1008
7973	635	6911
7973	635	2034
7973	635	8692
7973	635	2756
19648	636	378
19648	636	7379
19648	636	1840
3790	637	5881
3790	637	4745
3790	637	6831
3790	637	3661
3790	637	3345
3790	637	2885
3790	637	6593
18697	638	9173
18697	638	1774
18697	638	3477
18697	638	88
18697	638	8819
18697	638	7211
18697	638	2165
18697	638	5619
4897	639	287
4897	639	8346
4897	639	7861
4897	639	4746
4897	639	4287
4897	639	180
4897	639	9435
5823	640	8227
5823	640	8273
5823	640	8516
8267	641	6582
8267	641	419
8267	641	8967
13655	642	8215
13655	642	2504
13655	642	1449
13655	642	346
13655	642	4850
6154	643	8515
6154	643	6264
6154	643	4023
6154	643	9686
6154	643	95
6154	643	7473
15021	644	2295
15021	644	562
15021	644	2497
5685	645	4293
5685	645	4664
6356	646	221
6356	646	9718
6356	646	185
6356	646	11
6356	646	8873
6356	646	5168
14924	647	2261
14924	647	4022
976	648	4507
976	648	4162
976	648	8426
976	648	460
976	648	9300
976	648	8552
976	648	9989
976	648	7141
4616	649	9770
4616	649	906
4616	649	3845
4616	649	1027
4616	649	5416
4616	649	6541
4616	649	6859
4616	649	4274
4616	649	422
19442	650	9205
19442	650	1045
19442	650	3760
14763	651	9867
14763	651	452
14763	651	3212
14763	651	1757
14763	651	3090
14763	651	8550
14763	651	9000
14763	651	5233
18327	652	1646
18327	652	7365
18327	652	4691
6685	653	1765
6685	653	6840
6685	653	2082
6685	653	3694
6685	653	8679
6685	653	2135
6685	653	6732
6685	653	51
15212	654	72
15212	654	8043
15212	654	5463
15212	654	8560
15212	654	6076
15212	654	5194
15212	654	5435
15212	654	55
15212	654	2084
1524	655	7989
1524	655	4623
1524	655	9228
1524	655	5645
11433	656	3153
11433	656	5652
11433	656	5229
843	657	2454
843	657	1725
843	657	3370
843	657	5299
6576	658	1327
6576	658	6367
2483	659	4160
2483	659	2464
2483	659	7552
2483	659	1538
2206	660	724
8188	661	7996
18320	662	9552
18320	662	1988
18320	662	701
18320	662	4172
18320	662	517
16136	663	4395
16136	663	7311
16136	663	3005
16136	663	7191
16136	663	2128
16136	663	8510
4400	664	7217
4400	664	6985
4400	664	9132
4400	664	3881
4400	664	2544
4400	664	9938
4400	664	2464
13717	665	1789
17958	666	1508
11882	667	3467
902	668	8135
902	668	1567
902	668	3221
902	668	7893
902	668	5767
902	668	2543
902	668	2046
902	668	2174
19974	669	6311
19974	669	758
19974	669	3020
19974	669	574
19974	669	4675
5619	670	3489
5619	670	3488
18508	671	1722
18508	671	118
18508	671	5553
18508	671	3882
18508	671	8243
18508	671	9979
5997	672	5151
5997	672	1116
5997	672	709
5997	672	7551
5997	672	3018
5997	672	5578
16545	673	3014
16545	673	5909
19580	674	9983
19580	674	2836
19580	674	8800
19580	674	607
3445	675	7179
3445	675	8863
3445	675	8105
3445	675	6459
3445	675	2713
11451	676	4292
11451	676	6108
11451	676	102
11451	676	5916
11451	676	1098
11451	676	8997
5909	677	7621
5909	677	5251
5909	677	802
5909	677	923
5909	677	1752
5909	677	5768
5909	677	9360
5909	677	8479
9173	678	676
9173	678	5746
9173	678	4397
6125	679	1246
6125	679	7510
6125	679	1799
6125	679	9851
6125	679	5571
6125	679	6356
6125	679	3764
4484	680	6828
15007	681	9277
15007	681	3784
15007	681	272
15007	681	9659
15007	681	6797
15007	681	8013
15007	681	5479
15007	681	1316
15007	681	9466
6458	682	5471
4598	683	9803
4598	683	2991
4598	683	5905
4598	683	1833
2983	684	8659
2983	684	3646
2983	684	3570
2983	684	5186
2983	684	2632
12035	685	8769
12035	685	4034
7671	686	2915
7671	686	2105
7671	686	5428
7671	686	6239
7671	686	5410
18110	687	4016
18110	687	5432
18110	687	1793
19062	688	7922
19062	688	6085
18862	689	8682
18862	689	8961
18862	689	8054
18862	689	7231
12116	690	8455
12116	690	3350
12116	690	3182
12116	690	5582
12116	690	4673
12116	690	7279
12116	690	6476
12116	690	2855
12116	690	2794
2952	691	5585
5631	692	8873
5631	692	5370
5631	692	6709
5631	692	1214
5631	692	3861
5631	692	5736
6029	693	6378
6029	693	57
6029	693	2427
17133	694	2760
17133	694	9048
17133	694	5377
17133	694	592
17133	694	5248
17133	694	9466
6654	695	1861
6654	695	5940
6654	695	1344
2800	696	3444
2800	696	7963
2800	696	8367
2800	696	5571
2800	696	1139
2800	696	5334
2800	696	1694
2800	696	9030
2800	696	7041
592	697	9358
592	697	9334
592	697	7400
592	697	2100
592	697	5699
592	697	1023
18778	698	6803
18778	698	8494
18778	698	7251
18778	698	2717
18778	698	1347
18778	698	2499
18778	698	54
18821	699	111
18821	699	7814
7025	700	7173
7025	700	3424
7025	700	7277
7025	700	7076
8653	701	606
8653	701	4837
8653	701	3137
8653	701	4747
8653	701	4300
8821	702	6622
8821	702	8153
8821	702	2642
8821	702	4105
8821	702	6880
7911	703	8282
7911	703	3733
7911	703	415
7911	703	1992
7911	703	3458
7911	703	8867
7911	703	8210
7911	703	2169
17579	704	3164
17579	704	3810
17579	704	1120
17579	704	8651
17579	704	4645
17579	704	6065
17579	704	8913
17579	704	1814
7612	705	545
7612	705	9581
3498	706	539
3498	706	6256
3498	706	26
3498	706	971
3498	706	755
3498	706	8557
3498	706	5423
8671	707	3663
13084	708	8287
13084	708	3243
13084	708	5936
13084	708	3496
13084	708	772
1595	709	1943
1595	709	767
12380	710	526
12380	710	4434
12380	710	2322
12380	710	730
18033	711	4742
18033	711	1910
18033	711	3524
18033	711	7989
18033	711	3480
18033	711	4847
11227	712	1803
11227	712	8641
11227	712	582
11227	712	6517
14492	713	6262
14492	713	429
14492	713	7996
14492	713	9240
14457	714	5033
14457	714	3921
14457	714	5679
14457	714	7755
14457	714	885
14457	714	9810
14457	714	9469
14457	714	4370
8402	715	5147
8402	715	837
8402	715	8007
8402	715	4662
8402	715	7305
8402	715	1525
8402	715	9947
8402	715	5746
8402	715	5289
12347	716	7640
12347	716	9242
12347	716	283
11045	717	1191
11045	717	4500
18322	718	9042
17977	719	4614
17977	719	2447
17977	719	655
17977	719	637
17977	719	1703
17977	719	304
17977	719	2692
17977	719	7509
17977	719	7871
4740	720	1531
4740	720	3243
4740	720	3865
6117	721	7540
6117	721	1895
6117	721	176
6117	721	6488
13583	722	3306
13583	722	439
13583	722	71
13583	722	3546
13583	722	1639
9761	723	1324
9761	723	5007
5091	724	740
5091	724	3808
12433	725	1317
3511	726	1014
3511	726	9872
15910	727	9903
15910	727	7978
15910	727	5568
230	728	4837
230	728	5421
230	728	8660
230	728	1901
230	728	6762
230	728	1732
230	728	5643
230	728	7305
8851	729	7195
8851	729	1786
8851	729	8281
11470	730	3929
11470	730	3610
4539	731	2246
4539	731	9378
4539	731	808
4539	731	6722
4539	731	535
4539	731	2539
19465	732	4904
19465	732	4187
19465	732	1392
19465	732	8602
19465	732	3959
19465	732	4668
19465	732	4481
13452	733	702
13452	733	7740
13452	733	7923
922	734	194
922	734	1423
922	734	5309
922	734	2532
922	734	7263
2442	735	8921
2442	735	142
2442	735	4551
2442	735	4982
2442	735	8953
2442	735	2675
2442	735	995
6545	736	2926
6545	736	2626
6545	736	3837
6545	736	4935
6545	736	6291
6545	736	2321
6545	736	3641
7564	737	2925
7564	737	7262
19873	738	2153
19873	738	5472
16794	739	6631
16794	739	1400
16794	739	2122
16794	739	8519
16794	739	7325
16794	739	5683
18371	740	7670
18371	740	743
18371	740	3991
18371	740	1074
18371	740	5582
18371	740	5101
18371	740	4943
18371	740	5441
13680	741	4530
13680	741	9873
13680	741	3818
13680	741	6639
13680	741	4741
4819	742	1284
4819	742	8862
4819	742	7619
4819	742	8903
4819	742	3642
4819	742	5006
4819	742	5419
4819	742	5922
4819	742	3746
7237	743	9174
7237	743	3790
7237	743	2375
7237	743	6323
15213	744	9964
17732	745	2711
17732	745	7812
17732	745	4994
17732	745	6686
17732	745	4184
17732	745	2358
17732	745	932
17732	745	5433
15616	746	7668
15616	746	9374
18674	747	8203
18674	747	3378
18674	747	6312
18674	747	9043
18674	747	4922
18212	748	5595
18212	748	3934
18212	748	8282
10835	749	4335
10835	749	5508
10835	749	9855
10835	749	8545
10835	749	3099
10835	749	8971
16026	750	3741
16026	750	7139
16026	750	3164
16026	750	9930
16026	750	3762
16026	750	6475
16026	750	3629
16026	750	9100
9214	751	8073
9214	751	6049
9214	751	2328
9214	751	582
9214	751	3033
9214	751	3473
9214	751	2058
9214	751	3143
6145	752	1284
6145	752	9703
6145	752	6412
6145	752	2877
6145	752	3409
6145	752	2540
6145	752	5141
14936	753	2907
14936	753	4532
14936	753	3413
13111	754	9628
1823	755	5825
1823	755	5945
1823	755	3880
1823	755	3437
1823	755	836
1823	755	5008
1823	755	6046
17905	756	5331
17905	756	7843
19306	757	3782
19306	757	5762
19306	757	7239
19306	757	6035
19306	757	286
7445	758	2300
7445	758	6861
7445	758	9956
7445	758	7298
5257	759	4949
5257	759	2331
5257	759	3950
19423	760	1297
19423	760	8122
19423	760	8764
19423	760	5305
19423	760	4031
1782	761	4474
1782	761	1605
1782	761	5876
1782	761	1987
1782	761	4582
1782	761	8429
12255	762	1066
12255	762	2094
12255	762	1122
12852	763	4031
12852	763	4766
12852	763	8789
12852	763	3228
18207	764	9928
16711	765	4483
16711	765	8528
16711	765	6770
16711	765	4735
16711	765	1479
14868	766	9828
14868	766	8328
14868	766	2459
14868	766	9011
14868	766	659
14868	766	1542
14868	766	5344
14868	766	8942
6848	767	8972
7413	768	8285
7413	768	9738
7413	768	8888
14431	769	8771
14431	769	3423
14431	769	2079
14844	770	1755
14844	770	2380
14844	770	3240
14844	770	1651
14844	770	5058
14844	770	6368
14844	770	8416
14844	770	82
14844	770	5670
7703	771	1044
7703	771	2719
7703	771	841
4397	772	5234
4397	772	5615
4397	772	5421
958	773	3822
958	773	5010
958	773	859
958	773	3942
958	773	4531
958	773	8666
958	773	2273
958	773	8696
958	773	4118
11614	774	9876
10593	775	5775
10593	775	460
10938	776	6149
10938	776	9345
10938	776	3837
10938	776	6253
9896	777	4187
9896	777	9320
9896	777	5078
9896	777	2872
14573	778	6841
19902	779	3919
19902	779	802
19902	779	8405
19902	779	1275
1339	780	4182
1339	780	4501
1339	780	9513
1339	780	2696
1339	780	3673
1339	780	9670
1339	780	7453
1339	780	5432
1339	780	6462
760	781	3644
760	781	6116
13726	782	6831
13726	782	1193
13726	782	3271
13726	782	909
13726	782	3088
13726	782	3153
13726	782	3904
18670	783	6344
18670	783	6109
18670	783	74
18670	783	4219
18670	783	4671
18670	783	3052
19765	784	1214
4245	785	6704
4245	785	7158
4245	785	3022
4245	785	9943
12573	786	7365
12573	786	8017
12573	786	5798
12573	786	3599
12573	786	2945
12573	786	8732
12573	786	3623
12573	786	6269
11065	787	7949
11065	787	9379
11065	787	2920
11065	787	1911
11065	787	5607
11065	787	3339
11065	787	1055
11065	787	4556
16307	788	1168
16307	788	9957
16307	788	4378
16307	788	9726
16307	788	1758
16307	788	5216
16307	788	5556
16951	789	3550
16951	789	4032
16951	789	2494
14099	790	5203
14099	790	9269
14099	790	2074
12902	791	2896
16223	792	2706
16223	792	3980
16223	792	173
16223	792	6143
16223	792	4417
5320	793	4944
5320	793	8869
1884	794	7393
1884	794	9307
1884	794	6092
1884	794	8400
1884	794	4760
1884	794	592
1884	794	7726
1884	794	6267
1368	795	3344
1368	795	5488
1368	795	9080
1368	795	2498
11868	796	4820
11868	796	2978
11868	796	3320
16157	797	6817
16157	797	5271
16157	797	4076
16157	797	3768
16157	797	4498
19970	798	4341
19970	798	188
19970	798	3830
19970	798	2328
10611	799	6683
10611	799	408
10611	799	7982
6506	800	3492
6506	800	28
6506	800	1187
6506	800	7974
4629	801	1952
4629	801	3782
4629	801	6957
4629	801	9586
4629	801	5121
4629	801	9992
4629	801	5432
4629	801	2754
6122	802	7137
6122	802	2708
6122	802	3075
6122	802	4906
6122	802	2996
9895	803	9227
9895	803	7133
9895	803	1166
9895	803	5080
1022	804	5314
7125	805	1839
9827	806	6636
9827	806	3345
9827	806	6406
9827	806	1536
17336	807	922
17336	807	8010
17336	807	34
17336	807	9239
17336	807	7498
17336	807	8910
17336	807	3567
5242	808	6581
5242	808	275
5242	808	9493
5242	808	962
5242	808	2312
5242	808	9696
5242	808	3501
5242	808	6280
12626	809	1661
12626	809	1394
12626	809	8721
12626	809	1319
12626	809	7582
12626	809	7891
12626	809	9278
12626	809	4087
10098	810	1698
10098	810	3913
10098	810	111
10098	810	6708
10098	810	6505
10098	810	7991
10098	810	1507
454	811	9301
14384	812	5357
14384	812	5081
14384	812	5224
14384	812	7359
14384	812	4371
14384	812	2119
17652	813	4185
17652	813	6133
17652	813	1286
17652	813	5918
17652	813	4921
17652	813	7556
17652	813	2411
17652	813	8264
6688	814	8222
6688	814	5960
6688	814	6600
6688	814	7074
6688	814	6904
6688	814	6031
6688	814	2888
6688	814	6780
6688	814	7031
3903	815	3905
3903	815	1001
3903	815	8093
3903	815	5513
3903	815	3857
3903	815	1390
3903	815	6327
6799	816	4385
6799	816	5887
6799	816	4246
6799	816	1445
6799	816	5363
6557	817	3605
6557	817	9302
6557	817	4424
6557	817	7759
6557	817	8548
6557	817	8097
6557	817	7138
6380	818	5273
6380	818	9930
6380	818	9343
9411	819	7984
9411	819	1156
9411	819	835
9411	819	3285
2086	820	191
2086	820	8693
2086	820	7625
2086	820	519
11581	821	5309
11581	821	927
11581	821	9138
11581	821	126
11581	821	4778
11581	821	8709
11581	821	1739
11581	821	870
11581	821	3036
6453	822	555
6453	822	6487
6453	822	2080
6453	822	6864
6453	822	5663
6453	822	1603
6453	822	8275
6453	822	139
6453	822	7862
13141	823	8564
13141	823	8430
18516	824	8779
18516	824	5511
15181	825	4761
15181	825	5488
15181	825	3627
7529	826	8680
7529	826	1536
7529	826	3266
7529	826	605
7529	826	1698
13046	827	1903
13046	827	4998
13046	827	1354
13046	827	1673
13046	827	3409
13046	827	2479
13046	827	923
13046	827	799
13046	827	4548
12168	828	6183
12168	828	9892
12168	828	5698
12168	828	4404
12168	828	577
12168	828	7714
12168	828	4663
12168	828	1946
10708	829	2389
10708	829	7243
10708	829	7503
10708	829	2667
10708	829	7874
10708	829	630
10708	829	643
12681	830	292
12681	830	2647
12681	830	7517
12681	830	7073
12681	830	3644
12681	830	4816
14409	831	392
14409	831	8947
14409	831	1490
14409	831	4411
14409	831	878
14409	831	2640
14409	831	1394
3369	832	9690
3369	832	9111
5509	833	9892
5509	833	4944
5509	833	6088
5509	833	503
5509	833	8394
5509	833	1856
5509	833	4112
13502	834	756
13502	834	934
13502	834	6506
13502	834	166
13502	834	7384
13502	834	8371
13502	834	830
13502	834	5331
13502	834	9708
420	835	2203
420	835	2306
420	835	1041
420	835	3064
420	835	9411
420	835	1291
420	835	522
420	835	967
420	835	3413
3565	836	44
3565	836	381
3565	836	1499
3565	836	9962
3565	836	992
6595	837	3460
6595	837	3888
6595	837	5360
6595	837	3214
6595	837	2975
6595	837	6568
6595	837	2531
14561	838	7362
14561	838	7964
14561	838	6820
14561	838	6812
14561	838	88
14561	838	1109
14561	838	370
14561	838	105
10929	839	1346
15826	840	8258
15826	840	4643
15826	840	5177
15826	840	8539
15826	840	865
15826	840	1065
15826	840	3171
8558	841	8847
8558	841	5374
9618	842	7219
9618	842	4543
9618	842	9130
9618	842	2979
9618	842	6009
9618	842	5777
13281	843	4317
13281	843	3514
13281	843	7355
12404	844	2487
12404	844	6362
7161	845	9595
7161	845	2310
7161	845	4092
7161	845	730
7161	845	2865
7161	845	6509
7161	845	4387
7161	845	5847
7161	845	5888
4133	846	3619
4133	846	2517
4133	846	1311
4133	846	3561
6312	847	5730
6312	847	7619
6312	847	6781
6312	847	8485
6312	847	3254
6312	847	4113
6312	847	771
6312	847	2302
6312	847	2067
11371	848	5666
11371	848	6081
11371	848	7405
11371	848	2383
11371	848	2374
11371	848	7137
11371	848	4571
11371	848	476
7459	849	2830
7459	849	1319
6769	850	9070
6769	850	3273
6769	850	5332
6769	850	3962
6769	850	2425
9596	851	4790
10530	852	8995
10530	852	2537
7709	853	7239
7709	853	7970
7709	853	4218
19097	854	2284
19097	854	1349
19097	854	7817
19097	854	5339
19097	854	4830
13820	855	4915
13820	855	8690
13820	855	6961
13820	855	2909
13820	855	9434
13820	855	507
13820	855	2120
5429	856	5734
5429	856	725
5429	856	3706
5429	856	6156
5429	856	5416
11971	857	9092
12104	858	251
12104	858	3759
12104	858	8308
3013	859	6989
3013	859	6762
3013	859	7875
3013	859	3777
3013	859	9003
3013	859	8057
3013	859	5178
3013	859	4806
9558	860	7660
9558	860	8411
9558	860	1329
9558	860	7296
11776	861	213
11776	861	2927
11776	861	9724
11776	861	2119
11776	861	5895
2144	862	5341
2144	862	2757
2144	862	1405
2144	862	6233
2144	862	1834
2144	862	6535
2144	862	1197
2144	862	5018
10460	863	3318
10460	863	9602
10460	863	1397
9138	864	2547
9138	864	2386
9138	864	7571
9138	864	5720
9138	864	3606
280	865	4900
280	865	6253
280	865	6930
495	866	5683
495	866	2869
495	866	7838
495	866	6027
495	866	1347
495	866	5688
495	866	2202
11615	867	5948
11615	867	6645
11615	867	7343
11615	867	5719
6980	868	863
6980	868	7238
6980	868	1497
6980	868	3169
9030	869	3431
9030	869	2554
3029	870	7158
3029	870	739
3029	870	9775
3029	870	8773
3029	870	9947
3029	870	5842
3029	870	3496
3029	870	4541
3029	870	8155
7227	871	4760
7227	871	6586
7227	871	1805
7227	871	8829
7227	871	422
7227	871	8916
7227	871	487
7227	871	7617
15126	872	8372
15126	872	9484
15126	872	1039
15126	872	621
15126	872	1251
15126	872	2002
17175	873	9118
19077	874	698
19077	874	9947
1018	875	6913
12792	876	4034
12792	876	1075
12792	876	624
12792	876	1295
12792	876	1664
12792	876	9425
12792	876	6771
9819	877	3535
2837	878	1854
2837	878	9454
2837	878	6785
2837	878	5859
2837	878	4394
10034	879	4140
10034	879	2014
10034	879	2454
10034	879	5329
10034	879	3694
10034	879	3789
10034	879	1318
9588	880	5183
3934	881	2785
3934	881	1628
3934	881	3802
3934	881	6281
3934	881	3310
11526	882	8536
11526	882	5184
11526	882	8000
11526	882	5443
11526	882	1295
11526	882	7146
11526	882	1546
11874	883	4722
11874	883	113
12785	884	4686
12785	884	3014
12785	884	4800
12785	884	2535
12785	884	3873
12785	884	6484
12785	884	7179
8648	885	306
8648	885	565
8648	885	3925
8648	885	3288
8648	885	3809
543	886	8239
543	886	6879
543	886	9041
543	886	3021
543	886	9948
14253	887	1450
14253	887	9939
14253	887	4233
14253	887	2739
14253	887	5790
19198	888	9870
19198	888	7738
19198	888	5226
8533	889	7180
8533	889	3670
8533	889	1104
8533	889	4719
9314	890	5161
9314	890	4875
9314	890	3073
9314	890	549
9314	890	9691
9314	890	4060
9314	890	8527
19345	891	3839
19345	891	52
19345	891	139
19345	891	8460
19345	891	3708
19345	891	9514
9349	892	5625
9349	892	9607
9349	892	4462
17044	893	7807
17044	893	4792
17044	893	4845
17044	893	2090
17044	893	6139
9197	894	5545
9197	894	7773
9197	894	1273
9197	894	5747
9197	894	971
9197	894	3071
9197	894	4652
9197	894	3954
9197	894	4783
19149	895	8205
19149	895	9888
19149	895	7437
19149	895	8942
19149	895	5694
6933	896	6302
6933	896	9290
6933	896	8795
6892	897	4823
6892	897	8419
6892	897	6381
6892	897	9963
6892	897	6747
6892	897	8929
15740	898	2356
15740	898	4947
2497	899	8521
2497	899	3868
11783	900	2699
18158	901	3664
18158	901	5336
18158	901	8768
18158	901	462
18158	901	2603
15100	902	8798
15100	902	1019
15100	902	8639
15100	902	8543
15100	902	778
15100	902	4921
15100	902	2725
15100	902	2554
15100	902	5929
2529	903	2387
2529	903	1385
2529	903	2088
2529	903	2539
2673	904	8655
2673	904	4097
2673	904	4315
2673	904	3621
2673	904	8349
2673	904	9680
2673	904	6908
2673	904	7121
2673	904	6873
18518	905	4248
18518	905	6033
18518	905	2242
18518	905	8123
18518	905	3436
18518	905	3496
18518	905	3974
15190	906	3940
1695	907	2902
1695	907	4708
1695	907	8466
1695	907	6222
1695	907	7196
1695	907	9499
1695	907	6480
1695	907	2987
12965	908	4293
12965	908	5966
12965	908	609
12965	908	8066
12965	908	754
12965	908	1045
12965	908	9606
12965	908	2525
17492	909	1001
17492	909	2293
17492	909	7903
4601	910	672
4601	910	4697
4601	910	7394
4601	910	6544
4601	910	7571
17230	911	4367
17230	911	3534
17230	911	2222
17230	911	2883
17230	911	4598
5001	912	4801
5001	912	2940
5001	912	8269
5001	912	2110
5001	912	2941
5001	912	1120
5001	912	5950
5001	912	9126
6984	913	3519
6984	913	289
6984	913	5821
6984	913	1576
6984	913	7387
6984	913	4619
15117	914	5194
15117	914	8173
15117	914	8423
8744	915	1273
8744	915	1263
8744	915	4680
8744	915	4249
8744	915	1181
8744	915	9855
8744	915	6591
2418	916	8768
2418	916	1539
2418	916	6858
2418	916	2095
2418	916	9004
2418	916	9652
2418	916	8510
2418	916	3980
2418	916	2574
13644	917	6891
13644	917	8489
13644	917	725
13644	917	4690
13644	917	2300
13644	917	7242
8197	918	9378
8197	918	252
8197	918	7825
8197	918	9953
8197	918	8533
8197	918	464
8197	918	9349
8197	918	8817
8197	918	7574
16595	919	8451
16595	919	7866
16595	919	6715
16595	919	9790
18335	920	8196
18335	920	3807
18335	920	2448
18335	920	675
18335	920	5422
8477	921	1543
8477	921	2872
8477	921	390
8477	921	4996
8477	921	7013
13605	922	5970
13605	922	3377
13605	922	5437
13605	922	2313
13605	922	9521
13605	922	795
13605	922	3011
13605	922	9181
1447	923	2843
1447	923	6563
1447	923	3897
1447	923	9548
1447	923	377
12693	924	511
12693	924	6324
12693	924	9638
12693	924	5811
12693	924	788
12693	924	8228
12693	924	8094
12693	924	692
12693	924	5839
4802	925	5976
4802	925	320
4802	925	2443
17519	926	513
17519	926	6033
17519	926	7394
16362	927	8149
16362	927	9408
16362	927	2105
16362	927	2375
16362	927	7648
16362	927	3980
16362	927	4665
16362	927	9976
5348	928	5884
5348	928	7157
5348	928	6531
5348	928	3761
5348	928	2731
5348	928	5924
10664	929	578
10664	929	6383
10664	929	5840
10664	929	1848
10664	929	4661
10086	930	651
10086	930	9858
10086	930	2297
10086	930	2358
10176	931	5968
10176	931	4757
10176	931	8955
10176	931	7782
10176	931	3560
10176	931	5699
10176	931	4125
10176	931	7230
10176	931	5401
12103	932	3859
12103	932	1461
12103	932	460
12103	932	1304
12103	932	4388
18289	933	4479
18289	933	8897
18289	933	4361
18289	933	3446
1351	934	2402
9018	935	8912
18743	936	313
18743	936	5053
18743	936	463
18743	936	8479
18743	936	8751
18743	936	2981
18743	936	1971
18743	936	1597
3636	937	7254
3636	937	4011
3636	937	3948
3636	937	9731
3636	937	2294
3636	937	8208
3636	937	7981
3636	937	7525
3636	937	1272
46	938	3134
46	938	2791
46	938	2275
46	938	6548
46	938	9394
46	938	3237
14368	939	7610
14368	939	7955
11869	940	4378
11869	940	4755
11869	940	374
11869	940	4127
11869	940	3484
11869	940	8238
11869	940	6809
11869	940	5311
17094	941	5731
6681	942	9158
6681	942	5331
6681	942	4532
6681	942	8587
6681	942	7470
6681	942	7419
6681	942	2468
6681	942	8514
6681	942	6660
3941	943	517
3941	943	4226
3941	943	7062
3941	943	9588
17491	944	6982
11138	945	4529
11138	945	9167
11138	945	9534
11138	945	7701
11138	945	3003
11138	945	8164
11138	945	7267
2984	946	7159
2984	946	4333
2984	946	3261
484	947	5811
484	947	286
484	947	3499
6065	948	9226
6065	948	8228
6065	948	4661
6065	948	6070
6065	948	6987
8291	949	6367
8291	949	9093
8291	949	9014
8291	949	1698
8291	949	7614
8291	949	5164
8291	949	1437
17138	950	8705
17138	950	759
17138	950	1258
17138	950	3681
13427	951	4079
13427	951	2109
13427	951	7738
13427	951	5918
7063	952	4644
17575	953	2158
17575	953	6910
16334	954	6411
16334	954	3888
16334	954	907
16334	954	7555
16334	954	1136
16334	954	4138
16334	954	4729
12296	955	9004
12296	955	4016
12296	955	5949
12296	955	556
12296	955	9089
17667	956	6403
17667	956	6234
17667	956	3077
17667	956	325
17667	956	9082
17667	956	1266
17667	956	4545
11476	957	541
11476	957	9389
11476	957	7265
11476	957	9347
11476	957	3994
11476	957	5187
11476	957	7805
11476	957	328
11476	957	8899
18447	958	3685
18447	958	718
18447	958	731
18447	958	3968
18447	958	9636
18447	958	8900
18447	958	998
688	959	715
688	959	8178
688	959	9294
16386	960	7417
2202	961	9331
2202	961	8685
2202	961	6943
2202	961	7806
2202	961	7344
2202	961	2007
2202	961	9147
2202	961	9272
14898	962	5954
14898	962	9716
14264	963	8233
14264	963	6624
14264	963	4927
14264	963	861
14264	963	3628
14264	963	7711
14264	963	7469
14264	963	7282
13106	964	4002
13106	964	7995
13106	964	5795
13106	964	7819
13106	964	4842
13106	964	5731
4709	965	7663
4709	965	7790
4709	965	163
4709	965	2261
4709	965	5219
4709	965	4248
1449	966	5582
2753	967	8493
2753	967	3076
2753	967	9551
2753	967	6579
2753	967	9992
2753	967	1684
2753	967	5531
2753	967	3283
17002	968	7962
17002	968	4450
17002	968	3526
17002	968	7820
18911	969	5933
18911	969	4124
18911	969	8595
18911	969	5670
18911	969	4942
18911	969	6368
18911	969	9201
18911	969	8264
18911	969	8151
12225	970	6
12225	970	6885
12225	970	6129
12225	970	7281
12225	970	8192
12225	970	2102
12225	970	8696
8731	971	1719
8731	971	8431
8731	971	5299
8731	971	9598
8731	971	2291
8731	971	9562
8731	971	8856
8731	971	3866
19988	972	7571
19988	972	7886
19988	972	4537
19988	972	368
19988	972	946
5330	973	3584
5330	973	638
5330	973	4045
5330	973	5184
8078	974	9778
8078	974	8102
8078	974	5238
8078	974	6031
8078	974	5345
8078	974	9704
8078	974	8121
8078	974	5361
1316	975	1254
1316	975	80
1316	975	1141
1316	975	8904
1316	975	9302
1316	975	3492
1316	975	2642
15760	976	1003
15760	976	9486
15760	976	8323
15760	976	1355
15760	976	1240
15760	976	4341
15760	976	1567
15760	976	7029
15760	976	893
19594	977	1874
19594	977	5289
19594	977	8636
19594	977	2395
19594	977	7095
19594	977	8511
13666	978	516
13666	978	127
13666	978	4241
13666	978	452
13666	978	3338
492	979	6456
492	979	32
492	979	7529
19847	980	3321
19847	980	3597
19847	980	9911
19847	980	2882
19847	980	3209
19847	980	5283
19847	980	4701
16076	981	8284
16076	981	1144
16076	981	1232
16076	981	6484
16076	981	9841
16076	981	8684
16076	981	3420
16076	981	7485
14791	982	7822
14791	982	5317
14791	982	5456
8347	983	2328
8347	983	4134
8347	983	1078
8347	983	4645
8347	983	4126
8347	983	3965
14770	984	4401
14770	984	3774
14770	984	6550
14770	984	7207
14770	984	4699
14770	984	1883
19874	985	6275
19874	985	2634
19874	985	8953
19874	985	4913
19874	985	1764
19874	985	5888
19874	985	6262
19874	985	7035
19874	985	4941
2980	986	3356
2980	986	9731
2980	986	639
2980	986	5175
2980	986	5728
2980	986	3679
2980	986	8802
7429	987	2592
7429	987	8060
7429	987	2296
7429	987	9516
7429	987	5902
7429	987	8727
7429	987	6446
12352	988	2741
12352	988	6135
12352	988	3945
12352	988	6830
12352	988	2443
12352	988	6461
18105	989	7906
18105	989	3027
18105	989	9280
18105	989	6799
18105	989	7233
18105	989	88
18105	989	9420
18105	989	8681
9629	990	4627
9629	990	6595
9629	990	9928
9629	990	5222
9937	991	7012
12582	992	4297
12582	992	7476
12582	992	9557
12582	992	1792
3390	993	5543
3390	993	7143
3390	993	4747
3390	993	5193
3390	993	6870
3390	993	4936
3390	993	7312
3390	993	5360
3390	993	8239
5070	994	6919
5070	994	3348
5070	994	9758
5070	994	406
5070	994	2087
5070	994	485
10462	995	5199
10462	995	577
10462	995	7770
6257	996	8175
279	997	1661
279	997	8484
279	997	3813
279	997	4226
279	997	4837
279	997	5128
279	997	9941
279	997	6199
279	997	4595
4728	998	5493
4728	998	7674
4728	998	8909
4728	998	3806
4728	998	301
4728	998	8381
4728	998	6884
2218	999	5820
2218	999	5431
2218	999	4647
18482	1000	1605
18482	1000	3527
18482	1000	367
18482	1000	764
18482	1000	1729
18482	1000	6246
19356	1001	4380
19356	1001	3538
19356	1001	2678
19356	1001	4440
19356	1001	1777
19356	1001	5667
19356	1001	2599
19356	1001	9182
19356	1001	8996
9043	1002	9276
9043	1002	1402
9043	1002	7382
9043	1002	594
9043	1002	2636
9043	1002	6816
9043	1002	7872
9043	1002	8425
403	1003	5819
403	1003	5462
403	1003	2676
403	1003	753
403	1003	8979
16509	1004	9171
16509	1004	769
16509	1004	6597
16509	1004	4738
16509	1004	9576
16509	1004	2906
16509	1004	4920
10292	1005	7971
10292	1005	9020
10292	1005	8072
10292	1005	8465
8489	1006	1426
8489	1006	6997
7186	1007	7006
7186	1007	1585
7186	1007	3173
7186	1007	2607
7186	1007	1651
7186	1007	5394
7186	1007	4376
7186	1007	268
7186	1007	4186
17328	1008	711
17328	1008	9275
17328	1008	6596
17328	1008	1300
17328	1008	2490
8149	1009	579
4458	1010	1851
4458	1010	1719
4458	1010	8405
4458	1010	851
4458	1010	4568
4458	1010	2702
4458	1010	8229
9649	1011	7017
9649	1011	2589
9649	1011	2054
9649	1011	4919
13660	1012	4136
13660	1012	9165
13660	1012	8830
19359	1013	3507
19359	1013	1605
19359	1013	147
19359	1013	6560
19359	1013	8873
19359	1013	3616
11339	1014	8302
11339	1014	9706
11339	1014	7096
12519	1015	3828
12519	1015	8383
12519	1015	7780
12519	1015	7467
12519	1015	3624
12519	1015	3973
12519	1015	3250
12519	1015	3760
3433	1016	4592
3433	1016	458
3433	1016	4000
3433	1016	8139
3433	1016	3813
3433	1016	2577
1918	1017	2848
1918	1017	6450
1918	1017	2017
1918	1017	6655
1918	1017	3268
1918	1017	2133
1918	1017	2130
13443	1018	1019
13443	1018	2154
13443	1018	3377
13443	1018	6991
13443	1018	3605
1083	1019	4944
1083	1019	6230
1083	1019	216
1083	1019	2227
1083	1019	3297
1083	1019	1056
1083	1019	9026
1083	1019	2148
1083	1019	9799
3904	1020	7918
3904	1020	3362
3904	1020	5591
3904	1020	2064
3904	1020	31
3904	1020	8726
3904	1020	3968
12389	1021	553
12389	1021	7866
12389	1021	8678
16953	1022	429
16953	1022	5550
16953	1022	4818
16953	1022	9868
16953	1022	9183
16953	1022	9341
16953	1022	8939
16953	1022	5473
9231	1023	7055
9231	1023	2909
9231	1023	9232
9231	1023	4935
9231	1023	63
9231	1023	1480
9231	1023	3619
9231	1023	8836
9231	1023	5939
10243	1024	4335
10243	1024	6250
10243	1024	2479
10243	1024	4423
10243	1024	2687
10243	1024	1232
10243	1024	6398
10243	1024	7181
14487	1025	7734
14487	1025	2310
14487	1025	1503
14487	1025	5273
14487	1025	3371
15410	1026	7512
15410	1026	8037
15410	1026	9538
15410	1026	3411
15410	1026	6318
6997	1027	742
6997	1027	316
6997	1027	3654
6997	1027	5044
6997	1027	875
8489	1028	1949
8489	1028	8813
8489	1028	9660
8489	1028	1394
9608	1029	4612
9608	1029	7387
9608	1029	6234
9608	1029	6340
19986	1030	5150
19986	1030	1961
16366	1031	9885
16366	1031	5703
16366	1031	345
16366	1031	8742
16366	1031	1900
16366	1031	1804
18380	1032	7318
18380	1032	2689
18380	1032	8596
18380	1032	5565
18380	1032	1913
18380	1032	4397
18161	1033	2577
18161	1033	5137
18161	1033	5246
18161	1033	837
18161	1033	2585
18161	1033	3657
11841	1034	4524
11841	1034	3066
11841	1034	3182
11841	1034	6865
11841	1034	6155
11841	1034	1299
11841	1034	342
11841	1034	7455
11841	1034	1896
14282	1035	4286
14282	1035	9314
14282	1035	1543
14282	1035	3863
14282	1035	290
14282	1035	1491
14282	1035	1505
16738	1036	9630
16738	1036	2
16738	1036	4811
16738	1036	2889
16738	1036	46
16738	1036	3848
16738	1036	5401
16738	1036	5565
14214	1037	7279
14214	1037	8324
14214	1037	9503
14214	1037	3442
14214	1037	8197
14214	1037	9627
14214	1037	4272
14214	1037	7797
14214	1037	7083
14256	1038	3641
14256	1038	7769
14256	1038	9527
14256	1038	6312
14256	1038	3782
14256	1038	1532
14256	1038	2360
14256	1038	1933
14256	1038	2522
4296	1039	1775
4296	1039	2363
4296	1039	6437
11696	1040	660
11696	1040	8830
11696	1040	9400
11696	1040	5570
11696	1040	8731
11696	1040	5286
11696	1040	8135
11696	1040	6891
11696	1040	7347
10604	1041	1054
10604	1041	3436
10604	1041	9691
10604	1041	3338
10604	1041	9046
15751	1042	3016
15751	1042	5613
15751	1042	6852
9973	1043	5643
9973	1043	5625
9973	1043	764
9973	1043	3026
9973	1043	6343
9973	1043	9308
9973	1043	5882
9973	1043	3511
9973	1043	6643
1648	1044	575
1648	1044	7565
1648	1044	5486
1648	1044	2413
1648	1044	127
1648	1044	9064
19654	1045	1645
19654	1045	5989
19654	1045	2930
19654	1045	3598
19654	1045	6798
19654	1045	2983
19654	1045	1064
19654	1045	5419
19654	1045	6546
4062	1046	5632
4062	1046	9534
12070	1047	5562
12070	1047	6711
12070	1047	7119
12070	1047	3420
12070	1047	6080
12070	1047	955
12070	1047	9818
12070	1047	1020
12070	1047	3657
5442	1048	4199
5442	1048	5112
8744	1049	4187
8744	1049	610
8744	1049	6879
8744	1049	537
13232	1050	5678
13232	1050	1416
13232	1050	5568
13232	1050	4263
13232	1050	7793
13232	1050	5388
13232	1050	9086
13232	1050	5723
13232	1050	4871
18115	1051	9955
18115	1051	1789
18115	1051	7995
18115	1051	7108
5570	1052	9483
7490	1053	7603
7490	1053	5902
7490	1053	4083
7490	1053	5696
18294	1054	3208
18294	1054	5627
18294	1054	8456
18294	1054	5228
18294	1054	2131
18294	1054	8348
18294	1054	5902
18294	1054	5383
7157	1055	7162
7157	1055	5867
7157	1055	3454
7157	1055	198
7157	1055	710
7157	1055	8498
7157	1055	6174
7157	1055	8913
7157	1055	7745
19751	1056	848
19751	1056	6370
19751	1056	6918
19751	1056	9808
19751	1056	7124
19751	1056	4676
19751	1056	8214
19751	1056	4552
10522	1057	9178
10522	1057	1318
10522	1057	7422
10522	1057	2231
10522	1057	8938
10522	1057	6154
10522	1057	6127
6089	1058	5891
6089	1058	2791
6089	1058	581
6089	1058	8696
6089	1058	9417
6089	1058	394
19142	1059	7662
19142	1059	4964
19142	1059	3864
19142	1059	1120
19142	1059	3685
19142	1059	2541
6017	1060	600
6017	1060	6747
6017	1060	9316
6017	1060	6314
6017	1060	2834
6017	1060	4768
7192	1061	9846
7192	1061	3830
7192	1061	2182
7192	1061	3727
12535	1062	9276
12535	1062	8666
12535	1062	9396
17422	1063	7443
17422	1063	4076
17422	1063	1106
17422	1063	5806
17422	1063	4292
17422	1063	2706
17422	1063	9361
6176	1064	9355
6176	1064	7750
6176	1064	7404
6176	1064	8506
6176	1064	1829
5367	1065	6372
5367	1065	5162
5367	1065	1359
11299	1066	3771
11299	1066	9495
11299	1066	9066
11299	1066	2106
11299	1066	6568
7941	1067	769
7941	1067	5118
7941	1067	783
7941	1067	9231
7941	1067	3053
7941	1067	4631
13064	1068	1139
13064	1068	7954
14040	1069	5441
14040	1069	2631
14040	1069	1420
4377	1070	8467
4377	1070	5212
4377	1070	4937
19135	1071	6099
19135	1071	9422
19135	1071	6568
19135	1071	7871
19135	1071	4395
19135	1071	14
19135	1071	6202
15242	1072	9810
16553	1073	5974
16553	1073	7013
16553	1073	835
16553	1073	5508
16553	1073	2426
16553	1073	4170
16553	1073	2304
16553	1073	6231
12489	1074	8890
12489	1074	4616
12489	1074	9230
12489	1074	8984
12489	1074	2701
12489	1074	1515
12489	1074	6581
14830	1075	4348
14830	1075	7172
14830	1075	9634
11729	1076	2109
11729	1076	8345
5920	1077	7385
171	1078	8760
171	1078	3597
171	1078	9727
171	1078	7738
171	1078	2455
4177	1079	7953
4177	1079	4499
4177	1079	3259
9638	1080	5609
9638	1080	2909
9638	1080	3274
4066	1081	7528
4066	1081	9644
4066	1081	4750
4066	1081	175
4066	1081	4187
4066	1081	489
4066	1081	5114
4066	1081	2199
6514	1082	5749
6514	1082	6822
6514	1082	7963
6514	1082	7296
16491	1083	8922
16491	1083	4921
16491	1083	1769
16491	1083	1012
16491	1083	9654
16491	1083	8094
16491	1083	6487
16491	1083	3139
16491	1083	3549
18594	1084	7954
18594	1084	4867
18594	1084	5287
18594	1084	3494
18594	1084	6650
3141	1085	6666
3141	1085	2708
3141	1085	8597
3141	1085	1086
3141	1085	1093
3141	1085	9401
3141	1085	552
11359	1086	8770
11359	1086	7141
1269	1087	3050
18272	1088	6233
18272	1088	5190
18272	1088	4614
18272	1088	9913
18272	1088	499
18272	1088	348
18272	1088	6664
18272	1088	6730
10998	1089	9555
10998	1089	3953
10998	1089	396
5202	1090	1472
5202	1090	8195
5202	1090	7200
5202	1090	2936
6869	1091	4485
6869	1091	3149
6869	1091	1875
6869	1091	6713
6869	1091	2645
6869	1091	7413
6869	1091	5191
6869	1091	3600
19473	1092	2107
19473	1092	8542
2954	1093	4911
2954	1093	1229
2954	1093	5929
15606	1094	5454
15606	1094	3589
15606	1094	2946
15606	1094	676
15606	1094	7246
15606	1094	6282
15606	1094	2966
3014	1095	2984
3014	1095	7353
3014	1095	6951
3014	1095	7290
3014	1095	2958
13324	1096	3011
13324	1096	9003
13324	1096	7589
13324	1096	2502
13324	1096	763
13324	1096	4928
12126	1097	1049
12126	1097	8974
12126	1097	6113
12126	1097	6982
12126	1097	8804
18972	1098	5622
18972	1098	5333
18972	1098	5569
18972	1098	4302
18972	1098	7756
18972	1098	6852
8044	1099	8886
8044	1099	2244
8044	1099	8195
8044	1099	3784
5174	1100	2073
5174	1100	9583
5174	1100	1330
13796	1101	4967
13796	1101	1682
13796	1101	8275
13796	1101	5841
13796	1101	4499
13796	1101	6813
10016	1102	185
10016	1102	8955
10016	1102	9917
10016	1102	7019
10016	1102	8721
10016	1102	4416
4505	1103	7845
12237	1104	3138
12237	1104	2598
12237	1104	1053
12237	1104	4959
12237	1104	1549
12237	1104	3007
12237	1104	444
12237	1104	1530
501	1105	1289
501	1105	9092
501	1105	1271
501	1105	8285
501	1105	3054
501	1105	1175
501	1105	2408
6920	1106	9611
5234	1107	5541
5234	1107	4149
5234	1107	2785
5234	1107	4804
5234	1107	1017
5234	1107	3020
5234	1107	830
7766	1108	74
7766	1108	536
7766	1108	5269
7766	1108	7315
7766	1108	9991
7766	1108	7496
7766	1108	242
8781	1109	4350
8781	1109	388
8781	1109	9698
8781	1109	7654
8781	1109	4712
8781	1109	4411
8968	1110	699
16025	1111	1569
3621	1112	6201
3621	1112	863
3621	1112	3403
3621	1112	5917
3621	1112	4658
18737	1113	3481
18737	1113	2522
18737	1113	7366
18737	1113	590
18737	1113	1233
18737	1113	7422
18737	1113	219
18737	1113	4611
1624	1114	1362
1624	1114	5101
1624	1114	919
1624	1114	850
15328	1115	4486
15328	1115	2008
15328	1115	8326
19116	1116	2359
19116	1116	5111
19116	1116	6290
19116	1116	7781
19116	1116	1949
19116	1116	8525
19116	1116	6421
14541	1117	4934
14541	1117	8541
14541	1117	1681
14541	1117	1271
14541	1117	3145
14541	1117	9564
3843	1118	8891
3843	1118	398
3843	1118	8866
14780	1119	6834
14780	1119	9505
14780	1119	2138
1356	1120	1226
1356	1120	9084
1356	1120	5648
1356	1120	6767
1356	1120	568
1356	1120	5137
1356	1120	6797
1356	1120	6129
1356	1120	7882
14555	1121	3481
14555	1121	709
14555	1121	8119
14555	1121	6296
14555	1121	7184
14555	1121	7104
14555	1121	1891
14555	1121	4914
14555	1121	5588
1449	1122	6259
1449	1122	9752
1449	1122	3010
1449	1122	1418
9797	1123	517
9797	1123	1504
9797	1123	961
9797	1123	4334
12447	1124	4881
12447	1124	5348
12447	1124	7125
12447	1124	6265
12447	1124	1355
12447	1124	7524
12447	1124	8820
12447	1124	1550
12447	1124	3840
8712	1125	1169
8712	1125	5096
8712	1125	426
8712	1125	1725
8712	1125	9917
8712	1125	7641
9531	1126	8149
9531	1126	1059
9531	1126	1269
9531	1126	4614
9531	1126	1387
12585	1127	2702
12585	1127	8999
12585	1127	9478
12585	1127	7847
12585	1127	664
12585	1127	7808
13172	1128	1629
13172	1128	5482
13172	1128	6890
13172	1128	2566
13172	1128	9568
13172	1128	9956
13172	1128	245
13172	1128	1439
875	1129	9862
875	1129	7422
875	1129	6353
875	1129	8829
875	1129	1815
875	1129	7956
6874	1130	187
19508	1131	4556
19508	1131	4228
1938	1132	7188
1938	1132	5173
1938	1132	6818
1938	1132	9838
1938	1132	904
1938	1132	7544
1316	1133	663
1316	1133	9921
5138	1134	5463
5138	1134	2786
5138	1134	8830
5138	1134	7885
5138	1134	5510
5138	1134	626
5138	1134	4582
10970	1135	4344
10970	1135	6174
10970	1135	8433
10970	1135	9121
10970	1135	9006
5279	1136	501
5279	1136	7687
5279	1136	149
5279	1136	5347
5279	1136	8629
5279	1136	7986
11916	1137	1474
11916	1137	5758
11916	1137	9678
11916	1137	4484
11916	1137	2545
11916	1137	154
11916	1137	6129
11916	1137	9851
15075	1138	3109
15075	1138	5039
15075	1138	7279
15075	1138	4947
15075	1138	8982
15075	1138	2263
15075	1138	6680
15075	1138	8103
15075	1138	2212
9511	1139	8222
9511	1139	3609
9511	1139	8833
9511	1139	5610
9511	1139	2222
14521	1140	285
14521	1140	7089
14521	1140	9044
14521	1140	9722
15648	1141	411
15648	1141	4338
15648	1141	2544
15648	1141	8690
15648	1141	632
15648	1141	8994
15648	1141	2315
15648	1141	4960
15648	1141	8475
17518	1142	8025
17518	1142	8226
17518	1142	5582
17518	1142	5570
17518	1142	5180
17518	1142	4898
17518	1142	2465
17518	1142	2077
5417	1143	8950
5417	1143	3802
5417	1143	9403
2377	1144	63
16577	1145	3886
16577	1145	3243
16577	1145	8354
16577	1145	8583
16577	1145	5582
16577	1145	1973
1300	1146	1641
1300	1146	6227
1300	1146	7840
17750	1147	7935
17750	1147	582
17750	1147	1268
9019	1148	2650
9019	1148	6285
9019	1148	2775
9019	1148	7406
9019	1148	8907
1095	1149	1591
1095	1149	236
1095	1149	1447
1095	1149	6115
1095	1149	1612
5758	1150	7389
5758	1150	6700
5970	1151	1243
5970	1151	5728
5970	1151	4842
5970	1151	697
5970	1151	8873
5970	1151	2145
5970	1151	6108
5970	1151	5033
5970	1151	2972
14184	1152	8325
10050	1153	8010
10050	1153	1175
13805	1154	1089
13805	1154	5305
13805	1154	2384
13805	1154	9069
13805	1154	1040
13805	1154	713
19262	1155	9713
8981	1156	6080
8981	1156	9345
8981	1156	1715
8981	1156	4157
10492	1157	5207
10492	1157	8719
19517	1158	3770
19517	1158	2431
19517	1158	9391
13139	1159	697
13139	1159	1218
13139	1159	9967
13139	1159	275
13139	1159	4047
13139	1159	9369
13139	1159	7511
13139	1159	8855
1883	1160	3741
1883	1160	6351
1883	1160	4631
1883	1160	8314
1883	1160	2310
1883	1160	7687
1883	1160	7659
15251	1161	1749
15251	1161	9563
15251	1161	1142
19993	1162	938
19993	1162	1773
19993	1162	9045
19993	1162	850
19993	1162	3863
12344	1163	9178
4450	1164	5547
10219	1165	2182
10219	1165	8055
10219	1165	2496
10219	1165	4771
10219	1165	3670
10219	1165	2391
10219	1165	7491
10219	1165	3683
15583	1166	9559
15583	1166	3828
18750	1167	4485
18750	1167	5598
18750	1167	303
18750	1167	2149
18750	1167	2644
18750	1167	7067
18750	1167	735
16451	1168	8323
16451	1168	2306
16451	1168	9738
16451	1168	8302
16451	1168	816
1815	1169	3259
1815	1169	4091
1815	1169	5713
1815	1169	6359
1815	1169	3158
1815	1169	4669
1815	1169	2882
17184	1170	6727
12930	1171	31
12930	1171	6379
12930	1171	5908
12930	1171	395
12930	1171	4903
12930	1171	2727
12930	1171	724
7763	1172	7775
7763	1172	9139
7763	1172	3983
7763	1172	333
18972	1173	6941
18972	1173	660
18972	1173	175
18972	1173	6162
18972	1173	5733
18972	1173	5055
11557	1174	9660
14868	1175	7326
14868	1175	2579
14868	1175	136
14868	1175	7144
8170	1176	7404
7131	1177	4630
7131	1177	1131
7131	1177	6092
11502	1178	3185
11502	1178	4667
14491	1179	1299
14491	1179	1039
14491	1179	9397
14491	1179	1382
16641	1180	992
16641	1180	5814
16641	1180	1304
16641	1180	795
16641	1180	7655
1679	1181	1350
1679	1181	1413
1679	1181	1013
1679	1181	4831
8455	1182	1028
8455	1182	3423
8455	1182	3347
8455	1182	6390
8455	1182	6536
14661	1183	6851
14661	1183	9559
14661	1183	9621
14661	1183	7823
14661	1183	426
14661	1183	3744
14661	1183	888
14661	1183	9484
1023	1184	1906
1023	1184	404
1023	1184	8844
1023	1184	5988
1023	1184	4270
1023	1184	8627
16369	1185	9093
16369	1185	8046
16369	1185	8319
16369	1185	4774
16369	1185	9253
16369	1185	7698
16369	1185	4768
13347	1186	4969
13347	1186	5153
13347	1186	2472
13347	1186	2896
13347	1186	543
13347	1186	9283
13347	1186	7301
13347	1186	1687
11	1187	9212
11	1187	6923
11	1187	8208
12033	1188	4230
12033	1188	7229
12033	1188	4288
12033	1188	8805
12033	1188	799
161	1189	8455
161	1189	118
161	1189	3242
161	1189	9012
161	1189	3640
3695	1190	7864
4187	1191	1475
4187	1191	1901
5398	1192	2780
5398	1192	3034
5398	1192	4413
5398	1192	7580
5398	1192	404
5398	1192	107
5398	1192	2526
5398	1192	5891
7510	1193	5848
7510	1193	6947
7510	1193	9064
7510	1193	7602
7510	1193	1547
8651	1194	5559
8651	1194	4300
9407	1195	8748
9276	1196	8393
9276	1196	4568
9276	1196	4001
9276	1196	1563
9276	1196	362
9276	1196	2918
9276	1196	6392
9276	1196	6234
9276	1196	2181
12961	1197	1184
12961	1197	8658
12961	1197	6917
12961	1197	4569
12961	1197	8524
12961	1197	7867
12961	1197	7202
12961	1197	4606
9934	1198	6875
9934	1198	8881
9934	1198	9115
9934	1198	4900
9934	1198	7541
9934	1198	4807
9934	1198	4491
9934	1198	8655
6447	1199	6184
6771	1200	2150
6771	1200	3355
6771	1200	3241
6771	1200	4398
6771	1200	3337
6771	1200	3182
6771	1200	239
6771	1200	8066
5112	1201	3963
5112	1201	1325
5112	1201	1368
5112	1201	3288
5112	1201	894
5112	1201	3539
5112	1201	9142
5112	1201	3120
15035	1202	1030
2536	1203	6313
2536	1203	9314
2536	1203	5954
2536	1203	5498
2536	1203	7968
2536	1203	4787
2536	1203	2016
11109	1204	2447
11109	1204	6527
11109	1204	9359
11109	1204	26
17436	1205	5476
17436	1205	4973
17436	1205	2790
17436	1205	8065
17436	1205	8204
17436	1205	5153
17436	1205	7287
4582	1206	6436
4582	1206	9233
4582	1206	4738
4582	1206	3993
4582	1206	8981
4582	1206	3481
4582	1206	9825
9594	1207	5723
9594	1207	9683
9670	1208	2004
9670	1208	7420
9670	1208	2978
9670	1208	9896
9670	1208	6819
1622	1209	3517
1622	1209	420
1622	1209	1833
1622	1209	8138
1622	1209	420
1622	1209	7388
1622	1209	7787
1622	1209	4937
1622	1209	359
15558	1210	1635
15558	1210	5477
15558	1210	6196
11184	1211	8468
11184	1211	6121
11184	1211	5506
11851	1212	6027
11851	1212	8495
11851	1212	609
1797	1213	4165
1797	1213	1133
1797	1213	6720
1797	1213	5921
1797	1213	2920
1797	1213	8763
1797	1213	8464
1797	1213	1688
1797	1213	9142
14521	1214	3166
14521	1214	6885
14521	1214	8178
14521	1214	4673
14521	1214	4358
14521	1214	3076
19592	1215	5779
19592	1215	6382
19592	1215	7126
19592	1215	9426
17134	1216	5827
17134	1216	4629
17134	1216	6533
17134	1216	2768
17134	1216	6302
17134	1216	9519
17134	1216	6277
17134	1216	6150
17935	1217	4706
17935	1217	2711
17935	1217	382
17935	1217	645
17935	1217	704
17935	1217	7904
17935	1217	4232
17935	1217	5523
16580	1218	5730
4012	1219	6762
4012	1219	6122
4012	1219	8146
4012	1219	1454
4012	1219	2659
4012	1219	2994
4012	1219	1030
17867	1220	1466
17867	1220	5321
17867	1220	4039
17867	1220	5858
17867	1220	5787
6746	1221	3350
6746	1221	4452
6746	1221	967
6746	1221	2353
6746	1221	7739
6746	1221	6929
6746	1221	9042
6746	1221	7703
18336	1222	4679
18336	1222	7927
18336	1222	8822
18336	1222	7400
18336	1222	7085
18336	1222	9130
18336	1222	1557
5048	1223	6150
5048	1223	9627
5048	1223	5993
5048	1223	332
4285	1224	9275
4285	1224	2006
4285	1224	8077
10953	1225	6894
10953	1225	8433
10953	1225	4132
10953	1225	975
10953	1225	4644
10953	1225	840
10953	1225	201
10953	1225	2939
1749	1226	3826
1749	1226	928
1749	1226	9149
1749	1226	6659
16161	1227	8631
16161	1227	9825
1598	1228	7923
1598	1228	5769
17415	1229	9582
17415	1229	7961
17415	1229	3277
17415	1229	9239
17415	1229	7893
4746	1230	3747
7142	1231	4370
7142	1231	5394
7142	1231	8964
7142	1231	415
18139	1232	398
18139	1232	2857
18139	1232	4433
18139	1232	6099
18139	1232	7992
18139	1232	4698
18139	1232	9135
18139	1232	4576
18139	1232	2015
12770	1233	8677
12770	1233	6625
12770	1233	3668
12770	1233	8162
12770	1233	5943
17599	1234	894
17599	1234	3555
16505	1235	6697
16505	1235	2226
16505	1235	5375
16505	1235	5096
16505	1235	7758
16505	1235	7723
2781	1236	2643
18880	1237	670
18880	1237	148
14130	1238	3117
14130	1238	1680
14130	1238	7885
14130	1238	7638
14130	1238	4121
14130	1238	6754
19237	1239	644
457	1240	2045
457	1240	9597
457	1240	211
5376	1241	1862
5376	1241	7715
5376	1241	9975
8192	1242	5940
8192	1242	9098
8192	1242	1176
8192	1242	5051
8192	1242	9971
8192	1242	1730
8192	1242	6354
8192	1242	4207
8192	1242	6319
15120	1243	481
15120	1243	860
7173	1244	3067
7173	1244	175
7173	1244	9665
7173	1244	1906
7173	1244	9995
7173	1244	5084
7173	1244	3891
7173	1244	3051
7173	1244	8002
14510	1245	8369
14510	1245	950
14510	1245	7865
14510	1245	2815
14510	1245	9505
14510	1245	2907
14510	1245	8045
19902	1246	1827
11435	1247	3815
11435	1247	5168
11435	1247	9064
11435	1247	2774
11435	1247	9505
11435	1247	6661
18952	1248	5357
18952	1248	2760
18952	1248	5264
5101	1249	4921
5101	1249	896
5101	1249	3359
5101	1249	536
5101	1249	86
5719	1250	6583
318	1251	3240
318	1251	9974
318	1251	1926
318	1251	9787
318	1251	7788
318	1251	457
318	1251	2158
11034	1252	4043
11034	1252	1570
17201	1253	2293
17201	1253	5749
17201	1253	9571
17201	1253	3985
17201	1253	4986
17201	1253	4782
5139	1254	5277
5139	1254	2998
18120	1255	5208
8431	1256	9805
11108	1257	4542
11108	1257	1949
11108	1257	6498
15373	1258	9332
15373	1258	5198
15373	1258	1287
15373	1258	1388
13191	1259	811
13191	1259	9628
13191	1259	212
13191	1259	6169
13191	1259	4865
13191	1259	7402
13191	1259	238
13191	1259	3545
13191	1259	1585
1832	1260	3245
1832	1260	5648
1832	1260	8675
1832	1260	1228
4076	1261	2654
4076	1261	150
4076	1261	4987
4076	1261	9533
4076	1261	1828
4076	1261	6287
4076	1261	4307
5028	1262	5919
5028	1262	4343
5028	1262	6664
5028	1262	544
5028	1262	1911
5028	1262	9929
5164	1263	1405
5164	1263	1457
5164	1263	5418
5164	1263	707
5164	1263	8657
5164	1263	9575
16723	1264	393
16723	1264	5012
16723	1264	9868
16723	1264	4947
9751	1265	7458
17723	1266	9798
17723	1266	1637
17723	1266	9845
17723	1266	5518
17723	1266	7165
17723	1266	7781
17723	1266	6492
17723	1266	6523
12780	1267	8168
19634	1268	9510
19634	1268	1368
19634	1268	6920
17113	1269	8850
12028	1270	5687
12028	1270	5589
12028	1270	8228
12028	1270	8599
12028	1270	991
12028	1270	6505
12028	1270	6583
12184	1271	8325
12184	1271	1082
12184	1271	2220
12184	1271	8915
12184	1271	9941
12184	1271	7084
12184	1271	5965
12184	1271	6899
12184	1271	4978
7152	1272	342
7152	1272	9402
7152	1272	5092
7152	1272	3017
2682	1273	38
2682	1273	1698
2682	1273	8787
2682	1273	7502
2682	1273	1812
2682	1273	8640
2682	1273	5020
2682	1273	3835
2682	1273	7193
15070	1274	4459
14951	1275	8816
14951	1275	4909
14951	1275	1304
14951	1275	7806
14951	1275	8243
14951	1275	5961
9200	1276	8217
9200	1276	1182
9200	1276	6845
9200	1276	2945
14806	1277	4878
7388	1278	2548
706	1279	5660
706	1279	5952
706	1279	7887
706	1279	8227
706	1279	7313
706	1279	1513
8913	1280	1860
8913	1280	3600
8913	1280	8767
8913	1280	431
5956	1281	3331
5956	1281	4346
5956	1281	2546
5956	1281	3425
5956	1281	5012
5956	1281	6535
5956	1281	1060
5956	1281	6481
17285	1282	5063
17285	1282	1099
17285	1282	9162
17285	1282	8528
921	1283	9720
921	1283	6829
921	1283	3044
921	1283	2697
921	1283	1904
921	1283	379
921	1283	7278
921	1283	5362
2363	1284	601
19526	1285	9717
19526	1285	3380
19526	1285	9115
11885	1286	6195
11885	1286	1963
11885	1286	7292
11885	1286	1061
12844	1287	7604
12844	1287	5264
12844	1287	3731
12844	1287	7967
12844	1287	2575
11909	1288	9054
8836	1289	2479
8836	1289	1125
8836	1289	4877
8153	1290	8777
8153	1290	7180
8153	1290	4414
8153	1290	3696
8153	1290	1410
8153	1290	64
8153	1290	2225
8153	1290	4077
1819	1291	3937
1819	1291	5637
1819	1291	7947
4573	1292	976
4573	1292	2062
4573	1292	7407
4573	1292	9065
4573	1292	8856
4573	1292	7373
19195	1293	876
19195	1293	8647
19195	1293	413
19195	1293	4748
19195	1293	7643
19195	1293	6562
19195	1293	4980
11911	1294	4110
11911	1294	9277
11911	1294	3026
795	1295	9995
795	1295	5046
795	1295	9146
795	1295	7442
795	1295	6275
795	1295	5607
795	1295	4883
19726	1296	5818
19726	1296	2347
19726	1296	9760
19726	1296	3102
19726	1296	9756
19726	1296	3182
19726	1296	4060
19726	1296	8642
19726	1296	4046
2976	1297	3678
2976	1297	2988
2976	1297	5120
2976	1297	8423
2976	1297	1338
2976	1297	6275
2976	1297	4168
2976	1297	5307
2976	1297	8819
4000	1298	5176
4000	1298	7183
4000	1298	8298
4000	1298	710
4000	1298	9051
4000	1298	8594
4000	1298	2947
4000	1298	3832
10337	1299	8852
10337	1299	4461
10337	1299	7045
10337	1299	9220
10337	1299	5280
10337	1299	9141
10337	1299	1599
10337	1299	9677
773	1300	4774
773	1300	7392
773	1300	7845
773	1300	9089
773	1300	6391
10485	1301	9401
10485	1301	6163
10485	1301	2579
3439	1302	8042
3439	1302	1205
13485	1303	874
13485	1303	4453
13485	1303	8310
13485	1303	8714
13485	1303	8238
13485	1303	9943
13485	1303	20
12365	1304	7624
12365	1304	8524
12365	1304	8982
12365	1304	1094
12365	1304	910
12365	1304	6929
12365	1304	9786
8477	1305	7779
8477	1305	704
8477	1305	2370
8477	1305	8726
8477	1305	9990
8477	1305	8572
12391	1306	5716
12391	1306	4846
12391	1306	4794
12391	1306	9862
12391	1306	6361
12391	1306	9524
12391	1306	3887
12391	1306	57
1519	1307	1406
1519	1307	6034
1519	1307	9359
1519	1307	9348
9948	1308	9582
9948	1308	3324
9948	1308	7995
9948	1308	6098
9948	1308	2834
9948	1308	8409
16930	1309	9224
16930	1309	6584
16930	1309	2473
3661	1310	945
3661	1310	6345
11853	1311	303
11853	1311	1045
11853	1311	2929
11853	1311	2021
11853	1311	598
11853	1311	9802
11853	1311	6623
11853	1311	5048
15040	1312	9350
15040	1312	3049
18787	1313	5320
18787	1313	3457
18787	1313	7787
18787	1313	2022
18787	1313	8379
18787	1313	2053
3709	1314	880
3709	1314	7555
3709	1314	526
3709	1314	2214
10524	1315	4656
10524	1315	3081
10524	1315	8016
10524	1315	5597
10524	1315	1039
10524	1315	6517
10524	1315	1660
18771	1316	3734
18771	1316	9357
18771	1316	1838
18771	1316	4665
18771	1316	9757
18771	1316	9313
7936	1317	3943
7936	1317	8185
18447	1318	8641
18447	1318	7632
18447	1318	8203
18447	1318	3386
18447	1318	9357
18447	1318	3225
18447	1318	2625
18447	1318	5245
18447	1318	8972
15075	1319	9185
14738	1320	6592
10466	1321	2268
10466	1321	5076
10466	1321	8120
10466	1321	8396
10466	1321	5627
10466	1321	9232
10466	1321	3401
11416	1322	6745
11416	1322	6420
11416	1322	2294
11416	1322	4854
8489	1323	1267
8489	1323	1755
8489	1323	2038
8489	1323	775
8489	1323	1218
8489	1323	1453
9707	1324	562
9707	1324	6652
9707	1324	9317
3219	1325	495
3219	1325	930
3219	1325	4661
3219	1325	997
3219	1325	8538
3219	1325	6290
3219	1325	3468
9840	1326	9774
9840	1326	5685
9840	1326	998
629	1327	1924
629	1327	6157
629	1327	5997
629	1327	7030
629	1327	9281
629	1327	7073
629	1327	1061
629	1327	7131
629	1327	868
17645	1328	5429
17645	1328	9556
17645	1328	3852
17645	1328	6741
17645	1328	6667
17645	1328	6167
17645	1328	1082
17645	1328	9908
17645	1328	2821
19786	1329	3255
19786	1329	1726
19786	1329	6982
19786	1329	2945
19786	1329	394
19786	1329	4327
19786	1329	4799
3079	1330	204
3079	1330	6633
3079	1330	5767
3079	1330	9397
11070	1331	2734
11070	1331	6873
11070	1331	5856
17601	1332	7173
17601	1332	5976
17601	1332	9169
17601	1332	3511
17601	1332	6930
17601	1332	209
11951	1333	4562
11951	1333	9931
11951	1333	8566
11951	1333	4775
1262	1334	9431
1262	1334	8783
1262	1334	6950
12238	1335	2725
12238	1335	5799
1596	1336	5194
1596	1336	4302
1596	1336	6512
1596	1336	7788
1596	1336	8306
1596	1336	1917
1596	1336	7668
1596	1336	3556
1012	1337	6625
1012	1337	8611
1012	1337	3889
1012	1337	2282
1012	1337	5208
1012	1337	728
10058	1338	7896
10058	1338	2457
8747	1339	5721
8747	1339	2340
8747	1339	7861
8747	1339	197
8747	1339	2630
8747	1339	3834
12231	1340	7306
12231	1340	8824
12231	1340	4531
12231	1340	3136
12231	1340	7661
12231	1340	8628
12231	1340	9966
12231	1340	1775
8228	1341	7661
8228	1341	2126
8228	1341	8360
8228	1341	6809
8228	1341	2075
8228	1341	9999
8228	1341	5086
19233	1342	2043
19233	1342	72
19233	1342	6714
19233	1342	3097
19233	1342	5723
10159	1343	4632
5983	1344	4567
5983	1344	2944
5983	1344	56
5983	1344	3388
5983	1344	7646
5983	1344	5880
5983	1344	7388
8203	1345	2590
8203	1345	6331
8203	1345	6791
8203	1345	5454
12011	1346	3366
12011	1346	8770
12011	1346	3546
12011	1346	4338
12011	1346	226
12011	1346	3492
12011	1346	1671
12011	1346	2057
16091	1347	9757
16091	1347	2761
16091	1347	8662
16091	1347	7970
16091	1347	4220
16091	1347	6246
16091	1347	1364
9819	1348	1843
9819	1348	213
9819	1348	171
9819	1348	6214
9819	1348	3912
9819	1348	272
9819	1348	8765
9819	1348	1208
19738	1349	8022
19738	1349	6927
19738	1349	1544
19738	1349	9282
19738	1349	3199
10084	1350	376
10084	1350	5763
10084	1350	9585
10084	1350	7785
13098	1351	8075
15628	1352	1773
15628	1352	2433
15628	1352	6220
15628	1352	8752
15628	1352	4836
15628	1352	4460
15628	1352	6298
15628	1352	9379
17927	1353	8820
17927	1353	5759
17927	1353	1081
17927	1353	5163
17927	1353	1647
17927	1353	9392
17927	1353	4096
17927	1353	6736
17927	1353	3538
16746	1354	395
16746	1354	9028
16746	1354	6263
16746	1354	8737
15112	1355	6260
15112	1355	9254
15112	1355	1107
15112	1355	7588
15112	1355	4321
2111	1356	6543
2111	1356	4234
2111	1356	5922
2111	1356	8650
2111	1356	4402
2111	1356	5403
10131	1357	487
10131	1357	1594
5402	1358	3200
5402	1358	7645
5402	1358	6017
5402	1358	1382
5402	1358	1372
5402	1358	7007
11314	1359	570
11314	1359	7783
11314	1359	2712
11314	1359	5193
11314	1359	5431
7611	1360	9768
7611	1360	8541
7611	1360	8209
7611	1360	7055
16853	1361	5720
16853	1361	9781
16853	1361	92
16853	1361	5610
16641	1362	1519
16641	1362	5810
16641	1362	5587
16641	1362	8036
16641	1362	7984
16641	1362	2768
16641	1362	1135
16641	1362	5783
16641	1362	8249
7937	1363	1932
7937	1363	2508
12678	1364	5362
2344	1365	6469
2344	1365	3476
2344	1365	6449
2344	1365	645
2344	1365	6065
2344	1365	5835
2344	1365	7415
2344	1365	8282
426	1366	7754
426	1366	9215
426	1366	5532
16131	1367	6187
16131	1367	2700
16131	1367	6670
14629	1368	3742
14629	1368	6282
9125	1369	4775
9125	1369	4022
6472	1370	7813
6472	1370	3759
6472	1370	9964
6472	1370	5777
6472	1370	9607
6472	1370	1812
17086	1371	1109
17086	1371	4659
17086	1371	8323
17086	1371	3031
14104	1372	288
14104	1372	903
14104	1372	8903
14104	1372	1660
14104	1372	4605
8422	1373	9721
8422	1373	1884
8422	1373	3147
8422	1373	960
18563	1374	2379
18563	1374	4961
18563	1374	7728
18563	1374	9771
18563	1374	3348
18563	1374	3290
18563	1374	7539
18563	1374	2445
4656	1375	1972
4656	1375	9025
19969	1376	9266
19969	1376	71
10061	1377	279
7252	1378	8634
7252	1378	451
7252	1378	4695
14207	1379	1396
14207	1379	497
14207	1379	3390
14207	1379	842
14207	1379	3814
13449	1380	7363
13449	1380	3363
13449	1380	9847
13449	1380	9188
19277	1381	2194
19277	1381	8876
543	1382	8952
543	1382	2258
543	1382	6025
543	1382	706
543	1382	2795
543	1382	4269
543	1382	2869
543	1382	6789
11952	1383	5614
11952	1383	7933
11952	1383	3719
11952	1383	4382
11952	1383	7080
11952	1383	898
6310	1384	9226
6310	1384	4080
6310	1384	3178
6310	1384	2178
17932	1385	4942
17932	1385	1222
17932	1385	713
17932	1385	8363
17932	1385	5964
6086	1386	9074
6086	1386	543
6086	1386	8594
6086	1386	1429
6086	1386	1788
6086	1386	1022
6086	1386	653
18830	1387	9373
18830	1387	8427
18830	1387	2441
18830	1387	4516
18830	1387	9533
18830	1387	1447
18830	1387	8394
18830	1387	1475
135	1388	2741
135	1388	1453
135	1388	4455
135	1388	765
135	1388	1520
135	1388	5258
135	1388	6114
17107	1389	6957
17107	1389	6499
17107	1389	6643
17107	1389	8923
17107	1389	3828
5060	1390	3020
14950	1391	4861
14950	1391	8280
14950	1391	7156
14950	1391	3802
14950	1391	2947
19806	1392	8306
14457	1393	1569
14457	1393	1375
14457	1393	8150
14457	1393	5396
14457	1393	1869
14457	1393	8290
14457	1393	6403
14457	1393	6847
1297	1394	4923
1297	1394	3811
1297	1394	5443
1297	1394	125
18329	1395	6389
9078	1396	7377
9078	1396	9204
9078	1396	3671
9078	1396	2235
9078	1396	9165
9078	1396	1167
9078	1396	7104
9078	1396	6174
9078	1396	5292
10832	1397	4580
10832	1397	3287
10832	1397	2060
14265	1398	4074
14265	1398	8549
14265	1398	830
19988	1399	850
19988	1399	5518
19988	1399	1996
19988	1399	8640
19988	1399	6225
19988	1399	7399
19988	1399	2097
19988	1399	1773
19988	1399	7640
7319	1400	8883
7319	1400	3107
7319	1400	9495
7319	1400	9706
7319	1400	798
12630	1401	7124
12630	1401	1577
12630	1401	6933
12630	1401	4152
12630	1401	9659
12630	1401	3186
8947	1402	9835
8947	1402	2079
8947	1402	9551
8947	1402	4310
10214	1403	1422
10214	1403	6154
10214	1403	3605
10214	1403	1892
10214	1403	6704
10214	1403	9567
10214	1403	1967
10214	1403	3661
10214	1403	7225
14119	1404	1
8620	1405	9417
8620	1405	6836
8620	1405	464
8620	1405	9383
8620	1405	719
8620	1405	4606
8620	1405	7317
18566	1406	4453
18566	1406	2065
18566	1406	1206
18566	1406	3602
18566	1406	531
18566	1406	5516
18566	1406	3021
19713	1407	2846
19713	1407	1403
19713	1407	6426
19713	1407	986
19713	1407	179
19713	1407	3025
19713	1407	2217
8562	1408	803
8562	1408	3660
8562	1408	9854
5750	1409	2732
5750	1409	9335
1475	1410	6746
1475	1410	5195
16438	1411	5696
16438	1411	1395
16438	1411	7727
16438	1411	227
16438	1411	3531
16438	1411	561
16438	1411	2955
11373	1412	1263
11373	1412	732
11373	1412	1024
11373	1412	529
11373	1412	4401
11373	1412	4437
11373	1412	2539
11373	1412	3699
11373	1412	6293
13039	1413	6600
13039	1413	8320
13039	1413	8041
13039	1413	5241
13039	1413	8973
13039	1413	2155
13039	1413	6906
13039	1413	7180
13039	1413	9395
7662	1414	3963
7662	1414	9332
7662	1414	5130
7662	1414	6775
7662	1414	5122
6881	1415	2419
6881	1415	1938
6881	1415	4672
6881	1415	1095
6881	1415	7269
6881	1415	9012
6881	1415	9855
6881	1415	494
6881	1415	7271
13204	1416	2063
13204	1416	6636
13204	1416	4861
13204	1416	625
13204	1416	7304
13204	1416	5958
13204	1416	4434
13204	1416	3333
1203	1417	7265
1203	1417	3090
720	1418	6962
720	1418	5776
720	1418	8414
720	1418	6209
720	1418	362
720	1418	1063
720	1418	9877
8621	1419	9839
7282	1420	7298
7282	1420	5864
7282	1420	4524
7282	1420	7896
7282	1420	5006
7282	1420	509
7282	1420	6084
7282	1420	6693
15512	1421	4776
15512	1421	7737
15512	1421	1257
15512	1421	2281
6710	1422	7519
6710	1422	9328
6710	1422	4144
6710	1422	3527
6710	1422	896
6710	1422	2569
6710	1422	753
6710	1422	3425
15071	1423	8553
15071	1423	4219
12999	1424	9854
12999	1424	2769
12999	1424	8173
12999	1424	9414
5880	1425	6975
15454	1426	2029
19516	1427	5223
19516	1427	6514
19516	1427	2822
19516	1427	2518
19516	1427	526
19516	1427	47
19516	1427	7382
13401	1428	6915
13401	1428	6514
13401	1428	7101
18260	1429	8888
18260	1429	9585
18260	1429	8546
2733	1430	4042
2733	1430	177
2733	1430	3741
2733	1430	3549
2733	1430	4258
2345	1431	5281
2345	1431	3556
2345	1431	1554
2345	1431	2886
4941	1432	8569
4941	1432	5809
4941	1432	1815
4941	1432	8128
3736	1433	6623
3736	1433	3435
3736	1433	4979
3736	1433	7605
3736	1433	1182
3736	1433	266
3736	1433	4834
1462	1434	5173
1462	1434	4654
1462	1434	7275
1462	1434	831
1462	1434	8459
1462	1434	7270
1462	1434	2255
11378	1435	4447
11378	1435	7051
11378	1435	6513
11378	1435	8365
11378	1435	468
11378	1435	2078
11378	1435	9272
7849	1436	393
7849	1436	2957
7849	1436	3830
7849	1436	6858
7849	1436	4118
7849	1436	1773
7849	1436	5461
5022	1437	9827
5022	1437	5078
5022	1437	1756
5022	1437	6384
13326	1438	4217
13326	1438	1697
13326	1438	4194
2101	1439	9720
2101	1439	3381
1199	1440	4331
1199	1440	1663
6836	1441	4444
6836	1441	858
6836	1441	3602
6836	1441	4737
17861	1442	9981
17861	1442	1161
17861	1442	5816
17861	1442	4882
17861	1442	5142
17861	1442	6867
17861	1442	91
17861	1442	8879
17861	1442	1947
12782	1443	5786
12782	1443	8030
12782	1443	5306
12258	1444	8563
12258	1444	9134
12258	1444	5625
12258	1444	9796
12258	1444	6588
12258	1444	238
12258	1444	5192
12258	1444	4580
12258	1444	4557
1926	1445	970
1926	1445	9837
1926	1445	7937
1926	1445	2404
1926	1445	8722
1926	1445	8942
1926	1445	5345
1926	1445	1870
1926	1445	5333
11139	1446	4686
11139	1446	4132
11139	1446	6390
11139	1446	205
11139	1446	6976
11139	1446	3681
11139	1446	7449
19705	1447	819
19705	1447	2677
19705	1447	2985
19705	1447	1302
19705	1447	3003
16274	1448	7850
16274	1448	7814
16274	1448	1889
16274	1448	260
16274	1448	9192
16274	1448	5676
16274	1448	5559
16274	1448	6493
14622	1449	3474
14622	1449	3820
14622	1449	4756
14622	1449	7879
14622	1449	4959
14622	1449	7215
14622	1449	2203
14622	1449	7048
14622	1449	3046
4474	1450	8877
4474	1450	406
4474	1450	1841
4474	1450	2681
4474	1450	6276
4474	1450	1732
4474	1450	929
4474	1450	6918
3754	1451	4686
3754	1451	7370
3754	1451	3075
12057	1452	4659
10127	1453	2066
10127	1453	4229
10127	1453	5732
10127	1453	8437
10127	1453	2447
10127	1453	5468
10127	1453	7232
10127	1453	9918
10127	1453	1233
8614	1454	335
8614	1454	2980
8614	1454	1882
17559	1455	8357
17559	1455	463
17800	1456	4255
17800	1456	9221
18276	1457	6425
18276	1457	4005
18276	1457	9746
18276	1457	4481
18276	1457	9333
18276	1457	2800
18276	1457	5141
18276	1457	1511
18276	1457	5050
8498	1458	5895
8498	1458	4553
8498	1458	6615
8498	1458	4254
8498	1458	2716
8498	1458	7072
8498	1458	4806
8498	1458	1061
787	1459	9782
787	1459	4153
787	1459	4286
3745	1460	208
3745	1460	9266
3745	1460	4462
3745	1460	7778
986	1461	7214
986	1461	9788
986	1461	3485
18263	1462	9919
18263	1462	9742
18263	1462	5026
18263	1462	6077
18263	1462	7146
18263	1462	7823
18263	1462	1044
18263	1462	2291
16378	1463	1159
1892	1464	276
1892	1464	7207
1892	1464	1917
1892	1464	7771
1892	1464	1330
1892	1464	4665
1892	1464	1274
1892	1464	3691
9469	1465	3556
5738	1466	9396
5738	1466	805
5738	1466	5437
5738	1466	7665
5738	1466	3027
5738	1466	9768
5738	1466	1240
5738	1466	3594
5738	1466	8504
4389	1467	6929
4389	1467	6447
4389	1467	7721
4389	1467	3353
4389	1467	5006
4389	1467	7853
6578	1468	5931
6578	1468	4192
6578	1468	714
6578	1468	6796
6578	1468	1335
18098	1469	4984
18098	1469	8481
18098	1469	4906
16515	1470	1006
16515	1470	7391
8561	1471	4197
8561	1471	9463
8561	1471	2182
8561	1471	9217
16782	1472	1529
16782	1472	3473
16782	1472	8978
16782	1472	6210
16782	1472	6635
16782	1472	7135
16782	1472	7448
16782	1472	5591
16782	1472	8806
6004	1473	7912
6004	1473	4768
6004	1473	601
6004	1473	5518
6004	1473	5375
6004	1473	714
6004	1473	7055
6004	1473	7224
7718	1474	1499
7718	1474	6904
7718	1474	8897
15885	1475	6451
2436	1476	7543
2436	1476	992
2436	1476	6314
2436	1476	1764
2436	1476	1396
2436	1476	6634
2436	1476	2846
2436	1476	9019
11845	1477	1632
11845	1477	3254
11845	1477	6818
11845	1477	6966
11845	1477	923
16930	1478	1382
16930	1478	4566
16930	1478	9666
12599	1479	9100
12599	1479	9323
12599	1479	7542
12599	1479	827
12599	1479	7432
8498	1480	8292
8498	1480	7197
8498	1480	3173
8498	1480	3022
8498	1480	3477
8498	1480	7700
19665	1481	4811
19665	1481	7767
19665	1481	4056
19665	1481	4891
19665	1481	4481
19665	1481	8963
5497	1482	7457
5497	1482	5025
5497	1482	4853
5497	1482	5184
5497	1482	5633
18360	1483	5328
6190	1484	8403
6190	1484	8390
6190	1484	8873
6190	1484	6881
14717	1485	5032
14717	1485	8186
14717	1485	3377
14717	1485	8214
14717	1485	6253
14717	1485	8189
14717	1485	596
95	1486	3555
95	1486	4705
95	1486	7898
95	1486	9296
95	1486	9022
95	1486	2136
95	1486	6953
95	1486	4660
16073	1487	7046
16073	1487	4951
16073	1487	3729
16073	1487	8750
16073	1487	5595
18297	1488	1092
18297	1488	6661
18297	1488	3050
10370	1489	2353
10370	1489	1876
10370	1489	7706
10370	1489	4672
10370	1489	5144
10370	1489	9985
10370	1489	5169
1526	1490	9912
1526	1490	558
1526	1490	2741
1526	1490	1392
1526	1490	2900
1526	1490	975
1526	1490	7913
19576	1491	171
19576	1491	37
19576	1491	7025
19576	1491	4187
19576	1491	8756
5702	1492	7320
5702	1492	3872
5702	1492	8532
2862	1493	9342
2862	1493	152
2862	1493	4138
2862	1493	2208
2862	1493	286
2862	1493	9623
2862	1493	2266
2043	1494	3872
2043	1494	5329
2043	1494	9161
15384	1495	9123
15384	1495	3927
15384	1495	5250
15384	1495	5386
15384	1495	6961
15384	1495	3695
15384	1495	9838
4206	1496	3125
4206	1496	6520
4206	1496	2063
4206	1496	8188
18881	1497	6543
18881	1497	6411
18881	1497	6503
18881	1497	4548
18881	1497	1046
9479	1498	8056
9479	1498	1421
9479	1498	7368
9479	1498	9396
9479	1498	1541
9479	1498	5737
9479	1498	2683
9479	1498	9169
9479	1498	2296
17411	1499	365
17411	1499	8027
17411	1499	2236
17411	1499	6149
17411	1499	6826
17411	1499	4297
3330	1500	5553
3330	1500	239
3330	1500	4062
3330	1500	8074
3330	1500	4520
3330	1500	8942
3330	1500	9074
3330	1500	295
16643	1501	5829
16643	1501	9074
16643	1501	1201
16643	1501	902
16643	1501	5035
16643	1501	9365
16643	1501	8027
16643	1501	1876
19898	1502	318
19898	1502	1200
19898	1502	9382
19898	1502	8830
19898	1502	9815
19898	1502	3317
19898	1502	6674
15749	1503	8460
15749	1503	2894
15749	1503	1383
15749	1503	7428
15749	1503	3008
15749	1503	3207
15749	1503	6996
15749	1503	2586
15749	1503	2916
3490	1504	1422
3490	1504	5147
3490	1504	2905
3490	1504	5970
3490	1504	2644
3490	1504	9460
3490	1504	2253
3490	1504	6458
3490	1504	4101
14615	1505	832
14615	1505	4823
14615	1505	2345
14615	1505	5492
14615	1505	4014
14615	1505	59
5927	1506	1628
2176	1507	1931
2176	1507	7339
2176	1507	6708
2176	1507	3338
2176	1507	3598
2176	1507	4877
2176	1507	7917
6817	1508	322
6817	1508	6105
6817	1508	9787
6817	1508	6309
6817	1508	3957
6817	1508	2503
6817	1508	9375
13428	1509	3684
13428	1509	3192
13428	1509	7970
13428	1509	5703
13428	1509	5290
13428	1509	9295
13428	1509	5578
13428	1509	8878
17329	1510	79
17329	1510	2972
4694	1511	9061
5489	1512	26
5489	1512	1025
5489	1512	5133
8855	1513	4044
8855	1513	1621
8855	1513	5911
8855	1513	248
8855	1513	6358
8855	1513	8571
8855	1513	5566
8855	1513	6518
8855	1513	3060
8673	1514	3583
8673	1514	3125
8673	1514	6576
8673	1514	3143
8673	1514	7424
8673	1514	2191
8673	1514	6178
12849	1515	9644
12849	1515	2858
12849	1515	8245
12849	1515	9836
12849	1515	5657
12849	1515	5641
12849	1515	4602
15452	1516	5212
15452	1516	6675
17731	1517	6967
17731	1517	870
17731	1517	148
17731	1517	3719
17731	1517	5723
11115	1518	2763
11115	1518	2931
11115	1518	8132
11115	1518	5091
11115	1518	9817
11115	1518	7152
11115	1518	2937
11115	1518	5356
4645	1519	3380
14196	1520	9061
14196	1520	2526
14196	1520	919
14196	1520	1237
14196	1520	2653
14196	1520	1936
14196	1520	5439
5181	1521	8010
15746	1522	8606
15746	1522	443
15746	1522	6397
10916	1523	7787
10916	1523	4634
10916	1523	8596
10916	1523	8392
10916	1523	5029
10916	1523	2282
10916	1523	6422
10916	1523	4054
10916	1523	4122
83	1524	9341
11475	1525	1196
11475	1525	6926
11475	1525	2555
11475	1525	8006
11475	1525	8845
11475	1525	1681
11475	1525	228
13298	1526	1080
6766	1527	4292
6766	1527	6284
6766	1527	3727
9845	1528	3904
9845	1528	1118
9845	1528	1780
9845	1528	8307
9845	1528	3837
9845	1528	7422
9845	1528	5184
9845	1528	1784
9845	1528	515
18328	1529	7154
18328	1529	8990
18328	1529	2228
18328	1529	5803
19413	1530	1616
19413	1530	2263
19413	1530	6172
7187	1531	5501
7187	1531	9902
7187	1531	1100
7187	1531	5180
4666	1532	3213
4666	1532	4095
4666	1532	1271
4406	1533	4915
2173	1534	4680
2173	1534	2353
2173	1534	1486
2173	1534	6197
2173	1534	1800
2173	1534	9364
2173	1534	3709
2173	1534	7755
3699	1535	7126
9404	1536	4541
9404	1536	8548
9404	1536	3969
9404	1536	3297
9404	1536	3409
9404	1536	8576
9404	1536	7368
13463	1537	4836
13463	1537	1612
13463	1537	5262
13463	1537	4253
13463	1537	2207
14405	1538	2457
14405	1538	2106
10806	1539	185
10806	1539	9050
10806	1539	1697
10806	1539	4284
10806	1539	4720
10806	1539	767
10806	1539	3029
10806	1539	3879
10806	1539	8415
11005	1540	7131
11005	1540	1152
11005	1540	2169
11005	1540	4640
11005	1540	6633
11005	1540	6236
11005	1540	2377
11005	1540	5712
861	1541	6761
861	1541	2079
861	1541	6089
861	1541	6726
861	1541	5996
861	1541	8511
19324	1542	6850
19324	1542	2841
19324	1542	1827
19324	1542	9164
19324	1542	7008
19324	1542	864
19324	1542	5305
19324	1542	8345
848	1543	917
848	1543	1707
434	1544	9879
434	1544	3127
434	1544	9404
434	1544	210
434	1544	5044
4103	1545	4345
4103	1545	2939
4103	1545	1617
4103	1545	3114
4103	1545	9927
4103	1545	3752
6389	1546	8395
3043	1547	7489
3043	1547	4016
3043	1547	8038
4569	1548	1836
4569	1548	1618
4569	1548	7072
4569	1548	7774
4569	1548	8761
4569	1548	8631
4569	1548	4720
4569	1548	684
4569	1548	2208
1326	1549	9328
1326	1549	4656
18479	1550	8168
18479	1550	4744
18479	1550	4937
18479	1550	4517
18479	1550	8814
18479	1550	4235
17909	1551	2069
17909	1551	7728
17909	1551	793
17909	1551	8828
6966	1552	2723
6966	1552	1822
6966	1552	8619
6966	1552	676
6966	1552	8381
6966	1552	6266
1001	1553	9455
1001	1553	5111
5677	1554	7418
5677	1554	3604
5677	1554	536
5677	1554	8624
890	1555	7010
890	1555	397
890	1555	16
890	1555	2584
890	1555	7162
890	1555	9932
890	1555	9780
4940	1556	5953
4940	1556	3418
4940	1556	8159
4940	1556	646
4940	1556	7213
4940	1556	7228
8474	1557	9627
8474	1557	2770
8474	1557	4684
8474	1557	9430
8474	1557	6548
8474	1557	9656
15070	1558	2832
15070	1558	7189
15070	1558	8423
15070	1558	7773
15070	1558	6703
15070	1558	6995
15070	1558	9236
17725	1559	1072
17725	1559	1221
15536	1560	2454
15536	1560	5867
15536	1560	9022
15536	1560	7973
15536	1560	9688
15536	1560	4045
15536	1560	2030
15536	1560	2460
3392	1561	558
3392	1561	2971
8383	1562	1960
8383	1562	2652
8383	1562	3231
8383	1562	7918
11782	1563	2286
11782	1563	4364
11782	1563	3255
11782	1563	3339
11782	1563	8519
11782	1563	8097
11782	1563	7122
5529	1564	7084
5529	1564	4677
5529	1564	1632
19098	1565	5440
19098	1565	2372
19098	1565	1129
19098	1565	2040
19098	1565	3559
4154	1566	1154
4154	1566	9964
4154	1566	804
4154	1566	4696
4154	1566	2441
4154	1566	7623
4154	1566	7279
4154	1566	3621
4154	1566	1343
7429	1567	450
7429	1567	1572
7429	1567	4202
7429	1567	6085
7429	1567	1268
7429	1567	3160
7429	1567	9097
7584	1568	3164
7584	1568	2967
7584	1568	5348
7584	1568	7879
7584	1568	5648
7584	1568	405
7584	1568	1125
7584	1568	1257
7584	1568	4862
1892	1569	8184
1892	1569	7565
1892	1569	7701
1892	1569	1072
1892	1569	2913
1892	1569	9024
8742	1570	1061
8742	1570	6494
8742	1570	547
3606	1571	7261
3606	1571	8126
3606	1571	1715
3606	1571	1577
3606	1571	3589
3606	1571	3298
3606	1571	8828
15702	1572	2222
15702	1572	6129
15702	1572	2671
15702	1572	4748
14134	1573	4247
4745	1574	8682
4745	1574	6927
4745	1574	973
4745	1574	6932
4745	1574	6435
4745	1574	7651
4745	1574	9400
11056	1575	8150
11056	1575	8968
11056	1575	4969
11056	1575	8942
11056	1575	6268
11056	1575	1588
538	1576	2540
538	1576	9674
538	1576	8855
538	1576	5298
538	1576	4632
538	1576	6377
538	1576	225
538	1576	3463
538	1576	7432
4801	1577	1616
4801	1577	580
4801	1577	9073
4801	1577	3472
4801	1577	2552
4801	1577	6210
10128	1578	1569
15890	1579	7475
15890	1579	4075
15890	1579	6570
15890	1579	7307
15890	1579	6541
15890	1579	5673
9489	1580	1899
9489	1580	1608
9489	1580	4999
9489	1580	3173
9489	1580	7868
9489	1580	6296
13945	1581	1112
15362	1582	668
15362	1582	1296
15362	1582	7616
15675	1583	611
15675	1583	1093
15675	1583	7713
11159	1584	8923
11159	1584	2210
11159	1584	1850
11159	1584	1083
11159	1584	1002
3339	1585	8010
18189	1586	2079
18189	1586	3647
18189	1586	7205
12292	1587	1384
12292	1587	8128
12292	1587	3826
12292	1587	6914
12292	1587	6894
12292	1587	9945
10952	1588	8623
10952	1588	6689
10952	1588	3798
10952	1588	1201
10952	1588	1937
10952	1588	8804
10952	1588	4551
11868	1589	9527
11868	1589	3915
11868	1589	337
11868	1589	4355
7877	1590	1533
7877	1590	4533
7877	1590	3985
7877	1590	6987
17847	1591	8294
17847	1591	320
17847	1591	4075
17847	1591	8041
17847	1591	7351
15373	1592	7967
15373	1592	8333
15373	1592	3511
15373	1592	8102
4172	1593	7271
4172	1593	3996
4172	1593	6725
4172	1593	9001
4172	1593	6393
8866	1594	6388
8866	1594	4003
8866	1594	1111
8866	1594	8902
8866	1594	5694
8866	1594	9308
14786	1595	2465
14786	1595	8977
14786	1595	4012
14786	1595	8750
14786	1595	2746
14786	1595	6089
14786	1595	9575
11924	1596	5111
11924	1596	4002
19389	1597	3490
19389	1597	6733
19389	1597	3710
19389	1597	2521
19389	1597	5658
19389	1597	8388
19389	1597	9546
19389	1597	9549
19389	1597	2846
1747	1598	2905
1747	1598	8467
1747	1598	4208
1747	1598	6601
1747	1598	7840
1747	1598	7513
1747	1598	9460
1747	1598	3770
18855	1599	3835
18855	1599	3430
18855	1599	3693
4180	1600	9967
4180	1600	7786
4180	1600	6959
4180	1600	6933
4180	1600	2626
4180	1600	3649
4180	1600	9345
6229	1601	2542
6229	1601	7565
6229	1601	1660
6229	1601	9759
6229	1601	7268
8831	1602	4469
8831	1602	5843
8831	1602	9633
8831	1602	4986
8831	1602	7548
8831	1602	2395
8831	1602	1743
13662	1603	432
13662	1603	8924
13662	1603	7581
9696	1604	9264
9696	1604	2295
9696	1604	8440
9696	1604	5159
9696	1604	913
16922	1605	5353
16922	1605	6479
16922	1605	7353
15568	1606	9876
15568	1606	5513
15568	1606	4517
15568	1606	2205
15568	1606	7260
15568	1606	7512
15568	1606	2636
7097	1607	2009
7097	1607	6825
7097	1607	2114
7097	1607	2721
1256	1608	7459
5943	1609	9431
5943	1609	8859
5943	1609	1146
5943	1609	2390
5943	1609	9040
3707	1610	3446
3707	1610	6700
3707	1610	388
3707	1610	5025
3707	1610	48
3707	1610	85
3707	1610	9400
3707	1610	477
3707	1610	5726
9169	1611	955
9169	1611	5418
5494	1612	2085
5494	1612	2493
5494	1612	853
5494	1612	8204
5494	1612	2072
4314	1613	2804
4314	1613	1395
4314	1613	6141
4314	1613	3114
4314	1613	3521
4314	1613	1725
4314	1613	4063
11822	1614	1204
11822	1614	2553
11822	1614	7652
11822	1614	7934
12173	1615	3638
12173	1615	998
12173	1615	3213
12173	1615	6916
12173	1615	9876
3199	1616	8471
3199	1616	368
3199	1616	4827
3199	1616	5522
3199	1616	3629
3125	1617	7649
3125	1617	1906
3125	1617	9462
3125	1617	6317
3125	1617	41
3125	1617	9001
3125	1617	3668
6083	1618	4099
6083	1618	736
6083	1618	5791
6083	1618	6305
6083	1618	9431
6083	1618	981
6083	1618	1582
6083	1618	7106
6083	1618	9915
12463	1619	9464
12463	1619	6346
12463	1619	7637
12463	1619	6173
12463	1619	7847
12463	1619	5707
2995	1620	917
2995	1620	9941
2995	1620	6597
2995	1620	526
2995	1620	5010
2799	1621	7830
2799	1621	7755
2799	1621	9266
2799	1621	2036
2799	1621	6879
2799	1621	5711
2799	1621	8463
2799	1621	4083
2799	1621	409
700	1622	1872
700	1622	7870
700	1622	7862
700	1622	8281
12220	1623	285
12220	1623	798
12220	1623	5372
12220	1623	2201
12220	1623	262
8689	1624	9344
8689	1624	6748
8689	1624	5702
8689	1624	3661
8689	1624	5502
8689	1624	1712
18728	1625	4771
18728	1625	6656
18728	1625	2496
18728	1625	3245
18728	1625	3110
18728	1625	5360
18728	1625	7850
14386	1626	3432
14386	1626	865
14386	1626	132
3686	1627	1207
3686	1627	1391
3686	1627	215
3686	1627	1546
3686	1627	74
6366	1628	2283
6366	1628	2089
6366	1628	3337
13537	1629	3860
4947	1630	7142
4947	1630	7442
4947	1630	8665
4947	1630	6578
4947	1630	366
4947	1630	5000
4947	1630	9834
4232	1631	9896
4232	1631	5571
4232	1631	9544
6807	1632	5877
6807	1632	5467
6807	1632	8883
6807	1632	1550
6807	1632	564
6807	1632	7757
6807	1632	4779
6807	1632	8700
18469	1633	1858
18469	1633	8265
18469	1633	6543
18469	1633	2505
18469	1633	1212
14177	1634	107
3313	1635	9784
3313	1635	5283
3313	1635	358
3313	1635	9174
11802	1636	2524
11802	1636	2502
11802	1636	7970
11802	1636	6417
11802	1636	2226
11282	1637	7938
11282	1637	8032
11282	1637	859
11282	1637	5383
11282	1637	2377
11282	1637	123
6678	1638	8413
6678	1638	4205
6678	1638	9039
6678	1638	5921
16294	1639	3788
16294	1639	4000
16294	1639	6507
16294	1639	9507
16294	1639	9847
16294	1639	3506
16294	1639	628
5550	1640	6819
5550	1640	1195
467	1641	5689
467	1641	362
8298	1642	5874
8298	1642	8208
8298	1642	6850
8298	1642	268
8298	1642	277
8298	1642	3984
1901	1643	6331
5250	1644	4840
5250	1644	9262
5250	1644	5364
5250	1644	9351
5250	1644	7614
11643	1645	3875
11643	1645	5031
11643	1645	1768
11643	1645	8199
11643	1645	9964
12589	1646	8920
12589	1646	2147
12589	1646	9018
12589	1646	8961
12589	1646	2846
12589	1646	2723
12589	1646	3536
8281	1647	5013
13560	1648	2218
13560	1648	5974
13560	1648	5526
8889	1649	8204
8889	1649	9138
8889	1649	5935
8889	1649	5476
8889	1649	2442
8889	1649	9206
8889	1649	3152
16328	1650	4944
16328	1650	5689
16328	1650	3183
17416	1651	3153
2711	1652	8520
2711	1652	9737
2711	1652	6251
2711	1652	3007
2711	1652	901
2711	1652	9886
2711	1652	4323
18533	1653	6428
18533	1653	312
18533	1653	412
18533	1653	2621
18533	1653	7984
18533	1653	4919
18533	1653	8992
18533	1653	7236
6972	1654	8942
17654	1655	3397
3835	1656	3621
3835	1656	8349
3835	1656	1388
3835	1656	7596
3835	1656	2207
3835	1656	9014
12499	1657	9736
12499	1657	3827
12499	1657	2640
12499	1657	7504
1800	1658	2818
1800	1658	8151
12998	1659	7468
12998	1659	6235
12998	1659	579
12998	1659	872
12998	1659	1498
12998	1659	9917
12998	1659	1629
8536	1660	8493
8536	1660	8313
8536	1660	7051
8536	1660	9233
8536	1660	7568
8536	1660	1700
8536	1660	1574
15616	1661	3057
15616	1661	3212
15616	1661	510
15616	1661	5788
15616	1661	6872
15616	1661	6406
15616	1661	3110
2846	1662	2553
2846	1662	8808
2846	1662	6105
2846	1662	8157
8518	1663	940
8518	1663	8230
8518	1663	3097
8518	1663	7280
8518	1663	877
8518	1663	4581
8518	1663	5191
8518	1663	2180
8685	1664	5738
8685	1664	1786
19885	1665	4201
19885	1665	2863
19885	1665	3546
19885	1665	9292
13141	1666	721
11824	1667	7659
6026	1668	7175
3689	1669	6190
3689	1669	6614
319	1670	6802
319	1670	5505
319	1670	684
319	1670	2433
319	1670	2138
319	1670	8844
319	1670	7138
319	1670	2809
319	1670	3606
11393	1671	7306
11393	1671	876
11393	1671	7069
11393	1671	4079
11393	1671	9452
11393	1671	7188
15743	1672	6545
15743	1672	5867
15743	1672	3115
15743	1672	8745
15743	1672	8716
15743	1672	5907
15468	1673	5751
15468	1673	9272
15468	1673	2552
15468	1673	33
15468	1673	4230
14871	1674	3074
14871	1674	1460
14871	1674	7025
14871	1674	1944
14871	1674	497
14871	1674	8119
14871	1674	5446
14871	1674	4137
19776	1675	2708
5480	1676	9960
5480	1676	5802
5480	1676	8295
5480	1676	6688
5480	1676	7816
5480	1676	4327
5480	1676	9481
5480	1676	419
11727	1677	2467
11727	1677	5251
11727	1677	6068
11727	1677	2295
11727	1677	698
1315	1678	5709
1315	1678	3249
1315	1678	3690
1315	1678	6108
11176	1679	3187
11176	1679	7105
19143	1680	677
19143	1680	2635
19143	1680	8501
19143	1680	8459
19143	1680	3990
19396	1681	2094
19396	1681	5758
19396	1681	9743
19396	1681	3789
19396	1681	7823
9854	1682	4498
9854	1682	753
9854	1682	4451
9854	1682	8145
9854	1682	6720
9854	1682	24
2937	1683	6162
2937	1683	468
2937	1683	701
2937	1683	8501
2937	1683	2792
2937	1683	1464
2937	1683	1250
2937	1683	5514
12533	1684	9654
12533	1684	8944
12533	1684	5670
12533	1684	7082
12533	1684	435
12533	1684	5114
11163	1685	5791
17166	1686	8023
17166	1686	2028
17166	1686	337
17166	1686	9803
17166	1686	9562
17166	1686	324
11985	1687	2366
11985	1687	398
11985	1687	4502
6036	1688	35
6036	1688	7435
6036	1688	2887
6036	1688	7963
6036	1688	8993
6036	1688	8483
6036	1688	9557
6036	1688	8250
8158	1689	6989
8158	1689	1925
8158	1689	5716
8158	1689	7772
17688	1690	5092
17688	1690	2853
17688	1690	518
17688	1690	2892
17688	1690	9115
17688	1690	8304
17688	1690	9418
17688	1690	8550
17688	1690	633
15243	1691	5008
15243	1691	8337
15563	1692	7261
15563	1692	9838
15563	1692	4693
15563	1692	928
15563	1692	9865
16336	1693	4722
16336	1693	4343
16336	1693	1683
16336	1693	2975
16336	1693	6238
16336	1693	2713
16336	1693	763
16336	1693	2357
19233	1694	9729
19233	1694	4830
19233	1694	1377
19233	1694	700
19233	1694	2862
15167	1695	2937
15167	1695	7380
15167	1695	2696
10817	1696	5270
10817	1696	7044
10817	1696	165
10817	1696	4382
10817	1696	9937
2625	1697	1647
2625	1697	662
14669	1698	5690
14669	1698	3199
14669	1698	4408
14669	1698	3794
14669	1698	1751
14669	1698	3149
14669	1698	8970
6704	1699	2564
6704	1699	6186
6704	1699	5008
6704	1699	3236
6704	1699	8190
3199	1700	2389
3199	1700	7078
3199	1700	5165
3199	1700	9396
3199	1700	9934
3199	1700	5710
3199	1700	5857
3199	1700	2256
9638	1701	1288
9638	1701	9539
15456	1702	9327
15456	1702	5194
15456	1702	5052
15456	1702	8512
15456	1702	3143
15456	1702	7132
5683	1703	3488
5683	1703	5371
5683	1703	9055
5683	1703	713
5683	1703	6020
5683	1703	4865
13947	1704	3954
13947	1704	9021
13947	1704	3482
13947	1704	9223
13947	1704	5439
13947	1704	9701
13947	1704	9196
5366	1705	1691
5366	1705	5757
5366	1705	5313
5366	1705	2654
5366	1705	1294
5366	1705	7151
5366	1705	7939
13918	1706	4492
13918	1706	8628
16655	1707	8
16655	1707	7564
16655	1707	5578
16655	1707	894
16655	1707	1657
8622	1708	4944
8622	1708	1715
8622	1708	4638
8622	1708	9841
8663	1709	4261
158	1710	8092
158	1710	5126
158	1710	1464
158	1710	5003
158	1710	2225
158	1710	7432
158	1710	2515
158	1710	2141
158	1710	5256
10192	1711	9428
10192	1711	7572
10192	1711	5369
10192	1711	3767
10192	1711	5968
10192	1711	2224
10192	1711	5527
1058	1712	8641
1058	1712	7943
1058	1712	6613
1058	1712	5385
1058	1712	6861
1058	1712	6964
1058	1712	6554
1058	1712	3989
1058	1712	79
7691	1713	5703
7691	1713	7950
7691	1713	5281
7691	1713	1758
7691	1713	4396
7691	1713	6326
7691	1713	1555
13878	1714	6789
13878	1714	7667
13878	1714	8162
13878	1714	7467
13878	1714	1013
13878	1714	2086
13878	1714	5216
13878	1714	1978
13878	1714	9018
1551	1715	1174
1551	1715	4959
1551	1715	8610
6831	1716	5186
6831	1716	9797
6831	1716	5984
6831	1716	1587
6831	1716	5621
6831	1716	7380
18714	1717	6615
11920	1718	1631
11920	1718	5155
11920	1718	7186
7695	1719	8176
7695	1719	2188
7695	1719	8336
7695	1719	1156
7695	1719	7446
7695	1719	4793
7695	1719	7892
7695	1719	9383
1270	1720	3062
1270	1720	5673
1270	1720	2338
1270	1720	3036
1270	1720	6706
1270	1720	4834
14043	1721	796
14043	1721	7676
14043	1721	8731
14043	1721	7147
13059	1722	7165
13059	1722	8148
13059	1722	3694
12062	1723	2024
12062	1723	5788
2343	1724	4890
2343	1724	7503
2343	1724	2917
2343	1724	5033
2343	1724	2856
2343	1724	6593
2343	1724	8575
13443	1725	542
13443	1725	5306
13443	1725	3901
13443	1725	605
13443	1725	4188
13443	1725	860
13443	1725	6177
13443	1725	2742
13443	1725	8314
6694	1726	9641
6694	1726	6753
6694	1726	6070
104	1727	2476
104	1727	2697
104	1727	4243
104	1727	6064
104	1727	2172
16696	1728	2027
16696	1728	4895
16696	1728	4333
16696	1728	4706
16696	1728	2928
16696	1728	2187
16696	1728	3791
16696	1728	9049
16696	1728	2600
10592	1729	8597
10592	1729	4983
10592	1729	886
10592	1729	9116
10592	1729	715
10592	1729	4544
17751	1730	2848
17751	1730	9243
17751	1730	8148
17751	1730	2157
17751	1730	8431
17751	1730	8720
17751	1730	52
17751	1730	7295
4555	1731	3756
4555	1731	5024
19134	1732	8443
19134	1732	539
19134	1732	5454
7201	1733	797
7201	1733	3238
7201	1733	1987
7201	1733	6135
7201	1733	1937
7201	1733	1559
7201	1733	8183
7201	1733	9884
19115	1734	2311
19115	1734	6166
19115	1734	2506
19115	1734	2630
19115	1734	5220
19115	1734	7312
19115	1734	6688
19115	1734	5532
19115	1734	3838
11549	1735	7127
11549	1735	4827
11549	1735	9769
11549	1735	6568
11549	1735	4474
11549	1735	3758
11549	1735	1727
11549	1735	2259
11549	1735	5094
4810	1736	2954
4810	1736	5160
4810	1736	690
4810	1736	2565
4810	1736	2627
4810	1736	5634
10805	1737	7945
10805	1737	2147
10805	1737	7176
18867	1738	6912
18867	1738	5463
18867	1738	4515
19348	1739	2788
10828	1740	2867
10828	1740	225
10828	1740	7434
10828	1740	1466
10828	1740	9871
15672	1741	894
15672	1741	9711
8450	1742	3899
8450	1742	4938
8450	1742	7751
8450	1742	2100
8450	1742	8949
18347	1743	7343
18347	1743	6392
18347	1743	1
18347	1743	5050
18347	1743	1526
18347	1743	3060
18347	1743	2300
14143	1744	7051
14143	1744	6046
14143	1744	2331
14143	1744	16
14143	1744	3111
14143	1744	453
14143	1744	6205
14143	1744	4366
14143	1744	5009
117	1745	6002
117	1745	5203
117	1745	3948
117	1745	5372
4845	1746	7224
4845	1746	4215
4845	1746	9029
4845	1746	6633
4845	1746	331
4845	1746	7277
4570	1747	2343
4570	1747	1839
4570	1747	7000
4570	1747	6645
4570	1747	7705
4570	1747	8162
4570	1747	4439
4570	1747	3798
16024	1748	5338
11337	1749	365
11337	1749	9402
11337	1749	1678
11337	1749	927
11337	1749	88
11337	1749	557
11337	1749	8873
14069	1750	616
14069	1750	4850
14069	1750	7799
6272	1751	8804
6272	1751	9261
17323	1752	406
17323	1752	6652
17323	1752	7446
12637	1753	3353
12637	1753	9162
12637	1753	1247
12637	1753	5914
12637	1753	7762
12637	1753	2181
1969	1754	153
1969	1754	8284
1969	1754	9295
1969	1754	8266
1969	1754	9183
1969	1754	3156
1969	1754	2030
1969	1754	2383
1969	1754	85
2663	1755	376
2663	1755	3482
2663	1755	361
2663	1755	3541
2663	1755	3466
3499	1756	439
19242	1757	6030
19242	1757	8242
19242	1757	3826
19242	1757	9956
19242	1757	9657
19242	1757	8440
19242	1757	8826
19242	1757	2589
19242	1757	5764
18459	1758	979
18459	1758	5982
18459	1758	2965
18459	1758	1038
18459	1758	2059
599	1759	8625
599	1759	4826
6530	1760	5186
6530	1760	8955
6530	1760	7033
6530	1760	179
6530	1760	8669
6530	1760	9117
6530	1760	2574
6530	1760	7092
6530	1760	1461
18568	1761	934
18568	1761	1590
18568	1761	6356
18568	1761	9024
18568	1761	2302
18568	1761	5574
5213	1762	9462
5213	1762	6493
5213	1762	7775
5213	1762	659
5213	1762	2678
6711	1763	9512
6711	1763	1539
6711	1763	8095
6711	1763	3635
11871	1764	7192
11871	1764	743
11871	1764	1821
11871	1764	4775
11871	1764	8783
11871	1764	7380
11871	1764	7416
11871	1764	1561
5927	1765	5300
5927	1765	4025
5927	1765	4329
13784	1766	5029
13784	1766	8325
291	1767	8459
291	1767	9759
291	1767	4200
291	1767	5896
291	1767	8606
291	1767	8724
291	1767	2232
12513	1768	3916
12513	1768	1157
12513	1768	9770
12513	1768	8295
1459	1769	7938
1459	1769	2691
1459	1769	2537
1459	1769	4870
1459	1769	2651
1459	1769	7742
1459	1769	6977
1459	1769	5396
5627	1770	744
1026	1771	8607
1026	1771	6678
1026	1771	8408
1026	1771	3544
1026	1771	2312
1026	1771	7989
1278	1772	2013
1278	1772	2228
1278	1772	4547
11449	1773	8058
13154	1774	7052
10919	1775	6558
9093	1776	5186
14395	1777	4606
14395	1777	4007
14395	1777	1552
14395	1777	5791
14395	1777	8865
2138	1778	9951
2138	1778	8697
2138	1778	4753
2612	1779	2373
2612	1779	5896
2612	1779	2183
13577	1780	1615
13577	1780	7861
13577	1780	4163
13577	1780	4672
13577	1780	7794
15490	1781	1194
15490	1781	7537
15490	1781	2359
9463	1782	427
9463	1782	5770
9463	1782	1294
9463	1782	6923
9463	1782	3326
9463	1782	313
9463	1782	1508
9463	1782	7837
2844	1783	3704
2844	1783	4359
2844	1783	8691
2780	1784	9984
11508	1785	4526
11508	1785	9605
11508	1785	5252
11508	1785	5340
11508	1785	4901
11508	1785	6061
11508	1785	4598
16602	1786	9541
16602	1786	6288
16602	1786	1427
16602	1786	9016
16602	1786	9612
16602	1786	7164
16602	1786	1117
16602	1786	3626
16602	1786	9542
9763	1787	8057
9763	1787	7446
9763	1787	4802
9763	1787	956
9763	1787	2228
17032	1788	6252
17032	1788	9021
17032	1788	2048
17032	1788	9020
17032	1788	7875
17032	1788	3886
17032	1788	1521
14312	1789	8852
7307	1790	9801
7307	1790	4460
7307	1790	911
7307	1790	3596
5233	1791	8801
5233	1791	5912
5233	1791	4690
12421	1792	3367
12421	1792	6741
12421	1792	1894
12421	1792	5871
12421	1792	3712
12421	1792	4455
10730	1793	2527
10730	1793	7869
10730	1793	4690
10730	1793	7597
10730	1793	3344
14867	1794	3821
14867	1794	9104
14867	1794	4081
14867	1794	310
14867	1794	3059
15026	1795	2878
15026	1795	2531
15026	1795	5377
15026	1795	957
15026	1795	7068
15026	1795	668
15026	1795	839
18670	1796	1198
18670	1796	2226
5070	1797	6556
5070	1797	6458
5070	1797	8129
5070	1797	2183
5070	1797	4740
5070	1797	1058
5070	1797	7626
5070	1797	4249
5070	1797	8535
12757	1798	8043
12757	1798	31
12757	1798	897
12757	1798	2803
12757	1798	4861
2635	1799	653
2635	1799	5762
2635	1799	7848
2635	1799	1088
2635	1799	4944
6957	1800	9857
6957	1800	8266
6957	1800	463
2719	1801	7484
8917	1802	9562
8917	1802	8722
8917	1802	6434
8917	1802	2142
8917	1802	2042
8917	1802	2856
8917	1802	564
8917	1802	8931
14393	1803	5493
14393	1803	9944
14393	1803	7454
14393	1803	8777
14393	1803	1886
14393	1803	6215
14393	1803	209
14393	1803	6770
17823	1804	5997
17823	1804	9354
17823	1804	296
17823	1804	6979
10595	1805	1783
18473	1806	7018
18473	1806	8620
18473	1806	7705
18473	1806	8167
18473	1806	5470
18473	1806	3386
18473	1806	3218
18473	1806	6649
18473	1806	5942
5841	1807	8218
5841	1807	7308
5841	1807	9308
5841	1807	9237
5841	1807	7438
5841	1807	9938
15285	1808	2117
15285	1808	7323
15285	1808	9987
15285	1808	4884
15285	1808	3112
15285	1808	3581
15285	1808	3746
3926	1809	1963
3926	1809	5595
3926	1809	4291
3926	1809	7453
3926	1809	9090
3926	1809	1871
3926	1809	4588
3820	1810	2450
3820	1810	954
3820	1810	5198
3820	1810	9528
19659	1811	7440
19659	1811	5390
19659	1811	4067
19659	1811	6065
19659	1811	3909
11558	1812	9766
11558	1812	4954
11558	1812	7778
17462	1813	3265
17462	1813	7766
17462	1813	2322
17462	1813	1518
17462	1813	1538
17462	1813	2794
17462	1813	6588
17462	1813	7124
11159	1814	8623
11159	1814	6603
11159	1814	5295
17842	1815	7745
17842	1815	6436
17842	1815	3115
17842	1815	4180
11436	1816	1323
11436	1816	169
8363	1817	7324
8363	1817	939
8363	1817	6224
8363	1817	8307
8363	1817	5154
5797	1818	8408
5797	1818	6338
5797	1818	5540
5797	1818	8306
5797	1818	6164
5797	1818	5206
5797	1818	8074
4197	1819	4746
4197	1819	1763
4197	1819	5897
4197	1819	8172
4197	1819	1488
4197	1819	3949
4197	1819	6898
4197	1819	190
11460	1820	2809
11460	1820	2877
11460	1820	585
2196	1821	8935
1395	1822	767
1395	1822	7179
1395	1822	6253
1395	1822	1537
1395	1822	3484
1395	1822	6386
8948	1823	8727
18622	1824	409
18686	1825	40
1614	1826	3061
1614	1826	5351
1614	1826	1449
1614	1826	6323
7558	1827	4043
7558	1827	3494
7558	1827	345
7558	1827	2440
7558	1827	7551
7558	1827	96
7558	1827	4043
7558	1827	9010
7558	1827	943
8007	1828	8601
9846	1829	8702
9846	1829	5696
9846	1829	1976
9846	1829	5065
9846	1829	8186
9846	1829	3073
9846	1829	629
9342	1830	5758
9342	1830	9699
9342	1830	8249
9342	1830	1728
9342	1830	9855
9342	1830	1772
9342	1830	7978
9342	1830	9432
2814	1831	3727
2814	1831	5785
2814	1831	6784
2814	1831	9968
2814	1831	1085
2814	1831	5062
2814	1831	7518
2814	1831	7909
19273	1832	859
19273	1832	2157
19273	1832	4861
19273	1832	2509
10741	1833	6418
10741	1833	3521
10741	1833	8558
10741	1833	9620
10741	1833	6760
10741	1833	6484
10741	1833	9442
6509	1834	6921
6509	1834	7045
6509	1834	3723
12463	1835	1602
12463	1835	380
12463	1835	8485
12463	1835	1220
1678	1836	5520
1678	1836	8425
1678	1836	7560
1678	1836	8216
10273	1837	4214
10273	1837	74
10273	1837	6428
10273	1837	8537
10273	1837	6396
10273	1837	6049
10273	1837	2817
10273	1837	1923
17214	1838	1774
17214	1838	8589
17214	1838	1246
17214	1838	921
14791	1839	7592
14791	1839	1030
14791	1839	668
14791	1839	2050
14791	1839	8483
14791	1839	1944
7733	1840	2473
7733	1840	7102
7733	1840	8636
7733	1840	3580
9002	1841	1896
9002	1841	585
9002	1841	3401
9002	1841	3507
11113	1842	3654
11113	1842	963
11113	1842	6941
11113	1842	2495
11113	1842	8325
11113	1842	3661
11113	1842	5285
11113	1842	6840
11113	1842	1741
7273	1843	3124
7273	1843	4410
7273	1843	9348
957	1844	3553
957	1844	4861
957	1844	8683
957	1844	9908
957	1844	6951
957	1844	3967
1612	1845	9896
1612	1845	6185
1612	1845	5017
18851	1846	5016
18851	1846	6879
18851	1846	3967
18851	1846	6485
18851	1846	926
18851	1846	6182
6264	1847	5367
6264	1847	6946
6264	1847	7757
6264	1847	7602
6264	1847	8615
6264	1847	3249
18376	1848	7314
18376	1848	7327
18376	1848	9378
18376	1848	107
18376	1848	8978
18376	1848	1136
18376	1848	9421
9575	1849	167
9575	1849	1076
9575	1849	2442
9575	1849	385
4856	1850	9486
4856	1850	6371
4856	1850	3471
4856	1850	624
4856	1850	6052
4856	1850	9867
4856	1850	752
16084	1851	2277
16084	1851	1969
16084	1851	2008
16084	1851	3043
16799	1852	5824
16799	1852	7170
16799	1852	1118
16799	1852	7943
16799	1852	4218
8169	1853	3371
8169	1853	135
4824	1854	5765
4824	1854	3752
4824	1854	6085
4824	1854	7206
4824	1854	8830
4824	1854	5211
4824	1854	5224
4824	1854	6640
4824	1854	8070
18823	1855	1505
18823	1855	2245
18823	1855	5757
18823	1855	4051
18823	1855	8958
18823	1855	1135
18823	1855	8622
18823	1855	6560
10780	1856	1389
10780	1856	9662
10780	1856	7246
10780	1856	8886
7655	1857	2140
7655	1857	286
7655	1857	4605
7655	1857	5339
7655	1857	4152
7655	1857	6271
7655	1857	3692
7655	1857	8599
14910	1858	1535
14910	1858	7637
14910	1858	2542
14910	1858	3184
14910	1858	350
14910	1858	8331
14910	1858	917
14910	1858	387
14910	1858	2953
14207	1859	9876
14207	1859	8184
14207	1859	7704
14207	1859	5930
14207	1859	6012
7298	1860	172
1043	1861	3011
1043	1861	6834
1043	1861	1792
1043	1861	9122
1043	1861	6890
1043	1861	6229
1043	1861	7207
1043	1861	5239
2335	1862	8631
2335	1862	476
2335	1862	5628
2335	1862	4301
2335	1862	1169
2335	1862	3734
2335	1862	5927
15437	1863	8593
15437	1863	8015
15437	1863	4007
15437	1863	9233
15437	1863	131
15437	1863	413
15437	1863	6875
14700	1864	7998
14700	1864	4458
14700	1864	7872
14700	1864	3345
14700	1864	8758
14700	1864	1517
14700	1864	7618
14700	1864	6353
14700	1864	4930
8325	1865	4210
2168	1866	8434
2168	1866	1133
11179	1867	3780
11179	1867	2862
11179	1867	9861
11179	1867	1648
11179	1867	4487
11179	1867	3111
11179	1867	8359
11179	1867	3579
11179	1867	4948
7645	1868	6013
7645	1868	10
7645	1868	3737
7645	1868	2735
7645	1868	264
7645	1868	8274
7645	1868	9051
1396	1869	8697
1396	1869	1405
9966	1870	2771
9966	1870	1456
9966	1870	28
9966	1870	8948
9966	1870	4614
9966	1870	1238
9966	1870	2017
580	1871	8425
580	1871	3609
580	1871	4119
11046	1872	506
11046	1872	3079
11046	1872	7371
11046	1872	4919
11046	1872	2003
13231	1873	3963
13231	1873	176
13231	1873	8858
13231	1873	735
13231	1873	6932
13231	1873	1318
13231	1873	6649
13231	1873	6573
14157	1874	355
14157	1874	7134
14157	1874	5156
5183	1875	1265
5183	1875	4257
5183	1875	7537
5183	1875	6243
5183	1875	396
5183	1875	2615
18527	1876	5274
11320	1877	3418
11320	1877	3503
11320	1877	4178
11320	1877	1165
11320	1877	8332
11320	1877	9643
11320	1877	3869
11320	1877	5702
12194	1878	7810
12194	1878	7329
12194	1878	8306
12194	1878	8909
12194	1878	8262
12194	1878	4411
12194	1878	1860
12194	1878	252
2831	1879	3844
2831	1879	1474
2831	1879	2789
2831	1879	7823
2831	1879	3273
2831	1879	6304
2831	1879	8616
2831	1879	4680
7176	1880	405
7176	1880	6173
7176	1880	5425
7176	1880	8303
7176	1880	7840
3368	1881	9396
3368	1881	3514
3368	1881	905
3368	1881	8327
3368	1881	7868
3368	1881	840
14145	1882	1567
14145	1882	4478
14145	1882	8804
14145	1882	4164
14145	1882	5882
14145	1882	1376
14145	1882	3687
6165	1883	302
17255	1884	5570
17255	1884	7799
17255	1884	9945
17255	1884	6398
17255	1884	472
18552	1885	6383
18552	1885	5417
18552	1885	7406
18552	1885	9012
5862	1886	7756
5862	1886	1115
5862	1886	7726
11049	1887	9458
11049	1887	4114
11049	1887	3388
8330	1888	824
8330	1888	3345
8330	1888	1298
8330	1888	2720
8330	1888	5286
8330	1888	5971
14170	1889	3769
14170	1889	3533
14170	1889	8090
14170	1889	2398
14170	1889	2919
14170	1889	5568
14170	1889	9950
14170	1889	7710
2108	1890	3409
2108	1890	9321
2108	1890	9531
2108	1890	1736
2108	1890	2376
2108	1890	7822
2708	1891	4344
2708	1891	344
2708	1891	4210
2708	1891	9385
2708	1891	8256
2708	1891	4933
2708	1891	8149
2708	1891	8632
15905	1892	3243
15905	1892	5000
15905	1892	6553
15905	1892	1763
15905	1892	4175
17036	1893	5780
17036	1893	999
17036	1893	4585
17036	1893	2259
17036	1893	2050
1363	1894	8634
1363	1894	4296
1363	1894	4205
1363	1894	7495
1363	1894	2117
1363	1894	7361
1363	1894	7047
1363	1894	4809
1363	1894	7192
16381	1895	7445
16381	1895	7788
16381	1895	8418
16381	1895	176
16381	1895	349
16381	1895	2599
16381	1895	685
16381	1895	3941
12114	1896	2348
12114	1896	7025
12114	1896	7744
12114	1896	7743
12114	1896	2407
19704	1897	9346
19704	1897	8727
19704	1897	306
19704	1897	8330
19704	1897	3721
19704	1897	9708
19704	1897	7193
9256	1898	9110
9256	1898	3220
9256	1898	3431
9256	1898	8283
9256	1898	4457
9256	1898	5689
10069	1899	4556
10069	1899	3272
10069	1899	9095
10069	1899	1899
18181	1900	3719
18181	1900	4434
18181	1900	7473
18181	1900	9682
18181	1900	8616
18181	1900	6741
18181	1900	5947
18181	1900	9035
9840	1901	1110
9840	1901	4904
13603	1902	5892
19220	1903	2438
19220	1903	986
19220	1903	1710
16900	1904	879
16900	1904	7445
16900	1904	6628
16900	1904	361
16900	1904	1941
16900	1904	7942
13894	1905	2023
13894	1905	7567
13894	1905	576
13894	1905	6164
13894	1905	2124
13894	1905	1163
13894	1905	6323
13894	1905	8235
11359	1906	8736
11359	1906	9908
15698	1907	4796
15698	1907	1189
15698	1907	4082
9315	1908	6219
9315	1908	6211
9315	1908	3089
9315	1908	1217
9315	1908	9734
9315	1908	7003
9315	1908	8931
9315	1908	1180
4692	1909	5578
4692	1909	1746
4692	1909	8300
4692	1909	5521
4692	1909	485
13406	1910	4084
13406	1910	7555
13406	1910	9576
13406	1910	2060
13406	1910	2565
7489	1911	6091
7489	1911	3640
7489	1911	7995
7489	1911	8433
7489	1911	1213
7489	1911	6768
7489	1911	8234
7489	1911	8401
4968	1912	7784
4968	1912	5442
4968	1912	7802
4968	1912	834
4968	1912	1751
4968	1912	8850
4968	1912	7175
4968	1912	9508
15882	1913	1895
15882	1913	784
15882	1913	3808
15882	1913	3525
15882	1913	1668
15882	1913	2560
15882	1913	6397
15882	1913	9296
15882	1913	6007
15515	1914	5598
15515	1914	5654
15515	1914	3133
9190	1915	2824
9190	1915	5068
9190	1915	2582
9190	1915	1038
9190	1915	3765
321	1916	4359
321	1916	3125
321	1916	5362
1919	1917	6065
1919	1917	1021
1919	1917	9605
1919	1917	4050
1919	1917	7034
1919	1917	9060
1919	1917	7710
2947	1918	1634
2947	1918	562
2947	1918	2896
2947	1918	4666
2947	1918	7602
2947	1918	9217
2947	1918	3998
10036	1919	8654
10036	1919	6524
10036	1919	7559
10036	1919	5303
18335	1920	6734
18335	1920	4665
18335	1920	4367
18335	1920	983
18335	1920	5818
18335	1920	5537
18335	1920	8064
18335	1920	316
18335	1920	4552
6409	1921	8892
6409	1921	8756
6409	1921	5974
5429	1922	1089
10911	1923	4487
10911	1923	6956
10911	1923	6886
10911	1923	9557
10911	1923	7572
10911	1923	1908
10911	1923	7312
10911	1923	7392
12294	1924	583
12294	1924	4448
11073	1925	992
11073	1925	9613
13135	1926	1586
13135	1926	4837
13135	1926	9165
13135	1926	3377
13135	1926	1799
13135	1926	2679
13135	1926	6915
14993	1927	1888
14993	1927	9277
14993	1927	1924
14993	1927	3651
8802	1928	2037
8802	1928	6306
10941	1929	1947
10941	1929	2989
19807	1930	7400
19807	1930	6007
19807	1930	5216
14280	1931	8676
14280	1931	2091
14280	1931	2547
14280	1931	6467
14280	1931	1002
14280	1931	4323
14280	1931	7533
1043	1932	425
1043	1932	5276
1043	1932	3128
16688	1933	5484
16688	1933	8841
1863	1934	5060
1863	1934	4814
1863	1934	2716
1863	1934	679
1863	1934	5404
1863	1934	770
2388	1935	9018
2388	1935	279
2388	1935	6366
2388	1935	7279
2388	1935	8962
2388	1935	6007
2388	1935	7051
2388	1935	8339
2388	1935	4348
14125	1936	7311
14125	1936	9561
14125	1936	3990
14125	1936	9273
14125	1936	2278
14125	1936	6905
14125	1936	4419
14125	1936	9401
16725	1937	740
16725	1937	8068
4830	1938	9477
4830	1938	3996
4830	1938	2208
4830	1938	4867
4830	1938	6838
18231	1939	1672
18231	1939	5254
744	1940	1496
744	1940	1231
744	1940	9253
744	1940	1979
744	1940	3355
744	1940	5999
16414	1941	4404
16414	1941	7247
16414	1941	6859
17061	1942	9603
17061	1942	7094
17061	1942	1433
17061	1942	9211
17061	1942	8153
17061	1942	871
17061	1942	9946
11889	1943	4151
11889	1943	2936
11889	1943	225
11889	1943	8039
11889	1943	9858
11889	1943	5614
11889	1943	6228
11889	1943	1452
11889	1943	4253
6928	1944	1927
3745	1945	7817
3745	1945	1608
9087	1946	4726
9087	1946	2009
9087	1946	8067
9087	1946	965
9087	1946	2838
14182	1947	555
14182	1947	9591
14182	1947	7266
14182	1947	4354
14182	1947	1565
14182	1947	128
14182	1947	4138
14182	1947	7716
14182	1947	9754
3525	1948	9385
3525	1948	5580
6390	1949	2722
6390	1949	6553
6390	1949	2349
6390	1949	2096
6390	1949	1726
6390	1949	8871
6016	1950	7667
6016	1950	6989
6016	1950	8198
6016	1950	2172
6016	1950	2000
4809	1951	8109
4809	1951	8984
4809	1951	5979
4809	1951	8479
4809	1951	8034
4809	1951	1735
4809	1951	2058
4809	1951	9912
4809	1951	3115
207	1952	4115
207	1952	953
207	1952	8387
207	1952	8519
13255	1953	1289
13255	1953	189
13255	1953	7051
13255	1953	9971
13255	1953	5127
13255	1953	7353
13255	1953	767
13255	1953	2618
2164	1954	1718
2164	1954	800
2164	1954	1020
2164	1954	9437
2164	1954	5946
14468	1955	7000
14468	1955	8161
14468	1955	7248
14468	1955	8999
14468	1955	8326
14468	1955	5067
14468	1955	5706
14468	1955	2025
14468	1955	323
2244	1956	440
2244	1956	7193
2244	1956	5719
2244	1956	3619
2244	1956	6880
2244	1956	5593
5682	1957	7441
5682	1957	6352
5682	1957	7595
5682	1957	8146
5682	1957	7075
5682	1957	3361
14414	1958	490
12415	1959	3338
17861	1960	1772
17861	1960	4829
17861	1960	9688
17861	1960	1721
17861	1960	3238
17861	1960	6900
17861	1960	8333
17861	1960	2666
2641	1961	7167
2641	1961	4164
2641	1961	4399
2641	1961	9624
2641	1961	6432
2641	1961	3292
2641	1961	7367
2641	1961	7416
18271	1962	9001
18271	1962	2850
18271	1962	1494
17921	1963	6917
17921	1963	7571
17921	1963	3958
7161	1964	7912
7161	1964	3215
7161	1964	8433
7161	1964	2332
7161	1964	9765
17531	1965	6099
17531	1965	8635
17531	1965	8355
10541	1966	6350
10541	1966	4098
2236	1967	1430
2236	1967	199
2236	1967	3785
2236	1967	7595
2236	1967	9196
14192	1968	6490
14192	1968	9766
14192	1968	5089
14192	1968	114
14192	1968	6454
14192	1968	7990
14192	1968	1394
14192	1968	1669
6197	1969	2960
1109	1970	8419
1109	1970	8940
10858	1971	272
10858	1971	6642
10858	1971	8671
13320	1972	1659
13320	1972	9577
13320	1972	8413
13320	1972	1697
13320	1972	2341
13320	1972	1927
13320	1972	6189
13320	1972	8304
1711	1973	3173
1711	1973	2880
1711	1973	1214
1711	1973	2909
1711	1973	8210
1711	1973	6305
1711	1973	1870
1711	1973	1447
6286	1974	7488
6286	1974	6453
6286	1974	3928
7352	1975	2445
7352	1975	188
7352	1975	8600
7352	1975	6874
7352	1975	9465
7352	1975	8063
7352	1975	4951
7352	1975	1650
7352	1975	215
3739	1976	5452
3739	1976	704
3739	1976	5094
3739	1976	3055
3739	1976	8867
3739	1976	9491
3739	1976	824
15394	1977	2780
15394	1977	5689
15394	1977	7593
15394	1977	4128
15394	1977	8934
15394	1977	9676
15394	1977	695
15394	1977	3156
15394	1977	4506
15120	1978	3059
15120	1978	8826
15120	1978	6536
15120	1978	1579
15120	1978	9200
15120	1978	3795
15120	1978	2090
15120	1978	2226
15120	1978	9194
17740	1979	3997
17005	1980	6062
17005	1980	2654
17005	1980	2782
18636	1981	5452
18636	1981	8940
18636	1981	4848
18636	1981	633
18636	1981	7247
14263	1982	7712
14263	1982	9341
9443	1983	9058
9443	1983	6376
9443	1983	6705
9443	1983	1157
9443	1983	3959
9443	1983	7424
9443	1983	5853
12970	1984	6311
12970	1984	8306
12033	1985	5706
12033	1985	3844
12033	1985	6148
12033	1985	3504
12033	1985	4740
12033	1985	1901
12033	1985	7673
12033	1985	2504
12033	1985	8759
5372	1986	3860
5372	1986	4284
5372	1986	6159
5372	1986	8182
5372	1986	3189
5372	1986	2748
5372	1986	2165
11337	1987	5877
11337	1987	570
11337	1987	9179
11337	1987	8645
11337	1987	1431
12544	1988	7424
12544	1988	6648
12544	1988	1071
12544	1988	7438
12544	1988	8716
1762	1989	6549
1762	1989	5900
12938	1990	9543
12938	1990	932
12938	1990	631
6703	1991	356
6703	1991	8250
6703	1991	7513
6703	1991	5686
6703	1991	5872
9903	1992	5449
9903	1992	6083
9903	1992	572
9903	1992	2259
6380	1993	4744
6380	1993	657
6380	1993	2998
6380	1993	3464
6380	1993	2439
6380	1993	6934
6380	1993	7205
8628	1994	7972
8628	1994	7409
8628	1994	2470
9456	1995	7918
9456	1995	92
9456	1995	7512
1018	1996	1756
1018	1996	7881
1018	1996	2324
1018	1996	1495
1018	1996	9400
1018	1996	732
1018	1996	2457
9851	1997	9654
9851	1997	322
9851	1997	3397
9851	1997	232
9851	1997	1162
9851	1997	1418
9851	1997	577
16915	1998	3543
16915	1998	6871
16915	1998	2609
16915	1998	313
16915	1998	5743
16915	1998	9991
16915	1998	9274
16915	1998	6081
16915	1998	7214
14892	1999	1119
14892	1999	4092
2426	2000	658
2426	2000	196
2426	2000	6638
2426	2000	5130
2426	2000	7869
2426	2000	8688
2426	2000	2737
931	2001	9702
931	2001	3782
931	2001	2714
931	2001	4178
931	2001	4
14397	2002	7109
14397	2002	8084
14397	2002	4034
14397	2002	6602
14397	2002	7593
14397	2002	7983
14397	2002	5038
14397	2002	503
409	2003	8385
409	2003	1965
409	2003	6491
409	2003	8342
409	2003	9167
409	2003	1545
409	2003	1012
409	2003	556
14315	2004	2115
14315	2004	3555
14315	2004	4071
14315	2004	2985
14589	2005	4317
14589	2005	5209
14589	2005	70
18473	2006	5511
18473	2006	5469
18473	2006	6883
18473	2006	3223
18473	2006	4909
18473	2006	9068
6276	2007	1352
6276	2007	2768
6276	2007	9427
6276	2007	5591
6276	2007	7891
4374	2008	8027
4374	2008	847
4374	2008	6473
4374	2008	4888
4374	2008	1712
4374	2008	5033
4374	2008	8260
4374	2008	3918
4374	2008	2995
11524	2009	2847
11524	2009	1621
11524	2009	4007
11524	2009	2924
11524	2009	8816
11524	2009	9311
11524	2009	4446
18666	2010	9130
18666	2010	9881
18666	2010	8034
18666	2010	8168
18666	2010	9067
18666	2010	6790
18666	2010	2714
18666	2010	170
18666	2010	373
6593	2011	4247
6593	2011	2616
6593	2011	8173
7303	2012	4164
7303	2012	4543
7303	2012	2787
7303	2012	3224
7303	2012	8439
7303	2012	3676
7303	2012	9650
44	2013	3319
44	2013	2579
44	2013	3490
44	2013	6257
44	2013	5201
44	2013	5314
44	2013	1436
44	2013	3296
44	2013	1673
9794	2014	4911
9794	2014	8279
9794	2014	5454
9794	2014	4582
9794	2014	3389
9794	2014	4575
9794	2014	5464
3441	2015	6002
3441	2015	670
3441	2015	4516
3441	2015	3415
3441	2015	46
3441	2015	1086
11992	2016	556
11992	2016	1275
11992	2016	8516
11992	2016	3036
11992	2016	631
11992	2016	1155
11992	2016	220
12442	2017	3658
12442	2017	2788
12442	2017	6625
12442	2017	9177
12442	2017	813
12442	2017	3706
12442	2017	5919
12442	2017	5442
7915	2018	7048
7915	2018	932
7915	2018	4279
4866	2019	1257
4866	2019	5437
4866	2019	8101
4866	2019	6877
4866	2019	9771
6952	2020	7737
6952	2020	8797
1305	2021	3139
1305	2021	2738
1305	2021	1649
1305	2021	9850
1305	2021	6821
4515	2022	4319
4515	2022	5427
4515	2022	9717
4515	2022	7564
4515	2022	2716
4515	2022	1337
4515	2022	2434
4515	2022	2165
10607	2023	2721
10607	2023	7919
10607	2023	3164
10607	2023	3677
10607	2023	6997
10607	2023	1362
13577	2024	7901
1231	2025	2128
1231	2025	8537
1231	2025	2699
1231	2025	9596
1231	2025	7997
1231	2025	9338
1231	2025	4886
1231	2025	654
1231	2025	5714
14151	2026	3864
14151	2026	8810
14151	2026	7335
14151	2026	2379
14151	2026	6896
14151	2026	6301
14151	2026	8799
14151	2026	7329
10651	2027	1241
10651	2027	6032
10651	2027	4158
10651	2027	9545
17019	2028	2877
17019	2028	4448
17019	2028	5781
5353	2029	8108
5353	2029	1111
10607	2030	8834
10607	2030	4830
10607	2030	3897
10607	2030	6612
10607	2030	534
10607	2030	1950
10607	2030	8117
10607	2030	8918
10607	2030	5037
1697	2031	2961
8142	2032	9374
8142	2032	8615
8142	2032	3683
8142	2032	3073
8142	2032	2433
8142	2032	1019
8142	2032	5117
8142	2032	3286
8142	2032	7795
5663	2033	3680
5663	2033	5912
5663	2033	9758
5663	2033	711
5663	2033	6147
9524	2034	8207
9524	2034	3618
9524	2034	1050
9524	2034	3605
9524	2034	7605
9524	2034	9398
10390	2035	383
10390	2035	270
10390	2035	8550
10390	2035	3060
10390	2035	703
10390	2035	9346
15275	2036	9003
15275	2036	2814
12836	2037	3308
12836	2037	354
12836	2037	810
12836	2037	8395
12836	2037	493
18086	2038	8304
15297	2039	5286
15297	2039	5895
15297	2039	4265
15297	2039	4341
1115	2040	6172
1115	2040	835
1115	2040	5507
1115	2040	8173
1115	2040	7893
1115	2040	5043
1115	2040	6203
1115	2040	5977
16859	2041	9979
16859	2041	568
16859	2041	4276
16859	2041	5859
16859	2041	5465
16859	2041	7836
17339	2042	7898
17339	2042	858
17339	2042	2449
17339	2042	2375
17339	2042	9245
478	2043	6518
478	2043	9846
478	2043	1002
478	2043	1994
14918	2044	9096
14918	2044	28
15852	2045	3717
15852	2045	255
15852	2045	5605
15852	2045	4442
2443	2046	7980
2443	2046	3342
2443	2046	8454
2443	2046	5843
2443	2046	2794
2443	2046	3336
6727	2047	1289
6727	2047	1623
6727	2047	1061
6727	2047	1096
6727	2047	1376
6727	2047	6875
6727	2047	6759
9477	2048	3721
19126	2049	4694
19126	2049	728
19126	2049	2821
19126	2049	5731
19126	2049	4438
19126	2049	9116
19126	2049	9229
19126	2049	2164
18076	2050	399
18076	2050	7245
18076	2050	9796
11683	2051	4680
11683	2051	5818
11683	2051	3684
11683	2051	5738
11683	2051	2749
11683	2051	6767
11991	2052	6600
11991	2052	6875
11991	2052	329
11991	2052	7403
11991	2052	3365
11991	2052	8538
11991	2052	3040
11991	2052	9961
11557	2053	4417
11557	2053	7384
11557	2053	9040
11557	2053	9028
11557	2053	146
11557	2053	2551
11557	2053	8924
11557	2053	5062
4929	2054	9664
5406	2055	423
5406	2055	9404
5406	2055	6684
5406	2055	2414
2908	2056	6167
17435	2057	8143
9682	2058	4904
9682	2058	1479
9682	2058	5000
9682	2058	2193
9682	2058	4621
9682	2058	8972
2771	2059	2840
2771	2059	6414
2771	2059	1952
2771	2059	7724
2771	2059	7566
2771	2059	7229
19724	2060	2159
19724	2060	4179
19724	2060	356
19724	2060	2580
19724	2060	7968
19724	2060	6282
3307	2061	5243
3307	2061	4782
3307	2061	3726
3307	2061	4254
3307	2061	8371
3307	2061	8148
2237	2062	5568
2237	2062	660
2237	2062	5238
2237	2062	900
14362	2063	8834
14362	2063	3504
14362	2063	2571
14362	2063	1272
14362	2063	790
14362	2063	7587
14362	2063	7007
16701	2064	1853
16701	2064	1792
16701	2064	8343
18485	2065	6423
10514	2066	9334
10514	2066	57
1693	2067	7
1693	2067	5381
1693	2067	1487
1693	2067	1170
1693	2067	4653
1693	2067	5851
1693	2067	9990
1693	2067	2238
1693	2067	2144
826	2068	2185
4483	2069	3088
4483	2069	7710
4483	2069	3122
4483	2069	1338
4483	2069	5323
4483	2069	7948
4483	2069	5468
4483	2069	2971
10416	2070	3868
10416	2070	7957
10416	2070	2964
10416	2070	1036
10416	2070	2383
10416	2070	7030
10416	2070	4877
15996	2071	2606
15996	2071	2409
15996	2071	3126
15996	2071	4352
15996	2071	3334
15996	2071	1304
15996	2071	7296
15996	2071	1739
15996	2071	2957
7985	2072	8884
7985	2072	3244
7985	2072	5437
7985	2072	1758
7985	2072	1709
7985	2072	6416
7985	2072	4917
18536	2073	9020
18536	2073	4340
18536	2073	2113
18536	2073	1566
18536	2073	781
8898	2074	5147
8898	2074	1705
8898	2074	9782
8898	2074	3848
8898	2074	7825
8898	2074	5607
8898	2074	9805
8898	2074	2009
2057	2075	7343
2057	2075	3341
2057	2075	9565
2057	2075	5867
2057	2075	8570
2057	2075	6571
2057	2075	8574
16710	2076	9845
16710	2076	8410
16710	2076	2302
16710	2076	3050
16710	2076	3655
16710	2076	5340
16710	2076	3237
16710	2076	533
195	2077	8723
195	2077	8056
195	2077	2984
195	2077	3569
195	2077	4984
195	2077	5430
195	2077	4866
14335	2078	1478
14335	2078	9303
14335	2078	1745
4556	2079	2375
2196	2080	6391
2196	2080	3232
2196	2080	9349
2196	2080	5264
2196	2080	3044
2196	2080	8618
1340	2081	6377
1340	2081	5591
1340	2081	8494
1340	2081	400
1340	2081	6180
1340	2081	7424
1340	2081	3872
1340	2081	1330
9122	2082	2776
9122	2082	2697
9122	2082	5614
9122	2082	9142
9122	2082	1984
9122	2082	1683
9122	2082	1748
9122	2082	6483
13763	2083	9655
13763	2083	3270
13763	2083	1781
13763	2083	3789
13763	2083	9161
13763	2083	8271
13763	2083	9495
13763	2083	7754
13790	2084	2688
13790	2084	2626
13790	2084	6974
13790	2084	4677
5055	2085	7803
5055	2085	9170
5055	2085	5749
5055	2085	9935
5055	2085	6969
5055	2085	6844
9195	2086	1493
9195	2086	5718
16686	2087	7451
16686	2087	5600
16686	2087	5819
16686	2087	9083
16686	2087	4629
16686	2087	3205
6277	2088	1343
6277	2088	4643
6277	2088	6726
6277	2088	1968
6277	2088	5803
6277	2088	2398
6277	2088	6029
6277	2088	1355
13910	2089	434
10124	2090	5439
10124	2090	86
10124	2090	3641
10124	2090	2851
10124	2090	1943
10124	2090	4497
10124	2090	7793
380	2091	1202
380	2091	1102
380	2091	3700
380	2091	5627
380	2091	4018
380	2091	9196
380	2091	6318
12806	2092	7832
12806	2092	5656
12806	2092	7782
12806	2092	3684
12806	2092	451
12806	2092	5765
12806	2092	2903
8007	2093	2022
8007	2093	420
8007	2093	7469
8007	2093	4310
8007	2093	4249
8007	2093	188
16039	2094	7793
2954	2095	6756
2954	2095	7512
196	2096	6385
196	2096	4469
196	2096	1723
196	2096	6420
196	2096	5722
196	2096	4073
18971	2097	554
18971	2097	3678
18971	2097	3199
18971	2097	3443
18971	2097	1778
18971	2097	9612
18971	2097	1052
18971	2097	2047
13031	2098	8452
8347	2099	84
8024	2100	5734
17864	2101	8886
17864	2101	6992
17864	2101	5663
17864	2101	1771
17864	2101	5480
17864	2101	4225
5353	2102	6850
5353	2102	8902
5353	2102	3309
5353	2102	945
5353	2102	9992
5353	2102	6358
5353	2102	5610
5353	2102	8624
11232	2103	3660
18278	2104	8859
18278	2104	4826
3352	2105	8609
3352	2105	3087
3352	2105	7246
3352	2105	6231
3682	2106	6337
3682	2106	9905
3682	2106	2937
3682	2106	4095
19171	2107	6484
19171	2107	798
3484	2108	5994
3484	2108	7674
3484	2108	1580
3484	2108	6843
3484	2108	5746
3484	2108	1533
3484	2108	7733
3484	2108	1412
11012	2109	5092
11012	2109	9263
11012	2109	2379
11012	2109	3073
11012	2109	1802
11012	2109	12
11012	2109	6990
17139	2110	5814
17139	2110	2890
17139	2110	9417
17139	2110	8784
17139	2110	1292
17139	2110	6335
17139	2110	1486
17139	2110	7365
19486	2111	1634
19486	2111	4561
19486	2111	405
19486	2111	9330
19486	2111	120
19486	2111	9318
4414	2112	2830
4414	2112	8500
4414	2112	5847
4414	2112	6944
4414	2112	6260
4414	2112	8081
4414	2112	4051
11368	2113	7329
11368	2113	1444
11368	2113	3342
11368	2113	7578
11368	2113	7496
11368	2113	4866
11368	2113	3504
11368	2113	2839
11368	2113	1816
17519	2114	3068
17519	2114	2355
17519	2114	2987
8968	2115	6386
19454	2116	2386
19454	2116	199
19454	2116	8858
19454	2116	4946
13522	2117	5521
13522	2117	5637
13522	2117	496
6964	2118	7966
6964	2118	8637
6964	2118	2283
6964	2118	4078
6964	2118	9792
6964	2118	951
6964	2118	3715
6964	2118	3693
18794	2119	1938
18794	2119	8282
17555	2120	2260
17555	2120	3739
17555	2120	4501
17555	2120	4576
17555	2120	7800
15183	2121	7582
2548	2122	671
2548	2122	3798
4158	2123	856
4158	2123	8611
4158	2123	6987
4158	2123	3340
15831	2124	6569
15831	2124	114
15831	2124	8526
17872	2125	850
17872	2125	917
17872	2125	2246
17872	2125	6726
17872	2125	8146
17872	2125	8172
17872	2125	697
17872	2125	9105
7656	2126	6350
7656	2126	2840
7656	2126	205
7656	2126	4158
7656	2126	301
2299	2127	5797
2299	2127	4412
2299	2127	7438
2299	2127	104
2299	2127	9314
2299	2127	767
2299	2127	4837
2299	2127	2246
2299	2127	2330
10337	2128	6533
10337	2128	6233
10337	2128	2343
10337	2128	7983
10337	2128	4604
18030	2129	1572
18030	2129	3165
18030	2129	7204
18030	2129	9303
18030	2129	1345
18030	2129	8828
18030	2129	143
10402	2130	4418
10402	2130	2208
10402	2130	840
10402	2130	1868
10402	2130	3968
537	2131	6673
537	2131	6914
537	2131	6640
537	2131	5917
537	2131	7764
537	2131	1657
997	2132	5873
997	2132	4406
997	2132	4284
997	2132	8269
997	2132	688
997	2132	8138
997	2132	2506
997	2132	1174
16175	2133	4304
16175	2133	5011
16175	2133	3715
16175	2133	9972
16175	2133	7166
16175	2133	1121
16175	2133	603
9772	2134	1037
9772	2134	1623
9772	2134	6604
9772	2134	6855
9772	2134	3306
9772	2134	5865
9772	2134	4269
9772	2134	5331
9772	2134	2235
4413	2135	5285
4413	2135	6149
4413	2135	8285
18112	2136	515
18112	2136	984
15677	2137	5080
15677	2137	2069
15677	2137	928
15677	2137	8628
15677	2137	6444
15677	2137	5369
1306	2138	6540
1306	2138	1098
1306	2138	8183
1306	2138	9123
213	2139	7945
213	2139	4135
213	2139	1469
213	2139	2373
213	2139	3603
213	2139	5559
213	2139	5574
213	2139	8129
17942	2140	8098
17942	2140	5432
17942	2140	5938
17942	2140	4977
17942	2140	4661
17942	2140	388
17942	2140	1499
17942	2140	5629
16003	2141	9002
16003	2141	4374
16003	2141	1850
16003	2141	7833
9845	2142	3111
9845	2142	5851
9845	2142	1535
9845	2142	1010
9845	2142	1617
9845	2142	8799
9845	2142	5920
9845	2142	6083
9845	2142	2429
2859	2143	6004
2859	2143	7850
2859	2143	7649
2859	2143	8759
2859	2143	8894
9488	2144	5570
9488	2144	3906
9488	2144	3323
9488	2144	302
9488	2144	7132
9488	2144	5888
9488	2144	7832
403	2145	4422
403	2145	829
403	2145	9381
403	2145	1268
403	2145	1456
403	2145	3018
403	2145	5156
18123	2146	1766
18123	2146	6863
18123	2146	2460
18123	2146	8457
18123	2146	9611
18123	2146	492
18123	2146	6438
14532	2147	6853
14532	2147	9532
5100	2148	1138
13823	2149	2987
13823	2149	575
18061	2150	8476
18061	2150	3642
11036	2151	6776
11036	2151	6375
11036	2151	7340
11036	2151	8858
11036	2151	2919
11036	2151	2998
11036	2151	6907
11036	2151	4508
10163	2152	4112
10163	2152	9093
10163	2152	7303
10163	2152	7500
10163	2152	8252
10163	2152	6567
10163	2152	8710
12098	2153	4069
14132	2154	2663
14132	2154	6986
14132	2154	347
14132	2154	4992
14132	2154	3398
14132	2154	7046
14132	2154	6818
10138	2155	97
10138	2155	8651
10138	2155	8982
10138	2155	1623
10138	2155	1589
10138	2155	116
5557	2156	500
5557	2156	8210
5557	2156	2418
5557	2156	9575
5557	2156	2308
5557	2156	4008
16463	2157	1165
16463	2157	2988
9221	2158	6419
10641	2159	1207
18833	2160	1024
18833	2160	855
9724	2161	3094
9724	2161	1066
9724	2161	7749
9724	2161	4404
9724	2161	8664
9724	2161	8276
9724	2161	911
9724	2161	403
9724	2161	2695
3338	2162	3060
3338	2162	7327
3338	2162	5379
3338	2162	8776
3338	2162	4882
3338	2162	2099
19696	2163	7066
10682	2164	7020
10682	2164	6043
10682	2164	5756
10682	2164	1383
10682	2164	5304
10682	2164	8828
10682	2164	8357
10682	2164	8003
10682	2164	4366
12929	2165	6312
12929	2165	5660
12929	2165	7493
12929	2165	8719
12929	2165	2832
17748	2166	8507
17748	2166	7920
13495	2167	954
13495	2167	6766
13495	2167	7326
13495	2167	1785
13495	2167	896
13495	2167	4986
13495	2167	1474
13495	2167	346
13495	2167	3717
18202	2168	241
18202	2168	8216
18985	2169	9126
11782	2170	1658
11782	2170	8728
11782	2170	1061
5068	2171	2726
5068	2171	2633
5068	2171	9009
5068	2171	37
5068	2171	5241
5068	2171	7409
5068	2171	7745
5068	2171	413
5068	2171	8176
18712	2172	2320
18712	2172	6973
18712	2172	674
18712	2172	5914
17279	2173	7295
17279	2173	2853
17279	2173	5031
17279	2173	5584
17279	2173	7701
17279	2173	4754
17279	2173	198
17279	2173	3774
4011	2174	8966
4011	2174	7985
4011	2174	431
4011	2174	6504
4011	2174	2538
19664	2175	7164
19664	2175	5084
19664	2175	6528
19664	2175	6075
19664	2175	898
19664	2175	4210
19664	2175	9231
13216	2176	957
13216	2176	5280
13216	2176	2981
13216	2176	7355
13216	2176	5061
13216	2176	5351
5027	2177	5261
5027	2177	6349
5027	2177	6016
5027	2177	7608
13678	2178	3447
13678	2178	4235
13678	2178	6902
13678	2178	5791
13678	2178	1298
13678	2178	5401
13678	2178	4638
13678	2178	477
17369	2179	3419
17369	2179	9860
17369	2179	278
17369	2179	9661
17369	2179	4306
17369	2179	788
17369	2179	4199
17369	2179	2156
15892	2180	1092
15892	2180	2191
15892	2180	7133
15892	2180	8848
15892	2180	1351
15892	2180	8922
17561	2181	6248
17561	2181	1035
17561	2181	245
17561	2181	8306
17561	2181	6844
17561	2181	5543
17561	2181	8407
17561	2181	7211
18803	2182	2068
6837	2183	8189
6837	2183	8138
6837	2183	7008
6837	2183	6257
6837	2183	4939
6837	2183	9865
6837	2183	944
6837	2183	3705
6837	2183	8087
10594	2184	4698
10594	2184	5957
10594	2184	910
10594	2184	185
10594	2184	5750
10594	2184	8682
11378	2185	3732
11378	2185	3523
11378	2185	6454
11378	2185	305
11378	2185	953
11378	2185	2269
11378	2185	3688
16771	2186	5151
16771	2186	2230
16771	2186	2136
16771	2186	3708
16771	2186	1866
16771	2186	6506
475	2187	3834
475	2187	9482
475	2187	9957
475	2187	2529
475	2187	4397
8555	2188	114
8555	2188	8437
8555	2188	5087
8555	2188	322
8555	2188	1390
8555	2188	3265
8555	2188	2324
11340	2189	5470
11340	2189	6104
17264	2190	4848
17264	2190	8361
17264	2190	569
17264	2190	9200
8571	2191	3079
8571	2191	3325
11296	2192	1318
11296	2192	8960
11296	2192	127
11296	2192	2213
11296	2192	3696
11296	2192	3898
11296	2192	3618
8372	2193	3192
8372	2193	1475
8372	2193	2688
8372	2193	3735
8372	2193	897
8372	2193	1661
8372	2193	9590
17099	2194	3613
17099	2194	2812
17099	2194	1841
10916	2195	9644
10916	2195	1030
10916	2195	1249
10916	2195	5604
18676	2196	1934
18676	2196	9952
18676	2196	4587
18676	2196	73
18676	2196	5822
18676	2196	6327
18676	2196	994
18676	2196	5342
8618	2197	4008
8618	2197	6104
8618	2197	4217
2548	2198	9228
2548	2198	751
2548	2198	4502
2548	2198	2003
2548	2198	9687
2548	2198	8259
2548	2198	6456
2548	2198	4180
2548	2198	6096
13558	2199	8492
5416	2200	3982
5416	2200	3706
5416	2200	2905
5416	2200	2389
5416	2200	9792
18956	2201	5491
19340	2202	7474
19340	2202	2364
19340	2202	6688
19340	2202	5722
19340	2202	3563
19340	2202	6622
654	2203	4782
654	2203	4840
654	2203	7531
654	2203	4051
654	2203	7057
654	2203	8415
654	2203	9211
13369	2204	5231
13369	2204	5348
13369	2204	4200
13369	2204	5557
13369	2204	6454
14412	2205	347
14412	2205	503
14412	2205	9180
14412	2205	7622
14412	2205	4095
14412	2205	2781
9821	2206	9404
9501	2207	3661
9501	2207	7536
9501	2207	1817
9501	2207	7320
9501	2207	4614
9501	2207	1699
9501	2207	5544
6331	2208	9202
6331	2208	7071
6331	2208	4805
6331	2208	4492
14012	2209	3721
14012	2209	183
14012	2209	2732
14012	2209	9940
14012	2209	1338
14012	2209	7717
14012	2209	9670
14012	2209	3915
2055	2210	922
2055	2210	9745
2055	2210	7234
2055	2210	9933
2055	2210	1242
2055	2210	7968
16301	2211	150
16301	2211	4291
16301	2211	711
16301	2211	4524
16877	2212	9466
16877	2212	7317
14122	2213	1297
5076	2214	7500
5076	2214	5863
5076	2214	685
5076	2214	9875
5076	2214	7500
5076	2214	6983
5076	2214	965
1368	2215	3507
1368	2215	314
1368	2215	8316
1368	2215	6734
1368	2215	2471
1368	2215	2151
1368	2215	4191
1368	2215	3851
1368	2215	3368
6485	2216	3828
6485	2216	5589
6485	2216	8742
6485	2216	5477
17966	2217	5486
17966	2217	2718
17966	2217	1864
17966	2217	8699
17966	2217	2594
17966	2217	3664
14062	2218	273
14062	2218	2573
14062	2218	6984
14062	2218	8893
14062	2218	4212
14062	2218	8406
14062	2218	3351
14062	2218	6481
14062	2218	4593
12912	2219	470
12912	2219	2645
12912	2219	3423
12912	2219	1164
12912	2219	4593
12912	2219	4894
12912	2219	5536
12912	2219	5326
12912	2219	7602
12014	2220	8348
12014	2220	984
4081	2221	1796
4081	2221	6767
4081	2221	3998
4081	2221	26
4081	2221	4593
4081	2221	6597
4081	2221	1784
4081	2221	1363
4081	2221	6561
10714	2222	7504
10714	2222	2578
10714	2222	6258
10714	2222	528
10714	2222	7769
10714	2222	5518
19031	2223	4676
19031	2223	1407
19031	2223	8804
19031	2223	3405
19031	2223	299
19031	2223	9129
19031	2223	5323
5652	2224	1314
5652	2224	3875
5652	2224	9328
5652	2224	4164
5652	2224	6180
5652	2224	4361
18072	2225	309
18072	2225	2311
18072	2225	9191
18072	2225	3679
18072	2225	9555
18072	2225	2419
18072	2225	1828
18072	2225	8765
18072	2225	3510
5675	2226	7683
5675	2226	72
5675	2226	1367
5675	2226	1079
5675	2226	6908
5675	2226	614
5675	2226	5101
5675	2226	1829
5675	2226	8124
1084	2227	378
1084	2227	2748
1084	2227	5658
1084	2227	6725
1084	2227	6875
1084	2227	402
1084	2227	6451
1084	2227	4734
1084	2227	3356
7940	2228	3774
7940	2228	2796
7940	2228	4071
7940	2228	2440
5633	2229	6704
5633	2229	661
5633	2229	6940
14683	2230	9109
14683	2230	1815
14683	2230	857
14683	2230	6435
417	2231	2106
417	2231	8119
417	2231	6800
417	2231	7361
417	2231	1234
417	2231	5142
417	2231	7493
10655	2232	9613
10655	2232	3128
10655	2232	997
10655	2232	2157
13807	2233	4446
5128	2234	866
5128	2234	3519
5128	2234	5714
5128	2234	3994
5128	2234	742
327	2235	8695
327	2235	9573
327	2235	4449
327	2235	7121
327	2235	8633
327	2235	252
327	2235	4504
327	2235	5642
13015	2236	8607
13015	2236	6387
13015	2236	9361
13015	2236	6024
13015	2236	7292
13015	2236	6040
13015	2236	3825
16545	2237	8421
16545	2237	7556
16545	2237	9052
9387	2238	1201
9387	2238	9438
11648	2239	2952
11648	2239	4702
11648	2239	1791
11648	2239	6229
11648	2239	6354
11648	2239	3888
11648	2239	4701
4514	2240	4317
4514	2240	3414
4514	2240	194
4514	2240	6460
4514	2240	4421
4514	2240	5455
4514	2240	714
4514	2240	5259
14099	2241	2665
14099	2241	6782
14099	2241	6207
14099	2241	8860
14099	2241	3739
16110	2242	3222
16110	2242	2623
16110	2242	8146
16110	2242	3588
16110	2242	3871
16110	2242	2006
16110	2242	9717
16110	2242	6178
17684	2243	5394
17684	2243	3795
17684	2243	466
10123	2244	3071
10123	2244	931
10123	2244	8492
4159	2245	6381
4159	2245	5737
4159	2245	5336
4159	2245	1972
4159	2245	757
4159	2245	3181
13951	2246	4509
13951	2246	476
13951	2246	6910
13951	2246	8908
13951	2246	9239
3952	2247	8584
3952	2247	4273
3952	2247	1958
3952	2247	6234
3952	2247	476
3952	2247	4286
3952	2247	3140
3952	2247	631
3952	2247	4648
10245	2248	8668
10245	2248	2786
10245	2248	1545
10245	2248	9883
10245	2248	9292
7129	2249	3173
7129	2249	2770
7129	2249	6009
7129	2249	7304
7129	2249	6289
7129	2249	2690
7129	2249	3075
7129	2249	6058
9451	2250	2632
9451	2250	8157
9451	2250	5024
9451	2250	980
9451	2250	1013
9451	2250	747
9451	2250	2784
9451	2250	7833
10272	2251	3071
10272	2251	7795
10272	2251	1355
10272	2251	4456
10272	2251	8578
10272	2251	5483
10272	2251	913
11873	2252	7843
11873	2252	8468
11873	2252	6286
11873	2252	2106
11873	2252	44
15967	2253	8613
15967	2253	8468
15967	2253	1184
19521	2254	970
19521	2254	6116
19521	2254	6684
9052	2255	3116
9052	2255	9114
9052	2255	9708
9052	2255	7899
9052	2255	7141
9052	2255	1285
9052	2255	4767
9052	2255	5721
5428	2256	5191
5428	2256	3258
5428	2256	1372
1533	2257	8630
1533	2257	3404
1533	2257	2805
1533	2257	6901
1533	2257	2072
1533	2257	8139
1533	2257	9794
1533	2257	3109
11570	2258	8296
11570	2258	1243
11570	2258	4723
11570	2258	1495
11570	2258	3381
4019	2259	9753
4019	2259	7561
4019	2259	7052
4019	2259	694
4019	2259	2988
12194	2260	1882
12194	2260	1512
12194	2260	7645
12194	2260	1731
12194	2260	5368
12194	2260	5600
12194	2260	9186
5460	2261	9078
12259	2262	1319
12259	2262	8343
12259	2262	7373
12259	2262	6361
12259	2262	8571
12259	2262	9431
12259	2262	625
12259	2262	8582
8364	2263	828
8364	2263	6301
8364	2263	6006
8364	2263	580
17736	2264	144
17736	2264	2240
17736	2264	3709
4558	2265	8494
4558	2265	7362
4558	2265	3089
4558	2265	1257
4558	2265	5318
4558	2265	3324
18658	2266	2497
18658	2266	3455
18658	2266	1332
18658	2266	2886
18658	2266	1115
15769	2267	4085
15769	2267	5739
15769	2267	4441
15769	2267	3193
15769	2267	6655
15769	2267	7781
15769	2267	129
15769	2267	9307
3605	2268	5322
3605	2268	3429
3605	2268	534
3605	2268	4801
3605	2268	2427
3605	2268	1347
3605	2268	1040
3605	2268	7958
3605	2268	5912
5133	2269	2544
5133	2269	746
5133	2269	6914
5133	2269	3652
5133	2269	6952
5133	2269	9507
5133	2269	7180
5133	2269	4923
5133	2269	2745
8183	2270	1177
8183	2270	2173
8183	2270	2968
8183	2270	9655
8183	2270	2307
8183	2270	2415
8183	2270	4048
15399	2271	6673
15399	2271	7505
15399	2271	1418
15399	2271	5833
15399	2271	9778
15399	2271	8253
15399	2271	8180
704	2272	3701
704	2272	1049
704	2272	8371
704	2272	9060
704	2272	2791
704	2272	117
704	2272	6358
704	2272	6040
14914	2273	1619
14914	2273	7961
14914	2273	9706
14914	2273	9302
14914	2273	6492
14914	2273	3584
9265	2274	8095
1771	2275	5548
1771	2275	9686
1771	2275	4712
2005	2276	7070
13550	2277	1936
13550	2277	5654
13550	2277	7584
13550	2277	151
13550	2277	8007
13550	2277	9041
13550	2277	9132
13550	2277	3682
13550	2277	4380
18184	2278	94
18184	2278	5971
18184	2278	5256
18184	2278	3939
18184	2278	6340
3986	2279	9638
3986	2279	4916
7912	2280	7488
7912	2280	3599
7912	2280	5478
7912	2280	959
7912	2280	5172
7912	2280	9666
7912	2280	8216
7912	2280	7646
7912	2280	1078
9254	2281	5760
9254	2281	965
9254	2281	3260
9254	2281	4631
9254	2281	9674
9254	2281	3801
9254	2281	3985
9254	2281	3136
9254	2281	8449
16229	2282	3036
16229	2282	6366
16229	2282	1079
16229	2282	8740
8999	2283	5174
8999	2283	5532
8999	2283	7622
8999	2283	1922
8999	2283	8478
3227	2284	9920
3227	2284	7263
3227	2284	1056
3227	2284	6462
3227	2284	4411
3227	2284	1815
3227	2284	4597
3227	2284	7650
3227	2284	406
11875	2285	1143
19241	2286	1234
19241	2286	2090
19241	2286	8149
18409	2287	6626
18409	2287	4523
18409	2287	7212
18409	2287	4068
18409	2287	6387
18409	2287	7685
18409	2287	411
3107	2288	1174
3107	2288	5591
3107	2288	6621
9538	2289	3974
9538	2289	1063
9538	2289	744
9538	2289	9039
6212	2290	7580
15980	2291	9543
1433	2292	3123
1433	2292	7003
1433	2292	2379
1433	2292	762
1433	2292	719
1433	2292	6951
1433	2292	7409
1433	2292	9418
1433	2292	9095
13348	2293	4664
13348	2293	4962
13348	2293	9221
13348	2293	4923
16090	2294	4726
16090	2294	9054
16090	2294	6550
16090	2294	7311
16090	2294	1235
1305	2295	2887
1305	2295	5257
1305	2295	3912
1305	2295	9170
1305	2295	4126
1305	2295	7567
1305	2295	8600
1305	2295	7093
3638	2296	7306
3638	2296	9427
3638	2296	6666
3638	2296	9335
3638	2296	1314
3638	2296	4737
3638	2296	6198
3638	2296	9823
3638	2296	9913
8077	2297	3087
8077	2297	2130
8077	2297	2401
8077	2297	1998
8077	2297	2386
8077	2297	2183
17697	2298	5003
17697	2298	9420
17697	2298	7989
15621	2299	6802
15621	2299	3683
15621	2299	1255
15621	2299	164
15621	2299	6948
15621	2299	6116
15621	2299	1581
15621	2299	8249
15621	2299	313
5573	2300	6574
5573	2300	7353
5573	2300	460
5573	2300	2373
5573	2300	6729
5573	2300	894
5573	2300	3356
7039	2301	6083
7039	2301	3073
7039	2301	149
7039	2301	1426
8074	2302	1651
8074	2302	3756
8074	2302	4383
8074	2302	6088
8074	2302	401
8074	2302	5928
8074	2302	3226
8074	2302	3442
8074	2302	2804
17771	2303	6548
17771	2303	8925
17771	2303	1231
17771	2303	2011
17771	2303	1327
17771	2303	4298
17771	2303	2664
17503	2304	1567
17503	2304	991
17503	2304	646
17503	2304	5197
17503	2304	3408
17503	2304	2335
17503	2304	7331
17503	2304	4800
17503	2304	6856
17732	2305	2527
17732	2305	5077
17732	2305	3486
17732	2305	3942
17732	2305	4071
17732	2305	281
17732	2305	300
17732	2305	9494
17732	2305	4376
13419	2306	5592
13419	2306	8810
13419	2306	7761
16537	2307	3074
16537	2307	9030
16537	2307	6925
16537	2307	5478
11517	2308	6685
11517	2308	4275
11517	2308	8449
11517	2308	7770
11517	2308	2053
11517	2308	7109
11517	2308	5807
11517	2308	8342
11632	2309	8368
11632	2309	2770
11632	2309	2958
11632	2309	6287
11632	2309	4006
11632	2309	214
8976	2310	3986
8976	2310	1718
8976	2310	2880
8976	2310	6901
8976	2310	3696
8976	2310	5806
13528	2311	6751
13528	2311	4716
13528	2311	4060
13528	2311	1144
13528	2311	3344
13528	2311	8756
13528	2311	5845
13528	2311	7573
13528	2311	26
5811	2312	1593
5811	2312	8010
5811	2312	8645
3375	2313	7500
3119	2314	9625
3119	2314	3121
17932	2315	8797
17932	2315	5650
17932	2315	1818
17932	2315	7433
17932	2315	5579
17932	2315	808
9940	2316	5882
9940	2316	6208
9940	2316	4969
9188	2317	2975
9188	2317	351
18294	2318	3812
18294	2318	2527
18294	2318	6000
18294	2318	6688
18294	2318	2329
18294	2318	1778
18294	2318	4198
18294	2318	1648
13234	2319	1211
13234	2319	3811
13234	2319	5541
17303	2320	7412
17303	2320	9408
17303	2320	8365
17303	2320	8045
17303	2320	2216
17303	2320	6248
17303	2320	8611
518	2321	6876
518	2321	8237
518	2321	457
518	2321	2271
518	2321	6209
518	2321	4649
4120	2322	1999
4120	2322	9950
4120	2322	53
4120	2322	416
4120	2322	6158
15619	2323	3622
15619	2323	9265
15619	2323	4248
15619	2323	3906
15619	2323	5718
15619	2323	4835
15619	2323	9632
12538	2324	1271
12538	2324	4467
12538	2324	6626
12538	2324	7624
8737	2325	1964
8737	2325	9355
8737	2325	6073
19956	2326	92
19956	2326	7031
19956	2326	4923
19956	2326	5993
19956	2326	3880
19956	2326	3893
1038	2327	3303
1038	2327	577
1038	2327	332
1038	2327	8110
1038	2327	3768
1038	2327	3288
6816	2328	8362
6816	2328	3975
6816	2328	7867
6816	2328	2717
13220	2329	7129
13220	2329	2023
13220	2329	460
13220	2329	4326
13220	2329	5139
13220	2329	477
7530	2330	7173
11068	2331	8818
11068	2331	8966
11068	2331	3026
11068	2331	8144
11068	2331	2009
11068	2331	6439
11068	2331	5702
11068	2331	6629
11068	2331	7689
16331	2332	1930
16331	2332	9851
16331	2332	9297
16331	2332	4636
16331	2332	3875
16331	2332	3989
16331	2332	4987
16331	2332	9034
16331	2332	132
13140	2333	3468
13140	2333	4132
13140	2333	3468
13140	2333	9322
2502	2334	353
2502	2334	396
2502	2334	443
2502	2334	8441
2502	2334	7109
12285	2335	7184
12285	2335	8147
3229	2336	2771
3229	2336	9788
3229	2336	1565
3	2337	7735
3	2337	8682
3	2337	5642
3	2337	2610
8110	2338	5632
8110	2338	2065
8110	2338	8331
8110	2338	5393
8110	2338	4323
8110	2338	9710
8110	2338	254
7191	2339	7290
11943	2340	3093
11943	2340	306
11943	2340	3851
11943	2340	747
11943	2340	5275
11943	2340	3260
11943	2340	3940
16525	2341	2372
16525	2341	6876
16525	2341	664
16525	2341	2480
16525	2341	7161
16525	2341	3925
14035	2342	659
14035	2342	1454
14035	2342	7477
1474	2343	9389
1474	2343	6420
1474	2343	1828
1474	2343	3271
1474	2343	728
1474	2343	6854
1474	2343	1887
1474	2343	7601
19101	2344	1806
19101	2344	502
19101	2344	4893
18220	2345	7267
7372	2346	2477
7372	2346	7078
7372	2346	1512
7372	2346	6412
7372	2346	7946
7372	2346	9210
7372	2346	3563
7372	2346	8816
18635	2347	7296
12023	2348	4116
12023	2348	480
12023	2348	3857
12023	2348	6000
12023	2348	6160
12023	2348	4865
12023	2348	909
237	2349	2156
15360	2350	8097
15360	2350	2757
15360	2350	559
15360	2350	4417
9791	2351	7851
8022	2352	6583
8022	2352	9640
8022	2352	7633
8022	2352	3315
8022	2352	6693
8022	2352	7468
8022	2352	2972
11456	2353	7420
11456	2353	3723
11456	2353	2499
11456	2353	5624
11456	2353	5913
11456	2353	4361
11456	2353	4417
11456	2353	33
11456	2353	4110
14848	2354	6253
14848	2354	3451
14848	2354	485
14848	2354	4953
14848	2354	991
14848	2354	1275
14848	2354	6966
14848	2354	1532
14848	2354	4122
16965	2355	9425
16965	2355	8648
16965	2355	7659
16965	2355	958
16965	2355	968
8837	2356	6360
14702	2357	2065
14702	2357	9234
14702	2357	3313
14702	2357	1040
14702	2357	1838
2525	2358	4797
2525	2358	8191
2525	2358	3767
2525	2358	2965
2525	2358	3577
2525	2358	4314
2525	2358	787
9091	2359	5270
9091	2359	2947
9091	2359	6550
9091	2359	2071
9091	2359	4989
9091	2359	9650
9091	2359	6882
9091	2359	4639
9091	2359	200
6329	2360	2564
6329	2360	7745
6329	2360	5016
6329	2360	7895
6329	2360	4383
6329	2360	2172
6329	2360	1746
6329	2360	1317
12609	2361	2289
12609	2361	1204
12609	2361	5924
12609	2361	5333
12609	2361	4568
12609	2361	7963
12609	2361	4052
18135	2362	8044
18135	2362	1539
18135	2362	2451
18135	2362	8936
18135	2362	7101
18135	2362	72
18135	2362	2802
18135	2362	1920
15687	2363	7998
15687	2363	2155
15687	2363	7107
15687	2363	1667
15687	2363	5274
6635	2364	3533
6635	2364	783
6635	2364	3744
6635	2364	8513
6635	2364	8953
6635	2364	6175
6635	2364	5319
1456	2365	704
1456	2365	2673
1456	2365	8443
1456	2365	5397
1456	2365	6744
1456	2365	7034
1456	2365	8857
19279	2366	7523
19279	2366	1805
19279	2366	2860
19279	2366	7349
19279	2366	3441
19279	2366	8906
19279	2366	2778
19279	2366	5759
8403	2367	7917
8403	2367	4173
8403	2367	801
10092	2368	3036
10092	2368	94
10092	2368	6667
10092	2368	2819
10092	2368	1132
10092	2368	79
10092	2368	9782
10092	2368	9647
14131	2369	9882
14131	2369	4627
14131	2369	2608
14131	2369	7083
14131	2369	473
14131	2369	6672
14131	2369	9942
14131	2369	8347
2331	2370	7425
14412	2371	2746
4974	2372	145
4974	2372	1533
4974	2372	12
4974	2372	876
4974	2372	8367
4974	2372	3992
4974	2372	4313
8062	2373	4880
8062	2373	6241
8062	2373	8133
8062	2373	6299
8062	2373	1664
3246	2374	6208
3246	2374	6263
3246	2374	1522
3246	2374	6703
1389	2375	3033
1389	2375	3028
1389	2375	8652
1389	2375	7463
1389	2375	3674
1389	2375	4692
1389	2375	6474
1389	2375	3868
1389	2375	7978
8372	2376	405
8372	2376	6749
8372	2376	9558
8372	2376	7802
8372	2376	432
8372	2376	867
8372	2376	7370
8372	2376	1367
8372	2376	4411
18206	2377	5459
18206	2377	6739
18206	2377	4122
18206	2377	7622
18206	2377	9698
18206	2377	1940
18206	2377	5135
5873	2378	3771
5873	2378	1771
5873	2378	9636
5873	2378	5972
5873	2378	8178
5873	2378	3149
5873	2378	3299
5873	2378	2071
12384	2379	8462
12384	2379	7692
12384	2379	6268
12384	2379	1898
12384	2379	5762
12384	2379	2460
12384	2379	1265
12384	2379	672
12384	2379	7367
11088	2380	8734
11088	2380	6702
11088	2380	6377
11088	2380	6996
11088	2380	8410
11088	2380	6322
11088	2380	5858
11088	2380	8927
9375	2381	4220
9375	2381	3427
9375	2381	1069
9375	2381	1534
9375	2381	6337
9375	2381	4110
9375	2381	915
9375	2381	5875
9375	2381	9556
15932	2382	4067
5985	2383	7680
5985	2383	8635
5985	2383	1013
5985	2383	6790
5985	2383	2853
5985	2383	8096
5985	2383	2899
5985	2383	4260
5985	2383	3016
5144	2384	538
5144	2384	5006
5144	2384	5515
5144	2384	7596
5144	2384	7144
11556	2385	7838
11556	2385	1392
11556	2385	2288
11556	2385	9880
11556	2385	1692
11556	2385	8999
11556	2385	4272
11556	2385	7280
11556	2385	4995
20000	2386	7706
20000	2386	1575
20000	2386	5293
20000	2386	627
16929	2387	9155
18069	2388	3174
18069	2388	6463
7485	2389	1560
7485	2389	7999
7485	2389	7443
7485	2389	3997
7485	2389	553
7485	2389	8891
7485	2389	1755
7485	2389	9644
17597	2390	7833
17597	2390	469
17597	2390	3711
17597	2390	8451
17597	2390	675
17597	2390	4713
17597	2390	6494
17597	2390	6214
419	2391	9498
419	2391	146
419	2391	9919
419	2391	9439
419	2391	8587
419	2391	7283
419	2391	7151
419	2391	7425
419	2391	4683
10714	2392	7591
10714	2392	5000
10714	2392	9475
4856	2393	4272
4856	2393	4764
4856	2393	2314
4856	2393	2759
81	2394	7791
81	2394	8557
81	2394	619
81	2394	7831
81	2394	8421
81	2394	5202
81	2394	9224
6473	2395	6747
6473	2395	1739
6473	2395	5565
6473	2395	5712
6473	2395	4954
6473	2395	8364
6473	2395	3951
6473	2395	7017
6473	2395	8628
12916	2396	1879
12916	2396	480
12916	2396	7176
12916	2396	4339
12916	2396	6527
12916	2396	5655
12916	2396	2595
16613	2397	4562
16613	2397	9544
16613	2397	4060
16613	2397	1019
16613	2397	4196
16613	2397	9146
16613	2397	6717
14393	2398	4510
14393	2398	5451
2211	2399	2325
3735	2400	9774
3735	2400	1523
3735	2400	4991
18374	2401	682
18374	2401	6689
18374	2401	6111
18374	2401	5848
18374	2401	5277
18374	2401	1656
1911	2402	2573
1911	2402	6596
1911	2402	4426
1911	2402	9891
1911	2402	202
13445	2403	2388
18153	2404	7890
18153	2404	6333
18153	2404	6573
18153	2404	5991
18153	2404	8943
18153	2404	3705
600	2405	6669
600	2405	746
600	2405	7748
600	2405	3593
600	2405	9920
19043	2406	5234
19043	2406	1269
19043	2406	6114
19043	2406	9553
19043	2406	6818
19043	2406	1060
2863	2407	6229
2863	2407	5851
2863	2407	4362
15908	2408	3935
15908	2408	5649
15908	2408	7976
15908	2408	1939
15908	2408	2447
15908	2408	7086
7806	2409	4425
7806	2409	2646
17749	2410	5849
17749	2410	2940
17749	2410	5053
17749	2410	8183
17749	2410	337
17749	2410	7979
17749	2410	4713
17749	2410	7555
17749	2410	7969
16246	2411	9338
16246	2411	160
16246	2411	8215
16246	2411	858
16246	2411	2991
16246	2411	8051
16246	2411	8761
16246	2411	4286
16246	2411	2090
137	2412	9985
137	2412	2647
137	2412	5128
137	2412	6077
137	2412	1460
3238	2413	5269
3238	2413	5804
3238	2413	4960
3238	2413	4190
3238	2413	6956
18091	2414	9114
18091	2414	6925
19143	2415	1377
19143	2415	5315
3904	2416	6804
3904	2416	4192
3904	2416	7982
3904	2416	6461
3904	2416	2871
3904	2416	647
7486	2417	9772
7486	2417	674
15450	2418	853
15450	2418	5681
15450	2418	5200
4006	2419	4610
4006	2419	8674
4006	2419	10
4006	2419	4486
4006	2419	5078
4006	2419	4398
4006	2419	8522
4006	2419	1947
4006	2419	459
16783	2420	1639
16783	2420	7167
16783	2420	2074
16783	2420	8841
16783	2420	2021
16783	2420	9769
16783	2420	4521
18012	2421	5953
18012	2421	7366
18012	2421	9000
18012	2421	3671
18012	2421	2727
18012	2421	7850
18012	2421	8363
11058	2422	8027
11058	2422	4928
11058	2422	8616
6272	2423	2142
6272	2423	293
6272	2423	9736
17471	2424	8194
17471	2424	6830
17471	2424	8682
17471	2424	5531
17471	2424	722
17471	2424	2603
15062	2425	2227
15062	2425	8773
15062	2425	2513
15062	2425	1605
15062	2425	9010
15062	2425	463
14865	2426	7129
14865	2426	4312
14865	2426	9841
14865	2426	5415
14865	2426	1698
14865	2426	9310
14865	2426	5549
14865	2426	4356
6258	2427	4044
6105	2428	4631
6105	2428	851
6105	2428	5760
6105	2428	7097
13874	2429	7499
13874	2429	7222
13874	2429	329
13874	2429	4912
13874	2429	544
13874	2429	7813
13874	2429	2701
13874	2429	1095
13874	2429	4909
19079	2430	1989
19079	2430	7905
19079	2430	1834
19079	2430	6022
19079	2430	897
19079	2430	3357
19079	2430	328
19079	2430	887
19079	2430	8369
12363	2431	8038
5891	2432	2485
5891	2432	5147
5891	2432	3819
5891	2432	3558
5891	2432	4744
11280	2433	3758
9288	2434	6074
9288	2434	8989
9288	2434	6944
6180	2435	8311
6180	2435	8171
6180	2435	6929
6180	2435	6509
6180	2435	7641
6180	2435	66
6331	2436	6592
10515	2437	1712
10515	2437	3888
7900	2438	66
7900	2438	1482
7900	2438	3514
7900	2438	225
7900	2438	8898
7900	2438	1274
7900	2438	2905
7900	2438	2129
7900	2438	8815
8215	2439	5474
8215	2439	4000
6109	2440	2081
6109	2440	6144
6109	2440	1613
6109	2440	1973
6109	2440	9679
6109	2440	9702
5213	2441	1304
5213	2441	681
9315	2442	346
9315	2442	6875
9315	2442	9258
9315	2442	777
9315	2442	3562
9315	2442	4900
9315	2442	6578
12511	2443	7207
12511	2443	9319
12511	2443	9535
12511	2443	4256
12511	2443	857
12511	2443	4873
12511	2443	3808
1364	2444	868
1364	2444	9861
1364	2444	7603
1364	2444	9603
1364	2444	1633
1364	2444	435
1364	2444	3326
1364	2444	6949
12967	2445	6699
12967	2445	4516
12967	2445	7185
12967	2445	6789
12967	2445	9006
12967	2445	4972
12967	2445	7377
12967	2445	4302
7808	2446	517
7808	2446	599
15094	2447	4031
15094	2447	9423
7877	2448	2262
2535	2449	1140
2535	2449	7313
2535	2449	8136
14588	2450	6888
14588	2450	3703
14588	2450	6274
14588	2450	5323
14588	2450	9942
14588	2450	1033
14588	2450	8684
14588	2450	4877
14588	2450	2420
16401	2451	1358
16401	2451	8793
16401	2451	9085
16401	2451	6788
7350	2452	7797
7350	2452	1889
3660	2453	5647
3660	2453	6881
3660	2453	7494
3660	2453	2910
15554	2454	9957
15554	2454	8352
15554	2454	9987
15554	2454	6254
15554	2454	8814
15554	2454	9685
15554	2454	4407
15554	2454	9730
15189	2455	4143
15189	2455	9573
15189	2455	6652
15189	2455	1343
15189	2455	260
15189	2455	3010
15189	2455	6251
15189	2455	9258
15189	2455	6500
10625	2456	1922
10625	2456	5479
10625	2456	9033
10625	2456	9246
6776	2457	5025
6776	2457	9986
6776	2457	7660
6776	2457	768
6776	2457	461
6776	2457	2029
6776	2457	3256
14955	2458	1384
14955	2458	5043
14955	2458	7413
13317	2459	47
13317	2459	1178
13317	2459	3944
13317	2459	1438
4411	2460	9224
4411	2460	1587
13630	2461	9748
13630	2461	2428
13630	2461	8202
13630	2461	8866
13630	2461	6500
13630	2461	7620
17596	2462	9961
17596	2462	8427
17596	2462	5259
17596	2462	3238
17596	2462	4996
17596	2462	6961
17596	2462	1639
2772	2463	6176
2772	2463	6758
2772	2463	404
2772	2463	7486
2772	2463	9803
2772	2463	6821
2772	2463	7191
11234	2464	6314
11234	2464	4214
11234	2464	6212
11234	2464	9132
11234	2464	8092
11234	2464	9237
11234	2464	538
11234	2464	2807
11234	2464	454
15879	2465	8306
10992	2466	1113
10992	2466	5978
10992	2466	4375
10992	2466	8736
10992	2466	1366
10992	2466	8438
15347	2467	3086
15347	2467	9321
19747	2468	229
19747	2468	1109
19747	2468	5280
12784	2469	3818
12784	2469	4418
12784	2469	3893
12784	2469	421
3817	2470	3934
6509	2471	3128
6509	2471	4533
11283	2472	1586
11283	2472	9560
11283	2472	7832
4497	2473	8031
4497	2473	45
4497	2473	8259
4497	2473	4317
4497	2473	3137
4497	2473	5447
4497	2473	5451
19967	2474	5625
19967	2474	8925
19967	2474	893
19967	2474	7728
19967	2474	1861
19967	2474	972
18005	2475	2274
18005	2475	9358
18005	2475	4590
18005	2475	563
18005	2475	2259
18005	2475	8610
18005	2475	5997
18005	2475	5885
18005	2475	7827
17438	2476	7443
17438	2476	8109
17438	2476	2943
17438	2476	7417
17438	2476	6684
17438	2476	9482
8143	2477	4108
8143	2477	2854
8143	2477	922
8143	2477	3257
8143	2477	471
8143	2477	1615
8143	2477	9803
14490	2478	5659
14490	2478	1343
14490	2478	86
14490	2478	2764
18084	2479	5883
18084	2479	3400
18084	2479	463
7440	2480	4804
7440	2480	7359
7440	2480	7648
7440	2480	1851
7440	2480	7188
7440	2480	710
7440	2480	584
7440	2480	6558
1252	2481	3231
1252	2481	1746
1252	2481	7007
1252	2481	950
4153	2482	4817
4929	2483	172
4929	2483	4696
4929	2483	8943
4929	2483	1676
4929	2483	8625
4929	2483	6126
4929	2483	6037
15564	2484	9990
15564	2484	884
15564	2484	9012
15564	2484	6648
15564	2484	3538
15564	2484	6293
12928	2485	7345
12928	2485	9143
12928	2485	1618
12928	2485	1057
14187	2486	4875
14187	2486	4358
14187	2486	21
14187	2486	782
14187	2486	8773
14187	2486	2861
14187	2486	9412
14187	2486	9073
12494	2487	2365
12494	2487	1982
12494	2487	9358
16278	2488	6205
16278	2488	1912
16278	2488	9871
16278	2488	5803
16278	2488	964
16278	2488	8081
16278	2488	6885
16278	2488	2979
17191	2489	1558
17191	2489	110
17191	2489	8551
17191	2489	6578
17191	2489	7606
17191	2489	9103
17191	2489	1716
17191	2489	4372
348	2490	4749
348	2490	7735
348	2490	7812
348	2490	7589
19584	2491	4360
5821	2492	3187
4580	2493	3304
4580	2493	993
4580	2493	7944
4580	2493	160
4580	2493	3550
4580	2493	4325
4580	2493	8607
4580	2493	5248
4580	2493	1705
12129	2494	8975
12129	2494	4167
12129	2494	1742
10280	2495	2910
10280	2495	4005
10280	2495	5486
10280	2495	3546
10280	2495	2059
10280	2495	397
10280	2495	9784
2976	2496	7552
2976	2496	546
2976	2496	5622
2976	2496	8687
2976	2496	6570
2976	2496	2503
2976	2496	893
9794	2497	9062
9794	2497	4607
9794	2497	7682
9794	2497	1786
9794	2497	648
9794	2497	8953
13009	2498	3031
13009	2498	2986
13009	2498	398
13009	2498	4855
13009	2498	7387
13009	2498	8312
13009	2498	644
13009	2498	3044
15301	2499	2654
15301	2499	9535
16974	2500	4992
16044	2501	9739
16044	2501	1518
17809	2502	6377
17809	2502	3880
17809	2502	690
17809	2502	7072
17809	2502	338
17809	2502	4126
17809	2502	3026
17809	2502	8359
17809	2502	7807
13568	2503	8747
13568	2503	719
13568	2503	5704
12090	2504	7030
12090	2504	4967
12090	2504	3161
12090	2504	9234
12090	2504	1763
9577	2505	5061
9577	2505	5078
12897	2506	7559
12897	2506	4063
12897	2506	5050
12897	2506	9307
12673	2507	4056
12673	2507	5782
12673	2507	7614
12673	2507	6649
14219	2508	5377
14219	2508	7385
14219	2508	4236
14219	2508	4225
14219	2508	3344
14219	2508	5057
14219	2508	1518
590	2509	4039
590	2509	9526
590	2509	8045
590	2509	7363
590	2509	8123
1667	2510	8621
1667	2510	7605
1667	2510	4476
1667	2510	4651
1667	2510	116
1667	2510	6212
1667	2510	4070
9538	2511	9524
9538	2511	5786
9538	2511	2742
9538	2511	2260
9538	2511	2843
9538	2511	1698
637	2512	3175
637	2512	673
637	2512	6696
637	2512	7531
637	2512	2422
637	2512	3574
637	2512	6369
637	2512	317
12205	2513	9252
12205	2513	8859
12205	2513	9782
12205	2513	2024
12205	2513	875
12205	2513	9864
12205	2513	5301
12205	2513	1873
18808	2514	1004
18808	2514	8097
18808	2514	8127
18808	2514	3266
13452	2515	2446
13452	2515	5861
13452	2515	788
13452	2515	3248
6222	2516	3648
6222	2516	1606
6222	2516	6987
6222	2516	8719
6222	2516	4987
6222	2516	5364
6222	2516	5229
6222	2516	6492
6222	2516	5355
15602	2517	28
15602	2517	7257
15602	2517	545
15602	2517	6386
15602	2517	1174
15602	2517	3838
15602	2517	5005
15602	2517	9289
15602	2517	8816
8360	2518	2809
8360	2518	5512
8360	2518	1743
8360	2518	5965
8360	2518	8396
8360	2518	8721
18531	2519	5520
18531	2519	5685
18531	2519	1170
18531	2519	183
18531	2519	4414
18531	2519	4734
4241	2520	6000
4241	2520	4151
4241	2520	5254
4241	2520	7581
4241	2520	6106
4241	2520	9301
13034	2521	4908
12154	2522	6536
2537	2523	3389
2537	2523	8788
2537	2523	3713
17933	2524	2616
17933	2524	1011
17933	2524	4530
17933	2524	8433
17933	2524	7663
16211	2525	8731
16211	2525	1471
16211	2525	7220
16211	2525	1156
16211	2525	5717
16211	2525	9997
16211	2525	2881
16211	2525	8396
16211	2525	1838
5697	2526	9425
5697	2526	5173
5697	2526	4698
5697	2526	5192
5697	2526	7095
5697	2526	65
5697	2526	2277
5697	2526	6800
5697	2526	7894
15780	2527	5017
15780	2527	2188
15780	2527	1351
15780	2527	9702
15780	2527	6899
15780	2527	5635
664	2528	4446
664	2528	5328
15207	2529	1035
15207	2529	4481
12850	2530	6765
12850	2530	9449
12850	2530	131
14058	2531	9100
14058	2531	8357
14058	2531	5896
14058	2531	5206
14058	2531	7313
14058	2531	8826
14058	2531	2336
14058	2531	8796
12747	2532	8969
12747	2532	7787
12747	2532	8119
12747	2532	7568
12747	2532	4946
8092	2533	2651
8092	2533	9693
8092	2533	7452
8092	2533	8227
8092	2533	6112
8092	2533	6139
8092	2533	7377
1234	2534	621
17479	2535	9249
17479	2535	2077
17479	2535	39
17479	2535	4673
17479	2535	8640
17479	2535	546
17545	2536	9335
17545	2536	2389
17545	2536	8916
17545	2536	7328
17545	2536	3918
17545	2536	7389
17545	2536	6688
11872	2537	3718
16782	2538	2756
16782	2538	8032
800	2539	8907
800	2539	2520
800	2539	7665
800	2539	2081
800	2539	7797
800	2539	4166
5962	2540	3873
5962	2540	6800
5962	2540	2529
10568	2541	9409
10568	2541	7547
10568	2541	3942
10568	2541	5012
10568	2541	4275
10568	2541	6310
10568	2541	4259
16847	2542	1405
16847	2542	6060
16847	2542	3147
16847	2542	2451
3131	2543	8712
3131	2543	6606
3131	2543	1383
3131	2543	2711
3131	2543	7009
3131	2543	9070
3131	2543	3340
3131	2543	7424
12026	2544	5022
12026	2544	8432
12026	2544	1808
17244	2545	7095
17244	2545	5169
17244	2545	7417
17244	2545	4247
17244	2545	2946
4031	2546	5344
14189	2547	250
14189	2547	1453
14189	2547	1201
10087	2548	9845
10087	2548	3169
1170	2549	712
1170	2549	8178
1170	2549	6525
1170	2549	8274
1170	2549	4749
1170	2549	8963
1170	2549	392
3690	2550	5105
3690	2550	2035
3690	2550	9467
3690	2550	5963
3690	2550	6892
3690	2550	3221
3690	2550	5560
7474	2551	6488
7474	2551	1358
7474	2551	7916
7474	2551	3996
7474	2551	9532
7474	2551	152
7474	2551	6778
7474	2551	4881
7474	2551	2244
16411	2552	6843
16411	2552	6039
16411	2552	4134
16411	2552	6139
16411	2552	8493
16411	2552	5916
16411	2552	3864
15718	2553	7646
15718	2553	7125
15718	2553	7548
15718	2553	3236
15718	2553	6352
15718	2553	7996
15718	2553	1510
15718	2553	3535
15718	2553	7241
6759	2554	6006
6759	2554	4893
6759	2554	3304
6759	2554	7729
6759	2554	4763
3775	2555	3893
3775	2555	5071
3775	2555	6960
3775	2555	3577
3775	2555	7906
10292	2556	8526
10292	2556	7610
10292	2556	7808
2222	2557	6554
2222	2557	7503
14599	2558	332
14599	2558	8350
14599	2558	7704
14599	2558	5761
14599	2558	9037
14599	2558	755
14599	2558	4344
14599	2558	2152
19919	2559	1071
19919	2559	340
19919	2559	4347
19919	2559	1910
19919	2559	5142
19919	2559	6668
19919	2559	6112
19919	2559	2765
17050	2560	302
17050	2560	9796
17050	2560	9458
17050	2560	6598
17050	2560	1907
17050	2560	1481
3640	2561	9662
3640	2561	5979
3640	2561	3985
3640	2561	277
3640	2561	7663
3640	2561	3911
3640	2561	1566
3735	2562	6512
6219	2563	4162
6219	2563	7211
6219	2563	9539
6219	2563	4651
1259	2564	3275
1259	2564	4400
1259	2564	7321
1259	2564	5544
12257	2565	6509
12257	2565	8126
12257	2565	374
12257	2565	3069
12257	2565	2083
3242	2566	822
3242	2566	7049
3242	2566	2713
3242	2566	9105
3242	2566	1261
3242	2566	5422
14130	2567	2221
14130	2567	3328
14130	2567	8277
14130	2567	4709
14130	2567	8237
14130	2567	1625
19428	2568	8123
19428	2568	4058
19428	2568	3795
19428	2568	7947
19428	2568	9586
19428	2568	1860
19428	2568	433
19428	2568	958
19428	2568	4233
5018	2569	3855
5018	2569	4499
5018	2569	6228
5018	2569	5193
5018	2569	2143
5018	2569	6123
5018	2569	4150
4193	2570	5465
4193	2570	3842
4193	2570	1624
4193	2570	8550
4193	2570	9085
4193	2570	8366
4193	2570	9256
4193	2570	3293
4193	2570	7699
5781	2571	6206
5781	2571	5005
5781	2571	8210
5781	2571	2452
5781	2571	3312
5781	2571	14
5781	2571	3813
5781	2571	1953
2074	2572	8108
2074	2572	8078
2074	2572	6919
2074	2572	921
2074	2572	8667
2074	2572	2388
14785	2573	1758
14785	2573	2776
14785	2573	5594
14785	2573	2223
14785	2573	4427
14785	2573	1768
14785	2573	5212
14785	2573	7778
14785	2573	8843
11522	2574	9343
11522	2574	8731
11522	2574	5169
11522	2574	9123
11522	2574	9709
11522	2574	8074
7334	2575	3072
7334	2575	2347
7334	2575	1620
7334	2575	517
7334	2575	878
7334	2575	5254
7334	2575	5120
7334	2575	1236
19933	2576	82
19933	2576	2747
19933	2576	6196
4291	2577	318
4291	2577	7249
4291	2577	2398
4291	2577	224
4291	2577	8267
4291	2577	2272
4291	2577	6697
15865	2578	7899
15865	2578	9937
15865	2578	3361
15865	2578	7770
15865	2578	3504
15865	2578	1702
15865	2578	7594
9685	2579	3711
9685	2579	859
9685	2579	6008
9685	2579	5497
9685	2579	522
9685	2579	636
9685	2579	3487
9685	2579	420
7561	2580	3337
7561	2580	4329
7561	2580	7600
7561	2580	7057
3482	2581	6648
5311	2582	5359
5311	2582	3849
5311	2582	7977
5311	2582	4530
5311	2582	759
5311	2582	2177
5311	2582	5328
5311	2582	6475
8148	2583	7221
8148	2583	9349
8148	2583	8816
8148	2583	263
8148	2583	8652
8148	2583	9216
8148	2583	945
17842	2584	7317
17842	2584	5579
17842	2584	8024
17842	2584	5007
17842	2584	563
4281	2585	482
4281	2585	4106
4281	2585	8511
4281	2585	566
4281	2585	9711
4281	2585	1173
2355	2586	5712
2355	2586	4405
2355	2586	6386
2784	2587	6950
2784	2587	4900
2784	2587	1294
10799	2588	9767
10799	2588	8301
18947	2589	651
18947	2589	1119
18947	2589	6600
18947	2589	7653
18947	2589	7953
18947	2589	4377
18947	2589	2608
18947	2589	381
3349	2590	7074
3349	2590	5208
3349	2590	2812
3349	2590	6318
12899	2591	6157
12899	2591	9995
12899	2591	2351
12899	2591	5741
235	2592	1444
5768	2593	6953
4320	2594	5669
17300	2595	2282
17300	2595	1248
17300	2595	2830
17300	2595	9923
14835	2596	7520
14835	2596	4649
14835	2596	3016
14835	2596	5625
14835	2596	6198
14835	2596	2128
14835	2596	4562
14835	2596	4817
14835	2596	6445
17453	2597	1002
17453	2597	2539
17453	2597	209
17453	2597	8342
17453	2597	5524
17453	2597	9029
17453	2597	990
17453	2597	2059
17453	2597	2011
8276	2598	1934
8276	2598	8136
8276	2598	9155
8276	2598	7104
8276	2598	4768
14611	2599	3745
14611	2599	8707
14611	2599	3232
14611	2599	9441
14611	2599	9779
14611	2599	837
14611	2599	9755
14611	2599	5928
14611	2599	6002
8275	2600	9965
8275	2600	2896
8275	2600	1448
8275	2600	2038
8275	2600	2307
2027	2601	8749
17055	2602	317
17055	2602	7276
17055	2602	1104
17055	2602	4104
17055	2602	7414
17055	2602	1815
9421	2603	7208
9421	2603	5609
9421	2603	9932
9421	2603	528
9421	2603	4536
19674	2604	5974
19674	2604	1211
19674	2604	4363
19674	2604	6526
19674	2604	9196
2021	2605	5721
2021	2605	7624
2021	2605	7577
15016	2606	2491
15016	2606	2245
15016	2606	1060
14067	2607	283
14067	2607	956
14067	2607	996
14067	2607	747
14067	2607	1162
14067	2607	2296
14067	2607	5494
14067	2607	9810
4503	2608	5220
4503	2608	1061
4503	2608	5034
4503	2608	7512
4503	2608	9154
4503	2608	1105
4503	2608	8208
4503	2608	6243
4503	2608	2211
6745	2609	255
6745	2609	1223
8747	2610	4211
8747	2610	1264
8747	2610	5000
8747	2610	7392
8747	2610	8761
8747	2610	8190
8747	2610	5981
8747	2610	1925
8272	2611	7508
8272	2611	5913
8272	2611	2815
8272	2611	7826
8272	2611	1509
11439	2612	991
11439	2612	6188
11439	2612	5187
11439	2612	4928
11439	2612	4813
11439	2612	9773
11439	2612	3132
11439	2612	873
11439	2612	9984
11792	2613	3032
11792	2613	3859
11792	2613	4110
11792	2613	259
2500	2614	9633
2500	2614	3513
2500	2614	3022
2500	2614	5468
2500	2614	5063
2500	2614	8169
2500	2614	943
2500	2614	4316
917	2615	4427
917	2615	1619
917	2615	1327
917	2615	321
917	2615	3127
917	2615	2268
917	2615	4427
14897	2616	243
14897	2616	1385
14897	2616	5103
18838	2617	9877
8607	2618	2840
8607	2618	1185
8607	2618	2732
8607	2618	7941
8607	2618	7070
8607	2618	781
8607	2618	9815
8607	2618	7174
8607	2618	4054
18312	2619	8575
18312	2619	5643
18312	2619	3629
18312	2619	2755
18312	2619	2640
7648	2620	8135
7648	2620	8093
7648	2620	9061
17751	2621	8933
17751	2621	5323
17751	2621	6967
17751	2621	2435
17751	2621	973
17751	2621	3993
17751	2621	1410
8098	2622	7873
8098	2622	9386
8098	2622	7789
8098	2622	1211
8098	2622	6350
8098	2622	5725
9315	2623	2060
9315	2623	9097
9315	2623	426
8835	2624	1164
8835	2624	8029
8835	2624	6898
8835	2624	4599
4774	2625	9236
4774	2625	3922
4774	2625	218
16272	2626	3021
16272	2626	6170
17481	2627	2721
17481	2627	8821
17481	2627	2531
17481	2627	6651
17481	2627	2001
17481	2627	9517
17481	2627	1678
17481	2627	5872
12179	2628	4225
12179	2628	5005
12179	2628	4945
16982	2629	6708
16982	2629	7580
16982	2629	3385
16982	2629	1246
16982	2629	7241
16982	2629	8593
16982	2629	9007
16982	2629	5509
18440	2630	2549
18440	2630	4426
18440	2630	2438
6257	2631	1682
6257	2631	1277
6257	2631	97
6257	2631	9372
6257	2631	4695
6257	2631	4589
6257	2631	3369
6257	2631	3558
18852	2632	2384
18852	2632	4634
18852	2632	8197
18852	2632	6179
18852	2632	200
18852	2632	5565
18852	2632	8608
18852	2632	1142
18852	2632	1502
12392	2633	9483
12392	2633	8231
12392	2633	9370
12392	2633	2466
12392	2633	6145
1557	2634	7850
1557	2634	3230
1557	2634	1876
1557	2634	9930
1557	2634	5635
1557	2634	9188
18468	2635	3869
18468	2635	9203
18468	2635	5855
18468	2635	8803
18468	2635	6037
18468	2635	3170
18468	2635	5725
18468	2635	452
7361	2636	2475
7361	2636	5021
7361	2636	2623
7361	2636	5246
7361	2636	3442
14621	2637	9410
14621	2637	690
13452	2638	871
13452	2638	3565
13452	2638	2458
13452	2638	5003
13452	2638	766
13452	2638	5632
13452	2638	5586
13452	2638	9995
6873	2639	747
6873	2639	7497
6873	2639	8048
6873	2639	8367
6873	2639	4912
11564	2640	7104
11564	2640	2145
11564	2640	6945
11564	2640	9583
11564	2640	8696
11564	2640	832
6587	2641	8672
6587	2641	6208
6587	2641	3029
6587	2641	4353
6587	2641	7871
448	2642	6141
448	2642	6193
448	2642	4256
7677	2643	9006
7677	2643	8580
7677	2643	9839
7677	2643	412
7677	2643	3579
7677	2643	4677
7677	2643	875
7677	2643	8002
7677	2643	8294
6680	2644	5490
6680	2644	3395
6680	2644	3580
6680	2644	3584
6680	2644	4480
6120	2645	3766
6120	2645	4186
6120	2645	4625
6120	2645	3951
6120	2645	7893
6120	2645	4245
6427	2646	8323
6427	2646	7565
6427	2646	4762
6427	2646	6307
6427	2646	437
6427	2646	935
6427	2646	3847
15224	2647	4956
15224	2647	4999
15224	2647	6659
15224	2647	858
15224	2647	9078
15224	2647	4117
4878	2648	4157
4878	2648	9563
4878	2648	6725
4878	2648	1250
4878	2648	6274
4878	2648	6188
4878	2648	2708
4878	2648	4361
18719	2649	2251
2655	2650	9931
2655	2650	7998
2655	2650	432
2655	2650	1930
2655	2650	2618
2655	2650	9992
12530	2651	4489
12530	2651	5224
12530	2651	9335
11809	2652	3332
8982	2653	6504
8982	2653	5265
14388	2654	5849
14388	2654	3282
14388	2654	3185
14388	2654	4663
14388	2654	3916
14388	2654	6522
14388	2654	8991
14388	2654	9155
14388	2654	5189
13947	2655	8689
13947	2655	1009
13947	2655	415
13947	2655	1148
13947	2655	7220
13947	2655	4262
14893	2656	5119
14893	2656	3707
14893	2656	9911
14893	2656	6371
3118	2657	8533
14443	2658	1175
14443	2658	6230
14443	2658	9767
14443	2658	9319
14443	2658	3950
14443	2658	1475
14443	2658	2296
14443	2658	3355
6531	2659	2331
6531	2659	6165
6531	2659	1080
6531	2659	2411
6531	2659	1918
6185	2660	5415
6185	2660	6600
6185	2660	641
4231	2661	8709
4231	2661	1506
4231	2661	3864
4231	2661	1549
4231	2661	234
2627	2662	9810
2627	2662	6907
2627	2662	7419
5666	2663	7566
5666	2663	7029
5666	2663	3118
5666	2663	6277
5666	2663	4871
5666	2663	8770
637	2664	8032
637	2664	9534
637	2664	7489
637	2664	4767
637	2664	6073
637	2664	8146
637	2664	5018
637	2664	2432
18922	2665	3733
18922	2665	4454
18922	2665	7416
10806	2666	3623
10806	2666	7265
10806	2666	2012
13557	2667	8964
13557	2667	4524
13557	2667	5801
13557	2667	6565
13557	2667	6416
13557	2667	7938
13557	2667	9555
13557	2667	8751
12174	2668	8350
12174	2668	726
12174	2668	9153
12174	2668	368
12174	2668	9517
12174	2668	223
12174	2668	6809
12174	2668	2461
12174	2668	1701
16234	2669	8266
16234	2669	8249
16234	2669	5473
16234	2669	3103
16234	2669	3016
16234	2669	3843
5990	2670	4647
5990	2670	6950
5990	2670	4475
5990	2670	9614
5990	2670	6368
5990	2670	5961
5990	2670	9432
15393	2671	4713
15393	2671	2257
15393	2671	6728
15393	2671	9268
15393	2671	9014
15393	2671	3565
15393	2671	3768
15393	2671	1487
11923	2672	2897
11923	2672	4008
11923	2672	5132
10555	2673	3673
10555	2673	6055
10555	2673	3663
10555	2673	1201
10555	2673	3353
10555	2673	9265
10555	2673	5706
14385	2674	3154
14385	2674	899
14385	2674	9068
14385	2674	4907
14385	2674	8345
14385	2674	9477
14385	2674	5844
14385	2674	5328
17980	2675	1921
2370	2676	4217
2370	2676	3389
2370	2676	8284
2370	2676	6191
2370	2676	2592
2370	2676	4089
4867	2677	1913
4867	2677	2082
4867	2677	3912
4867	2677	6230
4867	2677	1436
4867	2677	6626
4867	2677	9335
4867	2677	8124
4867	2677	1653
19873	2678	9119
19873	2678	2966
19873	2678	8145
19873	2678	5640
19873	2678	1357
19873	2678	6326
19873	2678	4793
2045	2679	9172
2045	2679	7960
2045	2679	7029
2045	2679	2058
2045	2679	7595
2045	2679	8618
15472	2680	943
15472	2680	6671
15472	2680	8753
15472	2680	4136
17856	2681	9950
17856	2681	2094
17856	2681	9596
17856	2681	7629
17856	2681	6136
17856	2681	5307
7847	2682	1660
7847	2682	8790
7847	2682	114
7847	2682	9185
7847	2682	3487
9902	2683	1012
9902	2683	3399
9902	2683	1320
9902	2683	3158
9902	2683	9620
9902	2683	8634
9902	2683	3023
9902	2683	8849
9902	2683	6436
10452	2684	687
10452	2684	7053
10452	2684	5616
10452	2684	9124
10452	2684	252
10452	2684	61
10452	2684	3241
10452	2684	6646
12530	2685	1191
12530	2685	855
12530	2685	1114
12530	2685	548
12530	2685	2517
12530	2685	7376
12530	2685	5953
12530	2685	7376
12530	2685	5424
11352	2686	9327
11352	2686	872
11352	2686	6274
11352	2686	2237
11352	2686	161
11352	2686	676
11352	2686	3466
11352	2686	8306
11352	2686	977
16705	2687	2781
16705	2687	5190
16705	2687	7900
16705	2687	3880
6413	2688	9178
6413	2688	6182
6413	2688	2647
6413	2688	4840
6413	2688	7357
11325	2689	6485
11325	2689	4442
11325	2689	3610
11325	2689	1910
11325	2689	5426
11325	2689	3420
15061	2690	2513
15061	2690	9438
15061	2690	3103
15061	2690	5037
15061	2690	5408
15061	2690	6249
15061	2690	8055
15061	2690	6609
2099	2691	8272
2099	2691	963
8765	2692	1913
8765	2692	9867
18610	2693	1390
13595	2694	7317
13595	2694	3064
13595	2694	3144
13595	2694	4975
13595	2694	3781
9488	2695	9126
9488	2695	3030
5794	2696	2202
5794	2696	2971
5794	2696	6740
14578	2697	5893
14578	2697	1630
14578	2697	399
14578	2697	7227
14578	2697	9850
14578	2697	8923
14578	2697	4295
14650	2698	222
14650	2698	4862
15663	2699	9051
15663	2699	7164
15663	2699	4105
15663	2699	3550
15663	2699	2091
15663	2699	2338
15663	2699	8127
15663	2699	1695
15663	2699	8980
11435	2700	7915
11435	2700	8737
11435	2700	5959
11435	2700	608
19317	2701	4427
19317	2701	1966
19317	2701	8210
19317	2701	1923
19317	2701	3374
19317	2701	2734
19317	2701	7099
19317	2701	1059
19317	2701	7431
10691	2702	8122
10691	2702	6991
10691	2702	5838
10691	2702	8387
10691	2702	7647
19224	2703	3669
19224	2703	5440
19224	2703	2761
19224	2703	2111
19224	2703	9886
14633	2704	2662
14633	2704	3559
14633	2704	9317
14633	2704	9511
14633	2704	9286
14633	2704	9362
14633	2704	711
14633	2704	6545
425	2705	7255
425	2705	4550
425	2705	6830
425	2705	2535
425	2705	1753
425	2705	7325
1767	2706	1432
1767	2706	9997
1767	2706	2605
1767	2706	7650
1767	2706	5404
12684	2707	2719
12684	2707	5993
12684	2707	1027
12684	2707	1705
12684	2707	1708
12684	2707	3637
12684	2707	7871
12684	2707	9915
12684	2707	4005
8002	2708	3360
17527	2709	5105
17527	2709	7528
17527	2709	9977
17527	2709	5093
17527	2709	6342
17527	2709	4564
17527	2709	255
17527	2709	7081
13991	2710	8343
13991	2710	5368
17454	2711	7490
17454	2711	1540
17454	2711	2345
4643	2712	3325
4643	2712	2310
4643	2712	6978
4643	2712	6087
4643	2712	689
3760	2713	845
3760	2713	9803
3760	2713	8909
3760	2713	3221
3760	2713	3953
3760	2713	8994
3760	2713	3828
3760	2713	8619
3760	2713	4924
14465	2714	9797
14465	2714	6379
14465	2714	9366
8361	2715	4363
8361	2715	3396
8361	2715	6553
1010	2716	6802
1010	2716	8076
1010	2716	1618
1010	2716	7363
1010	2716	232
1010	2716	9283
1010	2716	3109
1010	2716	513
5754	2717	6086
5754	2717	6550
5754	2717	4288
5754	2717	6097
5754	2717	3608
5754	2717	2622
5754	2717	2677
5754	2717	5830
5754	2717	3697
7856	2718	3956
8936	2719	7345
8936	2719	9212
8936	2719	3636
8936	2719	2911
8936	2719	8864
8936	2719	1882
8936	2719	6481
8936	2719	2881
8936	2719	5202
17795	2720	2826
17795	2720	5244
17795	2720	5779
17795	2720	1249
17795	2720	732
19887	2721	5705
19887	2721	5924
19887	2721	3941
19887	2721	7040
19887	2721	2309
19887	2721	9578
19887	2721	8631
19887	2721	6407
18465	2722	6013
18465	2722	4418
18465	2722	343
9413	2723	2706
9413	2723	2810
9413	2723	5366
9413	2723	6434
9413	2723	7172
9413	2723	2325
9413	2723	6252
9413	2723	9777
15021	2724	488
15021	2724	2907
15021	2724	5165
15021	2724	55
10296	2725	5945
2620	2726	3715
2620	2726	4467
2620	2726	2377
2620	2726	6994
2620	2726	3377
2620	2726	9664
303	2727	5056
303	2727	8947
303	2727	9355
303	2727	259
303	2727	7565
303	2727	9956
16823	2728	4039
16823	2728	7266
8519	2729	2742
8519	2729	6409
19159	2730	7915
19159	2730	8551
19159	2730	7079
19159	2730	5520
10950	2731	3887
10950	2731	3751
10950	2731	1123
17773	2732	28
17773	2732	1142
17773	2732	3549
9556	2733	4954
9556	2733	1199
9556	2733	325
9556	2733	6675
16345	2734	2249
16345	2734	4004
16345	2734	2626
16345	2734	2258
16345	2734	1253
16345	2734	5916
18928	2735	4242
18928	2735	8663
18928	2735	6400
18928	2735	1229
18928	2735	6580
17544	2736	4851
17544	2736	1528
17544	2736	1695
17544	2736	7198
17544	2736	2052
17544	2736	6237
17544	2736	844
17544	2736	7432
17544	2736	9690
16705	2737	8214
16705	2737	769
16705	2737	10000
16705	2737	3565
16831	2738	7270
16831	2738	8425
16831	2738	46
16831	2738	2917
7519	2739	6522
7519	2739	7549
7519	2739	9280
7519	2739	8213
7519	2739	515
7519	2739	2286
11701	2740	4266
11701	2740	8826
11701	2740	7083
11701	2740	6001
11701	2740	7728
12343	2741	2047
12343	2741	5575
12343	2741	3366
12343	2741	8014
12343	2741	2347
9266	2742	484
9266	2742	6922
9266	2742	6621
7406	2743	831
7406	2743	1201
7406	2743	6897
17886	2744	8539
17886	2744	9315
17886	2744	8019
17886	2744	5081
17886	2744	6294
13554	2745	1526
13554	2745	3615
13554	2745	80
13554	2745	92
13554	2745	7337
13554	2745	5150
13554	2745	5170
13554	2745	3176
3429	2746	8267
3429	2746	9473
3429	2746	1283
3429	2746	7471
3429	2746	2544
3429	2746	95
3429	2746	3604
3429	2746	1878
3939	2747	3262
3939	2747	1891
3939	2747	3780
3939	2747	6677
3939	2747	6781
3939	2747	89
3939	2747	4067
10697	2748	7577
10697	2748	3092
10697	2748	1941
10697	2748	1381
10697	2748	378
10697	2748	5788
18098	2749	7481
18098	2749	6315
6189	2750	8142
13072	2751	2401
13072	2751	3619
13072	2751	181
13072	2751	2187
13072	2751	9378
13072	2751	3262
5240	2752	3869
5240	2752	742
5240	2752	5852
2741	2753	956
2741	2753	7955
711	2754	5848
711	2754	7713
14182	2755	2256
14182	2755	6021
14182	2755	382
14182	2755	8165
8032	2756	5386
8032	2756	4768
8032	2756	7790
8032	2756	2230
1254	2757	9206
1254	2757	6959
1254	2757	3280
1254	2757	2746
1254	2757	5691
1254	2757	2006
1254	2757	8655
1254	2757	7196
1254	2757	4186
19143	2758	5912
19143	2758	9565
19143	2758	8944
19143	2758	8768
19143	2758	1566
19143	2758	3610
19143	2758	7319
127	2759	8830
127	2759	7843
10077	2760	4868
10077	2760	8357
10077	2760	5129
10077	2760	2319
10077	2760	2410
10077	2760	7335
10077	2760	8683
10077	2760	9152
12939	2761	6533
12939	2761	5275
12939	2761	6035
12939	2761	2846
18114	2762	7343
18114	2762	2721
18114	2762	2047
8912	2763	5634
8912	2763	3398
8912	2763	7274
8912	2763	1254
8912	2763	4324
19196	2764	2715
19196	2764	4729
19196	2764	5051
19196	2764	3893
13226	2765	1652
13226	2765	8429
13226	2765	6526
13226	2765	2935
418	2766	6663
9444	2767	8816
7089	2768	7694
7089	2768	4475
18677	2769	1367
15785	2770	7816
15785	2770	1502
16329	2771	2886
16329	2771	3957
16329	2771	5672
7844	2772	6065
7844	2772	2561
7844	2772	6881
16494	2773	6139
16494	2773	4877
16494	2773	9193
16494	2773	2514
12280	2774	4432
12280	2774	9130
12280	2774	2090
12280	2774	4025
12280	2774	7315
12280	2774	2700
12280	2774	4909
268	2775	3718
268	2775	8466
268	2775	7920
268	2775	4972
19028	2776	6942
19028	2776	134
19028	2776	1107
19028	2776	446
19028	2776	7381
19028	2776	5220
19028	2776	7636
19028	2776	9660
19028	2776	263
7960	2777	2574
7960	2777	3993
7960	2777	9804
7960	2777	7059
7960	2777	4907
7960	2777	7381
16974	2778	3618
17676	2779	8966
17676	2779	9577
17676	2779	1869
17676	2779	3208
17676	2779	3780
17676	2779	2691
4989	2780	8871
12502	2781	4738
12502	2781	4974
12502	2781	5502
12502	2781	7193
12502	2781	9164
17479	2782	6185
17479	2782	9795
17479	2782	4376
17479	2782	7736
17479	2782	4979
17479	2782	8088
4946	2783	6930
4946	2783	4393
4946	2783	3193
4946	2783	5155
8636	2784	3058
8636	2784	1201
8636	2784	525
8636	2784	9205
8636	2784	3480
16917	2785	2308
4815	2786	7245
874	2787	822
874	2787	1468
874	2787	928
874	2787	9297
874	2787	3767
874	2787	3123
874	2787	4722
14649	2788	8014
14649	2788	6497
14649	2788	9777
14649	2788	1268
14649	2788	4483
14649	2788	7458
14649	2788	414
14649	2788	6769
15391	2789	9824
15391	2789	4764
15391	2789	3144
15391	2789	9549
15391	2789	6810
9646	2790	5999
9646	2790	6080
9646	2790	8775
9646	2790	530
9646	2790	1130
9646	2790	4512
9646	2790	2824
9646	2790	5593
10832	2791	8362
10832	2791	9348
10832	2791	5601
10832	2791	2519
10832	2791	981
10832	2791	4677
10832	2791	6250
10832	2791	4245
10832	2791	1320
4897	2792	346
4897	2792	5924
4897	2792	7771
4897	2792	1354
4897	2792	886
4897	2792	9720
10641	2793	2211
13774	2794	7644
17925	2795	1411
17925	2795	2938
17925	2795	7625
17925	2795	7695
17925	2795	9884
17925	2795	2568
17925	2795	8764
12777	2796	6532
12777	2796	4764
12777	2796	6705
12777	2796	2062
12777	2796	7707
12777	2796	3311
12777	2796	5146
16166	2797	6945
16166	2797	3177
16166	2797	3220
16166	2797	7598
16166	2797	8031
16166	2797	8371
16166	2797	5992
16166	2797	5456
4321	2798	6508
4321	2798	6112
4321	2798	8647
4321	2798	4540
4321	2798	9340
4321	2798	6587
4321	2798	5188
4321	2798	3112
1418	2799	9308
1418	2799	9176
1418	2799	3663
1418	2799	6054
11842	2800	3494
11842	2800	3118
11842	2800	5240
9159	2801	863
9159	2801	7296
9159	2801	2269
9159	2801	4684
9159	2801	6340
9159	2801	1419
9159	2801	9291
10688	2802	1265
10688	2802	237
10688	2802	6675
10688	2802	6900
10688	2802	1010
10688	2802	6494
10688	2802	5377
5344	2803	5474
5344	2803	8470
5344	2803	6
5344	2803	7329
5344	2803	4971
5344	2803	4640
11808	2804	663
11808	2804	8002
11808	2804	1070
11808	2804	5407
11808	2804	8695
4476	2805	8050
4476	2805	2267
4476	2805	742
4476	2805	6409
4476	2805	1567
4476	2805	5546
19915	2806	4606
19915	2806	2806
19915	2806	334
19915	2806	1619
627	2807	2551
627	2807	2612
627	2807	8906
627	2807	7120
627	2807	7149
627	2807	7718
6526	2808	3221
6526	2808	9725
6526	2808	9801
6526	2808	434
6526	2808	6405
6526	2808	5874
4792	2809	2374
4792	2809	5517
4792	2809	1692
4792	2809	927
4792	2809	6163
2139	2810	7145
2139	2810	9505
2139	2810	2953
6773	2811	5439
6773	2811	3648
6773	2811	7709
6773	2811	2720
6773	2811	4666
6773	2811	1361
4574	2812	931
4574	2812	8104
4574	2812	5228
4574	2812	7965
4574	2812	2119
4574	2812	4038
4574	2812	4304
19484	2813	7546
532	2814	8502
532	2814	9842
532	2814	229
532	2814	6408
9024	2815	9761
9024	2815	7751
9024	2815	2879
14365	2816	6925
8941	2817	4736
6476	2818	2611
6476	2818	8871
6476	2818	6465
6476	2818	3530
6580	2819	5168
6580	2819	9221
6580	2819	2484
6580	2819	9280
6580	2819	8541
6580	2819	3879
6580	2819	1471
10921	2820	9292
10921	2820	6611
6151	2821	3537
6151	2821	301
6151	2821	1937
6151	2821	1261
6151	2821	4032
6151	2821	5643
6151	2821	3153
14062	2822	5646
14062	2822	1209
14062	2822	814
14062	2822	1960
14062	2822	8663
14062	2822	501
8073	2823	9996
8073	2823	8221
8073	2823	1085
13455	2824	911
13455	2824	5183
13455	2824	5590
13455	2824	3697
13455	2824	8326
13455	2824	7299
13455	2824	1935
13455	2824	5727
16356	2825	930
16356	2825	7368
16356	2825	7722
16356	2825	1404
16356	2825	5180
16356	2825	874
16356	2825	6811
4800	2826	9198
4800	2826	8485
4800	2826	5495
4800	2826	2457
3809	2827	9344
3809	2827	5792
3809	2827	9479
3809	2827	5164
3809	2827	6235
3809	2827	7851
3809	2827	6432
3809	2827	3164
3809	2827	7061
12517	2828	2755
12517	2828	9587
12517	2828	1972
12517	2828	7115
12517	2828	1766
12517	2828	1698
12517	2828	3169
12517	2828	1071
12517	2828	2060
19820	2829	4571
19820	2829	1816
19820	2829	7624
19820	2829	7890
19820	2829	1668
2509	2830	3695
2509	2830	6973
2509	2830	9427
2509	2830	3019
2509	2830	9847
2509	2830	927
19202	2831	4708
19202	2831	3384
19202	2831	8018
19202	2831	9023
19202	2831	3887
19202	2831	6550
4808	2832	5373
4808	2832	1100
4808	2832	8763
4808	2832	7394
4808	2832	8208
4808	2832	515
4661	2833	8717
4661	2833	9152
4661	2833	9799
7370	2834	1202
7370	2834	1594
7370	2834	6447
7370	2834	4414
7370	2834	1766
7370	2834	1665
7370	2834	1785
7370	2834	7480
7370	2834	9474
9764	2835	3674
9764	2835	81
9764	2835	5356
9764	2835	7157
16717	2836	2680
16717	2836	470
16717	2836	9021
16717	2836	269
4107	2837	4353
4107	2837	4276
4107	2837	4912
4107	2837	2330
4107	2837	9487
4107	2837	2058
4107	2837	5130
4107	2837	9063
8180	2838	5564
9169	2839	5270
9169	2839	9666
9169	2839	3516
9169	2839	5856
9169	2839	3001
9169	2839	97
9169	2839	9352
2818	2840	623
2818	2840	9909
2818	2840	7578
6283	2841	7726
6283	2841	3402
6283	2841	9355
6283	2841	8822
6283	2841	7086
6283	2841	662
1517	2842	342
1517	2842	6205
1517	2842	6026
1517	2842	8256
1517	2842	5022
6934	2843	9257
6934	2843	2562
6934	2843	9697
6934	2843	5726
6934	2843	4787
6934	2843	3194
6934	2843	2898
6934	2843	6207
13097	2844	1317
13097	2844	6464
13097	2844	3430
13097	2844	5406
13097	2844	4952
13097	2844	7664
13097	2844	1082
13097	2844	6866
13097	2844	2142
13856	2845	2377
13856	2845	1126
13856	2845	6613
16168	2846	5580
16168	2846	6019
16168	2846	2144
16168	2846	8824
16168	2846	5806
16168	2846	1302
16334	2847	758
16334	2847	5781
16334	2847	9448
16334	2847	4457
16334	2847	6740
16334	2847	5132
16334	2847	9154
16334	2847	8318
8672	2848	5761
8672	2848	9223
1050	2849	8692
1050	2849	4617
1050	2849	3075
1050	2849	5607
1050	2849	8555
1050	2849	3096
16455	2850	7554
15079	2851	9668
15079	2851	1327
15079	2851	7144
15079	2851	9416
15079	2851	6143
15079	2851	1712
15079	2851	7555
15079	2851	1158
19425	2852	5006
4341	2853	7652
4341	2853	3725
4341	2853	8427
4341	2853	3047
4341	2853	2283
4341	2853	133
12550	2854	7035
12550	2854	2282
12550	2854	521
12550	2854	7905
12550	2854	9995
12550	2854	8105
12550	2854	5081
5464	2855	201
5464	2855	1929
5464	2855	595
5464	2855	3438
5464	2855	5909
5464	2855	7002
5464	2855	6718
5464	2855	3072
7185	2856	7338
10884	2857	8192
10884	2857	855
10884	2857	559
10884	2857	1448
10884	2857	4303
10884	2857	6698
10884	2857	2770
10884	2857	6962
7360	2858	2680
7360	2858	4983
4640	2859	7762
4640	2859	7333
4640	2859	9088
4640	2859	6560
4640	2859	9242
4640	2859	2133
4640	2859	50
4640	2859	1285
4640	2859	1436
19509	2860	1145
19509	2860	2432
19509	2860	5875
19509	2860	8446
19509	2860	7809
19509	2860	2794
3762	2861	1527
3762	2861	6727
3762	2861	6115
3762	2861	2490
3762	2861	9595
3762	2861	5645
3762	2861	3679
3762	2861	8580
2023	2862	9611
2023	2862	3779
2023	2862	5603
2023	2862	2560
2023	2862	8452
2023	2862	6482
2023	2862	8458
2023	2862	3638
12254	2863	52
12254	2863	1763
12254	2863	5187
12254	2863	8554
12254	2863	1354
12254	2863	5412
12254	2863	8898
12254	2863	8382
12254	2863	5762
8426	2864	4192
8426	2864	1953
8426	2864	9859
8426	2864	3957
8426	2864	1516
8426	2864	9446
8426	2864	7739
8426	2864	3620
9946	2865	5936
9946	2865	6595
9946	2865	9191
9946	2865	5260
9946	2865	6569
9946	2865	196
9946	2865	7377
14471	2866	9065
14471	2866	6554
14471	2866	8878
4994	2867	7470
4994	2867	2540
4994	2867	1068
4994	2867	7724
4994	2867	1490
16118	2868	8819
16118	2868	4055
16279	2869	3739
16279	2869	7258
16279	2869	798
16279	2869	5113
16279	2869	5533
16279	2869	7758
16279	2869	5988
16279	2869	7207
17393	2870	6755
11148	2871	2982
11148	2871	4896
11148	2871	2643
11148	2871	9443
11148	2871	1251
11148	2871	299
11148	2871	1621
18756	2872	8203
18756	2872	8644
18756	2872	9806
18756	2872	8081
18756	2872	7102
2628	2873	5210
2628	2873	8052
2628	2873	1068
2628	2873	7753
2628	2873	7734
18708	2874	8732
18708	2874	2560
18708	2874	8895
18708	2874	4221
18708	2874	6540
18708	2874	5260
18708	2874	3083
1241	2875	3054
8243	2876	6440
8243	2876	3819
8243	2876	5141
8243	2876	2748
8243	2876	5486
8243	2876	806
10052	2877	7327
10052	2877	6689
10052	2877	5732
16482	2878	8801
16482	2878	8204
16482	2878	5589
16482	2878	2641
15562	2879	1653
15562	2879	7818
15562	2879	6973
102	2880	8390
102	2880	5219
102	2880	5708
102	2880	2363
102	2880	331
17068	2881	3177
17068	2881	2332
17068	2881	8439
183	2882	2550
183	2882	7596
183	2882	9055
14889	2883	1566
7857	2884	5092
7857	2884	5173
7857	2884	2517
7857	2884	3768
7857	2884	1290
7857	2884	4288
12639	2885	5324
12639	2885	4880
12639	2885	2576
12639	2885	1823
12639	2885	9784
12186	2886	2732
12186	2886	8207
12186	2886	5518
12186	2886	6254
12186	2886	5572
12186	2886	1491
12186	2886	4284
12186	2886	6179
3003	2887	5880
3003	2887	3236
3003	2887	6084
3003	2887	1091
16814	2888	816
16814	2888	9749
12005	2889	3546
12005	2889	5416
12005	2889	895
12005	2889	2122
12005	2889	3095
12005	2889	3042
12554	2890	9296
12554	2890	7013
12554	2890	6173
12554	2890	252
12554	2890	7327
14621	2891	2867
14621	2891	6044
14621	2891	7378
14621	2891	9875
14621	2891	6466
14621	2891	3516
14621	2891	1945
14621	2891	5784
14621	2891	6577
7179	2892	1655
7179	2892	9547
7179	2892	3740
19485	2893	9291
19485	2893	7439
19485	2893	4786
19485	2893	6168
19485	2893	283
19485	2893	759
19485	2893	1688
19485	2893	847
19485	2893	1622
10218	2894	8848
10218	2894	2490
10218	2894	2205
10218	2894	2330
3241	2895	8289
3241	2895	2689
3241	2895	7892
3241	2895	4139
3241	2895	5199
12091	2896	3278
12091	2896	1922
12091	2896	9454
12091	2896	2408
12091	2896	3358
12091	2896	724
12091	2896	8621
953	2897	7118
953	2897	51
953	2897	9696
953	2897	3659
953	2897	17
953	2897	940
8435	2898	7287
8435	2898	8356
8435	2898	1450
8435	2898	4307
8435	2898	7399
8435	2898	834
8435	2898	3404
1042	2899	5530
18377	2900	8039
18377	2900	8666
18377	2900	1341
18377	2900	1288
18377	2900	8225
19350	2901	1848
19350	2901	5556
19350	2901	3461
7523	2902	4114
7523	2902	434
7523	2902	4199
7523	2902	3213
7523	2902	3741
7523	2902	5940
7523	2902	597
7523	2902	3708
7523	2902	6871
16453	2903	6981
883	2904	4203
16631	2905	6971
367	2906	2062
5318	2907	1481
5318	2907	1326
5318	2907	8361
5318	2907	321
5318	2907	6193
5318	2907	5783
5318	2907	3920
5318	2907	4015
5318	2907	8301
10542	2908	5454
15032	2909	175
15032	2909	5955
15032	2909	5064
15032	2909	1631
15032	2909	3261
15032	2909	8766
9096	2910	4533
9096	2910	2854
9096	2910	6508
9096	2910	8104
9096	2910	7202
9096	2910	7673
9096	2910	1073
9096	2910	4928
9096	2910	4268
18662	2911	2755
18662	2911	6484
18662	2911	877
18662	2911	6068
18662	2911	995
7696	2912	491
15384	2913	5962
1779	2914	1772
1779	2914	3686
1779	2914	4845
1779	2914	1356
4463	2915	7926
4463	2915	4627
4463	2915	7950
4463	2915	3487
13127	2916	7313
13127	2916	852
13127	2916	2983
13127	2916	1755
13127	2916	8576
6839	2917	4747
6839	2917	8273
6839	2917	3866
6839	2917	1955
6839	2917	8651
6839	2917	6551
12289	2918	831
12289	2918	6569
12289	2918	3412
12289	2918	9945
12289	2918	4305
17982	2919	5033
17982	2919	2323
17982	2919	4540
12990	2920	6399
12990	2920	291
12990	2920	7375
12990	2920	9218
12990	2920	5002
12990	2920	9888
12990	2920	5337
12990	2920	3579
8366	2921	6668
17980	2922	5178
17980	2922	8013
8823	2923	9154
8823	2923	3906
8823	2923	6669
8823	2923	4157
8823	2923	7320
1796	2924	5081
1796	2924	5035
1796	2924	1430
1796	2924	738
1796	2924	3531
3087	2925	5955
3087	2925	4415
3087	2925	5324
3087	2925	3478
3087	2925	7228
3087	2925	8549
3087	2925	7128
3087	2925	5445
3087	2925	9681
9429	2926	6728
9429	2926	3856
9429	2926	8926
9429	2926	1801
9429	2926	8226
5281	2927	961
5281	2927	8876
5281	2927	3975
5281	2927	2735
5281	2927	2363
5281	2927	7363
5281	2927	8704
1953	2928	3986
1953	2928	3742
1953	2928	9430
1953	2928	7610
18338	2929	6052
18338	2929	2500
18338	2929	9444
18338	2929	2352
18338	2929	7575
18338	2929	356
18119	2930	36
18119	2930	6996
18119	2930	3875
18119	2930	6933
9084	2931	3711
9084	2931	5736
9084	2931	2512
9084	2931	4690
9084	2931	4709
9084	2931	4133
9084	2931	1754
9084	2931	7220
9084	2931	3548
7167	2932	7605
7167	2932	9754
7167	2932	3897
7167	2932	9080
7167	2932	5610
7167	2932	6113
7167	2932	2552
7167	2932	9580
7167	2932	580
9423	2933	9200
9423	2933	4544
9423	2933	7337
9423	2933	6331
9423	2933	5581
9423	2933	4648
17090	2934	3402
17090	2934	341
17090	2934	8322
17090	2934	8139
17090	2934	134
17090	2934	2189
17090	2934	3429
5257	2935	5376
5257	2935	1557
5257	2935	3943
5257	2935	5641
5257	2935	2472
7677	2936	815
18271	2937	7037
18271	2937	6906
18271	2937	9447
18271	2937	7985
18271	2937	2963
18271	2937	4889
18271	2937	423
18271	2937	44
11370	2938	9798
11370	2938	9892
11370	2938	625
11370	2938	3467
11370	2938	9842
11370	2938	8864
11539	2939	6104
11539	2939	2738
11539	2939	4623
10090	2940	9409
10090	2940	3133
10090	2940	3707
10090	2940	2452
10090	2940	4392
10090	2940	4305
10090	2940	3752
5230	2941	8385
5230	2941	2460
5230	2941	1214
5230	2941	3555
5230	2941	2823
5230	2941	881
5230	2941	8407
5230	2941	4548
5230	2941	2653
10209	2942	8181
10209	2942	6719
10209	2942	303
10209	2942	4548
10209	2942	2558
10209	2942	8453
10209	2942	7420
10209	2942	214
6073	2943	9931
6073	2943	6673
6073	2943	1878
6073	2943	2732
6073	2943	4431
6073	2943	5208
3852	2944	4866
14845	2945	2439
5304	2946	5688
5304	2946	2375
5304	2946	2685
5304	2946	96
5304	2946	8374
5304	2946	910
12234	2947	8043
12234	2947	9198
12234	2947	9048
12234	2947	331
12234	2947	2393
12234	2947	510
12234	2947	5421
12234	2947	8874
2496	2948	296
2496	2948	518
2496	2948	9649
2496	2948	1472
2496	2948	7544
2496	2948	5214
8823	2949	5980
8823	2949	6960
8823	2949	1594
8823	2949	1254
8823	2949	8394
8823	2949	8123
9697	2950	1671
9697	2950	338
3619	2951	8696
3619	2951	2694
3619	2951	8004
3619	2951	1429
3619	2951	12
3619	2951	2356
3619	2951	5859
8505	2952	5917
8505	2952	1590
8505	2952	6779
8505	2952	1674
8505	2952	4579
8505	2952	8926
8505	2952	8345
2077	2953	2227
2077	2953	8538
2077	2953	2977
2077	2953	3844
2077	2953	4502
16474	2954	3346
16474	2954	2540
16474	2954	4052
16474	2954	7241
16474	2954	5450
16474	2954	1588
16474	2954	3787
16474	2954	4833
16474	2954	2692
2457	2955	2122
2457	2955	3343
2457	2955	5602
2457	2955	4860
2457	2955	5433
15946	2956	2186
15946	2956	8277
15946	2956	1736
15946	2956	1430
15946	2956	8002
15946	2956	2467
15946	2956	3321
15946	2956	1921
15946	2956	8508
3700	2957	8280
3700	2957	6164
3520	2958	1407
3520	2958	7629
18729	2959	4887
18729	2959	9198
18729	2959	8242
324	2960	4204
324	2960	1709
324	2960	2253
324	2960	392
324	2960	3700
324	2960	176
324	2960	6179
324	2960	9255
324	2960	1267
1629	2961	8364
1629	2961	5411
1629	2961	5411
1629	2961	6767
1629	2961	6621
1629	2961	1441
1629	2961	5839
1629	2961	8317
4034	2962	7402
4034	2962	3868
4034	2962	337
7016	2963	1566
13952	2964	3738
13952	2964	9961
13952	2964	8654
13952	2964	8688
13952	2964	5095
13952	2964	722
13952	2964	9022
13952	2964	9489
13952	2964	7602
15877	2965	1447
6024	2966	9988
6024	2966	5022
6024	2966	7352
6024	2966	4084
6024	2966	6384
6024	2966	497
2436	2967	2291
2436	2967	5221
2436	2967	1527
2436	2967	7831
2436	2967	8793
2436	2967	4457
2436	2967	2289
2436	2967	6006
2055	2968	6010
4787	2969	3871
4787	2969	7947
4787	2969	1433
4787	2969	722
4787	2969	129
4787	2969	4953
4787	2969	2265
13444	2970	9931
13444	2970	1802
13444	2970	1176
13444	2970	3035
13444	2970	7890
13444	2970	9578
13444	2970	5996
13444	2970	3381
13444	2970	6001
13445	2971	8971
13445	2971	2268
13445	2971	164
13445	2971	7957
15775	2972	695
7459	2973	2997
7459	2973	7271
7459	2973	5841
7459	2973	2935
7459	2973	5465
7459	2973	8564
15067	2974	8769
15067	2974	3193
15067	2974	7818
15067	2974	4613
10615	2975	9037
10615	2975	8212
10965	2976	6134
10965	2976	786
10965	2976	1075
10965	2976	8530
10965	2976	6883
10965	2976	6186
10965	2976	5392
10965	2976	2377
10965	2976	1600
9304	2977	6340
9304	2977	4094
9304	2977	3367
9304	2977	33
12333	2978	7766
12333	2978	6278
12333	2978	1924
12333	2978	8174
12333	2978	8811
12333	2978	7487
12333	2978	6774
4509	2979	5635
19458	2980	6928
19458	2980	9565
19458	2980	826
19458	2980	10000
19458	2980	7346
18539	2981	7379
18539	2981	6625
18539	2981	9435
15223	2982	8085
15223	2982	7767
15223	2982	1016
15223	2982	5063
15223	2982	7053
15223	2982	1013
15223	2982	2545
19780	2983	9160
19780	2983	4416
2080	2984	4438
2080	2984	2021
2080	2984	3044
2080	2984	1378
4786	2985	336
4786	2985	9684
4786	2985	8135
4786	2985	2361
4786	2985	2118
2554	2986	7815
18435	2987	4572
18435	2987	5945
18435	2987	7884
18435	2987	8425
18435	2987	9715
18435	2987	2934
5235	2988	4846
13927	2989	8241
12110	2990	5273
12110	2990	8231
12110	2990	4672
5109	2991	432
5109	2991	7512
5109	2991	1260
5109	2991	5984
5109	2991	9415
5109	2991	6416
19645	2992	9606
19645	2992	2087
19645	2992	7960
19645	2992	7632
19645	2992	7204
19645	2992	366
3724	2993	3073
3724	2993	8655
3724	2993	7454
3724	2993	6990
3724	2993	5467
6518	2994	9291
6518	2994	1112
6518	2994	3573
6518	2994	8737
6518	2994	5262
11254	2995	7489
11254	2995	3652
11254	2995	9207
11254	2995	4894
11254	2995	6945
11254	2995	3529
11254	2995	5289
11254	2995	5670
9921	2996	6338
10150	2997	1015
10150	2997	1036
10150	2997	7995
10150	2997	2765
10150	2997	9086
7960	2998	5864
2305	2999	9669
2305	2999	3939
2305	2999	7633
2305	2999	5940
2305	2999	5351
2305	2999	3188
2305	2999	1696
2305	2999	7983
2305	2999	2748
3666	3000	5813
3666	3000	6185
3666	3000	3509
3666	3000	2828
3666	3000	8471
12411	3001	9972
12411	3001	3979
11537	3002	8151
11537	3002	8161
11537	3002	5191
11537	3002	4900
11537	3002	1942
11537	3002	7829
11537	3002	9029
11537	3002	5604
7620	3003	15
7620	3003	5458
7620	3003	1266
7620	3003	8393
4492	3004	5820
4492	3004	7032
4492	3004	6455
4492	3004	8548
12752	3005	2414
12752	3005	371
12752	3005	5613
12752	3005	1073
13061	3006	5968
13061	3006	7457
13061	3006	6252
13061	3006	4528
3118	3007	3490
3118	3007	5237
3118	3007	8005
3118	3007	1654
3118	3007	3239
3118	3007	7263
3118	3007	9739
4076	3008	5603
6118	3009	2900
6574	3010	128
6574	3010	7129
6574	3010	9639
6574	3010	6800
6574	3010	5550
5625	3011	1148
5625	3011	5092
5625	3011	3459
15110	3012	7904
15110	3012	5382
15110	3012	9940
15110	3012	5823
15110	3012	5054
15110	3012	5432
15110	3012	8083
15110	3012	5983
18597	3013	2353
18597	3013	4525
15965	3014	5538
6882	3015	3764
6882	3015	8154
6882	3015	8553
6882	3015	2536
6882	3015	7899
7763	3016	3180
7763	3016	9642
7763	3016	8288
7763	3016	2977
7763	3016	2148
7763	3016	2343
7763	3016	3007
7763	3016	1126
9778	3017	4474
9778	3017	7685
9778	3017	2572
9778	3017	7628
9778	3017	9464
5287	3018	8176
5287	3018	1077
5287	3018	2752
5287	3018	2267
5287	3018	910
5287	3018	6737
5287	3018	6825
13720	3019	5449
13720	3019	8407
12069	3020	7912
969	3021	1344
8192	3022	9191
8192	3022	9778
8192	3022	8231
8192	3022	8988
8192	3022	3462
17819	3023	6929
17819	3023	994
17819	3023	2821
17819	3023	7811
17819	3023	9389
1465	3024	4829
1465	3024	3563
1465	3024	2343
1465	3024	9946
1465	3024	9941
1465	3024	5728
1465	3024	5458
1465	3024	2312
1465	3024	7239
16463	3025	7137
16463	3025	8310
16463	3025	9583
886	3026	6590
886	3026	6104
12097	3027	4981
877	3028	7644
877	3028	5984
877	3028	2983
877	3028	9978
877	3028	9745
877	3028	6644
877	3028	3417
15208	3029	5353
15208	3029	5292
15208	3029	8138
15208	3029	7472
15208	3029	30
15208	3029	3557
2400	3030	8601
2400	3030	3588
2400	3030	5394
2400	3030	6866
2400	3030	2659
4857	3031	8788
4857	3031	4012
4298	3032	5268
4298	3032	9054
4298	3032	6446
4298	3032	24
4298	3032	2328
4298	3032	4014
4298	3032	7202
8133	3033	4348
8133	3033	4334
6242	3034	7200
6242	3034	5463
6242	3034	2301
2708	3035	9053
2708	3035	163
8352	3036	3583
8352	3036	9468
8352	3036	8447
8352	3036	2405
8352	3036	6049
3041	3037	6671
3041	3037	9174
3041	3037	1212
1529	3038	342
1529	3038	758
1529	3038	9915
1529	3038	3943
1529	3038	4594
1529	3038	8522
1529	3038	7227
1529	3038	5819
1529	3038	2632
15303	3039	8134
15303	3039	438
1526	3040	141
1526	3040	9457
1526	3040	8992
1526	3040	8951
7089	3041	6584
7089	3041	2314
9891	3042	2597
9891	3042	3109
7093	3043	4309
8899	3044	5348
8899	3044	3618
8899	3044	2558
8899	3044	7843
8852	3045	6829
1899	3046	9889
1899	3046	8458
1899	3046	7618
1899	3046	3890
1899	3046	8715
1899	3046	6376
1899	3046	2927
13088	3047	3029
13088	3047	431
5808	3048	2225
5808	3048	6067
5808	3048	3948
5808	3048	7259
5808	3048	8773
5324	3049	1342
5324	3049	8999
5324	3049	4900
5324	3049	812
5324	3049	9498
5324	3049	4784
5324	3049	4741
5324	3049	2832
5324	3049	8190
8512	3050	211
8512	3050	8402
8512	3050	377
8512	3050	1645
8512	3050	8991
8512	3050	356
10511	3051	6177
10511	3051	1904
10511	3051	5385
10511	3051	4033
10511	3051	2473
10511	3051	3272
10511	3051	6478
10511	3051	516
17834	3052	8256
17834	3052	4571
17834	3052	300
17834	3052	5235
17834	3052	182
17834	3052	5618
17834	3052	6650
4068	3053	250
4068	3053	3572
98	3054	6737
98	3054	591
17692	3055	6092
17692	3055	8942
17692	3055	7575
17692	3055	2519
18337	3056	1202
18337	3056	4147
18337	3056	1516
5348	3057	4348
9876	3058	3784
9876	3058	5522
8927	3059	3586
8927	3059	7421
8927	3059	2887
8927	3059	1864
12020	3060	3728
12020	3060	7201
12020	3060	522
12020	3060	5999
12020	3060	6486
539	3061	144
539	3061	4074
539	3061	425
539	3061	5063
539	3061	6726
539	3061	5980
539	3061	2038
539	3061	4599
539	3061	3518
1437	3062	2267
1437	3062	1194
1437	3062	8729
1437	3062	9021
1437	3062	4893
1437	3062	4467
1437	3062	508
1437	3062	6626
6704	3063	1941
6704	3063	7707
6704	3063	3135
6704	3063	4866
6704	3063	1942
6704	3063	9836
6704	3063	507
6704	3063	2960
3961	3064	1145
3961	3064	172
13595	3065	149
13595	3065	8316
13595	3065	6299
13595	3065	8629
13595	3065	7246
13595	3065	657
13595	3065	8181
13595	3065	3395
13595	3065	1521
15665	3066	9037
15665	3066	7400
15665	3066	1132
15665	3066	6005
15665	3066	3863
4357	3067	8201
4357	3067	4826
4357	3067	365
4357	3067	4633
4357	3067	5974
14988	3068	5326
14988	3068	584
14988	3068	2194
14988	3068	3571
14988	3068	2247
12218	3069	8288
12975	3070	1933
13130	3071	4591
13130	3071	9942
13130	3071	2139
5443	3072	705
5443	3072	7204
5443	3072	2775
5443	3072	9060
14694	3073	3835
14694	3073	6816
14694	3073	4520
14694	3073	2332
14694	3073	5738
14694	3073	1253
6782	3074	6113
6782	3074	1458
6782	3074	3776
6782	3074	9768
6782	3074	7543
6782	3074	5054
6782	3074	6174
15	3075	5774
15	3075	3126
15	3075	9630
15	3075	5028
15	3075	4543
15	3075	4274
15	3075	8500
15	3075	6066
15	3075	7203
13939	3076	5796
13939	3076	3359
13939	3076	8971
13939	3076	1977
13939	3076	6216
13939	3076	5172
9604	3077	5685
19917	3078	344
15092	3079	4516
15092	3079	5040
15092	3079	1978
15092	3079	2281
15092	3079	4779
15092	3079	761
15092	3079	2008
15092	3079	335
17078	3080	1287
17078	3080	6377
17078	3080	854
17078	3080	3824
17078	3080	4267
17078	3080	9994
10067	3081	3432
16420	3082	9204
16420	3082	8119
17704	3083	5271
17704	3083	4796
17704	3083	8885
17704	3083	8367
5266	3084	1415
5266	3084	1791
5266	3084	9651
5266	3084	1880
5266	3084	3432
5266	3084	3262
5266	3084	5146
1292	3085	4892
19376	3086	5337
19376	3086	1205
19376	3086	8149
19376	3086	8858
19376	3086	1053
19376	3086	70
19376	3086	5870
19376	3086	1779
10082	3087	6421
10082	3087	5251
10082	3087	4357
10082	3087	2155
10082	3087	9830
10333	3088	7267
10333	3088	5549
10333	3088	2531
10333	3088	6773
5285	3089	1944
5285	3089	4124
5285	3089	8613
5285	3089	7988
5285	3089	7196
5285	3089	4004
5285	3089	6313
5285	3089	8654
5285	3089	9000
12533	3090	2391
12533	3090	4596
12533	3090	1571
12533	3090	1806
12533	3090	982
12533	3090	129
12533	3090	7629
12533	3090	5649
5688	3091	2195
5688	3091	440
5688	3091	3050
5688	3091	4321
5688	3091	5706
5688	3091	3491
16171	3092	9985
16171	3092	7423
15102	3093	6292
17788	3094	5500
17788	3094	8295
17788	3094	7605
17788	3094	5379
2168	3095	9181
12881	3096	5506
12881	3096	9367
12881	3096	8694
12881	3096	8766
12881	3096	7157
12881	3096	3878
12881	3096	8848
12881	3096	8476
12162	3097	8006
1383	3098	3109
13655	3099	7970
13655	3099	1228
13655	3099	7276
8863	3100	6151
8863	3100	4903
8863	3100	807
8863	3100	707
8863	3100	917
5393	3101	3657
2114	3102	3964
2114	3102	8655
2114	3102	3972
2114	3102	5184
2114	3102	362
2114	3102	1144
2114	3102	3668
8950	3103	3768
8950	3103	558
19922	3104	2473
19922	3104	4592
19922	3104	9822
19922	3104	9120
6183	3105	8710
6183	3105	8932
6183	3105	1279
6183	3105	5899
6183	3105	7075
6183	3105	4262
6183	3105	9347
6183	3105	9228
6183	3105	4779
14503	3106	9063
14503	3106	5906
14503	3106	9190
14503	3106	1274
14503	3106	8581
14503	3106	8364
14503	3106	9835
11467	3107	7898
11467	3107	8029
11467	3107	1138
11467	3107	6470
11467	3107	5143
11467	3107	3168
11467	3107	6580
4970	3108	2136
4970	3108	9534
4970	3108	1668
4970	3108	8230
4970	3108	7539
4970	3108	7236
10267	3109	2378
10267	3109	812
10267	3109	2969
10267	3109	8076
9310	3110	7140
9310	3110	4674
9310	3110	463
9310	3110	9992
9310	3110	2104
9310	3110	3633
9310	3110	6562
9310	3110	9239
10309	3111	2207
10309	3111	7226
10309	3111	2412
10309	3111	1311
10309	3111	9956
10309	3111	3136
10309	3111	8454
10309	3111	6370
12722	3112	4582
12722	3112	3762
12722	3112	5545
12722	3112	3233
17756	3113	5335
15492	3114	2146
15492	3114	6525
15492	3114	9503
15492	3114	3089
15492	3114	3893
15492	3114	2233
15492	3114	9225
5973	3115	5987
5973	3115	6707
5973	3115	67
5973	3115	4504
5973	3115	3782
12468	3116	8642
12468	3116	573
12468	3116	8390
12468	3116	4016
12468	3116	8766
15981	3117	977
15981	3117	1996
15981	3117	2208
15981	3117	1106
15981	3117	5333
15981	3117	7675
15981	3117	5649
5072	3118	5948
5072	3118	2133
5072	3118	347
5072	3118	6619
7677	3119	674
7677	3119	6477
7677	3119	5043
7677	3119	1372
7677	3119	957
17262	3120	9452
17262	3120	9940
17262	3120	5156
17262	3120	2250
17262	3120	224
17262	3120	3437
17262	3120	1709
17622	3121	6890
17622	3121	4024
10789	3122	2099
10789	3122	6038
10789	3122	7238
10789	3122	9084
10789	3122	1054
10789	3122	3064
10789	3122	1529
9930	3123	798
9930	3123	6419
9930	3123	2163
9930	3123	9855
9930	3123	5240
9930	3123	1581
9930	3123	3711
19495	3124	5237
12580	3125	9594
10986	3126	3101
10986	3126	4853
10986	3126	4299
10986	3126	2828
16135	3127	1385
16135	3127	8460
16135	3127	3915
16135	3127	4926
16135	3127	735
11310	3128	2103
11310	3128	526
11310	3128	1080
11310	3128	5727
11310	3128	3147
11948	3129	4041
11948	3129	928
11948	3129	8801
11948	3129	9962
11948	3129	9442
11948	3129	1866
14610	3130	2338
5727	3131	6490
5727	3131	4545
5727	3131	7202
5727	3131	5610
5727	3131	3638
5727	3131	6014
5727	3131	5076
5727	3131	3951
6784	3132	3569
6784	3132	6700
6784	3132	7801
6784	3132	7333
6784	3132	1900
6784	3132	3948
6784	3132	5960
6784	3132	8025
6784	3132	5982
19238	3133	4184
16268	3134	1526
16268	3134	2292
16268	3134	624
16849	3135	3759
16849	3135	608
13134	3136	9729
13134	3136	9974
13134	3136	1798
13134	3136	4823
13134	3136	1616
13134	3136	4115
11280	3137	733
11280	3137	4372
11280	3137	7381
11280	3137	7051
11280	3137	2327
1285	3138	6983
1285	3138	7222
1285	3138	8222
1285	3138	214
1285	3138	5001
18229	3139	4755
18229	3139	1705
18229	3139	4131
18229	3139	713
18229	3139	8475
18229	3139	2651
2993	3140	6539
2993	3140	3597
2993	3140	5383
2993	3140	2780
2993	3140	4862
2993	3140	7426
2993	3140	6894
2993	3140	4420
2993	3140	9442
7144	3141	5084
7144	3141	5610
7144	3141	1476
7144	3141	9231
7144	3141	674
7144	3141	1346
7144	3141	9529
7144	3141	6088
1898	3142	9045
1898	3142	4016
1898	3142	8629
1898	3142	9589
1898	3142	7029
1898	3142	3611
1898	3142	2464
1898	3142	9846
1898	3142	249
1844	3143	5192
1844	3143	4932
1844	3143	6682
1844	3143	2228
1844	3143	7004
1844	3143	3750
1844	3143	4738
1844	3143	4476
3009	3144	3616
3009	3144	971
2438	3145	2141
2438	3145	7581
2438	3145	1755
2438	3145	8612
2438	3145	9766
2438	3145	5205
2438	3145	2113
2438	3145	7788
2438	3145	1332
18944	3146	1223
18944	3146	5870
18944	3146	845
18944	3146	3412
18944	3146	7764
18944	3146	763
18944	3146	2885
2992	3147	2335
2992	3147	4390
2992	3147	5111
2992	3147	1297
2992	3147	4441
2992	3147	5914
2992	3147	9765
11267	3148	4021
11267	3148	9817
11267	3148	8293
11267	3148	7128
11267	3148	3095
11267	3148	2672
10014	3149	9454
10014	3149	9169
10014	3149	1756
10014	3149	3224
10014	3149	1817
10014	3149	4805
10014	3149	8621
5283	3150	4426
5283	3150	4238
5283	3150	6343
5283	3150	6535
18274	3151	6129
18274	3151	6899
17308	3152	6323
17308	3152	437
17308	3152	8129
17308	3152	5261
17308	3152	1699
17308	3152	5631
17308	3152	7301
7287	3153	2658
7287	3153	3348
7287	3153	165
7287	3153	155
8760	3154	1829
8760	3154	4399
8760	3154	3167
8760	3154	1323
6042	3155	9145
13642	3156	1032
13642	3156	5780
13642	3156	843
13642	3156	3856
13642	3156	3008
13642	3156	5377
13642	3156	2305
13407	3157	9231
13407	3157	2356
13407	3157	3814
13407	3157	3858
7711	3158	1054
7711	3158	6449
7711	3158	5191
18092	3159	7674
18092	3159	4509
18092	3159	869
18092	3159	6682
18092	3159	9200
18092	3159	1132
9890	3160	7903
9890	3160	7353
9890	3160	7537
9890	3160	8493
7366	3161	2729
7366	3161	3801
7366	3161	3227
7366	3161	380
7366	3161	3580
7366	3161	4435
7366	3161	2973
7366	3161	4335
17613	3162	4058
17613	3162	6095
17613	3162	1868
17613	3162	5578
17613	3162	8270
17613	3162	5124
17613	3162	6416
17613	3162	1400
3558	3163	8840
3625	3164	4425
3625	3164	6733
3625	3164	2660
3625	3164	3997
3625	3164	2384
3625	3164	3342
3625	3164	2972
3625	3164	4815
2460	3165	871
2460	3165	5786
2460	3165	5064
2460	3165	2778
13029	3166	761
6842	3167	2176
6842	3167	1258
6842	3167	4448
6842	3167	7127
6842	3167	2323
18682	3168	3592
18682	3168	5970
17495	3169	5262
12045	3170	9443
12045	3170	8245
12045	3170	7792
4479	3171	1501
4479	3171	3995
4479	3171	5395
4479	3171	3355
18648	3172	8071
18648	3172	2009
6927	3173	6315
6927	3173	7350
6927	3173	415
6927	3173	4062
6927	3173	7381
6927	3173	1810
11609	3174	3541
11609	3174	8226
11609	3174	3552
11609	3174	2222
11609	3174	817
11609	3174	4955
11609	3174	7694
11609	3174	5702
11609	3174	3106
7042	3175	1070
7042	3175	421
7042	3175	4455
10656	3176	9556
10656	3176	3028
10656	3176	7598
16829	3177	8072
16829	3177	3992
16829	3177	1181
16829	3177	6825
16829	3177	619
16829	3177	2377
16829	3177	591
16829	3177	4566
16829	3177	7063
1137	3178	2300
1137	3178	3035
1137	3178	3748
1137	3178	8311
1137	3178	7447
1137	3178	401
1137	3178	156
1137	3178	8537
1137	3178	1329
7411	3179	6502
7411	3179	7635
7411	3179	8657
8257	3180	2628
8257	3180	6329
8257	3180	8735
8257	3180	9603
8257	3180	1022
8257	3180	7621
12314	3181	5312
12314	3181	6619
12314	3181	2746
761	3182	8388
12647	3183	7295
12647	3183	3350
12647	3183	8215
12647	3183	2210
12647	3183	2955
12647	3183	413
12647	3183	5987
2596	3184	7452
2596	3184	7190
2596	3184	1852
2596	3184	9234
7162	3185	556
7162	3185	5515
7459	3186	2965
7459	3186	1925
15821	3187	9208
15821	3187	5873
6125	3188	6937
6125	3188	4236
6125	3188	8488
6125	3188	3565
18159	3189	2809
18159	3189	6636
18159	3189	9618
18159	3189	9151
18159	3189	6470
11355	3190	2337
11355	3190	4707
3287	3191	3270
3287	3191	2948
15206	3192	2144
15206	3192	3204
15206	3192	4496
15206	3192	7339
7616	3193	9486
7616	3193	4206
7616	3193	432
16688	3194	493
16688	3194	4156
16688	3194	660
13148	3195	5297
13148	3195	1966
13148	3195	4026
1631	3196	3377
1631	3196	4696
1631	3196	4419
1631	3196	6495
1631	3196	3471
1631	3196	7001
1631	3196	876
1631	3196	7404
16892	3197	1633
16892	3197	4967
16892	3197	3197
16892	3197	2901
12025	3198	8609
12025	3198	767
12025	3198	4637
16215	3199	2071
16215	3199	5434
16215	3199	6723
16215	3199	7920
19104	3200	3150
19104	3200	8914
19104	3200	8068
19104	3200	2063
19104	3200	1905
19104	3200	2393
19104	3200	3698
19104	3200	9932
19104	3200	5137
14414	3201	6681
9200	3202	4152
9200	3202	6755
9200	3202	656
9200	3202	3352
9200	3202	4389
9200	3202	1606
9200	3202	6085
19563	3203	756
19563	3203	3139
19563	3203	3371
19563	3203	6692
19563	3203	8721
19563	3203	4651
19563	3203	5402
19563	3203	8927
19563	3203	6104
18910	3204	4869
18910	3204	8504
14935	3205	6363
14935	3205	1100
14935	3205	7497
14935	3205	2069
14935	3205	4522
18346	3206	7976
18346	3206	314
18346	3206	9003
18346	3206	3534
18346	3206	348
18346	3206	7217
18346	3206	9355
18346	3206	6319
5361	3207	2181
5361	3207	1632
5361	3207	3262
5361	3207	5040
5361	3207	5327
5361	3207	4176
5361	3207	4955
7913	3208	1264
16961	3209	9606
16961	3209	8759
16961	3209	822
16961	3209	2828
16961	3209	9410
16961	3209	7252
16961	3209	614
16961	3209	8689
5728	3210	7352
5728	3210	6735
5728	3210	7538
13707	3211	5524
13707	3211	2912
13707	3211	1751
13707	3211	4618
13707	3211	6735
7973	3212	6278
7973	3212	5592
7973	3212	8251
7973	3212	6881
7973	3212	1458
7973	3212	5579
7973	3212	1614
7973	3212	5848
7973	3212	3298
12418	3213	9942
12418	3213	505
12418	3213	4296
12418	3213	663
12418	3213	9195
12418	3213	6381
9261	3214	233
9261	3214	1537
9261	3214	73
9261	3214	4338
9261	3214	1242
9261	3214	7292
9261	3214	3844
9261	3214	1343
3696	3215	1391
3696	3215	8502
3696	3215	8065
3696	3215	5372
3696	3215	9513
3696	3215	7029
3696	3215	6071
12286	3216	2064
12286	3216	7529
12286	3216	8374
12286	3216	2298
12286	3216	5158
12286	3216	1565
12286	3216	3018
12286	3216	6745
12286	3216	3540
17823	3217	3904
17823	3217	5659
17823	3217	9509
17823	3217	6117
17823	3217	1108
17823	3217	4181
5108	3218	2271
5108	3218	5341
5108	3218	786
5108	3218	6789
5108	3218	9878
5108	3218	2339
5108	3218	9240
5108	3218	2192
5108	3218	7198
13413	3219	7930
13413	3219	7414
13413	3219	8809
13413	3219	4664
13413	3219	4780
13413	3219	3984
13413	3219	768
13413	3219	8479
13413	3219	2300
9278	3220	893
9278	3220	267
9278	3220	4677
9278	3220	4798
9278	3220	2618
9278	3220	3914
9278	3220	4837
19001	3221	6434
19001	3221	9879
19001	3221	294
19001	3221	4758
19001	3221	6714
19001	3221	7232
19001	3221	9766
19001	3221	8175
19001	3221	6216
2026	3222	3740
2026	3222	6065
2026	3222	3228
2026	3222	8077
2026	3222	802
2026	3222	292
1170	3223	3178
1170	3223	9110
1170	3223	7099
1170	3223	8534
1170	3223	8907
1170	3223	8124
9432	3224	5222
9432	3224	8078
9432	3224	5463
9432	3224	3217
9432	3224	664
9432	3224	6946
9432	3224	4093
9432	3224	8844
9432	3224	1735
17667	3225	4107
17667	3225	962
17667	3225	8056
17667	3225	6947
17667	3225	6224
17667	3225	830
12586	3226	2558
12586	3226	7341
12586	3226	3494
12586	3226	5487
14442	3227	6055
14442	3227	2595
14442	3227	2850
14442	3227	2392
14442	3227	280
14442	3227	7316
16291	3228	4439
16291	3228	5954
6589	3229	4728
6589	3229	8209
6589	3229	9207
6589	3229	9813
6589	3229	5614
6589	3229	5422
15627	3230	7151
15627	3230	2746
15627	3230	4830
15627	3230	777
15627	3230	4809
15627	3230	6265
5526	3231	4749
5526	3231	8182
5526	3231	9763
5526	3231	9216
5526	3231	401
12728	3232	2607
12728	3232	9894
12728	3232	8258
18070	3233	5766
18070	3233	897
18070	3233	3019
18070	3233	542
17448	3234	6718
17448	3234	360
17448	3234	5576
17448	3234	3483
17448	3234	7409
14604	3235	2025
14604	3235	4921
14604	3235	4053
14604	3235	6272
14604	3235	6476
14604	3235	8903
8245	3236	9105
8245	3236	9717
8245	3236	9578
8245	3236	3664
8245	3236	3319
8245	3236	9150
8245	3236	8374
8245	3236	6834
3508	3237	2440
3508	3237	9933
3508	3237	1977
3508	3237	5934
3508	3237	2957
4124	3238	1527
4124	3238	2821
4124	3238	6773
4124	3238	6262
4124	3238	7087
4124	3238	6512
4124	3238	5034
2897	3239	4135
2897	3239	7028
2897	3239	1193
2897	3239	5144
2897	3239	4636
2897	3239	6212
2897	3239	485
2897	3239	2482
18509	3240	5176
18509	3240	3824
18509	3240	451
18509	3240	9130
18509	3240	305
18509	3240	4236
18509	3240	3914
18509	3240	550
18509	3240	4225
17720	3241	7630
17720	3241	3205
17720	3241	2440
17720	3241	9366
17720	3241	5320
18287	3242	8000
18287	3242	4989
18287	3242	6913
18287	3242	2744
18287	3242	488
18287	3242	5932
18287	3242	8987
18287	3242	3572
2403	3243	1313
2403	3243	9991
2403	3243	1094
2403	3243	5219
2893	3244	6804
2893	3244	758
2893	3244	2585
6144	3245	7784
2711	3246	2557
2711	3246	175
2711	3246	9398
2711	3246	4547
2711	3246	5475
2711	3246	9999
16743	3247	1732
16743	3247	1731
16743	3247	6640
16743	3247	7389
16743	3247	6746
16743	3247	9215
16743	3247	6528
16743	3247	8722
17793	3248	9061
17793	3248	2709
5414	3249	1078
5414	3249	6489
5414	3249	9984
5414	3249	7126
5414	3249	4490
5414	3249	58
5414	3249	9686
5414	3249	3642
4726	3250	1259
4726	3250	6942
4726	3250	5748
4726	3250	4856
4726	3250	2357
6869	3251	6244
6869	3251	6192
6869	3251	2772
6869	3251	7884
6869	3251	1917
6869	3251	2101
6869	3251	3782
6869	3251	7920
18358	3252	9499
18358	3252	5321
18358	3252	6086
18358	3252	3674
18358	3252	1112
18358	3252	5544
3470	3253	2417
3470	3253	1586
3470	3253	6177
3470	3253	9890
3470	3253	7691
3470	3253	9037
3470	3253	6989
3470	3253	2091
14823	3254	5089
14823	3254	3096
14823	3254	4352
14823	3254	3556
14823	3254	375
5581	3255	7123
14026	3256	4823
14026	3256	8475
1131	3257	7977
1131	3257	9386
1131	3257	3653
1131	3257	9265
5640	3258	7100
5640	3258	4285
2816	3259	8421
2816	3259	4535
2816	3259	6129
1101	3260	4412
1101	3260	2490
1101	3260	4615
1101	3260	6279
14798	3261	8894
14798	3261	9923
14798	3261	3785
5668	3262	905
5668	3262	6249
5668	3262	8059
3266	3263	3183
3266	3263	5793
4142	3264	9470
4142	3264	9920
4142	3264	2175
4142	3264	1542
4142	3264	7880
4142	3264	8793
4142	3264	9133
10763	3265	6684
10763	3265	3137
12640	3266	4117
12640	3266	4172
7282	3267	2004
7282	3267	8960
7282	3267	2303
7282	3267	9672
7282	3267	5235
7282	3267	792
7282	3267	4186
7282	3267	185
7282	3267	1836
16289	3268	246
8833	3269	8058
8833	3269	764
19448	3270	6563
19448	3270	3464
19448	3270	2082
12535	3271	7136
18681	3272	25
18681	3272	7384
18681	3272	6419
18681	3272	4121
9770	3273	4609
2342	3274	2969
2342	3274	810
2342	3274	9770
2342	3274	4109
2342	3274	6199
2342	3274	6245
12538	3275	8743
12538	3275	6038
12538	3275	853
12538	3275	7748
12538	3275	7418
12538	3275	3532
12538	3275	3527
12538	3275	7063
12538	3275	8455
16447	3276	5129
16447	3276	2143
16447	3276	4612
16447	3276	7642
12769	3277	9248
12769	3277	5694
12769	3277	7187
12769	3277	9352
12769	3277	3620
12769	3277	5671
12769	3277	9374
12769	3277	8555
12769	3277	2349
14953	3278	8850
14953	3278	9368
14953	3278	4849
14953	3278	2875
14953	3278	1328
14042	3279	132
14042	3279	5497
14042	3279	1348
14042	3279	4433
14042	3279	5293
15282	3280	5117
15282	3280	8908
15282	3280	7947
15282	3280	457
6663	3281	5454
6663	3281	8952
18167	3282	2834
18167	3282	7624
18167	3282	5110
18167	3282	254
18167	3282	557
18167	3282	8546
14906	3283	5728
14906	3283	660
14906	3283	3427
14906	3283	8262
14906	3283	5430
14906	3283	3452
14906	3283	6297
14906	3283	2845
937	3284	3384
937	3284	1134
937	3284	8903
937	3284	9613
937	3284	7132
937	3284	6686
14691	3285	6594
14691	3285	1654
14691	3285	4665
1923	3286	93
1923	3286	1726
10220	3287	9050
10220	3287	9278
10220	3287	864
10220	3287	7915
10220	3287	9269
10220	3287	4894
10220	3287	35
10220	3287	5910
10220	3287	3512
3848	3288	3182
3848	3288	867
3848	3288	8117
3848	3288	17
3848	3288	8931
3848	3288	3299
3848	3288	7729
3848	3288	4618
7773	3289	2345
7773	3289	8094
7773	3289	4628
7773	3289	8828
7773	3289	3529
7773	3289	9812
1356	3290	10
17880	3291	7149
17880	3291	8825
17880	3291	4071
17880	3291	5653
17880	3291	7142
10469	3292	6839
10469	3292	5962
10469	3292	5442
10469	3292	7076
10469	3292	6450
12919	3293	5400
12919	3293	3564
12919	3293	9453
12919	3293	4314
12919	3293	2925
12919	3293	497
12919	3293	7963
12919	3293	5300
12919	3293	4950
1822	3294	6683
1822	3294	2165
1822	3294	8273
1822	3294	9592
1822	3294	8606
4339	3295	4558
4339	3295	2597
4339	3295	1817
4339	3295	7548
4339	3295	3503
4339	3295	3993
4339	3295	4986
4339	3295	9363
4339	3295	8018
366	3296	9886
366	3296	3940
366	3296	3761
366	3296	661
366	3296	2636
10464	3297	8325
10464	3297	4747
10464	3297	3095
10464	3297	280
10464	3297	2024
83	3298	224
83	3298	7983
83	3298	3636
14794	3299	8696
14794	3299	4479
14794	3299	3351
14794	3299	6813
14794	3299	7427
14794	3299	3503
14794	3299	298
14794	3299	8602
14794	3299	3424
18222	3300	3977
18222	3300	2696
18222	3300	6716
4400	3301	319
4400	3301	5551
4400	3301	2215
4400	3301	5345
17694	3302	2628
17694	3302	6541
17694	3302	2935
17694	3302	5162
18277	3303	6751
18277	3303	5479
18277	3303	3456
18277	3303	5465
2031	3304	3379
2031	3304	2926
2031	3304	1635
8525	3305	314
8525	3305	6965
8525	3305	4532
8525	3305	4613
8525	3305	2635
8525	3305	327
8525	3305	3123
8525	3305	4150
10441	3306	8506
10441	3306	7788
10441	3306	284
10441	3306	4519
10441	3306	3684
7994	3307	9472
7994	3307	5282
7994	3307	4756
7994	3307	5448
7994	3307	6031
7994	3307	8865
7994	3307	7159
13523	3308	9743
13523	3308	5336
13523	3308	8630
13523	3308	1831
3392	3309	8526
3392	3309	3062
3392	3309	9868
3392	3309	1725
3392	3309	2900
3392	3309	3886
3392	3309	7934
6668	3310	7239
6668	3310	8815
6668	3310	7575
6668	3310	2429
6668	3310	9758
6668	3310	1101
6668	3310	6028
6668	3310	1852
6668	3310	3434
10317	3311	2913
10317	3311	1569
10317	3311	1963
10317	3311	4181
10317	3311	9360
10317	3311	7317
10317	3311	3993
10317	3311	5618
10317	3311	4295
10791	3312	5022
16911	3313	3614
16911	3313	6899
16911	3313	2965
16911	3313	7373
16911	3313	8221
16911	3313	4696
16911	3313	2972
13930	3314	3386
13930	3314	6746
16380	3315	1486
16380	3315	69
7364	3316	209
7364	3316	2209
7364	3316	6438
7364	3316	9135
4212	3317	9071
4212	3317	5131
4212	3317	1245
4212	3317	915
948	3318	222
948	3318	8051
13190	3319	8105
13190	3319	990
13190	3319	3443
13190	3319	5675
17639	3320	8867
17639	3320	3757
9343	3321	5146
9343	3321	3838
9343	3321	6916
233	3322	3526
233	3322	6252
233	3322	1129
13606	3323	5623
13606	3323	8168
13606	3323	6696
13606	3323	4600
13606	3323	6596
13606	3323	1200
13606	3323	9944
13719	3324	6976
13719	3324	2776
13719	3324	1994
13719	3324	5016
13719	3324	8721
13719	3324	9926
13719	3324	6522
13719	3324	6218
13719	3324	36
9271	3325	7182
9271	3325	4949
9271	3325	8064
9977	3326	395
4778	3327	5512
4778	3327	6129
4778	3327	1980
4778	3327	984
4778	3327	7341
4778	3327	1111
5877	3328	5966
5877	3328	9961
5877	3328	4166
11520	3329	130
11520	3329	1801
11520	3329	2840
11520	3329	5643
11520	3329	2749
11520	3329	1619
11520	3329	5820
11520	3329	4752
11520	3329	2913
148	3330	2185
148	3330	9864
148	3330	7147
148	3330	2110
148	3330	8294
148	3330	8415
2508	3331	222
2508	3331	9030
9699	3332	1780
9699	3332	9044
9699	3332	3785
9699	3332	7484
9699	3332	5488
9699	3332	2319
9699	3332	6228
9699	3332	4685
6199	3333	4353
6199	3333	3839
6199	3333	2176
12124	3334	4700
12124	3334	924
12124	3334	1146
12124	3334	6028
12124	3334	678
12124	3334	5976
12124	3334	4149
17668	3335	1933
17668	3335	6522
17668	3335	3361
17668	3335	861
14550	3336	4488
10824	3337	121
10824	3337	215
12379	3338	8393
12379	3338	564
4993	3339	8783
4993	3339	2188
10829	3340	6358
10829	3340	3247
10829	3340	6818
10829	3340	8384
10829	3340	9353
10829	3340	7736
10829	3340	4788
6360	3341	8297
6360	3341	1724
6360	3341	9879
6360	3341	4570
6360	3341	148
6360	3341	7481
6360	3341	6872
6360	3341	8470
6360	3341	636
18040	3342	7618
18040	3342	9690
18040	3342	1489
8467	3343	2285
8467	3343	8634
8467	3343	9809
8467	3343	4230
3419	3344	5548
3419	3344	114
3419	3344	779
3419	3344	5203
3419	3344	6273
3419	3344	2964
3419	3344	5224
3419	3344	4315
3419	3344	8685
1939	3345	3133
1939	3345	6525
1939	3345	964
15971	3346	3477
15971	3346	802
15971	3346	3276
15971	3346	7259
15971	3346	8824
8096	3347	4856
8096	3347	1721
8096	3347	4327
8096	3347	2867
8096	3347	3926
8096	3347	4821
8096	3347	9041
8096	3347	2874
8096	3347	8511
18624	3348	5317
18624	3348	1269
13559	3349	6605
13559	3349	6118
13559	3349	2589
10909	3350	4846
10909	3350	57
10909	3350	6616
10909	3350	2573
10909	3350	9282
19776	3351	7753
19776	3351	3894
19776	3351	785
19776	3351	8599
19776	3351	5126
19776	3351	5714
19776	3351	5160
19776	3351	3168
19776	3351	2126
4364	3352	5113
4364	3352	7527
4364	3352	5489
16452	3353	2232
16452	3353	7873
12943	3354	1187
12943	3354	532
12943	3354	3076
10401	3355	7383
10401	3355	7595
10401	3355	8085
10401	3355	6889
10401	3355	7086
17608	3356	4416
17608	3356	7047
17608	3356	7548
17608	3356	4928
10919	3357	9159
10919	3357	1846
10919	3357	9682
10919	3357	4485
10919	3357	1723
10919	3357	2398
18966	3358	8287
18966	3358	1973
18966	3358	4062
18966	3358	4811
18966	3358	6470
18966	3358	345
18966	3358	5197
18966	3358	6685
17060	3359	7758
17060	3359	6872
17060	3359	2281
17060	3359	8091
17060	3359	8752
17060	3359	6366
17060	3359	858
17060	3359	9740
17060	3359	7358
7656	3360	3867
7656	3360	2298
7656	3360	3839
7656	3360	9081
7656	3360	1807
7656	3360	8776
7656	3360	6318
8818	3361	2281
8818	3361	3735
8818	3361	4184
8818	3361	8057
8818	3361	8024
8818	3361	5369
8818	3361	1458
7510	3362	5966
7510	3362	4697
7510	3362	5707
7510	3362	6450
7510	3362	4528
7510	3362	6433
17428	3363	1852
17428	3363	8302
17428	3363	5577
17428	3363	4494
17428	3363	8635
856	3364	6060
856	3364	8837
856	3364	3444
856	3364	4228
856	3364	6568
856	3364	4288
856	3364	2763
856	3364	1714
856	3364	208
17019	3365	4835
17019	3365	3173
17019	3365	3918
7247	3366	9295
7247	3366	712
7247	3366	6703
7247	3366	2631
7247	3366	3694
7247	3366	6270
7247	3366	2299
7247	3366	9070
7247	3366	1549
10045	3367	2989
10045	3367	9319
10045	3367	4471
10045	3367	530
10045	3367	3172
10045	3367	9953
13311	3368	9925
13311	3368	2110
13311	3368	8970
13311	3368	4178
13311	3368	6915
15860	3369	3780
15860	3369	2820
14582	3370	5085
14582	3370	997
7118	3371	8751
7118	3371	4703
7345	3372	1712
7345	3372	7716
16928	3373	2201
16928	3373	6991
16928	3373	7283
16928	3373	4017
10028	3374	8573
10028	3374	8346
10028	3374	713
10028	3374	8183
10028	3374	6721
10028	3374	514
16458	3375	6693
16458	3375	9635
16458	3375	1064
16458	3375	1737
16458	3375	9929
16458	3375	712
16230	3376	7210
16230	3376	6663
16230	3376	270
16230	3376	6447
16230	3376	8295
16230	3376	5422
16230	3376	5189
16230	3376	9669
16230	3376	395
2917	3377	9805
2917	3377	8265
2917	3377	8576
14902	3378	4672
14902	3378	3763
14902	3378	9879
14902	3378	1931
14902	3378	7170
14902	3378	2099
3535	3379	1072
3535	3379	8528
3535	3379	7526
3535	3379	2858
3535	3379	8848
3535	3379	4823
3535	3379	8884
7111	3380	8496
7111	3380	7290
7111	3380	6280
7111	3380	7779
7111	3380	6818
7111	3380	145
7111	3380	1522
99	3381	8381
99	3381	9386
99	3381	2506
99	3381	4706
16047	3382	5104
16047	3382	3736
16047	3382	3867
16047	3382	6853
16047	3382	8393
16047	3382	6098
15239	3383	7669
12099	3384	3278
12099	3384	7987
12099	3384	2936
12099	3384	6006
2220	3385	3504
2220	3385	4769
2220	3385	6830
2220	3385	4027
2220	3385	1698
2902	3386	9420
2902	3386	4265
2902	3386	7723
2902	3386	8
2902	3386	5524
2902	3386	1097
2902	3386	823
2902	3386	2640
12286	3387	6500
12286	3387	4796
12987	3388	7945
12987	3388	5845
12987	3388	2775
12987	3388	5825
12987	3388	7651
12987	3388	6207
12987	3388	8776
19196	3389	1739
19196	3389	3487
19196	3389	7919
19196	3389	3222
19196	3389	512
19196	3389	9207
19196	3389	7936
7561	3390	3890
7561	3390	1894
16200	3391	5403
16200	3391	4546
16200	3391	6764
16200	3391	1103
16200	3391	5351
17145	3392	8878
13627	3393	594
13627	3393	558
13627	3393	2948
13627	3393	6024
13627	3393	551
13627	3393	4069
13627	3393	159
13627	3393	773
13627	3393	4899
497	3394	8821
497	3394	8156
497	3394	3571
497	3394	4511
497	3394	7856
497	3394	4271
497	3394	9588
11223	3395	6351
11223	3395	7368
16280	3396	15
16280	3396	4168
16280	3396	8009
16280	3396	3540
14220	3397	8773
14220	3397	301
14220	3397	1128
14220	3397	262
14220	3397	5500
3700	3398	8359
3577	3399	2390
3577	3399	9837
3577	3399	7101
3577	3399	6563
3577	3399	485
3577	3399	2983
3577	3399	4136
3577	3399	2301
3577	3399	3171
17342	3400	521
17758	3401	668
6114	3402	3455
6114	3402	2482
6114	3402	1145
6114	3402	1438
6114	3402	2224
6114	3402	7410
6114	3402	836
6114	3402	7088
6114	3402	9251
19543	3403	8651
18636	3404	2375
18636	3404	8902
18636	3404	6378
18636	3404	5846
18636	3404	4350
18636	3404	1650
18636	3404	2856
18636	3404	1098
18636	3404	9640
17781	3405	8662
14625	3406	6630
14625	3406	1029
19859	3407	1313
19859	3407	5153
19859	3407	7962
19859	3407	2235
19859	3407	5862
19859	3407	4510
19859	3407	1517
11903	3408	2806
11903	3408	366
11903	3408	8763
19583	3409	9721
19583	3409	1392
19583	3409	1511
19583	3409	6695
17858	3410	2261
17858	3410	4709
17858	3410	1090
17858	3410	9730
17858	3410	2153
17858	3410	5438
17858	3410	6812
17858	3410	9513
17858	3410	3992
7425	3411	4745
7425	3411	1017
7425	3411	7326
7425	3411	368
7425	3411	3571
16557	3412	7378
16557	3412	1413
16557	3412	8670
16557	3412	2047
3118	3413	7071
3118	3413	8754
3118	3413	2357
3118	3413	1268
3118	3413	4938
10610	3414	7934
10610	3414	9585
13924	3415	6492
13924	3415	389
13924	3415	4625
13924	3415	97
14335	3416	581
14335	3416	8733
14335	3416	3039
14335	3416	441
14335	3416	8976
13818	3417	1248
13818	3417	8628
10237	3418	3657
10237	3418	2766
18493	3419	4481
18493	3419	1893
18493	3419	3349
7580	3420	439
7580	3420	2768
7580	3420	9454
7580	3420	3110
7580	3420	5738
7580	3420	3199
13711	3421	609
13711	3421	7388
13711	3421	9238
13711	3421	3031
13711	3421	5082
13711	3421	6062
13711	3421	169
13711	3421	7825
1186	3422	4609
1186	3422	7090
1186	3422	3477
1186	3422	6950
1186	3422	7144
1186	3422	6993
1186	3422	6055
1186	3422	9282
1186	3422	6249
2660	3423	3296
2660	3423	4254
2660	3423	9468
11573	3424	5215
11573	3424	6668
11573	3424	196
11573	3424	7544
11573	3424	2660
11573	3424	5091
8743	3425	6683
8743	3425	6494
8743	3425	2916
8743	3425	4235
8743	3425	910
5247	3426	8945
5247	3426	3703
5247	3426	3395
5247	3426	9228
3776	3427	603
3776	3427	697
3776	3427	9553
3776	3427	5040
3776	3427	2754
3776	3427	5836
13491	3428	9369
13491	3428	9897
13491	3428	4881
13491	3428	3925
13491	3428	7497
13491	3428	9212
9370	3429	9074
9370	3429	252
9370	3429	3135
9370	3429	4673
9370	3429	3247
9370	3429	2876
7131	3430	3744
7131	3430	4935
7131	3430	7966
7131	3430	6899
7131	3430	2012
7131	3430	4195
18505	3431	5007
18505	3431	8495
18505	3431	8238
18505	3431	4030
18505	3431	3674
18505	3431	9855
18505	3431	471
18505	3431	7549
18505	3431	8693
13317	3432	2121
13317	3432	5846
13317	3432	407
13317	3432	5567
13317	3432	6510
13317	3432	6047
13317	3432	8715
13317	3432	8171
13317	3432	5768
11244	3433	9947
17278	3434	5297
17278	3434	6908
17278	3434	7501
17278	3434	3732
17278	3434	9395
17278	3434	1007
17278	3434	9873
17175	3435	1332
17175	3435	923
17175	3435	2727
17175	3435	1102
17175	3435	4014
17175	3435	1313
17175	3435	2608
17175	3435	963
17175	3435	4027
15517	3436	7057
15517	3436	7569
16953	3437	7555
16953	3437	2869
16953	3437	7829
16953	3437	2172
16953	3437	8269
16953	3437	4367
13949	3438	6490
13949	3438	2429
13949	3438	7974
13949	3438	423
15982	3439	6467
8044	3440	2500
8044	3440	4830
8044	3440	1083
8044	3440	856
8044	3440	2679
8044	3440	2423
8044	3440	7824
8044	3440	9083
8044	3440	7672
16188	3441	6085
16188	3441	5825
16188	3441	1524
16188	3441	6574
16188	3441	1426
12511	3442	9354
12511	3442	4531
12511	3442	8457
12511	3442	899
12511	3442	5867
12511	3442	6531
12511	3442	7039
12511	3442	1632
12511	3442	804
13256	3443	8819
13256	3443	544
13256	3443	5914
13256	3443	6499
13256	3443	7626
4313	3444	9110
4313	3444	8990
4313	3444	8765
11607	3445	4930
16206	3446	2800
16206	3446	4972
16206	3446	7594
16206	3446	1887
16206	3446	541
16206	3446	9944
16206	3446	1669
16206	3446	7506
12989	3447	2015
12989	3447	1178
12989	3447	4415
12989	3447	5020
12989	3447	4210
14019	3448	353
14019	3448	6263
14019	3448	2586
14019	3448	1752
14019	3448	1599
18208	3449	5599
18208	3449	2342
18208	3449	4221
18208	3449	729
18208	3449	9626
18208	3449	911
18208	3449	9300
402	3450	8695
402	3450	3437
10377	3451	8609
10377	3451	464
12124	3452	3675
12124	3452	6995
12124	3452	5614
12124	3452	152
18904	3453	9653
18904	3453	2496
11864	3454	1121
11864	3454	8616
11864	3454	7606
11864	3454	2535
11864	3454	5142
11864	3454	2216
11864	3454	2272
15770	3455	4409
15770	3455	2823
15770	3455	7584
15770	3455	6786
8561	3456	1536
304	3457	9232
304	3457	234
4898	3458	1659
4898	3458	4845
4898	3458	9779
4898	3458	3774
4898	3458	1503
4898	3458	5077
4898	3458	1435
14892	3459	4577
14892	3459	4257
14892	3459	1732
14892	3459	831
11036	3460	2477
14642	3461	6574
14642	3461	9838
14642	3461	8690
14642	3461	6365
14642	3461	814
14642	3461	7571
14642	3461	3038
14588	3462	782
14588	3462	1096
14588	3462	9931
14588	3462	9692
14588	3462	1581
14588	3462	9729
14588	3462	4385
14588	3462	2475
14588	3462	4379
1486	3463	9676
1486	3463	7114
1486	3463	1007
1486	3463	7
1486	3463	3646
1486	3463	9003
1486	3463	9431
1486	3463	250
1486	3463	1341
2137	3464	7371
3497	3465	2491
3497	3465	3966
3497	3465	761
3497	3465	4880
9774	3466	5676
9774	3466	3979
9774	3466	4292
9774	3466	4229
9774	3466	6060
9774	3466	6701
9774	3466	1155
9774	3466	2479
9774	3466	5820
16621	3467	477
16621	3467	5092
16621	3467	7520
16621	3467	244
11838	3468	1025
11838	3468	8128
11838	3468	9159
11838	3468	5752
13813	3469	2939
13813	3469	2788
13813	3469	4059
13813	3469	6999
13813	3469	3532
13813	3469	9893
13813	3469	2774
13813	3469	4927
13813	3469	6055
14159	3470	2333
14159	3470	8910
14159	3470	2704
14159	3470	4991
14159	3470	5826
17228	3471	6394
17228	3471	6977
17228	3471	4
5556	3472	5473
5556	3472	65
5556	3472	138
5556	3472	6791
5556	3472	4598
5556	3472	555
11091	3473	3475
11091	3473	6268
11091	3473	758
11091	3473	2304
11091	3473	2587
11091	3473	4603
11091	3473	5086
1116	3474	2626
1116	3474	7283
1116	3474	7274
1116	3474	5117
1116	3474	9182
1116	3474	3374
1116	3474	4599
1116	3474	7433
1116	3474	1238
7082	3475	5849
7082	3475	9676
7082	3475	2133
7082	3475	1492
7082	3475	8673
7082	3475	1601
17749	3476	6703
17749	3476	5594
17749	3476	6132
17749	3476	6923
17749	3476	1059
17749	3476	1754
17749	3476	1702
17749	3476	699
748	3477	9516
16375	3478	4143
16375	3478	7607
16375	3478	6272
16375	3478	8993
16375	3478	4385
16375	3478	2058
16375	3478	8688
16375	3478	9468
2338	3479	8718
2338	3479	8773
2338	3479	6657
2338	3479	7174
2338	3479	6476
2338	3479	2522
2338	3479	8887
2338	3479	2595
3175	3480	6712
3175	3480	130
3175	3480	2196
3175	3480	5841
3175	3480	766
3175	3480	8296
3175	3480	280
3175	3480	6683
7713	3481	5120
7713	3481	2450
10088	3482	6631
10088	3482	6634
10088	3482	5267
10088	3482	8742
10088	3482	6359
10088	3482	7359
10088	3482	8541
10088	3482	6608
6581	3483	7147
6581	3483	9910
6581	3483	9725
6581	3483	6272
6581	3483	7403
6581	3483	911
6581	3483	1621
6581	3483	7376
12235	3484	699
18479	3485	8060
18479	3485	7686
18479	3485	8163
18479	3485	295
39	3486	3119
39	3486	8803
39	3486	1867
39	3486	1572
11754	3487	6541
11754	3487	3368
1459	3488	814
1459	3488	7172
1459	3488	1242
1459	3488	7049
14959	3489	5313
14358	3490	6421
14358	3490	2079
14358	3490	9904
14358	3490	7838
14358	3490	2949
14358	3490	4001
9628	3491	3791
9628	3491	1129
9628	3491	7663
9628	3491	8318
7259	3492	808
7259	3492	50
7259	3492	9057
7259	3492	9009
13692	3493	9981
13692	3493	5370
13692	3493	1046
13692	3493	136
2528	3494	9877
18187	3495	2941
18187	3495	499
18187	3495	5657
18187	3495	5120
18187	3495	8515
18187	3495	1511
18187	3495	9565
18187	3495	6977
18187	3495	7964
16198	3496	9363
16198	3496	1600
2815	3497	1094
3185	3498	1148
3185	3498	8889
3185	3498	5251
3185	3498	409
14771	3499	5407
14771	3499	7954
14771	3499	9296
14771	3499	6794
14771	3499	6556
14771	3499	2303
14771	3499	9455
14771	3499	6163
14771	3499	4989
12273	3500	5800
12273	3500	1536
6853	3501	3281
6853	3501	7757
6853	3501	7264
6853	3501	8552
6853	3501	7949
6853	3501	3371
6853	3501	9996
6853	3501	3648
6853	3501	848
6189	3502	4230
6189	3502	1453
6189	3502	6780
6189	3502	9192
6189	3502	950
6189	3502	9371
13268	3503	691
13268	3503	7365
13268	3503	3958
15210	3504	6241
15210	3504	829
15210	3504	6496
15210	3504	1586
15210	3504	824
15210	3504	9276
15210	3504	8737
16215	3505	4741
16215	3505	8451
16215	3505	8396
16215	3505	9494
16215	3505	3176
16215	3505	9957
12396	3506	7212
12396	3506	2
12396	3506	1240
12396	3506	7162
12396	3506	840
6652	3507	9519
6652	3507	4360
6652	3507	4177
6652	3507	3786
6652	3507	5108
6652	3507	50
6652	3507	3656
6652	3507	1262
6652	3507	9107
18217	3508	9934
18217	3508	5499
18217	3508	329
18217	3508	4099
18217	3508	5910
539	3509	3025
539	3509	926
539	3509	2334
539	3509	3196
539	3509	5140
539	3509	6440
539	3509	2931
402	3510	4632
402	3510	4061
402	3510	6902
5622	3511	3081
5622	3511	9628
5622	3511	8737
2140	3512	7059
2140	3512	1890
2140	3512	915
2140	3512	3680
2140	3512	5022
2140	3512	7557
2140	3512	9509
12820	3513	9221
12820	3513	6280
12820	3513	4918
12820	3513	8406
5285	3514	75
5285	3514	4658
5285	3514	5280
5285	3514	6786
5285	3514	9841
5285	3514	7805
5285	3514	1459
5285	3514	9015
17583	3515	346
17583	3515	5245
17583	3515	2166
17253	3516	6616
17253	3516	5424
17253	3516	8332
17253	3516	6845
13369	3517	4081
13369	3517	4780
13369	3517	4455
13369	3517	1887
13369	3517	1446
13369	3517	692
13369	3517	7495
12824	3518	54
12824	3518	3000
12824	3518	9371
12824	3518	6180
12824	3518	6449
12824	3518	2900
13961	3519	76
13961	3519	6590
13961	3519	641
13961	3519	4194
13961	3519	4725
13961	3519	4190
13961	3519	8101
13961	3519	1698
9394	3520	6029
9394	3520	9357
9394	3520	5650
17916	3521	7046
17916	3521	3810
17916	3521	1273
17916	3521	1669
17916	3521	5783
17916	3521	7155
17916	3521	1458
6310	3522	7852
6310	3522	2556
6310	3522	6847
6310	3522	6358
6310	3522	4167
6310	3522	1455
6310	3522	9809
6310	3522	2713
6310	3522	2134
7606	3523	196
7606	3523	3824
7606	3523	1862
7606	3523	4808
5319	3524	6540
5319	3524	3348
15029	3525	916
15029	3525	1604
15029	3525	8530
13196	3526	450
13196	3526	3672
13196	3526	9390
13196	3526	3742
13196	3526	804
13196	3526	6857
13196	3526	4061
14817	3527	4923
14817	3527	7020
14817	3527	6307
14817	3527	9467
14161	3528	4146
14161	3528	7637
14161	3528	6158
14161	3528	3352
14161	3528	1223
14161	3528	2523
14161	3528	7265
14161	3528	1476
14161	3528	3991
17826	3529	4752
8436	3530	1299
8436	3530	1350
17973	3531	6012
17973	3531	9682
17973	3531	767
17973	3531	5315
17973	3531	8786
17973	3531	7562
17973	3531	4559
17973	3531	1690
17973	3531	1471
1117	3532	2007
1117	3532	1243
1117	3532	7401
1117	3532	2343
1117	3532	4651
1117	3532	7275
1117	3532	5589
1117	3532	6536
1117	3532	6073
7268	3533	4640
7268	3533	5975
7268	3533	6228
13771	3534	8842
13771	3534	2031
13771	3534	781
13771	3534	6904
13771	3534	2728
13771	3534	9763
13771	3534	2219
13771	3534	9220
13824	3535	9164
13824	3535	9504
13824	3535	2675
13824	3535	306
13824	3535	2616
13824	3535	8017
13824	3535	888
13824	3535	7699
13824	3535	4421
14296	3536	5465
14296	3536	3159
14296	3536	9290
14296	3536	1596
14296	3536	4495
14296	3536	7779
14296	3536	5896
12402	3537	1177
12402	3537	3803
12402	3537	7859
4558	3538	9427
9781	3539	9574
2338	3540	1928
15646	3541	4024
15646	3541	6197
15646	3541	2220
15646	3541	7264
1991	3542	1827
1991	3542	2484
1991	3542	6673
1991	3542	369
1991	3542	3532
1991	3542	7416
1991	3542	6121
485	3543	4094
485	3543	3099
485	3543	6389
485	3543	288
485	3543	5396
485	3543	4647
485	3543	9390
485	3543	9534
12414	3544	2454
12414	3544	2357
12414	3544	3682
12414	3544	9212
12414	3544	8719
12414	3544	6448
19092	3545	4864
19092	3545	7606
19092	3545	5177
19092	3545	8011
15088	3546	3751
15088	3546	1076
15088	3546	442
15088	3546	6073
15088	3546	1909
1254	3547	3439
1254	3547	7875
1254	3547	3181
1254	3547	9929
1254	3547	2998
1254	3547	3039
1254	3547	9671
1254	3547	8551
4604	3548	8506
4604	3548	987
4604	3548	7349
4604	3548	9863
4604	3548	3522
4604	3548	7560
4604	3548	751
7864	3549	4718
7864	3549	8534
7864	3549	2177
7864	3549	9521
12002	3550	3556
12002	3550	322
12002	3550	6113
12002	3550	7438
12002	3550	6901
12002	3550	7499
12002	3550	7920
2841	3551	4850
2841	3551	9236
2841	3551	4656
2841	3551	1588
2841	3551	2140
2841	3551	178
2841	3551	2997
2841	3551	6703
5631	3552	8791
5631	3552	6673
5631	3552	2350
5631	3552	4539
5631	3552	6014
5631	3552	310
19091	3553	958
19091	3553	2451
19091	3553	1734
19091	3553	8266
19091	3553	6361
19091	3553	8050
19091	3553	7784
19091	3553	350
14046	3554	1616
14046	3554	1521
14046	3554	4120
14046	3554	8492
14046	3554	1376
14046	3554	6012
14046	3554	8570
14046	3554	5430
14046	3554	1090
14900	3555	2087
14900	3555	2121
14900	3555	3019
11761	3556	3281
14800	3557	5138
14800	3557	9931
14800	3557	5382
14800	3557	9611
14800	3557	8804
14800	3557	4505
14800	3557	8150
471	3558	2672
471	3558	8089
471	3558	8511
471	3558	3205
471	3558	6259
471	3558	9191
471	3558	9102
471	3558	982
471	3558	5477
10173	3559	5786
10173	3559	174
10173	3559	4847
10173	3559	4171
10173	3559	6136
10173	3559	7089
11197	3560	7389
11197	3560	4084
6371	3561	2218
6371	3561	2175
6371	3561	1469
6371	3561	6087
6371	3561	1028
6371	3561	1191
10722	3562	2204
10722	3562	3715
10722	3562	3019
10722	3562	3353
10722	3562	1248
10722	3562	6987
10722	3562	622
10722	3562	1887
10722	3562	4276
11490	3563	3000
11490	3563	4936
11490	3563	312
11490	3563	9551
11490	3563	7780
11490	3563	8065
11490	3563	2930
11490	3563	5846
14188	3564	3171
14188	3564	6372
14188	3564	7178
14188	3564	9119
14188	3564	6393
14188	3564	8442
14188	3564	6965
14188	3564	3582
6265	3565	4887
6265	3565	941
6265	3565	7068
6265	3565	4098
6265	3565	3881
6265	3565	7037
6265	3565	2155
6265	3565	2108
6265	3565	4056
896	3566	9840
896	3566	918
896	3566	7995
896	3566	6553
896	3566	2032
896	3566	1899
896	3566	9255
6704	3567	1167
6704	3567	691
6704	3567	7970
6704	3567	2653
3503	3568	9292
3503	3568	8495
3503	3568	5733
3503	3568	2795
3503	3568	2404
3503	3568	3724
3503	3568	7799
15116	3569	1198
3777	3570	4687
3777	3570	5350
3777	3570	5222
9028	3571	4723
9028	3571	1471
9028	3571	8153
9028	3571	2343
9028	3571	8176
2888	3572	2237
2888	3572	8682
18999	3573	2970
18999	3573	4182
18999	3573	4088
18999	3573	2706
18999	3573	5650
14240	3574	994
14240	3574	118
14240	3574	7430
14240	3574	613
14240	3574	6157
14240	3574	4026
14240	3574	441
14240	3574	4337
14614	3575	5499
14614	3575	5131
14614	3575	5930
14614	3575	5633
14614	3575	7900
17787	3576	8063
17787	3576	9350
17787	3576	423
17787	3576	1525
3929	3577	3320
3929	3577	1987
3929	3577	4005
3929	3577	2648
3929	3577	5690
2643	3578	1899
2643	3578	6709
2643	3578	3234
2643	3578	5059
2643	3578	3446
2643	3578	8089
2643	3578	9930
2643	3578	6934
506	3579	1193
506	3579	2584
506	3579	1869
506	3579	2418
506	3579	9595
2986	3580	1257
2986	3580	1078
2986	3580	1686
2986	3580	1796
2986	3580	9492
2986	3580	8205
2634	3581	6416
2634	3581	2378
2634	3581	1711
2634	3581	7272
2634	3581	6031
2634	3581	1141
2634	3581	8359
2634	3581	1937
2634	3581	6112
15595	3582	7571
15595	3582	9452
15595	3582	3454
15595	3582	7093
15595	3582	10
15595	3582	8002
15595	3582	2507
19557	3583	6645
19557	3583	8295
19557	3583	1990
16203	3584	5899
6939	3585	9245
6939	3585	8091
6939	3585	1396
6939	3585	9845
6939	3585	487
6939	3585	9110
6939	3585	2129
17546	3586	3776
17546	3586	8311
17546	3586	8021
17546	3586	8943
17546	3586	2339
17546	3586	7389
17546	3586	4942
17546	3586	1414
5619	3587	2207
5619	3587	5165
5619	3587	8739
17048	3588	6604
17048	3588	2115
270	3589	4054
270	3589	4395
270	3589	8959
270	3589	8075
270	3589	2368
270	3589	3182
270	3589	3859
18048	3590	6317
18048	3590	2381
18048	3590	3167
18048	3590	2225
920	3591	7638
4065	3592	1368
4065	3592	8509
4065	3592	32
4065	3592	7235
4065	3592	7079
4065	3592	2914
4065	3592	6210
4065	3592	4756
15845	3593	3204
15845	3593	4297
15845	3593	1840
15845	3593	8090
18003	3594	7988
18003	3594	9070
18003	3594	9352
18003	3594	1909
18003	3594	8658
9733	3595	3456
9733	3595	2892
9733	3595	9502
9733	3595	2501
9733	3595	4715
5609	3596	1806
5609	3596	5032
5609	3596	2172
5609	3596	7812
5609	3596	406
5609	3596	7954
5609	3596	4543
5609	3596	3930
5609	3596	3137
12056	3597	2123
12056	3597	7558
12056	3597	5254
12056	3597	9642
2895	3598	1241
2895	3598	2120
2895	3598	8815
2895	3598	8773
2895	3598	1589
2895	3598	4935
2895	3598	1909
2895	3598	2902
2632	3599	2230
2632	3599	3059
2632	3599	773
2632	3599	8093
2632	3599	4148
2632	3599	1778
7795	3600	6423
7795	3600	6085
7795	3600	6527
7795	3600	3528
7795	3600	9090
7795	3600	4601
7795	3600	7746
7795	3600	9410
7795	3600	2011
5566	3601	6542
5566	3601	8763
5566	3601	4705
5566	3601	2217
5566	3601	8584
9337	3602	5688
9337	3602	7317
9337	3602	6608
9337	3602	7966
9337	3602	6445
9337	3602	4328
9337	3602	9844
9337	3602	1238
15560	3603	6100
15560	3603	5364
15560	3603	8180
15560	3603	6956
15560	3603	8616
15560	3603	9419
13472	3604	8654
10196	3605	3553
10196	3605	856
10196	3605	9277
10196	3605	2571
10196	3605	4288
10196	3605	2641
10196	3605	6986
10196	3605	3600
10196	3605	1357
1551	3606	7511
1551	3606	1719
12924	3607	5533
12924	3607	1329
12924	3607	9606
12924	3607	4578
12924	3607	4211
12924	3607	846
12924	3607	8518
4233	3608	4332
4233	3608	9803
4233	3608	645
4233	3608	6448
4233	3608	3478
4233	3608	8825
4233	3608	6156
4233	3608	9556
4233	3608	745
10644	3609	4188
10644	3609	9151
10644	3609	13
3567	3610	1100
3567	3610	1
3567	3610	2966
3567	3610	4108
3567	3610	5539
3567	3610	1184
3567	3610	7290
3567	3610	9178
3567	3610	9901
2475	3611	3420
2475	3611	247
2475	3611	5537
2475	3611	5216
2475	3611	4219
2475	3611	7037
2475	3611	8060
4334	3612	5099
4334	3612	7900
4334	3612	8368
4334	3612	422
4334	3612	4343
4334	3612	9505
5848	3613	6357
5848	3613	6633
1703	3614	5070
1703	3614	6582
1703	3614	8113
1703	3614	1943
1703	3614	656
1703	3614	5600
12042	3615	9798
12042	3615	5169
15580	3616	5948
15580	3616	7647
15580	3616	167
15580	3616	2070
15580	3616	1479
15580	3616	973
5831	3617	2757
5831	3617	1358
5831	3617	4423
8441	3618	5337
8441	3618	3895
8441	3618	1234
8441	3618	7335
8441	3618	5332
8441	3618	4413
11784	3619	5483
11784	3619	6626
11784	3619	67
11784	3619	6688
2220	3620	5330
2220	3620	6100
2220	3620	672
2220	3620	8687
2220	3620	9835
2220	3620	786
2220	3620	3523
2220	3620	2568
2220	3620	1091
13147	3621	4859
13147	3621	5978
13147	3621	7844
13147	3621	2656
13147	3621	5030
13147	3621	3427
8198	3622	6005
8198	3622	3361
8198	3622	6124
8198	3622	1989
8198	3622	3143
8198	3622	7312
8198	3622	9653
9023	3623	6058
9023	3623	722
9023	3623	5843
9023	3623	6699
9023	3623	6880
9023	3623	3368
18744	3624	6163
18744	3624	2934
18744	3624	3774
18744	3624	1231
18744	3624	9188
18744	3624	4751
9670	3625	2763
9670	3625	165
13726	3626	2215
13726	3626	5935
13726	3626	614
13726	3626	956
13726	3626	9977
13726	3626	4927
13726	3626	9965
13726	3626	4836
19172	3627	4421
19172	3627	3885
19172	3627	7931
17968	3628	6917
17968	3628	4904
17968	3628	8031
17968	3628	7745
15441	3629	1471
15441	3629	3375
15441	3629	1992
15441	3629	5892
15441	3629	2847
15441	3629	2667
15441	3629	7495
6566	3630	6945
6566	3630	4816
5692	3631	1832
5692	3631	4813
5692	3631	6875
5692	3631	7547
5692	3631	2589
5692	3631	664
5692	3631	9576
4485	3632	2840
4485	3632	9569
4485	3632	2711
4485	3632	8918
4485	3632	8360
4485	3632	372
4407	3633	6911
8913	3634	3994
8913	3634	7521
8913	3634	6680
8913	3634	5811
8913	3634	2597
8913	3634	7941
8913	3634	1072
8913	3634	8677
8913	3634	8177
17096	3635	752
17096	3635	3783
17096	3635	398
17096	3635	2118
12223	3636	9681
12223	3636	3108
12223	3636	9673
12223	3636	4142
12223	3636	7869
12223	3636	8264
12223	3636	5202
6914	3637	7070
6914	3637	4486
6914	3637	3402
6914	3637	1087
6914	3637	7786
6914	3637	1631
2622	3638	6802
1887	3639	6157
1887	3639	384
1887	3639	8600
1887	3639	4815
3768	3640	2736
3768	3640	9677
3768	3640	8249
3768	3640	4186
3768	3640	1321
15862	3641	4213
15862	3641	8936
15862	3641	1420
15862	3641	268
15862	3641	6451
15862	3641	5769
15862	3641	2456
15862	3641	3149
11769	3642	9707
7784	3643	5237
7784	3643	7261
7784	3643	1823
7784	3643	4429
7784	3643	9582
7784	3643	5851
7784	3643	7651
7784	3643	8717
7784	3643	3566
13429	3644	2599
4610	3645	6197
4610	3645	8253
4610	3645	6698
4610	3645	8281
4610	3645	6988
4610	3645	9280
4610	3645	8558
4610	3645	6418
4610	3645	7431
1993	3646	7711
1993	3646	9490
1993	3646	6726
1993	3646	2615
1993	3646	9326
1993	3646	9821
1993	3646	245
1993	3646	3093
1993	3646	5039
8636	3647	9448
8636	3647	6001
8636	3647	8201
8636	3647	7875
8636	3647	4751
8636	3647	3766
8636	3647	5895
8636	3647	4643
8636	3647	7445
14529	3648	3783
14529	3648	6089
14529	3648	4719
14529	3648	3140
14529	3648	7116
14529	3648	4433
14529	3648	9466
14681	3649	2926
14681	3649	7735
14681	3649	1395
14681	3649	7330
9298	3650	2213
9298	3650	2533
9298	3650	8708
9298	3650	5626
9298	3650	8618
9298	3650	4434
9298	3650	5858
9298	3650	5683
5642	3651	3725
5642	3651	2985
5642	3651	8209
5642	3651	3959
124	3652	9948
124	3652	5477
124	3652	2231
124	3652	502
124	3652	3843
124	3652	3899
124	3652	8833
143	3653	4236
143	3653	8229
143	3653	1245
10405	3654	5265
10405	3654	9671
10405	3654	8419
1300	3655	1498
1300	3655	9303
1300	3655	9791
1300	3655	4977
14756	3656	3504
14756	3656	9663
14756	3656	1155
4293	3657	5586
4293	3657	426
4293	3657	4511
4293	3657	4655
4293	3657	8661
15926	3658	6098
8608	3659	6746
8608	3659	5938
14185	3660	9239
14185	3660	7316
15483	3661	2034
15483	3661	7930
15483	3661	9635
15483	3661	8658
15483	3661	9419
15483	3661	7706
15483	3661	9059
11609	3662	2213
11609	3662	8400
15276	3663	2462
2581	3664	4773
8815	3665	5590
8815	3665	4463
8815	3665	9222
8815	3665	4902
8815	3665	9325
8815	3665	5898
8815	3665	5078
8815	3665	7354
8815	3665	1935
8794	3666	5688
8794	3666	7602
8794	3666	4060
8794	3666	4868
8794	3666	8360
8794	3666	4785
8794	3666	3752
17307	3667	2567
17307	3667	7205
17307	3667	8793
17307	3667	5987
17307	3667	1026
17307	3667	5124
1622	3668	1271
1622	3668	8410
1622	3668	225
1622	3668	6595
1622	3668	9592
1622	3668	9015
1622	3668	8999
1622	3668	1602
1622	3668	2107
1798	3669	1626
1798	3669	106
1798	3669	3657
1798	3669	7561
1798	3669	2018
854	3670	7197
13575	3671	2721
13575	3671	2481
13575	3671	2475
13575	3671	3128
13575	3671	5487
14225	3672	3863
14225	3672	9246
14225	3672	4648
14225	3672	255
14225	3672	1691
14225	3672	6114
14225	3672	6789
17398	3673	9608
17398	3673	2716
17398	3673	3905
17398	3673	3767
17398	3673	2336
17398	3673	6504
17398	3673	7631
17398	3673	7757
4810	3674	7674
4810	3674	7268
8112	3675	2755
8112	3675	2784
8112	3675	1907
8112	3675	4445
16422	3676	8857
16422	3676	6897
16422	3676	2071
16422	3676	3364
3006	3677	1333
3006	3677	8519
3006	3677	7226
3006	3677	4438
3006	3677	6863
17538	3678	4580
17538	3678	4998
17538	3678	7743
17538	3678	1487
17538	3678	342
17538	3678	9293
17538	3678	7417
6639	3679	6489
6639	3679	6589
6639	3679	3874
6639	3679	3695
6639	3679	8248
6639	3679	9505
8169	3680	3866
8169	3680	1678
8169	3680	7414
8169	3680	8910
8169	3680	5724
8169	3680	3059
8169	3680	9647
8169	3680	7471
8119	3681	5086
8119	3681	8353
8119	3681	9583
8119	3681	4303
8119	3681	1942
8119	3681	231
8119	3681	2110
19048	3682	6231
18577	3683	3430
18577	3683	2177
18577	3683	2110
18577	3683	4790
18577	3683	5572
18577	3683	530
9664	3684	4167
9664	3684	8747
9664	3684	9700
7253	3685	3277
7253	3685	1319
9497	3686	1922
9497	3686	6616
9497	3686	1213
9497	3686	9853
9497	3686	7341
9803	3687	2693
4786	3688	6019
4786	3688	4847
4786	3688	8788
2398	3689	5788
2398	3689	9075
2398	3689	9545
2398	3689	4590
2398	3689	2029
17204	3690	9343
17204	3690	6576
17204	3690	1916
17204	3690	9175
8043	3691	187
2200	3692	3935
2200	3692	9612
2200	3692	4800
2200	3692	2876
2200	3692	6131
2200	3692	5430
2200	3692	7162
7475	3693	2756
7475	3693	2336
7475	3693	4327
7475	3693	4414
11669	3694	3044
11669	3694	9898
11669	3694	3027
11669	3694	6857
11669	3694	1525
13910	3695	1727
13910	3695	9926
13910	3695	2834
13910	3695	3163
13910	3695	6872
13910	3695	4735
9362	3696	66
9362	3696	7163
9362	3696	2817
9362	3696	4660
9362	3696	6091
9362	3696	2660
9362	3696	3140
9733	3697	7724
9733	3697	3910
1563	3698	2066
1563	3698	4461
1563	3698	7993
1563	3698	9348
1563	3698	4489
1563	3698	5344
1563	3698	1838
1563	3698	5333
1563	3698	6552
15710	3699	9084
5987	3700	3775
5987	3700	4847
5987	3700	699
5987	3700	5026
5987	3700	3833
16642	3701	7469
16642	3701	626
16642	3701	2872
16642	3701	1274
16642	3701	5032
16642	3701	6124
16642	3701	5674
16642	3701	7109
16642	3701	1213
12119	3702	5367
12119	3702	7333
12119	3702	6123
12119	3702	7520
12119	3702	371
12119	3702	1034
12119	3702	7790
12119	3702	8172
6407	3703	7319
6407	3703	2150
6407	3703	6969
6407	3703	5310
6407	3703	9422
6407	3703	3552
1769	3704	2064
1769	3704	2565
1769	3704	6493
1769	3704	3430
1769	3704	7502
1769	3704	3346
1769	3704	4805
1769	3704	3387
1769	3704	6370
6676	3705	8249
6676	3705	3893
15351	3706	7581
15351	3706	8600
15351	3706	7182
15351	3706	3742
15351	3706	9375
15351	3706	2212
15351	3706	8626
4024	3707	7549
4024	3707	9448
4024	3707	7546
4024	3707	4768
4024	3707	9497
4024	3707	9113
13386	3708	6837
13386	3708	8662
13386	3708	4721
13386	3708	1821
892	3709	2458
12	3710	6453
12	3710	3751
12	3710	7755
12	3710	9097
12	3710	5428
12	3710	3560
793	3711	975
793	3711	4335
793	3711	8119
793	3711	3241
793	3711	5589
793	3711	5151
7845	3712	240
7845	3712	3378
4949	3713	6542
8356	3714	477
8356	3714	682
8356	3714	2587
8356	3714	9902
8356	3714	865
8356	3714	1526
8356	3714	7685
8356	3714	9938
8356	3714	9387
5527	3715	5238
5527	3715	3852
5527	3715	1454
543	3716	63
543	3716	1244
543	3716	5857
543	3716	8478
543	3716	6636
543	3716	2737
5349	3717	2852
5349	3717	9382
5349	3717	1364
5349	3717	4056
5349	3717	6398
5349	3717	2096
16943	3718	5528
16943	3718	8493
16943	3718	1176
16943	3718	8105
16943	3718	6973
16943	3718	2131
4767	3719	569
4767	3719	7390
4767	3719	4824
4767	3719	7148
4767	3719	6955
4767	3719	3576
4726	3720	2394
4726	3720	4627
4726	3720	4040
2023	3721	5216
2023	3721	5894
2023	3721	3456
2023	3721	6243
2131	3722	2287
2131	3722	4787
2131	3722	1980
2131	3722	8225
2131	3722	5745
742	3723	3103
742	3723	2677
15785	3724	3931
15785	3724	1435
15785	3724	8065
15785	3724	1238
15785	3724	5374
320	3725	2662
320	3725	2136
19523	3726	1427
19523	3726	7984
19523	3726	8555
4636	3727	9538
4636	3727	6098
4636	3727	3298
4636	3727	7957
4636	3727	861
4636	3727	8831
2985	3728	9898
2985	3728	1034
4919	3729	6562
4919	3729	3550
4919	3729	1426
4919	3729	4482
4919	3729	9052
4919	3729	8564
13042	3730	4078
13042	3730	9022
13042	3730	1343
13042	3730	4486
13042	3730	2967
13042	3730	9915
13042	3730	7979
13042	3730	7959
3017	3731	7092
12286	3732	8493
19025	3733	9363
19025	3733	4339
17649	3734	4343
17649	3734	5182
17649	3734	2328
17649	3734	6861
19914	3735	7534
19914	3735	7883
12750	3736	5887
12750	3736	3562
12750	3736	472
2433	3737	4928
2433	3737	9762
2433	3737	3389
2433	3737	3249
2433	3737	3992
2433	3737	206
2433	3737	9638
2433	3737	1759
14298	3738	9586
14298	3738	1795
14298	3738	5032
14298	3738	1048
14298	3738	3483
16819	3739	8519
16819	3739	739
16819	3739	2477
16819	3739	9665
16819	3739	1625
16819	3739	422
16819	3739	6822
16819	3739	532
235	3740	3266
8626	3741	2085
8626	3741	4993
8626	3741	4052
8626	3741	3152
8626	3741	5278
8626	3741	9521
2291	3742	4528
2291	3742	2583
2291	3742	1780
2291	3742	5177
2291	3742	2458
2291	3742	7806
2291	3742	2755
2291	3742	2143
14270	3743	646
14270	3743	8566
14270	3743	4543
14270	3743	865
10216	3744	6173
10216	3744	8819
10216	3744	5790
10216	3744	230
16070	3745	2355
16070	3745	32
16070	3745	3084
16070	3745	5853
16070	3745	4710
18505	3746	2106
7380	3747	7857
7380	3747	9748
19954	3748	8012
733	3749	2444
733	3749	1767
733	3749	8460
733	3749	2715
733	3749	5729
733	3749	8627
8500	3750	6046
8500	3750	6766
8500	3750	3026
9840	3751	620
9840	3751	4147
9840	3751	7736
9840	3751	7000
10919	3752	3571
10919	3752	2822
10919	3752	9543
10919	3752	6447
10919	3752	2228
10919	3752	446
10919	3752	8284
8107	3753	7834
8107	3753	1656
8107	3753	1279
8107	3753	8571
8107	3753	8894
8107	3753	3738
8107	3753	1060
8107	3753	6582
8107	3753	9505
11901	3754	8442
11901	3754	4878
11901	3754	1106
11901	3754	779
11901	3754	8839
11901	3754	8508
19572	3755	8065
19572	3755	2619
19572	3755	3652
19572	3755	9110
19572	3755	7559
19572	3755	6357
19572	3755	4564
19572	3755	7101
19572	3755	1180
4570	3756	1782
578	3757	75
578	3757	8875
578	3757	8922
578	3757	9941
578	3757	5171
578	3757	2807
578	3757	7664
578	3757	3945
578	3757	2708
7773	3758	6172
7773	3758	5471
7773	3758	3712
7773	3758	8242
7773	3758	4305
6357	3759	4672
6357	3759	5606
6357	3759	5447
6220	3760	5337
6220	3760	7562
6220	3760	4168
6220	3760	5531
6220	3760	4533
6220	3760	8293
13069	3761	4851
13069	3761	3076
13069	3761	9356
13069	3761	7703
13069	3761	7589
13069	3761	3373
13069	3761	6258
13069	3761	6677
13069	3761	1229
10793	3762	5736
10793	3762	8696
10793	3762	7600
10793	3762	562
10793	3762	4187
10793	3762	6137
10793	3762	6719
8842	3763	7570
8842	3763	2758
8842	3763	4773
12002	3764	1398
12002	3764	5279
12002	3764	7850
12002	3764	1161
12002	3764	8263
12002	3764	5263
12002	3764	7135
7707	3765	8274
7707	3765	7316
7707	3765	1168
7707	3765	9671
7707	3765	9508
6359	3766	1675
6359	3766	472
6359	3766	1930
6359	3766	4974
472	3767	1634
17048	3768	5867
17048	3768	8459
17048	3768	4458
7931	3769	7145
7931	3769	8255
7931	3769	3854
7931	3769	8343
7931	3769	358
7422	3770	4200
7422	3770	967
7422	3770	3711
7422	3770	1156
7422	3770	2420
7422	3770	6611
7422	3770	7744
7422	3770	843
15976	3771	6807
15976	3771	1482
15976	3771	6501
4952	3772	1092
4952	3772	7205
1829	3773	491
1829	3773	9060
1829	3773	9390
1829	3773	6687
1829	3773	7769
1829	3773	8220
1829	3773	3945
1829	3773	5350
1829	3773	176
17282	3774	659
17282	3774	2563
17282	3774	7475
15133	3775	79
15133	3775	6370
15133	3775	6160
15133	3775	9700
15133	3775	4246
15133	3775	8560
15133	3775	2945
15133	3775	3615
15133	3775	5759
169	3776	5502
169	3776	283
169	3776	7108
14809	3777	6761
5842	3778	6850
5842	3778	7706
5842	3778	190
5842	3778	9318
5842	3778	3771
5842	3778	4684
5842	3778	5162
5842	3778	7952
5842	3778	4632
3478	3779	9143
3478	3779	4800
3478	3779	322
3478	3779	8825
11348	3780	1083
11348	3780	3031
11348	3780	4073
17513	3781	7133
3528	3782	3503
3528	3782	9118
3528	3782	1435
3528	3782	8549
3528	3782	8804
6954	3783	5857
6954	3783	180
6954	3783	4531
6954	3783	5689
6954	3783	3009
6954	3783	646
6954	3783	8306
6954	3783	1905
6954	3783	6884
12002	3784	9918
12002	3784	5827
12002	3784	3974
12002	3784	2198
16108	3785	6942
16108	3785	4
16108	3785	5689
16108	3785	652
16108	3785	3152
16108	3785	8280
10328	3786	1165
10328	3786	2485
10328	3786	5115
10328	3786	9803
10328	3786	3971
10328	3786	6110
10328	3786	54
10328	3786	5294
10593	3787	8308
10593	3787	4963
10593	3787	9232
10593	3787	6516
10593	3787	8407
10593	3787	3427
10593	3787	5492
10593	3787	654
911	3788	2455
911	3788	7736
911	3788	3064
911	3788	9502
911	3788	8325
911	3788	4633
911	3788	9401
911	3788	8092
9213	3789	1584
9213	3789	817
2940	3790	1925
2940	3790	5398
2940	3790	3179
2940	3790	6888
2940	3790	6161
2940	3790	2247
2940	3790	5515
9831	3791	3549
9831	3791	3815
9831	3791	560
9831	3791	4264
9831	3791	2475
9831	3791	2846
9831	3791	4451
9831	3791	7532
9831	3791	9150
12074	3792	2426
12074	3792	3627
12074	3792	6078
12074	3792	2856
12074	3792	3953
12074	3792	1867
12074	3792	3597
12074	3792	3167
12074	3792	3802
13293	3793	1417
13293	3793	9405
13293	3793	4038
13293	3793	6603
13293	3793	1527
13293	3793	188
13293	3793	6968
13293	3793	9898
13293	3793	8819
1370	3794	3111
1370	3794	7683
1370	3794	426
1370	3794	3558
1370	3794	2345
1370	3794	9549
1370	3794	5540
1370	3794	4135
1370	3794	4576
9526	3795	1029
9526	3795	7961
9526	3795	4562
9526	3795	532
9526	3795	4010
9526	3795	964
9526	3795	554
9526	3795	4481
13650	3796	8574
13650	3796	744
13650	3796	6768
13650	3796	8369
13650	3796	82
13650	3796	6076
13650	3796	9894
8910	3797	635
8910	3797	5131
11367	3798	9794
11367	3798	5231
11367	3798	7756
11367	3798	3504
11367	3798	6513
11367	3798	3819
11367	3798	8208
11367	3798	4063
7912	3799	8411
7912	3799	7456
7912	3799	8776
7912	3799	643
7912	3799	8270
7912	3799	1107
12675	3800	142
12675	3800	482
8599	3801	8200
8599	3801	3206
8599	3801	9554
8599	3801	9177
8599	3801	8066
8599	3801	7009
8599	3801	9219
8599	3801	9542
8599	3801	1282
11018	3802	7491
11018	3802	2937
11018	3802	3783
10635	3803	915
937	3804	8433
937	3804	9489
937	3804	2212
3507	3805	2402
3507	3805	9884
3507	3805	4236
3507	3805	6517
598	3806	5617
598	3806	8088
598	3806	9180
598	3806	7000
598	3806	4623
598	3806	1854
598	3806	874
7934	3807	8343
7934	3807	755
7934	3807	7608
7934	3807	5601
7934	3807	2162
7934	3807	4424
7934	3807	8565
7934	3807	6385
7934	3807	6571
7141	3808	9003
7141	3808	7153
7141	3808	7966
7566	3809	2003
7566	3809	412
12024	3810	6959
12024	3810	9872
12024	3810	8197
12024	3810	2174
12024	3810	1820
12024	3810	8338
12024	3810	3634
1573	3811	757
1573	3811	9516
1573	3811	3245
1573	3811	9472
1573	3811	1128
1573	3811	9668
13252	3812	2148
8644	3813	4915
8644	3813	2895
8644	3813	1662
8644	3813	9335
8644	3813	6395
8644	3813	9938
8644	3813	9827
8644	3813	7428
8644	3813	6838
13011	3814	3132
13011	3814	5526
13011	3814	7654
13011	3814	9601
13011	3814	1761
9310	3815	5317
9310	3815	8497
9310	3815	2487
9310	3815	7621
9310	3815	1616
9310	3815	1612
9310	3815	3604
9310	3815	4959
9310	3815	9679
10409	3816	7938
10409	3816	4749
5413	3817	2325
1642	3818	9255
1642	3818	7743
1642	3818	4048
1642	3818	9323
1642	3818	4460
8277	3819	9343
8277	3819	9246
8277	3819	8707
8277	3819	6979
8277	3819	6701
8277	3819	6735
8277	3819	1001
8277	3819	9847
18201	3820	9970
18201	3820	2204
18201	3820	3080
15507	3821	5887
15507	3821	1679
15507	3821	7425
15507	3821	9126
15507	3821	6574
15507	3821	5736
13474	3822	9117
13474	3822	3798
13474	3822	942
13474	3822	5925
13474	3822	3059
13262	3823	2572
8501	3824	4635
8501	3824	2584
8501	3824	2726
8501	3824	4518
8501	3824	5056
8501	3824	2274
8501	3824	5596
8501	3824	4669
1188	3825	9598
1188	3825	9528
1188	3825	102
1713	3826	9036
1713	3826	3673
1713	3826	2194
1713	3826	9938
1713	3826	3975
1713	3826	4214
1713	3826	9166
7669	3827	4428
7669	3827	5056
9167	3828	6683
9167	3828	6480
9167	3828	6150
9167	3828	4017
9167	3828	7135
9167	3828	6220
387	3829	6442
387	3829	6945
387	3829	5064
387	3829	920
387	3829	9322
387	3829	3517
387	3829	558
14481	3830	273
14481	3830	2461
14481	3830	9245
14481	3830	500
14481	3830	6667
14481	3830	5658
14481	3830	555
14998	3831	790
14998	3831	4517
14998	3831	7754
14998	3831	4954
14998	3831	1929
10405	3832	4626
10405	3832	115
10405	3832	4420
10405	3832	9335
10405	3832	4034
10405	3832	9818
19559	3833	4805
19559	3833	9730
19559	3833	2988
19559	3833	7354
19559	3833	5795
19559	3833	3360
19559	3833	4484
19559	3833	7171
14570	3834	7899
14570	3834	6056
14570	3834	7305
14570	3834	6521
14570	3834	5653
913	3835	9777
913	3835	9559
10707	3836	6699
10707	3836	1495
10707	3836	5
10707	3836	1155
10707	3836	7013
10707	3836	5298
5204	3837	6998
5204	3837	6113
5204	3837	5049
5204	3837	1419
5204	3837	2068
5204	3837	1955
5204	3837	6331
6059	3838	6899
6059	3838	3790
1604	3839	3869
1604	3839	149
1604	3839	5596
1604	3839	7402
1604	3839	6489
1604	3839	9306
1604	3839	7276
18460	3840	7596
18460	3840	8245
18460	3840	7850
18460	3840	6124
18460	3840	3197
603	3841	8392
603	3841	9120
603	3841	3215
603	3841	5696
603	3841	8971
603	3841	7612
12993	3842	1712
12993	3842	8331
12993	3842	9930
12105	3843	4426
12105	3843	8597
12105	3843	6572
12105	3843	6415
12105	3843	976
12105	3843	2212
12105	3843	9333
12105	3843	1672
16091	3844	273
16091	3844	5976
16091	3844	5107
412	3845	8502
412	3845	2865
412	3845	6729
6287	3846	2773
6287	3846	1732
6287	3846	8522
6287	3846	9049
6287	3846	1449
3442	3847	324
3442	3847	736
3442	3847	2952
3442	3847	7711
3442	3847	9076
11610	3848	8948
11610	3848	7697
11610	3848	2478
1999	3849	6950
1999	3849	5361
1999	3849	6001
12649	3850	1432
12649	3850	4062
6274	3851	8942
6274	3851	1333
6274	3851	4870
6274	3851	9610
6274	3851	8457
6274	3851	8347
6274	3851	6306
6274	3851	5568
3135	3852	7892
3135	3852	3101
14324	3853	299
14324	3853	7950
14324	3853	7916
14324	3853	7130
14324	3853	8312
14324	3853	132
14324	3853	173
14324	3853	8056
14324	3853	3774
9745	3854	6605
9745	3854	3218
9745	3854	2406
1744	3855	9057
1744	3855	6406
1744	3855	8805
1744	3855	9757
1744	3855	274
1744	3855	3884
1744	3855	8367
4280	3856	7013
4280	3856	7878
4280	3856	3835
4280	3856	3322
4280	3856	3418
9982	3857	4514
9982	3857	3140
9982	3857	7293
9982	3857	434
9982	3857	2784
9982	3857	8013
9874	3858	6
9874	3858	2570
12808	3859	2644
12808	3859	7428
12808	3859	7388
12808	3859	5923
12808	3859	8538
12808	3859	5219
12808	3859	1959
9485	3860	5893
9485	3860	6346
12701	3861	4234
6426	3862	5610
6426	3862	9415
6426	3862	2849
6426	3862	4898
6426	3862	4400
6426	3862	7217
6426	3862	5769
6426	3862	1101
6426	3862	2022
16733	3863	4717
17902	3864	2164
17902	3864	7292
17902	3864	7770
17902	3864	770
17902	3864	2044
17902	3864	2004
17902	3864	5784
3104	3865	7290
3104	3865	896
3104	3865	221
3104	3865	9257
19747	3866	7506
19747	3866	1492
18523	3867	9879
18523	3867	260
18523	3867	9990
18523	3867	1103
18523	3867	7595
9768	3868	4136
9768	3868	4662
9768	3868	7948
9768	3868	3266
9768	3868	9182
9768	3868	7887
9768	3868	5569
14145	3869	619
14145	3869	1696
14145	3869	2605
14145	3869	3401
14145	3869	3735
14145	3869	5083
14145	3869	7685
14145	3869	9534
14145	3869	2611
11752	3870	6647
11752	3870	9591
11752	3870	8913
11752	3870	9288
11752	3870	9338
11752	3870	1777
11752	3870	516
11752	3870	3832
11752	3870	4580
19326	3871	8881
19326	3871	4041
7555	3872	2696
4572	3873	1811
4572	3873	1752
4572	3873	5422
4572	3873	2183
4572	3873	7909
4572	3873	9853
7725	3874	5557
7725	3874	1294
7725	3874	2524
7725	3874	3375
7725	3874	2820
7725	3874	3904
7725	3874	8356
333	3875	1315
333	3875	2260
333	3875	7007
333	3875	9512
333	3875	2657
333	3875	722
333	3875	762
333	3875	5840
16726	3876	8253
16726	3876	5320
16726	3876	7718
16726	3876	2289
16726	3876	3841
16726	3876	3430
16726	3876	9006
16726	3876	8653
16726	3876	5858
17028	3877	3322
17028	3877	9872
17028	3877	4071
17028	3877	7524
11552	3878	7933
442	3879	8157
442	3879	2987
442	3879	7332
442	3879	3176
442	3879	9803
442	3879	1703
442	3879	9640
442	3879	3074
14289	3880	5669
14289	3880	7484
10832	3881	5637
10832	3881	2393
10832	3881	4835
10832	3881	956
10832	3881	7020
13645	3882	7880
13645	3882	2082
13645	3882	9329
13645	3882	8098
13645	3882	7974
13645	3882	4842
13645	3882	5232
423	3883	3404
423	3883	303
423	3883	7747
423	3883	406
423	3883	5389
423	3883	1588
18935	3884	421
18935	3884	1167
18935	3884	9299
18935	3884	2284
18935	3884	4598
10941	3885	1980
10941	3885	1892
10941	3885	9369
10941	3885	3539
10941	3885	4404
10941	3885	5535
10941	3885	4494
10941	3885	5459
10941	3885	3253
8840	3886	3560
8840	3886	8028
8840	3886	4196
8840	3886	3628
11214	3887	7888
11214	3887	8635
11214	3887	2195
11214	3887	355
11214	3887	9030
11214	3887	6082
11214	3887	4726
11214	3887	367
11214	3887	3755
14629	3888	5472
14629	3888	8809
11827	3889	4909
7087	3890	6581
7087	3890	2959
7087	3890	9224
7087	3890	98
7087	3890	8375
4259	3891	9444
4259	3891	7697
4259	3891	2312
4259	3891	4015
4259	3891	2419
4259	3891	488
7044	3892	8751
7044	3892	9710
7044	3892	3062
7044	3892	750
7044	3892	2882
12291	3893	2612
12291	3893	5524
12291	3893	5612
12291	3893	6815
12291	3893	7710
12291	3893	8347
12291	3893	6561
12291	3893	1719
939	3894	2179
939	3894	3639
939	3894	1104
939	3894	2052
939	3894	2666
10555	3895	5586
10555	3895	6939
10555	3895	9240
10555	3895	1633
10555	3895	2845
10555	3895	7248
10555	3895	5624
10555	3895	5033
10555	3895	6950
1177	3896	7109
1177	3896	4279
1177	3896	5495
1177	3896	5052
1177	3896	6960
1177	3896	9110
1177	3896	3037
1177	3896	8546
1177	3896	5936
6366	3897	5427
6366	3897	8991
6366	3897	8197
6366	3897	2964
6366	3897	6992
6366	3897	525
6366	3897	9846
6366	3897	9128
12174	3898	9986
12174	3898	2975
12174	3898	3240
12174	3898	9922
12174	3898	2092
15036	3899	9894
15036	3899	1015
15036	3899	3391
15036	3899	2929
5549	3900	7671
5549	3900	4491
5549	3900	75
5549	3900	1775
5549	3900	3007
5549	3900	1958
5549	3900	1114
5549	3900	8803
11327	3901	720
11327	3901	4318
14493	3902	21
14493	3902	5974
14493	3902	3409
14493	3902	896
14493	3902	4939
14493	3902	6532
14493	3902	7683
17593	3903	4496
17593	3903	5339
17593	3903	5568
17593	3903	4059
17593	3903	169
17593	3903	7132
17593	3903	9925
17593	3903	6153
17593	3903	4843
11477	3904	8408
11477	3904	9246
237	3905	9794
10264	3906	1190
2716	3907	9552
2716	3907	4445
2716	3907	5386
2716	3907	5266
2716	3907	5027
2716	3907	3049
2716	3907	7886
11902	3908	6555
11902	3908	3792
11902	3908	7338
11902	3908	1542
3408	3909	8997
3408	3909	3203
3408	3909	5141
3408	3909	2730
15512	3910	1190
15512	3910	5680
15512	3910	2554
15512	3910	5125
17832	3911	5859
17832	3911	6163
17832	3911	3618
17832	3911	3726
17832	3911	5485
17832	3911	6057
17832	3911	5518
11707	3912	9239
11707	3912	6351
11707	3912	8446
11707	3912	3009
11707	3912	8012
11707	3912	2486
11707	3912	942
11707	3912	299
11707	3912	8354
4159	3913	9008
4159	3913	9262
4159	3913	1374
4159	3913	379
4159	3913	42
4159	3913	5647
4159	3913	4534
4159	3913	5297
6617	3914	1693
3981	3915	5907
3981	3915	8923
3981	3915	683
3981	3915	5024
3981	3915	2456
3981	3915	237
3981	3915	4312
19918	3916	4051
19918	3916	4526
19918	3916	5275
19918	3916	1860
19918	3916	7166
19918	3916	8958
19918	3916	7194
12234	3917	4047
12234	3917	8736
12234	3917	8722
12234	3917	9336
12234	3917	9251
12234	3917	2992
12234	3917	8768
12234	3917	7887
6323	3918	128
18170	3919	3949
18170	3919	4276
18170	3919	8796
18170	3919	3574
18170	3919	4825
18170	3919	6503
18170	3919	5328
18170	3919	5945
9425	3920	8006
9425	3920	2721
9425	3920	4732
9425	3920	2510
9425	3920	1933
9425	3920	3856
9425	3920	4409
9425	3920	7131
9425	3920	6455
2558	3921	5439
2558	3921	2989
2558	3921	6643
2558	3921	6095
2558	3921	4220
2558	3921	6121
2558	3921	775
6568	3922	7689
6568	3922	7602
9464	3923	5435
9464	3923	6269
9464	3923	3272
9464	3923	6757
9464	3923	3090
18368	3924	3285
18368	3924	2081
18368	3924	2375
18368	3924	7343
18368	3924	3590
2383	3925	5924
2383	3925	2855
2383	3925	8465
2383	3925	9790
2383	3925	831
2383	3925	7997
2383	3925	9945
2383	3925	3104
12776	3926	447
12776	3926	8008
12776	3926	8169
12776	3926	2821
12776	3926	2789
12776	3926	5361
16432	3927	7339
16339	3928	2089
10385	3929	1581
10385	3929	9691
10385	3929	7814
10385	3929	9817
5275	3930	2588
5275	3930	796
1732	3931	726
1732	3931	2564
1732	3931	8968
1732	3931	3482
10360	3932	3749
10360	3932	3452
6537	3933	5906
6537	3933	783
6537	3933	9865
6537	3933	3460
6537	3933	2445
6537	3933	1315
6537	3933	7661
6537	3933	301
7564	3934	8962
7564	3934	9800
7564	3934	8808
7564	3934	4273
7564	3934	6520
7564	3934	6909
7564	3934	2842
7564	3934	919
8756	3935	3648
8756	3935	4885
10370	3936	8967
10370	3936	1723
10370	3936	129
10370	3936	639
9821	3937	6728
9821	3937	3720
9277	3938	9016
5327	3939	3972
5327	3939	2800
5327	3939	1003
5327	3939	4934
5327	3939	9695
5327	3939	4248
5327	3939	3999
2289	3940	5199
2289	3940	1539
7625	3941	5711
7625	3941	354
7625	3941	8306
7625	3941	6204
7625	3941	6233
7625	3941	2872
7625	3941	9932
8359	3942	3202
7036	3943	7554
7036	3943	3514
7036	3943	5462
7036	3943	3919
7036	3943	2164
7036	3943	9722
11851	3944	3132
11851	3944	5996
11851	3944	7011
11851	3944	7243
11851	3944	2451
7643	3945	391
7643	3945	9809
7643	3945	7745
7643	3945	5378
7643	3945	6443
7643	3945	5935
7643	3945	8011
7643	3945	2090
10443	3946	8285
10443	3946	7579
10443	3946	950
10443	3946	5973
10443	3946	3851
8483	3947	8146
8483	3947	2236
8483	3947	858
8483	3947	1065
8483	3947	4844
8483	3947	1324
8483	3947	8661
5382	3948	3732
9363	3949	3680
9363	3949	1874
6648	3950	2519
6648	3950	3408
6648	3950	8718
6648	3950	168
6648	3950	3548
6648	3950	494
6648	3950	2175
6648	3950	4899
6648	3950	3087
18106	3951	992
18106	3951	2975
18106	3951	7828
18106	3951	6188
18106	3951	4598
16010	3952	2477
16010	3952	7946
16010	3952	3740
16010	3952	8233
6262	3953	1761
6262	3953	3225
6262	3953	1436
6262	3953	2063
19780	3954	5520
19780	3954	1975
19780	3954	1726
8405	3955	227
8405	3955	1957
8405	3955	5959
8405	3955	1590
6702	3956	8423
972	3957	376
972	3957	5003
13953	3958	1032
13953	3958	659
13953	3958	6173
13953	3958	7382
13953	3958	9345
13953	3958	1172
16771	3959	8824
16771	3959	6948
16771	3959	3193
16771	3959	5212
16771	3959	9847
16771	3959	9465
16771	3959	7190
16771	3959	1035
16771	3959	9202
10750	3960	3505
10750	3960	6280
10750	3960	2856
14280	3961	9848
14280	3961	5363
1148	3962	788
1148	3962	9383
1148	3962	2620
1148	3962	6199
1148	3962	2110
9375	3963	6609
18929	3964	6605
18929	3964	321
18929	3964	5981
18929	3964	9492
18929	3964	6257
18929	3964	5743
18929	3964	2174
18929	3964	5022
2441	3965	2978
2441	3965	2339
2441	3965	4511
2441	3965	8652
2441	3965	8412
2441	3965	8323
2441	3965	9192
10343	3966	6110
3705	3967	6978
3705	3967	4026
3705	3967	3869
3705	3967	172
3705	3967	4450
3705	3967	4521
3705	3967	1457
3705	3967	8847
3705	3967	2506
3393	3968	6868
3393	3968	7311
3393	3968	722
3393	3968	4830
3393	3968	3602
3393	3968	998
9733	3969	1713
9733	3969	7009
9733	3969	1676
9733	3969	9404
9733	3969	8334
6436	3970	9570
6436	3970	3642
6436	3970	3451
6436	3970	1250
9703	3971	2479
9703	3971	8577
9703	3971	8914
9703	3971	3461
10272	3972	5658
10272	3972	7835
10272	3972	5938
10272	3972	6852
10272	3972	1913
10272	3972	2388
7274	3973	8489
7274	3973	1280
7274	3973	8145
7274	3973	1712
7274	3973	145
7274	3973	2980
7274	3973	308
11931	3974	9314
12331	3975	6659
12331	3975	9141
12331	3975	7555
12331	3975	9086
731	3976	222
731	3976	1716
731	3976	3892
731	3976	7032
731	3976	2062
4295	3977	8171
4295	3977	5644
4295	3977	5689
4295	3977	3619
4295	3977	3819
4295	3977	7612
4295	3977	7216
4295	3977	3270
4295	3977	8783
996	3978	5194
996	3978	1038
996	3978	512
996	3978	9402
996	3978	681
996	3978	2471
996	3978	7273
1783	3979	2065
1783	3979	5350
1783	3979	4725
7015	3980	4005
7015	3980	3289
7015	3980	6858
7015	3980	6453
7015	3980	5528
7015	3980	7929
798	3981	8559
3095	3982	2148
3095	3982	2936
3095	3982	7574
3095	3982	380
8769	3983	3583
8769	3983	507
8769	3983	9880
8769	3983	5890
8769	3983	2242
8769	3983	8207
13531	3984	8313
13531	3984	5261
16393	3985	4637
16393	3985	5749
16393	3985	2096
16393	3985	3710
16393	3985	3913
16393	3985	5714
3206	3986	919
3206	3986	7265
3206	3986	6573
9771	3987	5345
9771	3987	5996
9771	3987	7285
9771	3987	389
9771	3987	8162
9771	3987	4435
9771	3987	8162
9771	3987	6086
12671	3988	8827
12671	3988	3548
12671	3988	7330
12671	3988	9286
4035	3989	3239
1047	3990	3557
1047	3990	5900
1047	3990	4329
1047	3990	6339
16957	3991	2219
16957	3991	9810
16957	3991	1666
16957	3991	5888
1786	3992	1244
1786	3992	8339
1786	3992	6732
1786	3992	7687
1786	3992	5094
18843	3993	9836
18843	3993	3097
18843	3993	8997
18843	3993	2161
18843	3993	1082
13937	3994	7861
13937	3994	7625
13937	3994	3956
1374	3995	975
18508	3996	3872
18508	3996	7877
18508	3996	9534
3390	3997	5522
3390	3997	332
3390	3997	4574
3390	3997	8047
4005	3998	2689
7327	3999	2917
7327	3999	8673
7327	3999	6514
7327	3999	3756
7327	3999	3423
7327	3999	7742
6527	4000	3563
6527	4000	7925
6527	4000	7497
6527	4000	3612
6527	4000	5893
6527	4000	2419
6527	4000	9965
6527	4000	4004
6527	4000	6435
14005	4001	306
14005	4001	4226
14005	4001	7657
14005	4001	3611
14005	4001	1378
14005	4001	4489
14005	4001	6552
12910	4002	1755
12910	4002	1662
7707	4003	9977
7707	4003	9950
7707	4003	7019
2489	4004	3803
2489	4004	9037
2489	4004	9028
2489	4004	434
2489	4004	7482
2489	4004	2034
7577	4005	3961
35	4006	9694
35	4006	3643
35	4006	5174
35	4006	7956
35	4006	8746
15563	4007	1306
15563	4007	1307
15563	4007	5627
15563	4007	2299
15563	4007	7128
15563	4007	6109
2069	4008	5936
2069	4008	7301
2069	4008	7511
10934	4009	7225
8326	4010	1535
8326	4010	8565
8326	4010	3678
8326	4010	2198
8326	4010	6255
8326	4010	1894
8326	4010	9341
8326	4010	6050
8326	4010	3798
2617	4011	6775
2617	4011	7488
2617	4011	5734
2617	4011	8163
2617	4011	5735
2617	4011	5105
2617	4011	6858
18110	4012	7362
18110	4012	5083
2264	4013	4483
2264	4013	9587
2264	4013	3633
2264	4013	2735
2264	4013	361
2264	4013	7079
2264	4013	3235
2264	4013	8220
10154	4014	4132
10154	4014	3688
10154	4014	8190
5341	4015	948
1069	4016	6895
14511	4017	5779
14511	4017	1654
14511	4017	7465
14511	4017	9074
14511	4017	1038
14511	4017	1294
14511	4017	4699
14511	4017	3494
6791	4018	7779
6791	4018	3636
6791	4018	719
4961	4019	1322
4961	4019	4911
4961	4019	7562
4961	4019	1741
4961	4019	6960
4961	4019	9841
9078	4020	7433
1001	4021	578
1001	4021	4637
9057	4022	313
9057	4022	8508
9057	4022	8072
9057	4022	7597
9057	4022	2704
5087	4023	7083
9029	4024	5015
9029	4024	7647
9029	4024	57
9029	4024	6888
9029	4024	6812
14248	4025	2347
19887	4026	4500
19887	4026	1980
19887	4026	6324
19887	4026	7857
19887	4026	3576
19887	4026	2888
19887	4026	1724
19887	4026	4183
19887	4026	2818
19260	4027	6754
19260	4027	1818
17101	4028	7987
17101	4028	1198
17101	4028	853
17101	4028	9028
17101	4028	4933
15641	4029	8355
15641	4029	508
15641	4029	6447
15641	4029	803
15641	4029	654
15641	4029	5671
15641	4029	6656
15641	4029	1022
18016	4030	8974
18016	4030	679
18016	4030	8804
11614	4031	4535
11614	4031	7175
7243	4032	1801
7243	4032	1316
7243	4032	7669
7243	4032	4464
12846	4033	9580
12846	4033	3006
12846	4033	4672
10551	4034	7074
10551	4034	1084
10551	4034	7191
10551	4034	7870
10551	4034	7801
10551	4034	6931
10551	4034	7141
10551	4034	7088
10551	4034	3289
1972	4035	7657
1972	4035	7864
1972	4035	8484
1972	4035	7603
1972	4035	3030
1972	4035	8249
1972	4035	8924
13586	4036	6463
13586	4036	5069
13586	4036	8704
13586	4036	5208
13586	4036	2914
13586	4036	2978
1268	4037	2962
1268	4037	2436
1268	4037	7840
1268	4037	5240
1268	4037	9578
1268	4037	1528
1268	4037	957
1268	4037	3684
17505	4038	909
17505	4038	3500
12954	4039	7111
143	4040	636
143	4040	6908
12971	4041	4216
15798	4042	6651
15798	4042	3869
15798	4042	5664
10254	4043	5431
10254	4043	5448
1699	4044	4091
1699	4044	7537
15150	4045	8570
15150	4045	1387
15150	4045	6195
15150	4045	6418
4162	4046	7208
4162	4046	8764
4162	4046	2231
4162	4046	7075
4162	4046	5060
4162	4046	4919
4162	4046	5744
10033	4047	8505
10033	4047	681
10033	4047	5582
10033	4047	7930
10033	4047	6938
10033	4047	4080
10033	4047	504
18535	4048	3478
18535	4048	1130
18535	4048	3955
18535	4048	7689
18535	4048	8503
18535	4048	4714
18535	4048	7107
18535	4048	7132
5426	4049	4712
17583	4050	79
17583	4050	4337
17583	4050	9483
17583	4050	5002
17583	4050	6353
8081	4051	4300
8081	4051	3694
8081	4051	6587
8081	4051	9194
8081	4051	3538
16498	4052	7041
16498	4052	372
16498	4052	3029
16498	4052	1122
16498	4052	2523
17750	4053	2916
17750	4053	4944
17750	4053	7101
17750	4053	8621
17750	4053	9462
17750	4053	3384
17750	4053	1669
17750	4053	1248
17750	4053	9421
19585	4054	4501
19585	4054	4081
14407	4055	6986
14407	4055	1463
14407	4055	6028
14407	4055	565
14407	4055	2251
14407	4055	2463
14407	4055	3025
8543	4056	2559
8543	4056	8966
8543	4056	1364
8543	4056	4493
8543	4056	489
8543	4056	2648
8543	4056	4873
8543	4056	5200
8543	4056	1561
4251	4057	2152
4251	4057	2783
4251	4057	2471
4251	4057	9447
4251	4057	1708
4251	4057	3517
4251	4057	9971
8926	4058	1606
8926	4058	1015
8926	4058	2603
8926	4058	2814
8926	4058	7442
6638	4059	1658
6638	4059	3616
6638	4059	179
6638	4059	7852
6638	4059	5068
6638	4059	2560
6638	4059	6248
6638	4059	9502
2214	4060	7586
2214	4060	8554
2214	4060	6308
5193	4061	1037
5193	4061	619
5193	4061	5101
5903	4062	4320
5903	4062	7821
5903	4062	1942
6534	4063	5607
6534	4063	8823
6534	4063	6414
6534	4063	156
6534	4063	7727
6534	4063	7500
6534	4063	442
11084	4064	8494
11084	4064	3913
3467	4065	9056
3467	4065	2049
3467	4065	7194
3467	4065	3498
3467	4065	1816
3467	4065	1146
3467	4065	4437
3467	4065	1441
3764	4066	7424
11834	4067	8730
11834	4067	7826
11834	4067	6188
11834	4067	2624
11834	4067	4365
11834	4067	5893
15415	4068	9678
15415	4068	5850
15415	4068	4147
15415	4068	3000
15415	4068	4534
15415	4068	3167
15415	4068	6340
10138	4069	7177
19600	4070	9617
19600	4070	9738
15023	4071	9722
15023	4071	9958
15023	4071	1760
15023	4071	8067
15023	4071	3380
15023	4071	3006
15023	4071	4965
15023	4071	4788
3929	4072	1765
3929	4072	5829
3929	4072	444
3929	4072	6830
18512	4073	7532
18512	4073	6666
18512	4073	1358
9474	4074	4456
9474	4074	4401
9474	4074	7034
9474	4074	1208
9474	4074	4795
9474	4074	9450
9474	4074	4353
9474	4074	6189
18531	4075	2064
18531	4075	6344
18531	4075	7260
18531	4075	3463
18531	4075	2439
18531	4075	1432
18531	4075	360
18531	4075	6138
14690	4076	317
14690	4076	2091
16557	4077	7544
16557	4077	4636
16557	4077	4258
16557	4077	8337
16557	4077	8681
16557	4077	4360
16557	4077	1227
3174	4078	8980
3174	4078	1494
3174	4078	9763
3174	4078	4136
2662	4079	8025
2662	4079	8620
2662	4079	7282
11236	4080	7416
11236	4080	3439
11236	4080	4545
12333	4081	4462
12333	4081	6043
12333	4081	8905
12333	4081	6077
12333	4081	1509
12333	4081	7715
12333	4081	3883
12333	4081	2194
12333	4081	9212
7213	4082	2360
7213	4082	2841
7213	4082	3042
7213	4082	3071
15065	4083	1757
15065	4083	8500
15065	4083	23
15065	4083	4041
15065	4083	9542
15065	4083	4072
15065	4083	9088
15065	4083	7567
11439	4084	7310
11439	4084	6154
11439	4084	5977
11439	4084	8992
11439	4084	6757
11439	4084	6578
11439	4084	9365
11439	4084	6346
11439	4084	5086
9253	4085	6361
9253	4085	4479
2736	4086	617
2736	4086	6239
2736	4086	7308
12600	4087	1026
12600	4087	1265
12600	4087	2127
14424	4088	1839
14424	4088	8098
14424	4088	3702
14424	4088	2127
14424	4088	3944
14424	4088	298
14424	4088	8731
12078	4089	2339
12078	4089	77
12078	4089	6272
12078	4089	3755
12078	4089	8951
12078	4089	5610
12078	4089	435
17064	4090	1108
17064	4090	3918
17064	4090	9547
17064	4090	9612
17064	4090	752
17064	4090	4317
17064	4090	8269
16691	4091	9687
16691	4091	3396
16691	4091	7307
16691	4091	5583
16691	4091	6452
4197	4092	9872
4197	4092	2433
4197	4092	3919
4197	4092	7697
4197	4092	2987
4197	4092	4174
4197	4092	8668
17374	4093	2462
17374	4093	7923
17374	4093	296
17374	4093	7509
17374	4093	2339
17374	4093	8846
17374	4093	1163
17374	4093	7827
17374	4093	8136
11664	4094	7845
11664	4094	9879
11664	4094	3489
11664	4094	5200
11664	4094	8764
11664	4094	2677
11664	4094	7428
11664	4094	191
5058	4095	652
5058	4095	7284
5058	4095	3475
5058	4095	224
5058	4095	1251
5058	4095	7738
5058	4095	7230
5058	4095	5608
1613	4096	8467
1613	4096	2544
1613	4096	7753
1613	4096	831
1613	4096	5263
1613	4096	6039
6644	4097	8741
6644	4097	2017
6644	4097	1257
16974	4098	9206
16974	4098	5501
16974	4098	321
16974	4098	6091
16974	4098	9861
1384	4099	241
19339	4100	2573
19339	4100	5783
14079	4101	5526
14079	4101	3191
14079	4101	6175
14079	4101	6041
14079	4101	2658
14079	4101	9360
14079	4101	5975
14079	4101	3211
6901	4102	3120
6901	4102	3756
6901	4102	4739
8297	4103	2645
8297	4103	6336
8297	4103	6836
8297	4103	4526
8297	4103	9006
16730	4104	3322
18274	4105	1727
18274	4105	8238
18274	4105	5175
10912	4106	80
10912	4106	3702
1074	4107	3413
16840	4108	9402
16840	4108	9927
16840	4108	8752
16840	4108	589
16840	4108	5773
16840	4108	5961
16840	4108	1802
17851	4109	8694
17851	4109	2897
17851	4109	6817
17851	4109	4425
17851	4109	9751
17851	4109	8649
16100	4110	5723
16100	4110	4968
16100	4110	4890
16100	4110	5136
16100	4110	1688
16100	4110	1831
16100	4110	5862
16100	4110	4573
14939	4111	9291
14939	4111	7735
14939	4111	5012
14939	4111	5085
14939	4111	4434
14939	4111	2440
14939	4111	5157
92	4112	897
92	4112	8538
8799	4113	8955
8799	4113	9967
8799	4113	5329
6127	4114	9447
6127	4114	9855
6127	4114	4127
6127	4114	4035
6127	4114	9703
6127	4114	9330
451	4115	2952
174	4116	7911
174	4116	1798
174	4116	7331
174	4116	6303
11499	4117	9629
11499	4117	1121
11499	4117	2421
11499	4117	4163
11499	4117	8673
11499	4117	1975
11499	4117	6903
11499	4117	1966
146	4118	8146
146	4118	6164
146	4118	611
19164	4119	8408
19058	4120	352
19058	4120	7421
19058	4120	1934
19058	4120	5382
19058	4120	4321
19058	4120	778
13424	4121	4444
13424	4121	1042
13424	4121	887
13424	4121	4636
13424	4121	2260
13424	4121	6946
16906	4122	4123
16906	4122	1949
16906	4122	7998
4636	4123	1651
4636	4123	2383
4636	4123	7662
4636	4123	2328
4636	4123	1881
4636	4123	849
6218	4124	8620
6218	4124	7716
6218	4124	5056
6218	4124	8405
6218	4124	7895
6218	4124	4333
6218	4124	8720
6218	4124	8460
6218	4124	1105
17532	4125	7469
17532	4125	9821
17532	4125	6065
17532	4125	1426
17532	4125	1400
17532	4125	7755
5620	4126	9813
5620	4126	4654
5620	4126	1636
5620	4126	3155
5620	4126	3744
5620	4126	937
5620	4126	3025
5620	4126	4628
8896	4127	6585
8896	4127	9841
8896	4127	281
8896	4127	7100
16106	4128	6901
17072	4129	8631
17072	4129	1776
17072	4129	8172
17072	4129	8172
17072	4129	5293
17072	4129	7247
17072	4129	542
764	4130	7977
764	4130	4746
764	4130	6969
764	4130	8598
764	4130	6159
5130	4131	2715
1772	4132	3685
1772	4132	5096
1772	4132	6448
1772	4132	4763
1772	4132	6019
1772	4132	5403
1772	4132	5494
1772	4132	2376
1948	4133	3934
1948	4133	1996
1948	4133	9768
1948	4133	6664
1948	4133	5596
1948	4133	9141
1948	4133	6062
1948	4133	211
1948	4133	9874
11784	4134	9888
11784	4134	8843
11784	4134	9507
11784	4134	3237
11784	4134	1547
11784	4134	4571
11784	4134	1582
11784	4134	8252
7695	4135	3127
7695	4135	8084
7695	4135	532
7695	4135	8310
19721	4136	6905
19721	4136	5999
19721	4136	3479
19721	4136	2248
13637	4137	1157
13637	4137	6233
13637	4137	666
13637	4137	9711
13637	4137	6217
13637	4137	7130
13637	4137	5751
13637	4137	573
6185	4138	4455
6185	4138	8616
1726	4139	7681
1726	4139	2959
1726	4139	8343
1726	4139	4702
1726	4139	7385
7203	4140	350
7203	4140	5369
7203	4140	7556
7203	4140	4016
7203	4140	2873
7203	4140	222
7203	4140	6403
7203	4140	2351
7203	4140	3760
13437	4141	5909
13437	4141	8234
13437	4141	7983
13437	4141	6895
13437	4141	964
13437	4141	8146
13437	4141	8167
13437	4141	7001
13437	4141	6591
13623	4142	5600
13623	4142	6415
13623	4142	3743
13623	4142	6078
13623	4142	6525
13623	4142	6181
13623	4142	5280
4349	4143	9419
4349	4143	3088
4349	4143	8198
4349	4143	9767
4349	4143	9962
4349	4143	1600
4349	4143	7474
7776	4144	1187
7776	4144	1387
7776	4144	4623
7776	4144	2471
7776	4144	1730
7776	4144	2076
7776	4144	5019
7776	4144	8579
13553	4145	1564
13553	4145	9265
13553	4145	9479
13553	4145	362
13553	4145	626
13553	4145	3288
13553	4145	9556
13553	4145	9525
3989	4146	257
3989	4146	52
3989	4146	7650
3989	4146	3381
3150	4147	9731
3150	4147	134
3150	4147	1578
3150	4147	3721
3150	4147	7415
3150	4147	4016
3150	4147	1682
7845	4148	7893
7845	4148	1381
7845	4148	1066
7845	4148	6575
7845	4148	5759
2667	4149	6173
2667	4149	4960
2667	4149	9579
2667	4149	9954
2667	4149	5688
2667	4149	3963
10219	4150	335
10219	4150	8833
10219	4150	7128
7404	4151	5683
7404	4151	7837
7404	4151	6116
7404	4151	3717
7404	4151	1760
7404	4151	9755
10886	4152	2812
10886	4152	9360
10886	4152	6231
10886	4152	3287
828	4153	4116
828	4153	8659
12990	4154	504
12990	4154	6859
12990	4154	1442
12990	4154	3976
12990	4154	2056
12990	4154	5980
10678	4155	5034
10678	4155	4137
10678	4155	2670
10678	4155	8599
10678	4155	8400
10678	4155	6583
10678	4155	3753
10678	4155	3851
10678	4155	9160
1203	4156	2331
16619	4157	3649
16619	4157	2068
16619	4157	5470
16278	4158	4924
16278	4158	983
16278	4158	1767
16278	4158	2520
3360	4159	2282
3360	4159	6004
3360	4159	3024
3360	4159	2921
3360	4159	9147
2428	4160	7418
2428	4160	4089
2428	4160	4103
2428	4160	6418
2428	4160	519
2428	4160	9819
17619	4161	4319
644	4162	6475
644	4162	4064
644	4162	1102
644	4162	6834
644	4162	494
644	4162	6731
644	4162	6970
6773	4163	1571
6773	4163	7152
6773	4163	4546
6773	4163	5498
18540	4164	6066
258	4165	4673
258	4165	2468
258	4165	2365
258	4165	9749
258	4165	31
258	4165	2721
8582	4166	9663
8582	4166	6479
8582	4166	5093
8582	4166	4430
8582	4166	5831
1689	4167	6960
1689	4167	9330
3389	4168	1029
7498	4169	8040
15404	4170	2862
15404	4170	7443
6546	4171	4117
6546	4171	3038
4734	4172	4062
4734	4172	4380
4734	4172	7785
4734	4172	8839
13756	4173	4580
13756	4173	6651
13756	4173	8797
13756	4173	4731
13756	4173	7365
2964	4174	2558
2964	4174	7907
2964	4174	8802
2964	4174	2191
2964	4174	7057
11791	4175	2773
14705	4176	4793
14705	4176	5353
5436	4177	4200
5436	4177	9745
5436	4177	7598
5436	4177	9819
4018	4178	1984
4018	4178	2571
4018	4178	749
4018	4178	5384
4018	4178	2696
4018	4178	6620
4018	4178	8633
671	4179	4541
671	4179	2016
671	4179	5647
671	4179	1936
671	4179	6013
671	4179	7475
671	4179	8229
671	4179	6287
671	4179	3805
18376	4180	6798
18376	4180	6325
18376	4180	985
18376	4180	5766
18376	4180	2385
18376	4180	4565
18376	4180	4591
18376	4180	4014
53	4181	5619
53	4181	2609
53	4181	7107
6496	4182	2085
6496	4182	346
2662	4183	7006
2662	4183	3900
2662	4183	8529
2662	4183	1782
14917	4184	609
14917	4184	9404
14917	4184	93
18065	4185	366
18065	4185	7629
18065	4185	252
18065	4185	2043
18065	4185	9051
5901	4186	1441
5901	4186	7193
5901	4186	9859
5901	4186	9552
5901	4186	7948
16079	4187	7072
16079	4187	8546
16079	4187	7067
14635	4188	9313
10870	4189	86
10870	4189	2260
10870	4189	1529
10870	4189	7039
10870	4189	2587
10870	4189	36
10870	4189	3025
10870	4189	9586
10870	4189	725
15581	4190	5108
15581	4190	5875
15581	4190	6620
15581	4190	9855
15581	4190	4974
15581	4190	5324
13704	4191	7932
13704	4191	9242
13704	4191	8210
13704	4191	3469
8385	4192	1983
8385	4192	5581
8385	4192	6169
8385	4192	1511
8385	4192	6570
8385	4192	3040
8385	4192	1306
8385	4192	8778
8385	4192	5215
6294	4193	1114
6294	4193	4288
13303	4194	6549
13303	4194	2231
16799	4195	1188
16799	4195	724
16799	4195	1697
16799	4195	2590
16799	4195	552
16799	4195	8603
16799	4195	951
16799	4195	5352
16799	4195	6948
6041	4196	5019
6041	4196	6178
6041	4196	4968
6041	4196	5649
6041	4196	3383
8212	4197	6135
13371	4198	16
13371	4198	8147
13371	4198	4472
13371	4198	5008
13371	4198	8115
13371	4198	6539
13371	4198	4138
13371	4198	383
13371	4198	6741
247	4199	4230
247	4199	6760
247	4199	7582
247	4199	7049
247	4199	7108
247	4199	1445
11831	4200	7034
11831	4200	8739
11831	4200	1595
11831	4200	6287
11831	4200	1983
11831	4200	8009
11831	4200	3151
14759	4201	7743
14759	4201	389
14759	4201	1423
5734	4202	8783
5734	4202	1729
5734	4202	1558
5734	4202	9387
11346	4203	8700
11346	4203	4965
11346	4203	4013
11346	4203	9230
11346	4203	3720
8218	4204	1605
8218	4204	5492
8218	4204	7908
19273	4205	104
19273	4205	2162
19273	4205	5148
19273	4205	8774
19273	4205	429
19273	4205	5697
19273	4205	4701
19273	4205	3259
19273	4205	1899
7325	4206	7282
7325	4206	8488
7325	4206	6850
7325	4206	4826
9859	4207	8377
9859	4207	4399
9859	4207	5407
9859	4207	888
9859	4207	9269
9859	4207	6030
9859	4207	4009
13077	4208	673
13077	4208	6648
13077	4208	4063
13077	4208	5099
92	4209	7154
92	4209	8407
92	4209	9344
92	4209	6380
92	4209	4917
92	4209	5820
92	4209	8174
10322	4210	9233
11760	4211	9377
11760	4211	2290
11760	4211	1344
11760	4211	6658
10128	4212	8877
10128	4212	7877
10128	4212	2076
10128	4212	4739
10128	4212	3525
10128	4212	5411
10128	4212	4079
6836	4213	6819
6836	4213	4428
6836	4213	9710
12734	4214	1431
12734	4214	1162
12734	4214	745
12734	4214	4099
17675	4215	2451
17675	4215	6151
17675	4215	3123
17675	4215	9948
17675	4215	6213
17675	4215	3543
6503	4216	9618
2096	4217	1355
2096	4217	4807
2096	4217	8561
2096	4217	4291
2096	4217	3800
2096	4217	111
6466	4218	6877
6466	4218	9985
6466	4218	9885
12591	4219	6975
12591	4219	4336
12591	4219	7324
4260	4220	9671
4260	4220	7902
4260	4220	2176
4260	4220	3420
4260	4220	1246
4260	4220	8665
17297	4221	4507
17297	4221	1876
17297	4221	5498
17297	4221	3011
17297	4221	820
17297	4221	5523
13331	4222	2100
13331	4222	5604
18047	4223	5476
18047	4223	82
17244	4224	833
17244	4224	2996
12012	4225	6340
12012	4225	6825
12012	4225	8351
12012	4225	938
12012	4225	4329
12012	4225	4725
12012	4225	5566
12012	4225	7004
14170	4226	5707
14170	4226	1405
14170	4226	7589
14170	4226	2869
14170	4226	406
14170	4226	3360
14170	4226	716
14170	4226	5550
14170	4226	1810
12277	4227	1182
12277	4227	8685
12277	4227	9634
12277	4227	5270
1952	4228	7515
1952	4228	7183
1952	4228	3460
13638	4229	7003
17626	4230	4952
17626	4230	2952
17626	4230	7992
17626	4230	4318
17626	4230	3151
17626	4230	9471
17626	4230	563
17626	4230	7312
8989	4231	2083
8989	4231	8952
11910	4232	4768
11910	4232	5914
11910	4232	2065
11910	4232	5852
11910	4232	502
11910	4232	7682
11910	4232	9756
638	4233	8397
638	4233	9988
638	4233	8237
638	4233	4733
638	4233	8486
9566	4234	7450
9566	4234	7629
9566	4234	4718
9566	4234	9571
9566	4234	3649
9566	4234	8872
9566	4234	4405
9566	4234	3724
4240	4235	8978
4240	4235	4606
4240	4235	3362
13010	4236	4415
13010	4236	2239
13010	4236	4838
13010	4236	5524
13010	4236	2176
13010	4236	1661
12129	4237	7899
12129	4237	8420
12129	4237	3183
12129	4237	2009
12129	4237	1107
12129	4237	878
17503	4238	4075
17503	4238	8334
17503	4238	3135
17503	4238	3321
17503	4238	3029
17503	4238	6357
8914	4239	5104
8914	4239	4780
8914	4239	7721
8914	4239	6074
8914	4239	2160
8914	4239	6381
8914	4239	5703
8914	4239	325
8914	4239	6500
19268	4240	4944
19268	4240	6992
16075	4241	6982
16075	4241	3378
16075	4241	9147
10440	4242	2171
15747	4243	7651
15747	4243	3726
15747	4243	2760
15747	4243	8350
15747	4243	1785
5868	4244	5988
5868	4244	5620
5868	4244	2122
5868	4244	463
5868	4244	9985
4311	4245	29
4311	4245	1189
4311	4245	6445
4311	4245	4019
4311	4245	1156
4311	4245	6907
11818	4246	668
12574	4247	1052
12574	4247	4240
12574	4247	2076
12574	4247	3192
6441	4248	900
6441	4248	7843
6441	4248	7737
9287	4249	552
9287	4249	6084
9287	4249	9673
9287	4249	7507
9287	4249	1101
10682	4250	960
10682	4250	3432
10682	4250	6007
10682	4250	5627
10682	4250	4053
3580	4251	6433
3580	4251	4104
3580	4251	2216
3580	4251	8205
3580	4251	7719
3580	4251	2787
3580	4251	4269
3580	4251	4160
3580	4251	35
6932	4252	8986
6932	4252	9563
6932	4252	6913
18760	4253	3785
18760	4253	8246
12901	4254	2161
12901	4254	1321
12901	4254	6048
12166	4255	9549
12166	4255	9598
12166	4255	1861
12166	4255	1573
12166	4255	545
12166	4255	8154
12166	4255	7661
11814	4256	2357
9035	4257	947
9035	4257	9723
9035	4257	8632
9035	4257	8180
15555	4258	6937
14963	4259	8520
14963	4259	9463
14963	4259	8254
14963	4259	4575
14963	4259	3226
14963	4259	5128
14963	4259	1738
2920	4260	1782
1039	4261	1118
1039	4261	4086
1039	4261	7688
1039	4261	8016
1039	4261	1119
1039	4261	364
9876	4262	2434
9876	4262	7830
9876	4262	1184
9876	4262	5631
9876	4262	1013
9876	4262	3989
9876	4262	7931
9876	4262	5899
19969	4263	8757
19969	4263	1360
19969	4263	5032
19969	4263	9246
19969	4263	6661
18189	4264	3265
18189	4264	5948
18189	4264	4016
18189	4264	6307
18189	4264	7059
18189	4264	5262
5452	4265	7878
5452	4265	379
5452	4265	1572
1635	4266	45
1635	4266	6716
1635	4266	9175
1635	4266	9901
1635	4266	8877
1635	4266	2082
1635	4266	1920
14362	4267	9907
14362	4267	5532
14362	4267	6735
16613	4268	9124
16613	4268	5605
16613	4268	9972
16613	4268	3550
16613	4268	2302
16613	4268	4268
16613	4268	7366
16613	4268	6361
11561	4269	8487
11561	4269	2624
11561	4269	4157
11561	4269	9928
11561	4269	7665
11561	4269	9162
11561	4269	7888
15720	4270	7006
15720	4270	2955
15720	4270	566
15720	4270	7624
15720	4270	9606
15720	4270	2707
15720	4270	699
15720	4270	2444
15720	4270	5211
10276	4271	6386
8547	4272	2133
8547	4272	2594
8547	4272	8181
17493	4273	5673
17493	4273	1148
17493	4273	1546
17493	4273	9571
17493	4273	5167
17493	4273	590
17493	4273	9919
17493	4273	8191
10646	4274	8411
10646	4274	5809
10646	4274	1849
10646	4274	6552
10646	4274	2736
10646	4274	296
10646	4274	7895
18880	4275	3430
18880	4275	1138
18880	4275	6302
18880	4275	2389
18880	4275	7361
18880	4275	9815
16451	4276	9229
11562	4277	8201
11562	4277	5653
11562	4277	6494
11562	4277	5535
11562	4277	8796
11562	4277	8237
11562	4277	2984
10743	4278	3069
10743	4278	6287
10743	4278	7069
10743	4278	8302
10743	4278	9430
10743	4278	2079
10743	4278	57
10743	4278	9237
11462	4279	5513
11462	4279	872
7710	4280	9227
7710	4280	6216
7710	4280	6158
7710	4280	76
7710	4280	9437
7710	4280	9524
7710	4280	1188
7710	4280	3053
4579	4281	8021
4579	4281	163
4579	4281	2046
4579	4281	7281
4579	4281	4889
4579	4281	6789
4579	4281	2881
4579	4281	6410
12969	4282	4861
12969	4282	3810
12969	4282	3390
12969	4282	7293
12969	4282	9152
14344	4283	704
14344	4283	4722
14344	4283	316
14344	4283	3551
12862	4284	5469
15466	4285	9522
15466	4285	7529
9642	4286	9067
16829	4287	9808
16829	4287	6243
16829	4287	9725
16829	4287	7227
16829	4287	6224
16829	4287	3585
16829	4287	2950
16829	4287	9425
17892	4288	1857
17892	4288	4032
17892	4288	9489
17892	4288	1745
17892	4288	1513
17892	4288	5301
17892	4288	7253
17892	4288	1443
17892	4288	1336
15117	4289	9251
15117	4289	4214
15117	4289	2460
15117	4289	7622
18956	4290	9517
18956	4290	2238
18956	4290	5972
18956	4290	8399
18956	4290	5071
18956	4290	2814
18956	4290	2629
18956	4290	5181
18956	4290	1708
1916	4291	9633
1916	4291	7178
4569	4292	1424
4569	4292	1301
4569	4292	7509
11815	4293	1559
11815	4293	8994
11815	4293	5506
14427	4294	8171
14427	4294	5591
14427	4294	8090
14427	4294	5058
3578	4295	8037
3578	4295	137
3578	4295	1964
3578	4295	1453
3578	4295	28
3578	4295	1863
14738	4296	4582
14738	4296	8751
14738	4296	4048
14738	4296	557
11228	4297	7403
11228	4297	8636
17543	4298	6319
17543	4298	3709
17543	4298	5448
5292	4299	7087
5292	4299	7116
5292	4299	276
5292	4299	178
5292	4299	3299
5292	4299	6446
5292	4299	9446
5292	4299	3004
8486	4300	7446
2309	4301	6727
2309	4301	803
2309	4301	3446
2309	4301	7190
2309	4301	3726
2309	4301	1724
2309	4301	8297
2309	4301	1189
1269	4302	8715
1269	4302	8723
1269	4302	8150
1269	4302	8737
1269	4302	7323
8099	4303	3717
8099	4303	7707
8099	4303	7142
8099	4303	8371
8099	4303	5336
8099	4303	3887
8099	4303	1411
8099	4303	7159
8099	4303	9845
17136	4304	4737
17136	4304	6888
17136	4304	8430
17136	4304	6108
17136	4304	5720
17136	4304	8147
10577	4305	4154
10577	4305	5769
10577	4305	6718
10577	4305	3405
10577	4305	7180
10577	4305	9749
10577	4305	1817
10577	4305	1087
10577	4305	1366
19590	4306	1360
19590	4306	4544
19590	4306	3022
19590	4306	4795
19590	4306	4374
285	4307	7321
285	4307	8665
285	4307	3641
285	4307	9559
285	4307	9603
1936	4308	763
4245	4309	1629
4245	4309	5157
4245	4309	2992
4245	4309	5370
4245	4309	9673
4245	4309	5852
4245	4309	2748
4245	4309	1494
4245	4309	2929
5062	4310	3499
5062	4310	4476
5062	4310	2813
5062	4310	6383
16023	4311	4434
16023	4311	4385
16023	4311	4070
16023	4311	2160
16023	4311	1051
5088	4312	3597
5088	4312	9897
5088	4312	6995
5088	4312	5611
5088	4312	7656
5088	4312	1285
5088	4312	3326
6683	4313	6349
6683	4313	6286
6683	4313	4279
6683	4313	339
6683	4313	3352
6683	4313	7873
2937	4314	6762
2937	4314	5431
6172	4315	7124
6172	4315	8518
6172	4315	7463
6172	4315	5656
6172	4315	4577
6172	4315	4228
6172	4315	386
7475	4316	8384
7475	4316	3524
571	4317	2658
571	4317	2033
571	4317	4739
571	4317	7574
571	4317	8330
571	4317	7612
571	4317	8846
571	4317	5926
571	4317	1043
10452	4318	7281
10452	4318	8462
10452	4318	4603
10452	4318	1091
10452	4318	926
10452	4318	2759
10452	4318	7201
9548	4319	9810
17311	4320	1729
18738	4321	6350
18738	4321	5146
18738	4321	4908
18738	4321	6790
18738	4321	5304
18738	4321	9745
18738	4321	674
5578	4322	3234
5578	4322	4680
5578	4322	184
5578	4322	8018
5578	4322	6829
5578	4322	1282
15262	4323	2442
15262	4323	6292
15262	4323	8658
15262	4323	6946
15262	4323	9658
15262	4323	5348
14134	4324	8596
14134	4324	1305
14134	4324	1445
14134	4324	692
3946	4325	9604
3946	4325	1947
3946	4325	2337
3946	4325	1276
3946	4325	9833
18982	4326	4709
18982	4326	1812
18982	4326	9890
18982	4326	2452
18982	4326	9186
19755	4327	1851
19755	4327	9927
19755	4327	3769
19755	4327	3499
19755	4327	111
19888	4328	9435
19888	4328	1242
19888	4328	5082
19888	4328	383
19888	4328	3460
19888	4328	6165
13362	4329	1204
13362	4329	2989
13362	4329	5828
13362	4329	3003
13362	4329	2863
13362	4329	4100
13362	4329	3058
13362	4329	6460
13362	4329	5928
2017	4330	5979
2017	4330	9851
2017	4330	6860
2017	4330	8824
2017	4330	5476
2017	4330	3756
2017	4330	1157
8319	4331	7274
8319	4331	8047
8319	4331	102
8319	4331	2823
8319	4331	2206
8319	4331	7038
8319	4331	6475
8319	4331	7174
8065	4332	3415
8065	4332	4008
8065	4332	6844
8065	4332	6754
11325	4333	8671
11325	4333	6928
11325	4333	2700
11325	4333	4802
11325	4333	9208
11325	4333	7865
10076	4334	9071
4970	4335	9655
4970	4335	3166
4970	4335	2197
4970	4335	2071
4970	4335	9086
4970	4335	539
4970	4335	9515
4970	4335	5764
9943	4336	654
9943	4336	1046
9943	4336	1020
9943	4336	7570
9943	4336	2601
9943	4336	3015
12359	4337	8669
12359	4337	5532
12359	4337	1476
1980	4338	5306
1980	4338	4503
1980	4338	3458
1980	4338	2468
1980	4338	7816
1980	4338	4619
1980	4338	8501
1980	4338	6245
1980	4338	9474
16275	4339	8872
16275	4339	4116
16275	4339	2024
16275	4339	1338
16275	4339	7414
16275	4339	8781
4477	4340	6742
2720	4341	8579
2720	4341	4072
2720	4341	3753
8349	4342	128
8349	4342	5409
8349	4342	126
8349	4342	3482
8349	4342	3388
2980	4343	2060
2980	4343	1415
2980	4343	2601
2980	4343	8674
2980	4343	8206
2980	4343	9232
10843	4344	483
10843	4344	4883
10843	4344	8411
3785	4345	4154
3785	4345	7514
3785	4345	8531
3785	4345	9895
3785	4345	5690
3785	4345	1634
19678	4346	1797
19678	4346	8327
19678	4346	4261
18286	4347	4151
18286	4347	4492
18286	4347	3358
1743	4348	445
1743	4348	7178
1743	4348	9689
1743	4348	498
1743	4348	8651
1743	4348	6268
1743	4348	9228
6977	4349	2631
6977	4349	5164
6977	4349	5436
17588	4350	9665
17588	4350	9415
13185	4351	5404
13185	4351	5845
13185	4351	4348
7150	4352	7064
7150	4352	5441
7150	4352	8211
7294	4353	2441
7294	4353	2138
7294	4353	4161
7294	4353	2215
7294	4353	8144
7294	4353	9436
7294	4353	5198
7294	4353	7602
7294	4353	7393
8198	4354	4208
4837	4355	6066
4837	4355	6309
4837	4355	9845
4837	4355	611
4837	4355	9998
4837	4355	960
792	4356	5676
792	4356	6025
792	4356	1393
792	4356	7167
792	4356	9328
792	4356	6792
15633	4357	9101
15633	4357	8364
15633	4357	311
15633	4357	2951
15633	4357	1800
15633	4357	8450
15633	4357	4307
15633	4357	9563
15633	4357	9429
1643	4358	7194
7971	4359	1802
7971	4359	5243
7971	4359	684
7971	4359	9847
7971	4359	2581
8761	4360	7463
8761	4360	9888
8761	4360	997
8761	4360	2612
8761	4360	138
8761	4360	4265
8761	4360	1401
8761	4360	1316
8761	4360	1241
12967	4361	90
12967	4361	5159
12967	4361	6663
12967	4361	7051
9026	4362	1538
9026	4362	5414
9026	4362	9428
9026	4362	1491
9026	4362	2882
9026	4362	9549
1579	4363	7273
14725	4364	33
14167	4365	1596
14167	4365	9125
14167	4365	4995
8845	4366	8115
8845	4366	1664
8845	4366	7168
8845	4366	8452
8845	4366	255
8845	4366	5815
8845	4366	3087
8845	4366	5816
5267	4367	5661
5267	4367	7714
5267	4367	4931
5267	4367	9323
5267	4367	7131
5267	4367	984
5267	4367	2380
5267	4367	2908
2718	4368	7083
2718	4368	7577
6784	4369	6026
6784	4369	1827
6784	4369	5289
6784	4369	6471
11585	4370	5203
11585	4370	4624
11585	4370	6063
11585	4370	7130
11585	4370	8889
11585	4370	50
11585	4370	1002
11585	4370	6142
11585	4370	1018
14085	4371	8729
14085	4371	6948
14085	4371	8430
14085	4371	991
14085	4371	8575
14085	4371	4276
14085	4371	3776
1811	4372	2064
1811	4372	5589
1811	4372	5943
1811	4372	4921
1811	4372	1160
1811	4372	4003
1811	4372	7910
1811	4372	2291
1811	4372	7929
17840	4373	5114
17840	4373	5826
17840	4373	6195
8924	4374	2779
8924	4374	4923
19686	4375	345
19686	4375	8730
19686	4375	2414
19686	4375	3111
19686	4375	1739
6638	4376	9175
6638	4376	3265
6638	4376	2170
6638	4376	9832
5220	4377	1332
5220	4377	9683
5220	4377	8235
5220	4377	6696
5220	4377	8281
5220	4377	7984
5220	4377	9452
5220	4377	8554
5220	4377	3042
4434	4378	7586
4434	4378	9414
4434	4378	4469
4434	4378	28
4434	4378	4172
4434	4378	8153
12776	4379	3352
12776	4379	4174
12776	4379	3551
12776	4379	1059
12776	4379	2339
10857	4380	1783
10857	4380	537
10857	4380	1321
10857	4380	5528
19398	4381	3553
19398	4381	4112
19398	4381	6142
19398	4381	9594
19398	4381	8799
19398	4381	3941
19398	4381	5248
11391	4382	103
1279	4383	5645
1279	4383	6845
1279	4383	9913
1279	4383	2940
1279	4383	627
13536	4384	7083
2047	4385	7303
2047	4385	4578
2047	4385	7404
2047	4385	2500
2047	4385	5320
2047	4385	7079
2047	4385	7400
2047	4385	6180
18239	4386	6171
18239	4386	869
18239	4386	2166
18239	4386	3998
14338	4387	4298
14338	4387	5286
14338	4387	3940
14338	4387	3282
14338	4387	4971
14338	4387	223
12805	4388	5522
12805	4388	1858
12805	4388	2134
12805	4388	2377
12805	4388	677
12805	4388	98
12805	4388	3543
15680	4389	9540
15680	4389	8998
7936	4390	6338
7936	4390	3861
7936	4390	5221
7936	4390	6479
7936	4390	1074
7936	4390	9804
7936	4390	2910
6016	4391	7788
6016	4391	1207
6016	4391	7271
6016	4391	9805
14082	4392	4500
14082	4392	4212
14082	4392	2593
14082	4392	7743
14082	4392	6510
14082	4392	7683
14082	4392	2267
4182	4393	5459
4182	4393	2983
4182	4393	3214
4182	4393	7412
4182	4393	6520
4182	4393	59
4182	4393	7728
3879	4394	1372
3879	4394	4992
3879	4394	9478
3879	4394	4195
3879	4394	3268
3879	4394	3835
18586	4395	5958
6739	4396	4349
6739	4396	4421
6739	4396	9104
6739	4396	4016
6739	4396	3670
6739	4396	2683
6739	4396	3268
14924	4397	8450
14924	4397	1471
14924	4397	7031
14924	4397	7256
14924	4397	1195
11363	4398	227
18661	4399	1353
18661	4399	2184
18661	4399	569
18661	4399	6195
18661	4399	2914
18661	4399	6508
18661	4399	7837
9736	4400	7856
9736	4400	3383
9736	4400	4580
9736	4400	4920
9736	4400	9941
16356	4401	85
16356	4401	9524
16356	4401	2134
16356	4401	2558
16356	4401	5818
7308	4402	8522
7308	4402	9114
7308	4402	3647
7308	4402	591
11020	4403	3211
11020	4403	66
301	4404	804
301	4404	7900
7434	4405	7371
7434	4405	2112
7434	4405	4220
7434	4405	2269
7434	4405	3722
7434	4405	6093
7434	4405	8370
7434	4405	7557
15245	4406	7773
15245	4406	1132
15245	4406	203
15245	4406	1937
15245	4406	2748
15245	4406	9751
15245	4406	3834
15245	4406	6010
15245	4406	3088
13619	4407	2479
13619	4407	1136
14859	4408	6380
15023	4409	6543
15023	4409	6031
15023	4409	305
15023	4409	9409
10836	4410	3697
9670	4411	4343
10860	4412	5807
10860	4412	3142
10860	4412	2579
10860	4412	4120
10860	4412	3089
10860	4412	8412
10860	4412	5932
7151	4413	4307
7151	4413	7836
7151	4413	1769
7151	4413	1867
7151	4413	9216
7151	4413	1541
7151	4413	9634
7151	4413	2970
7151	4413	7209
2657	4414	1479
2657	4414	6405
2657	4414	900
8274	4415	1071
8274	4415	7139
8274	4415	9456
8274	4415	8951
8274	4415	926
1118	4416	3334
1118	4416	5093
1118	4416	6376
1118	4416	6267
1118	4416	2842
1118	4416	5265
1118	4416	6609
1118	4416	7879
1118	4416	1541
17359	4417	7684
17359	4417	9896
12941	4418	6015
12941	4418	4116
12941	4418	5759
12941	4418	869
12941	4418	8346
12941	4418	4697
12941	4418	7452
12941	4418	9860
12941	4418	1576
6688	4419	4568
6688	4419	6806
6688	4419	6373
6688	4419	935
6688	4419	7104
6688	4419	8045
7606	4420	5828
7606	4420	2635
7606	4420	3667
7606	4420	1829
7606	4420	5416
7606	4420	4927
7606	4420	6748
7606	4420	5761
7606	4420	2769
18283	4421	4683
18283	4421	3662
18283	4421	8925
18283	4421	6530
18283	4421	643
18283	4421	692
18283	4421	2882
9421	4422	8115
9421	4422	8473
9421	4422	7816
9421	4422	6178
9421	4422	6799
9421	4422	9726
9421	4422	8670
9421	4422	5105
8057	4423	4664
8057	4423	6022
8057	4423	7970
8057	4423	9715
15198	4424	410
15198	4424	6589
5532	4425	4722
5532	4425	7016
5532	4425	2944
5532	4425	5723
5532	4425	6148
5532	4425	3743
5532	4425	4464
5532	4425	6168
5532	4425	8666
4556	4426	4005
4556	4426	2461
4556	4426	2116
4556	4426	3359
16161	4427	1472
16161	4427	4029
353	4428	988
353	4428	5987
353	4428	3864
353	4428	3037
353	4428	6930
353	4428	1506
7931	4429	9243
7931	4429	3448
7931	4429	2965
8872	4430	1631
17194	4431	28
17194	4431	8393
2859	4432	7947
2859	4432	2516
8083	4433	8926
8083	4433	369
8083	4433	7231
8083	4433	6326
8083	4433	6488
8083	4433	332
8693	4434	4347
8693	4434	472
8693	4434	7797
8693	4434	582
8693	4434	5015
8693	4434	4097
9946	4435	9296
9946	4435	7954
9946	4435	5020
9946	4435	9067
9946	4435	2236
9946	4435	8244
12437	4436	2586
12437	4436	7090
12437	4436	7831
12437	4436	6126
12437	4436	768
12437	4436	4850
12437	4436	5195
12437	4436	3968
3842	4437	6200
3842	4437	8220
3842	4437	9480
3842	4437	7224
3842	4437	2682
3842	4437	1315
3842	4437	8434
12528	4438	9110
12528	4438	1997
14382	4439	1682
14382	4439	635
14382	4439	5452
14382	4439	2780
14382	4439	5270
14382	4439	134
14382	4439	5484
14382	4439	5087
7039	4440	9784
7039	4440	5504
7039	4440	8118
7039	4440	2852
19795	4441	8637
19795	4441	9070
19795	4441	9047
19795	4441	7758
19795	4441	4110
19795	4441	6811
3794	4442	5416
3794	4442	2516
3794	4442	2868
3794	4442	4092
3794	4442	5519
3794	4442	3849
3794	4442	6841
3794	4442	6581
11300	4443	7499
11300	4443	1002
11300	4443	5213
11300	4443	1201
11300	4443	9708
11300	4443	4704
11300	4443	9183
4099	4444	3034
4099	4444	1357
4099	4444	966
4099	4444	2308
19890	4445	6630
19890	4445	559
19890	4445	2303
7007	4446	1094
7007	4446	274
7007	4446	3612
7007	4446	2326
7007	4446	5011
12736	4447	4565
16476	4448	1475
16476	4448	2007
8618	4449	7812
8618	4449	9345
8618	4449	5885
8618	4449	9182
3014	4450	6866
3014	4450	1595
3014	4450	8522
3014	4450	3654
3014	4450	4397
11744	4451	7906
11744	4451	4265
11744	4451	2216
11744	4451	5202
11744	4451	982
11744	4451	1180
11744	4451	581
11744	4451	1670
11744	4451	6622
16431	4452	4375
16431	4452	2035
16431	4452	9441
16431	4452	4643
16431	4452	9941
8409	4453	6281
8409	4453	507
8409	4453	4544
8409	4453	7425
8409	4453	3082
8409	4453	4051
8409	4453	7630
8409	4453	7918
8409	4453	6323
16716	4454	8342
16716	4454	4716
16716	4454	8254
16716	4454	2487
16716	4454	392
16716	4454	9969
9025	4455	9638
9025	4455	2548
9025	4455	5369
9025	4455	4614
1874	4456	9295
1874	4456	8020
5470	4457	4181
9144	4458	5471
9144	4458	1592
9144	4458	6653
9144	4458	3721
9144	4458	4917
9144	4458	9377
9144	4458	2375
15906	4459	4594
15906	4459	7398
15906	4459	7593
15906	4459	7542
15906	4459	1721
15906	4459	6345
15906	4459	1731
15906	4459	2092
15906	4459	9870
7180	4460	2678
7180	4460	8999
7180	4460	2146
7180	4460	3005
7180	4460	9227
7180	4460	3841
7180	4460	4540
7180	4460	9942
7180	4460	3206
19102	4461	1366
19102	4461	1787
19102	4461	1390
19102	4461	4825
19102	4461	5805
19102	4461	6655
19102	4461	2555
19102	4461	4269
6991	4462	121
6991	4462	3057
12526	4463	5814
12526	4463	4976
12526	4463	4925
12526	4463	8415
12526	4463	3100
12526	4463	5648
4603	4464	1101
4603	4464	8855
4603	4464	1471
3183	4465	1653
3183	4465	9828
3183	4465	6003
3183	4465	5655
1158	4466	6893
1158	4466	4474
10429	4467	8510
10429	4467	1427
10429	4467	4826
10429	4467	9378
18179	4468	8580
18179	4468	9519
18179	4468	4367
18179	4468	5562
18179	4468	5752
18179	4468	8422
5789	4469	8109
5789	4469	7338
5789	4469	5968
5789	4469	3983
6721	4470	2450
6721	4470	2292
6721	4470	3751
6721	4470	5612
6721	4470	6984
6721	4470	5304
7450	4471	6620
7450	4471	2504
7450	4471	590
7450	4471	1346
7450	4471	8606
7450	4471	7352
7450	4471	8688
7450	4471	6418
17419	4472	520
17419	4472	372
17419	4472	8951
6853	4473	2044
6853	4473	6182
6853	4473	747
6853	4473	4389
6853	4473	3329
6853	4473	7419
12213	4474	7244
12213	4474	8387
12213	4474	4918
12213	4474	7187
12213	4474	6408
12213	4474	964
12213	4474	9564
12213	4474	2263
12213	4474	6383
14258	4475	9220
13277	4476	2745
13277	4476	6476
13277	4476	6047
13277	4476	9397
13277	4476	3768
13277	4476	6253
13277	4476	2721
4568	4477	3891
4568	4477	7526
4568	4477	1092
4568	4477	589
4568	4477	1283
4568	4477	6950
4568	4477	924
4568	4477	3889
4568	4477	9682
18157	4478	5662
18157	4478	6204
18157	4478	4369
18157	4478	666
18157	4478	2107
18157	4478	5912
14006	4479	7315
14006	4479	9317
14006	4479	4160
14006	4479	3958
14006	4479	7639
19798	4480	5927
19798	4480	6034
19798	4480	6762
19798	4480	5153
19798	4480	2350
19798	4480	1983
19798	4480	6891
19798	4480	5264
5156	4481	6842
1599	4482	4440
1599	4482	8867
1599	4482	1990
1599	4482	5537
1599	4482	6922
1599	4482	8425
1599	4482	9724
1599	4482	9334
1599	4482	9035
8598	4483	6877
7437	4484	4518
7437	4484	1451
7437	4484	3709
11397	4485	3721
11397	4485	3948
7344	4486	5378
7344	4486	9662
7344	4486	6253
7344	4486	3731
9767	4487	7366
9767	4487	9626
9767	4487	322
9767	4487	9133
9767	4487	9033
9767	4487	8086
9767	4487	6271
9767	4487	4898
9767	4487	5705
2166	4488	4750
2166	4488	8622
2166	4488	9151
2166	4488	3364
1459	4489	9546
17355	4490	2919
17355	4490	5940
17355	4490	4237
19884	4491	1025
19884	4491	6852
19884	4491	4446
19884	4491	4255
15236	4492	8348
15236	4492	9655
15236	4492	4639
15236	4492	6570
15236	4492	6995
15236	4492	961
15236	4492	8677
15236	4492	3771
4850	4493	849
4850	4493	1937
4850	4493	3942
4850	4493	8891
4850	4493	3808
4850	4493	418
145	4494	3881
1750	4495	3809
1750	4495	4992
1750	4495	3024
1750	4495	5
1750	4495	6293
1750	4495	3111
1750	4495	6147
1750	4495	4420
1750	4495	8635
18104	4496	9125
18104	4496	9040
18104	4496	7048
18104	4496	3880
18104	4496	7670
18104	4496	7936
18104	4496	5268
18104	4496	2793
18104	4496	5601
17422	4497	5763
17422	4497	7309
17422	4497	9961
686	4498	773
686	4498	5578
686	4498	6705
8748	4499	7036
8748	4499	9869
8748	4499	7685
8748	4499	8913
8748	4499	4181
8748	4499	6080
8748	4499	7960
8748	4499	4341
8748	4499	4218
8015	4500	2837
8015	4500	6856
8015	4500	5398
8015	4500	3915
8015	4500	6740
8015	4500	4955
8015	4500	778
8015	4500	2078
8015	4500	6448
5056	4501	5916
5056	4501	1795
5056	4501	8331
5056	4501	4140
13953	4502	6518
13953	4502	3777
13953	4502	2573
13953	4502	1383
13953	4502	7124
13953	4502	167
13229	4503	9142
13229	4503	1642
13229	4503	2201
13229	4503	5190
13229	4503	3494
13229	4503	9224
13229	4503	6306
5647	4504	3255
5647	4504	2825
5647	4504	3988
8308	4505	769
8308	4505	6414
8308	4505	6267
8308	4505	4967
8308	4505	1492
8308	4505	8998
8308	4505	9486
8308	4505	7570
12204	4506	8411
12204	4506	2426
12204	4506	6507
12204	4506	1183
12204	4506	567
12204	4506	1951
16729	4507	6420
16729	4507	9671
17337	4508	6890
17337	4508	1645
17337	4508	6568
17337	4508	4934
17337	4508	2128
17337	4508	6213
14790	4509	7726
14790	4509	5674
14790	4509	2252
14790	4509	3868
7077	4510	2207
7077	4510	5351
7077	4510	9945
7077	4510	8064
7077	4510	7253
7077	4510	1490
7077	4510	356
7077	4510	8014
7077	4510	5097
5644	4511	5485
5644	4511	1060
5644	4511	4760
5644	4511	2891
10194	4512	4193
10194	4512	6032
10194	4512	7276
10194	4512	5253
10194	4512	2664
10194	4512	6467
10194	4512	9737
10194	4512	628
10194	4512	4385
19739	4513	9222
19739	4513	7593
19739	4513	6654
19739	4513	7209
2803	4514	3658
2803	4514	9632
2803	4514	4279
2803	4514	4519
2803	4514	2973
2803	4514	2308
13384	4515	6562
13384	4515	8207
13384	4515	3929
13384	4515	7895
13384	4515	7079
14790	4516	3743
14790	4516	1807
14790	4516	9073
14790	4516	5670
14790	4516	6830
14790	4516	7847
612	4517	5109
6630	4518	9114
6630	4518	3434
6630	4518	1171
15351	4519	7838
15351	4519	704
15351	4519	5675
15351	4519	502
15351	4519	5016
15351	4519	1642
15351	4519	8655
7526	4520	7078
7526	4520	9336
7526	4520	4100
7526	4520	2383
7526	4520	4258
7526	4520	2947
1568	4521	7695
1568	4521	377
1568	4521	9809
1568	4521	6545
10399	4522	8963
12079	4523	2231
12079	4523	8802
12079	4523	6183
12079	4523	583
12079	4523	5100
12079	4523	9913
15213	4524	5803
15213	4524	3655
15213	4524	5291
15213	4524	7547
15213	4524	6517
15213	4524	2989
15213	4524	2549
15213	4524	9246
16095	4525	1107
16095	4525	6023
16095	4525	3857
16095	4525	2936
16095	4525	3542
16095	4525	5
16095	4525	811
12202	4526	311
12202	4526	5747
12202	4526	9693
12202	4526	3101
12202	4526	3074
12202	4526	6986
12202	4526	708
12202	4526	2439
12202	4526	4299
14468	4527	4203
14468	4527	5550
14468	4527	1700
14468	4527	1115
14468	4527	6479
14468	4527	8142
15668	4528	6772
15668	4528	1637
15668	4528	6058
15668	4528	1849
15668	4528	9075
15668	4528	4791
15668	4528	3381
15668	4528	7945
6990	4529	736
6990	4529	4229
6990	4529	5136
19720	4530	7685
19720	4530	3553
19720	4530	733
19720	4530	1666
19720	4530	8107
19720	4530	8729
19720	4530	2479
19720	4530	5724
19720	4530	9693
4580	4531	6001
4580	4531	1867
4580	4531	5757
4580	4531	997
4580	4531	1266
9636	4532	4429
9636	4532	6249
9636	4532	407
9636	4532	5433
2314	4533	7748
2314	4533	9069
2314	4533	1878
2314	4533	292
2314	4533	6206
2314	4533	5051
2314	4533	2008
9885	4534	8610
9885	4534	3551
9885	4534	8098
9885	4534	9835
13840	4535	3699
5534	4536	7837
5534	4536	2996
5534	4536	5680
5534	4536	1244
5534	4536	4361
5534	4536	2630
5534	4536	1010
5534	4536	1056
5534	4536	6097
11862	4537	2851
11862	4537	5507
11862	4537	9806
11862	4537	9317
11862	4537	2131
10252	4538	3171
10252	4538	2145
10252	4538	9564
10252	4538	3025
10252	4538	6013
4218	4539	8040
4218	4539	9011
4218	4539	3288
4218	4539	7440
13512	4540	3909
13512	4540	4654
13512	4540	5475
13512	4540	7540
13512	4540	5356
13512	4540	2392
13512	4540	7677
13512	4540	2462
13512	4540	513
17104	4541	9443
17104	4541	9990
17104	4541	7991
17104	4541	3638
17104	4541	6915
3137	4542	9394
3137	4542	4339
3137	4542	7291
3137	4542	3130
3137	4542	5134
3137	4542	7777
3137	4542	1285
5792	4543	7794
5792	4543	523
5792	4543	7086
5792	4543	6014
14520	4544	3981
14520	4544	4542
14520	4544	9711
14520	4544	5049
365	4545	5829
365	4545	8813
365	4545	2612
365	4545	3667
365	4545	8221
10612	4546	9306
10612	4546	9463
6886	4547	1762
6886	4547	783
6886	4547	2385
6886	4547	6993
6886	4547	2155
6886	4547	531
6886	4547	2848
6886	4547	9490
6886	4547	3548
19473	4548	1940
19473	4548	9105
19473	4548	7196
19473	4548	4846
19473	4548	2464
19473	4548	6576
19473	4548	3418
19473	4548	827
19473	4548	9776
613	4549	3449
613	4549	2591
613	4549	1148
613	4549	6732
613	4549	2344
613	4549	6486
7362	4550	711
7362	4550	1526
7362	4550	673
7362	4550	6247
7362	4550	5353
17166	4551	4661
17166	4551	1867
17166	4551	6772
17166	4551	545
17166	4551	7179
17166	4551	2175
17166	4551	4337
17166	4551	7345
16111	4552	5342
16111	4552	3637
16111	4552	8895
16111	4552	7610
16111	4552	7572
16111	4552	1804
16111	4552	3714
16111	4552	9484
56	4553	2916
56	4553	7528
56	4553	8411
56	4553	6550
6547	4554	670
6547	4554	9857
6547	4554	6896
6547	4554	2939
6547	4554	1404
6547	4554	6700
6547	4554	8413
6547	4554	5602
19180	4555	5752
19180	4555	6379
19180	4555	1361
19180	4555	9740
19180	4555	6201
19180	4555	2557
19180	4555	1919
19180	4555	6434
19180	4555	9879
2565	4556	6400
2565	4556	6165
2565	4556	7624
2565	4556	1591
2565	4556	1502
2565	4556	3074
2565	4556	1505
2565	4556	808
2565	4556	8722
2556	4557	3691
2556	4557	5988
2556	4557	9684
2556	4557	4852
2556	4557	9250
2556	4557	6325
2556	4557	3252
9685	4558	2185
9685	4558	7171
9685	4558	8041
9685	4558	4934
9685	4558	4986
9685	4558	8040
9685	4558	7363
9685	4558	9175
9685	4558	5300
302	4559	1402
302	4559	7283
10144	4560	4363
10144	4560	7068
10144	4560	5369
10144	4560	9510
8990	4561	3359
8990	4561	1641
8990	4561	1204
8990	4561	1392
8990	4561	7091
8990	4561	5691
8990	4561	3029
8990	4561	3145
8990	4561	8045
4815	4562	3941
4815	4562	1596
4815	4562	9991
4815	4562	7945
4815	4562	3377
4815	4562	8336
19077	4563	3361
19077	4563	9277
19077	4563	7539
19077	4563	2024
19077	4563	8263
15362	4564	4168
15362	4564	7331
15362	4564	9867
15362	4564	9229
15362	4564	7803
15362	4564	9114
15362	4564	7622
19158	4565	8627
19158	4565	8088
19158	4565	9759
19158	4565	6849
19158	4565	180
19158	4565	5702
19158	4565	7814
19158	4565	9073
19158	4565	5632
9719	4566	7465
10173	4567	4666
10173	4567	1117
18408	4568	9315
18408	4568	2223
18408	4568	6476
18408	4568	2151
2446	4569	162
2446	4569	8283
2446	4569	2163
2446	4569	2774
3174	4570	8577
3174	4570	8790
3174	4570	967
3174	4570	7223
3174	4570	4551
2052	4571	5315
2052	4571	3149
6621	4572	221
6621	4572	2616
6621	4572	7371
6621	4572	4581
6621	4572	8948
6621	4572	9780
6621	4572	6179
6803	4573	2847
433	4574	5378
433	4574	1620
433	4574	9187
433	4574	832
433	4574	7066
433	4574	2403
433	4574	6897
11688	4575	3582
11688	4575	2979
11688	4575	9721
5134	4576	2783
5134	4576	8533
304	4577	8413
304	4577	2007
304	4577	6404
6600	4578	9144
6600	4578	4600
6600	4578	7851
15142	4579	138
15142	4579	4048
15142	4579	3924
14670	4580	9934
14670	4580	6161
14670	4580	6622
13073	4581	8904
13073	4581	9270
13073	4581	7733
13073	4581	1081
13073	4581	4691
13073	4581	2412
13073	4581	9052
5951	4582	311
5951	4582	2035
5951	4582	2912
5951	4582	2183
5951	4582	760
5951	4582	6070
5951	4582	6269
5951	4582	1631
18727	4583	9386
18727	4583	2220
18727	4583	2179
18727	4583	8255
18727	4583	4247
18727	4583	8756
18727	4583	9060
18727	4583	4800
18727	4583	8986
19490	4584	6368
19490	4584	2547
19490	4584	7320
19490	4584	7362
19490	4584	580
19490	4584	7329
19490	4584	8544
13595	4585	4089
13595	4585	2872
13595	4585	8980
13595	4585	5119
13595	4585	4654
13595	4585	7710
13595	4585	4197
13595	4585	1948
18536	4586	9247
18536	4586	6184
18536	4586	1144
18536	4586	6083
18536	4586	1524
18536	4586	3530
18536	4586	3706
18536	4586	8761
18536	4586	4073
17453	4587	8893
17453	4587	2435
17453	4587	1441
17453	4587	109
17453	4587	3947
17453	4587	7552
17453	4587	5932
17453	4587	4857
12761	4588	1993
12761	4588	3839
12761	4588	3920
12761	4588	4634
12761	4588	6638
12761	4588	2927
12761	4588	9834
2550	4589	482
2550	4589	5837
2550	4589	3948
2550	4589	6728
2550	4589	3782
2550	4589	5185
14355	4590	7931
14355	4590	9823
12921	4591	1991
12921	4591	9321
12921	4591	8809
12921	4591	4843
1357	4592	2446
1357	4592	5762
1357	4592	4685
1357	4592	7538
1357	4592	8123
1357	4592	4670
1357	4592	6549
15163	4593	1541
15163	4593	3852
15163	4593	1305
15163	4593	52
15163	4593	1950
15163	4593	6825
18540	4594	5497
18540	4594	6724
18540	4594	763
18540	4594	3118
18540	4594	900
18540	4594	9924
1750	4595	3818
1750	4595	9648
1750	4595	2348
1750	4595	1268
1750	4595	2760
1750	4595	3569
1750	4595	7362
1750	4595	8556
10559	4596	126
10559	4596	1089
10559	4596	8677
10559	4596	543
10559	4596	1887
10559	4596	4712
8719	4597	4059
8719	4597	2710
8719	4597	185
8719	4597	9596
8719	4597	3168
8719	4597	405
8719	4597	3431
8719	4597	3720
9616	4598	5820
9616	4598	9908
9616	4598	1502
9616	4598	3411
8472	4599	6329
8472	4599	9855
8472	4599	4967
16269	4600	6197
16269	4600	760
16269	4600	4588
16269	4600	4724
16269	4600	52
19918	4601	4578
19918	4601	3358
19918	4601	5897
19918	4601	6593
19918	4601	8026
19918	4601	8738
5591	4602	7258
5591	4602	4531
5591	4602	7239
5591	4602	4085
8272	4603	4095
8272	4603	8369
8272	4603	2415
16622	4604	536
16622	4604	5268
16622	4604	2080
16622	4604	2069
16622	4604	4665
16622	4604	529
16622	4604	7344
16622	4604	8314
13198	4605	9175
13198	4605	2986
13198	4605	8330
1116	4606	9379
9292	4607	5812
9292	4607	4705
10467	4608	3000
10467	4608	3685
10467	4608	4583
7515	4609	1301
7515	4609	3346
7515	4609	7794
7515	4609	902
7515	4609	1304
7515	4609	1818
7515	4609	1820
7515	4609	411
10648	4610	7581
10648	4610	5759
10648	4610	7485
10648	4610	514
10648	4610	4099
10648	4610	390
10648	4610	6655
8896	4611	1620
8896	4611	7191
8896	4611	6919
8896	4611	1065
8896	4611	5535
8896	4611	2653
8896	4611	6944
5404	4612	3043
5404	4612	1979
5404	4612	1431
5404	4612	2540
5404	4612	6105
5404	4612	2534
5404	4612	5377
5404	4612	8994
5404	4612	7589
17308	4613	7823
17308	4613	4404
17308	4613	6128
17308	4613	7467
17308	4613	5987
17308	4613	9638
17308	4613	7650
379	4614	8697
379	4614	3337
379	4614	5839
379	4614	6641
379	4614	8242
379	4614	2082
19807	4615	4669
19807	4615	6185
19807	4615	1130
19807	4615	2645
19807	4615	138
19807	4615	1835
19807	4615	484
19807	4615	6912
19807	4615	2674
17026	4616	1941
17026	4616	8114
17026	4616	2302
17026	4616	3925
17026	4616	3175
17026	4616	3182
17026	4616	729
17026	4616	1532
17026	4616	5078
13824	4617	7900
13824	4617	3332
13824	4617	9301
13824	4617	9086
2052	4618	5048
2052	4618	8036
2052	4618	4676
2052	4618	7565
2052	4618	570
4202	4619	3770
4202	4619	4157
4202	4619	9484
4202	4619	4964
4202	4619	2629
4202	4619	9401
4202	4619	6142
17676	4620	3836
17676	4620	6760
17676	4620	9722
17676	4620	6367
17676	4620	2617
17676	4620	2392
17676	4620	5779
17676	4620	9616
18198	4621	1914
18198	4621	1300
18198	4621	6333
18198	4621	7196
18198	4621	6279
18198	4621	6861
18198	4621	6181
11804	4622	6193
11804	4622	3525
11804	4622	4842
11804	4622	4746
11804	4622	9238
2454	4623	5846
2454	4623	6784
2454	4623	2594
2454	4623	1251
2454	4623	1649
15658	4624	3731
15658	4624	2602
15658	4624	233
15658	4624	8508
15658	4624	5430
15658	4624	9532
15658	4624	71
7848	4625	9077
7848	4625	3916
10333	4626	3277
10014	4627	4680
10014	4627	2449
10014	4627	5868
2594	4628	5964
2594	4628	2605
2594	4628	8203
2594	4628	3595
2594	4628	6499
2594	4628	8950
2594	4628	2677
2594	4628	6782
2594	4628	9023
12326	4629	5905
12326	4629	554
12326	4629	1505
12326	4629	3070
12326	4629	58
12326	4629	9991
16386	4630	5472
16386	4630	1995
16386	4630	6138
16386	4630	3915
16386	4630	626
3174	4631	7228
3174	4631	7146
3174	4631	6778
3174	4631	8321
3174	4631	4363
3174	4631	8880
19538	4632	4253
19538	4632	5185
19538	4632	2439
19538	4632	920
19538	4632	4240
5470	4633	9331
5470	4633	3396
5470	4633	8141
5470	4633	5126
5470	4633	20
5470	4633	4840
5470	4633	3841
5470	4633	8668
5841	4634	9168
5841	4634	7250
5841	4634	3197
5841	4634	1633
5841	4634	4225
5841	4634	878
8546	4635	4446
8546	4635	9727
8546	4635	4644
16970	4636	4872
16970	4636	4951
8236	4637	4206
8236	4637	5860
8236	4637	1802
8236	4637	604
11457	4638	8994
11457	4638	8825
11457	4638	5862
11457	4638	3287
7468	4639	4925
7468	4639	6101
7468	4639	323
7468	4639	6415
7468	4639	1535
7468	4639	367
7468	4639	2357
11991	4640	9664
11991	4640	4364
11991	4640	4413
15397	4641	1433
15397	4641	736
15397	4641	6909
15397	4641	8402
9632	4642	7090
18893	4643	5442
18893	4643	2908
18893	4643	5486
18893	4643	3594
18893	4643	7496
18893	4643	7597
18893	4643	9462
18893	4643	7649
18893	4643	5386
7575	4644	8603
7575	4644	6681
7575	4644	5674
7575	4644	5138
7575	4644	547
7575	4644	8563
8097	4645	3947
8097	4645	4829
8097	4645	5166
8097	4645	572
8097	4645	4488
8097	4645	7372
8097	4645	9745
8097	4645	7612
8097	4645	2708
16762	4646	7150
16762	4646	9757
16762	4646	8898
16762	4646	9760
16762	4646	4718
16762	4646	7843
16762	4646	5250
16762	4646	3836
16762	4646	5822
6388	4647	2354
6388	4647	9871
7818	4648	3086
7818	4648	2090
7818	4648	6303
7818	4648	8283
7818	4648	610
7818	4648	9769
10037	4649	840
10037	4649	4705
10037	4649	475
10037	4649	4142
10037	4649	2006
10037	4649	7890
2663	4650	1922
16449	4651	4287
16449	4651	5131
15352	4652	4058
15352	4652	1277
15352	4652	2533
15352	4652	3312
10634	4653	9071
10634	4653	3802
10634	4653	9612
6921	4654	5591
6921	4654	9517
6921	4654	2290
6921	4654	8397
6921	4654	6049
14651	4655	9078
14651	4655	482
14651	4655	9844
14651	4655	6128
19858	4656	5653
19858	4656	2845
19858	4656	5774
19858	4656	7834
19858	4656	9156
19858	4656	7344
19858	4656	1486
19858	4656	6
19858	4656	718
19590	4657	3453
19590	4657	8219
19590	4657	4507
19590	4657	9509
19590	4657	7376
19590	4657	3232
19590	4657	4761
5189	4658	2717
5189	4658	5362
5189	4658	5032
5189	4658	6964
5189	4658	6589
5189	4658	5545
5189	4658	587
5189	4658	7929
4871	4659	5326
4871	4659	3247
4871	4659	4392
4871	4659	7562
4871	4659	602
4871	4659	856
4871	4659	3497
4871	4659	7521
8968	4660	8019
8968	4660	511
8968	4660	8820
8968	4660	7410
8968	4660	875
8968	4660	5482
8968	4660	8378
8968	4660	4757
4636	4661	4175
4636	4661	655
4636	4661	2889
4636	4661	6201
4636	4661	2659
4636	4661	2648
4636	4661	302
18243	4662	6518
18243	4662	897
18243	4662	8673
18243	4662	729
18243	4662	2044
18243	4662	5747
18243	4662	4801
10912	4663	3631
10912	4663	1891
10912	4663	4272
10912	4663	6967
10912	4663	7696
10912	4663	3695
10912	4663	2939
7670	4664	3110
10307	4665	3013
10307	4665	9535
10307	4665	661
10307	4665	4959
10307	4665	921
10307	4665	581
10307	4665	1387
10307	4665	9766
10307	4665	3794
13465	4666	568
7354	4667	8831
7354	4667	4063
7354	4667	4433
7354	4667	9384
7354	4667	725
3290	4668	6837
3290	4668	7511
3290	4668	1662
3290	4668	63
3290	4668	8037
3290	4668	180
3290	4668	9620
3290	4668	2280
3290	4668	5210
18543	4669	2869
18543	4669	7197
13160	4670	6544
13160	4670	449
13160	4670	8677
13160	4670	5359
13160	4670	2148
13160	4670	2474
13160	4670	1998
13160	4670	3089
16596	4671	7570
16596	4671	311
16596	4671	676
16596	4671	4030
16596	4671	4088
16596	4671	5224
16596	4671	1340
16596	4671	4686
87	4672	3438
87	4672	2259
87	4672	3322
87	4672	9713
87	4672	3645
87	4672	2065
87	4672	3439
87	4672	1651
87	4672	9883
7940	4673	4601
7940	4673	2363
7940	4673	6303
7940	4673	9330
7940	4673	76
7940	4673	6286
7940	4673	8202
15827	4674	3013
15827	4674	2539
8378	4675	9869
8378	4675	1756
8378	4675	8723
8378	4675	1102
8378	4675	5643
8378	4675	1231
8378	4675	2461
8378	4675	7738
11878	4676	3853
11878	4676	2645
10367	4677	9373
10367	4677	3032
10367	4677	5913
10367	4677	4057
10367	4677	1144
13571	4678	1757
13571	4678	8258
13571	4678	3770
13571	4678	5434
13571	4678	3218
13571	4678	3938
13571	4678	6151
18933	4679	3347
18519	4680	3894
18519	4680	8874
18519	4680	2274
18519	4680	6566
9645	4681	6720
19874	4682	5799
19874	4682	7568
19874	4682	3861
19874	4682	7262
19874	4682	3652
19874	4682	6467
722	4683	9975
722	4683	944
722	4683	9788
722	4683	1363
722	4683	7632
722	4683	2271
722	4683	8018
722	4683	6269
722	4683	4909
17540	4684	5978
17540	4684	4843
17540	4684	9577
17540	4684	2805
17540	4684	4986
17540	4684	8819
17540	4684	9319
17540	4684	3333
1927	4685	945
1927	4685	4703
1927	4685	597
1927	4685	1049
17955	4686	559
17955	4686	6803
17955	4686	9500
17955	4686	3196
4029	4687	620
4029	4687	2386
2295	4688	7928
2295	4688	2868
2295	4688	1041
2295	4688	9782
2295	4688	2893
2295	4688	3780
1165	4689	189
1165	4689	6970
1165	4689	8796
18830	4690	1953
18830	4690	7812
18830	4690	1496
18830	4690	108
18830	4690	4264
18830	4690	8278
2341	4691	4621
2341	4691	4931
2341	4691	8475
2341	4691	4988
7565	4692	3198
7565	4692	8636
12893	4693	2186
12893	4693	5658
7870	4694	5106
7870	4694	2
7870	4694	9491
7870	4694	7933
7870	4694	52
7870	4694	3409
12473	4695	195
12473	4695	5050
12473	4695	4799
12473	4695	1289
12473	4695	2815
12473	4695	3432
12473	4695	881
12473	4695	3551
12473	4695	7426
13832	4696	4881
13832	4696	6564
13832	4696	6280
13832	4696	4526
9440	4697	4714
9440	4697	7093
9440	4697	6130
9440	4697	2947
9440	4697	7805
9440	4697	3487
9440	4697	9813
9440	4697	4906
6779	4698	1924
6779	4698	998
6779	4698	8997
4323	4699	376
4323	4699	7694
4323	4699	958
4323	4699	7375
4323	4699	3385
4323	4699	7732
4323	4699	6533
4323	4699	7783
11221	4700	8319
11221	4700	7969
11221	4700	4955
18309	4701	7702
18309	4701	39
18309	4701	6970
18309	4701	9219
18309	4701	4902
5266	4702	178
5266	4702	7492
5266	4702	2868
5266	4702	5483
5266	4702	9070
5266	4702	503
10684	4703	425
10684	4703	9046
10684	4703	6276
10684	4703	1460
10684	4703	359
10684	4703	8098
10684	4703	8994
10684	4703	5935
10684	4703	4831
15397	4704	8885
15397	4704	1351
15397	4704	8838
15397	4704	4729
15397	4704	1311
15397	4704	2895
15397	4704	5616
15397	4704	6371
13460	4705	6611
13460	4705	335
13460	4705	1602
8037	4706	1918
8037	4706	6529
10731	4707	7380
10731	4707	1015
10731	4707	6703
10731	4707	9444
10731	4707	3706
10731	4707	9804
12828	4708	8958
12828	4708	2368
12828	4708	5193
12828	4708	6643
12828	4708	6978
12828	4708	380
12828	4708	8537
11833	4709	6191
11833	4709	1620
11833	4709	1540
11833	4709	9741
11833	4709	2469
4082	4710	3216
4082	4710	1643
4082	4710	1409
4082	4710	5519
4082	4710	1457
4082	4710	6499
4082	4710	1314
6152	4711	1542
6152	4711	7733
14947	4712	4082
14947	4712	6918
14947	4712	8895
14947	4712	4071
14947	4712	8541
8118	4713	9957
2539	4714	4346
2539	4714	8280
2539	4714	3382
2539	4714	8968
2539	4714	3485
2539	4714	666
15167	4715	7716
15167	4715	5004
15167	4715	5010
15167	4715	315
15167	4715	4106
8755	4716	558
17674	4717	4849
17674	4717	5546
17674	4717	4130
17674	4717	5901
17674	4717	3796
17674	4717	4169
17674	4717	891
17674	4717	7767
17674	4717	2999
14207	4718	1481
14207	4718	4090
14207	4718	5777
14207	4718	876
11449	4719	4058
11449	4719	1979
11449	4719	2119
11449	4719	1319
11449	4719	7285
11449	4719	5458
16912	4720	5560
16912	4720	6898
16912	4720	1377
14306	4721	4701
14306	4721	5678
14306	4721	7439
14306	4721	5404
14306	4721	9694
14306	4721	5190
14306	4721	3808
14306	4721	3221
14306	4721	7526
1316	4722	2143
1316	4722	321
1316	4722	2100
7102	4723	5223
7102	4723	8359
7102	4723	4765
7102	4723	2078
7102	4723	1284
10184	4724	4358
10184	4724	21
10184	4724	7924
10184	4724	5361
10184	4724	5346
10184	4724	3585
10184	4724	5081
10184	4724	997
12438	4725	8880
12438	4725	1748
12438	4725	8684
12438	4725	8225
12438	4725	8124
12438	4725	2844
12438	4725	5232
12438	4725	4561
19843	4726	5603
19843	4726	9889
19843	4726	1061
1375	4727	8674
1375	4727	8802
1375	4727	6941
1375	4727	3453
1375	4727	1638
8963	4728	7345
8963	4728	1518
8963	4728	8540
8963	4728	6886
8963	4728	1544
8963	4728	4825
8963	4728	7659
8963	4728	3292
3930	4729	2386
3930	4729	802
3930	4729	2852
11964	4730	4344
11964	4730	93
17264	4731	2774
17264	4731	2367
17264	4731	4749
17264	4731	7538
17264	4731	4788
17264	4731	6
4783	4732	8231
4783	4732	8610
4783	4732	2054
4783	4732	7120
4783	4732	9795
4783	4732	2260
5719	4733	5003
5719	4733	6216
5719	4733	6486
5719	4733	7792
5719	4733	5805
5719	4733	6807
5719	4733	189
5719	4733	7344
11907	4734	1483
11907	4734	4551
11907	4734	8394
11907	4734	9779
11907	4734	9669
11907	4734	2855
11907	4734	332
11907	4734	4423
4429	4735	12
4429	4735	9801
4429	4735	4924
4429	4735	8618
4429	4735	3098
4429	4735	9175
4429	4735	3864
4429	4735	5858
11273	4736	9509
19682	4737	6658
19682	4737	1511
19682	4737	9868
19682	4737	9645
19682	4737	1721
19682	4737	6813
19682	4737	5591
19682	4737	3019
19682	4737	4491
697	4738	5985
697	4738	9228
697	4738	4981
697	4738	5334
697	4738	3398
697	4738	4639
697	4738	6740
697	4738	6431
697	4738	4175
1974	4739	897
1974	4739	1307
1974	4739	8391
1974	4739	5736
1974	4739	8822
1974	4739	3162
16286	4740	1542
16286	4740	4540
16286	4740	457
13774	4741	5039
13774	4741	5847
13774	4741	5157
13774	4741	5037
13774	4741	2131
15734	4742	9588
15734	4742	3130
15734	4742	2260
15734	4742	9350
15734	4742	827
2566	4743	8170
6416	4744	6736
6416	4744	8118
497	4745	8115
497	4745	4407
497	4745	271
497	4745	4505
497	4745	2816
497	4745	6331
497	4745	7744
497	4745	4925
497	4745	6979
5012	4746	3880
5012	4746	3790
5012	4746	4810
5012	4746	2245
5012	4746	6180
5012	4746	6161
5012	4746	8062
5132	4747	6420
8326	4748	7075
8326	4748	2599
8326	4748	1087
8326	4748	5
8326	4748	1938
8326	4748	6963
8326	4748	648
8326	4748	6754
8326	4748	9567
15258	4749	195
15258	4749	6472
15258	4749	3596
15258	4749	778
15258	4749	556
6308	4750	2054
6308	4750	9832
6308	4750	4467
6308	4750	738
6308	4750	6002
11138	4751	3198
11138	4751	4888
11138	4751	8054
11138	4751	8
11138	4751	2412
11138	4751	6848
11138	4751	8637
11138	4751	6121
11138	4751	5493
10649	4752	2119
10649	4752	9558
10649	4752	394
10649	4752	3690
13774	4753	280
13774	4753	7100
13774	4753	249
13774	4753	1072
13774	4753	2477
13774	4753	7723
6429	4754	8539
6429	4754	3434
6429	4754	1840
6429	4754	8778
6429	4754	4491
6429	4754	3031
6429	4754	9354
6429	4754	1082
6429	4754	2176
4848	4755	9520
14484	4756	457
14484	4756	8702
14484	4756	4475
14484	4756	9652
14484	4756	5128
14484	4756	8547
14484	4756	895
14484	4756	4960
14484	4756	5153
14657	4757	9753
14657	4757	792
14657	4757	2081
14657	4757	6514
14657	4757	1202
14657	4757	6383
14657	4757	5964
14657	4757	2039
14657	4757	7171
11434	4758	7294
11434	4758	5187
11434	4758	7785
11434	4758	9775
11434	4758	4869
11322	4759	7152
11322	4759	6846
11322	4759	2281
11322	4759	8257
11322	4759	4085
11322	4759	3860
15808	4760	2843
15808	4760	5986
15808	4760	6712
15808	4760	3098
15932	4761	3627
15932	4761	5696
15932	4761	122
15932	4761	9131
15932	4761	5769
15932	4761	648
15932	4761	7682
15932	4761	1108
15932	4761	2411
10506	4762	3282
10506	4762	9140
10506	4762	5541
10506	4762	4345
10506	4762	4612
614	4763	2848
614	4763	8887
614	4763	5268
614	4763	8470
614	4763	4041
614	4763	8091
14951	4764	2846
3971	4765	6902
3971	4765	6148
3971	4765	3682
3971	4765	1820
3971	4765	8995
15763	4766	7415
15763	4766	8527
15763	4766	1332
15763	4766	7907
15763	4766	4093
15763	4766	8989
16089	4767	2640
16089	4767	1673
16089	4767	7338
16089	4767	1299
16089	4767	7785
16089	4767	3826
14219	4768	8864
14219	4768	7044
14219	4768	8816
14219	4768	9184
14219	4768	4562
14219	4768	9846
17537	4769	4593
17537	4769	7644
17537	4769	2149
17537	4769	1088
17537	4769	9235
17537	4769	8029
17537	4769	2023
17537	4769	2997
80	4770	4990
80	4770	5624
80	4770	8439
9310	4771	3512
9310	4771	625
9310	4771	762
9310	4771	97
18663	4772	6740
19471	4773	9775
19471	4773	9051
19471	4773	1019
19471	4773	4316
19471	4773	145
19471	4773	4112
15246	4774	8778
15246	4774	252
15246	4774	5824
15246	4774	8206
15246	4774	3691
15246	4774	1371
15246	4774	4681
8911	4775	9220
8911	4775	6186
12660	4776	712
12660	4776	4004
12660	4776	895
12660	4776	7900
12660	4776	1657
12660	4776	4103
15586	4777	3918
15586	4777	8720
15586	4777	3943
15586	4777	7889
15586	4777	3327
15586	4777	6697
15586	4777	404
2232	4778	5041
2232	4778	8763
2232	4778	8712
2232	4778	6662
2232	4778	281
2232	4778	607
9050	4779	903
9050	4779	9883
9050	4779	1681
9050	4779	2865
9050	4779	8806
9050	4779	1634
9050	4779	4384
9050	4779	6764
9050	4779	5871
9164	4780	7396
9164	4780	1995
9164	4780	1314
9164	4780	2528
9164	4780	2012
9164	4780	4408
9164	4780	2220
9164	4780	5104
9164	4780	4465
12198	4781	4405
12198	4781	2160
12198	4781	6981
5849	4782	9150
5849	4782	255
5849	4782	8186
396	4783	2092
14392	4784	1105
14392	4784	7411
3630	4785	2090
3630	4785	1286
3630	4785	7156
3630	4785	9199
3630	4785	376
3630	4785	6768
3630	4785	2236
16894	4786	6879
788	4787	2262
788	4787	4948
788	4787	1263
788	4787	3628
788	4787	6430
788	4787	298
788	4787	9747
788	4787	9890
788	4787	8950
2371	4788	9633
2371	4788	8292
2371	4788	4379
2371	4788	6904
2371	4788	5489
2371	4788	5864
2371	4788	6031
19317	4789	4572
19317	4789	2648
19317	4789	272
19317	4789	4439
19317	4789	9194
19317	4789	407
19317	4789	562
19317	4789	2623
19317	4789	6549
6906	4790	2619
17297	4791	8307
17297	4791	2811
17297	4791	7657
17297	4791	7196
3270	4792	4756
3270	4792	6156
3270	4792	7595
3270	4792	4170
3270	4792	5779
3270	4792	7597
3270	4792	38
2303	4793	4899
2303	4793	1761
2303	4793	48
2303	4793	3167
2303	4793	7346
8991	4794	2052
8991	4794	8951
8991	4794	3281
8991	4794	3790
2773	4795	1601
2773	4795	3670
2773	4795	1607
6735	4796	2785
6735	4796	4924
6735	4796	604
6735	4796	4626
6735	4796	7436
6735	4796	3454
6735	4796	6324
227	4797	1500
227	4797	4507
16352	4798	6745
16352	4798	5750
16352	4798	8876
7599	4799	7602
7599	4799	2019
7599	4799	9967
12581	4800	6404
15806	4801	1003
15806	4801	5601
15806	4801	5208
15806	4801	5761
15806	4801	5366
15806	4801	9492
15806	4801	8436
12073	4802	1074
12073	4802	8389
12073	4802	7703
8213	4803	2009
8213	4803	3772
8213	4803	3471
8213	4803	7577
8213	4803	1717
8213	4803	9636
18254	4804	7283
18254	4804	2445
18254	4804	8726
18254	4804	142
18254	4804	6016
18254	4804	7710
12612	4805	6952
12612	4805	6972
12612	4805	8934
12612	4805	9099
17468	4806	7861
17468	4806	2267
17468	4806	8456
17468	4806	3873
17468	4806	8229
17468	4806	4296
4011	4807	8311
4011	4807	7770
4011	4807	9039
4011	4807	5684
9564	4808	3516
9564	4808	3032
9564	4808	9002
9564	4808	6520
9564	4808	9
9564	4808	4639
9564	4808	4407
12532	4809	76
12532	4809	5646
12532	4809	4512
12532	4809	2586
12532	4809	2655
12532	4809	4977
16985	4810	9869
16985	4810	7377
14772	4811	5624
14772	4811	7664
14772	4811	7454
14772	4811	4273
14772	4811	7853
14772	4811	5374
14772	4811	4601
14772	4811	2560
15073	4812	6029
15073	4812	959
15073	4812	2800
15073	4812	2286
15073	4812	5722
15073	4812	5621
15073	4812	255
15073	4812	9449
7443	4813	3639
7443	4813	2106
7443	4813	8568
7443	4813	5496
7443	4813	2202
7443	4813	7280
7443	4813	195
7443	4813	4128
7443	4813	6574
4590	4814	3639
4590	4814	8791
4590	4814	3442
4590	4814	6809
4590	4814	419
5047	4815	7189
5047	4815	6253
5047	4815	8211
5047	4815	7620
5047	4815	1770
5047	4815	1400
5047	4815	8160
5047	4815	639
8555	4816	7365
8555	4816	6260
8555	4816	1492
8555	4816	4620
8555	4816	9201
8555	4816	8630
9764	4817	8414
9764	4817	4105
9764	4817	5145
9764	4817	8528
9764	4817	6790
9764	4817	6945
12637	4818	9133
1249	4819	1402
1249	4819	2908
1249	4819	7690
1249	4819	4913
1249	4819	6096
1249	4819	6866
1249	4819	3511
1249	4819	5705
1249	4819	5315
4519	4820	8578
4519	4820	5455
4519	4820	660
4519	4820	8335
4519	4820	36
5886	4821	3339
5886	4821	5217
4166	4822	4093
4166	4822	3553
9514	4823	9404
9514	4823	9145
9514	4823	7955
9514	4823	5294
10658	4824	8272
10658	4824	8371
10658	4824	468
10658	4824	1044
10658	4824	5671
10658	4824	9989
7082	4825	8298
7082	4825	7755
7082	4825	1083
7082	4825	2560
15705	4826	3182
15705	4826	5887
15705	4826	7138
15705	4826	3063
15705	4826	7845
15705	4826	6079
15705	4826	4784
15705	4826	3279
15705	4826	9608
15811	4827	5607
15811	4827	9299
15811	4827	3407
17462	4828	80
17462	4828	652
17462	4828	5409
17462	4828	4823
17462	4828	7821
17462	4828	6770
17462	4828	6968
17462	4828	3404
17462	4828	2498
11572	4829	156
7125	4830	2294
7125	4830	3469
7125	4830	2166
7125	4830	9590
8823	4831	5313
8823	4831	8259
8823	4831	7645
8823	4831	8855
8823	4831	9711
8823	4831	5928
12167	4832	9646
12167	4832	5943
18822	4833	3531
18822	4833	6411
18822	4833	8312
18822	4833	7019
18822	4833	4835
18822	4833	5904
18822	4833	6938
18822	4833	2622
17098	4834	4633
17098	4834	3189
18263	4835	8542
18263	4835	7880
18263	4835	4428
18263	4835	3436
18263	4835	1528
18263	4835	6363
18263	4835	5731
18263	4835	8842
18263	4835	7026
10238	4836	6635
10238	4836	2840
10238	4836	8921
10238	4836	8955
10238	4836	4257
10238	4836	5665
183	4837	2831
183	4837	3458
183	4837	4316
6314	4838	4619
6314	4838	3604
6314	4838	7295
6314	4838	9273
6314	4838	61
6314	4838	5348
6314	4838	3331
6314	4838	6511
12157	4839	9082
12157	4839	6120
12157	4839	1109
12157	4839	1727
12157	4839	3592
12157	4839	1053
12157	4839	4752
12157	4839	2841
4227	4840	307
4227	4840	3970
4227	4840	7131
4227	4840	2631
4227	4840	6559
11280	4841	8179
11280	4841	3590
11280	4841	7310
16725	4842	3019
16725	4842	285
16725	4842	346
16725	4842	2868
16725	4842	9992
16725	4842	4289
16725	4842	7317
16725	4842	5994
6059	4843	6185
6059	4843	7010
6059	4843	7599
2169	4844	9323
2169	4844	580
2169	4844	3613
12961	4845	3317
12961	4845	9186
10358	4846	8209
10358	4846	3688
1394	4847	5017
1394	4847	399
1394	4847	3470
1394	4847	3398
1394	4847	9327
1394	4847	4974
1394	4847	3491
1394	4847	3460
1394	4847	2415
10396	4848	6617
10396	4848	5972
15376	4849	7002
15376	4849	5715
15376	4849	3715
15376	4849	7121
15376	4849	3234
16414	4850	4757
16414	4850	4421
16414	4850	3949
16414	4850	2370
16414	4850	3810
16414	4850	7805
16414	4850	9291
583	4851	6309
583	4851	1871
583	4851	7719
583	4851	7136
583	4851	5438
6562	4852	4585
6562	4852	1087
6562	4852	5152
6562	4852	305
16218	4853	6339
16218	4853	2024
16665	4854	8356
16665	4854	1544
16665	4854	6365
11047	4855	9439
11047	4855	8911
11047	4855	3378
11047	4855	3982
11047	4855	3023
11047	4855	1792
16259	4856	7289
9964	4857	395
9964	4857	2357
9964	4857	9735
9964	4857	2282
9964	4857	4725
9964	4857	4842
9964	4857	2246
12454	4858	2650
1610	4859	984
18989	4860	6361
17434	4861	7823
17434	4861	2813
17434	4861	5249
14989	4862	3721
14989	4862	4600
14989	4862	1469
14989	4862	7176
16318	4863	7653
16318	4863	6993
16318	4863	982
16318	4863	2731
16318	4863	2893
16318	4863	5756
2008	4864	8498
2008	4864	3162
2008	4864	7009
2008	4864	8590
2008	4864	4845
2008	4864	1768
2008	4864	3924
2008	4864	9054
2008	4864	664
3290	4865	3873
3290	4865	8873
3290	4865	4720
3290	4865	632
3290	4865	1255
3290	4865	7313
3290	4865	1348
3290	4865	2178
14044	4866	9412
14044	4866	8735
14044	4866	1203
14044	4866	4511
14044	4866	1043
9830	4867	4543
9830	4867	5957
9830	4867	2447
9830	4867	4303
11302	4868	5589
11302	4868	827
11302	4868	1443
11302	4868	917
4238	4869	8912
4238	4869	3846
4238	4869	5533
149	4870	5249
149	4870	1177
149	4870	65
149	4870	5202
1580	4871	2080
1580	4871	7673
1580	4871	2640
1580	4871	5115
1580	4871	9588
1580	4871	2832
1580	4871	8050
12115	4872	23
12115	4872	5091
12115	4872	3237
12115	4872	4003
12115	4872	9298
637	4873	2781
637	4873	4305
18839	4874	3446
18839	4874	5114
4078	4875	6824
4078	4875	953
4078	4875	8773
4078	4875	7069
4078	4875	2628
4078	4875	3386
4078	4875	6685
18930	4876	4885
18930	4876	6888
18930	4876	921
18930	4876	2984
18930	4876	1827
18930	4876	8073
18930	4876	9079
62	4877	4221
62	4877	8502
62	4877	244
62	4877	8705
62	4877	3318
62	4877	6393
2555	4878	3796
2555	4878	6556
2555	4878	6662
2555	4878	8591
2555	4878	7762
2555	4878	9630
12878	4879	317
12878	4879	8768
14943	4880	9340
14943	4880	4613
14943	4880	5159
14943	4880	4899
2910	4881	9838
2910	4881	6342
11941	4882	2409
11941	4882	1611
11941	4882	1698
11941	4882	3286
11941	4882	7849
11941	4882	6673
11941	4882	4656
11941	4882	5864
11941	4882	5605
1102	4883	2159
1102	4883	8826
1102	4883	9654
1102	4883	4470
1102	4883	509
4237	4884	2497
4237	4884	8946
4237	4884	3664
4237	4884	7534
4237	4884	6904
4237	4884	8135
13808	4885	1406
13808	4885	8432
13808	4885	3717
13808	4885	1049
13808	4885	52
13808	4885	5066
9338	4886	7559
9338	4886	6517
9338	4886	5757
9338	4886	9542
9338	4886	7447
9338	4886	5168
16452	4887	3443
16452	4887	6217
16452	4887	4500
16452	4887	5347
16452	4887	8822
16452	4887	9326
1037	4888	658
1037	4888	3861
1037	4888	9234
13360	4889	8287
13360	4889	2467
13360	4889	1646
13360	4889	2684
14366	4890	1734
14366	4890	8827
14366	4890	6447
14366	4890	1578
14366	4890	6545
14366	4890	298
14366	4890	8648
14366	4890	3809
9775	4891	547
9775	4891	767
9775	4891	339
9775	4891	54
9775	4891	633
4733	4892	3425
10004	4893	7236
11768	4894	3606
11768	4894	200
11768	4894	1227
11768	4894	9997
11768	4894	2938
5983	4895	8173
5983	4895	8442
5983	4895	6212
5983	4895	2879
5983	4895	6868
5983	4895	1864
6735	4896	8680
6735	4896	1806
6735	4896	9161
6735	4896	9625
6735	4896	5026
937	4897	6544
937	4897	8798
937	4897	1028
7812	4898	7475
7812	4898	7822
7812	4898	1005
7812	4898	7107
17824	4899	1945
13939	4900	7438
13939	4900	2447
13939	4900	27
13939	4900	8965
13939	4900	6253
13939	4900	4960
13939	4900	9533
13939	4900	9664
13939	4900	4465
3142	4901	483
3142	4901	7127
3142	4901	7101
3142	4901	9397
3142	4901	6058
3142	4901	4150
8351	4902	5229
8351	4902	5594
8351	4902	8028
8351	4902	2622
8351	4902	2482
8351	4902	8360
8351	4902	8658
8351	4902	4209
8351	4902	7627
9453	4903	2575
13448	4904	899
13448	4904	8390
13448	4904	8492
13448	4904	6316
13448	4904	9111
13448	4904	4211
13448	4904	6024
13448	4904	9236
6890	4905	4781
6890	4905	3636
6890	4905	6351
6890	4905	7201
6890	4905	2934
6890	4905	2758
6890	4905	2435
6890	4905	9960
6890	4905	5131
8482	4906	5833
8482	4906	4228
11021	4907	4420
11021	4907	5123
11021	4907	6255
11021	4907	4264
11021	4907	5620
11021	4907	3399
11021	4907	1030
11021	4907	9524
11021	4907	6760
8412	4908	5863
8412	4908	3709
8412	4908	9795
16616	4909	1601
15711	4910	1311
15711	4910	9535
15711	4910	9951
18950	4911	4129
18950	4911	1508
18950	4911	1289
18950	4911	7751
18950	4911	7460
18950	4911	4621
18950	4911	5853
14908	4912	5309
14908	4912	3490
6049	4913	3588
6049	4913	5415
6049	4913	9172
6049	4913	3955
6049	4913	2568
6049	4913	8049
11015	4914	8567
11015	4914	8840
11015	4914	1169
11015	4914	2798
11015	4914	1716
15409	4915	3645
15409	4915	6294
15409	4915	8039
15409	4915	8603
2341	4916	1488
2341	4916	9699
2341	4916	2336
2341	4916	3065
8467	4917	711
8467	4917	8995
8467	4917	7895
3079	4918	599
3079	4918	9988
3079	4918	1235
3079	4918	372
3079	4918	323
43	4919	8287
43	4919	9455
43	4919	8507
43	4919	906
43	4919	8121
43	4919	3024
43	4919	8205
43	4919	7555
16305	4920	7354
16305	4920	1896
16305	4920	8354
16305	4920	9584
16305	4920	2240
16305	4920	2579
4066	4921	9964
4066	4921	2787
4066	4921	9528
4066	4921	4099
3306	4922	9806
3306	4922	8605
3306	4922	5674
8055	4923	8326
8055	4923	5259
8055	4923	5483
8055	4923	2937
8055	4923	3894
13362	4924	2491
13362	4924	1095
13362	4924	6734
13362	4924	2394
1997	4925	1498
1997	4925	3726
1997	4925	3049
1997	4925	9173
1997	4925	2954
1997	4925	8631
1997	4925	8861
1997	4925	8789
1997	4925	9206
3392	4926	1250
3392	4926	5385
3392	4926	8125
3392	4926	4642
3392	4926	9107
3392	4926	405
3392	4926	356
19056	4927	4183
19056	4927	3724
19056	4927	2917
19056	4927	5737
19056	4927	2283
19056	4927	3818
19056	4927	8943
19056	4927	8721
13691	4928	8669
13691	4928	9493
13691	4928	5674
13691	4928	2527
8576	4929	4680
8576	4929	6601
8576	4929	4626
8576	4929	9718
7071	4930	8603
7071	4930	7400
7071	4930	9610
16556	4931	7351
19755	4932	4166
19755	4932	2939
19755	4932	710
19755	4932	6442
19755	4932	1876
19755	4932	2245
19755	4932	9695
19755	4932	9077
19755	4932	9052
17323	4933	6940
17323	4933	6434
17323	4933	1238
17323	4933	4168
17323	4933	5821
17323	4933	39
1497	4934	6084
1497	4934	9778
1497	4934	6177
1497	4934	4616
7335	4935	2329
7335	4935	9654
7335	4935	926
7335	4935	3558
15450	4936	6057
15450	4936	7106
15450	4936	4392
15450	4936	6852
15450	4936	5574
15450	4936	8804
15450	4936	6101
15450	4936	7004
17464	4937	8070
17464	4937	8682
17464	4937	2989
17464	4937	1158
17464	4937	9964
17464	4937	3863
17464	4937	8407
17464	4937	9254
17464	4937	6370
3887	4938	3694
3887	4938	5496
5162	4939	1995
5162	4939	6853
5162	4939	6494
5162	4939	2915
5162	4939	5356
5162	4939	2414
5162	4939	8899
5162	4939	186
5162	4939	3619
13784	4940	8969
13784	4940	5829
13784	4940	2889
13784	4940	7045
13784	4940	8484
13784	4940	9815
13784	4940	9716
5261	4941	5509
8814	4942	2560
8814	4942	6490
8814	4942	7703
8814	4942	3811
8814	4942	7179
8814	4942	1135
8814	4942	8173
8814	4942	2384
8814	4942	7218
13866	4943	9563
13866	4943	7701
13866	4943	8838
13866	4943	9479
13866	4943	7386
13866	4943	6842
13866	4943	8855
5331	4944	2305
5331	4944	6108
5331	4944	528
5331	4944	7133
5331	4944	688
5331	4944	4679
8483	4945	9313
8483	4945	1444
8483	4945	6526
8483	4945	828
19365	4946	2348
19365	4946	7606
7426	4947	2204
7426	4947	9749
8854	4948	8668
8854	4948	1671
8854	4948	4239
8854	4948	6771
8854	4948	1942
8854	4948	4132
8854	4948	7281
19256	4949	4280
19256	4949	7528
19256	4949	4648
19256	4949	1669
6107	4950	731
6107	4950	8450
6107	4950	5471
6107	4950	5514
6107	4950	3453
15170	4951	9628
15170	4951	6748
15170	4951	2124
15170	4951	3441
15170	4951	435
15170	4951	9382
15170	4951	2484
2612	4952	8796
2612	4952	8289
2612	4952	7846
2612	4952	6508
2612	4952	1258
2612	4952	8883
17021	4953	9307
5495	4954	835
5495	4954	3780
17872	4955	4824
17872	4955	6692
9074	4956	5836
9074	4956	540
9074	4956	1530
9074	4956	3229
5071	4957	5283
5071	4957	7137
5071	4957	3248
5071	4957	9435
5071	4957	9852
9350	4958	7787
9350	4958	834
9350	4958	9356
9350	4958	2873
9350	4958	1388
9350	4958	3901
16242	4959	3582
16242	4959	5009
16242	4959	8550
16242	4959	1634
16242	4959	6329
11869	4960	2232
11869	4960	4682
11869	4960	8647
11869	4960	9735
11869	4960	3932
11869	4960	5922
11869	4960	5738
11869	4960	5953
11869	4960	8103
6223	4961	1368
6223	4961	1856
6223	4961	3371
6223	4961	3631
11725	4962	8928
11725	4962	2135
11725	4962	3643
11725	4962	9784
11725	4962	3899
11725	4962	3085
11725	4962	8410
11725	4962	9386
19275	4963	1523
19275	4963	3362
19275	4963	3354
19275	4963	4423
19275	4963	2855
19275	4963	4868
14004	4964	3068
14004	4964	3228
14004	4964	5750
14004	4964	6817
12404	4965	5839
12404	4965	7462
1647	4966	7817
1647	4966	5068
1647	4966	4575
1647	4966	2454
1647	4966	6937
1647	4966	8259
1647	4966	3127
1647	4966	6971
7574	4967	9989
7574	4967	7091
7574	4967	6412
7574	4967	3190
7574	4967	5376
6384	4968	3864
6384	4968	4659
6384	4968	1291
6384	4968	9215
6384	4968	1600
17140	4969	2357
17140	4969	4127
17140	4969	5173
17140	4969	8173
17140	4969	5769
17140	4969	2941
17140	4969	6806
17140	4969	4337
16399	4970	4516
16399	4970	3572
10343	4971	3742
10343	4971	6327
10343	4971	1539
10343	4971	8443
10343	4971	1670
10343	4971	8295
10343	4971	7978
9565	4972	3709
9565	4972	1118
9565	4972	3125
13393	4973	1868
13393	4973	196
13393	4973	2725
8528	4974	976
18540	4975	505
18540	4975	9524
18540	4975	7583
18540	4975	5484
18540	4975	2561
17602	4976	1502
17602	4976	9134
17602	4976	2780
17602	4976	8220
10388	4977	3838
10388	4977	6368
10388	4977	6140
10388	4977	4583
10388	4977	1208
10388	4977	8895
10388	4977	865
10395	4978	8895
16058	4979	9888
12021	4980	3108
12021	4980	1073
12021	4980	624
12021	4980	6348
12021	4980	2875
12021	4980	7370
12021	4980	4246
12021	4980	3224
12021	4980	3432
4653	4981	356
4653	4981	8478
4653	4981	367
4653	4981	6253
4653	4981	3192
4653	4981	7940
4653	4981	8836
4653	4981	1476
8701	4982	6119
8701	4982	9373
5608	4983	5131
5608	4983	4599
5608	4983	6751
5608	4983	5729
5608	4983	6594
5608	4983	4351
5608	4983	1342
354	4984	5360
354	4984	9875
354	4984	5760
354	4984	5079
354	4984	5337
16316	4985	6217
16316	4985	8553
16316	4985	5956
5098	4986	2334
5098	4986	6724
5098	4986	7781
5098	4986	1908
3565	4987	7776
3565	4987	3090
3565	4987	7922
3565	4987	1270
3565	4987	4093
3565	4987	9083
3565	4987	453
3565	4987	6925
6374	4988	791
6374	4988	6304
6374	4988	9271
6374	4988	1712
6374	4988	9994
6374	4988	9426
6374	4988	9263
6374	4988	882
6374	4988	3542
15267	4989	278
15267	4989	7507
15267	4989	627
11194	4990	7291
11194	4990	9751
2924	4991	4410
2924	4991	7291
2924	4991	9971
2924	4991	856
2924	4991	323
2924	4991	1146
2924	4991	6710
2924	4991	50
2924	4991	8626
18031	4992	195
18031	4992	5642
18031	4992	125
18031	4992	1408
11634	4993	9489
11634	4993	155
955	4994	437
974	4995	1164
14873	4996	1000
14873	4996	9443
14873	4996	9959
14873	4996	9279
14873	4996	6668
14873	4996	6633
14873	4996	469
14873	4996	6499
14873	4996	7265
15403	4997	8189
15403	4997	1747
2097	4998	546
2097	4998	6645
13205	4999	1253
13205	4999	3077
13205	4999	3662
13205	4999	4673
13205	4999	3106
13205	4999	1244
13205	4999	9639
13205	4999	4364
12221	5000	7159
12221	5000	6078
12221	5000	1753
12221	5000	7692
15441	5001	5549
15441	5001	4398
15441	5001	7568
15441	5001	3244
8400	5002	2745
8400	5002	582
8959	5003	9056
11278	5004	2250
11278	5004	9382
9859	5005	8823
9859	5005	6815
9859	5005	9889
9859	5005	6267
9859	5005	3012
9859	5005	2330
9859	5005	4188
19285	5006	8686
19285	5006	2768
19285	5006	1816
19285	5006	5827
19285	5006	7477
19285	5006	6127
19285	5006	6541
6712	5007	4667
6712	5007	6754
6712	5007	2292
6712	5007	1272
6712	5007	1278
6712	5007	6122
9615	5008	869
9615	5008	4259
9615	5008	7702
9615	5008	5680
9615	5008	4856
9615	5008	8777
9615	5008	5577
9615	5008	7410
9615	5008	9074
2731	5009	7845
2731	5009	8538
2731	5009	9057
2731	5009	8774
2731	5009	4254
2731	5009	250
2731	5009	6337
2731	5009	247
2731	5009	1779
1110	5010	6347
1110	5010	56
1110	5010	7861
1110	5010	6785
1110	5010	7170
1110	5010	5628
1110	5010	8596
1110	5010	719
1110	5010	8430
17358	5011	6630
17358	5011	5362
17358	5011	8833
17358	5011	8964
10620	5012	730
10620	5012	7443
10620	5012	7787
10620	5012	2144
10620	5012	319
10620	5012	8098
10620	5012	8108
10620	5012	6010
10620	5012	5206
3672	5013	244
3672	5013	3423
3672	5013	7178
3672	5013	4517
10493	5014	2761
10493	5014	4355
10493	5014	3880
10493	5014	5643
10493	5014	5711
10493	5014	8505
10493	5014	8867
10493	5014	1215
10493	5014	5546
11579	5015	4997
11579	5015	7410
11579	5015	9670
11579	5015	4760
11579	5015	9453
7614	5016	8480
7614	5016	8670
7614	5016	1817
7614	5016	5912
7614	5016	884
7614	5016	8013
7614	5016	1564
16116	5017	1730
16116	5017	6728
16116	5017	862
16116	5017	3747
16116	5017	9007
16116	5017	4121
16116	5017	3253
3844	5018	9096
3844	5018	1997
19	5019	9176
19	5019	9449
2357	5020	2577
2357	5020	4056
2357	5020	5244
18727	5021	1964
18727	5021	8058
18727	5021	5303
18727	5021	1456
18727	5021	7132
18727	5021	7309
12969	5022	9402
12969	5022	3303
11759	5023	2203
11759	5023	7691
11759	5023	3006
11759	5023	1222
11759	5023	6173
2951	5024	8775
2951	5024	6463
2951	5024	7102
2951	5024	2569
2951	5024	1262
9128	5025	444
9128	5025	2474
9128	5025	7482
9128	5025	7732
9128	5025	2348
9128	5025	5456
9128	5025	8233
9128	5025	9995
17540	5026	4854
14844	5027	9392
14844	5027	5783
12451	5028	8872
12451	5028	2350
9393	5029	3217
9393	5029	1273
11259	5030	6449
11259	5030	2013
11259	5030	4257
11259	5030	7625
11259	5030	8475
11259	5030	8478
11259	5030	9632
17006	5031	5106
17006	5031	7417
17006	5031	2029
6601	5032	8930
6601	5032	9590
6601	5032	2660
13832	5033	564
13832	5033	2815
13832	5033	4872
13832	5033	6188
13832	5033	949
13832	5033	7963
13832	5033	9420
13832	5033	6718
13832	5033	6012
19712	5034	5681
19712	5034	9056
19712	5034	5270
19712	5034	5256
11638	5035	4860
11638	5035	5508
11638	5035	280
16485	5036	3622
16485	5036	1399
16485	5036	400
16485	5036	9489
16485	5036	9823
16485	5036	8145
16485	5036	3509
16485	5036	9717
16485	5036	6895
14119	5037	2096
14119	5037	491
14119	5037	4989
14119	5037	618
14119	5037	975
14119	5037	6728
14119	5037	3872
14119	5037	8519
14119	5037	1604
19497	5038	3163
19497	5038	803
10771	5039	4829
10771	5039	8458
10771	5039	1587
10771	5039	6342
10771	5039	945
10771	5039	6443
10771	5039	9689
10771	5039	4800
10771	5039	3675
4409	5040	4243
4409	5040	707
4409	5040	9371
4409	5040	430
10516	5041	577
10516	5041	9437
10516	5041	9488
10516	5041	4234
10516	5041	8054
10516	5041	6245
19838	5042	2123
19838	5042	2448
19838	5042	4724
19838	5042	1410
19838	5042	761
19838	5042	580
19838	5042	7098
19838	5042	4284
7439	5043	4101
7439	5043	8979
7439	5043	2747
9751	5044	3554
9751	5044	9675
9751	5044	3630
9751	5044	9155
19830	5045	8208
19830	5045	5347
19830	5045	1652
19830	5045	6211
19830	5045	1957
19830	5045	5068
19830	5045	2465
19830	5045	6158
19830	5045	2689
12485	5046	2244
12485	5046	5811
8604	5047	3373
8604	5047	8090
8604	5047	2011
8604	5047	7627
19166	5048	518
13351	5049	7975
13351	5049	7796
78	5050	1436
78	5050	1734
78	5050	78
78	5050	2268
78	5050	3825
78	5050	7908
78	5050	2501
2064	5051	2029
2064	5051	8228
12405	5052	2741
12405	5052	3193
12405	5052	9759
2985	5053	6598
2985	5053	5682
2985	5053	3924
2985	5053	1874
2985	5053	7479
2985	5053	7456
2985	5053	4461
5377	5054	8891
5377	5054	4738
15861	5055	2560
15861	5055	4266
15861	5055	8056
7475	5056	7326
7475	5056	9929
7475	5056	6068
7475	5056	7224
6897	5057	5032
6897	5057	7538
6897	5057	3738
6897	5057	7700
6897	5057	3326
6897	5057	7382
6897	5057	195
19552	5058	3281
19552	5058	2897
19552	5058	1304
19552	5058	594
19552	5058	9492
19552	5058	1976
19552	5058	4312
19552	5058	4813
19552	5058	6777
8951	5059	4735
8951	5059	3318
8951	5059	8210
8951	5059	4705
8951	5059	1509
8951	5059	3885
10377	5060	3716
10377	5060	9250
7124	5061	5412
15626	5062	3540
15626	5062	7093
15626	5062	3613
15626	5062	8628
272	5063	4542
272	5063	1759
272	5063	9287
272	5063	772
272	5063	1166
272	5063	2098
15018	5064	5322
15018	5064	9971
15018	5064	5972
15018	5064	5719
15018	5064	2367
15018	5064	7903
8411	5065	1704
8411	5065	6934
8411	5065	8857
8411	5065	9526
8411	5065	4045
8411	5065	3886
8411	5065	9133
8411	5065	6416
8411	5065	4512
968	5066	69
968	5066	3379
968	5066	870
968	5066	2177
968	5066	6884
968	5066	5876
968	5066	4870
968	5066	1523
968	5066	4755
17281	5067	5865
17281	5067	9604
17281	5067	9134
17281	5067	861
17281	5067	1952
10661	5068	3191
10661	5068	1762
10661	5068	4955
10661	5068	3891
10661	5068	2370
10661	5068	4219
10661	5068	981
10661	5068	5765
10661	5068	5387
9982	5069	7910
9982	5069	1778
9982	5069	3795
9982	5069	5191
9982	5069	9447
9982	5069	3770
9982	5069	8456
9982	5069	8846
9982	5069	8548
5534	5070	3004
5534	5070	6054
5534	5070	5733
5534	5070	3381
5534	5070	5309
5534	5070	604
5534	5070	1151
5534	5070	7264
13421	5071	7919
13529	5072	7980
13529	5072	900
13529	5072	2024
13529	5072	423
13529	5072	2293
13529	5072	4191
13529	5072	3894
13529	5072	6964
16229	5073	4456
16229	5073	561
16229	5073	6848
16229	5073	2356
15760	5074	1163
15760	5074	9543
15760	5074	9366
3317	5075	7332
3317	5075	4954
3317	5075	4513
3317	5075	2410
3317	5075	5390
11900	5076	4429
11900	5076	2674
11900	5076	6279
11900	5076	2896
11900	5076	2701
11900	5076	629
3782	5077	7345
3782	5077	8539
3782	5077	5353
3782	5077	3838
3782	5077	6459
3782	5077	4628
3782	5077	5177
3782	5077	2096
9538	5078	2007
9538	5078	2791
9538	5078	4612
9538	5078	6774
9538	5078	5310
5309	5079	4953
5309	5079	7130
5309	5079	4671
5309	5079	8018
6389	5080	2801
6389	5080	6306
16624	5081	3019
16624	5081	596
16624	5081	5879
16624	5081	292
16624	5081	8560
16624	5081	5496
16624	5081	8756
6854	5082	2725
5386	5083	1731
5386	5083	8393
5386	5083	1809
5386	5083	3295
5386	5083	1510
5386	5083	4620
9822	5084	6759
9822	5084	1867
9822	5084	6927
9822	5084	8942
9822	5084	4489
9822	5084	8794
9822	5084	4359
9822	5084	4318
5422	5085	5356
5422	5085	6116
1471	5086	5646
1471	5086	7541
1471	5086	7360
1471	5086	7919
1471	5086	3576
1471	5086	7425
1471	5086	8526
1471	5086	6067
1471	5086	2203
3367	5087	2973
3367	5087	6681
12145	5088	5259
12145	5088	2627
12145	5088	7873
12145	5088	2206
12145	5088	4272
12145	5088	2652
12145	5088	3845
12145	5088	7914
12145	5088	4061
6067	5089	4213
6067	5089	1842
6067	5089	3859
6067	5089	6967
4450	5090	5024
4450	5090	9338
4450	5090	2815
4450	5090	3011
4450	5090	5306
4450	5090	6643
4450	5090	6767
4450	5090	3336
4450	5090	3736
15897	5091	8843
15897	5091	9454
15897	5091	7446
13192	5092	3620
13192	5092	286
13192	5092	8478
7567	5093	7003
7567	5093	9246
7567	5093	3981
7567	5093	5473
7567	5093	930
7567	5093	6731
7567	5093	9143
7567	5093	5580
7225	5094	6669
7225	5094	2762
7225	5094	3237
7225	5094	250
7225	5094	5024
7225	5094	3680
7225	5094	7318
7225	5094	2364
15673	5095	3215
15673	5095	6606
15673	5095	8649
15673	5095	8945
15673	5095	5798
15673	5095	8905
15673	5095	8931
4335	5096	7304
4335	5096	69
4335	5096	9955
4335	5096	3908
4335	5096	8686
4335	5096	155
4335	5096	6647
4335	5096	6883
4335	5096	5726
9339	5097	6798
9339	5097	3702
6242	5098	2790
5717	5099	245
5717	5099	220
5717	5099	9902
5717	5099	3349
5717	5099	3744
5717	5099	9801
5717	5099	5763
5717	5099	4138
1870	5100	6663
9114	5101	9756
9114	5101	8944
9114	5101	731
9114	5101	6027
9114	5101	8119
9114	5101	1324
10135	5102	4536
10135	5102	7516
10135	5102	9766
15036	5103	2382
15036	5103	827
15036	5103	3547
15036	5103	94
15036	5103	6520
15036	5103	1680
19597	5104	1266
19597	5104	8165
19597	5104	3226
1482	5105	4731
17791	5106	6357
19807	5107	2395
19807	5107	8272
19807	5107	7724
19807	5107	3873
19807	5107	3142
19807	5107	7146
19807	5107	8102
17053	5108	8718
17053	5108	6358
17053	5108	4738
17053	5108	6516
17053	5108	1684
684	5109	5520
684	5109	7467
684	5109	9634
684	5109	9439
13169	5110	6956
13169	5110	3104
13169	5110	3464
13169	5110	3910
13169	5110	8247
9525	5111	8633
9525	5111	5454
9525	5111	4133
9525	5111	9541
9525	5111	4216
7309	5112	239
7309	5112	3991
7309	5112	4117
7309	5112	5262
7309	5112	8916
7309	5112	7402
7309	5112	7819
7309	5112	1925
7309	5112	5943
2792	5113	2369
2792	5113	4031
2792	5113	9223
2343	5114	7202
2636	5115	8898
2636	5115	2103
2636	5115	3543
10935	5116	6025
10935	5116	4468
10935	5116	8213
4487	5117	9211
4487	5117	6975
4487	5117	4135
4487	5117	5961
4487	5117	5494
4487	5117	4737
13678	5118	6759
13678	5118	8816
13678	5118	891
13678	5118	20
16466	5119	476
16466	5119	3757
16466	5119	9274
16466	5119	5277
16466	5119	4907
16466	5119	5214
16466	5119	4664
16466	5119	4791
10962	5120	3301
10962	5120	7788
10962	5120	1475
10962	5120	9550
3490	5121	7360
3490	5121	6202
3490	5121	5288
3490	5121	42
3490	5121	2716
3490	5121	595
10771	5122	867
10771	5122	5542
6658	5123	1136
6658	5123	623
6658	5123	9652
6658	5123	3691
6658	5123	5980
6658	5123	3646
6658	5123	1371
8174	5124	1467
8174	5124	7441
16614	5125	2473
16614	5125	5012
12295	5126	3323
12295	5126	9104
12295	5126	5402
12295	5126	6906
12295	5126	6350
12295	5126	2734
12295	5126	2364
7659	5127	7145
7659	5127	5614
7659	5127	3649
7659	5127	9410
7659	5127	8917
7659	5127	4809
7659	5127	4150
6506	5128	8337
6506	5128	492
6451	5129	4902
6451	5129	6518
6451	5129	9671
10567	5130	3370
10567	5130	5001
10567	5130	9666
10567	5130	9940
10567	5130	7940
10567	5130	7068
10808	5131	90
10808	5131	1144
10808	5131	8147
10808	5131	4950
10808	5131	6770
10808	5131	8326
10808	5131	9904
10808	5131	5802
1606	5132	612
1606	5132	8791
1606	5132	1481
1606	5132	1635
1606	5132	1262
2702	5133	3938
2702	5133	4013
2702	5133	5035
2702	5133	3508
2702	5133	244
2702	5133	5474
2702	5133	6684
2702	5133	6848
14920	5134	6011
14920	5134	407
14920	5134	8127
14920	5134	4412
14920	5134	3020
13913	5135	5844
13913	5135	7716
13913	5135	5403
13913	5135	2762
13913	5135	4005
13913	5135	1659
13913	5135	1686
18850	5136	8645
18850	5136	1969
18850	5136	4042
18850	5136	1723
9286	5137	1576
18583	5138	7251
18583	5138	8344
18583	5138	1417
18583	5138	2109
18583	5138	7420
18583	5138	2528
18583	5138	4744
13424	5139	3092
13424	5139	2862
13424	5139	4309
13424	5139	6132
13424	5139	6740
13424	5139	5176
4853	5140	3682
4853	5140	4011
4853	5140	2443
4853	5140	6210
1907	5141	7665
1907	5141	8375
1907	5141	3751
16119	5142	3944
16119	5142	1194
16119	5142	806
17457	5143	8069
17457	5143	1017
17457	5143	6307
17457	5143	5481
17457	5143	8180
11689	5144	6601
11689	5144	9307
11689	5144	7517
11689	5144	6461
11689	5144	2277
11689	5144	579
11689	5144	4513
11689	5144	1810
19757	5145	389
19757	5145	5593
19757	5145	3687
19757	5145	7493
19757	5145	9616
19757	5145	1453
19757	5145	2656
19757	5145	9682
12284	5146	3796
16617	5147	3689
16617	5147	5227
16617	5147	51
16617	5147	511
16617	5147	1486
17955	5148	2177
17955	5148	5248
17955	5148	9791
17955	5148	5005
17955	5148	1071
17955	5148	8429
17955	5148	8847
17955	5148	3175
17955	5148	7317
5087	5149	8159
5087	5149	559
5087	5149	5517
5087	5149	8622
5087	5149	9004
8501	5150	9179
8501	5150	9887
16632	5151	284
16632	5151	9297
16632	5151	5154
16632	5151	144
16632	5151	9077
16632	5151	7283
5597	5152	5893
5597	5152	7367
5597	5152	2862
5597	5152	9934
5597	5152	3632
5597	5152	2290
14811	5153	5696
14811	5153	6021
14811	5153	477
14811	5153	6812
14811	5153	4466
14811	5153	9188
14811	5153	6893
14811	5153	8982
12697	5154	9345
5953	5155	3879
5953	5155	2002
5953	5155	7113
5953	5155	7212
5953	5155	8547
10718	5156	9454
10718	5156	6176
10718	5156	5223
10718	5156	9131
19868	5157	671
2454	5158	9920
2454	5158	8601
2454	5158	9499
2454	5158	166
2454	5158	3499
2454	5158	3405
2454	5158	3225
18799	5159	4557
18799	5159	5018
18799	5159	8268
17876	5160	165
169	5161	7117
169	5161	2853
169	5161	2261
169	5161	6744
169	5161	7091
169	5161	8523
169	5161	9368
7848	5162	9985
7848	5162	9579
5389	5163	5609
5389	5163	3515
5389	5163	3113
5389	5163	4540
13600	5164	2465
13600	5164	4626
13600	5164	3665
13600	5164	8713
13600	5164	7917
15801	5165	4796
15801	5165	4249
19716	5166	183
19716	5166	9941
19716	5166	7578
19716	5166	1522
19716	5166	2511
19716	5166	9301
19716	5166	4973
19716	5166	1129
19716	5166	3278
10508	5167	6809
10508	5167	9921
10508	5167	4167
10508	5167	916
10508	5167	5024
10508	5167	4278
10508	5167	5820
14682	5168	1327
14682	5168	2464
14682	5168	4015
14682	5168	9984
14682	5168	2637
19163	5169	1322
19163	5169	412
19163	5169	1632
19163	5169	8154
19163	5169	2424
19163	5169	1619
19163	5169	4287
19163	5169	5585
19163	5169	9765
4456	5170	5820
16912	5171	8038
18717	5172	4847
6001	5173	5432
6001	5173	2695
6001	5173	7886
6001	5173	5753
6001	5173	5190
16798	5174	1592
16798	5174	4154
16798	5174	3260
16798	5174	853
16798	5174	1549
16798	5174	4250
12554	5175	729
12554	5175	4853
5477	5176	389
533	5177	5964
533	5177	9391
533	5177	105
533	5177	2308
533	5177	6199
533	5177	5355
533	5177	252
19296	5178	4476
19296	5178	877
19296	5178	3922
19296	5178	9318
19296	5178	9468
19296	5178	4577
19296	5178	9518
17817	5179	1559
17817	5179	2700
16108	5180	2981
16108	5180	6722
16108	5180	2386
16108	5180	495
16108	5180	217
16108	5180	5839
16108	5180	8727
6605	5181	3843
6605	5181	412
3941	5182	9728
3941	5182	4195
3941	5182	1360
3941	5182	2865
3941	5182	6487
3941	5182	9277
18988	5183	9029
18988	5183	9657
18988	5183	3427
18988	5183	2518
5858	5184	4900
5858	5184	1003
5858	5184	3518
5858	5184	2560
5858	5184	2373
17719	5185	5842
17719	5185	1728
17719	5185	3537
6388	5186	2914
8667	5187	9196
8667	5187	9059
8667	5187	6742
8667	5187	5396
8667	5187	7454
8667	5187	4727
8667	5187	6628
8667	5187	2646
8667	5187	4588
16249	5188	1318
16249	5188	7862
16249	5188	1185
16249	5188	8565
16249	5188	5747
16249	5188	516
16249	5188	7958
6707	5189	1122
6707	5189	5248
6707	5189	6686
6707	5189	218
6707	5189	2266
14788	5190	4293
10955	5191	3878
10955	5191	1271
10955	5191	1330
10955	5191	1650
16416	5192	9492
16416	5192	1452
16416	5192	6689
16416	5192	7450
13695	5193	7563
13695	5193	3447
13695	5193	6117
13695	5193	6021
13695	5193	748
13695	5193	4388
13695	5193	6521
13695	5193	790
8676	5194	3134
8676	5194	9915
8676	5194	5926
8676	5194	8776
10246	5195	5763
10246	5195	4284
609	5196	7596
609	5196	6604
609	5196	2300
609	5196	3218
609	5196	1731
9728	5197	4686
6922	5198	8584
6922	5198	3548
15664	5199	8136
15664	5199	7694
15664	5199	4363
13325	5200	3208
13325	5200	9089
13325	5200	8284
5938	5201	6430
5938	5201	3023
13142	5202	4403
13142	5202	1683
13142	5202	3686
13142	5202	8270
13142	5202	3673
13142	5202	4711
13142	5202	1183
13142	5202	8782
14131	5203	35
14131	5203	6347
14131	5203	4505
14131	5203	1477
14131	5203	5941
685	5204	2881
685	5204	3208
685	5204	8156
685	5204	9267
899	5205	720
715	5206	5567
715	5206	4588
715	5206	3006
715	5206	3704
715	5206	6901
715	5206	9289
715	5206	9684
715	5206	3429
3169	5207	4450
3169	5207	3034
3169	5207	3039
2258	5208	9253
2258	5208	8355
2258	5208	9749
2258	5208	9904
2258	5208	306
19189	5209	1763
19189	5209	1880
19189	5209	5139
19189	5209	7666
19189	5209	3666
19189	5209	4823
19189	5209	4453
19189	5209	7834
19189	5209	6968
10644	5210	6682
10644	5210	1441
10644	5210	7634
10644	5210	6582
10644	5210	9733
10644	5210	1314
10644	5210	3425
10644	5210	3264
13859	5211	3634
2934	5212	8553
18956	5213	308
18956	5213	9075
11313	5214	4001
11313	5214	4564
11313	5214	3466
19015	5215	372
6972	5216	3569
6972	5216	4399
10865	5217	7907
10865	5217	6136
10865	5217	5790
10865	5217	4077
10865	5217	8849
10865	5217	7215
10865	5217	6468
10865	5217	1822
4387	5218	5680
4387	5218	3935
4387	5218	7884
11543	5219	3967
11543	5219	9413
11543	5219	2797
11543	5219	1939
11543	5219	4992
11543	5219	5514
11543	5219	3103
11543	5219	7936
11543	5219	3206
5642	5220	2294
5642	5220	2044
5642	5220	8821
5173	5221	4259
5173	5221	19
5173	5221	4157
5173	5221	3929
5173	5221	2744
5173	5221	1354
5173	5221	1423
5173	5221	770
5173	5221	3260
19625	5222	300
19625	5222	9920
19625	5222	2991
19625	5222	1707
19625	5222	5784
19625	5222	1490
19625	5222	3021
19625	5222	7759
19625	5222	4794
12296	5223	5437
12296	5223	2443
12296	5223	5005
12296	5223	8509
12296	5223	9635
12296	5223	8414
12296	5223	7929
12296	5223	5423
2413	5224	7009
2413	5224	1074
2413	5224	5571
2413	5224	5270
2413	5224	2015
14904	5225	6149
14904	5225	2111
3489	5226	1299
3489	5226	9245
3489	5226	1028
3489	5226	7928
3489	5226	8610
3489	5226	5249
3489	5226	9703
3489	5226	5550
15130	5227	5017
15130	5227	4777
15130	5227	9063
16977	5228	6329
16977	5228	679
16977	5228	6650
16977	5228	8755
16977	5228	8335
16977	5228	9513
16977	5228	7047
16977	5228	4403
16977	5228	4187
1552	5229	6100
1552	5229	6342
1552	5229	1406
1552	5229	3650
1552	5229	1449
4255	5230	3834
4255	5230	1193
4255	5230	1669
4255	5230	5753
4255	5230	9920
4255	5230	1312
2947	5231	6651
2947	5231	1601
2947	5231	6143
2947	5231	5156
2947	5231	3043
2947	5231	9770
2947	5231	8732
5132	5232	4735
973	5233	642
973	5233	5547
858	5234	1411
858	5234	2436
858	5234	9669
858	5234	7345
858	5234	4196
858	5234	5718
858	5234	2434
858	5234	5494
858	5234	6156
15352	5235	9116
15352	5235	4674
15352	5235	9335
15352	5235	5091
13002	5236	4054
13002	5236	6936
13002	5236	3439
13002	5236	8513
13002	5236	4060
13002	5236	4497
13002	5236	3003
13002	5236	9780
13002	5236	8329
14889	5237	2107
14889	5237	1846
14889	5237	5580
14889	5237	3699
15504	5238	9151
15504	5238	6165
15504	5238	9961
15504	5238	8608
15504	5238	9777
19111	5239	49
19111	5239	884
19111	5239	2046
19111	5239	3078
17314	5240	5296
17314	5240	1638
17314	5240	5776
17314	5240	3467
6854	5241	7885
6854	5241	8668
6854	5241	1497
6854	5241	6434
6854	5241	4295
6854	5241	3440
6854	5241	307
988	5242	4379
988	5242	3618
988	5242	3132
13196	5243	25
13196	5243	2311
13196	5243	5439
13196	5243	903
13196	5243	7607
3803	5244	8242
3803	5244	8436
7221	5245	4080
7221	5245	5849
7221	5245	4359
7221	5245	3809
7221	5245	7905
7221	5245	9190
7221	5245	1742
7221	5245	1193
7221	5245	1563
83	5246	1960
83	5246	9594
83	5246	7415
83	5246	4007
83	5246	4879
1453	5247	3378
1453	5247	3779
1453	5247	2940
1453	5247	1496
1453	5247	7597
1453	5247	7326
1453	5247	1488
1453	5247	9201
2321	5248	1557
2321	5248	6579
2915	5249	2184
11122	5250	6843
11122	5250	5869
11122	5250	5673
5997	5251	305
5997	5251	4702
5997	5251	2984
9080	5252	103
7502	5253	2697
7502	5253	9557
7502	5253	4737
7502	5253	1740
14826	5254	412
14826	5254	8279
14826	5254	8516
14826	5254	2960
14826	5254	8810
14826	5254	6039
12282	5255	9892
12282	5255	2902
12282	5255	9418
12282	5255	3337
12282	5255	8858
12282	5255	4759
12282	5255	2489
12282	5255	9360
12282	5255	5520
8070	5256	5534
8070	5256	3312
8070	5256	2612
8070	5256	7714
8070	5256	9310
8070	5256	5057
8947	5257	8627
8947	5257	8605
8947	5257	7121
8947	5257	2213
15464	5258	1767
15464	5258	4185
15464	5258	4162
15464	5258	8872
15464	5258	7901
15464	5258	4249
15464	5258	4190
8764	5259	7911
8764	5259	7614
8764	5259	5790
8764	5259	7609
3204	5260	9212
3204	5260	67
3204	5260	4800
3204	5260	893
3204	5260	1001
10499	5261	4555
10499	5261	8827
10499	5261	9512
10499	5261	738
10499	5261	3252
1721	5262	2463
1721	5262	8406
1721	5262	7763
5125	5263	6234
5125	5263	4756
5125	5263	8951
5125	5263	934
5125	5263	6183
5125	5263	1837
5148	5264	9101
5148	5264	609
5148	5264	7753
5148	5264	3894
5148	5264	4745
5148	5264	4630
5148	5264	4218
5148	5264	5775
5148	5264	1031
19963	5265	3486
19963	5265	7634
19963	5265	3165
19963	5265	7897
19963	5265	3880
19963	5265	662
19963	5265	628
19963	5265	7559
4606	5266	2117
4606	5266	6531
4606	5266	846
4606	5266	8422
4606	5266	7543
4606	5266	5659
4606	5266	7181
4606	5266	6351
4606	5266	7423
2605	5267	5791
2605	5267	5404
2605	5267	6394
2605	5267	5652
2605	5267	9176
2605	5267	2965
2605	5267	5660
8161	5268	3791
1943	5269	1317
1943	5269	2437
1943	5269	9272
1943	5269	4635
1943	5269	5555
1943	5269	8411
1943	5269	13
1943	5269	4519
14966	5270	1294
14966	5270	1571
14966	5270	8972
14966	5270	145
14966	5270	6332
14966	5270	8999
14966	5270	8661
15865	5271	2995
15865	5271	9965
15865	5271	2619
15865	5271	5468
15865	5271	9165
15865	5271	4620
15865	5271	4789
15865	5271	2221
15865	5271	8803
17893	5272	9638
17893	5272	5700
17893	5272	2436
17893	5272	6230
17893	5272	919
17893	5272	8222
17893	5272	629
17893	5272	860
49	5273	4084
49	5273	8508
49	5273	4543
12525	5274	4315
12525	5274	501
12525	5274	4192
12525	5274	1007
12525	5274	488
12525	5274	9645
12525	5274	2808
12525	5274	9550
12525	5274	6371
19530	5275	7949
19530	5275	4080
19530	5275	5939
19530	5275	8753
19530	5275	1076
19530	5275	8089
19530	5275	3081
8174	5276	6012
8174	5276	3709
8174	5276	2620
8174	5276	2487
8174	5276	783
1807	5277	9532
1807	5277	9194
1807	5277	9609
1807	5277	7666
1807	5277	1014
1807	5277	2261
1807	5277	8034
1470	5278	3081
1470	5278	3013
1470	5278	8738
1470	5278	4690
6889	5279	147
6889	5279	3663
6889	5279	5427
6889	5279	7288
6889	5279	3956
6889	5279	8846
13758	5280	7614
1388	5281	6394
1388	5281	3280
1388	5281	8499
1388	5281	4528
1388	5281	587
1388	5281	8879
1388	5281	4016
1388	5281	7520
2950	5282	7691
2950	5282	3120
2950	5282	2573
2950	5282	5439
2950	5282	1428
2950	5282	5122
16802	5283	3357
16802	5283	2078
16802	5283	8107
4243	5284	3424
4243	5284	7186
4243	5284	8899
4243	5284	5023
4243	5284	5555
4243	5284	2752
8358	5285	2000
1808	5286	4336
1808	5286	5758
7899	5287	9661
7899	5287	5436
7899	5287	1013
12071	5288	3631
12071	5288	8270
12071	5288	3284
12071	5288	8626
12071	5288	6269
12071	5288	6188
12071	5288	8899
9314	5289	8607
9314	5289	7608
9314	5289	5515
9314	5289	5113
9314	5289	7378
7461	5290	2836
7461	5290	4761
7461	5290	7323
7461	5290	1403
7461	5290	471
7461	5290	4343
3310	5291	6484
8182	5292	7134
8182	5292	648
8182	5292	2847
8182	5292	8241
2153	5293	7196
2153	5293	7551
2153	5293	253
2153	5293	6189
8605	5294	5381
8605	5294	4048
9893	5295	958
9893	5295	8470
9893	5295	1966
9893	5295	762
201	5296	6762
201	5296	3581
201	5296	1106
201	5296	1611
201	5296	4072
18904	5297	3439
18904	5297	8904
18904	5297	1380
18904	5297	303
4536	5298	3638
4536	5298	4527
4536	5298	9328
4536	5298	2256
6722	5299	1856
6722	5299	7776
6722	5299	6200
6722	5299	5724
6722	5299	5793
6722	5299	1185
6722	5299	4489
6722	5299	7021
6722	5299	3755
14785	5300	6564
14785	5300	8397
14785	5300	159
14785	5300	2180
14785	5300	6615
14785	5300	9583
14785	5300	5801
3047	5301	6151
3047	5301	5726
3047	5301	8092
3047	5301	8793
3047	5301	6325
3047	5301	9239
3047	5301	8481
3047	5301	1500
3316	5302	4493
3316	5302	835
3316	5302	4581
3316	5302	9857
3316	5302	8159
3316	5302	5897
3316	5302	1883
19949	5303	1822
19949	5303	5114
19949	5303	4942
19949	5303	6862
2965	5304	8283
2965	5304	4236
2965	5304	6666
2965	5304	5753
7823	5305	8220
7823	5305	3677
16091	5306	8739
16091	5306	6538
16091	5306	5615
16091	5306	121
16091	5306	4882
6329	5307	2282
6329	5307	3181
6329	5307	3997
6329	5307	1946
331	5308	3333
331	5308	3116
331	5308	8612
331	5308	2262
331	5308	5534
11309	5309	3874
11309	5309	6594
11309	5309	8453
11309	5309	2157
12307	5310	1950
12307	5310	9021
12307	5310	7436
12307	5310	4563
12307	5310	2594
12307	5310	2406
12307	5310	8324
12307	5310	2730
13376	5311	776
13376	5311	2150
13376	5311	5771
13376	5311	862
13376	5311	460
13376	5311	1535
13376	5311	4199
3269	5312	2186
3269	5312	1573
3269	5312	356
3269	5312	2532
3269	5312	6768
3269	5312	9773
3269	5312	3592
3269	5312	3964
19467	5313	2414
7897	5314	4503
7897	5314	8304
7897	5314	5151
7897	5314	2912
7897	5314	5082
7897	5314	6619
7897	5314	6352
12248	5315	6672
12248	5315	3071
12248	5315	4151
12248	5315	7086
12248	5315	3625
12248	5315	512
12248	5315	6226
9058	5316	5019
9058	5316	5165
9058	5316	8604
9058	5316	7712
9058	5316	5168
9058	5316	1080
9058	5316	8778
9058	5316	39
8377	5317	752
8377	5317	842
14133	5318	1596
14133	5318	6864
14133	5318	4041
14133	5318	6713
14133	5318	3811
14133	5318	7600
14133	5318	5873
14133	5318	4600
9277	5319	8827
19157	5320	842
19157	5320	9821
19157	5320	3606
939	5321	2498
939	5321	2508
939	5321	9166
939	5321	5287
939	5321	8786
939	5321	9689
939	5321	4525
939	5321	5844
939	5321	7651
15411	5322	2890
15411	5322	891
15411	5322	1749
15411	5322	6965
18924	5323	5770
18924	5323	9191
18924	5323	8725
18924	5323	943
18924	5323	3191
18924	5323	4601
18924	5323	8818
18924	5323	6792
18924	5323	9957
5691	5324	9341
5691	5324	3121
5691	5324	9164
5691	5324	5767
5691	5324	8781
5691	5324	7370
12188	5325	4507
12188	5325	9003
12188	5325	8172
12188	5325	1359
2629	5326	4160
2629	5326	1492
2629	5326	9288
2629	5326	9806
2629	5326	4310
6181	5327	1062
6181	5327	5598
6181	5327	3237
6181	5327	6146
6181	5327	9212
6181	5327	58
6181	5327	9280
6181	5327	1884
6181	5327	4708
12398	5328	812
10242	5329	8211
10242	5329	823
12839	5330	6524
12839	5330	7204
12839	5330	6743
12839	5330	6304
12839	5330	6885
3185	5331	7791
3185	5331	9748
3185	5331	3123
3185	5331	3723
3185	5331	252
3185	5331	71
3185	5331	1207
3185	5331	7493
3185	5331	6765
7936	5332	1229
7936	5332	2677
7936	5332	4243
7936	5332	9706
7936	5332	9257
7936	5332	2247
10738	5333	3412
10738	5333	1755
10738	5333	9263
10738	5333	5282
10738	5333	448
10738	5333	772
10738	5333	6015
10738	5333	7016
10738	5333	6578
1640	5334	9293
1640	5334	2559
1640	5334	8198
1640	5334	6909
1640	5334	8479
468	5335	3195
468	5335	342
468	5335	1130
468	5335	4003
2037	5336	711
2037	5336	9034
2037	5336	4805
2037	5336	9840
2037	5336	9866
2037	5336	6021
2037	5336	4172
2037	5336	7095
1792	5337	9979
1792	5337	1570
1792	5337	3537
1792	5337	8251
1792	5337	6591
1792	5337	3387
1792	5337	2380
1792	5337	7949
15577	5338	5826
19996	5339	8494
19996	5339	5376
19996	5339	7729
19996	5339	2999
19996	5339	6462
9426	5340	7350
9426	5340	8765
13427	5341	4502
13427	5341	8871
13427	5341	2029
13427	5341	325
13427	5341	737
13427	5341	6898
13427	5341	9393
13427	5341	1466
15855	5342	2640
15855	5342	260
15855	5342	5728
15855	5342	9719
15855	5342	5737
15855	5342	1500
15855	5342	8091
15855	5342	566
1780	5343	9708
1780	5343	3475
1780	5343	8739
1780	5343	1492
1780	5343	2868
1780	5343	1461
1780	5343	1052
13557	5344	19
13557	5344	1846
13557	5344	6719
13557	5344	1888
13557	5344	56
14542	5345	1384
14542	5345	6982
14542	5345	4290
14542	5345	2786
14542	5345	8892
14542	5345	2665
14542	5345	5967
14542	5345	6722
13480	5346	8258
13480	5346	5158
13480	5346	7192
13480	5346	8658
13480	5346	2484
7733	5347	3989
13549	5348	1021
13549	5348	7536
13549	5348	6156
13549	5348	3697
13549	5348	996
13549	5348	4752
13549	5348	6794
7970	5349	9350
7970	5349	2590
7970	5349	1471
7970	5349	2823
7970	5349	4647
7970	5349	2234
7970	5349	9117
7970	5349	7971
8252	5350	3657
8252	5350	823
8252	5350	1157
8252	5350	8317
6877	5351	1043
5028	5352	7973
5028	5352	7892
5028	5352	2295
5028	5352	3460
5028	5352	3660
5028	5352	4392
16096	5353	6456
16096	5353	6075
16096	5353	8182
16096	5353	8212
16096	5353	8625
16096	5353	7992
16096	5353	1768
16096	5353	8537
12856	5354	3436
14190	5355	1662
14190	5355	2982
14190	5355	3203
14190	5355	5760
14190	5355	4211
4844	5356	1676
4844	5356	7747
4844	5356	4390
4844	5356	3185
4844	5356	2711
4844	5356	2649
6383	5357	8126
6383	5357	8387
6383	5357	3035
6383	5357	545
9510	5358	7177
9510	5358	3396
9510	5358	2195
9510	5358	2296
9510	5358	7425
9510	5358	8956
9510	5358	8612
9510	5358	6281
19043	5359	4424
19043	5359	4029
19043	5359	8768
19267	5360	7453
19267	5360	2457
19267	5360	5355
19267	5360	1990
19267	5360	1236
19267	5360	3131
19267	5360	9549
19267	5360	1797
19267	5360	6891
11365	5361	2861
11365	5361	7233
11365	5361	8115
11365	5361	1262
11365	5361	2472
11365	5361	3945
11365	5361	9561
11365	5361	9581
11365	5361	6950
161	5362	1823
17425	5363	4395
17425	5363	1470
17404	5364	2187
9316	5365	9587
9316	5365	1253
16404	5366	8283
209	5367	8817
209	5367	9483
209	5367	2108
209	5367	466
209	5367	9654
209	5367	5130
209	5367	9492
209	5367	6498
12169	5368	5252
12169	5368	4548
12169	5368	7666
12169	5368	6229
12169	5368	2934
12169	5368	6901
12766	5369	7335
12766	5369	9891
12766	5369	4776
12766	5369	8829
12766	5369	8160
6506	5370	9599
6506	5370	6115
6506	5370	1899
6506	5370	6976
6506	5370	2892
6506	5370	8154
6506	5370	1660
6506	5370	6175
6506	5370	6705
13189	5371	1615
13189	5371	1090
13189	5371	4653
13189	5371	3028
13189	5371	3086
13189	5371	2726
13189	5371	6772
7493	5372	3656
7493	5372	5664
7493	5372	2280
7493	5372	1937
7493	5372	5349
7493	5372	5578
14386	5373	6968
14386	5373	5604
17377	5374	7889
17377	5374	3238
17377	5374	3137
17377	5374	6740
17377	5374	6893
17377	5374	2108
17377	5374	4243
17377	5374	8156
7467	5375	927
7467	5375	737
7467	5375	437
7467	5375	7888
7467	5375	5029
7467	5375	4940
7467	5375	9898
7467	5375	3785
1049	5376	2929
14341	5377	6761
14341	5377	2120
14341	5377	2848
14341	5377	2809
14341	5377	939
14341	5377	9924
14341	5377	9570
14341	5377	9334
18462	5378	2265
18462	5378	2178
10211	5379	2276
10211	5379	6528
10211	5379	4016
10211	5379	1235
10211	5379	1694
10211	5379	447
10211	5379	7288
10211	5379	1459
1584	5380	23
1584	5380	4845
1584	5380	905
17630	5381	6957
17630	5381	8412
17630	5381	3439
17630	5381	2132
17630	5381	9290
17630	5381	8716
17630	5381	6458
17630	5381	107
10860	5382	8622
10860	5382	8279
10860	5382	1019
10860	5382	488
5229	5383	7017
5229	5383	8438
5229	5383	4644
5229	5383	5129
5229	5383	4395
1705	5384	8769
1705	5384	9206
1705	5384	6931
1705	5384	6209
14455	5385	2626
14455	5385	4396
2824	5386	1868
2824	5386	6349
2824	5386	7222
2824	5386	839
2824	5386	1596
2824	5386	4666
7744	5387	1699
5984	5388	4773
5984	5388	2308
5984	5388	332
5984	5388	580
5984	5388	5429
5984	5388	2266
5984	5388	9443
5984	5388	2521
5984	5388	377
10085	5389	8914
10085	5389	4675
10085	5389	6370
10085	5389	3605
16755	5390	7545
16755	5390	2077
16755	5390	858
6246	5391	2610
5972	5392	8029
5972	5392	5617
581	5393	493
581	5393	6734
581	5393	9537
581	5393	3041
581	5393	163
581	5393	5206
581	5393	2622
581	5393	4143
581	5393	5790
12170	5394	7347
12170	5394	21
12170	5394	4709
12170	5394	3253
12170	5394	1825
12170	5394	3423
12170	5394	4358
12170	5394	6841
12170	5394	41
10491	5395	1022
10491	5395	7040
10491	5395	8917
10491	5395	2896
10491	5395	370
782	5396	3129
782	5396	3391
13627	5397	9773
13627	5397	1957
13627	5397	7355
13627	5397	5059
13627	5397	9606
13291	5398	7392
13291	5398	5112
13291	5398	6029
13291	5398	8152
13291	5398	2659
13291	5398	5690
11782	5399	450
11782	5399	99
11782	5399	2448
11782	5399	6877
11782	5399	2830
11782	5399	3586
11782	5399	3128
11782	5399	6828
11782	5399	2264
16584	5400	7525
16584	5400	7712
16584	5400	2178
16584	5400	9105
16584	5400	3693
16584	5400	7675
245	5401	7629
245	5401	5319
245	5401	4444
245	5401	7691
245	5401	8965
245	5401	3211
245	5401	8246
245	5401	3676
2774	5402	5333
2774	5402	25
2774	5402	7643
2774	5402	2816
2774	5402	7822
10899	5403	6664
10899	5403	2205
10899	5403	3848
10899	5403	4308
5105	5404	8322
5105	5404	3477
17619	5405	7835
17619	5405	9257
14155	5406	2527
18380	5407	3544
18380	5407	8214
18380	5407	6323
18380	5407	403
18380	5407	8717
18380	5407	6609
18380	5407	6030
2848	5408	4461
2848	5408	9486
2848	5408	6032
2848	5408	8181
2848	5408	7035
2848	5408	7748
2848	5408	63
2848	5408	1716
16076	5409	8100
16076	5409	8268
16076	5409	5813
16076	5409	2849
16076	5409	5722
16076	5409	5650
16076	5409	1500
16076	5409	7284
16076	5409	9329
12725	5410	8814
12725	5410	5128
12725	5410	6823
12725	5410	8567
13332	5411	1374
13332	5411	6378
4199	5412	2282
4199	5412	8756
4199	5412	5798
4199	5412	5029
7024	5413	2058
7024	5413	3788
7024	5413	5118
17860	5414	1010
17860	5414	7109
17860	5414	4614
17860	5414	9487
17860	5414	8701
17860	5414	9647
10889	5415	7331
10889	5415	9874
10889	5415	3245
10889	5415	3904
10889	5415	811
10889	5415	9386
16810	5416	8798
16810	5416	6348
16810	5416	9556
16810	5416	4791
16810	5416	7603
16810	5416	5713
16810	5416	9883
16810	5416	5298
16810	5416	1238
8964	5417	1514
8964	5417	3191
8964	5417	9329
8964	5417	9305
16203	5418	1512
16203	5418	2283
16203	5418	8982
16203	5418	741
16203	5418	8821
16203	5418	5946
14366	5419	1665
14366	5419	2271
14366	5419	4305
14366	5419	4078
14366	5419	6602
14366	5419	329
14366	5419	1483
14366	5419	3151
10866	5420	5318
10866	5420	5899
3688	5421	9027
3688	5421	6596
3688	5421	3939
3688	5421	3870
3688	5421	4327
3688	5421	1878
3688	5421	1329
3688	5421	7631
1563	5422	6215
1563	5422	7134
1563	5422	5140
1563	5422	5671
1563	5422	4876
1563	5422	4293
1778	5423	9756
1778	5423	3656
1778	5423	6409
1778	5423	5011
1778	5423	7739
2886	5424	7372
2886	5424	1457
2886	5424	1169
2886	5424	7537
2886	5424	2394
2886	5424	767
4479	5425	7652
2614	5426	6840
2614	5426	3516
2614	5426	9065
2614	5426	6021
2614	5426	418
2614	5426	2125
6587	5427	133
6587	5427	7847
6587	5427	7550
6587	5427	3138
6587	5427	5068
8875	5428	216
8875	5428	292
8875	5428	3514
8875	5428	7795
16424	5429	86
16424	5429	7262
16424	5429	6258
16424	5429	9417
13933	5430	2091
13933	5430	2220
8631	5431	3252
8631	5431	1715
8631	5431	8063
8631	5431	6300
8631	5431	7721
8631	5431	3875
8631	5431	49
8631	5431	6361
11555	5432	2744
11555	5432	8252
11555	5432	2005
11555	5432	9381
11555	5432	4786
11555	5432	7758
11555	5432	6501
9128	5433	4471
16690	5434	9481
16020	5435	4832
16020	5435	5762
16020	5435	4222
16020	5435	3554
16020	5435	7540
16020	5435	1397
16020	5435	6376
2356	5436	2279
2356	5436	449
2356	5436	5277
2356	5436	2980
19319	5437	6749
19319	5437	1853
19319	5437	681
8468	5438	2573
8468	5438	3113
8468	5438	8970
8468	5438	127
8468	5438	1629
8468	5438	8362
8468	5438	5009
8468	5438	7032
5706	5439	5319
5706	5439	8759
18879	5440	3673
18879	5440	5001
18879	5440	3993
18879	5440	5194
18879	5440	5994
18879	5440	4393
18879	5440	7725
5467	5441	722
5467	5441	9584
5467	5441	5948
5467	5441	2765
5467	5441	2072
5467	5441	4146
5467	5441	6856
3712	5442	9969
3712	5442	5193
3712	5442	4578
4605	5443	5036
4605	5443	15
4605	5443	3521
18936	5444	4175
18936	5444	6562
18936	5444	1888
18936	5444	6138
18936	5444	5273
18936	5444	2356
18936	5444	9459
8072	5445	6338
8072	5445	8074
8072	5445	8208
8072	5445	7130
8072	5445	7687
4370	5446	8756
4370	5446	3690
4370	5446	8124
4370	5446	767
4370	5446	28
18973	5447	3522
18973	5447	4634
18973	5447	7278
18973	5447	1234
18973	5447	796
18973	5447	7214
18973	5447	9619
18973	5447	667
18973	5447	3780
14938	5448	7296
14648	5449	6810
14648	5449	2473
14648	5449	2426
19407	5450	5189
19407	5450	9788
18812	5451	7170
18812	5451	9177
18812	5451	2059
18812	5451	234
18812	5451	71
18812	5451	6678
18812	5451	6855
18812	5451	8645
18812	5451	3820
8023	5452	5436
8023	5452	6854
8023	5452	8365
8023	5452	4630
8023	5452	5699
8023	5452	3766
11649	5453	5179
11649	5453	5896
5500	5454	2077
5500	5454	7925
5500	5454	3176
5500	5454	4755
5500	5454	4662
5500	5454	3835
5500	5454	7552
6500	5455	8126
6500	5455	1792
6500	5455	3371
6500	5455	6427
6500	5455	8828
6500	5455	2017
8187	5456	2603
8187	5456	8113
8187	5456	5122
8187	5456	8966
8187	5456	5800
8187	5456	7419
8187	5456	9767
8187	5456	3969
8187	5456	9380
5500	5457	2017
5500	5457	1196
5500	5457	5730
5500	5457	8126
5500	5457	2100
5500	5457	5577
1396	5458	9654
1396	5458	3568
1396	5458	6787
1396	5458	4753
1396	5458	1227
1396	5458	6515
1396	5458	6882
17796	5459	2931
17796	5459	1800
17796	5459	5598
17796	5459	1784
17796	5459	4112
17796	5459	1872
17796	5459	6921
17796	5459	5885
17796	5459	8598
6701	5460	7483
6701	5460	6409
6701	5460	9187
6701	5460	3262
6701	5460	3443
10484	5461	9142
10484	5461	3293
10329	5462	6690
10329	5462	6309
10329	5462	8907
10329	5462	8638
10329	5462	5181
10329	5462	2274
2919	5463	1449
2919	5463	9937
2919	5463	4602
2919	5463	89
6762	5464	8545
6762	5464	937
6762	5464	3583
6762	5464	522
6762	5464	7377
5115	5465	4147
5115	5465	8554
5115	5465	9508
5115	5465	9424
5115	5465	7971
5115	5465	6629
5115	5465	7768
9527	5466	2110
9527	5466	5219
9527	5466	6142
9527	5466	8181
9527	5466	4900
9527	5466	6075
9527	5466	96
9527	5466	5941
9527	5466	286
19420	5467	3735
19420	5467	4680
19420	5467	4364
19420	5467	6266
19420	5467	6103
19420	5467	1219
14720	5468	878
14720	5468	5250
14720	5468	2139
16159	5469	3527
16159	5469	7170
16159	5469	9264
16159	5469	9939
16159	5469	2407
16159	5469	62
16159	5469	6624
15685	5470	5203
15685	5470	3364
17227	5471	3958
17227	5471	6726
17227	5471	7667
17227	5471	595
17227	5471	8671
17227	5471	5741
17227	5471	3801
17227	5471	2910
19067	5472	7376
19067	5472	4984
19067	5472	2060
19067	5472	8659
3381	5473	1897
19126	5474	4399
19126	5474	9322
19126	5474	1470
19126	5474	8286
19126	5474	6985
19126	5474	3913
19126	5474	8973
19126	5474	4526
19126	5474	3867
5050	5475	4216
5050	5475	181
5050	5475	6304
5050	5475	5675
5050	5475	8514
5050	5475	3355
5050	5475	211
5050	5475	957
5050	5475	9204
6233	5476	4405
6233	5476	6528
6233	5476	6065
2434	5477	3583
2434	5477	1124
2434	5477	7325
2434	5477	381
2434	5477	6870
14162	5478	5577
14162	5478	2571
14162	5478	879
14162	5478	1750
14162	5478	7005
6138	5479	4286
6138	5479	9364
6138	5479	3475
6138	5479	7755
16270	5480	1870
16270	5480	1235
16270	5480	4939
16270	5480	8192
18140	5481	4354
18140	5481	6016
18140	5481	5108
18140	5481	2261
18140	5481	8324
18140	5481	7263
18140	5481	2110
18789	5482	3549
18789	5482	9543
18789	5482	5449
18789	5482	1595
18789	5482	1990
18789	5482	2711
18789	5482	5321
18789	5482	9063
18789	5482	4972
14465	5483	8856
14465	5483	4581
14465	5483	5843
17988	5484	4015
17988	5484	8691
17988	5484	434
17988	5484	3104
11627	5485	2877
11627	5485	4525
11627	5485	2682
12492	5486	7072
12492	5486	4902
12492	5486	3524
12492	5486	1909
11845	5487	5386
11845	5487	8145
11845	5487	8744
11845	5487	4303
11845	5487	9202
11845	5487	6702
11845	5487	5029
11845	5487	2710
8950	5488	821
8950	5488	5616
8950	5488	4209
6755	5489	1237
18764	5490	5395
18764	5490	3420
18764	5490	8803
18764	5490	8322
18764	5490	9505
10267	5491	7834
10267	5491	6932
10267	5491	670
10267	5491	973
10267	5491	4517
10267	5491	5113
10267	5491	3250
10267	5491	5135
1059	5492	5125
6892	5493	4477
6892	5493	5003
6892	5493	6749
6892	5493	6308
6892	5493	6286
6892	5493	4820
6892	5493	1925
6892	5493	1676
6892	5493	5090
449	5494	754
449	5494	5702
449	5494	8681
449	5494	9324
449	5494	5937
1879	5495	3776
1879	5495	2697
1879	5495	7066
1879	5495	7320
1879	5495	6852
1879	5495	6028
1879	5495	3920
1879	5495	2165
1879	5495	120
11643	5496	1889
11643	5496	9286
11643	5496	1921
11643	5496	8764
11643	5496	572
11643	5496	5790
5711	5497	1846
5711	5497	8915
5711	5497	9577
5711	5497	2535
5711	5497	2247
5711	5497	4660
5711	5497	8475
5711	5497	5127
5711	5497	1576
6992	5498	9198
6992	5498	9491
6992	5498	9805
6992	5498	7843
6992	5498	2013
6992	5498	8224
6992	5498	7561
190	5499	2749
190	5499	5354
190	5499	7656
190	5499	1586
190	5499	4891
190	5499	2727
3847	5500	6911
3847	5500	8308
3847	5500	7785
3847	5500	4441
3847	5500	1247
3847	5500	3807
6695	5501	7547
6695	5501	6067
6695	5501	6848
6695	5501	4433
6695	5501	7426
8300	5502	365
8300	5502	7183
8300	5502	746
8300	5502	8992
8300	5502	975
8300	5502	7188
8300	5502	5245
8300	5502	8129
8300	5502	4128
389	5503	7847
389	5503	1212
389	5503	2470
389	5503	9422
389	5503	3793
389	5503	7546
389	5503	8459
389	5503	5943
389	5503	3478
1330	5504	9949
1330	5504	9191
1330	5504	5503
12760	5505	1691
12760	5505	7389
13622	5506	6597
10111	5507	2505
10111	5507	3933
10111	5507	5691
10111	5507	3124
10111	5507	5458
10111	5507	9715
10111	5507	4130
10839	5508	7921
10839	5508	3190
10839	5508	300
10839	5508	4326
10839	5508	2160
10839	5508	1953
10839	5508	2415
10839	5508	8734
10839	5508	4649
15545	5509	86
15545	5509	8395
15545	5509	3761
15545	5509	9635
15545	5509	4764
15545	5509	3351
15545	5509	1782
12214	5510	1506
12214	5510	2722
12214	5510	6957
12214	5510	268
12214	5510	5879
12214	5510	9379
12214	5510	9681
12214	5510	5719
12214	5510	3680
6630	5511	870
6630	5511	6527
6630	5511	6343
6630	5511	8759
6630	5511	2394
6630	5511	9390
6630	5511	4185
6630	5511	6570
4897	5512	8391
4897	5512	6795
4897	5512	4454
4897	5512	3588
4897	5512	3789
4897	5512	6837
4897	5512	5620
3924	5513	8852
3924	5513	6334
3924	5513	4252
3924	5513	4589
3924	5513	4970
3924	5513	3270
3320	5514	5769
3320	5514	7141
3320	5514	762
3320	5514	2284
3320	5514	5588
3320	5514	961
15408	5515	6841
15408	5515	6958
15408	5515	5818
15408	5515	1914
15408	5515	4087
15408	5515	2455
15408	5515	6843
15408	5515	624
15528	5516	8693
15528	5516	1359
15528	5516	2153
15528	5516	7179
12291	5517	1446
12291	5517	7955
12291	5517	9238
12291	5517	8050
12291	5517	5051
12291	5517	7283
12291	5517	1003
8002	5518	7761
8002	5518	721
8002	5518	8643
8002	5518	1438
8002	5518	4891
8002	5518	1967
6823	5519	674
6823	5519	6147
6823	5519	5879
6823	5519	9227
6823	5519	3091
6823	5519	1067
13473	5520	1099
13473	5520	1110
5094	5521	4008
5094	5521	8175
5094	5521	940
3227	5522	337
3227	5522	5953
3227	5522	3085
3227	5522	9793
3227	5522	6638
1405	5523	5488
1405	5523	1728
14581	5524	4819
14581	5524	6007
14581	5524	5362
14581	5524	7372
15418	5525	7272
15418	5525	4366
15418	5525	6566
15418	5525	1088
15418	5525	1705
14386	5526	340
14386	5526	8458
6553	5527	9035
6553	5527	8189
6553	5527	4675
6553	5527	4116
2775	5528	8452
2775	5528	8250
2775	5528	437
2775	5528	6640
2775	5528	7148
2775	5528	1044
2775	5528	4753
4639	5529	5893
4639	5529	8697
4639	5529	8220
4639	5529	1641
9045	5530	1770
9045	5530	6776
9045	5530	1713
9045	5530	9974
14243	5531	4608
14243	5531	7635
14243	5531	6286
14243	5531	1559
14243	5531	2226
14243	5531	6260
14243	5531	3626
14243	5531	2779
13001	5532	8674
13001	5532	4211
13001	5532	8781
13001	5532	8739
15904	5533	1919
15904	5533	4044
15904	5533	2051
15904	5533	382
15904	5533	5858
15904	5533	4720
14997	5534	3999
14997	5534	1154
14997	5534	6843
14997	5534	3059
14997	5534	9548
14997	5534	1493
14997	5534	9749
3334	5535	9871
505	5536	6894
505	5536	1751
505	5536	5678
19353	5537	2349
19353	5537	4915
19353	5537	9973
19353	5537	7204
19353	5537	5315
19353	5537	6961
19353	5537	8620
19353	5537	2889
19353	5537	3279
13477	5538	4919
13477	5538	7071
13477	5538	5551
13477	5538	273
13477	5538	5018
13477	5538	7408
14760	5539	8845
14760	5539	2185
14760	5539	1788
14760	5539	9900
14760	5539	9294
16073	5540	3672
16073	5540	8860
16073	5540	5431
16073	5540	6210
16073	5540	7469
9753	5541	2256
9753	5541	1584
9753	5541	5262
9753	5541	6906
9753	5541	4572
9753	5541	1726
11401	5542	1243
11401	5542	4736
11401	5542	6316
11401	5542	4513
11401	5542	5870
11401	5542	3752
11401	5542	6858
11401	5542	546
11401	5542	465
11451	5543	2775
11451	5543	3926
11451	5543	4335
11451	5543	200
11451	5543	3810
11451	5543	1809
11451	5543	1544
12114	5544	8039
12114	5544	8777
12114	5544	9312
12114	5544	4011
12114	5544	1452
14699	5545	7819
14699	5545	2774
14699	5545	9179
14699	5545	8388
14699	5545	4415
14699	5545	1534
14699	5545	8320
14699	5545	2016
108	5546	4951
108	5546	2927
108	5546	2455
108	5546	3185
9058	5547	9799
9058	5547	1698
9058	5547	1978
9058	5547	1966
9058	5547	280
9058	5547	2351
9058	5547	3746
9058	5547	7567
9058	5547	4420
18740	5548	8331
18740	5548	9482
18740	5548	4025
18740	5548	6044
18740	5548	754
4901	5549	2535
4901	5549	7629
19959	5550	4346
19959	5550	2601
19959	5550	9917
19959	5550	8136
12932	5551	7981
12932	5551	573
12932	5551	3880
12932	5551	9867
12932	5551	3777
12932	5551	4375
12932	5551	1469
12932	5551	9126
12932	5551	1983
12656	5552	5094
12656	5552	3159
12656	5552	2968
12656	5552	9694
12656	5552	2405
12656	5552	6192
12656	5552	1699
12656	5552	4303
16158	5553	4390
16158	5553	9588
16158	5553	9470
16158	5553	4056
16158	5553	7898
16158	5553	3630
16158	5553	3013
11960	5554	8547
11960	5554	3588
11960	5554	5211
11960	5554	4811
11960	5554	6851
11960	5554	7593
3965	5555	5498
3965	5555	6763
3965	5555	5537
3965	5555	3129
3965	5555	7652
7742	5556	9784
7742	5556	8016
7742	5556	5407
7742	5556	8657
7742	5556	2740
7742	5556	8238
7686	5557	9036
7686	5557	9713
7686	5557	7366
7686	5557	460
7686	5557	4415
7686	5557	6636
7686	5557	1982
7686	5557	6150
7686	5557	9424
9662	5558	5048
9662	5558	9301
9662	5558	465
9662	5558	7128
12327	5559	1962
12327	5559	2294
12327	5559	8450
12327	5559	532
12327	5559	7076
12327	5559	3842
12327	5559	4278
18828	5560	3207
18828	5560	4914
18828	5560	6429
18828	5560	415
18828	5560	8157
17495	5561	6704
17495	5561	4103
9267	5562	7146
2846	5563	837
2846	5563	6266
2359	5564	6558
2359	5564	8570
2359	5564	4712
2359	5564	3462
2359	5564	9971
8147	5565	8707
11704	5566	7275
11704	5566	6823
11704	5566	2421
11704	5566	2155
11704	5566	4267
1648	5567	5538
1648	5567	2876
1648	5567	9884
1648	5567	9164
1648	5567	6920
11252	5568	1478
11252	5568	3437
11252	5568	6655
11252	5568	6864
11252	5568	3346
11252	5568	79
11252	5568	7723
11252	5568	8436
7947	5569	2972
7947	5569	6404
7947	5569	129
7947	5569	6617
13310	5570	6329
5966	5571	2058
5966	5571	5061
5966	5571	9728
5966	5571	8232
5966	5571	6176
5966	5571	2137
10217	5572	7244
10217	5572	2198
10217	5572	715
10217	5572	516
10217	5572	1574
10217	5572	4303
10217	5572	9827
10217	5572	6796
3713	5573	4640
3713	5573	3080
3713	5573	1164
3713	5573	765
3713	5573	325
15138	5574	1430
15138	5574	5853
15138	5574	4614
15138	5574	8789
15138	5574	8179
9948	5575	6830
9948	5575	2095
9948	5575	6769
9948	5575	2285
9948	5575	391
9948	5575	1567
9948	5575	7421
11058	5576	4352
11058	5576	1658
11058	5576	2058
11058	5576	7881
11058	5576	9061
11058	5576	5210
11058	5576	7048
11058	5576	4077
11058	5576	3509
11585	5577	8842
11585	5577	5422
11585	5577	4419
11585	5577	1792
11585	5577	3420
10155	5578	5524
10155	5578	124
10155	5578	2858
10155	5578	4144
10155	5578	7373
10155	5578	9047
10155	5578	9066
10155	5578	6674
10155	5578	8069
6981	5579	7196
6981	5579	5803
6981	5579	9711
9636	5580	7806
9636	5580	5801
19887	5581	8164
19887	5581	7232
19887	5581	2978
19887	5581	5072
19887	5581	9419
19887	5581	4537
3464	5582	2348
3464	5582	5297
17636	5583	2463
17636	5583	7761
17636	5583	4999
17636	5583	7792
17636	5583	7944
17636	5583	391
17636	5583	8928
16693	5584	9542
16693	5584	8236
16693	5584	6246
16693	5584	8780
16693	5584	8623
16693	5584	361
5646	5585	4264
5646	5585	1257
5646	5585	1095
2971	5586	6948
2971	5586	4352
2971	5586	8592
2971	5586	248
2971	5586	8199
2971	5586	7410
12063	5587	3909
12063	5587	1219
12063	5587	3144
12063	5587	4774
12063	5587	7538
12063	5587	3600
12063	5587	7354
12063	5587	622
9948	5588	8868
9948	5588	1227
9948	5588	6709
9948	5588	4044
18185	5589	9308
18185	5589	5418
18185	5589	9842
18185	5589	6851
18185	5589	6060
18185	5589	1996
18185	5589	4170
18185	5589	7713
15360	5590	7895
15360	5590	3525
15360	5590	4240
15360	5590	9347
15360	5590	6661
15360	5590	7483
5801	5591	3092
5801	5591	4066
5801	5591	5720
5801	5591	2563
5801	5591	8679
5801	5591	9867
5801	5591	7956
11700	5592	453
11700	5592	3821
11700	5592	2995
11700	5592	2287
11700	5592	6449
11700	5592	3378
12938	5593	5620
12938	5593	5945
12938	5593	5747
12938	5593	8458
12938	5593	893
12938	5593	9858
12938	5593	2263
12938	5593	9873
12938	5593	3794
13578	5594	7266
13578	5594	3933
13578	5594	5491
13578	5594	7112
13578	5594	9635
11160	5595	203
11160	5595	2846
11160	5595	5784
11160	5595	4716
11160	5595	2409
11160	5595	762
11160	5595	8281
4908	5596	3076
17133	5597	4195
17133	5597	742
17133	5597	6977
17133	5597	2913
17133	5597	1026
17133	5597	8276
17133	5597	8462
17133	5597	4856
11235	5598	8895
11235	5598	8314
11235	5598	320
11235	5598	8984
11235	5598	9956
11235	5598	9231
19944	5599	1627
19944	5599	6300
19944	5599	8502
19944	5599	9461
19944	5599	7566
19944	5599	7833
19944	5599	9933
19944	5599	1004
19944	5599	4969
10577	5600	6508
10577	5600	5529
10577	5600	4811
10577	5600	5710
10577	5600	6791
6181	5601	7666
6181	5601	2849
6181	5601	3764
6181	5601	376
6181	5601	5587
6181	5601	2524
16646	5602	3106
16646	5602	2063
13746	5603	1514
13746	5603	1134
13746	5603	6186
13746	5603	4784
15264	5604	8313
15264	5604	8030
15264	5604	836
15264	5604	4454
593	5605	2647
593	5605	615
13840	5606	16
13840	5606	2280
13840	5606	6789
13840	5606	52
18267	5607	8590
18267	5607	6907
18267	5607	274
18299	5608	1131
18299	5608	8884
18299	5608	5039
18299	5608	8666
17362	5609	4882
17362	5609	3476
17362	5609	9384
17362	5609	4067
17362	5609	1178
17362	5609	796
2138	5610	218
2138	5610	6927
2138	5610	5405
886	5611	14
886	5611	440
10643	5612	255
8643	5613	6978
8643	5613	8015
8643	5613	9600
8643	5613	2097
8643	5613	8561
8643	5613	1166
8643	5613	4832
8643	5613	4408
8643	5613	6020
12918	5614	1781
12918	5614	9778
12918	5614	3612
12918	5614	6356
12918	5614	8461
12918	5614	9879
12918	5614	2393
12918	5614	3935
12918	5614	9296
923	5615	4721
923	5615	9736
923	5615	5290
923	5615	7199
923	5615	1018
923	5615	1913
923	5615	1014
923	5615	9325
15570	5616	4260
15570	5616	6227
15570	5616	7583
15570	5616	690
15570	5616	5984
15570	5616	9436
15570	5616	8019
6616	5617	8271
6616	5617	7622
6616	5617	2807
6616	5617	5707
6616	5617	6004
6616	5617	9917
6616	5617	9327
6616	5617	9801
14768	5618	8477
14768	5618	210
14768	5618	7763
18413	5619	7850
18413	5619	91
18413	5619	9989
18413	5619	4105
18413	5619	5030
18413	5619	8273
18413	5619	6816
18413	5619	9122
2985	5620	4553
2985	5620	1288
2985	5620	389
2985	5620	2990
9051	5621	4332
9051	5621	1577
9051	5621	8541
9051	5621	15
9051	5621	5791
9051	5621	8516
15275	5622	9130
15275	5622	3270
15275	5622	5698
15275	5622	8444
15275	5622	3609
15275	5622	3560
15275	5622	5959
15275	5622	7972
15275	5622	4754
6589	5623	6865
6589	5623	2912
6589	5623	3625
6589	5623	3017
6589	5623	7840
2219	5624	5667
2219	5624	7850
2819	5625	521
2819	5625	1952
13122	5626	1185
13122	5626	4907
13122	5626	813
13122	5626	2895
1469	5627	1844
1469	5627	9206
1469	5627	6073
1469	5627	6786
1469	5627	8465
1469	5627	3438
1469	5627	7037
11392	5628	9583
11392	5628	8259
11392	5628	7232
252	5629	861
252	5629	1838
252	5629	678
252	5629	214
13999	5630	4925
13999	5630	5548
13999	5630	7354
13999	5630	7658
13999	5630	2633
13999	5630	2439
19340	5631	9796
19340	5631	9144
19340	5631	1740
19340	5631	3360
19340	5631	2025
247	5632	6687
247	5632	9658
247	5632	7459
247	5632	2041
247	5632	6316
247	5632	2357
247	5632	5566
11057	5633	8392
11057	5633	8875
11057	5633	8960
11057	5633	2548
11057	5633	5808
11057	5633	1107
11057	5633	9409
11057	5633	1877
18671	5634	4452
18671	5634	6742
4614	5635	7836
4614	5635	7790
4614	5635	7705
4614	5635	6358
4614	5635	8899
4614	5635	7648
4614	5635	621
4614	5635	1085
4614	5635	6547
13148	5636	8642
13148	5636	7568
13148	5636	3556
13148	5636	7691
13148	5636	8287
12152	5637	2740
12152	5637	8544
12381	5638	4945
12381	5638	7665
12381	5638	389
12381	5638	8065
12381	5638	1935
12381	5638	9433
12381	5638	2090
19561	5639	5306
19561	5639	2580
19561	5639	3491
19561	5639	5167
19561	5639	6958
19561	5639	8224
6336	5640	4659
6336	5640	4241
6336	5640	3803
6336	5640	9430
6336	5640	5679
6336	5640	6224
6336	5640	1300
13210	5641	3662
13210	5641	8300
13210	5641	794
18034	5642	2185
13686	5643	9566
13686	5643	8724
13686	5643	7442
7330	5644	7324
7330	5644	8420
4163	5645	910
4163	5645	5234
4163	5645	1165
4163	5645	2746
4163	5645	3078
4163	5645	192
4163	5645	3601
4163	5645	7687
4163	5645	8754
18537	5646	1083
18537	5646	3723
18537	5646	8711
18537	5646	1584
18537	5646	5378
1222	5647	4403
1222	5647	6727
1222	5647	8212
1222	5647	961
17295	5648	3775
17295	5648	4698
17295	5648	5889
17295	5648	8684
17295	5648	5282
13731	5649	9359
7543	5650	931
7543	5650	2882
7543	5650	6693
7543	5650	955
7543	5650	2489
12528	5651	8831
12528	5651	9276
12528	5651	1456
12528	5651	4909
4735	5652	2039
10175	5653	4862
10175	5653	4625
10175	5653	9980
10175	5653	4924
10175	5653	673
13257	5654	8474
13257	5654	5078
13257	5654	1050
13257	5654	6397
13257	5654	2354
13257	5654	3253
13257	5654	1109
8731	5655	504
8731	5655	5897
8731	5655	3492
8731	5655	2952
3368	5656	9247
3368	5656	8253
18604	5657	1774
18604	5657	8845
18604	5657	1057
18604	5657	2831
18604	5657	4318
18604	5657	4878
1549	5658	1595
1549	5658	1686
1549	5658	9941
1549	5658	7898
1549	5658	1743
1549	5658	3512
1549	5658	5451
14449	5659	2251
14449	5659	5326
14449	5659	6079
14449	5659	1200
14449	5659	4465
19538	5660	8025
19538	5660	9464
19538	5660	6914
17312	5661	9594
12245	5662	1496
12245	5662	8515
12245	5662	3517
9432	5663	9946
5394	5664	7133
5394	5664	6688
5394	5664	7432
5394	5664	2703
5394	5664	4504
5394	5664	9903
5394	5664	8418
5394	5664	5961
8951	5665	9069
8951	5665	2755
8951	5665	4128
8951	5665	1901
8951	5665	5397
8951	5665	3548
8951	5665	2579
8951	5665	6577
18557	5666	1574
18557	5666	1567
18557	5666	6941
18557	5666	9905
18557	5666	2003
18557	5666	9502
18557	5666	9838
18557	5666	5690
15180	5667	98
5353	5668	2687
5353	5668	8737
5353	5668	5225
5353	5668	4493
5353	5668	303
5353	5668	4319
5353	5668	2897
5353	5668	6847
5353	5668	7393
6164	5669	672
6164	5669	9963
6164	5669	1778
6164	5669	3445
6164	5669	2305
6164	5669	998
6164	5669	9770
6164	5669	1352
6164	5669	3014
14665	5670	3654
14665	5670	990
14665	5670	5392
14665	5670	4128
14665	5670	5254
14665	5670	5482
14665	5670	5568
14665	5670	8062
732	5671	1407
732	5671	8830
732	5671	9176
9742	5672	3463
9742	5672	4981
9742	5672	3875
9742	5672	96
9742	5672	6415
9742	5672	2802
16738	5673	7382
16738	5673	8994
16738	5673	3374
16738	5673	7438
16738	5673	3159
16738	5673	4046
16738	5673	1485
16738	5673	3845
17651	5674	9198
17651	5674	7928
17651	5674	4844
17651	5674	7509
17651	5674	9098
17651	5674	4036
17651	5674	7432
17651	5674	9004
17651	5674	3429
13175	5675	4158
13175	5675	275
13175	5675	9486
13175	5675	6827
13175	5675	6250
13175	5675	8380
13175	5675	1638
18293	5676	5812
18293	5676	483
18293	5676	5697
18293	5676	4048
14112	5677	4110
14112	5677	3522
14112	5677	7872
14112	5677	710
14112	5677	1893
14112	5677	724
14112	5677	1137
14112	5677	3495
14112	5677	1507
14637	5678	561
9218	5679	1665
9218	5679	4926
9218	5679	5196
9218	5679	159
9218	5679	1455
9218	5679	7767
16980	5680	851
16980	5680	5007
16980	5680	9240
16980	5680	9676
16980	5680	5582
16980	5680	4522
16980	5680	4846
16980	5680	1540
16980	5680	9461
9314	5681	7725
9314	5681	3310
9314	5681	9715
6667	5682	448
6667	5682	7189
6667	5682	161
6667	5682	3719
6667	5682	7101
3892	5683	8456
3892	5683	9344
3892	5683	6493
8434	5684	9708
8434	5684	7628
8434	5684	3670
8434	5684	8519
8434	5684	2836
8434	5684	3803
15043	5685	5761
15043	5685	1616
15043	5685	2957
15043	5685	9971
15043	5685	810
15043	5685	6555
15043	5685	680
15043	5685	481
15043	5685	7512
2361	5686	5297
2361	5686	8299
2361	5686	1668
812	5687	484
812	5687	517
812	5687	2224
6067	5688	7024
6067	5688	9471
6067	5688	8016
4180	5689	4682
4180	5689	118
3570	5690	2191
3570	5690	1560
3570	5690	6539
3570	5690	6115
3570	5690	2563
3570	5690	1797
3570	5690	4150
3570	5690	7142
3570	5690	6324
3870	5691	3382
3870	5691	2222
3870	5691	4910
3870	5691	5284
3870	5691	3959
3870	5691	3144
3870	5691	149
3870	5691	7594
313	5692	9669
13622	5693	1969
13622	5693	7320
13622	5693	5251
13622	5693	1146
13622	5693	4200
18967	5694	6958
18967	5694	1729
18967	5694	7639
18967	5694	3369
18967	5694	9478
18967	5694	6324
10769	5695	769
10769	5695	6128
10769	5695	7142
10769	5695	8788
10769	5695	8851
10769	5695	4343
10769	5695	2471
10769	5695	7314
10769	5695	7113
9502	5696	834
9502	5696	1389
9502	5696	6987
9502	5696	2542
9502	5696	4783
9502	5696	868
9502	5696	1398
9502	5696	2290
9502	5696	6296
1276	5697	9794
1276	5697	5071
1276	5697	8599
1276	5697	1658
1276	5697	1507
1276	5697	4802
3576	5698	4731
3576	5698	5501
13798	5699	7085
13798	5699	7161
13798	5699	540
13798	5699	5901
13798	5699	8960
13798	5699	7240
17795	5700	1389
17795	5700	6977
17795	5700	1109
17795	5700	3228
17458	5701	5628
17458	5701	7587
9493	5702	4150
9493	5702	5816
9493	5702	9841
9493	5702	668
9493	5702	1953
6682	5703	4378
6682	5703	8489
6682	5703	1454
6682	5703	6335
3923	5704	4673
3923	5704	222
3923	5704	8357
3923	5704	6511
3923	5704	7481
16296	5705	3335
16296	5705	2522
16296	5705	8740
16296	5705	3457
16296	5705	4505
16296	5705	3552
16296	5705	7799
16296	5705	2801
16296	5705	6917
14277	5706	1510
14277	5706	1132
14277	5706	7976
14277	5706	7138
14277	5706	7540
14277	5706	2008
14277	5706	8314
3541	5707	6680
3541	5707	2304
10208	5708	2577
10208	5708	7023
10208	5708	5772
10208	5708	9317
10208	5708	7522
10208	5708	5264
10208	5708	4035
10208	5708	5131
10208	5708	2865
19649	5709	1289
19649	5709	6291
19649	5709	6373
19649	5709	8696
19649	5709	9143
12331	5710	4697
12331	5710	8069
6665	5711	6136
6665	5711	5648
6665	5711	5452
6665	5711	8824
6665	5711	7201
6665	5711	2559
6665	5711	3704
6665	5711	2750
6665	5711	5514
1814	5712	2073
1814	5712	914
1814	5712	4972
3696	5713	3855
3696	5713	8608
3696	5713	4175
3696	5713	9971
3696	5713	7543
3696	5713	4866
3696	5713	1462
3696	5713	3646
3696	5713	9507
15127	5714	317
15127	5714	95
15127	5714	7350
15127	5714	7136
15127	5714	3176
15127	5714	5178
15127	5714	297
15127	5714	9214
15127	5714	727
11184	5715	3207
11184	5715	1235
11184	5715	8964
11184	5715	276
1186	5716	5881
1186	5716	2733
1186	5716	567
1186	5716	4008
1186	5716	7692
1186	5716	5096
1186	5716	4572
1186	5716	3661
1186	5716	1414
9239	5717	7332
9239	5717	1978
9239	5717	1187
1930	5718	8092
1930	5718	7099
1930	5718	8854
1930	5718	4403
18996	5719	5320
18996	5719	7351
18996	5719	8774
18996	5719	1353
18996	5719	1840
18996	5719	4356
18996	5719	6292
18996	5719	4865
18996	5719	6507
9196	5720	3256
9196	5720	6779
9196	5720	3420
9196	5720	7156
9196	5720	2170
9196	5720	3980
5505	5721	4835
18380	5722	4732
18380	5722	29
18380	5722	4095
18380	5722	5836
18380	5722	4275
2107	5723	3242
2107	5723	9278
2107	5723	6381
11178	5724	6149
11178	5724	3765
11178	5724	35
11178	5724	929
1915	5725	9560
7670	5726	4888
7670	5726	4545
7646	5727	7081
7646	5727	3554
7646	5727	1899
7646	5727	3935
7646	5727	5096
7646	5727	3580
7646	5727	8735
7646	5727	6981
13082	5728	376
13082	5728	6827
13082	5728	5187
13082	5728	3393
13082	5728	5195
4550	5729	5365
4550	5729	7992
4550	5729	2964
4550	5729	3268
4550	5729	9111
4550	5729	7059
4550	5729	6741
4550	5729	2633
6016	5730	8271
3326	5731	8595
3326	5731	8963
3326	5731	5807
3326	5731	1299
3326	5731	3627
3326	5731	6886
3326	5731	805
15726	5732	6467
15726	5732	8956
15726	5732	7729
15726	5732	9883
15726	5732	5791
15726	5732	7662
12513	5733	254
12513	5733	1356
12513	5733	5695
12513	5733	5813
12513	5733	1877
12513	5733	8577
12513	5733	4480
1893	5734	708
1893	5734	5146
1893	5734	9115
1893	5734	1967
1893	5734	9509
11195	5735	7494
11195	5735	4838
11195	5735	3396
10543	5736	6045
10543	5736	5010
10543	5736	2694
10543	5736	7822
5936	5737	3905
5936	5737	9401
5936	5737	5990
6095	5738	1461
6095	5738	9692
6095	5738	1208
6095	5738	128
6095	5738	9804
6095	5738	223
5832	5739	6317
5832	5739	9417
5832	5739	1345
5832	5739	6266
5832	5739	6734
5832	5739	3178
17794	5740	9454
17794	5740	1620
17794	5740	7398
17794	5740	9136
17794	5740	7919
17794	5740	2014
17794	5740	2274
17180	5741	8898
17180	5741	5734
17180	5741	8033
2421	5742	107
2421	5742	9485
2421	5742	2396
19585	5743	6994
19585	5743	8714
19585	5743	7315
19585	5743	6230
19585	5743	9578
19585	5743	2722
19585	5743	9461
19585	5743	3639
19585	5743	921
18263	5744	9589
18263	5744	8370
18263	5744	4367
18263	5744	1777
18263	5744	7947
18263	5744	7986
18263	5744	7777
18263	5744	7648
14450	5745	5700
14450	5745	6784
14450	5745	3132
14450	5745	396
14450	5745	6836
14450	5745	644
14450	5745	7438
14450	5745	8409
370	5746	8954
370	5746	2211
370	5746	2307
370	5746	737
370	5746	7083
5565	5747	2121
5565	5747	733
5565	5747	7521
16329	5748	7178
16329	5748	5932
16329	5748	2587
16329	5748	333
5087	5749	2402
5087	5749	2181
5087	5749	5922
5087	5749	2267
8775	5750	6903
8775	5750	9755
7496	5751	6150
7496	5751	1807
7496	5751	8606
7496	5751	276
7496	5751	4682
7496	5751	4832
7496	5751	7552
6947	5752	1950
6947	5752	3222
6947	5752	9077
6947	5752	7794
6947	5752	3717
6947	5752	2580
6947	5752	4665
6947	5752	5089
7388	5753	4259
7388	5753	6286
7388	5753	374
7388	5753	6102
7388	5753	7311
7388	5753	5776
7388	5753	8431
15014	5754	6339
15014	5754	805
15014	5754	4274
18726	5755	3057
18726	5755	2853
18726	5755	3841
18726	5755	6406
18726	5755	2975
571	5756	9545
571	5756	5927
571	5756	9984
571	5756	8080
571	5756	7885
571	5756	5241
571	5756	4354
12589	5757	6845
12589	5757	1893
12589	5757	9990
12589	5757	4900
12589	5757	806
9704	5758	7329
9704	5758	7711
9704	5758	3960
3688	5759	4002
3688	5759	1763
3688	5759	5323
3688	5759	101
3688	5759	615
3688	5759	2852
3688	5759	292
3688	5759	3569
13637	5760	9613
13637	5760	5705
13637	5760	588
13637	5760	3114
13637	5760	1508
13637	5760	3096
13637	5760	6817
4279	5761	4307
4279	5761	3127
6835	5762	4514
6835	5762	6225
6835	5762	5508
6835	5762	3738
6835	5762	3161
6835	5762	877
6835	5762	8547
6835	5762	4062
6835	5762	7894
17854	5763	60
17854	5763	6353
4382	5764	1598
4382	5764	8106
4382	5764	1579
4382	5764	3659
4382	5764	4825
4382	5764	9641
4382	5764	3093
4382	5764	8085
4382	5764	9829
12656	5765	7447
7599	5766	5991
7599	5766	2241
7599	5766	5871
14897	5767	2765
14897	5767	5887
14897	5767	4485
14897	5767	592
14897	5767	6133
14897	5767	8548
14897	5767	6748
14897	5767	5211
14897	5767	8418
13137	5768	1322
13137	5768	1572
13137	5768	9017
13137	5768	4641
14809	5769	9810
14809	5769	914
14092	5770	1210
14092	5770	814
14092	5770	1764
14092	5770	1
14092	5770	5801
14092	5770	3741
14092	5770	5103
8239	5771	7095
8239	5771	6359
8239	5771	273
8239	5771	5098
8239	5771	6569
8239	5771	8232
8239	5771	1272
8239	5771	4958
8239	5771	5861
11722	5772	2293
11722	5772	4239
11722	5772	5530
11722	5772	1514
11722	5772	7507
11722	5772	6160
11722	5772	7462
5118	5773	6470
5118	5773	3990
5118	5773	5290
5118	5773	9826
5118	5773	5668
5118	5773	7011
18606	5774	6697
18606	5774	1049
18606	5774	5716
3751	5775	8308
3751	5775	6839
3751	5775	9054
3751	5775	1775
14128	5776	8214
10449	5777	4528
2448	5778	9435
2448	5778	2375
2448	5778	7652
2448	5778	532
14742	5779	679
14742	5779	9345
14742	5779	723
14742	5779	2600
14742	5779	8994
14742	5779	4161
17375	5780	9912
17375	5780	1475
17375	5780	6803
17375	5780	5598
17375	5780	8644
17375	5780	412
17375	5780	3501
8357	5781	5905
8357	5781	2870
3726	5782	661
3726	5782	8460
3726	5782	5660
3726	5782	2651
3726	5782	7716
3726	5782	984
3726	5782	3907
3726	5782	9443
3726	5782	5517
15416	5783	9243
15416	5783	9245
15416	5783	1529
9292	5784	2650
9292	5784	6261
9292	5784	1458
9292	5784	5444
9292	5784	8365
4541	5785	6589
4541	5785	4871
3983	5786	5017
3983	5786	634
3983	5786	9871
3983	5786	1191
3983	5786	9246
3983	5786	7587
3983	5786	2150
3983	5786	4418
5563	5787	5052
3280	5788	4842
3280	5788	9492
3280	5788	9444
3280	5788	5627
3280	5788	1053
3280	5788	4687
3280	5788	9996
15165	5789	6626
15165	5789	5826
15165	5789	6637
15165	5789	5544
15165	5789	9920
15165	5789	3328
15165	5789	5674
15165	5789	2486
3858	5790	2006
3858	5790	9905
3858	5790	2969
3858	5790	625
124	5791	3918
124	5791	8949
124	5791	2956
124	5791	2241
11137	5792	3737
11137	5792	3503
11137	5792	8853
11137	5792	6925
11137	5792	3900
11137	5792	7551
11137	5792	6729
11137	5792	5919
6407	5793	6314
6407	5793	2707
9896	5794	516
9896	5794	2763
9896	5794	3506
9896	5794	6771
7390	5795	524
7390	5795	206
7390	5795	8942
7390	5795	1464
19563	5796	7049
19563	5796	4910
19563	5796	6987
19563	5796	3232
19563	5796	3636
19563	5796	1755
17051	5797	2221
17051	5797	5037
10485	5798	1368
10485	5798	9603
10485	5798	1241
16578	5799	7097
16578	5799	8300
3872	5800	9078
3872	5800	5740
3872	5800	280
3872	5800	1294
3872	5800	704
3872	5800	558
3872	5800	7201
13606	5801	5737
13606	5801	1688
13606	5801	203
13606	5801	4667
253	5802	7341
253	5802	4016
253	5802	8092
253	5802	1041
253	5802	9611
337	5803	2094
337	5803	8165
7803	5804	610
7803	5804	8473
7803	5804	2375
7803	5804	5403
7803	5804	3019
7803	5804	2328
7803	5804	5824
7803	5804	1329
7803	5804	9805
7933	5805	5329
6986	5806	7394
6986	5806	3344
6986	5806	5455
6986	5806	3280
17364	5807	1425
17364	5807	9453
17364	5807	3391
6390	5808	7162
6390	5808	3772
6390	5808	6027
7881	5809	5523
7881	5809	1380
7881	5809	8241
7881	5809	8808
18900	5810	2420
18900	5810	2013
18900	5810	292
18900	5810	9005
18900	5810	8844
5229	5811	2040
10241	5812	1545
19571	5813	7426
14969	5814	6996
14969	5814	7793
13596	5815	2964
13596	5815	1752
13596	5815	5002
13596	5815	6257
13596	5815	8912
13596	5815	135
13596	5815	3662
13596	5815	242
13596	5815	1555
2235	5816	3101
2235	5816	1433
2235	5816	9433
2235	5816	7691
2235	5816	863
2235	5816	2867
2235	5816	2274
17060	5817	2799
17060	5817	5772
17060	5817	9250
17060	5817	4173
17060	5817	3680
17661	5818	977
17661	5818	5914
17661	5818	9698
17661	5818	9140
17661	5818	4260
13067	5819	5064
13067	5819	4895
13067	5819	5357
13067	5819	4323
13067	5819	6679
13067	5819	5409
13067	5819	7773
13067	5819	9189
13067	5819	2351
16529	5820	1870
16529	5820	2544
11436	5821	5297
11436	5821	9139
8991	5822	9101
8991	5822	8405
8991	5822	7893
8991	5822	1839
8991	5822	491
8991	5822	7246
8991	5822	2454
8991	5822	4760
8991	5822	7532
18499	5823	841
18499	5823	839
18499	5823	8508
18729	5824	6900
18729	5824	8085
18729	5824	917
18729	5824	1874
18239	5825	6938
18239	5825	890
18239	5825	6245
18239	5825	3719
18239	5825	4454
18239	5825	7584
12183	5826	5456
12183	5826	2590
12183	5826	2792
12183	5826	7148
12183	5826	598
12183	5826	5115
12183	5826	8140
12183	5826	1278
12183	5826	8240
8968	5827	3750
8968	5827	7825
8968	5827	3253
9942	5828	3024
9942	5828	5235
9942	5828	4641
10477	5829	9950
10477	5829	3936
10477	5829	4620
10477	5829	3394
10477	5829	6659
817	5830	1742
817	5830	7620
817	5830	3085
817	5830	2046
817	5830	2964
15208	5831	2843
15208	5831	6085
41	5832	2195
41	5832	9391
41	5832	4313
41	5832	9261
41	5832	2078
19394	5833	8694
3313	5834	9260
3313	5834	9850
3313	5834	217
3313	5834	4894
3313	5834	5955
3313	5834	6046
3313	5834	6325
3313	5834	7002
12525	5835	7265
12525	5835	4032
12525	5835	7469
12525	5835	9645
18274	5836	8291
18274	5836	5743
18274	5836	8135
18274	5836	9329
10749	5837	811
10749	5837	6511
10749	5837	5503
10749	5837	7403
10749	5837	3418
10749	5837	199
19687	5838	8981
19687	5838	2180
19687	5838	9386
19687	5838	5778
19687	5838	8560
19687	5838	1610
19687	5838	481
19687	5838	3982
983	5839	6812
983	5839	1357
983	5839	3196
983	5839	1115
983	5839	1399
983	5839	5893
983	5839	3135
983	5839	7650
6856	5840	8535
6856	5840	2662
6856	5840	5497
6856	5840	307
6856	5840	7135
7893	5841	4176
7893	5841	85
7893	5841	6977
7893	5841	1239
7893	5841	1862
7893	5841	943
7893	5841	6893
7893	5841	2939
2946	5842	488
2946	5842	797
2946	5842	2661
2946	5842	5460
3774	5843	1510
3774	5843	1342
3774	5843	9930
3774	5843	1357
3774	5843	6954
3774	5843	1303
8484	5844	5715
12404	5845	6996
12404	5845	3607
12404	5845	5930
12404	5845	4343
12404	5845	1536
12404	5845	2741
5341	5846	4462
5341	5846	7994
5341	5846	6258
5341	5846	7
5341	5846	7956
5341	5846	6394
19658	5847	5925
19658	5847	1374
19658	5847	7601
19658	5847	6148
19658	5847	1569
19658	5847	2014
19658	5847	1559
19658	5847	1602
19658	5847	9884
12283	5848	3177
12283	5848	7512
18868	5849	8353
18868	5849	8243
18868	5849	7178
18868	5849	5443
18868	5849	4980
18868	5849	2214
7543	5850	9792
7543	5850	4115
7543	5850	491
7543	5850	3368
7543	5850	5720
6671	5851	9461
6671	5851	7957
6671	5851	8392
7668	5852	845
7668	5852	5519
7668	5852	4444
7668	5852	8281
7668	5852	4334
7668	5852	5812
7668	5852	3335
7668	5852	8491
3454	5853	4361
4636	5854	7452
4636	5854	1261
4636	5854	1627
4636	5854	6583
4636	5854	5867
4636	5854	7130
4636	5854	5261
2145	5855	252
2145	5855	8933
2145	5855	6504
2145	5855	680
2145	5855	3173
2145	5855	3182
2145	5855	7143
2145	5855	5828
2145	5855	6544
6253	5856	4153
6253	5856	523
6253	5856	3192
6253	5856	486
6253	5856	6944
6253	5856	4254
1514	5857	1622
1514	5857	1440
17165	5858	6986
17165	5858	6381
17165	5858	5107
17165	5858	3869
17165	5858	2709
17165	5858	8672
17165	5858	1457
17165	5858	5378
17165	5858	9894
1879	5859	2665
1879	5859	1844
9883	5860	3867
9883	5860	4228
9883	5860	7165
2068	5861	5425
2068	5861	9836
2068	5861	6422
2068	5861	5282
19115	5862	1031
19115	5862	7241
19115	5862	4023
19115	5862	7815
19115	5862	6301
1056	5863	9862
1056	5863	4579
1056	5863	7090
1056	5863	5718
4278	5864	8454
4278	5864	1724
5508	5865	5628
5508	5865	3506
5508	5865	6358
5508	5865	5124
5508	5865	334
5508	5865	6283
5508	5865	206
5508	5865	8650
5508	5865	864
15498	5866	9916
15498	5866	3339
15498	5866	668
15498	5866	4393
15498	5866	5005
15498	5866	5945
4604	5867	5040
4604	5867	5637
4604	5867	8846
4604	5867	2183
4604	5867	3139
4604	5867	1863
4604	5867	795
4604	5867	3717
14111	5868	2607
14111	5868	291
14111	5868	6761
14111	5868	6122
8877	5869	3089
8877	5869	4898
8877	5869	288
8877	5869	9430
2585	5870	9661
5978	5871	6985
5978	5871	718
5978	5871	1775
5978	5871	3511
4096	5872	5624
4096	5872	953
4096	5872	7358
4096	5872	7602
4096	5872	4665
4096	5872	8081
15482	5873	730
15430	5874	4991
15430	5874	2449
15430	5874	5339
15430	5874	549
15430	5874	6657
15218	5875	8849
7027	5876	8963
7027	5876	3063
7027	5876	947
7027	5876	417
7027	5876	1507
12994	5877	4998
12994	5877	2768
12994	5877	6537
19265	5878	87
19265	5878	2710
19265	5878	9395
19265	5878	2649
19265	5878	5403
19265	5878	7269
19265	5878	9503
19265	5878	1550
3440	5879	4340
3440	5879	6158
3440	5879	8051
3440	5879	6532
3440	5879	2327
3440	5879	8183
3440	5879	9447
17682	5880	7198
17682	5880	8100
17682	5880	7376
17851	5881	646
17851	5881	3213
17851	5881	8623
17851	5881	2091
17851	5881	2065
17851	5881	6442
9248	5882	5516
9248	5882	474
15344	5883	2138
15344	5883	4634
15344	5883	8467
15344	5883	208
15344	5883	9364
15344	5883	4096
15344	5883	2791
9710	5884	9246
12098	5885	2592
12098	5885	2378
9087	5886	4085
9087	5886	3200
9087	5886	6434
9087	5886	1663
9087	5886	6827
9087	5886	3783
9087	5886	1945
9087	5886	4472
9087	5886	9541
10529	5887	6504
10529	5887	1478
10529	5887	3881
4870	5888	5623
4870	5888	60
4870	5888	3767
4870	5888	7853
4870	5888	7480
4870	5888	211
4870	5888	76
19231	5889	4880
19231	5889	2300
19231	5889	522
19231	5889	264
19231	5889	2027
19231	5889	6838
19231	5889	1197
19231	5889	9549
19231	5889	4517
4738	5890	4004
8157	5891	3694
8157	5891	5981
8157	5891	5364
8157	5891	9956
8157	5891	2057
8157	5891	288
14249	5892	9585
14249	5892	6361
14249	5892	6136
14249	5892	6470
14249	5892	9797
19356	5893	5735
19356	5893	162
19356	5893	6817
13545	5894	6992
13545	5894	6137
18818	5895	2229
18818	5895	2506
18818	5895	1704
18818	5895	8408
18818	5895	9448
18818	5895	1178
18818	5895	5532
18818	5895	2242
18118	5896	5832
18118	5896	678
18118	5896	4322
18118	5896	3722
18118	5896	6223
18118	5896	1548
18118	5896	2090
18118	5896	6816
10445	5897	7793
10445	5897	6473
10445	5897	3382
4021	5898	635
2623	5899	8126
2623	5899	324
2623	5899	9875
2623	5899	2800
2623	5899	5925
2623	5899	5756
2623	5899	4837
5258	5900	5953
5258	5900	6616
5258	5900	2910
5258	5900	5204
5258	5900	7994
5258	5900	4855
5258	5900	5245
5258	5900	4570
8887	5901	6407
4325	5902	3211
4325	5902	7208
4325	5902	1647
4325	5902	1627
4325	5902	8130
6666	5903	1396
13281	5904	2209
13281	5904	4076
13281	5904	3371
13281	5904	3014
13281	5904	2646
13281	5904	7691
13281	5904	9077
13281	5904	6583
13281	5904	8058
12375	5905	9520
12375	5905	2278
14683	5906	6974
14683	5906	2916
14683	5906	9413
14683	5906	1533
14683	5906	9399
14683	5906	7757
14683	5906	33
14683	5906	1987
14683	5906	7556
13079	5907	8174
13079	5907	8395
13079	5907	6667
13079	5907	7793
13079	5907	1826
13079	5907	3986
13079	5907	5816
14696	5908	1525
3116	5909	8173
3116	5909	9547
3116	5909	4510
3116	5909	568
3116	5909	1530
3116	5909	3134
3116	5909	1115
3116	5909	2418
3116	5909	5692
3015	5910	8855
3015	5910	9137
3015	5910	9208
3015	5910	1938
3015	5910	6155
3015	5910	7593
3015	5910	3108
3015	5910	1480
6018	5911	1205
6018	5911	8843
6018	5911	6692
6018	5911	25
6018	5911	6042
6018	5911	3084
6018	5911	5453
6018	5911	5276
14427	5912	7324
14427	5912	730
14427	5912	3976
14427	5912	4106
14427	5912	5219
12845	5913	44
12845	5913	55
12845	5913	1558
12845	5913	9895
12845	5913	993
12537	5914	3482
12537	5914	764
12537	5914	6164
12537	5914	1236
12537	5914	3702
12537	5914	8900
11153	5915	1097
11153	5915	9759
11153	5915	5455
10698	5916	696
10698	5916	4508
10698	5916	8554
10698	5916	4991
10698	5916	8794
10698	5916	810
10698	5916	1295
10698	5916	5370
14904	5917	27
14904	5917	4160
14904	5917	8018
14904	5917	1102
14904	5917	4962
14904	5917	3504
14904	5917	9878
14904	5917	6359
2700	5918	2505
2700	5918	4822
2700	5918	3069
2700	5918	3993
2700	5918	7644
15340	5919	7456
15340	5919	9046
15340	5919	9910
15340	5919	5617
15340	5919	9665
15340	5919	1424
15340	5919	3926
15340	5919	7373
15340	5919	2216
14076	5920	7229
14076	5920	9801
14076	5920	7432
8120	5921	8706
8120	5921	8555
8120	5921	7559
8120	5921	2029
8120	5921	9666
8120	5921	3246
8120	5921	875
8120	5921	5266
8120	5921	497
8345	5922	1841
8345	5922	2229
8345	5922	3673
8345	5922	3332
8345	5922	4768
8345	5922	1730
8345	5922	654
5364	5923	6134
5364	5923	752
5364	5923	377
5364	5923	98
5364	5923	1515
5364	5923	5045
5364	5923	7583
19621	5924	4581
19621	5924	763
19621	5924	1527
4360	5925	4862
1989	5926	8003
1989	5926	4092
1989	5926	9298
1989	5926	8326
1989	5926	5919
1989	5926	1227
1989	5926	5718
1989	5926	7415
16354	5927	669
16354	5927	580
16354	5927	2480
16354	5927	742
16354	5927	6436
16354	5927	7878
16354	5927	7216
16354	5927	2538
1726	5928	6771
1726	5928	8324
1726	5928	9466
1726	5928	2787
4865	5929	4748
4865	5929	7033
4865	5929	759
4865	5929	7031
4865	5929	6565
7561	5930	294
7561	5930	5032
7561	5930	7945
7561	5930	3230
5390	5931	9034
5390	5931	9509
5390	5931	502
5390	5931	9090
5390	5931	1484
5390	5931	5309
5390	5931	7042
17345	5932	2841
15744	5933	9674
15744	5933	8962
15744	5933	3018
4103	5934	5823
9825	5935	4760
9825	5935	4801
9825	5935	2102
9825	5935	474
9825	5935	8521
9825	5935	3701
1589	5936	1118
8271	5937	6187
8271	5937	6408
8271	5937	163
8271	5937	6922
8271	5937	7498
8271	5937	5313
14828	5938	5169
14828	5938	7271
14828	5938	2312
14828	5938	9664
1562	5939	4917
1562	5939	9999
1562	5939	1871
1562	5939	3112
67	5940	1715
67	5940	7413
67	5940	9843
67	5940	9154
67	5940	6975
18574	5941	7564
18574	5941	4324
18574	5941	8332
18574	5941	9860
3462	5942	3765
3462	5942	3488
3462	5942	7468
3462	5942	3311
6306	5943	8164
6306	5943	5977
6306	5943	9076
6306	5943	5587
6306	5943	5051
6306	5943	7405
6306	5943	9151
6306	5943	1713
6306	5943	8996
5519	5944	3641
5519	5944	1638
5519	5944	1150
5519	5944	104
5519	5944	1591
5519	5944	3753
5657	5945	9467
5657	5945	5809
5657	5945	6856
5657	5945	4136
5657	5945	4451
5657	5945	5018
7638	5946	89
7638	5946	6482
7638	5946	7507
7638	5946	5202
7638	5946	4853
7638	5946	6664
7638	5946	1783
7638	5946	1062
7638	5946	8560
10831	5947	3984
10831	5947	5388
10831	5947	3676
15017	5948	2978
15017	5948	4146
15017	5948	3875
17455	5949	3891
17455	5949	1330
17455	5949	1335
17455	5949	1822
17455	5949	5304
17455	5949	1712
14199	5950	8378
14199	5950	1113
14199	5950	4015
14199	5950	6475
700	5951	9077
700	5951	399
700	5951	5894
700	5951	7921
19485	5952	3392
19485	5952	6209
19485	5952	5494
19485	5952	6925
19485	5952	5604
19485	5952	3056
19485	5952	2127
13401	5953	856
13401	5953	1096
13401	5953	1926
13401	5953	2982
13401	5953	4217
1798	5954	9293
1798	5954	6299
1798	5954	2224
15655	5955	7446
15655	5955	1245
2250	5956	83
4015	5957	1853
4015	5957	9776
4015	5957	3709
4015	5957	4419
4015	5957	9023
2493	5958	9074
2493	5958	8159
2493	5958	8587
2493	5958	1744
2493	5958	528
2493	5958	9615
3620	5959	6987
3620	5959	5264
3620	5959	5908
652	5960	1044
652	5960	8327
652	5960	6206
652	5960	184
652	5960	3920
652	5960	3767
652	5960	7442
14113	5961	8866
14113	5961	4230
18986	5962	8465
18986	5962	8222
18986	5962	7752
18986	5962	198
18986	5962	4249
18986	5962	3479
18986	5962	768
18986	5962	3201
1285	5963	7699
13129	5964	2417
13129	5964	6478
13129	5964	1135
13129	5964	5703
13129	5964	5379
13129	5964	8621
13129	5964	9532
6021	5965	409
6021	5965	7282
6021	5965	1143
17682	5966	5405
17682	5966	4189
17682	5966	4330
17682	5966	2852
17682	5966	5608
17682	5966	4820
17682	5966	2008
3080	5967	4551
3080	5967	1290
3080	5967	4109
3080	5967	8429
3080	5967	4682
3080	5967	4092
3080	5967	81
3080	5967	5614
19886	5968	5407
452	5969	3666
19948	5970	3583
19948	5970	1780
19948	5970	6495
19948	5970	2942
19948	5970	3085
19948	5970	5698
19948	5970	6530
7695	5971	4017
7695	5971	2912
7695	5971	6885
1101	5972	525
1101	5972	2563
1101	5972	7085
1101	5972	1797
1101	5972	4550
1101	5972	4755
903	5973	1762
903	5973	2148
903	5973	604
903	5973	9675
903	5973	8905
903	5973	7954
903	5973	7110
903	5973	8118
1360	5974	5022
1360	5974	309
1360	5974	8275
1360	5974	7205
1360	5974	5515
1360	5974	8346
1360	5974	6239
13686	5975	358
13686	5975	6525
13686	5975	7939
13686	5975	8795
13686	5975	1268
13686	5975	6736
13686	5975	5170
13686	5975	6545
13686	5975	1328
17064	5976	6537
17064	5976	3332
17064	5976	3703
17064	5976	9618
17064	5976	3587
17064	5976	5923
7723	5977	9917
7723	5977	5522
7723	5977	8020
7723	5977	8409
7723	5977	6170
7723	5977	9382
7723	5977	8268
9608	5978	7579
9608	5978	9720
9608	5978	1519
9608	5978	7172
9608	5978	3418
9608	5978	1303
2440	5979	7872
2440	5979	8753
2440	5979	4756
2440	5979	6017
2440	5979	1634
2440	5979	8384
2440	5979	9088
2440	5979	498
435	5980	3524
435	5980	5958
435	5980	6493
435	5980	4103
435	5980	8480
435	5980	7093
435	5980	6469
435	5980	2632
17297	5981	2932
17297	5981	6801
17297	5981	9584
13160	5982	5096
13160	5982	3583
13160	5982	7981
4167	5983	8360
4167	5983	3144
4167	5983	2044
4167	5983	6053
4167	5983	4424
4167	5983	5211
4167	5983	5159
9483	5984	1322
9483	5984	609
9483	5984	7863
9483	5984	7470
9483	5984	4266
9483	5984	7927
9483	5984	2575
9483	5984	9571
3228	5985	4425
3228	5985	8581
3228	5985	3275
3228	5985	1646
3228	5985	8481
3228	5985	710
3228	5985	7778
11281	5986	1484
11281	5986	9470
11281	5986	3147
11281	5986	5697
13622	5987	3978
13622	5987	5177
13622	5987	8390
13622	5987	6297
13622	5987	1101
13622	5987	990
13622	5987	4578
13622	5987	3130
13622	5987	4408
11783	5988	5302
11783	5988	5999
11783	5988	4278
11783	5988	7809
3572	5989	4344
3572	5989	6648
3572	5989	5789
3572	5989	5418
3572	5989	9559
3572	5989	5545
3572	5989	792
3572	5989	1327
19481	5990	1301
19481	5990	2143
19902	5991	1737
19902	5991	204
13704	5992	4600
13704	5992	9870
13704	5992	2134
5849	5993	8199
5849	5993	7912
5849	5993	2355
5849	5993	2653
5849	5993	4791
5849	5993	4448
5849	5993	3648
5849	5993	526
15656	5994	919
15656	5994	1124
15656	5994	9461
15656	5994	6202
15656	5994	6182
15656	5994	4479
15656	5994	2778
15656	5994	1808
15656	5994	1603
12785	5995	5369
12785	5995	260
12785	5995	3599
12785	5995	3722
9280	5996	5428
9280	5996	5892
9280	5996	5371
19698	5997	2239
19698	5997	1107
19698	5997	2720
19698	5997	234
19698	5997	4810
19698	5997	8567
4330	5998	6466
4330	5998	9857
4330	5998	1739
4330	5998	5134
4330	5998	6914
223	5999	6086
223	5999	4416
223	5999	6432
223	5999	7927
223	5999	5955
223	5999	2267
7525	6000	8979
7525	6000	4504
7525	6000	9221
7525	6000	4120
7525	6000	3872
16984	6001	5853
16984	6001	4609
16984	6001	7550
16984	6001	2959
16984	6001	7669
16984	6001	6906
16984	6001	9046
16984	6001	3424
16984	6001	3864
5465	6002	100
5465	6002	3881
5465	6002	4715
5465	6002	9144
5465	6002	4544
5465	6002	7862
5465	6002	4151
5465	6002	5156
5650	6003	6040
5650	6003	2870
5650	6003	7214
3023	6004	9588
3023	6004	1518
3023	6004	217
3023	6004	8536
3023	6004	2646
3023	6004	4356
3023	6004	2231
3023	6004	5918
3023	6004	5616
9521	6005	2951
9521	6005	5714
9521	6005	4819
9521	6005	1676
9521	6005	7020
9521	6005	3849
8131	6006	3425
8131	6006	6345
8131	6006	7920
7675	6007	5951
7675	6007	6663
19226	6008	9777
19226	6008	6215
19226	6008	8353
19226	6008	2715
19226	6008	1771
19226	6008	6267
19226	6008	711
19226	6008	3952
3743	6009	5709
3743	6009	5660
3743	6009	7764
3743	6009	2825
4152	6010	6145
4152	6010	3163
11755	6011	3322
11755	6011	6079
11755	6011	2658
11755	6011	1088
11755	6011	1901
11755	6011	3887
11755	6011	8311
11755	6011	9268
11755	6011	1869
7606	6012	5514
7606	6012	9118
7606	6012	4811
7606	6012	4554
7606	6012	6428
5012	6013	2536
5012	6013	7261
5012	6013	9714
5012	6013	2046
5012	6013	694
5012	6013	4098
5012	6013	3407
15150	6014	7888
15150	6014	555
10217	6015	2984
10217	6015	9878
10217	6015	5813
10217	6015	7887
10217	6015	6850
10217	6015	4220
10217	6015	5625
19445	6016	80
19445	6016	1190
19445	6016	5716
19445	6016	9076
40	6017	7392
40	6017	4662
40	6017	9254
40	6017	9683
40	6017	3547
40	6017	4741
731	6018	88
731	6018	9250
731	6018	3989
731	6018	5187
731	6018	9516
731	6018	5974
14704	6019	1714
14704	6019	8942
17249	6020	5157
17249	6020	3717
17249	6020	3214
17249	6020	6219
17249	6020	6545
17249	6020	3468
17307	6021	2915
17307	6021	6713
17307	6021	3562
17307	6021	8870
17307	6021	5916
16642	6022	4273
16642	6022	7198
16642	6022	2176
16642	6022	4384
1856	6023	1461
1856	6023	5832
1856	6023	5195
1856	6023	7908
1856	6023	5943
1856	6023	5891
1856	6023	6745
5974	6024	7337
5974	6024	651
5974	6024	2388
5974	6024	4946
5974	6024	1221
5974	6024	7699
5974	6024	5835
5974	6024	4855
5974	6024	857
17528	6025	233
17528	6025	1166
17528	6025	9652
17528	6025	9964
17528	6025	2847
17528	6025	4177
13128	6026	3335
13128	6026	5437
13128	6026	2628
13128	6026	193
13128	6026	2936
13128	6026	7530
13128	6026	9813
91	6027	7022
13972	6028	4286
13972	6028	999
13972	6028	7500
13972	6028	2901
13972	6028	4866
13972	6028	1868
13972	6028	9608
5087	6029	5891
5087	6029	1989
5087	6029	2967
19978	6030	6975
2521	6031	7381
2521	6031	6932
2521	6031	2332
2521	6031	8620
2521	6031	9289
2521	6031	6260
2521	6031	770
2521	6031	6766
2521	6031	2290
10514	6032	5246
10514	6032	9818
10514	6032	7435
10514	6032	3480
10514	6032	8040
10514	6032	2929
10514	6032	1143
10514	6032	6768
12113	6033	319
12113	6033	5087
12113	6033	5418
12113	6033	5837
12113	6033	2634
12113	6033	6376
12387	6034	4623
12387	6034	7150
12387	6034	4438
12387	6034	7634
12387	6034	5339
12387	6034	5342
6658	6035	2087
15008	6036	5172
15008	6036	7603
15008	6036	3492
15008	6036	7741
4726	6037	5026
4726	6037	8831
4726	6037	7184
4726	6037	7060
4726	6037	8967
4726	6037	5854
4726	6037	8292
4726	6037	5086
16132	6038	3679
14340	6039	759
14340	6039	2266
14340	6039	3687
14340	6039	9529
14340	6039	9950
14340	6039	6686
14340	6039	9237
14340	6039	4526
14340	6039	5135
441	6040	8286
441	6040	9089
441	6040	6259
441	6040	9135
441	6040	1154
441	6040	4525
441	6040	7818
441	6040	710
1319	6041	7669
1319	6041	3065
1319	6041	8384
1319	6041	5012
1319	6041	8420
1319	6041	9885
1319	6041	2790
18096	6042	8638
18096	6042	7697
18096	6042	4797
18096	6042	1374
18096	6042	2860
18096	6042	6165
18096	6042	9515
18096	6042	212
17190	6043	7
19784	6044	8865
19784	6044	6854
19784	6044	2378
19784	6044	466
19784	6044	8655
19784	6044	5589
19784	6044	768
19784	6044	2130
3288	6045	4223
3288	6045	4172
3288	6045	7832
3288	6045	4199
3288	6045	4071
3288	6045	655
15016	6046	3000
15016	6046	7128
15016	6046	7752
15016	6046	1682
15016	6046	1165
15016	6046	5451
15016	6046	5455
19354	6047	4678
19354	6047	459
19354	6047	3688
19354	6047	8978
19354	6047	7465
19354	6047	1850
9699	6048	6503
9699	6048	549
9699	6048	8249
9699	6048	1995
9699	6048	8243
9699	6048	9916
9699	6048	7125
9699	6048	6630
14177	6049	1618
14177	6049	1795
14177	6049	3309
14177	6049	8571
14177	6049	8494
14177	6049	1848
14177	6049	279
17053	6050	2226
17053	6050	2622
17053	6050	2702
17053	6050	5066
17053	6050	1549
4452	6051	1881
4452	6051	7119
4452	6051	1722
4452	6051	9204
4452	6051	6237
4452	6051	5210
4452	6051	3446
4452	6051	5042
14533	6052	9408
14533	6052	5930
14533	6052	1939
14533	6052	3303
14533	6052	9704
14533	6052	6395
7026	6053	9202
7026	6053	9598
7026	6053	7027
7026	6053	1954
7026	6053	3197
7026	6053	8027
7026	6053	4261
7026	6053	2942
7026	6053	540
4956	6054	836
4956	6054	1029
17383	6055	8076
17383	6055	385
17383	6055	5383
17383	6055	2481
11354	6056	2435
11354	6056	3843
11354	6056	2258
11354	6056	4248
11354	6056	6860
11354	6056	1842
5741	6057	1562
5741	6057	8691
5741	6057	5612
5741	6057	7310
19581	6058	5467
19581	6058	281
19581	6058	1248
19581	6058	3279
15051	6059	8121
15051	6059	3059
15051	6059	8616
15051	6059	9051
15051	6059	3651
18524	6060	255
18524	6060	6914
18524	6060	7674
18524	6060	1242
18524	6060	283
18524	6060	2078
18524	6060	5994
19795	6061	5642
19795	6061	3976
19795	6061	6987
19795	6061	4434
19795	6061	766
19795	6061	9899
19795	6061	1372
19795	6061	885
19795	6061	8737
19956	6062	2467
16921	6063	8358
16921	6063	4803
16921	6063	4122
16921	6063	8257
16921	6063	1803
16921	6063	1745
3287	6064	1797
3287	6064	6594
3287	6064	9594
3287	6064	512
3287	6064	8208
3287	6064	4697
3287	6064	1439
3287	6064	8313
6230	6065	1893
6230	6065	4214
6230	6065	4742
3359	6066	9989
3359	6066	7450
3359	6066	9933
3359	6066	3842
3359	6066	3151
3359	6066	3422
9720	6067	4656
9720	6067	6195
9720	6067	3806
16039	6068	3978
16039	6068	6923
16039	6068	4460
16039	6068	979
16039	6068	3494
14671	6069	9386
14671	6069	9951
3329	6070	2364
3329	6070	2743
3329	6070	1512
3329	6070	4189
16333	6071	9747
16333	6071	2322
16333	6071	7709
16333	6071	1637
16333	6071	3151
5071	6072	6688
5071	6072	381
5071	6072	1699
5071	6072	7344
5071	6072	8913
5071	6072	7686
5071	6072	2149
5071	6072	1268
2027	6073	1739
2027	6073	9720
2027	6073	3657
2027	6073	6367
8271	6074	1541
8271	6074	6011
6707	6075	2209
6707	6075	6277
6707	6075	1540
6247	6076	7029
6247	6076	4125
6247	6076	3670
6247	6076	9618
6247	6076	204
6247	6076	4172
6247	6076	7115
6249	6077	6478
6249	6077	300
6249	6077	1998
6249	6077	3043
6249	6077	4120
6249	6077	6661
6249	6077	8016
4280	6078	9921
4280	6078	6677
4280	6078	5076
4280	6078	1467
4280	6078	6561
4280	6078	5314
3583	6079	477
3583	6079	8328
4894	6080	5123
4894	6080	8028
4894	6080	4561
4894	6080	4735
2823	6081	2260
2823	6081	5783
2823	6081	401
2823	6081	4331
12948	6082	616
12948	6082	6884
12948	6082	4379
12948	6082	2633
1321	6083	9124
1321	6083	2751
1321	6083	3741
1321	6083	1234
1321	6083	3429
1321	6083	4819
1321	6083	8112
1321	6083	5682
18571	6084	1217
18571	6084	4533
18571	6084	2537
18571	6084	5096
18571	6084	7825
18571	6084	4515
14530	6085	4621
14530	6085	4761
14530	6085	2838
14530	6085	1879
14530	6085	8730
14530	6085	1949
14530	6085	6845
14530	6085	591
10246	6086	2288
225	6087	7061
3299	6088	7471
3299	6088	793
3299	6088	9563
16584	6089	2645
16584	6089	9519
16584	6089	5137
17584	6090	7543
17969	6091	5446
17969	6091	9468
17969	6091	5242
17969	6091	651
17969	6091	7247
17969	6091	8706
17969	6091	8506
17969	6091	1710
2456	6092	8308
2456	6092	9940
14964	6093	6467
14964	6093	1967
14964	6093	5879
14964	6093	2581
6462	6094	3445
6462	6094	4124
6462	6094	4795
6462	6094	3101
6462	6094	7060
6462	6094	1953
3784	6095	9374
3784	6095	7769
3784	6095	3233
3784	6095	7753
665	6096	3563
665	6096	5163
665	6096	3246
665	6096	8958
665	6096	5118
665	6096	8846
665	6096	9545
665	6096	7545
665	6096	2690
4128	6097	7904
4128	6097	897
4134	6098	1610
13544	6099	6058
13544	6099	9496
16682	6100	9140
16682	6100	6893
16682	6100	9293
16682	6100	3893
16682	6100	1448
16682	6100	9023
16682	6100	7452
6879	6101	2990
6879	6101	2793
6879	6101	105
6879	6101	5064
6879	6101	25
6879	6101	7941
14160	6102	8909
14160	6102	6934
14160	6102	1109
14160	6102	4598
14160	6102	726
14160	6102	9747
372	6103	8835
372	6103	8026
372	6103	2799
372	6103	8540
372	6103	5727
372	6103	6202
372	6103	3560
372	6103	2130
18127	6104	7445
18127	6104	5284
18127	6104	1917
18127	6104	3307
18127	6104	5215
8100	6105	2989
8100	6105	6997
8100	6105	4035
8100	6105	8008
3135	6106	4036
18611	6107	9173
18611	6107	5012
18611	6107	221
18611	6107	8494
18611	6107	2781
18611	6107	9485
18611	6107	8283
10558	6108	8002
10558	6108	6674
10558	6108	3577
10558	6108	6541
10558	6108	2141
10558	6108	6918
12180	6109	7179
12180	6109	6110
12180	6109	2894
12180	6109	47
12180	6109	83
12180	6109	4852
12180	6109	3609
12180	6109	8923
11192	6110	2981
11192	6110	2051
11192	6110	296
11192	6110	7169
8816	6111	1867
8816	6111	7907
8816	6111	5867
11897	6112	8434
11897	6112	845
3413	6113	6145
3413	6113	3673
3413	6113	1053
3413	6113	7163
3413	6113	7044
3413	6113	2630
3413	6113	4455
3413	6113	4888
3413	6113	9258
12793	6114	8388
12793	6114	6489
12793	6114	2492
12793	6114	939
12793	6114	7305
12793	6114	1376
4857	6115	651
4857	6115	4661
4857	6115	9899
9573	6116	5540
9573	6116	3431
9573	6116	8389
9573	6116	7378
9573	6116	1050
9573	6116	2866
9573	6116	5313
13377	6117	9117
13377	6117	6790
13377	6117	8080
13377	6117	3047
1646	6118	7857
1646	6118	3833
4444	6119	7099
4444	6119	7793
4444	6119	6141
4444	6119	133
4444	6119	9794
4444	6119	9561
4444	6119	7371
4444	6119	8677
3446	6120	2546
3446	6120	407
3446	6120	4497
3446	6120	1689
3446	6120	6461
3446	6120	2966
3446	6120	8945
3446	6120	3523
7312	6121	4936
7312	6121	2568
7312	6121	6207
7312	6121	7756
2367	6122	7376
2367	6122	5914
2367	6122	7018
2367	6122	6915
2367	6122	2394
2678	6123	6425
13443	6124	6578
13443	6124	1458
13443	6124	1972
13443	6124	6791
13443	6124	396
13443	6124	450
13443	6124	1941
13443	6124	9645
13443	6124	3966
12719	6125	7699
12719	6125	34
12719	6125	1583
12719	6125	845
12719	6125	3402
12719	6125	472
12719	6125	207
12719	6125	4071
12719	6125	7380
15660	6126	4194
15660	6126	7058
15660	6126	8442
15660	6126	4519
15660	6126	8966
15660	6126	1961
15660	6126	6340
15660	6126	3250
13301	6127	1509
13301	6127	6200
13301	6127	1810
13301	6127	47
4570	6128	4168
4570	6128	3762
4570	6128	2620
4570	6128	7490
4570	6128	497
4570	6128	585
7668	6129	484
7668	6129	37
7668	6129	3437
7668	6129	7572
7668	6129	9817
7668	6129	3215
18567	6130	2410
18567	6130	6679
18567	6130	8870
18567	6130	6615
14398	6131	1033
14398	6131	2891
14398	6131	8845
14398	6131	3509
14398	6131	9165
14398	6131	7527
1483	6132	25
1483	6132	2672
1483	6132	7626
1483	6132	7463
1483	6132	3519
1483	6132	5860
1483	6132	1276
1483	6132	3748
13278	6133	9567
13278	6133	3408
1870	6134	1676
1870	6134	5713
1870	6134	4956
1870	6134	4134
1870	6134	7734
1870	6134	9075
1870	6134	5674
13897	6135	9256
13897	6135	8775
16684	6136	7073
16684	6136	4746
16684	6136	5934
16684	6136	2706
15321	6137	241
15321	6137	3852
15321	6137	9016
14808	6138	9540
14808	6138	524
1853	6139	4738
1853	6139	8043
1853	6139	8515
1853	6139	5904
1853	6139	5623
1853	6139	8880
1853	6139	6280
1853	6139	3416
1853	6139	8437
5374	6140	3933
5374	6140	1858
5374	6140	7690
5374	6140	5383
5374	6140	9884
5374	6140	8075
13179	6141	7809
13179	6141	9532
13179	6141	3177
13179	6141	5810
13179	6141	5943
11196	6142	1727
11196	6142	8233
11196	6142	5322
11196	6142	4249
11196	6142	269
11196	6142	824
11196	6142	2058
11196	6142	4933
5483	6143	9431
5483	6143	1275
5483	6143	1252
5483	6143	9486
5483	6143	2815
9081	6144	8124
9081	6144	3288
9081	6144	3308
9081	6144	6504
9081	6144	1900
9081	6144	4558
9081	6144	2522
8011	6145	8666
8011	6145	4243
8011	6145	4445
8011	6145	193
8011	6145	146
8011	6145	1800
8011	6145	6691
8011	6145	31
8011	6145	2295
17597	6146	7360
17597	6146	2266
17597	6146	2516
17597	6146	3887
17597	6146	842
10170	6147	8813
17916	6148	6386
17916	6148	9123
17916	6148	8657
17916	6148	9754
17916	6148	216
17916	6148	7625
17916	6148	9249
17916	6148	7457
17916	6148	1728
5140	6149	7655
5140	6149	6073
5140	6149	9027
5140	6149	5425
5140	6149	2674
5140	6149	9691
16694	6150	538
16694	6150	5202
16694	6150	1006
16694	6150	8052
16694	6150	6216
16694	6150	9806
16694	6150	2349
16694	6150	2381
16906	6151	1927
16906	6151	107
16906	6151	3703
16906	6151	6397
16906	6151	8144
16906	6151	9907
16906	6151	3041
16906	6151	6843
16906	6151	9560
11551	6152	2225
11551	6152	6015
11551	6152	7026
6991	6153	5390
6991	6153	9585
6991	6153	5077
6991	6153	1020
6991	6153	5592
17263	6154	2677
17263	6154	3639
17263	6154	1371
17263	6154	7498
17263	6154	5336
17263	6154	8200
17263	6154	9593
17263	6154	5857
2492	6155	338
2492	6155	1808
2492	6155	8343
2492	6155	2285
2492	6155	6030
2492	6155	8989
5255	6156	940
5255	6156	8881
5255	6156	4899
5255	6156	8637
5255	6156	8339
9161	6157	407
9161	6157	4425
9161	6157	7436
9161	6157	9613
9161	6157	3012
9161	6157	8040
9161	6157	4348
9161	6157	4627
9161	6157	7241
12243	6158	3202
12243	6158	9015
12243	6158	4972
12243	6158	6121
12243	6158	7574
3997	6159	4766
3997	6159	3944
3997	6159	3996
3997	6159	9777
8808	6160	9971
8808	6160	7300
1002	6161	2041
1002	6161	8015
1002	6161	7975
1002	6161	4688
1002	6161	7587
1002	6161	8986
1002	6161	1782
1002	6161	130
1002	6161	4912
17700	6162	29
14656	6163	7829
14656	6163	7381
14656	6163	5648
14656	6163	8030
14656	6163	984
14656	6163	8385
14656	6163	6147
15856	6164	3706
15651	6165	8528
15651	6165	9548
15651	6165	1417
15651	6165	3072
15651	6165	4026
19348	6166	3296
19348	6166	9863
19348	6166	5400
19348	6166	9051
19348	6166	3936
19348	6166	7372
19348	6166	4562
17245	6167	2712
17245	6167	9429
17245	6167	8785
17245	6167	3374
4977	6168	9633
4977	6168	5629
4977	6168	7460
4977	6168	5504
4977	6168	7349
4977	6168	5861
4977	6168	7080
4977	6168	3050
13292	6169	9790
13292	6169	5884
18514	6170	1746
18514	6170	218
11692	6171	6874
11692	6171	3620
11692	6171	5815
11692	6171	8944
11692	6171	9901
11692	6171	5442
11692	6171	8639
16857	6172	7003
16857	6172	5840
16857	6172	7837
16857	6172	2258
16857	6172	8963
16857	6172	3900
1546	6173	4996
1546	6173	2116
1546	6173	4921
724	6174	2344
724	6174	2999
724	6174	8243
724	6174	6710
724	6174	8389
1293	6175	2553
3138	6176	4205
3138	6176	8701
3138	6176	6206
3138	6176	8336
3138	6176	3983
3138	6176	6708
3138	6176	957
18399	6177	3282
18399	6177	7875
18399	6177	8741
2587	6178	2863
2587	6178	2716
2587	6178	6513
2587	6178	3387
2587	6178	5038
2587	6178	4855
3124	6179	1267
3124	6179	1175
8912	6180	9404
8912	6180	3643
8912	6180	9102
3928	6181	9031
3928	6181	5153
3928	6181	4090
3928	6181	4139
10315	6182	7132
10315	6182	6522
10315	6182	2746
10315	6182	2762
10315	6182	4984
17252	6183	9241
17252	6183	688
17252	6183	1904
17252	6183	5474
17252	6183	2135
17252	6183	7247
17252	6183	8509
17252	6183	1431
17125	6184	6869
17125	6184	9351
17125	6184	5347
17125	6184	1796
17125	6184	2961
17125	6184	3692
17125	6184	7108
18024	6185	6069
18024	6185	1340
19695	6186	8862
19695	6186	2497
19695	6186	8321
19695	6186	3183
17059	6187	3498
14379	6188	1568
14379	6188	5852
14379	6188	5245
14379	6188	1895
14379	6188	5235
14379	6188	6432
14379	6188	8333
1659	6189	195
1659	6189	1784
1659	6189	6654
1659	6189	9982
19427	6190	6554
19427	6190	9392
19427	6190	4573
19427	6190	4325
19427	6190	1220
19427	6190	866
18397	6191	28
445	6192	9413
445	6192	42
445	6192	2816
445	6192	9107
445	6192	4720
445	6192	9065
7275	6193	105
7275	6193	1948
7275	6193	7618
1124	6194	8448
8915	6195	7122
8915	6195	9225
8915	6195	6427
8915	6195	93
8915	6195	3992
8915	6195	5257
8915	6195	2795
8915	6195	4444
8915	6195	3971
3177	6196	2151
3177	6196	4234
3177	6196	1106
3177	6196	5055
4352	6197	2113
4352	6197	2040
4352	6197	3895
4352	6197	1362
8313	6198	7056
8313	6198	8921
8313	6198	8713
1726	6199	1461
1726	6199	3849
1726	6199	1393
1726	6199	8691
1726	6199	2040
1726	6199	465
1726	6199	3008
1726	6199	110
1726	6199	3510
13328	6200	3789
13328	6200	6506
13328	6200	1469
13328	6200	3365
13328	6200	665
13328	6200	5760
14305	6201	4868
10664	6202	9691
10664	6202	8210
10664	6202	7270
10664	6202	9865
7306	6203	6155
7306	6203	289
7306	6203	2169
7306	6203	4344
7306	6203	5466
7306	6203	5081
7306	6203	5714
7306	6203	3194
4316	6204	1232
4316	6204	8172
4316	6204	5332
4316	6204	6495
4316	6204	1689
15685	6205	7361
15685	6205	7709
15685	6205	3340
15685	6205	7388
15685	6205	1483
15685	6205	8370
15685	6205	9648
70	6206	8632
70	6206	6567
70	6206	4828
70	6206	1610
70	6206	7197
70	6206	4359
70	6206	4833
70	6206	5851
18380	6207	7611
11960	6208	9630
11960	6208	3594
11960	6208	6775
11960	6208	5043
19741	6209	6387
19741	6209	5875
19741	6209	4039
19741	6209	2465
19741	6209	3248
19741	6209	9079
19741	6209	6700
19741	6209	6159
16066	6210	6742
16066	6210	548
16066	6210	9990
12357	6211	3977
12357	6211	6860
12357	6211	2592
10114	6212	946
10114	6212	2768
10114	6212	6553
10114	6212	8257
4855	6213	192
4855	6213	7216
4855	6213	7657
4855	6213	6360
673	6214	187
673	6214	5090
673	6214	2612
673	6214	4551
14636	6215	6244
14636	6215	1513
14636	6215	1886
4155	6216	2259
4155	6216	8192
4155	6216	5872
4155	6216	8955
18284	6217	9887
18284	6217	680
18284	6217	4559
18284	6217	1755
18284	6217	8710
445	6218	3254
445	6218	9183
445	6218	2223
445	6218	1107
445	6218	60
445	6218	5938
445	6218	7814
12407	6219	7206
12407	6219	2479
12407	6219	7558
12407	6219	7525
12407	6219	2231
12407	6219	6490
12407	6219	9850
12407	6219	1535
7515	6220	4172
7515	6220	6181
7515	6220	9547
7515	6220	5763
7515	6220	198
7515	6220	5745
7515	6220	7361
7515	6220	9167
7515	6220	2457
9374	6221	8119
9374	6221	7417
9374	6221	8316
9374	6221	3411
9374	6221	4715
9374	6221	9320
9374	6221	7691
6908	6222	9676
6908	6222	2489
6908	6222	537
6908	6222	1953
6908	6222	8346
15563	6223	7066
15563	6223	5452
15563	6223	3740
15563	6223	4170
15563	6223	6444
15563	6223	9349
8474	6224	9323
8474	6224	1238
8474	6224	4299
8474	6224	3466
8474	6224	4767
8474	6224	9389
8474	6224	9593
8474	6224	8246
8474	6224	8426
4329	6225	618
4329	6225	9698
4329	6225	3137
4329	6225	4203
4329	6225	977
4329	6225	7988
4573	6226	8538
4573	6226	612
4573	6226	1202
4573	6226	8124
4573	6226	6863
4573	6226	3143
4573	6226	8714
4573	6226	5111
9616	6227	6861
9616	6227	8563
9616	6227	7025
9616	6227	52
9616	6227	8837
9616	6227	1161
9616	6227	2794
9616	6227	5300
6847	6228	9973
6847	6228	7740
6847	6228	2285
6847	6228	8017
6847	6228	7658
6847	6228	4826
6847	6228	813
6847	6228	2357
4816	6229	6447
4816	6229	6149
4816	6229	3131
4816	6229	3234
4816	6229	4871
4816	6229	3946
4816	6229	3258
4816	6229	3529
3090	6230	8859
3090	6230	6712
18137	6231	1476
15844	6232	7162
15844	6232	7049
15844	6232	7300
15844	6232	7069
15844	6232	6763
15844	6232	2930
14930	6233	9658
14930	6233	5749
14930	6233	365
14930	6233	5438
14930	6233	7168
14930	6233	5578
14930	6233	4836
14930	6233	2221
18539	6234	1189
18539	6234	5379
18539	6234	9786
18539	6234	8242
155	6235	771
155	6235	1802
155	6235	6286
155	6235	9009
155	6235	4152
17975	6236	984
17975	6236	1563
17975	6236	195
11148	6237	3883
11148	6237	8274
11148	6237	9021
19584	6238	928
19584	6238	4128
19584	6238	1856
19584	6238	4522
19584	6238	7267
19584	6238	4222
19584	6238	9809
7	6239	5577
7	6239	7079
7	6239	8182
7	6239	9115
7	6239	7674
19583	6240	8195
19583	6240	7858
19583	6240	3497
19583	6240	1979
19583	6240	6127
19583	6240	9013
19583	6240	1985
19583	6240	5939
3031	6241	975
3031	6241	7526
10398	6242	4990
10398	6242	60
15835	6243	296
15835	6243	4860
15835	6243	1413
15835	6243	2358
16592	6244	9812
16592	6244	1778
16592	6244	1618
16592	6244	875
16592	6244	4502
16592	6244	8899
16592	6244	548
16592	6244	2676
16592	6244	6876
14344	6245	3595
11904	6246	4248
11904	6246	8090
11904	6246	3530
11904	6246	4844
11904	6246	9170
11904	6246	1910
11904	6246	884
11904	6246	3163
11678	6247	1749
11678	6247	3814
11678	6247	7928
11678	6247	5408
11678	6247	3360
11678	6247	390
16960	6248	8347
16960	6248	9872
16960	6248	2227
16960	6248	1188
16960	6248	2589
4710	6249	8997
4710	6249	4945
4710	6249	4810
4710	6249	218
4710	6249	4777
4710	6249	1559
4710	6249	1184
5698	6250	9358
5698	6250	9509
1394	6251	5048
1394	6251	4073
6138	6252	5880
6138	6252	4173
17897	6253	4115
17897	6253	6514
17897	6253	3707
17897	6253	9753
18523	6254	9959
10012	6255	243
10012	6255	9326
10012	6255	6235
10012	6255	9403
10012	6255	1302
10012	6255	9355
6939	6256	1230
6939	6256	5869
14413	6257	7673
14413	6257	2596
14413	6257	5208
10899	6258	2867
10899	6258	643
10899	6258	2749
10899	6258	3873
10899	6258	2921
9509	6259	296
9509	6259	7785
9509	6259	4192
9509	6259	2155
9509	6259	8230
9509	6259	1722
9509	6259	5924
4064	6260	4375
4064	6260	4022
15789	6261	7133
15789	6261	3533
15789	6261	1603
15789	6261	5234
15789	6261	2730
15789	6261	7415
15789	6261	1290
15789	6261	9634
11114	6262	7589
11114	6262	9719
11114	6262	8031
11114	6262	9086
11114	6262	1634
11114	6262	2668
11114	6262	3113
11114	6262	7014
4496	6263	1673
4496	6263	7641
4496	6263	7162
12483	6264	4207
12483	6264	932
12483	6264	2382
12483	6264	7665
12483	6264	2851
12483	6264	9780
12483	6264	8063
10154	6265	7325
10154	6265	4505
4291	6266	9419
4499	6267	2669
10100	6268	6517
10100	6268	1722
10100	6268	3008
9451	6269	6472
9451	6269	8503
9451	6269	1184
9451	6269	3122
9451	6269	2116
9451	6269	1072
9451	6269	4790
14916	6270	2508
14916	6270	6763
14916	6270	3623
14916	6270	5321
9016	6271	1302
9016	6271	5317
9016	6271	8803
3848	6272	4464
3848	6272	2392
3848	6272	6530
3848	6272	6712
18438	6273	8244
18438	6273	1556
18438	6273	4408
11524	6274	3588
11524	6274	9177
11524	6274	4772
11524	6274	4314
11524	6274	4358
11524	6274	5125
11524	6274	8031
11524	6274	8720
11524	6274	9677
7665	6275	1611
7665	6275	5768
7677	6276	3211
7677	6276	705
7677	6276	7758
4142	6277	849
4142	6277	4203
4142	6277	6667
4142	6277	3621
4142	6277	7950
4142	6277	176
4142	6277	9785
11103	6278	9390
11103	6278	7614
11103	6278	4949
11103	6278	4989
11103	6278	3795
7365	6279	8695
7365	6279	4504
7365	6279	2664
7365	6279	1704
7365	6279	5705
7365	6279	6662
4728	6280	7545
4728	6280	1049
11995	6281	8703
11995	6281	6103
11995	6281	953
11995	6281	9104
11995	6281	1384
11995	6281	5009
11995	6281	1732
11995	6281	4661
2644	6282	3686
2644	6282	3724
2644	6282	4394
14848	6283	5442
14848	6283	7134
14848	6283	2952
14848	6283	3187
14848	6283	7734
14848	6283	5663
14848	6283	8618
14848	6283	9456
14848	6283	4829
15506	6284	1717
15506	6284	9515
15506	6284	8801
15506	6284	3534
15506	6284	5765
15506	6284	9043
15506	6284	521
15506	6284	985
17438	6285	1462
17438	6285	7104
17438	6285	172
17438	6285	8965
17438	6285	9686
17438	6285	3057
17438	6285	3296
17438	6285	7513
17438	6285	8473
8475	6286	7136
16242	6287	6840
16242	6287	6460
16242	6287	9421
16242	6287	9218
16242	6287	5496
16242	6287	4365
16242	6287	7451
1492	6288	2842
1492	6288	5143
1492	6288	2702
1492	6288	5215
15832	6289	4665
15832	6289	2484
15832	6289	3099
15832	6289	4687
15832	6289	1497
15832	6289	498
15832	6289	5363
15832	6289	3282
15832	6289	8694
3071	6290	6043
3071	6290	6348
4110	6291	2012
4110	6291	7032
4110	6291	4962
19298	6292	9831
19298	6292	3757
19298	6292	892
19298	6292	7140
19298	6292	313
19298	6292	1121
19298	6292	4366
19298	6292	6490
1533	6293	3001
1533	6293	1433
1533	6293	9275
1533	6293	163
1533	6293	6043
1533	6293	3570
1533	6293	5552
12887	6294	6029
12887	6294	1389
12887	6294	6728
12887	6294	4313
12887	6294	6467
12887	6294	3983
12887	6294	329
12887	6294	4015
6577	6295	8962
6577	6295	9787
6577	6295	71
6577	6295	9858
6577	6295	1781
6577	6295	9346
6577	6295	8900
11253	6296	8844
11253	6296	2006
11253	6296	2189
11253	6296	9810
11253	6296	4095
11253	6296	9491
11253	6296	4004
11253	6296	6446
11253	6296	984
1681	6297	5063
7923	6298	9588
7923	6298	2949
7923	6298	7174
7923	6298	1257
2133	6299	7892
2133	6299	3631
153	6300	6593
153	6300	5331
153	6300	5719
153	6300	1247
153	6300	4354
7884	6301	2373
7260	6302	4697
7260	6302	4684
7260	6302	352
7716	6303	8348
7356	6304	4070
16848	6305	2366
16848	6305	4306
16848	6305	3028
5524	6306	8059
5524	6306	5652
5524	6306	6620
10021	6307	9994
18448	6308	9701
18448	6308	6787
18448	6308	4351
18448	6308	1812
18448	6308	3891
18448	6308	8976
18448	6308	7601
18448	6308	5323
1949	6309	1109
1949	6309	2532
1949	6309	6954
1949	6309	6686
1949	6309	1750
1949	6309	9611
1949	6309	3766
16233	6310	6773
16233	6310	7257
16233	6310	1699
14043	6311	7996
14043	6311	6771
14043	6311	927
14043	6311	512
14043	6311	1828
14043	6311	9128
14043	6311	9858
14043	6311	5027
14043	6311	5135
1368	6312	124
1368	6312	4261
1368	6312	165
1368	6312	8845
1368	6312	1855
1368	6312	5271
1368	6312	5944
1368	6312	7928
19511	6313	3332
19511	6313	1941
19511	6313	7133
17744	6314	7384
17744	6314	7348
15025	6315	8195
15025	6315	5389
15025	6315	4730
15025	6315	9662
15025	6315	7788
15025	6315	2413
15025	6315	6942
15025	6315	4951
4168	6316	956
4168	6316	134
4168	6316	1600
4168	6316	9983
4168	6316	4994
4168	6316	9854
4168	6316	338
4168	6316	6654
12630	6317	53
12630	6317	5803
12630	6317	5882
12630	6317	5878
3670	6318	5552
3670	6318	2132
3670	6318	5691
3670	6318	8455
16616	6319	3550
16616	6319	1752
16616	6319	6841
16616	6319	4487
16616	6319	9614
16616	6319	3888
16616	6319	1043
7761	6320	7674
7761	6320	1767
7761	6320	4302
7761	6320	1919
16532	6321	4950
16532	6321	2539
18757	6322	6272
18757	6322	9513
18757	6322	1287
18757	6322	9924
18757	6322	4436
18757	6322	322
18757	6322	8675
18757	6322	1914
18757	6322	9545
15372	6323	9699
15372	6323	1411
15372	6323	3749
15372	6323	1616
15372	6323	5373
15372	6323	5717
15372	6323	8046
15939	6324	9493
15939	6324	1986
15939	6324	6178
15939	6324	1145
15939	6324	7732
15939	6324	3409
15939	6324	3675
15939	6324	6877
15939	6324	5344
13917	6325	4845
13917	6325	1492
13917	6325	3270
13917	6325	860
13917	6325	6810
13917	6325	1127
14608	6326	3027
14608	6326	6542
14608	6326	256
14608	6326	9541
14608	6326	5301
14608	6326	7758
14608	6326	1843
14608	6326	3141
14608	6326	4575
15688	6327	4881
12014	6328	3311
12014	6328	8975
12014	6328	292
12014	6328	2771
12014	6328	5732
12014	6328	7680
12014	6328	7197
12014	6328	7567
12014	6328	3745
16640	6329	6164
16640	6329	5742
16640	6329	5281
16640	6329	7052
16640	6329	5841
9629	6330	330
9629	6330	3156
9629	6330	1782
17955	6331	8017
17955	6331	5369
17955	6331	8336
17955	6331	9047
17955	6331	7615
5790	6332	5347
5790	6332	2957
5790	6332	1973
4605	6333	8364
4605	6333	4261
4605	6333	9884
4605	6333	120
10976	6334	6197
10976	6334	3383
10976	6334	5478
10976	6334	6706
10976	6334	1522
10976	6334	3954
10976	6334	9715
10976	6334	4134
6518	6335	4166
6518	6335	2051
6518	6335	8205
6518	6335	1950
6518	6335	7658
6518	6335	7636
2035	6336	9944
2035	6336	6555
2035	6336	6423
2035	6336	5943
2035	6336	6435
2035	6336	6124
2035	6336	3335
2035	6336	1257
2035	6336	7209
10827	6337	4166
10827	6337	7091
10827	6337	6989
10827	6337	2819
5523	6338	4226
5523	6338	8196
5523	6338	1584
5523	6338	245
5523	6338	9294
5523	6338	7242
5523	6338	1079
5256	6339	6126
5256	6339	2467
5256	6339	5830
5256	6339	4589
5256	6339	4109
5256	6339	1409
5256	6339	3408
5256	6339	8578
5256	6339	5803
12095	6340	9627
12095	6340	6077
12095	6340	9559
12095	6340	3333
12095	6340	9266
3466	6341	1188
3466	6341	7928
3466	6341	2985
3466	6341	8428
3466	6341	4971
3466	6341	7994
3466	6341	7166
3466	6341	6822
3466	6341	9753
11659	6342	5763
11659	6342	9121
11659	6342	9943
11659	6342	6762
11659	6342	1852
11659	6342	9881
11659	6342	3245
11659	6342	9115
11659	6342	9256
14499	6343	1476
14499	6343	877
14499	6343	8128
14499	6343	7058
14499	6343	717
14499	6343	5765
11413	6344	8324
11413	6344	2559
11413	6344	4039
11413	6344	1068
11413	6344	7477
12309	6345	1998
12309	6345	3780
3816	6346	7188
3816	6346	155
3816	6346	4444
3816	6346	8659
3816	6346	2613
3816	6346	1113
3816	6346	5185
12506	6347	6577
12506	6347	4606
12506	6347	7644
12506	6347	3197
12506	6347	9478
12506	6347	3331
12506	6347	808
12506	6347	7975
4837	6348	9271
4837	6348	9110
8590	6349	548
8590	6349	6178
8590	6349	9383
8590	6349	1273
8590	6349	7387
8590	6349	8449
8590	6349	7943
17501	6350	9713
17501	6350	624
17501	6350	7896
17501	6350	257
17501	6350	277
17501	6350	1301
17501	6350	4733
17501	6350	9649
18063	6351	6057
9010	6352	6285
9010	6352	1405
9010	6352	4382
10012	6353	4900
10012	6353	9251
10012	6353	7060
3584	6354	2702
8792	6355	3477
8792	6355	229
8792	6355	8980
8792	6355	5597
8792	6355	5095
8792	6355	1503
2597	6356	1351
2597	6356	5062
2597	6356	1491
2597	6356	202
2597	6356	6685
2597	6356	5259
2597	6356	7299
2597	6356	2076
2597	6356	3197
4353	6357	2562
4353	6357	5771
4353	6357	3354
4353	6357	5362
4353	6357	640
4353	6357	5983
14947	6358	1363
14947	6358	8226
14947	6358	4785
14947	6358	3492
14947	6358	6300
12990	6359	2287
12990	6359	1890
12990	6359	5490
12990	6359	8813
12990	6359	287
12990	6359	7563
12990	6359	5153
12990	6359	3742
10209	6360	1725
10209	6360	1757
10209	6360	6980
10209	6360	1905
10209	6360	4551
10209	6360	4124
12027	6361	1257
12027	6361	8535
12027	6361	3160
12027	6361	7813
12027	6361	8782
12027	6361	5214
12027	6361	6659
16766	6362	3600
16766	6362	2833
16766	6362	3792
16766	6362	6273
16766	6362	4222
18233	6363	2825
18233	6363	6728
18233	6363	781
18233	6363	4296
18233	6363	6094
5505	6364	1136
5505	6364	4147
5505	6364	8374
5505	6364	239
5505	6364	4364
5505	6364	80
5505	6364	4978
5505	6364	7702
5505	6364	9192
11839	6365	459
11839	6365	6154
11839	6365	314
11839	6365	9306
11839	6365	1874
11839	6365	1098
18943	6366	1637
18943	6366	1924
18943	6366	5949
18943	6366	5723
18943	6366	8028
7678	6367	431
13169	6368	9089
13169	6368	2175
6543	6369	2743
6543	6369	8179
6543	6369	7349
6595	6370	6947
6595	6370	6733
15132	6371	8859
15132	6371	5884
15132	6371	5097
15132	6371	3855
15132	6371	5934
15132	6371	543
15132	6371	4212
15132	6371	2901
15132	6371	7664
7516	6372	5576
7516	6372	4526
7516	6372	1615
7516	6372	9874
7516	6372	2693
7516	6372	6715
7516	6372	5436
7516	6372	3548
7516	6372	9082
19248	6373	2909
19248	6373	7340
19248	6373	5547
19248	6373	4330
19248	6373	9328
7706	6374	7247
7706	6374	4620
2667	6375	3145
2667	6375	5545
2667	6375	1545
2667	6375	1850
2667	6375	1230
2667	6375	9241
9576	6376	3880
9576	6376	9564
9576	6376	1582
9576	6376	4664
9576	6376	3862
9576	6376	8767
9576	6376	616
9576	6376	932
9576	6376	9346
1782	6377	4834
1782	6377	2594
1782	6377	2557
1782	6377	8862
1782	6377	7581
1782	6377	8687
1782	6377	6206
1782	6377	8921
5564	6378	7461
5564	6378	5144
5564	6378	4528
5564	6378	4869
5564	6378	5381
5564	6378	8350
5564	6378	1613
5564	6378	4288
6299	6379	5891
6299	6379	3591
6299	6379	4080
6299	6379	2966
6299	6379	5293
6299	6379	1036
12358	6380	669
12358	6380	8927
12358	6380	3640
12358	6380	6262
12358	6380	8220
12358	6380	9422
12358	6380	3699
12358	6380	3531
14241	6381	9631
14241	6381	5613
14241	6381	7769
3307	6382	66
3307	6382	4837
3307	6382	9544
3307	6382	6269
3307	6382	3729
3307	6382	6356
3307	6382	1573
3307	6382	7698
12115	6383	8497
12115	6383	5981
7498	6384	5402
7498	6384	3276
7498	6384	7080
7498	6384	4460
7498	6384	6588
634	6385	3467
634	6385	8839
634	6385	1891
634	6385	7222
634	6385	9811
634	6385	5967
634	6385	9828
634	6385	9540
9883	6386	409
9738	6387	5598
9738	6387	5489
9738	6387	9088
9738	6387	7604
9738	6387	121
14685	6388	3061
14685	6388	2011
14685	6388	2318
14685	6388	3474
14685	6388	6492
14685	6388	9987
17143	6389	3744
17143	6389	7067
17143	6389	8181
17143	6389	8188
17143	6389	4080
17143	6389	5278
17143	6389	5650
17421	6390	1599
17421	6390	267
17421	6390	291
17421	6390	2715
17421	6390	3658
17421	6390	8849
17421	6390	8371
17421	6390	2793
1946	6391	6757
4068	6392	919
4068	6392	2680
4068	6392	1581
4068	6392	154
889	6393	723
889	6393	3672
4083	6394	7479
18136	6395	4738
18136	6395	244
18136	6395	6289
18136	6395	3758
18136	6395	540
18136	6395	3247
18136	6395	7185
18136	6395	1137
3719	6396	1431
3719	6396	374
3719	6396	6221
3719	6396	7582
3719	6396	6920
3719	6396	5884
3719	6396	3900
3719	6396	2551
12617	6397	1646
12617	6397	8522
12617	6397	4999
12617	6397	4619
12617	6397	1518
12617	6397	7993
12617	6397	8410
12617	6397	6543
8248	6398	5705
8248	6398	4795
8248	6398	4315
3208	6399	9433
3208	6399	1350
3208	6399	4130
3208	6399	7612
3208	6399	6008
3208	6399	1418
3208	6399	2078
3208	6399	2367
3208	6399	4457
13519	6400	4947
13519	6400	8052
13519	6400	3863
13519	6400	865
13519	6400	6790
13519	6400	2816
13519	6400	8250
13519	6400	4487
990	6401	4495
990	6401	6939
990	6401	5688
990	6401	5446
990	6401	8154
990	6401	6878
990	6401	3685
15095	6402	5064
15095	6402	3521
15095	6402	7701
4375	6403	2682
14354	6404	4039
14354	6404	5963
14354	6404	3810
14354	6404	6653
14354	6404	7217
19155	6405	2802
19155	6405	7949
19155	6405	829
19155	6405	8094
19155	6405	7837
19155	6405	6172
19155	6405	8350
19155	6405	7696
3468	6406	1219
3468	6406	8451
3468	6406	7916
3468	6406	8208
12184	6407	9041
12184	6407	4370
12184	6407	5518
12184	6407	5522
12184	6407	8189
12184	6407	3873
12184	6407	5496
12184	6407	4579
15997	6408	5228
15997	6408	2391
15997	6408	2317
15997	6408	6675
15997	6408	6690
11461	6409	5599
11461	6409	2440
11461	6409	7335
11461	6409	2814
11461	6409	7167
11461	6409	2776
11461	6409	2176
11461	6409	9744
11461	6409	598
5976	6410	3586
5976	6410	6904
5976	6410	3383
5976	6410	6006
5976	6410	2488
5976	6410	5826
5976	6410	2725
5976	6410	5556
5976	6410	4367
14284	6411	3219
14284	6411	6399
14284	6411	9181
14284	6411	6804
14284	6411	2766
14284	6411	2084
10933	6412	7312
10933	6412	8274
10933	6412	9595
10933	6412	6297
10933	6412	6536
10933	6412	7872
10933	6412	7805
2046	6413	4839
2046	6413	6227
2046	6413	3024
10215	6414	574
10215	6414	9364
10215	6414	5508
10204	6415	252
10204	6415	7981
10204	6415	5553
10204	6415	461
10204	6415	6808
10204	6415	4762
10204	6415	2738
11523	6416	869
11523	6416	8013
11523	6416	9480
11523	6416	9327
11523	6416	5013
7294	6417	8817
8737	6418	6326
8737	6418	5932
8737	6418	9886
8737	6418	2076
8737	6418	4431
8737	6418	8493
8737	6418	696
8737	6418	6741
8737	6418	3881
17787	6419	2541
17787	6419	5591
17787	6419	9727
17787	6419	5726
17787	6419	2976
17815	6420	7577
17815	6420	2457
17815	6420	7269
17815	6420	7305
17815	6420	7453
17815	6420	8139
17815	6420	112
17815	6420	227
17815	6420	8551
8282	6421	8194
2338	6422	77
15305	6423	9659
15305	6423	3575
15305	6423	5483
7242	6424	6921
7242	6424	7646
16505	6425	8586
16505	6425	9329
16505	6425	8974
16505	6425	965
16505	6425	6267
16505	6425	6702
16505	6425	3762
16505	6425	4038
16505	6425	3324
8663	6426	5452
6195	6427	1350
6195	6427	8150
6195	6427	2949
6195	6427	12
6195	6427	8708
6195	6427	973
6195	6427	2111
6195	6427	1493
11060	6428	5050
11060	6428	1690
11060	6428	2300
11060	6428	8252
11060	6428	239
11060	6428	4284
11060	6428	8928
3754	6429	3800
3754	6429	2511
9243	6430	494
9243	6430	618
9243	6430	3841
9243	6430	5277
9243	6430	3857
4217	6431	5892
4217	6431	4498
4217	6431	9907
19639	6432	8440
4070	6433	7122
4070	6433	4197
4070	6433	8884
4070	6433	3406
4070	6433	3568
4070	6433	1735
4070	6433	9371
10526	6434	83
10526	6434	9666
10526	6434	2124
10526	6434	7274
5084	6435	257
5084	6435	7153
12072	6436	196
3861	6437	6855
3861	6437	2761
3861	6437	5091
3861	6437	1556
3861	6437	9622
3861	6437	1978
3861	6437	4243
13682	6438	6561
13682	6438	4147
13682	6438	4425
13682	6438	4884
13682	6438	2695
13682	6438	6550
13682	6438	508
13682	6438	6437
13682	6438	2656
8424	6439	7892
8424	6439	2627
8424	6439	7525
8424	6439	8975
8424	6439	1757
8424	6439	7149
3145	6440	6192
3145	6440	7449
3145	6440	226
3145	6440	6145
17601	6441	3012
17601	6441	3067
17601	6441	2735
17601	6441	3038
17601	6441	7757
17601	6441	9020
17601	6441	7548
14205	6442	1541
14205	6442	3189
14205	6442	6672
14205	6442	6945
14205	6442	77
14205	6442	1618
14205	6442	5504
14205	6442	2739
10948	6443	5734
10948	6443	582
10948	6443	1533
10948	6443	921
10948	6443	5232
10948	6443	4903
10948	6443	2592
10948	6443	5761
5410	6444	874
5410	6444	9848
5173	6445	8061
5173	6445	2427
5173	6445	1229
5173	6445	8546
18933	6446	8127
18933	6446	3140
18933	6446	2703
18933	6446	9981
18933	6446	1605
18933	6446	5792
11278	6447	8226
11278	6447	7942
11278	6447	3011
11278	6447	79
17250	6448	8091
17250	6448	881
17250	6448	1318
17250	6448	6935
17250	6448	2920
9048	6449	7002
9048	6449	9661
9048	6449	8818
9048	6449	9659
5338	6450	6908
5338	6450	2874
5338	6450	5016
5338	6450	613
3862	6451	5952
3862	6451	1032
3862	6451	7360
3862	6451	8203
15727	6452	5749
15727	6452	317
15727	6452	2545
15727	6452	4169
14085	6453	8007
14085	6453	8858
14085	6453	5902
3708	6454	6036
8477	6455	2102
8477	6455	8644
8477	6455	3424
8477	6455	7770
8477	6455	6404
8700	6456	7312
8700	6456	2750
8700	6456	2176
8700	6456	4943
8700	6456	505
8700	6456	1817
8700	6456	5520
8700	6456	779
5760	6457	730
5760	6457	4850
5760	6457	1787
5760	6457	437
5760	6457	5603
5760	6457	5985
17469	6458	7386
17469	6458	59
17469	6458	578
17469	6458	4431
17469	6458	4035
17469	6458	4945
17469	6458	8089
17469	6458	7169
4036	6459	3271
4036	6459	2151
4036	6459	7170
4036	6459	1788
4036	6459	6870
8510	6460	2146
8510	6460	4085
16239	6461	9399
16239	6461	3856
16239	6461	8691
16239	6461	8585
16239	6461	1959
16239	6461	3761
1861	6462	4504
1861	6462	3387
1861	6462	3370
11030	6463	2091
11030	6463	1069
11030	6463	1844
11399	6464	2714
11399	6464	8445
11399	6464	7475
16405	6465	719
8209	6466	2388
8209	6466	9025
8209	6466	6109
8209	6466	1473
6633	6467	9016
6633	6467	1174
6633	6467	299
6633	6467	6402
6633	6467	1824
6633	6467	5975
6633	6467	6208
6633	6467	2599
13786	6468	52
13786	6468	9330
13786	6468	9996
9969	6469	3720
9787	6470	4512
9787	6470	3733
9787	6470	6448
9787	6470	1294
9787	6470	6400
9787	6470	9004
17722	6471	7743
15476	6472	2723
12885	6473	1336
12885	6473	2940
12885	6473	3898
12885	6473	2181
12885	6473	6379
12885	6473	3000
12885	6473	7367
16302	6474	8988
11970	6475	6320
15275	6476	4617
15275	6476	5616
15275	6476	2690
9741	6477	8345
11422	6478	3862
11422	6478	3714
11422	6478	4332
11422	6478	8834
10306	6479	2791
10306	6479	2564
10306	6479	2095
10306	6479	4963
10306	6479	7692
10306	6479	9655
10306	6479	9795
10306	6479	407
10306	6479	3710
15142	6480	420
18506	6481	4406
18506	6481	7975
18506	6481	992
18506	6481	4603
18506	6481	8717
18506	6481	7870
18506	6481	8755
18506	6481	3957
8727	6482	9631
8727	6482	6802
8727	6482	8507
8727	6482	5946
8727	6482	6475
8727	6482	932
8727	6482	7686
8727	6482	8077
8727	6482	9444
16320	6483	4568
16320	6483	7155
16320	6483	9548
16320	6483	2888
16320	6483	1908
16320	6483	9532
16320	6483	3142
16320	6483	5931
16320	6483	576
3013	6484	413
3013	6484	7394
3013	6484	4041
3013	6484	8016
3013	6484	8787
3013	6484	7285
3013	6484	1108
3013	6484	8617
1049	6485	9234
1049	6485	5675
1049	6485	8743
1049	6485	7568
1049	6485	7756
1049	6485	8491
1049	6485	2215
12510	6486	2541
12510	6486	8622
12510	6486	9766
12510	6486	6657
12510	6486	3725
12510	6486	8907
16280	6487	3304
16280	6487	4322
16280	6487	8410
16280	6487	1724
16280	6487	245
16280	6487	2785
16280	6487	194
16280	6487	4307
5856	6488	2657
5856	6488	9797
17407	6489	6843
17407	6489	4447
17407	6489	5150
17407	6489	1018
17407	6489	845
17407	6489	460
6487	6490	1067
6487	6490	9606
6487	6490	6593
6487	6490	4129
6487	6490	1380
6487	6490	5631
6487	6490	2629
18943	6491	9618
18943	6491	4946
18943	6491	7473
18943	6491	3376
18943	6491	6881
18943	6491	1175
4481	6492	4955
4481	6492	8697
4481	6492	5745
4481	6492	3008
4481	6492	5434
4481	6492	3626
4779	6493	6303
4779	6493	5359
4779	6493	4079
4779	6493	1707
4779	6493	8788
11430	6494	2248
11430	6494	3595
11430	6494	9159
11430	6494	1021
11430	6494	714
11430	6494	7803
11430	6494	3618
13919	6495	5247
13919	6495	6807
13919	6495	1726
1027	6496	6228
1027	6496	4580
1027	6496	6590
1027	6496	9419
1027	6496	7513
1027	6496	7915
1027	6496	6893
1020	6497	7470
1020	6497	2325
1020	6497	9252
1020	6497	2042
1020	6497	7645
1020	6497	1490
1020	6497	9805
1020	6497	5552
1020	6497	6192
11221	6498	6050
5883	6499	3452
1842	6500	3637
1842	6500	1613
1842	6500	6635
16249	6501	5842
16249	6501	2192
16249	6501	5988
16249	6501	7644
16249	6501	4820
16249	6501	9683
16249	6501	6634
16249	6501	3979
8270	6502	6616
8270	6502	3419
8270	6502	321
8270	6502	7485
8270	6502	8178
8270	6502	6130
8270	6502	9625
11224	6503	9490
11224	6503	7388
11224	6503	1007
11224	6503	377
3458	6504	9489
3458	6504	9755
3458	6504	3964
3458	6504	2960
3458	6504	8398
9054	6505	2848
9054	6505	2462
9054	6505	4904
9054	6505	3807
9054	6505	1124
9054	6505	6313
9054	6505	9798
17835	6506	4653
17835	6506	5624
17835	6506	5361
7515	6507	8284
7515	6507	4140
7515	6507	6085
7515	6507	7048
7515	6507	8553
7515	6507	3280
7515	6507	5666
10927	6508	4381
10927	6508	7124
10927	6508	828
10927	6508	7650
15428	6509	5004
18286	6510	5745
18286	6510	3002
12563	6511	5874
12563	6511	8389
12563	6511	9557
13361	6512	9428
13361	6512	8442
13361	6512	7166
4338	6513	1312
4338	6513	9750
4338	6513	2382
4338	6513	1354
4338	6513	9033
4338	6513	2567
4338	6513	479
72	6514	6716
72	6514	4471
5826	6515	1300
5826	6515	4313
11250	6516	2681
11250	6516	8948
11250	6516	5912
11250	6516	9363
11250	6516	2885
11250	6516	9434
6315	6517	8684
6315	6517	2735
6315	6517	3275
6315	6517	5807
6315	6517	8346
6315	6517	2490
12758	6518	2650
12758	6518	2459
12758	6518	7915
12758	6518	7039
12758	6518	1662
12758	6518	4475
12758	6518	9630
12758	6518	8130
1730	6519	501
1730	6519	8577
1730	6519	7901
1730	6519	3638
9251	6520	4561
4951	6521	3276
4951	6521	2166
4951	6521	9549
4951	6521	8115
4951	6521	109
4951	6521	8543
18087	6522	7889
18087	6522	2488
19866	6523	28
19866	6523	8007
19866	6523	3188
19866	6523	4377
13084	6524	8338
13084	6524	9592
16268	6525	7178
16268	6525	5436
16268	6525	8160
16268	6525	6593
5489	6526	3457
5489	6526	6565
5489	6526	5409
5489	6526	3108
5489	6526	7483
5489	6526	9686
5489	6526	9647
5489	6526	4266
9588	6527	5188
9588	6527	9655
9588	6527	8188
9588	6527	2917
9588	6527	8992
4897	6528	9093
4401	6529	9520
4401	6529	4734
4401	6529	9162
4401	6529	9983
4401	6529	3792
4401	6529	1161
4401	6529	5077
4401	6529	2327
4401	6529	7062
12107	6530	8502
12107	6530	3723
12107	6530	650
1696	6531	733
1696	6531	8482
1696	6531	7798
1696	6531	6466
1696	6531	3276
1696	6531	570
1696	6531	8441
1696	6531	1617
1696	6531	8138
18689	6532	7568
16435	6533	9066
16435	6533	6762
16435	6533	5899
16435	6533	9692
16435	6533	3708
16435	6533	5286
16435	6533	3782
4445	6534	7724
4445	6534	7876
4445	6534	6233
4445	6534	9337
4445	6534	9910
4445	6534	2018
4445	6534	4436
2395	6535	6441
2395	6535	9635
2395	6535	6728
2395	6535	7131
2395	6535	776
2395	6535	2732
912	6536	9736
912	6536	9325
912	6536	6447
912	6536	6060
912	6536	2176
912	6536	9548
912	6536	1693
16266	6537	8281
16266	6537	2710
16266	6537	8238
16266	6537	7878
16266	6537	3011
16266	6537	1425
16266	6537	4589
16266	6537	2071
17036	6538	6983
17036	6538	6786
17036	6538	7539
17036	6538	6957
17036	6538	6612
17036	6538	3483
12385	6539	9678
12385	6539	4890
12385	6539	5478
12385	6539	2113
8367	6540	2701
8367	6540	3997
8367	6540	2449
8367	6540	6212
8367	6540	9261
8367	6540	5681
8367	6540	1126
13618	6541	730
11238	6542	1934
11238	6542	4793
11238	6542	4016
11238	6542	7113
11238	6542	5897
16691	6543	8333
16691	6543	5781
16691	6543	7024
15573	6544	8854
15573	6544	3565
15573	6544	62
15573	6544	2828
15573	6544	1118
15573	6544	1403
15573	6544	6392
15573	6544	1851
16499	6545	861
16499	6545	2668
19381	6546	7477
19381	6546	4686
19381	6546	1703
19381	6546	4432
19381	6546	9535
19381	6546	3760
10324	6547	3677
10324	6547	3559
8383	6548	3157
8383	6548	3386
8383	6548	7175
8383	6548	2288
8383	6548	4191
8383	6548	981
8383	6548	5223
9515	6549	5410
9515	6549	6579
510	6550	3556
510	6550	6573
510	6550	1464
9698	6551	1781
9698	6551	7682
9698	6551	5125
695	6552	5105
695	6552	938
695	6552	4300
695	6552	1711
695	6552	7771
695	6552	5503
695	6552	5261
695	6552	9699
695	6552	1805
15336	6553	5820
15336	6553	9324
15336	6553	4931
15336	6553	1291
12791	6554	6910
12791	6554	9162
13865	6555	8259
13865	6555	752
13865	6555	1147
13865	6555	3513
13865	6555	224
13865	6555	6071
13865	6555	8366
13865	6555	6987
16555	6556	4673
16555	6556	8937
16555	6556	8106
16555	6556	203
16555	6556	5031
16555	6556	9956
16555	6556	3789
9870	6557	7654
9870	6557	6857
9870	6557	9531
9870	6557	9119
9870	6557	8518
1638	6558	8873
1638	6558	1049
1638	6558	25
1638	6558	8257
1638	6558	617
1638	6558	8344
1638	6558	8920
1638	6558	9341
1638	6558	4349
2410	6559	6427
2410	6559	1717
2410	6559	5536
2410	6559	5764
2410	6559	5977
14051	6560	8277
17786	6561	3299
17786	6561	3463
17786	6561	9184
17786	6561	9632
699	6562	185
699	6562	388
699	6562	8281
699	6562	4246
699	6562	786
4797	6563	2268
4797	6563	8452
4797	6563	4575
4797	6563	7349
4797	6563	4388
4797	6563	5849
4797	6563	1386
4797	6563	4369
4797	6563	308
1389	6564	6845
1389	6564	5748
14060	6565	6589
14060	6565	5088
14060	6565	2644
14060	6565	6790
2356	6566	5198
2356	6566	8413
2356	6566	9349
2356	6566	4120
8786	6567	8912
8786	6567	3890
8786	6567	6825
8786	6567	2513
8786	6567	6213
8786	6567	8454
10487	6568	6422
10487	6568	8512
10487	6568	3285
10487	6568	1185
10487	6568	5645
10118	6569	1318
10118	6569	9034
10118	6569	6735
10118	6569	9125
10118	6569	9271
10118	6569	6849
10118	6569	4194
10118	6569	2968
10118	6569	9075
15173	6570	4511
15173	6570	4335
19051	6571	8764
19051	6571	5801
19051	6571	1738
19051	6571	3655
19051	6571	1783
19051	6571	6200
19051	6571	649
7233	6572	3005
7233	6572	9403
7826	6573	4068
7826	6573	7416
7826	6573	892
7826	6573	5813
7826	6573	3977
7826	6573	9229
7826	6573	8412
7826	6573	556
2409	6574	4821
2409	6574	4200
2409	6574	295
7701	6575	1741
7701	6575	1739
7701	6575	864
7701	6575	5337
7701	6575	9324
7701	6575	4226
7701	6575	6944
7701	6575	9563
18408	6576	1587
18408	6576	694
18408	6576	1349
6369	6577	1225
6369	6577	8484
6369	6577	5737
6369	6577	5594
6369	6577	6023
6369	6577	385
6369	6577	3470
6065	6578	2236
7646	6579	9609
7646	6579	4069
7646	6579	1585
5618	6580	5772
5618	6580	3729
5618	6580	2295
5618	6580	6284
19507	6581	2786
19507	6581	3018
19507	6581	8363
10830	6582	3816
10830	6582	7449
10830	6582	1459
10830	6582	8209
10830	6582	7727
10830	6582	8168
10830	6582	5347
10830	6582	1206
2409	6583	4089
2409	6583	7982
2409	6583	9191
16069	6584	6487
7870	6585	7281
7870	6585	1948
7870	6585	3164
7870	6585	6462
7870	6585	578
7439	6586	6868
7439	6586	5693
9765	6587	2917
9765	6587	3567
9765	6587	8526
19000	6588	8683
3693	6589	357
3693	6589	9754
17251	6590	1585
17251	6590	192
17251	6590	2594
17251	6590	4224
17251	6590	4337
5726	6591	2363
5726	6591	8872
5726	6591	1078
5726	6591	2892
5726	6591	6585
5726	6591	10
5726	6591	3745
5726	6591	4964
13096	6592	8198
13096	6592	5402
13096	6592	1580
13096	6592	212
10226	6593	2129
10226	6593	6009
10226	6593	8117
10226	6593	8460
10226	6593	2149
11786	6594	1657
11786	6594	2550
11786	6594	4796
11786	6594	1201
11786	6594	3168
11786	6594	9936
5074	6595	7501
5074	6595	7640
5074	6595	3826
5074	6595	2410
9117	6596	452
9117	6596	7497
92	6597	793
92	6597	3479
92	6597	1218
984	6598	4513
984	6598	6449
984	6598	6962
984	6598	7908
984	6598	2559
984	6598	3931
8763	6599	6489
8763	6599	7401
8763	6599	2787
8763	6599	2165
8763	6599	2153
8763	6599	9681
8763	6599	3875
16774	6600	539
16774	6600	2043
9203	6601	7915
9203	6601	3729
9203	6601	4025
9203	6601	8440
9203	6601	3944
9203	6601	9619
9203	6601	7493
9203	6601	9491
9203	6601	1262
13163	6602	8350
13163	6602	7935
6704	6603	2700
6704	6603	4216
6704	6603	1843
6704	6603	6645
6704	6603	9665
6704	6603	1509
6704	6603	6696
12371	6604	9550
12371	6604	8897
12371	6604	866
17600	6605	2152
17600	6605	1874
17600	6605	5540
17600	6605	1278
15845	6606	8510
15845	6606	3276
15845	6606	8173
15845	6606	1391
1881	6607	2242
1881	6607	2788
1881	6607	2987
1881	6607	159
1881	6607	3059
17197	6608	5981
17197	6608	9189
15396	6609	2903
15396	6609	4047
15396	6609	5333
15396	6609	5234
15396	6609	6234
15396	6609	2842
15396	6609	3306
15396	6609	9448
15396	6609	967
1909	6610	2220
1909	6610	6064
1909	6610	729
1909	6610	9106
4017	6611	6302
4017	6611	6960
4017	6611	8520
4017	6611	9009
4017	6611	2215
4017	6611	7190
16312	6612	9110
16312	6612	4890
1907	6613	3458
1907	6613	6630
1907	6613	3852
307	6614	1688
307	6614	2101
307	6614	909
307	6614	3011
307	6614	5977
307	6614	6254
307	6614	64
307	6614	5418
307	6614	6694
18863	6615	1275
18863	6615	5044
18863	6615	8651
18863	6615	5280
18863	6615	5898
18863	6615	9224
18863	6615	7664
18863	6615	2313
18863	6615	8230
8967	6616	9847
8967	6616	4481
8967	6616	1626
8967	6616	5972
8967	6616	9753
8967	6616	9974
8967	6616	2373
8967	6616	1787
8967	6616	8302
15051	6617	7658
15051	6617	2958
15051	6617	6286
9440	6618	8572
394	6619	2682
394	6619	9975
394	6619	1365
6304	6620	837
6304	6620	7105
6304	6620	6903
6304	6620	4516
6304	6620	650
6304	6620	2280
6304	6620	5521
6304	6620	1237
6304	6620	657
14946	6621	4042
14946	6621	9625
14946	6621	3045
14946	6621	8558
14946	6621	484
14946	6621	7663
14946	6621	5914
859	6622	1231
859	6622	4019
859	6622	932
3175	6623	9060
3175	6623	2103
3175	6623	4670
3175	6623	8508
3175	6623	2631
6228	6624	702
6228	6624	2986
6228	6624	2802
6228	6624	6052
6228	6624	4114
6228	6624	783
6228	6624	5326
6228	6624	6633
11385	6625	8794
11385	6625	589
11385	6625	4931
11385	6625	4366
11385	6625	6333
11385	6625	4109
11385	6625	3198
11385	6625	87
12275	6626	6208
12275	6626	3661
12275	6626	2441
12275	6626	107
12275	6626	5986
12275	6626	8060
12275	6626	9871
12275	6626	2080
12891	6627	7271
12891	6627	5234
12891	6627	1691
12891	6627	6468
12891	6627	1458
12891	6627	4810
12891	6627	7313
12891	6627	9197
18607	6628	1958
18607	6628	9527
18607	6628	5659
18607	6628	6630
18607	6628	8052
10643	6629	5790
4514	6630	8756
4514	6630	5400
4514	6630	2880
4514	6630	5821
4514	6630	3900
4514	6630	6391
4514	6630	1784
14885	6631	4968
14885	6631	1433
14885	6631	896
14885	6631	1651
15858	6632	5664
15858	6632	564
15858	6632	3765
15858	6632	5661
15858	6632	5085
15858	6632	4358
12282	6633	3583
12282	6633	7417
12282	6633	489
2769	6634	8070
14022	6635	4708
14022	6635	5550
14022	6635	8714
14022	6635	8058
14022	6635	770
12372	6636	9288
12372	6636	7581
12372	6636	690
19865	6637	825
19865	6637	6104
19865	6637	4533
19865	6637	4132
19865	6637	6082
19865	6637	7713
19865	6637	891
3320	6638	7846
3320	6638	6534
3320	6638	8880
3320	6638	3838
18781	6639	6941
18781	6639	9158
7381	6640	2931
7381	6640	3786
7381	6640	4732
7381	6640	6414
9197	6641	1340
9197	6641	1315
9197	6641	7840
9197	6641	9789
18581	6642	9617
18581	6642	4527
16763	6643	8318
16763	6643	8078
16763	6643	2157
16763	6643	6376
16763	6643	9089
16763	6643	2675
16763	6643	7297
10272	6644	5158
13629	6645	7628
13629	6645	8932
13629	6645	8074
13629	6645	9567
13629	6645	106
13629	6645	9441
13629	6645	2135
13629	6645	756
13629	6645	9386
13364	6646	1818
13364	6646	2735
13364	6646	244
10817	6647	5101
10817	6647	3550
6231	6648	759
6231	6648	5730
6231	6648	4822
6231	6648	4117
11536	6649	8067
11536	6649	3895
11536	6649	9682
11536	6649	3262
11536	6649	9546
11536	6649	4888
11536	6649	5801
18323	6650	2629
18323	6650	6389
18323	6650	5205
18323	6650	4844
18323	6650	5417
18323	6650	5089
18323	6650	2093
11973	6651	124
11973	6651	2164
11973	6651	2282
11973	6651	4315
11973	6651	5488
11973	6651	7244
11973	6651	9518
11973	6651	9351
9111	6652	3876
9111	6652	7832
9111	6652	8837
15696	6653	6541
15696	6653	3290
15696	6653	5701
15696	6653	5755
15696	6653	3654
15696	6653	2149
3332	6654	7572
3332	6654	2188
3332	6654	2071
3332	6654	7219
3332	6654	5028
3332	6654	9825
3332	6654	3904
888	6655	9148
888	6655	2081
888	6655	7482
888	6655	6144
888	6655	6630
888	6655	1296
17735	6656	3555
17735	6656	309
17735	6656	8367
17735	6656	6829
1466	6657	1177
1466	6657	2210
1466	6657	3157
1466	6657	5226
1466	6657	24
1466	6657	268
3127	6658	431
3127	6658	2097
3127	6658	8912
3127	6658	4759
3127	6658	7741
3127	6658	5469
3127	6658	2320
3127	6658	5923
16266	6659	2423
16266	6659	8879
16266	6659	415
16266	6659	9101
16266	6659	711
16266	6659	4059
16266	6659	3599
16266	6659	5126
19768	6660	1471
19768	6660	6523
19768	6660	4650
19768	6660	7288
19768	6660	578
19768	6660	7975
13707	6661	6000
13420	6662	7851
5953	6663	2860
5953	6663	1848
5953	6663	8851
5953	6663	8122
5953	6663	815
2785	6664	4393
2785	6664	8062
8123	6665	771
8123	6665	4843
8123	6665	3387
8123	6665	1598
8915	6666	8789
8915	6666	7594
8915	6666	3140
8915	6666	2319
8915	6666	9801
8915	6666	7583
8915	6666	5504
8915	6666	4034
8915	6666	9705
951	6667	9097
951	6667	3420
1594	6668	22
1594	6668	1519
9318	6669	1033
9318	6669	2003
9318	6669	17
8101	6670	2473
8101	6670	4439
8101	6670	8582
8101	6670	6881
15943	6671	9851
15943	6671	3320
15943	6671	434
15943	6671	6029
15943	6671	7338
15943	6671	2280
15943	6671	5676
15943	6671	6847
15943	6671	6347
17639	6672	1803
17639	6672	1870
17639	6672	4666
17639	6672	6654
17639	6672	5479
17639	6672	283
17639	6672	7874
17639	6672	2969
613	6673	9647
613	6673	1750
613	6673	6572
613	6673	3584
613	6673	6916
613	6673	8803
613	6673	330
613	6673	7401
613	6673	6771
4499	6674	1049
4499	6674	3458
4499	6674	2336
6596	6675	9936
6596	6675	463
6596	6675	9929
6596	6675	6975
11556	6676	6450
11556	6676	7037
18990	6677	2236
18990	6677	6011
18990	6677	535
18990	6677	6324
18990	6677	1643
18990	6677	8826
18990	6677	8240
16338	6678	5014
16338	6678	838
16338	6678	7089
16338	6678	3540
16338	6678	509
11957	6679	2497
11957	6679	1550
11957	6679	2490
11957	6679	7888
11957	6679	4280
11957	6679	5711
7592	6680	8856
7592	6680	4384
7592	6680	6277
7592	6680	6981
7592	6680	5598
7592	6680	373
7592	6680	3468
7592	6680	5075
7592	6680	2652
10283	6681	9274
10283	6681	3597
10283	6681	1294
10283	6681	8781
10283	6681	8936
10283	6681	7682
10283	6681	7330
8620	6682	1799
10533	6683	1231
10533	6683	1305
10533	6683	446
10533	6683	7109
10533	6683	4576
11738	6684	7851
11738	6684	1120
11738	6684	2558
11738	6684	9491
6528	6685	7410
6528	6685	9824
6528	6685	2025
6528	6685	5367
6528	6685	1280
16775	6686	9093
16775	6686	9574
16775	6686	3718
16775	6686	8635
2384	6687	8540
2384	6687	5710
2384	6687	601
849	6688	1478
849	6688	8974
849	6688	4361
849	6688	1145
849	6688	1807
849	6688	126
7687	6689	8681
7687	6689	9459
7687	6689	4205
7687	6689	8010
7687	6689	4275
7687	6689	3033
7687	6689	9034
7687	6689	3540
5027	6690	617
5027	6690	9014
5027	6690	4649
5027	6690	3804
5027	6690	2983
5027	6690	2548
5027	6690	4366
5027	6690	3628
5027	6690	4
8557	6691	2174
8557	6691	7730
4985	6692	1615
4985	6692	7473
4985	6692	1266
10138	6693	7676
10138	6693	4413
10138	6693	955
1918	6694	5237
1918	6694	609
1918	6694	9206
1918	6694	3124
1918	6694	830
1918	6694	2058
1918	6694	193
1918	6694	3073
1918	6694	1653
16109	6695	7004
16109	6695	6243
16109	6695	8044
16109	6695	8918
8309	6696	1565
8309	6696	4891
8309	6696	5848
8309	6696	6037
8309	6696	8165
8309	6696	7436
18176	6697	7143
18176	6697	8416
18176	6697	9672
18176	6697	2105
2043	6698	5176
2043	6698	4009
2043	6698	9931
2043	6698	1427
2043	6698	4620
2043	6698	3684
2043	6698	3693
2759	6699	5593
2759	6699	7769
2759	6699	1495
2759	6699	8668
2759	6699	5155
2759	6699	4621
2759	6699	7634
2759	6699	3672
7205	6700	9381
7205	6700	5426
7205	6700	7945
7205	6700	4183
7205	6700	497
7205	6700	66
7205	6700	1740
7205	6700	98
17530	6701	8943
13153	6702	8219
13153	6702	8294
13153	6702	5746
13153	6702	3921
13153	6702	737
9839	6703	9310
2097	6704	4283
2097	6704	5738
2097	6704	7435
2097	6704	2569
2097	6704	1257
2097	6704	3146
2097	6704	1600
14690	6705	8516
14690	6705	4021
15706	6706	1751
15706	6706	5126
15706	6706	3436
15706	6706	489
15847	6707	6378
15847	6707	6908
15847	6707	4584
5638	6708	4975
17990	6709	6848
17990	6709	8765
17990	6709	9224
17990	6709	2081
17990	6709	3298
7641	6710	6912
7641	6710	793
7641	6710	6392
7641	6710	2327
7641	6710	8195
7641	6710	7425
14688	6711	2032
14688	6711	8479
14688	6711	7610
14688	6711	4686
14688	6711	361
14688	6711	2260
5505	6712	9623
5505	6712	2534
5505	6712	4043
5505	6712	3367
5505	6712	3040
5505	6712	5406
5505	6712	8135
5505	6712	1306
19568	6713	7486
19568	6713	3881
19568	6713	3629
19568	6713	37
15822	6714	6578
15822	6714	4529
15822	6714	1541
15822	6714	2857
15822	6714	8686
15822	6714	167
15822	6714	5831
15822	6714	6986
15894	6715	3594
15894	6715	6587
15894	6715	6622
15894	6715	2654
15894	6715	4535
15894	6715	4029
15894	6715	3480
15894	6715	1731
9174	6716	2849
9174	6716	1959
9174	6716	1239
9174	6716	1091
9174	6716	6891
967	6717	7706
967	6717	4446
967	6717	308
967	6717	7159
967	6717	91
967	6717	2895
967	6717	5658
967	6717	6408
18513	6718	7936
18513	6718	5387
18513	6718	8759
18513	6718	6717
18513	6718	2761
18513	6718	7816
4522	6719	1240
4522	6719	4327
4522	6719	8620
4522	6719	3151
4522	6719	6568
4522	6719	9536
4522	6719	8815
4522	6719	7497
4522	6719	825
19167	6720	9577
19167	6720	7380
19167	6720	8386
18419	6721	7191
11621	6722	88
11621	6722	4933
11621	6722	6220
11621	6722	4184
11621	6722	497
12543	6723	8763
12543	6723	9678
16126	6724	7273
16126	6724	2107
8660	6725	9704
9272	6726	8383
9272	6726	5332
3859	6727	3688
3859	6727	7935
3859	6727	55
3859	6727	1428
17400	6728	3163
17400	6728	7146
17400	6728	5378
1550	6729	2392
1550	6729	7949
1550	6729	8747
1550	6729	9653
6679	6730	6704
6679	6730	8320
6679	6730	1122
6679	6730	6832
6679	6730	1844
6679	6730	9782
6679	6730	3431
6679	6730	5838
14646	6731	7191
14646	6731	6048
14646	6731	6083
14646	6731	9833
14646	6731	9039
14646	6731	5799
14646	6731	5505
14646	6731	3875
1411	6732	700
1411	6732	3980
1411	6732	6203
1411	6732	1358
1411	6732	7141
8661	6733	267
8661	6733	2209
8661	6733	4381
8661	6733	7740
8661	6733	6990
8661	6733	4297
14887	6734	2434
14887	6734	2176
16756	6735	514
16756	6735	124
16756	6735	7701
16756	6735	7483
16756	6735	8856
16756	6735	8066
16756	6735	939
15857	6736	8793
15857	6736	5155
15857	6736	52
15857	6736	2632
15857	6736	4002
15857	6736	605
15857	6736	6787
13821	6737	8359
13821	6737	9272
14675	6738	3143
4385	6739	1112
4385	6739	7289
4385	6739	4321
4385	6739	3391
4385	6739	8951
4385	6739	8556
4385	6739	5114
14413	6740	6782
12098	6741	6255
12098	6741	2538
12098	6741	5408
12098	6741	1315
12098	6741	848
12098	6741	7683
12098	6741	8523
12098	6741	3492
4094	6742	4206
15339	6743	405
15339	6743	218
15339	6743	3757
15339	6743	3693
18200	6744	5620
18200	6744	777
18599	6745	6773
18599	6745	1965
18599	6745	9624
18599	6745	5841
18599	6745	3840
18599	6745	1181
18599	6745	7789
18599	6745	4721
18599	6745	7870
17458	6746	903
17458	6746	9506
17458	6746	6435
17458	6746	979
17458	6746	5849
17458	6746	253
17458	6746	7734
17458	6746	3983
15644	6747	2066
15644	6747	9465
15644	6747	5612
15644	6747	5200
15644	6747	6064
15644	6747	1700
15644	6747	5846
15644	6747	8646
19248	6748	7376
19248	6748	797
19248	6748	3218
209	6749	8172
209	6749	9029
209	6749	1454
209	6749	4971
209	6749	8092
19583	6750	997
19583	6750	7492
19583	6750	6270
19583	6750	1117
19583	6750	3922
14277	6751	7243
14277	6751	2399
14277	6751	3961
14277	6751	3051
14277	6751	6069
14277	6751	2067
14277	6751	9057
14114	6752	3703
14114	6752	3081
14114	6752	4716
14114	6752	3617
14114	6752	6112
5609	6753	2098
5609	6753	8432
5609	6753	3634
19405	6754	3863
19405	6754	4973
19405	6754	5618
19405	6754	2763
11688	6755	42
12305	6756	8957
12305	6756	7895
12305	6756	7290
12305	6756	7113
12305	6756	7809
14626	6757	5874
14626	6757	2304
14626	6757	8713
14626	6757	811
14626	6757	910
1902	6758	7104
1902	6758	8910
1902	6758	3370
1902	6758	7115
8455	6759	2813
9875	6760	2035
9875	6760	5616
9875	6760	4066
9875	6760	5212
284	6761	4175
284	6761	7821
284	6761	9090
284	6761	9889
284	6761	1850
284	6761	432
284	6761	3957
284	6761	5641
284	6761	8182
431	6762	963
431	6762	8373
9798	6763	4435
9798	6763	9336
9798	6763	3575
9798	6763	3446
9798	6763	4630
9798	6763	6482
878	6764	2647
878	6764	6706
878	6764	6702
878	6764	926
18595	6765	4197
18595	6765	130
18595	6765	642
18595	6765	886
8662	6766	9626
8662	6766	7582
8662	6766	4601
14493	6767	6225
14493	6767	7471
14493	6767	6738
14493	6767	6448
14493	6767	4741
14493	6767	727
14493	6767	9274
14493	6767	4336
14493	6767	5585
6529	6768	7427
6529	6768	2470
6529	6768	8215
6529	6768	9273
10995	6769	2647
10995	6769	3005
15491	6770	2616
15491	6770	9067
15491	6770	9171
15491	6770	9178
15491	6770	7916
15491	6770	7777
15491	6770	6254
8937	6771	5056
8937	6771	2138
8937	6771	2145
8937	6771	1114
8937	6771	3879
8937	6771	2895
11020	6772	2461
11020	6772	9502
11020	6772	5458
11020	6772	5565
11020	6772	2759
252	6773	6767
252	6773	8971
252	6773	6058
252	6773	3688
252	6773	6264
252	6773	5257
252	6773	1182
252	6773	4668
252	6773	5891
10784	6774	2809
11133	6775	5693
11133	6775	6690
11133	6775	3778
11133	6775	1362
11133	6775	6775
11133	6775	7006
11133	6775	2616
7594	6776	7605
7594	6776	3993
7594	6776	4587
7594	6776	4271
7594	6776	7092
7594	6776	2962
7594	6776	6339
6057	6777	8689
6057	6777	9289
6057	6777	7523
6057	6777	8502
6057	6777	8558
6057	6777	3936
6057	6777	7562
6057	6777	1055
6057	6777	4748
18036	6778	7583
18036	6778	4647
647	6779	9777
647	6779	8235
647	6779	1101
647	6779	5360
647	6779	5897
647	6779	300
15723	6780	9416
15723	6780	2473
15723	6780	5137
15723	6780	5136
15723	6780	1506
15723	6780	6642
15723	6780	107
19767	6781	8949
8615	6782	8224
8615	6782	1638
6017	6783	9127
6017	6783	1239
6017	6783	8814
6017	6783	6983
6017	6783	6158
6017	6783	6475
6017	6783	7215
12888	6784	6774
12888	6784	9403
12888	6784	6260
12888	6784	6938
12888	6784	1627
4917	6785	5763
9153	6786	4895
9153	6786	4903
4235	6787	8562
4235	6787	3814
4235	6787	2758
4235	6787	2041
4235	6787	842
4235	6787	6915
4235	6787	4009
4235	6787	4926
1378	6788	5265
1378	6788	3427
16659	6789	447
16659	6789	8078
16659	6789	9594
16659	6789	4343
16659	6789	5107
16659	6789	1369
16659	6789	5361
16659	6789	8416
16659	6789	6103
7911	6790	6104
7911	6790	6719
7911	6790	9455
7911	6790	7860
7911	6790	2863
7911	6790	2274
3735	6791	4219
3735	6791	8038
6798	6792	2768
6798	6792	5644
6798	6792	3927
61	6793	9561
61	6793	5148
16021	6794	8950
16021	6794	3547
15531	6795	3352
15531	6795	6129
15531	6795	5906
3098	6796	1222
3098	6796	1150
1419	6797	8129
1419	6797	7307
1419	6797	9700
1419	6797	6891
1419	6797	8038
1419	6797	1012
1419	6797	4314
1419	6797	1359
1419	6797	1584
17552	6798	9895
17552	6798	9426
17552	6798	226
17552	6798	1754
17552	6798	2872
17552	6798	6858
17552	6798	3736
1253	6799	2210
1253	6799	2227
1253	6799	5177
1253	6799	6967
1253	6799	850
19326	6800	9698
19326	6800	6475
19326	6800	6225
19326	6800	8761
19326	6800	8110
3690	6801	2471
3690	6801	180
3690	6801	2792
3690	6801	1205
3690	6801	5992
3690	6801	4729
529	6802	5696
529	6802	352
529	6802	6125
529	6802	398
529	6802	5673
529	6802	504
529	6802	352
5644	6803	7503
17414	6804	6878
17414	6804	6071
17414	6804	410
17414	6804	9056
17414	6804	8777
17414	6804	8274
17414	6804	5984
17414	6804	9787
17414	6804	7178
15058	6805	351
15058	6805	8089
15058	6805	5074
15058	6805	6561
15058	6805	557
15058	6805	635
15058	6805	4792
7695	6806	3255
7695	6806	2880
7695	6806	4094
7695	6806	894
7695	6806	2957
7695	6806	8801
7695	6806	4751
7695	6806	3553
17252	6807	9116
17252	6807	7003
17252	6807	1352
17252	6807	795
15887	6808	3366
15887	6808	8134
15887	6808	4078
15887	6808	8731
15887	6808	6523
15887	6808	2961
15887	6808	6682
15887	6808	4113
15887	6808	5139
8509	6809	4005
8509	6809	6047
8509	6809	4908
8509	6809	2743
12216	6810	3568
12216	6810	7743
12216	6810	5964
12216	6810	9829
12216	6810	5538
12216	6810	5438
12216	6810	195
12216	6810	7930
1865	6811	5287
1865	6811	3635
1865	6811	9433
1865	6811	3634
1865	6811	2485
1865	6811	8732
1865	6811	7414
1865	6811	8349
16354	6812	4687
16354	6812	5928
16354	6812	8315
16354	6812	2327
16354	6812	4790
16354	6812	1979
11226	6813	1990
11226	6813	1216
19894	6814	6421
19894	6814	3180
19894	6814	7051
19894	6814	3437
19894	6814	3220
19894	6814	6619
19894	6814	3222
19894	6814	4678
19894	6814	2969
9474	6815	5937
9474	6815	2262
9474	6815	8732
9474	6815	7099
9474	6815	4454
9474	6815	8131
9474	6815	679
9474	6815	3115
12668	6816	7868
12668	6816	2482
12668	6816	4712
12668	6816	9202
2943	6817	5730
2943	6817	3276
2943	6817	8067
2943	6817	3719
2943	6817	3893
2943	6817	153
6535	6818	9601
6535	6818	7487
6535	6818	8867
6535	6818	14
18432	6819	688
18432	6819	1729
18432	6819	949
18432	6819	879
18432	6819	5378
18432	6819	1536
3377	6820	4956
3377	6820	7428
3377	6820	4693
3377	6820	2025
4078	6821	1255
3884	6822	8359
3884	6822	2640
3884	6822	1011
3884	6822	3834
3884	6822	7286
3884	6822	4235
3884	6822	3759
2371	6823	6100
2371	6823	1905
2371	6823	7810
2371	6823	1285
2371	6823	2558
2371	6823	1007
2371	6823	4827
2371	6823	5599
13218	6824	9155
13218	6824	2716
13218	6824	3894
15094	6825	5893
15094	6825	2097
15094	6825	4742
15094	6825	6840
15094	6825	8971
15094	6825	3217
16087	6826	5510
16087	6826	5208
16087	6826	378
16087	6826	3760
16087	6826	7752
16087	6826	9568
16087	6826	5200
16087	6826	6657
17506	6827	8660
17506	6827	1753
17506	6827	5126
17506	6827	7607
17506	6827	3013
17506	6827	6724
3863	6828	6294
3863	6828	8362
3863	6828	926
3863	6828	4376
3863	6828	5156
12281	6829	1867
12281	6829	1836
12281	6829	6074
12281	6829	8589
12281	6829	5087
12281	6829	629
11038	6830	788
11038	6830	2909
11038	6830	4080
11038	6830	7078
11038	6830	9960
11038	6830	9488
11038	6830	8373
11038	6830	3284
11038	6830	7716
7579	6831	7470
7579	6831	4048
7579	6831	8976
5434	6832	2752
5434	6832	3553
5434	6832	549
5434	6832	5288
9551	6833	4048
9551	6833	1476
10670	6834	7782
10670	6834	5333
10670	6834	1120
10670	6834	6001
10670	6834	7025
10670	6834	9140
10670	6834	6521
10670	6834	6609
3791	6835	6671
3791	6835	7422
3791	6835	6231
3791	6835	2481
3791	6835	4233
3791	6835	485
11635	6836	125
11635	6836	6912
12102	6837	8743
12102	6837	3241
12102	6837	5430
12102	6837	8251
12102	6837	6080
12102	6837	2818
10598	6838	3333
10598	6838	816
10598	6838	929
10598	6838	6564
10598	6838	4504
10598	6838	8204
10598	6838	9526
10598	6838	326
7132	6839	4384
7132	6839	6194
7132	6839	4258
7132	6839	2772
14798	6840	2511
14798	6840	2031
14798	6840	3105
14798	6840	4493
14798	6840	2068
14798	6840	1763
14798	6840	7826
12979	6841	583
13553	6842	5788
13553	6842	1864
13553	6842	669
6357	6843	6618
6357	6843	8365
6357	6843	8651
6357	6843	3807
6357	6843	2026
6357	6843	2500
6357	6843	8122
6357	6843	2082
6357	6843	8189
17374	6844	1957
17374	6844	1365
18211	6845	8877
18211	6845	4232
18211	6845	3531
14674	6846	8969
14674	6846	1586
14674	6846	3947
14674	6846	5793
14674	6846	4528
14674	6846	823
14674	6846	2540
14674	6846	4183
14674	6846	5404
2413	6847	3627
2413	6847	9128
13603	6848	6501
13603	6848	8826
13603	6848	552
12689	6849	7617
12689	6849	4705
12689	6849	8510
12689	6849	4062
12689	6849	8322
12689	6849	5120
17492	6850	5903
17492	6850	4887
17492	6850	567
17492	6850	3858
17492	6850	9474
17492	6850	2165
17492	6850	753
17492	6850	7508
4423	6851	1099
4423	6851	5226
691	6852	9092
691	6852	6702
691	6852	5699
691	6852	5390
691	6852	2975
691	6852	5658
691	6852	3657
691	6852	3675
2364	6853	3393
2364	6853	9011
2364	6853	3892
2364	6853	3910
2364	6853	4582
2364	6853	2167
2364	6853	2437
16270	6854	4401
16270	6854	3305
16270	6854	5880
16270	6854	7881
5550	6855	473
5550	6855	5453
5550	6855	8620
5550	6855	3719
16600	6856	1973
16600	6856	3931
16600	6856	7374
16600	6856	4696
16600	6856	7819
7395	6857	3251
7395	6857	2487
7395	6857	479
7395	6857	8115
7395	6857	2441
7395	6857	5276
7395	6857	9263
7395	6857	4459
7395	6857	3234
14328	6858	1551
14328	6858	4450
14328	6858	9764
9448	6859	1054
9448	6859	303
9448	6859	1437
9448	6859	7463
9448	6859	5150
9448	6859	37
8990	6860	926
8990	6860	1307
8990	6860	8455
8990	6860	9759
19046	6861	4247
19046	6861	1608
19046	6861	3655
19046	6861	6832
19046	6861	328
10955	6862	9890
10955	6862	3500
10955	6862	2086
10955	6862	6145
10955	6862	2419
10955	6862	6249
10955	6862	7504
10955	6862	1701
10955	6862	3766
10747	6863	7284
10747	6863	612
10747	6863	2374
10747	6863	3089
10747	6863	8585
4168	6864	6509
4168	6864	2826
4168	6864	4089
4168	6864	1106
4168	6864	7549
4168	6864	8281
4168	6864	8754
4168	6864	6687
4168	6864	5665
12551	6865	5856
8880	6866	6524
8880	6866	6645
8880	6866	481
8880	6866	1960
8880	6866	8545
8880	6866	6161
8880	6866	5871
9248	6867	4625
9248	6867	8064
9248	6867	6526
9248	6867	3160
6042	6868	231
6042	6868	2955
6869	6869	8003
6869	6869	1400
6869	6869	984
6869	6869	8604
6869	6869	1894
6869	6869	2485
6869	6869	3440
6869	6869	9224
4768	6870	5405
4768	6870	6471
4768	6870	2509
4768	6870	2511
4768	6870	2860
1724	6871	5026
1724	6871	5888
1724	6871	3122
1724	6871	6819
1724	6871	4300
1724	6871	6153
1724	6871	222
1724	6871	5907
2622	6872	6946
2622	6872	6749
2622	6872	3125
2622	6872	8313
2622	6872	470
2622	6872	8962
2622	6872	6790
19822	6873	5517
19822	6873	6201
19822	6873	453
19822	6873	8015
19822	6873	8989
19822	6873	7670
9230	6874	4072
9230	6874	2550
9230	6874	8430
14783	6875	2241
14783	6875	1144
13320	6876	8330
13320	6876	6204
13320	6876	8611
13320	6876	5213
13320	6876	5913
13320	6876	895
13320	6876	4347
13320	6876	8960
13320	6876	7350
3585	6877	3026
3585	6877	6069
3585	6877	1892
3585	6877	829
3585	6877	9431
3585	6877	5944
3585	6877	5502
3585	6877	826
13477	6878	7612
13477	6878	6694
8086	6879	5835
8086	6879	1707
8086	6879	5762
15307	6880	1345
15307	6880	3015
15307	6880	2488
15307	6880	1842
5351	6881	4403
5351	6881	7815
2352	6882	4453
2352	6882	6936
2352	6882	9834
2352	6882	3933
2352	6882	351
2352	6882	6720
2352	6882	8211
2352	6882	8984
1651	6883	3501
1651	6883	8831
1651	6883	1725
1651	6883	9000
1651	6883	7821
1651	6883	4155
1651	6883	5111
9889	6884	7807
9889	6884	3722
9889	6884	5834
9634	6885	5643
9634	6885	9992
9634	6885	703
4856	6886	8387
4856	6886	183
4856	6886	5560
4856	6886	3631
4856	6886	238
4856	6886	6356
154	6887	2009
154	6887	2207
154	6887	9339
154	6887	1280
154	6887	6992
154	6887	8152
154	6887	4410
5594	6888	5338
17938	6889	6388
17938	6889	3838
17938	6889	2889
17938	6889	5334
17938	6889	3235
17938	6889	9535
1629	6890	2797
1629	6890	6417
1629	6890	3671
1151	6891	3040
1151	6891	4310
1151	6891	8112
1151	6891	2308
1151	6891	8640
7947	6892	1514
7947	6892	4161
12126	6893	6116
12126	6893	445
12126	6893	2197
17915	6894	1275
17915	6894	2898
17915	6894	794
17915	6894	1335
19379	6895	1278
10877	6896	1501
15233	6897	7403
15233	6897	4692
15233	6897	7955
15233	6897	1165
8125	6898	9267
8125	6898	802
8416	6899	9127
1897	6900	2051
1897	6900	5473
1897	6900	8888
1897	6900	7850
1897	6900	639
1897	6900	4058
1897	6900	5034
1897	6900	5866
10266	6901	4800
10266	6901	1012
10266	6901	4157
10266	6901	5242
10266	6901	1087
10266	6901	8368
10266	6901	728
19231	6902	3195
19231	6902	5645
19231	6902	9159
19231	6902	1886
19231	6902	4328
19231	6902	157
19231	6902	4692
19231	6902	1167
19231	6902	9917
10316	6903	1243
10316	6903	66
10316	6903	8043
10316	6903	1585
10316	6903	1896
10316	6903	2112
10316	6903	2032
7833	6904	1804
7833	6904	473
7833	6904	1407
2646	6905	6481
2646	6905	4969
2646	6905	6998
2646	6905	9693
2646	6905	7090
2646	6905	9797
2646	6905	6057
2646	6905	6525
9485	6906	7288
9485	6906	5922
9485	6906	304
9485	6906	9399
9485	6906	8651
9485	6906	542
9485	6906	9156
9485	6906	2854
9485	6906	545
15270	6907	6620
6290	6908	7888
6290	6908	5548
6290	6908	3779
6290	6908	2935
6290	6908	8797
6290	6908	6584
14250	6909	2636
14250	6909	4003
14250	6909	7978
14250	6909	815
14250	6909	6184
14250	6909	1681
14250	6909	580
14250	6909	5157
1407	6910	2172
1407	6910	7479
1407	6910	8909
1407	6910	8416
1988	6911	6426
1988	6911	7002
1988	6911	4649
1988	6911	6206
15772	6912	7534
15772	6912	4297
15772	6912	5773
15772	6912	550
15772	6912	4514
15772	6912	8914
14658	6913	8323
14658	6913	7098
14658	6913	5931
1159	6914	1412
1159	6914	3244
1159	6914	2997
1159	6914	6394
1159	6914	7930
16958	6915	6507
16958	6915	3168
16958	6915	6354
16958	6915	1871
16958	6915	669
16958	6915	9426
16958	6915	3067
16958	6915	7178
16958	6915	3936
14360	6916	7957
14360	6916	2439
14360	6916	8474
14360	6916	4366
14360	6916	7416
1166	6917	4775
1166	6917	8641
1166	6917	306
1166	6917	2042
18439	6918	7808
15443	6919	4029
15443	6919	1603
15443	6919	5757
15443	6919	1088
15443	6919	6840
15443	6919	3756
17061	6920	3974
17061	6920	9367
12020	6921	6589
12020	6921	179
12020	6921	763
12020	6921	64
12020	6921	3912
12020	6921	7293
12020	6921	7634
12020	6921	2841
12020	6921	7077
19475	6922	1038
19475	6922	6377
19475	6922	5114
19475	6922	6415
19475	6922	7376
19475	6922	3389
19475	6922	7351
19475	6922	3379
14581	6923	6959
14581	6923	4614
14581	6923	1187
14581	6923	6395
14581	6923	1427
14581	6923	393
13539	6924	4468
13539	6924	6081
13539	6924	2286
13539	6924	9397
13539	6924	3620
13539	6924	7051
12260	6925	2843
12260	6925	6823
12260	6925	5098
12260	6925	5997
12260	6925	4739
12260	6925	8989
12260	6925	3159
15253	6926	9470
15253	6926	6641
15253	6926	3062
15253	6926	1641
15253	6926	2821
15253	6926	6242
15253	6926	8729
11103	6927	8769
7014	6928	8865
7014	6928	7489
7014	6928	6284
7014	6928	7128
7014	6928	2054
7014	6928	4619
12518	6929	7965
12518	6929	8464
12518	6929	554
12518	6929	2245
12518	6929	3607
12518	6929	2779
12518	6929	4520
6767	6930	3340
6767	6930	2000
6767	6930	8973
6767	6930	4234
16523	6931	5110
16523	6931	5866
16523	6931	4507
16523	6931	7061
1335	6932	919
1335	6932	1144
1335	6932	5666
18010	6933	9471
18010	6933	6224
10784	6934	9789
10784	6934	1525
10784	6934	650
10784	6934	2074
4323	6935	5028
12342	6936	4250
12342	6936	7497
12342	6936	8438
12342	6936	5820
12342	6936	673
12342	6936	53
12342	6936	3393
12342	6936	9715
729	6937	8075
729	6937	9730
729	6937	4274
729	6937	5748
729	6937	927
729	6937	5593
729	6937	8111
13097	6938	1210
13097	6938	6227
13097	6938	3367
13097	6938	1103
13097	6938	4537
13097	6938	3446
3039	6939	7972
3039	6939	8652
3039	6939	589
3039	6939	5562
7345	6940	221
7345	6940	2025
7345	6940	53
7345	6940	2692
7345	6940	7870
4812	6941	7891
4812	6941	1465
4812	6941	8451
4812	6941	593
4812	6941	3155
4812	6941	6681
4812	6941	7361
4812	6941	2389
4812	6941	6916
17880	6942	7191
17880	6942	9427
17880	6942	524
17880	6942	7467
17880	6942	5873
17880	6942	5471
7844	6943	1024
7844	6943	4235
7844	6943	8644
2065	6944	3642
2065	6944	4994
2065	6944	187
2065	6944	4411
2065	6944	7246
2065	6944	5541
2828	6945	8752
2828	6945	5242
12531	6946	3970
12531	6946	1413
12531	6946	5129
12531	6946	9163
12531	6946	3817
12531	6946	6451
12531	6946	6342
12531	6946	3618
12531	6946	5795
3287	6947	2964
3287	6947	896
3287	6947	4848
3287	6947	4471
3287	6947	6297
3287	6947	4397
3287	6947	1548
3287	6947	7346
2326	6948	5167
2326	6948	5605
2326	6948	4794
2326	6948	7942
2326	6948	3043
12013	6949	4211
12013	6949	8833
12013	6949	2986
14763	6950	6906
14763	6950	9379
14763	6950	1346
14763	6950	9945
14763	6950	5452
14763	6950	5296
14763	6950	6949
14763	6950	3338
9592	6951	7150
9592	6951	2275
9592	6951	8890
9592	6951	1112
9592	6951	2641
9592	6951	4678
9592	6951	4133
9592	6951	4747
9592	6951	8301
7505	6952	3998
7505	6952	525
7505	6952	7182
7505	6952	2131
7505	6952	1866
7505	6952	3388
7505	6952	5263
12749	6953	324
12749	6953	1586
12664	6954	1024
12664	6954	9073
12664	6954	9213
12664	6954	8454
12664	6954	406
5074	6955	1817
5074	6955	8018
5074	6955	4480
5074	6955	3455
7556	6956	8235
16339	6957	96
16339	6957	9660
16339	6957	215
16339	6957	9045
16339	6957	3748
16339	6957	3157
16339	6957	4937
16339	6957	4765
18487	6958	2010
18487	6958	9286
18487	6958	868
18487	6958	492
18487	6958	5689
11568	6959	5092
11568	6959	4409
11568	6959	6543
11568	6959	5194
11568	6959	718
11568	6959	4673
13452	6960	2234
13452	6960	3281
13452	6960	4476
13452	6960	9038
9453	6961	511
9453	6961	5319
9453	6961	5161
9453	6961	9737
9453	6961	7883
9453	6961	1402
9453	6961	5060
9453	6961	4083
9453	6961	2800
10066	6962	6552
10066	6962	9026
10066	6962	4986
10066	6962	316
10066	6962	437
11509	6963	5481
11509	6963	4617
11509	6963	1094
12306	6964	4296
12306	6964	4853
12306	6964	9925
12306	6964	772
12306	6964	414
12306	6964	2065
4762	6965	3207
4762	6965	7401
5763	6966	6245
5763	6966	5221
5763	6966	3044
5763	6966	4253
5763	6966	2204
5763	6966	3233
5763	6966	9501
5763	6966	8603
5763	6966	3802
10024	6967	6659
10024	6967	901
10024	6967	5888
10024	6967	6941
10024	6967	4689
10024	6967	8576
10024	6967	1393
10024	6967	7220
10024	6967	8958
4381	6968	6195
4381	6968	4164
4381	6968	821
4381	6968	5008
3333	6969	5726
3333	6969	5095
3333	6969	7697
3333	6969	5851
3333	6969	9691
3333	6969	7890
3333	6969	2888
3333	6969	6334
3333	6969	9038
10464	6970	5228
10464	6970	5528
10464	6970	2726
10464	6970	1902
10464	6970	3844
10464	6970	8861
13113	6971	2828
13113	6971	3387
13113	6971	5322
13113	6971	7565
13113	6971	3911
13113	6971	9538
15147	6972	6430
15147	6972	7297
15147	6972	1610
15147	6972	2004
15147	6972	6825
15147	6972	4393
15147	6972	7421
496	6973	965
496	6973	2922
496	6973	8499
496	6973	5131
496	6973	2628
496	6973	5610
4079	6974	1195
4079	6974	519
14686	6975	4461
14686	6975	6417
14686	6975	1730
5389	6976	1224
5389	6976	4122
5389	6976	1320
5389	6976	3317
5389	6976	1224
5389	6976	8968
5389	6976	8663
18361	6977	6524
18361	6977	8748
18361	6977	8906
18361	6977	8705
18361	6977	3106
15780	6978	1174
15780	6978	906
15780	6978	1235
15780	6978	9422
15780	6978	1564
452	6979	9407
452	6979	7506
12507	6980	1418
12507	6980	8875
12507	6980	8691
12507	6980	2413
12507	6980	6757
12507	6980	3540
12507	6980	6079
12507	6980	1884
6895	6981	3673
6895	6981	4827
6895	6981	4354
7377	6982	1929
7377	6982	1540
7377	6982	4527
7377	6982	3008
7377	6982	9285
7377	6982	526
13208	6983	2104
13208	6983	2756
13208	6983	7596
13208	6983	8435
13208	6983	9508
13208	6983	4755
13208	6983	6476
13208	6983	4438
13208	6983	3344
15739	6984	4809
15739	6984	1978
18805	6985	8711
18805	6985	746
18805	6985	35
18805	6985	7896
18805	6985	764
18805	6985	1256
15463	6986	6136
10685	6987	7557
10685	6987	8033
10685	6987	213
4300	6988	6191
4300	6988	9115
4300	6988	1348
4300	6988	4694
4300	6988	4413
4300	6988	7630
4300	6988	3681
19631	6989	5158
19631	6989	9565
19631	6989	3638
19631	6989	2249
19631	6989	3945
19631	6989	5999
19631	6989	8834
15896	6990	4958
18742	6991	9703
785	6992	7417
785	6992	4234
785	6992	424
785	6992	4578
785	6992	1721
15438	6993	9909
15438	6993	640
15438	6993	4501
14343	6994	7472
8518	6995	9735
8518	6995	3488
8518	6995	9461
8518	6995	1839
8518	6995	6584
8518	6995	2561
14577	6996	1229
14577	6996	9510
1882	6997	1429
1882	6997	9010
1882	6997	4631
1882	6997	432
7837	6998	7830
7837	6998	50
7837	6998	3731
7837	6998	4855
7837	6998	9898
7837	6998	6195
11408	6999	6645
11408	6999	5470
8958	7000	8551
8958	7000	9123
8958	7000	7077
8958	7000	1114
8958	7000	7628
8391	7001	6079
18655	7002	7571
18655	7002	730
18655	7002	2982
15040	7003	2602
15040	7003	7955
15040	7003	8826
15040	7003	2944
15040	7003	129
15040	7003	6776
15040	7003	8422
9001	7004	3828
2795	7005	6151
2795	7005	3287
2795	7005	7113
2795	7005	4071
4050	7006	8917
4050	7006	3504
4050	7006	985
4050	7006	4111
4050	7006	153
4050	7006	3906
4050	7006	9986
4050	7006	1501
4050	7006	9131
10562	7007	1641
10562	7007	4317
10562	7007	4533
10562	7007	7736
10562	7007	4122
10562	7007	5104
10562	7007	5698
10562	7007	7903
10562	7007	5494
18799	7008	7133
18799	7008	2423
18799	7008	2295
18799	7008	1544
18799	7008	9013
18799	7008	4818
18799	7008	8895
18799	7008	8136
18799	7008	7696
5598	7009	8887
5598	7009	8788
5598	7009	5840
5598	7009	3780
5598	7009	7741
5598	7009	2704
5598	7009	7175
5598	7009	9238
5598	7009	4997
19628	7010	9164
13717	7011	9658
17088	7012	2924
17088	7012	6749
17088	7012	4001
17088	7012	7616
17088	7012	4652
17088	7012	1702
17088	7012	3509
17088	7012	2140
7439	7013	3436
7439	7013	2534
7439	7013	4344
7439	7013	7264
7439	7013	735
7439	7013	2510
18515	7014	3746
18515	7014	3086
18515	7014	2767
18515	7014	2286
18515	7014	1485
18515	7014	1686
15787	7015	1528
15787	7015	6989
8503	7016	1154
8503	7016	2789
8503	7016	1671
8503	7016	9917
8503	7016	1128
8503	7016	3813
8503	7016	7789
8503	7016	170
8503	7016	524
17336	7017	248
14472	7018	1488
14472	7018	4677
14472	7018	9464
14472	7018	6177
14472	7018	616
3485	7019	5637
11611	7020	7660
11611	7020	5653
11611	7020	4371
11611	7020	8684
11611	7020	3137
11611	7020	7066
11611	7020	2881
4688	7021	3478
4688	7021	9534
4688	7021	1564
4688	7021	390
13701	7022	3836
13701	7022	5096
18933	7023	987
18933	7023	2587
18933	7023	3149
18933	7023	9794
18933	7023	7811
18933	7023	3854
18933	7023	8822
772	7024	7586
772	7024	8555
4779	7025	1878
4779	7025	3757
4779	7025	6085
4779	7025	5790
17876	7026	9351
17876	7026	1589
17876	7026	3236
9100	7027	6254
9100	7027	6133
9100	7027	8972
9100	7027	7197
9100	7027	9618
9100	7027	9556
9100	7027	6340
9100	7027	8117
1823	7028	3500
1823	7028	396
1823	7028	3621
1823	7028	5498
1823	7028	8181
1823	7028	8818
1823	7028	4674
1823	7028	9242
12877	7029	5513
12877	7029	3269
12877	7029	9068
12877	7029	3980
12877	7029	2296
12877	7029	1826
12877	7029	5464
12877	7029	884
12877	7029	5851
8062	7030	8465
8062	7030	3063
8062	7030	994
8062	7030	4145
8062	7030	3235
8062	7030	8294
8062	7030	1508
8062	7030	7887
366	7031	5979
366	7031	4785
366	7031	5081
8753	7032	2489
8753	7032	3265
8753	7032	837
8753	7032	8892
8753	7032	9124
8753	7032	4638
12292	7033	1634
12292	7033	6699
12292	7033	8082
12292	7033	8165
12292	7033	9539
12292	7033	3501
16335	7034	1298
4270	7035	7117
4270	7035	6680
4270	7035	2762
4270	7035	7900
4270	7035	1824
17045	7036	1199
17045	7036	4005
15012	7037	5673
13942	7038	9106
13942	7038	1058
13942	7038	5745
13942	7038	7976
13942	7038	3047
13942	7038	6046
18208	7039	243
18208	7039	6973
18208	7039	5329
18208	7039	1754
18208	7039	815
18208	7039	1064
18208	7039	4397
7004	7040	9724
7004	7040	6957
7004	7040	9893
7004	7040	3574
7004	7040	4874
7004	7040	5042
7004	7040	6089
7004	7040	2857
7004	7040	9532
2570	7041	8711
2570	7041	5616
2570	7041	3340
2570	7041	6609
12665	7042	4031
12665	7042	9956
12665	7042	6200
12665	7042	6585
12665	7042	3095
12665	7042	6527
12665	7042	5735
12665	7042	4138
12665	7042	7343
12108	7043	9161
12108	7043	2231
12108	7043	1590
12108	7043	2102
12108	7043	5179
12108	7043	2220
12108	7043	3737
12108	7043	9963
6116	7044	9010
6116	7044	2246
6116	7044	7607
6116	7044	4317
6116	7044	5643
6116	7044	8899
2258	7045	6355
2258	7045	9738
2258	7045	8807
2258	7045	6668
2258	7045	377
2258	7045	2864
2258	7045	9688
2258	7045	6226
16943	7046	8060
16943	7046	2637
3071	7047	2665
3071	7047	3715
3071	7047	1752
3071	7047	553
3071	7047	5410
3071	7047	3102
11930	7048	1822
11930	7048	2234
11930	7048	521
11930	7048	8599
2472	7049	2771
2472	7049	5919
2472	7049	9864
2472	7049	4454
2472	7049	3086
2472	7049	2174
2472	7049	2225
2472	7049	4281
2472	7049	1240
6124	7050	9469
6124	7050	5923
12323	7051	6145
12323	7051	4325
12323	7051	7509
12323	7051	1696
9561	7052	3275
9561	7052	3252
9561	7052	5267
9561	7052	7661
9561	7052	7554
9561	7052	6723
9561	7052	2492
9561	7052	5090
8786	7053	6467
8786	7053	7013
8786	7053	5798
8786	7053	5937
8786	7053	3489
13526	7054	4319
13526	7054	7321
13526	7054	2242
17928	7055	1609
17928	7055	8033
17928	7055	1379
17928	7055	5366
4758	7056	1087
4758	7056	4325
4758	7056	661
5515	7057	121
5515	7057	7635
5515	7057	8926
5515	7057	1326
5515	7057	3715
5515	7057	7809
18375	7058	7033
18375	7058	1095
18375	7058	6717
18375	7058	6609
18375	7058	6756
18375	7058	4943
18375	7058	26
18375	7058	3749
2766	7059	812
2766	7059	5473
2766	7059	6769
2766	7059	6274
2766	7059	2468
19001	7060	8353
19001	7060	2109
19001	7060	5090
19001	7060	2230
19001	7060	6957
19001	7060	1706
19001	7060	2402
19001	7060	2088
19001	7060	2080
15104	7061	833
15104	7061	5631
15104	7061	7040
15104	7061	2801
15104	7061	4392
13000	7062	5364
13000	7062	3540
13000	7062	599
13000	7062	3025
10224	7063	8011
10224	7063	2306
10224	7063	2166
10224	7063	9137
10224	7063	6439
18479	7064	393
18479	7064	3151
18479	7064	2473
18479	7064	4849
18479	7064	834
18479	7064	1257
7863	7065	8685
7863	7065	3011
7863	7065	2417
7863	7065	4129
7863	7065	2973
7863	7065	7730
16551	7066	7241
19426	7067	5725
19426	7067	6999
10891	7068	1802
10891	7068	4187
10891	7068	589
10891	7068	9988
10891	7068	8157
10891	7068	5284
10891	7068	8192
148	7069	5107
148	7069	1115
13678	7070	3821
9466	7071	4331
9466	7071	2602
9466	7071	9269
9466	7071	9636
9466	7071	5549
9466	7071	3312
9466	7071	9
9466	7071	3815
17842	7072	7575
17842	7072	6828
17842	7072	1375
17842	7072	1880
17842	7072	5381
17842	7072	5152
17842	7072	3024
17842	7072	4630
17842	7072	342
11781	7073	9631
11781	7073	502
11781	7073	4490
3555	7074	2609
3555	7074	548
3555	7074	6841
3555	7074	1346
3555	7074	2786
3555	7074	1933
3555	7074	4250
3555	7074	8101
3555	7074	828
22	7075	9204
7385	7076	5470
7385	7076	5861
7385	7076	6282
7385	7076	2062
7385	7076	8837
7385	7076	5344
14553	7077	3839
14553	7077	8745
14553	7077	3349
14553	7077	4677
7759	7078	7572
7759	7078	8814
7759	7078	6357
5278	7079	5762
5278	7079	6589
5278	7079	1542
17945	7080	4504
17945	7080	6885
3123	7081	5441
3123	7081	845
3123	7081	3859
3123	7081	6054
3123	7081	4333
3123	7081	2854
3123	7081	354
3123	7081	5336
13755	7082	5850
13755	7082	320
13755	7082	3470
13755	7082	8205
13755	7082	8766
13755	7082	36
13755	7082	7843
13755	7082	7219
6544	7083	445
6544	7083	287
6544	7083	3384
6544	7083	7740
6544	7083	2499
16697	7084	8701
16697	7084	8728
14988	7085	1701
17838	7086	2191
17838	7086	7131
17838	7086	3386
13539	7087	9873
13539	7087	2347
15201	7088	6323
15201	7088	9493
15201	7088	8821
1042	7089	9440
1042	7089	1954
1042	7089	6969
1042	7089	4266
1042	7089	6501
1042	7089	7125
1042	7089	8872
1042	7089	5078
1042	7089	8073
1342	7090	1998
1342	7090	2270
1342	7090	7694
1342	7090	1340
1342	7090	9933
3772	7091	970
3772	7091	5020
3772	7091	4374
3772	7091	7011
3772	7091	9141
14425	7092	7883
14425	7092	8424
14425	7092	3646
2678	7093	683
2678	7093	2817
10454	7094	1902
10454	7094	1193
10454	7094	208
10454	7094	9522
7971	7095	7268
7971	7095	3946
15183	7096	8930
15183	7096	7060
15183	7096	8183
15183	7096	7992
15183	7096	5104
14010	7097	3281
14010	7097	4052
14010	7097	8653
14010	7097	6787
14010	7097	5687
14010	7097	9655
7954	7098	8999
7954	7098	3446
7954	7098	5766
7954	7098	5935
7954	7098	2563
7954	7098	4792
7781	7099	3196
7781	7099	4124
1820	7100	4964
1820	7100	6781
1820	7100	691
1820	7100	838
1820	7100	158
1820	7100	5748
1820	7100	5912
16949	7101	5694
16949	7101	8363
16949	7101	2085
16949	7101	5881
16949	7101	3407
932	7102	7180
932	7102	6791
15256	7103	1911
15256	7103	1356
15256	7103	4990
15256	7103	6298
15256	7103	5508
7740	7104	5428
17668	7105	9300
17668	7105	5961
17668	7105	9736
17668	7105	4351
3823	7106	5219
3823	7106	113
3823	7106	2834
16682	7107	2211
16682	7107	6943
16682	7107	5784
16682	7107	6473
16682	7107	7585
16682	7107	8223
15916	7108	2969
15916	7108	8514
15916	7108	8965
15916	7108	5209
15916	7108	3941
15916	7108	5486
7771	7109	3037
7771	7109	6233
7771	7109	8893
7771	7109	8578
7771	7109	8477
7771	7109	22
7771	7109	4758
7771	7109	7332
11691	7110	9578
11691	7110	1033
13036	7111	404
6881	7112	2261
6881	7112	8300
6881	7112	4180
6881	7112	7638
6881	7112	7506
6881	7112	520
7023	7113	5468
7023	7113	7603
3980	7114	2760
3980	7114	2778
3980	7114	6862
3980	7114	7719
3980	7114	9291
3980	7114	9960
3980	7114	2796
3980	7114	7672
3980	7114	9994
230	7115	1373
230	7115	6082
230	7115	3671
230	7115	966
230	7115	9016
230	7115	111
13944	7116	6094
13944	7116	9586
13944	7116	6141
13944	7116	3652
7291	7117	3761
7291	7117	3641
7291	7117	876
7291	7117	4109
7291	7117	9582
7291	7117	1235
7291	7117	8799
7291	7117	389
7539	7118	6440
7539	7118	465
7539	7118	179
7539	7118	6394
16794	7119	2103
16794	7119	6655
1526	7120	5837
1526	7120	2218
1526	7120	105
1526	7120	9283
14992	7121	5295
14992	7121	5397
14992	7121	7414
10351	7122	6697
10351	7122	3333
10351	7122	5269
10351	7122	4114
10351	7122	995
10351	7122	1552
10351	7122	4586
10351	7122	5820
10351	7122	78
5820	7123	6208
5820	7123	2132
5820	7123	2199
5820	7123	8796
5820	7123	9479
5820	7123	4676
19887	7124	2736
19887	7124	2908
19887	7124	4391
420	7125	2405
420	7125	8931
420	7125	9383
420	7125	7824
420	7125	8759
420	7125	1980
2917	7126	4270
2917	7126	7026
2917	7126	4847
2917	7126	5632
2917	7126	4049
2917	7126	5246
2917	7126	232
5273	7127	53
5273	7127	82
5273	7127	228
5273	7127	7898
5273	7127	6394
18879	7128	1329
18879	7128	2388
18879	7128	4174
18879	7128	3929
18879	7128	8041
18879	7128	8214
18879	7128	5781
18879	7128	909
1922	7129	8837
1922	7129	8090
1922	7129	6259
1922	7129	7039
1922	7129	3922
1922	7129	7859
1922	7129	8838
1922	7129	1425
1922	7129	8265
12612	7130	4579
12612	7130	3671
12612	7130	5419
12612	7130	6449
12612	7130	2090
12612	7130	3293
12612	7130	2019
12612	7130	4662
12612	7130	9475
14666	7131	7579
14666	7131	5331
14666	7131	612
10277	7132	5446
10277	7132	2215
10277	7132	2519
10277	7132	106
10277	7132	3948
10277	7132	4787
10277	7132	2950
4849	7133	9758
4849	7133	825
4849	7133	7123
4849	7133	3180
4849	7133	2718
4849	7133	2873
4849	7133	2056
4849	7133	8405
1846	7134	5532
1846	7134	2687
1846	7134	2848
1846	7134	9767
1846	7134	8061
1846	7134	6376
1846	7134	9663
1846	7134	5154
1846	7134	3356
12146	7135	4799
12146	7135	5711
12146	7135	9988
12146	7135	4126
12146	7135	4180
12146	7135	9803
12146	7135	9975
19483	7136	7540
14404	7137	3987
14404	7137	1869
14404	7137	3525
14404	7137	5899
3218	7138	6501
3218	7138	4156
7916	7139	6608
7916	7139	5024
7916	7139	615
7916	7139	4025
7916	7139	9765
7503	7140	2258
7503	7140	9932
7503	7140	7421
7503	7140	9765
12532	7141	6947
12532	7141	527
12532	7141	5188
12532	7141	4545
12532	7141	4262
12532	7141	2774
5076	7142	6289
5076	7142	1091
5076	7142	1077
5076	7142	6703
5076	7142	2200
5076	7142	7444
5076	7142	2733
19359	7143	4174
19359	7143	8841
6204	7144	1388
15588	7145	9773
15588	7145	7490
15588	7145	6835
15588	7145	9347
15588	7145	660
15588	7145	3647
15588	7145	8830
15588	7145	3072
15588	7145	6535
10750	7146	8477
10750	7146	5367
10750	7146	7873
10750	7146	7658
10750	7146	6964
8905	7147	8645
8905	7147	4278
8905	7147	4415
8905	7147	2697
8905	7147	2752
18572	7148	4661
18572	7148	7176
5083	7149	562
5083	7149	9283
5083	7149	8089
5083	7149	1978
5083	7149	2933
5083	7149	3994
5083	7149	9926
5243	7150	8390
5243	7150	7172
5243	7150	7598
5243	7150	377
5243	7150	4969
5243	7150	7314
5243	7150	5880
5243	7150	8628
13432	7151	3084
13432	7151	7999
13432	7151	2995
13432	7151	5486
13432	7151	546
13432	7151	6015
13432	7151	2811
815	7152	5180
4987	7153	369
4987	7153	946
4987	7153	3298
4987	7153	3146
4987	7153	9582
4987	7153	3460
17890	7154	6084
17890	7154	8548
17890	7154	9906
17890	7154	9301
17890	7154	9597
17890	7154	4910
17890	7154	6974
17890	7154	5285
17890	7154	9446
5488	7155	9126
5488	7155	7401
5488	7155	2186
5488	7155	1530
5488	7155	6082
5488	7155	9611
19033	7156	4440
19033	7156	288
19033	7156	2609
19033	7156	2213
19033	7156	4605
19033	7156	4124
8300	7157	3759
8300	7157	6113
8300	7157	7842
8300	7157	8835
16890	7158	7961
16890	7158	7571
15716	7159	5120
15716	7159	5675
15716	7159	5620
15716	7159	7440
15716	7159	3948
15716	7159	3550
15716	7159	2784
15716	7159	3650
4967	7160	928
4967	7160	4323
4967	7160	5164
670	7161	8116
670	7161	7000
670	7161	4595
4067	7162	3445
4067	7162	5240
4067	7162	5851
4067	7162	6854
4067	7162	1373
4067	7162	5715
4067	7162	4502
19330	7163	10000
19330	7163	5517
19330	7163	6551
2290	7164	3179
2290	7164	3024
2290	7164	3963
2290	7164	2852
2290	7164	7153
17050	7165	826
17050	7165	8721
17050	7165	5274
17050	7165	4493
17050	7165	2331
17050	7165	3387
17050	7165	2524
17050	7165	26
6407	7166	9827
6407	7166	2068
6407	7166	9208
6407	7166	2383
6981	7167	9099
6981	7167	585
6981	7167	229
6981	7167	9645
6981	7167	5086
6981	7167	1440
6981	7167	8322
6981	7167	5266
1394	7168	91
1394	7168	7172
1394	7168	4195
1394	7168	1473
1394	7168	3045
4288	7169	6516
12321	7170	9192
12321	7170	8866
8263	7171	4828
8263	7171	6766
8263	7171	4496
17380	7172	630
17380	7172	8021
17380	7172	8680
17380	7172	2235
17380	7172	2070
17380	7172	1356
1095	7173	8061
1095	7173	2661
1095	7173	2780
1095	7173	4197
1095	7173	2407
1095	7173	3482
1095	7173	7381
1095	7173	2311
663	7174	262
663	7174	7386
17483	7175	9289
17483	7175	7985
17483	7175	2515
17483	7175	2025
17483	7175	8133
17483	7175	4839
17483	7175	4912
17483	7175	7162
17483	7175	5294
17608	7176	994
17608	7176	839
17608	7176	2398
17608	7176	7121
17608	7176	86
17608	7176	3503
17608	7176	3759
17608	7176	8715
17608	7176	1311
12297	7177	4469
12297	7177	9208
12297	7177	4022
12297	7177	8567
12297	7177	8964
12297	7177	3892
12297	7177	7939
10118	7178	1468
10452	7179	1009
10452	7179	4149
10452	7179	4764
10452	7179	9926
10452	7179	6085
10452	7179	8995
10452	7179	8643
15212	7180	7408
15212	7180	4112
15212	7180	117
15212	7180	8356
15212	7180	3186
15212	7180	6811
15212	7180	4244
15212	7180	9105
7735	7181	3100
4187	7182	9654
4187	7182	6137
4187	7182	7874
4187	7182	1832
4187	7182	1383
4187	7182	3883
4187	7182	3533
4187	7182	6681
1848	7183	9317
1848	7183	530
1848	7183	9747
1848	7183	5258
1848	7183	5722
1848	7183	8166
8604	7184	7846
8604	7184	1286
8604	7184	5927
8604	7184	8966
8604	7184	2237
8604	7184	9802
8604	7184	6571
8604	7184	6456
8604	7184	6955
13402	7185	6336
9002	7186	8803
9002	7186	2492
9002	7186	7836
7524	7187	3221
7524	7187	489
7524	7187	977
7524	7187	987
7524	7187	2945
16151	7188	8464
16151	7188	1365
16151	7188	5478
16151	7188	3420
16151	7188	6930
9531	7189	8527
9531	7189	1647
9531	7189	9817
9531	7189	4771
9531	7189	9193
9531	7189	8225
9531	7189	3698
16679	7190	9317
16679	7190	8904
16679	7190	2108
16679	7190	9074
16679	7190	8234
16679	7190	3803
16679	7190	6806
16679	7190	6556
12745	7191	7165
12745	7191	4606
12745	7191	1916
12745	7191	8031
12745	7191	6643
12745	7191	804
12745	7191	4736
12745	7191	753
19654	7192	9829
13270	7193	5087
13270	7193	1114
13270	7193	4939
13270	7193	5452
13270	7193	3668
3395	7194	7399
3395	7194	449
3395	7194	6
3395	7194	8978
3395	7194	1028
1713	7195	7491
5155	7196	8251
5155	7196	4617
5155	7196	7126
5155	7196	1069
5155	7196	9982
5155	7196	9462
19821	7197	1112
4279	7198	2996
4279	7198	5685
4279	7198	4444
4279	7198	3064
4279	7198	7249
3731	7199	150
3731	7199	6768
12459	7200	6140
12459	7200	8373
12459	7200	5516
12459	7200	9391
12459	7200	6474
12459	7200	6754
12459	7200	2873
11873	7201	7251
4533	7202	8350
4533	7202	2462
4533	7202	7747
7771	7203	1137
1053	7204	2912
1053	7204	780
1053	7204	9328
1053	7204	1721
1053	7204	4164
1053	7204	568
1053	7204	1237
1053	7204	8676
2275	7205	1110
2275	7205	8466
2275	7205	7961
2275	7205	619
2275	7205	129
6081	7206	8825
6081	7206	3357
6081	7206	7066
6081	7206	9516
6081	7206	3866
6081	7206	2951
6081	7206	339
6081	7206	3679
6081	7206	4366
5662	7207	2433
5662	7207	77
5662	7207	5509
5662	7207	5602
5662	7207	8317
5662	7207	5086
5662	7207	4971
5662	7207	9194
5662	7207	9784
5469	7208	2519
5469	7208	499
5469	7208	4067
5469	7208	9715
5469	7208	2474
5469	7208	475
11965	7209	1616
13402	7210	8852
13402	7210	4192
13402	7210	3601
13402	7210	1370
13402	7210	5006
13402	7210	8479
13402	7210	773
13402	7210	8010
13402	7210	9506
19959	7211	5962
19959	7211	7656
19959	7211	4064
19959	7211	4278
19959	7211	2098
19959	7211	5954
19959	7211	1766
6270	7212	7024
15593	7213	8284
15593	7213	4721
15593	7213	9262
15593	7213	8265
11839	7214	8311
11839	7214	1618
11839	7214	208
11839	7214	6698
11839	7214	7125
11839	7214	5108
4263	7215	9928
4263	7215	3608
4263	7215	2170
4263	7215	9131
4263	7215	6081
4263	7215	6654
4263	7215	3315
4263	7215	4430
4263	7215	6532
13479	7216	8712
13479	7216	1148
13479	7216	6622
13479	7216	5951
13479	7216	3660
13479	7216	2621
13479	7216	4090
13479	7216	5595
3352	7217	9899
3352	7217	2327
3352	7217	5555
15176	7218	6319
15176	7218	4738
15176	7218	8129
15176	7218	1757
10831	7219	2683
10831	7219	8502
10831	7219	7266
10831	7219	9954
19704	7220	4181
19704	7220	8780
19704	7220	4952
19704	7220	8551
19704	7220	8686
19704	7220	8737
19704	7220	4647
19704	7220	893
19704	7220	5908
17181	7221	6868
17181	7221	2673
17181	7221	40
17181	7221	6673
17181	7221	188
17181	7221	9213
17181	7221	5410
17181	7221	3344
4058	7222	8843
4058	7222	4662
4058	7222	7631
4058	7222	585
10958	7223	7638
10958	7223	2848
10958	7223	7972
10958	7223	9526
10958	7223	373
10958	7223	7126
938	7224	2498
938	7224	2504
938	7224	8880
938	7224	1077
938	7224	7735
938	7224	3592
938	7224	7140
938	7224	2921
11536	7225	5288
11536	7225	2461
11536	7225	719
11536	7225	1442
2365	7226	8170
2365	7226	3894
2365	7226	1622
18712	7227	6250
18712	7227	5776
18712	7227	8548
18712	7227	4938
18712	7227	6406
18712	7227	2983
18712	7227	5886
14653	7228	8509
14653	7228	1060
14653	7228	3731
14653	7228	3727
14653	7228	9924
14653	7228	4708
14653	7228	4439
14653	7228	325
17746	7229	9876
17746	7229	5291
17746	7229	7590
17746	7229	6559
17746	7229	8502
14021	7230	3688
14021	7230	561
14021	7230	2235
14021	7230	4702
14021	7230	7038
14021	7230	7899
16053	7231	3092
16053	7231	397
15972	7232	4028
15972	7232	9406
15972	7232	5070
15972	7232	4183
15972	7232	9441
3350	7233	8617
13031	7234	4542
13031	7234	1039
13031	7234	1972
13031	7234	6014
13031	7234	9420
13031	7234	6467
13031	7234	3630
13031	7234	2023
13031	7234	8431
15742	7235	9546
15742	7235	4501
15742	7235	8438
15742	7235	4677
18437	7236	6851
18437	7236	6352
18437	7236	6838
18437	7236	8436
18437	7236	9219
2482	7237	7446
2482	7237	5477
2482	7237	1848
2482	7237	4567
2482	7237	3185
2482	7237	863
2482	7237	1069
9990	7238	893
9990	7238	6795
9990	7238	1784
9990	7238	1034
419	7239	7816
419	7239	6281
419	7239	8081
419	7239	8315
419	7239	4478
419	7239	5653
419	7239	9360
419	7239	82
19484	7240	5754
19484	7240	338
19484	7240	2395
19380	7241	7750
8061	7242	2159
8061	7242	1197
8061	7242	2502
8061	7242	1975
8061	7242	3570
8061	7242	8301
8061	7242	1798
8061	7242	7894
16462	7243	9602
16462	7243	7919
16462	7243	4406
16462	7243	577
16462	7243	9699
16462	7243	3423
16462	7243	4267
16462	7243	8492
934	7244	2524
934	7244	323
934	7244	5600
934	7244	1873
934	7244	6446
12094	7245	7228
12094	7245	3248
12094	7245	9864
12094	7245	1068
12094	7245	4803
12094	7245	7906
12094	7245	2102
1461	7246	7661
1461	7246	606
1461	7246	2947
1461	7246	4693
1461	7246	9437
1461	7246	5440
5335	7247	471
5335	7247	8128
5335	7247	8163
5335	7247	6873
5335	7247	6224
19970	7248	6269
19970	7248	4582
19970	7248	624
19970	7248	9352
19970	7248	6921
19970	7248	9671
19970	7248	8810
19970	7248	5027
19970	7248	6786
9827	7249	7844
9827	7249	2927
9827	7249	2883
9827	7249	4052
9827	7249	8217
9827	7249	9951
9827	7249	7195
13091	7250	5334
13091	7250	9605
13091	7250	7167
13091	7250	7964
13091	7250	130
13091	7250	8866
13091	7250	3520
12892	7251	4813
12892	7251	6542
12892	7251	5149
12892	7251	5827
12304	7252	3397
12304	7252	8520
12304	7252	8364
12654	7253	2987
12654	7253	4928
12654	7253	5213
12654	7253	2952
12654	7253	9957
12654	7253	817
12654	7253	793
13238	7254	2771
12335	7255	9170
12335	7255	7222
13720	7256	5364
13720	7256	5598
13720	7256	5494
13720	7256	6565
13720	7256	6313
13720	7256	1949
13720	7256	3346
13720	7256	3724
13720	7256	4997
16025	7257	9548
13538	7258	3629
13538	7258	5239
13538	7258	2693
13538	7258	9569
13538	7258	9385
13538	7258	3637
11169	7259	524
11169	7259	8513
11169	7259	3021
11169	7259	3532
11169	7259	7622
11169	7259	7514
11169	7259	9848
6954	7260	2469
6954	7260	9884
6954	7260	226
6954	7260	8172
6954	7260	4965
6954	7260	9446
6954	7260	8547
6954	7260	4293
6954	7260	5489
18040	7261	2099
18040	7261	9704
7026	7262	2561
7026	7262	8042
7026	7262	9930
7026	7262	1712
7026	7262	2128
7026	7262	9789
16670	7263	5394
16670	7263	6049
16670	7263	6050
16670	7263	1853
16670	7263	9552
16670	7263	95
16670	7263	5069
16670	7263	2210
502	7264	8518
502	7264	1442
502	7264	8461
502	7264	2218
7519	7265	790
7519	7265	4771
7519	7265	6731
7519	7265	4987
7519	7265	8180
6496	7266	877
6496	7266	4949
6496	7266	7350
6496	7266	2733
6496	7266	4111
12658	7267	89
12658	7267	4545
12658	7267	3422
12658	7267	7717
12658	7267	5939
12658	7267	6434
12658	7267	7786
12658	7267	7366
12658	7267	3620
17138	7268	2035
17138	7268	8537
17138	7268	3116
17138	7268	2475
17138	7268	8144
17138	7268	2947
17138	7268	3441
17138	7268	2004
17138	7268	6521
5908	7269	1876
5908	7269	31
4850	7270	2170
4850	7270	8783
4850	7270	2245
4850	7270	9264
4850	7270	9110
4850	7270	7283
4850	7270	96
4198	7271	41
4198	7271	7899
4198	7271	7385
4198	7271	1529
4198	7271	5271
18670	7272	5434
18670	7272	2716
3958	7273	9386
3958	7273	7902
3958	7273	403
3958	7273	1580
3958	7273	1272
3958	7273	8021
10812	7274	2821
10812	7274	4448
10812	7274	3550
10812	7274	4670
10812	7274	5343
4158	7275	7925
4158	7275	8740
4158	7275	8231
4158	7275	2154
4158	7275	1424
4158	7275	1431
4158	7275	2595
4158	7275	4851
4158	7275	403
9700	7276	5354
9700	7276	8288
9700	7276	2386
9700	7276	2775
9700	7276	4010
9700	7276	498
9700	7276	6526
9700	7276	1892
9700	7276	8538
19935	7277	5120
19935	7277	6237
19935	7277	5282
19935	7277	372
19935	7277	1294
19163	7278	4532
19163	7278	4747
19163	7278	9895
12841	7279	5099
12841	7279	6499
12841	7279	2477
15192	7280	3118
15192	7280	126
15192	7280	7764
15192	7280	9215
15192	7280	1001
15192	7280	1374
15192	7280	4831
15192	7280	4074
10728	7281	8547
10728	7281	7846
10728	7281	3446
10728	7281	4304
10728	7281	7918
2072	7282	4526
2072	7282	5026
2072	7282	9463
2072	7282	9376
8413	7283	8931
8413	7283	996
8413	7283	3659
8413	7283	6320
8413	7283	4587
8413	7283	1826
19487	7284	779
19487	7284	2197
19487	7284	4473
19487	7284	9045
19487	7284	3249
19487	7284	4773
19487	7284	2626
19487	7284	439
2868	7285	976
2868	7285	5214
2868	7285	7717
2868	7285	4452
9028	7286	7900
9028	7286	2865
9028	7286	837
9028	7286	6309
9028	7286	329
9028	7286	8892
9028	7286	2811
5724	7287	6572
5724	7287	4096
5724	7287	7302
5724	7287	8824
5724	7287	4639
5724	7287	6267
8334	7288	6540
8334	7288	7941
8334	7288	4592
8334	7288	3930
8334	7288	1223
8334	7288	2815
7158	7289	5319
7158	7289	7958
7158	7289	7784
7158	7289	4374
7158	7289	2387
7158	7289	8480
16300	7290	8657
16300	7290	4196
16251	7291	4866
16251	7291	4750
16251	7291	3125
16251	7291	641
16251	7291	2599
16251	7291	1064
16251	7291	5381
16251	7291	2806
16251	7291	6077
1769	7292	2232
1769	7292	4429
1769	7292	1340
1769	7292	4553
1769	7292	1238
11975	7293	2614
10425	7294	5596
16802	7295	9686
16802	7295	2644
9749	7296	1302
9749	7296	1146
9749	7296	6622
9749	7296	5272
9749	7296	8371
9749	7296	4978
9749	7296	3683
9749	7296	6197
9749	7296	4406
176	7297	1847
176	7297	1174
11338	7298	4593
11338	7298	4759
11338	7298	6520
11338	7298	8121
11338	7298	5617
11338	7298	948
9260	7299	1437
9260	7299	5462
9260	7299	9248
9260	7299	8330
19006	7300	5172
19006	7300	737
19006	7300	5615
19006	7300	5502
19006	7300	6876
4985	7301	3087
4985	7301	9502
4985	7301	1259
4985	7301	7000
4985	7301	7685
12028	7302	5517
12028	7302	2433
12028	7302	7874
12028	7302	451
12028	7302	8665
12028	7302	5622
12028	7302	9575
12028	7302	8032
2235	7303	8958
2235	7303	4857
2235	7303	5254
2235	7303	2205
19091	7304	2471
19091	7304	4759
19091	7304	1134
19091	7304	3832
18907	7305	9000
6835	7306	7337
6835	7306	6231
6835	7306	9401
6835	7306	4734
6835	7306	9111
6835	7306	1151
6835	7306	7361
4238	7307	7329
4238	7307	3539
4238	7307	7251
4238	7307	9227
19300	7308	7348
19300	7308	174
19300	7308	9196
19300	7308	5063
19300	7308	1179
19300	7308	7219
19300	7308	8817
2846	7309	5164
2846	7309	7713
2846	7309	2517
2846	7309	7577
2846	7309	1213
2846	7309	1393
2846	7309	6550
2846	7309	7883
2846	7309	2320
14765	7310	1556
14765	7310	9805
14765	7310	2807
14765	7310	1795
14765	7310	5670
14765	7310	3530
14765	7310	5660
6472	7311	3057
6472	7311	436
6472	7311	7922
6472	7311	6329
6472	7311	5397
6472	7311	7623
6472	7311	101
6472	7311	4633
6472	7311	9551
2691	7312	8304
2691	7312	4711
6109	7313	2611
6109	7313	3488
6109	7313	9861
6109	7313	1365
13523	7314	3167
13523	7314	8451
13523	7314	8821
13523	7314	5237
13523	7314	9346
13523	7314	5810
13523	7314	2650
13523	7314	1611
13523	7314	3575
12371	7315	9232
12371	7315	8370
12371	7315	5114
12371	7315	7358
12371	7315	9290
12371	7315	2844
12371	7315	8323
7118	7316	5737
7118	7316	2734
7118	7316	2475
7118	7316	7555
7118	7316	3154
4436	7317	1143
4436	7317	2062
18839	7318	9944
18839	7318	3406
18839	7318	4692
18839	7318	1825
18839	7318	4232
18839	7318	2792
10533	7319	1315
10533	7319	4530
10533	7319	6682
10533	7319	5014
14152	7320	6495
14152	7320	919
14152	7320	7290
14152	7320	4704
14152	7320	3470
15403	7321	4667
15403	7321	877
15403	7321	3539
15403	7321	440
15403	7321	5740
15403	7321	588
18928	7322	4716
18928	7322	3288
18928	7322	763
18928	7322	9958
18928	7322	2559
18928	7322	1994
18928	7322	1130
18928	7322	988
18928	7322	6120
19317	7323	7727
19317	7323	9334
8558	7324	3304
8558	7324	2700
8558	7324	8128
8558	7324	7168
8558	7324	8928
8558	7324	1514
8558	7324	5104
8558	7324	7005
6249	7325	2783
1019	7326	8824
1019	7326	6035
18676	7327	5929
18676	7327	6885
18676	7327	5308
18676	7327	2823
15853	7328	4017
15853	7328	6863
15853	7328	8113
15853	7328	3979
11559	7329	8127
11559	7329	5579
11559	7329	7663
11559	7329	2274
11559	7329	1896
11559	7329	6688
11559	7329	4971
11559	7329	4025
11559	7329	7437
2907	7330	3424
2907	7330	1952
2907	7330	39
4658	7331	654
4658	7331	158
4862	7332	1589
4862	7332	436
4862	7332	8105
11082	7333	6994
11082	7333	6014
11082	7333	8843
11082	7333	7819
2000	7334	2308
2000	7334	7818
18308	7335	2386
18308	7335	682
17572	7336	4327
17572	7336	5015
2058	7337	8994
2058	7337	2294
2058	7337	556
2058	7337	221
16076	7338	7192
16076	7338	7635
16076	7338	6709
16076	7338	2399
16076	7338	7102
2856	7339	2749
2856	7339	7105
2856	7339	2891
2856	7339	4042
2856	7339	5164
2856	7339	8687
8108	7340	9601
8108	7340	3013
8108	7340	191
5180	7341	2270
5180	7341	4081
5180	7341	6612
7432	7342	9814
7432	7342	4731
7432	7342	9953
7432	7342	360
7432	7342	7472
7432	7342	202
7432	7342	4394
7432	7342	4308
7432	7342	2937
4822	7343	2947
4822	7343	6623
4822	7343	3418
4822	7343	3274
4822	7343	2827
4822	7343	87
4822	7343	8064
4822	7343	974
4822	7343	7452
15305	7344	867
15305	7344	1184
15305	7344	9682
15305	7344	6214
15305	7344	7801
15305	7344	8782
4398	7345	6931
4398	7345	5079
6286	7346	1567
6286	7346	7504
6286	7346	2158
6286	7346	370
6286	7346	2844
6286	7346	6828
6286	7346	9911
6286	7346	4717
6286	7346	2202
1840	7347	2912
1840	7347	365
1840	7347	9643
1840	7347	1134
1840	7347	7509
1840	7347	1203
1840	7347	6471
1840	7347	8032
1840	7347	6386
6426	7348	6254
6426	7348	6016
6426	7348	1616
6426	7348	9375
6426	7348	7987
6426	7348	9939
6426	7348	277
6426	7348	6802
8620	7349	9322
8620	7349	843
8620	7349	7421
8620	7349	8229
8620	7349	440
8620	7349	4118
8620	7349	9747
2725	7350	8675
2725	7350	6811
2725	7350	4621
2725	7350	8195
2725	7350	8497
5212	7351	3186
5212	7351	2406
5212	7351	24
5212	7351	6420
5212	7351	2263
4020	7352	3373
4020	7352	6831
4020	7352	5222
19686	7353	1265
19686	7353	3327
19686	7353	1831
19686	7353	2050
19686	7353	8078
19686	7353	5622
19686	7353	5089
19686	7353	8565
11445	7354	8029
11445	7354	2201
11445	7354	4780
10878	7355	4293
10878	7355	8454
10878	7355	5526
10878	7355	2900
10878	7355	5300
10878	7355	2031
10878	7355	9079
10878	7355	2963
10878	7355	4471
7665	7356	6566
7665	7356	6254
9508	7357	3983
9508	7357	4204
9508	7357	8695
9508	7357	2720
9508	7357	7305
9508	7357	2572
3300	7358	9293
3300	7358	7443
12462	7359	7219
12462	7359	2668
18903	7360	528
18903	7360	1477
18903	7360	5235
18903	7360	817
18903	7360	2215
18903	7360	1875
18903	7360	5038
18903	7360	3058
18903	7360	9253
8020	7361	5332
15999	7362	7451
15999	7362	5444
15999	7362	6386
15999	7362	7200
15999	7362	1117
15999	7362	4161
12070	7363	4363
12070	7363	772
12070	7363	8043
12070	7363	7626
12070	7363	8798
12070	7363	8723
16601	7364	9181
16601	7364	6385
16601	7364	8908
16601	7364	7188
16601	7364	1600
16601	7364	3355
16601	7364	7383
16601	7364	9445
431	7365	7975
431	7365	8201
431	7365	5944
431	7365	6914
6916	7366	5446
6916	7366	9970
6916	7366	5275
6916	7366	4377
15463	7367	5572
15463	7367	7632
15463	7367	9537
15463	7367	4382
15463	7367	5978
15463	7367	4283
2393	7368	4655
2393	7368	9132
2393	7368	5819
2393	7368	4453
2393	7368	6259
9526	7369	650
9526	7369	7164
9526	7369	3088
9526	7369	1274
9526	7369	4210
9526	7369	51
9526	7369	9173
9526	7369	9689
8686	7370	4443
8686	7370	2515
8686	7370	9033
8686	7370	7724
8569	7371	6417
8569	7371	2467
8569	7371	8705
8569	7371	6973
14048	7372	6580
1725	7373	4277
13583	7374	5565
13583	7374	4249
13583	7374	783
13583	7374	3286
13583	7374	1095
13583	7374	6703
13583	7374	9493
969	7375	648
969	7375	5212
969	7375	8141
969	7375	9083
14601	7376	4550
14601	7376	5800
14601	7376	3873
14601	7376	7888
14601	7376	3780
14601	7376	2912
14601	7376	8780
14601	7376	4158
14601	7376	2889
7072	7377	2341
2846	7378	8723
2846	7378	1299
14196	7379	3680
14919	7380	7942
4199	7381	6957
4199	7381	9445
4199	7381	5642
4199	7381	9369
4199	7381	3207
4199	7381	9109
814	7382	7505
2368	7383	8643
2368	7383	9509
2368	7383	3893
2368	7383	8684
2368	7383	8438
2368	7383	7926
2368	7383	4733
2368	7383	9666
2368	7383	679
19573	7384	193
15395	7385	8881
15395	7385	846
708	7386	2883
708	7386	7682
708	7386	8431
708	7386	9201
708	7386	9174
19705	7387	9639
19705	7387	3557
19705	7387	6547
19705	7387	7529
12820	7388	3934
12820	7388	7479
12820	7388	3598
12820	7388	832
12820	7388	1681
12820	7388	6886
12820	7388	2426
19379	7389	3117
19379	7389	8029
9150	7390	8400
9150	7390	9321
9150	7390	4401
3758	7391	2240
3758	7391	633
3758	7391	1389
3758	7391	4801
3758	7391	3578
3758	7391	3503
3758	7391	6036
3758	7391	5040
3758	7391	3293
8580	7392	1566
8580	7392	3775
8580	7392	5906
8580	7392	7845
8580	7392	8886
8580	7392	9326
8580	7392	4004
17609	7393	3353
18777	7394	3452
18777	7394	5562
18777	7394	2231
18777	7394	9129
18777	7394	1545
14900	7395	4649
14900	7395	7691
14900	7395	838
14900	7395	4688
14900	7395	499
14900	7395	8487
14900	7395	7245
3786	7396	9834
3786	7396	8782
3786	7396	8186
3786	7396	5862
3786	7396	813
3786	7396	7180
3786	7396	3231
1844	7397	2616
1844	7397	3277
1844	7397	9706
1844	7397	6967
1844	7397	353
8165	7398	3375
8165	7398	741
8165	7398	3591
8165	7398	1291
8165	7398	2225
8165	7398	7650
8165	7398	300
8165	7398	6378
17987	7399	2108
18148	7400	9280
18148	7400	7092
18148	7400	765
3010	7401	8107
3010	7401	9851
3010	7401	1787
3010	7401	5787
3010	7401	9715
14666	7402	8228
14666	7402	1079
14666	7402	2339
14666	7402	3894
14666	7402	6414
14356	7403	8683
14356	7403	5102
14356	7403	6796
14356	7403	7121
14356	7403	2452
14356	7403	668
14356	7403	5071
14356	7403	9499
14356	7403	3637
9429	7404	9040
9429	7404	3449
2490	7405	899
2490	7405	8420
2490	7405	8102
2490	7405	951
2490	7405	3797
8930	7406	3321
8930	7406	9428
8930	7406	2793
2805	7407	3907
14792	7408	2338
14792	7408	106
14792	7408	2342
14792	7408	5972
14792	7408	3430
14792	7408	6695
14792	7408	4234
14792	7408	4758
8370	7409	3105
7712	7410	8056
7712	7410	2827
7712	7410	1850
7712	7410	9843
7712	7410	5921
3786	7411	1662
3786	7411	5151
3786	7411	4435
3786	7411	3449
15920	7412	4143
15920	7412	1053
15920	7412	8842
15920	7412	4092
15920	7412	2609
15920	7412	6832
15920	7412	7897
16119	7413	1652
13603	7414	6709
13603	7414	8480
13603	7414	3610
13603	7414	7998
13603	7414	3776
13603	7414	8788
13603	7414	8159
1534	7415	3218
1534	7415	3870
17031	7416	4822
17031	7416	3228
17031	7416	6960
17031	7416	2673
17031	7416	737
17031	7416	5805
19162	7417	2199
19162	7417	5701
19162	7417	6711
19857	7418	7780
19857	7418	9987
9616	7419	1831
9616	7419	5599
9616	7419	8386
9616	7419	786
9616	7419	5070
9616	7419	3772
11940	7420	2454
11940	7420	7862
11940	7420	5438
11940	7420	1526
3023	7421	6320
3023	7421	3205
3023	7421	7892
3023	7421	2654
3023	7421	5138
3023	7421	468
3023	7421	8260
11804	7422	9244
11804	7422	7369
5613	7423	6024
5613	7423	5753
5613	7423	8851
5613	7423	9930
15642	7424	4099
15642	7424	6315
15642	7424	6203
18528	7425	1124
18528	7425	1675
18528	7425	6825
18528	7425	1299
18528	7425	8632
18528	7425	4336
18528	7425	2306
18528	7425	6456
18528	7425	5242
12199	7426	2095
12199	7426	8720
12199	7426	441
12199	7426	7561
17369	7427	7176
17369	7427	2602
17369	7427	488
17369	7427	5797
17369	7427	5617
17369	7427	8009
17369	7427	337
17369	7427	8749
16602	7428	4168
16602	7428	9743
14607	7429	5988
14607	7429	5539
14607	7429	3622
14607	7429	1638
14607	7429	9374
14607	7429	8932
14607	7429	5536
11744	7430	6264
11744	7430	4113
11744	7430	985
11744	7430	4076
11744	7430	2888
11744	7430	8031
8035	7431	7181
8035	7431	5873
8035	7431	2303
8035	7431	6251
8035	7431	238
8035	7431	8175
8035	7431	7658
7844	7432	4732
7844	7432	5505
7844	7432	9618
7844	7432	3674
7844	7432	6805
7844	7432	1665
7844	7432	3600
18944	7433	4719
18944	7433	3109
2567	7434	9649
2567	7434	7279
2567	7434	2594
2567	7434	6444
12123	7435	3709
12123	7435	360
12123	7435	4674
12123	7435	4218
12123	7435	3431
16299	7436	3106
16299	7436	511
16299	7436	4850
16299	7436	732
16299	7436	7713
16299	7436	4139
16299	7436	1424
16299	7436	218
16299	7436	9450
19618	7437	3768
19618	7437	128
19618	7437	5398
19618	7437	5347
19618	7437	5474
19618	7437	2684
15065	7438	9661
15065	7438	7870
15065	7438	8012
15065	7438	8756
15065	7438	7208
16836	7439	4301
16836	7439	4973
741	7440	1562
741	7440	2778
741	7440	2133
741	7440	1777
2875	7441	5236
2875	7441	8301
2875	7441	8373
2875	7441	2198
2875	7441	3926
2875	7441	1984
2875	7441	1993
2875	7441	2654
2875	7441	7327
17776	7442	3133
17776	7442	4667
17776	7442	9885
17776	7442	6347
17776	7442	4810
17776	7442	2160
17776	7442	5574
17776	7442	8618
5086	7443	770
5086	7443	10000
5086	7443	947
12487	7444	4319
12487	7444	7837
12487	7444	4256
12487	7444	4788
12487	7444	9738
12487	7444	2184
15515	7445	5529
15515	7445	3867
9272	7446	8059
9272	7446	3859
9272	7446	676
9272	7446	1038
9272	7446	9420
9272	7446	3978
17531	7447	8362
17531	7447	8231
17531	7447	4218
17531	7447	2393
17531	7447	4147
17531	7447	3257
13485	7448	1175
13485	7448	3765
13485	7448	1141
13485	7448	6843
13485	7448	3677
13485	7448	4235
13485	7448	9586
13485	7448	6607
13485	7448	4972
18378	7449	8935
18378	7449	7668
17125	7450	7517
17125	7450	8598
17125	7450	1958
17125	7450	6083
17125	7450	299
17125	7450	9621
17125	7450	33
13279	7451	1477
13279	7451	7205
13279	7451	7579
13279	7451	6614
13279	7451	8330
13279	7451	3808
13279	7451	4464
13279	7451	7372
18658	7452	8129
18658	7452	8447
18658	7452	7632
18658	7452	6956
18658	7452	5118
18658	7452	8691
18658	7452	280
18658	7452	3566
359	7453	7114
3154	7454	4639
3154	7454	4327
3154	7454	9526
3154	7454	537
3154	7454	205
14320	7455	1269
14320	7455	8162
3454	7456	1907
3454	7456	5825
3454	7456	9419
3454	7456	597
3454	7456	8449
5551	7457	5231
5551	7457	5989
5551	7457	1377
5551	7457	2595
5551	7457	4007
5551	7457	7753
5551	7457	5412
5551	7457	3895
11601	7458	4820
11601	7458	5917
11601	7458	4395
5773	7459	904
5773	7459	6533
5773	7459	7806
801	7460	4264
801	7460	5505
801	7460	7061
801	7460	4491
3629	7461	8557
5903	7462	5838
5903	7462	9409
5903	7462	5962
5903	7462	3633
5903	7462	3850
5903	7462	4168
16863	7463	8106
16863	7463	1203
12803	7464	6420
12803	7464	6873
12803	7464	5919
12803	7464	7940
12803	7464	6912
5748	7465	6642
5748	7465	5092
2783	7466	3196
2783	7466	1894
2783	7466	9942
2783	7466	800
2783	7466	5302
2783	7466	7320
2783	7466	9074
14027	7467	4361
14027	7467	5281
14027	7467	5619
1421	7468	2102
1421	7468	880
1421	7468	9317
1421	7468	9696
989	7469	7714
989	7469	761
989	7469	4168
989	7469	3801
989	7469	8663
989	7469	2651
989	7469	5812
989	7469	5865
17191	7470	567
19767	7471	9142
19767	7471	6568
19767	7471	29
19767	7471	3682
19767	7471	1070
19767	7471	7045
11414	7472	9650
11414	7472	7929
11414	7472	9442
11414	7472	4110
11414	7472	7990
11414	7472	9330
11414	7472	4560
11414	7472	442
11414	7472	8926
17908	7473	9743
13574	7474	2494
13574	7474	4653
13574	7474	9104
13574	7474	7657
13574	7474	9490
14959	7475	1848
14959	7475	9306
16463	7476	7186
16463	7476	1291
18547	7477	4267
17838	7478	1501
17838	7478	8090
17838	7478	7774
17838	7478	8469
17838	7478	2402
17838	7478	5217
17838	7478	2605
17838	7478	9939
17838	7478	1075
4729	7479	1638
4729	7479	5623
4729	7479	3976
4729	7479	4823
4729	7479	5609
7396	7480	4279
7396	7480	324
7396	7480	6098
7396	7480	8389
7396	7480	5460
7396	7480	606
6196	7481	8541
6196	7481	7272
6196	7481	6441
6196	7481	228
6196	7481	3573
6196	7481	7587
6196	7481	9534
6196	7481	8015
6196	7481	681
13555	7482	5480
13555	7482	7210
13555	7482	5870
13555	7482	9183
13555	7482	2165
13555	7482	5304
13555	7482	1887
13555	7482	683
8511	7483	6162
8352	7484	2513
8352	7484	2950
8352	7484	673
8352	7484	5727
8352	7484	4514
8352	7484	543
5414	7485	2143
5414	7485	3413
12839	7486	7013
12839	7486	854
12839	7486	7418
12839	7486	8678
3255	7487	57
3255	7487	2495
3255	7487	3644
3255	7487	8265
3255	7487	5744
15773	7488	711
15773	7488	1507
15773	7488	1777
15773	7488	1033
15773	7488	1025
19404	7489	1330
19404	7489	3335
19404	7489	6747
19404	7489	5955
19404	7489	8867
19404	7489	398
19404	7489	3902
19404	7489	2497
6415	7490	998
6415	7490	7185
6415	7490	9703
6415	7490	480
6415	7490	7911
6415	7490	3205
6415	7490	3560
6415	7490	626
13161	7491	800
13161	7491	5844
16680	7492	1548
5090	7493	4576
5090	7493	4384
5090	7493	8144
5090	7493	3914
5090	7493	1535
5090	7493	7887
509	7494	1489
509	7494	9570
509	7494	4241
509	7494	5672
509	7494	3060
509	7494	2718
509	7494	9764
509	7494	8225
5216	7495	4903
5216	7495	9829
5216	7495	781
5216	7495	8598
5216	7495	7970
5216	7495	7037
5216	7495	6878
5216	7495	6790
4922	7496	9680
4922	7496	4449
4922	7496	6343
13359	7497	5160
13359	7497	6482
13359	7497	6621
10436	7498	2556
18865	7499	551
18865	7499	9381
18865	7499	1205
18865	7499	7167
18865	7499	8503
18865	7499	8326
18865	7499	188
10695	7500	336
10695	7500	9203
10050	7501	7884
10050	7501	7616
10050	7501	763
10050	7501	6154
10050	7501	5666
10050	7501	9203
10050	7501	3012
10050	7501	6340
13055	7502	1875
13055	7502	7388
13055	7502	9144
13055	7502	5251
13055	7502	1615
18996	7503	6847
6000	7504	358
6000	7504	7232
6000	7504	621
6000	7504	4706
19299	7505	8383
19299	7505	4184
18869	7506	8398
18869	7506	1145
15983	7507	991
15983	7507	8953
15983	7507	1401
15983	7507	4718
15983	7507	9755
19706	7508	1827
19706	7508	2130
19706	7508	4982
19706	7508	5445
19706	7508	3809
19706	7508	2529
19706	7508	5045
19706	7508	2944
7870	7509	5284
7870	7509	8037
15582	7510	7644
15582	7510	3039
15582	7510	5954
15582	7510	5480
1848	7511	4766
1848	7511	6091
18069	7512	2970
18069	7512	3843
3758	7513	9670
3758	7513	3710
3758	7513	6177
3758	7513	6783
3758	7513	1917
3758	7513	3064
3758	7513	3187
3758	7513	384
3758	7513	2019
2217	7514	3098
2217	7514	5321
2217	7514	6731
2217	7514	8820
2217	7514	2312
2217	7514	2664
2217	7514	5802
5169	7515	4847
5169	7515	3932
5169	7515	5309
5169	7515	5985
5169	7515	789
12595	7516	4775
12595	7516	8475
14587	7517	5782
14587	7517	7746
1030	7518	5201
1030	7518	2993
1030	7518	7047
1030	7518	3448
1030	7518	5629
1030	7518	6779
1030	7518	534
1030	7518	5599
1030	7518	4373
7571	7519	5510
7571	7519	2458
7571	7519	8731
5795	7520	1911
5795	7520	8102
5795	7520	703
5795	7520	1989
5795	7520	5785
5795	7520	396
5795	7520	6682
5795	7520	1627
5795	7520	67
2863	7521	8579
14618	7522	206
14618	7522	6342
14618	7522	6463
14618	7522	1075
14618	7522	5992
14618	7522	3498
14618	7522	1830
17023	7523	9566
17023	7523	8163
17023	7523	1385
17023	7523	4756
17023	7523	4110
17023	7523	7272
17023	7523	5731
17023	7523	2821
17023	7523	9595
1337	7524	3732
1337	7524	4284
1337	7524	3839
7452	7525	3679
7452	7525	8044
7452	7525	171
7452	7525	5026
4594	7526	9775
4594	7526	8960
4594	7526	5144
4594	7526	37
4594	7526	7983
4594	7526	1540
4594	7526	9329
6802	7527	7039
6802	7527	7009
6802	7527	7845
6802	7527	7881
6802	7527	1459
6802	7527	5168
6802	7527	5926
9771	7528	361
9771	7528	7097
9771	7528	8115
9771	7528	608
9771	7528	4014
6234	7529	5900
6234	7529	2965
6234	7529	6186
6234	7529	6615
6234	7529	9884
6234	7529	2144
6234	7529	6724
6234	7529	695
2109	7530	9397
2109	7530	3738
2109	7530	939
2109	7530	5257
2109	7530	868
13533	7531	511
13533	7531	3476
13533	7531	92
4469	7532	4737
4469	7532	6664
4469	7532	917
4469	7532	7845
4469	7532	5539
4469	7532	318
11148	7533	2829
18180	7534	1537
18180	7534	4601
18180	7534	7391
18180	7534	3862
18180	7534	9138
18180	7534	6421
18180	7534	1341
18370	7535	767
18370	7535	9860
18370	7535	3541
18370	7535	297
14525	7536	4738
14525	7536	632
14525	7536	8622
14525	7536	2846
14525	7536	4582
14525	7536	1082
4844	7537	1607
4844	7537	9009
4844	7537	3956
4844	7537	2471
4844	7537	6987
4844	7537	3865
18648	7538	6319
18648	7538	4106
18648	7538	8286
18648	7538	7424
18648	7538	8934
13434	7539	2344
13434	7539	8196
4303	7540	9647
4303	7540	142
4303	7540	239
4303	7540	2836
4303	7540	4938
4303	7540	134
4303	7540	4094
3034	7541	22
3034	7541	1645
3034	7541	7363
3034	7541	3479
3034	7541	5341
11121	7542	2768
11121	7542	868
11121	7542	6071
11121	7542	2877
11121	7542	2857
11121	7542	51
11121	7542	1431
5434	7543	7872
5434	7543	9435
5434	7543	6604
5434	7543	793
5434	7543	1298
5434	7543	7505
5434	7543	5858
5434	7543	2955
18051	7544	33
18051	7544	9167
18051	7544	236
18051	7544	6128
18051	7544	3314
18051	7544	7191
13251	7545	9540
13251	7545	8263
13251	7545	5715
13251	7545	7892
13251	7545	6040
13251	7545	8299
17454	7546	2013
17454	7546	9988
17454	7546	5238
17454	7546	951
17454	7546	3215
17454	7546	9738
17454	7546	4767
17454	7546	9249
17454	7546	3371
18170	7547	658
18170	7547	3879
18170	7547	8637
8221	7548	8751
8221	7548	1943
8221	7548	9756
8221	7548	2540
8221	7548	1034
8221	7548	5899
8221	7548	8434
8221	7548	105
8221	7548	2659
11875	7549	5256
11875	7549	502
16369	7550	7880
16369	7550	3201
16369	7550	741
16369	7550	2714
16369	7550	5926
16369	7550	5557
16369	7550	9547
16369	7550	6972
16369	7550	5795
13367	7551	8230
13367	7551	5331
13367	7551	4715
5432	7552	9469
5432	7552	4617
5432	7552	6952
5432	7552	3489
5432	7552	1078
1248	7553	275
1248	7553	1305
13744	7554	7695
13744	7554	2475
13744	7554	4911
13744	7554	5125
9185	7555	4802
9185	7555	6132
9185	7555	9531
9185	7555	7336
9185	7555	7834
9185	7555	5907
9185	7555	9203
9185	7555	3278
3244	7556	5297
3244	7556	4185
18618	7557	3902
18618	7557	3311
18618	7557	2268
18618	7557	6994
18618	7557	6652
8970	7558	2592
8970	7558	9148
6459	7559	5006
6459	7559	8011
6459	7559	2994
6459	7559	8500
6459	7559	2843
6459	7559	4520
6459	7559	1103
16192	7560	2425
16192	7560	6732
16192	7560	6552
11397	7561	8928
11397	7561	6724
11397	7561	5472
11397	7561	3124
11397	7561	3068
11397	7561	7372
11397	7561	4024
11397	7561	2064
11397	7561	8679
14526	7562	1878
14526	7562	2773
14526	7562	5961
14526	7562	4127
14526	7562	3447
14526	7562	3838
18619	7563	7775
10293	7564	7038
10293	7564	885
10293	7564	3603
10293	7564	2979
10293	7564	9754
10293	7564	146
12213	7565	7261
12213	7565	464
12213	7565	9943
12213	7565	408
12213	7565	7564
12213	7565	2816
12213	7565	3328
731	7566	6081
731	7566	48
731	7566	9752
731	7566	3914
731	7566	2327
731	7566	6004
6528	7567	4362
6528	7567	2523
6528	7567	3214
6528	7567	2951
6528	7567	9384
8879	7568	380
8879	7568	1610
8879	7568	1784
8879	7568	228
8879	7568	1259
14525	7569	526
14525	7569	2573
14525	7569	8001
14525	7569	9657
14525	7569	5180
14525	7569	7245
14525	7569	8886
11059	7570	8254
11059	7570	9809
11059	7570	8308
11059	7570	5735
11059	7570	2591
11059	7570	6829
11059	7570	6132
11059	7570	3431
11059	7570	2242
3795	7571	4505
3795	7571	3542
3795	7571	9861
3795	7571	8919
3795	7571	1926
3795	7571	2144
3795	7571	7210
3795	7571	1771
3795	7571	18
13692	7572	4200
13692	7572	6409
13692	7572	3020
13692	7572	8339
13692	7572	9186
13692	7572	5556
13692	7572	6232
10301	7573	2323
10301	7573	8931
10301	7573	3208
10301	7573	2477
10301	7573	5063
10301	7573	71
10301	7573	1757
16332	7574	8373
16332	7574	3496
16332	7574	1892
16332	7574	285
16332	7574	4467
16332	7574	3273
16332	7574	2750
16332	7574	7835
2085	7575	4267
2085	7575	1656
2085	7575	666
2085	7575	8607
2085	7575	1579
2085	7575	3307
2085	7575	8367
516	7576	8381
516	7576	3347
516	7576	5399
516	7576	7249
516	7576	7777
516	7576	4276
516	7576	9982
516	7576	7603
16537	7577	3744
16537	7577	805
18341	7578	9429
18341	7578	1879
18341	7578	25
18341	7578	9462
13422	7579	9088
13422	7579	9256
13422	7579	1477
13422	7579	706
13422	7579	5127
13422	7579	5843
13422	7579	2383
13422	7579	5921
13422	7579	5818
10491	7580	3054
10491	7580	151
10491	7580	4927
10491	7580	9227
10491	7580	569
19650	7581	6683
19650	7581	2350
19650	7581	3844
19650	7581	680
19650	7581	4839
19650	7581	5187
19650	7581	6373
19650	7581	5902
17910	7582	1471
17910	7582	4782
17910	7582	3864
762	7583	8374
762	7583	4482
762	7583	3668
762	7583	8915
762	7583	4551
762	7583	947
14639	7584	3170
17046	7585	8803
5332	7586	3047
2841	7587	2144
2841	7587	9646
8394	7588	3935
3812	7589	3037
14956	7590	6701
14956	7590	1049
14956	7590	1412
14956	7590	1023
14956	7590	5516
14956	7590	9572
14956	7590	7905
14956	7590	8717
7057	7591	2750
7057	7591	9255
7057	7591	7040
7057	7591	1077
7057	7591	9769
7057	7591	5004
7057	7591	1576
5974	7592	1238
5974	7592	1397
5974	7592	3321
5974	7592	28
5974	7592	6827
5974	7592	5566
5974	7592	791
5974	7592	904
15887	7593	4564
15887	7593	2281
7713	7594	6844
7713	7594	5085
7713	7594	1428
7713	7594	8891
7713	7594	5783
7713	7594	6787
4705	7595	668
4705	7595	3194
4705	7595	6378
1882	7596	508
1882	7596	9072
1882	7596	2527
1882	7596	1891
1882	7596	3996
5772	7597	1804
5772	7597	2485
5772	7597	7206
5772	7597	7312
5772	7597	8450
5772	7597	9136
5772	7597	6036
5772	7597	5768
5772	7597	7285
12713	7598	2272
12713	7598	18
12713	7598	7610
11353	7599	530
15471	7600	5609
15471	7600	2936
15471	7600	9762
11059	7601	1804
11059	7601	455
11059	7601	4926
11059	7601	8495
12208	7602	1780
12208	7602	9102
12208	7602	9508
12208	7602	45
12208	7602	6651
12208	7602	929
12208	7602	396
12208	7602	8558
2398	7603	3719
2398	7603	2228
2398	7603	4489
2398	7603	3587
2398	7603	6827
2398	7603	1627
2398	7603	5676
2398	7603	916
1920	7604	6613
1920	7604	1185
19485	7605	941
19485	7605	7039
19485	7605	7288
19485	7605	3304
19485	7605	9988
19485	7605	5257
19485	7605	9528
19485	7605	5420
19485	7605	7611
5117	7606	4157
5117	7606	3670
12931	7607	5480
12931	7607	659
12931	7607	684
12931	7607	1785
12931	7607	9722
9957	7608	1862
18944	7609	2030
18944	7609	7558
18944	7609	1544
18944	7609	1528
18944	7609	7693
18944	7609	7593
16502	7610	6197
16502	7610	7303
16502	7610	9247
15666	7611	1839
15666	7611	2230
15666	7611	181
15477	7612	8966
15477	7612	3819
2823	7613	9663
2823	7613	4533
3671	7614	14
3671	7614	75
3671	7614	5433
15326	7615	1922
15326	7615	701
15326	7615	5268
18174	7616	499
18174	7616	4139
18174	7616	1675
9341	7617	6913
9341	7617	473
9341	7617	9115
9341	7617	8900
9341	7617	3569
9341	7617	4858
9341	7617	6901
9341	7617	7858
4396	7618	5121
4396	7618	7704
18757	7619	4049
18757	7619	5732
18757	7619	8957
18757	7619	7948
18757	7619	2110
18757	7619	9967
18757	7619	9840
18757	7619	1169
18052	7620	1224
18052	7620	7157
18052	7620	1918
18052	7620	5603
18052	7620	4238
18052	7620	1766
14994	7621	3701
11622	7622	1489
11622	7622	3788
11622	7622	622
11622	7622	1684
11622	7622	9779
11622	7622	9695
11622	7622	9251
11622	7622	1795
11622	7622	5444
14417	7623	4706
16812	7624	4217
11412	7625	8364
11412	7625	7199
11412	7625	8834
17056	7626	140
17056	7626	7058
10889	7627	5800
10889	7627	9624
10889	7627	5903
10889	7627	7359
10889	7627	5185
10889	7627	5825
8376	7628	4235
8376	7628	3801
8376	7628	531
8376	7628	9393
8376	7628	3419
8376	7628	6254
8376	7628	1895
15388	7629	4775
4266	7630	8732
4266	7630	273
4266	7630	2576
4266	7630	5181
4266	7630	5445
4266	7630	3998
6780	7631	9841
3469	7632	9429
3469	7632	7326
3469	7632	928
3469	7632	6336
3469	7632	4955
3469	7632	1879
8909	7633	1265
8909	7633	7587
8909	7633	89
8909	7633	8653
8909	7633	4392
8909	7633	9631
8909	7633	227
8909	7633	6148
6945	7634	2021
13950	7635	2203
13950	7635	807
13950	7635	7289
13950	7635	4986
13950	7635	7334
13950	7635	9155
7092	7636	3208
7092	7636	3008
6128	7637	4047
6128	7637	8411
6128	7637	1822
6128	7637	4873
6128	7637	2355
6128	7637	4896
6128	7637	7751
6128	7637	4519
7345	7638	7219
7345	7638	8195
7345	7638	252
7345	7638	9780
7345	7638	4267
7345	7638	2828
7345	7638	7453
18547	7639	3297
18547	7639	7386
10271	7640	219
10271	7640	5099
4633	7641	2742
4633	7641	9183
4633	7641	1696
4633	7641	5127
4633	7641	1763
4633	7641	5763
4633	7641	1853
4633	7641	303
15376	7642	2824
15376	7642	6271
15376	7642	4440
15376	7642	4330
15376	7642	3686
12855	7643	8949
12855	7643	4837
13198	7644	5196
10996	7645	3186
10996	7645	3684
10996	7645	8409
10996	7645	9051
10996	7645	1324
10996	7645	7072
10996	7645	4545
10996	7645	1436
768	7646	4459
768	7646	2099
768	7646	7438
768	7646	9618
768	7646	2791
11953	7647	1986
2073	7648	4417
2073	7648	7148
17168	7649	8968
17168	7649	4034
17168	7649	1700
17168	7649	4538
17168	7649	3426
17168	7649	7477
17168	7649	7427
17168	7649	2193
8356	7650	5215
8356	7650	8474
8356	7650	6489
8356	7650	8593
8356	7650	4205
8356	7650	2895
13858	7651	3061
13858	7651	5676
13858	7651	5291
13858	7651	2702
13858	7651	7808
13858	7651	411
13561	7652	4674
13561	7652	3917
13561	7652	3754
13561	7652	5523
16834	7653	5346
16834	7653	4233
16834	7653	8863
16834	7653	4892
16834	7653	3060
16834	7653	6871
16834	7653	2487
3117	7654	5844
3117	7654	1985
3117	7654	9898
3117	7654	2270
10250	7655	2819
10250	7655	2554
10250	7655	7588
10250	7655	6959
10250	7655	5570
4881	7656	9722
4881	7656	4117
4881	7656	8931
1831	7657	6654
1831	7657	7835
1831	7657	7116
19869	7658	6986
19869	7658	9146
19869	7658	920
19869	7658	3964
19869	7658	7156
19869	7658	3551
19869	7658	9928
17716	7659	9773
17716	7659	5593
17716	7659	9339
12908	7660	6389
12908	7660	9682
17655	7661	3543
17655	7661	6304
17655	7661	6131
17655	7661	7576
17655	7661	7521
10296	7662	2497
10296	7662	1115
10296	7662	434
10296	7662	8289
10296	7662	9843
19049	7663	8352
19049	7663	1187
19049	7663	6652
19049	7663	2594
19049	7663	7344
19049	7663	8839
7508	7664	8442
7508	7664	6823
7508	7664	4344
7508	7664	7447
7508	7664	2788
7508	7664	7309
7508	7664	6814
7508	7664	146
7508	7664	730
14761	7665	162
14761	7665	9822
14761	7665	1030
14761	7665	2755
14761	7665	8043
14761	7665	3551
14761	7665	753
14761	7665	2121
14761	7665	526
15669	7666	3195
15669	7666	7469
15669	7666	655
18952	7667	5641
18952	7667	467
6442	7668	4417
10338	7669	3368
10338	7669	2165
10338	7669	7516
10338	7669	1159
10338	7669	666
10338	7669	4634
10338	7669	3155
14673	7670	1340
14673	7670	3108
14673	7670	1091
14673	7670	3840
14673	7670	2084
14673	7670	676
8087	7671	2900
8087	7671	9739
8087	7671	9148
8087	7671	2685
8087	7671	1726
8087	7671	9719
8087	7671	3176
8087	7671	8960
4135	7672	2888
4135	7672	1590
4135	7672	898
4135	7672	6210
4135	7672	6310
4135	7672	5525
10528	7673	5669
10528	7673	8496
10528	7673	1790
10528	7673	9916
10528	7673	5336
656	7674	6411
656	7674	9484
656	7674	8799
656	7674	266
656	7674	7510
656	7674	2140
656	7674	5784
18100	7675	5001
18100	7675	1361
18100	7675	9131
18100	7675	1756
2469	7676	8797
16560	7677	8661
16560	7677	8727
16560	7677	6045
16560	7677	9206
15008	7678	1471
5662	7679	4107
8511	7680	5347
531	7681	3984
5419	7682	3575
5419	7682	8050
5419	7682	4275
5419	7682	3141
5419	7682	4807
5419	7682	8577
5365	7683	6938
5365	7683	1897
6800	7684	4107
6800	7684	6141
6800	7684	9242
6800	7684	505
6800	7684	477
9504	7685	498
9504	7685	3154
9504	7685	9764
9504	7685	1756
9504	7685	841
9504	7685	9221
9504	7685	978
9504	7685	6137
487	7686	4527
487	7686	5825
12603	7687	1053
12603	7687	5184
12603	7687	3357
12603	7687	624
12603	7687	7581
12603	7687	4784
12603	7687	1073
4101	7688	5578
4101	7688	7537
4101	7688	3334
4101	7688	4937
4101	7688	7096
4101	7688	5459
4101	7688	4134
18633	7689	7653
18633	7689	8228
18633	7689	1063
18633	7689	3655
18633	7689	7016
4505	7690	3467
4505	7690	5400
4505	7690	1706
4505	7690	5958
4505	7690	7390
4505	7690	9483
4505	7690	7928
4505	7690	840
4505	7690	6339
9132	7691	7578
9132	7691	7871
9132	7691	2192
9132	7691	6846
9132	7691	1820
9132	7691	3939
11290	7692	4446
11290	7692	4486
11290	7692	6468
14613	7693	5799
14613	7693	6065
7283	7694	8235
7283	7694	8734
7283	7694	3392
7283	7694	5392
7283	7694	7772
7283	7694	2976
7283	7694	5573
117	7695	2471
117	7695	4044
117	7695	8007
117	7695	3943
117	7695	9366
117	7695	7712
117	7695	9427
16321	7696	8713
16321	7696	6085
16321	7696	8920
16321	7696	1811
16321	7696	6481
16321	7696	4552
16321	7696	8818
16321	7696	4338
4689	7697	6416
4689	7697	4586
8025	7698	2173
8025	7698	2456
8025	7698	7515
8025	7698	7369
18359	7699	1260
18359	7699	1910
18359	7699	2501
18359	7699	2939
11285	7700	7711
11285	7700	9134
11285	7700	827
11285	7700	9750
11285	7700	305
15639	7701	4255
15639	7701	432
3383	7702	1769
3383	7702	580
3383	7702	3554
3383	7702	350
16121	7703	4109
16121	7703	2517
16121	7703	6422
611	7704	1558
611	7704	5150
611	7704	77
611	7704	3681
611	7704	1907
611	7704	3898
611	7704	157
1011	7705	8566
1011	7705	9146
1011	7705	9254
1011	7705	6532
1011	7705	4484
1011	7705	5981
15077	7706	9528
15077	7706	2123
15077	7706	834
15077	7706	8658
15077	7706	6516
16347	7707	4009
16347	7707	1249
16347	7707	558
16347	7707	4816
16347	7707	6178
4317	7708	9697
4317	7708	3630
4317	7708	4541
4317	7708	2434
4317	7708	9782
4317	7708	105
4317	7708	9904
4317	7708	4471
4317	7708	7705
17907	7709	9456
17907	7709	4753
17907	7709	5748
17907	7709	7792
17907	7709	3516
17907	7709	4616
17907	7709	6714
18294	7710	237
18294	7710	8975
18294	7710	6922
9253	7711	3580
9253	7711	4131
9253	7711	4
9253	7711	8669
9253	7711	3318
9253	7711	5924
1080	7712	9696
8450	7713	8859
11561	7714	407
11561	7714	6015
11561	7714	7451
11561	7714	7022
11561	7714	9028
11561	7714	3206
11561	7714	2151
11561	7714	9177
11561	7714	9670
18731	7715	3590
18731	7715	6618
18731	7715	8107
18731	7715	8229
18731	7715	6351
18731	7715	3973
2846	7716	8878
2846	7716	5335
2846	7716	3882
2846	7716	1214
2846	7716	3585
2846	7716	6213
2846	7716	248
2846	7716	6920
2846	7716	5821
7853	7717	4005
7853	7717	3151
7853	7717	9056
7853	7717	9400
7853	7717	5417
1502	7718	8236
1502	7718	43
1502	7718	2456
1502	7718	2169
1502	7718	2496
1502	7718	6541
1502	7718	2625
5931	7719	9657
5931	7719	4223
5931	7719	6265
5931	7719	278
5931	7719	1899
5931	7719	2433
1337	7720	2489
9315	7721	3745
9315	7721	7474
9315	7721	8357
9315	7721	9335
9315	7721	5963
9315	7721	6191
9315	7721	7703
9315	7721	3807
9315	7721	4137
13139	7722	7238
13139	7722	2133
17591	7723	7954
17591	7723	2604
17591	7723	4497
17591	7723	5144
17591	7723	6659
17591	7723	2822
17591	7723	1290
10193	7724	802
10193	7724	6011
10193	7724	1591
10193	7724	563
10193	7724	2974
10193	7724	2519
10193	7724	5719
10193	7724	5485
10193	7724	5899
2084	7725	2148
2084	7725	8792
2084	7725	7160
2084	7725	8534
2084	7725	3537
2084	7725	5530
14239	7726	843
14239	7726	7310
14239	7726	3126
14239	7726	3832
14239	7726	1351
14239	7726	8592
14239	7726	773
14239	7726	6576
10734	7727	9463
10734	7727	1863
10734	7727	4226
10734	7727	2546
10734	7727	4511
10734	7727	991
16599	7728	1328
16599	7728	2845
16599	7728	2276
16599	7728	3312
19775	7729	5255
19775	7729	9078
19775	7729	7215
2880	7730	3767
9515	7731	3057
9515	7731	946
9515	7731	9454
9515	7731	7062
9515	7731	5226
9515	7731	4777
9515	7731	261
11030	7732	232
15894	7733	8209
7621	7734	522
7621	7734	8240
15386	7735	9422
15386	7735	5125
15386	7735	9548
15386	7735	4944
15386	7735	900
2262	7736	9078
2262	7736	4773
2262	7736	5511
2262	7736	1096
2262	7736	9240
14959	7737	5172
14959	7737	1503
14959	7737	8822
14959	7737	8793
14959	7737	2012
14959	7737	9862
14959	7737	1749
90	7738	65
90	7738	406
90	7738	9535
17549	7739	6254
2851	7740	6020
2851	7740	5279
2851	7740	1733
2851	7740	8547
2851	7740	201
2851	7740	3972
2851	7740	340
2851	7740	7362
15534	7741	9269
15534	7741	762
14030	7742	8441
14030	7742	3512
14030	7742	6494
14030	7742	9271
14030	7742	6080
12559	7743	522
12559	7743	4618
12559	7743	8858
12559	7743	5650
9836	7744	7304
9836	7744	6833
9836	7744	4723
9836	7744	9022
9836	7744	9733
9836	7744	7024
9836	7744	3742
9836	7744	6821
9836	7744	9383
19808	7745	7787
19808	7745	9041
16194	7746	7915
16194	7746	9093
16194	7746	1551
16194	7746	20
16194	7746	2050
16194	7746	6087
16194	7746	8755
16194	7746	2177
16194	7746	3390
1486	7747	2714
1486	7747	6136
1486	7747	2686
1486	7747	9851
15530	7748	2512
15530	7748	5355
14809	7749	6478
14809	7749	4735
14809	7749	6613
14809	7749	214
14809	7749	8867
3161	7750	3335
3161	7750	366
3161	7750	4652
3161	7750	950
3161	7750	4351
3161	7750	9600
3161	7750	5992
16551	7751	9313
16551	7751	2242
16551	7751	6186
16551	7751	3047
8121	7752	1210
8121	7752	8668
8121	7752	3151
8121	7752	4387
8121	7752	4670
8538	7753	2689
8538	7753	1828
8538	7753	9141
8538	7753	4077
524	7754	5314
3893	7755	1913
3893	7755	6958
3893	7755	5010
3893	7755	9164
3893	7755	83
17052	7756	4079
17052	7756	2652
17052	7756	3246
17052	7756	4600
17052	7756	6990
17052	7756	425
9193	7757	9979
9193	7757	1116
9193	7757	1226
9193	7757	8280
9193	7757	5805
9193	7757	7115
9193	7757	6888
9193	7757	6389
9193	7757	9497
5485	7758	3055
5485	7758	7221
5485	7758	5062
5485	7758	8075
5485	7758	3048
5485	7758	5474
5485	7758	4989
5485	7758	288
12184	7759	5844
12184	7759	1595
12184	7759	9485
12184	7759	1274
14083	7760	9800
14083	7760	367
14083	7760	3296
14083	7760	4173
14083	7760	6495
14083	7760	506
14083	7760	6347
6872	7761	7640
6872	7761	4901
6872	7761	4962
6872	7761	326
6872	7761	8055
6872	7761	3277
6151	7762	7937
6151	7762	9857
12703	7763	7835
5172	7764	8969
5172	7764	733
5172	7764	8412
5172	7764	8255
5172	7764	1929
5172	7764	2897
5172	7764	6818
5172	7764	8281
12434	7765	8326
12434	7765	1568
12434	7765	622
12434	7765	8183
12434	7765	1988
1912	7766	4826
6161	7767	9390
6161	7767	3306
6161	7767	2886
6161	7767	3206
6161	7767	7803
6161	7767	3462
6161	7767	3977
6161	7767	6210
8784	7768	4112
8784	7768	7374
8784	7768	6562
8784	7768	317
8784	7768	5279
8784	7768	834
8280	7769	5726
8280	7769	6433
8280	7769	7763
8280	7769	9657
8280	7769	4923
8280	7769	6338
8280	7769	259
8280	7769	5770
6285	7770	5341
6285	7770	8056
6285	7770	4057
6285	7770	5288
6285	7770	3030
17511	7771	2284
17511	7771	3874
17511	7771	9746
17511	7771	7807
16130	7772	2436
16130	7772	7060
16130	7772	2845
16130	7772	7510
3134	7773	926
3134	7773	4471
3134	7773	1576
3134	7773	2453
3134	7773	2722
3134	7773	5800
3134	7773	5122
3134	7773	8552
14624	7774	4834
14624	7774	3921
14624	7774	6646
14624	7774	8580
16741	7775	1191
16741	7775	2396
16741	7775	7157
16741	7775	6625
4849	7776	6031
4849	7776	9566
4849	7776	8209
4849	7776	1809
4849	7776	998
4849	7776	722
18602	7777	7672
17723	7778	1628
17723	7778	1324
17723	7778	4756
17723	7778	677
17723	7778	8795
17723	7778	7999
12415	7779	9251
12415	7779	1947
12415	7779	3753
12415	7779	9273
12415	7779	9263
12415	7779	6338
8117	7780	8936
8117	7780	5684
8117	7780	3639
8117	7780	794
8117	7780	3067
8117	7780	793
8117	7780	5000
8500	7781	4222
8500	7781	4745
8500	7781	6826
8500	7781	437
8500	7781	7350
8500	7781	7222
12316	7782	9850
12316	7782	5718
12316	7782	4377
12316	7782	9436
12316	7782	6260
12316	7782	1074
12316	7782	8685
12316	7782	5592
12316	7782	8855
11360	7783	8844
11360	7783	3079
11360	7783	8859
11360	7783	2223
11360	7783	6110
11360	7783	9110
11360	7783	2716
4302	7784	6586
4302	7784	6823
4302	7784	2816
4302	7784	8177
4302	7784	2750
4302	7784	7350
4302	7784	1414
8984	7785	1245
8984	7785	4810
8984	7785	6553
8984	7785	9181
8984	7785	7405
8984	7785	1419
8984	7785	6662
6967	7786	5898
6967	7786	275
6967	7786	6029
6967	7786	5741
6967	7786	3817
6967	7786	1934
6967	7786	2171
6967	7786	556
14216	7787	6376
14216	7787	9503
14216	7787	4363
14216	7787	5798
14216	7787	9647
14216	7787	8756
14216	7787	525
14216	7787	4192
14216	7787	6654
941	7788	6545
941	7788	9108
941	7788	3608
941	7788	4208
941	7788	9351
941	7788	2809
14343	7789	7323
14343	7789	3248
14343	7789	207
14343	7789	5108
3522	7790	2231
3522	7790	250
3522	7790	5415
3522	7790	5876
167	7791	667
167	7791	7199
167	7791	3506
167	7791	3218
167	7791	6878
167	7791	6907
167	7791	237
167	7791	1483
11624	7792	4599
11624	7792	4781
11624	7792	4490
11624	7792	9034
11624	7792	740
11624	7792	1831
18059	7793	1244
18059	7793	3230
18059	7793	130
733	7794	929
733	7794	2499
733	7794	1928
733	7794	944
733	7794	7110
733	7794	7366
733	7794	8918
1497	7795	9778
1497	7795	10000
1497	7795	3626
1497	7795	9143
1497	7795	3364
1497	7795	4122
1497	7795	1035
7068	7796	631
7068	7796	73
7068	7796	7237
7068	7796	3884
5175	7797	186
5175	7797	5014
5175	7797	7702
5175	7797	3414
5175	7797	2394
13031	7798	1566
13031	7798	5760
13031	7798	7089
14323	7799	4599
14323	7799	7621
9047	7800	1204
17810	7801	5749
17810	7801	1164
17810	7801	7757
17810	7801	9166
9850	7802	1315
9850	7802	1430
9850	7802	7444
9850	7802	3461
8125	7803	4851
8125	7803	1573
839	7804	1661
839	7804	2383
839	7804	4827
839	7804	8738
839	7804	6473
15575	7805	3234
15575	7805	3734
15575	7805	8971
15575	7805	756
15575	7805	1267
15575	7805	9349
15575	7805	1429
3276	7806	3011
3276	7806	4335
3276	7806	8418
3276	7806	9845
3276	7806	3558
41	7807	3927
41	7807	2604
41	7807	7461
41	7807	1455
41	7807	8966
41	7807	1566
9648	7808	9743
9648	7808	1204
9648	7808	2880
9648	7808	7150
1416	7809	729
1416	7809	3098
1416	7809	226
1416	7809	7552
1416	7809	9061
1416	7809	6413
1416	7809	9811
19315	7810	3992
10390	7811	4816
10390	7811	1099
10390	7811	4479
10390	7811	6515
10390	7811	2611
10390	7811	9862
10390	7811	5313
10390	7811	523
13871	7812	4914
13871	7812	5888
13871	7812	1273
13871	7812	260
13871	7812	5074
13871	7812	5143
12483	7813	6184
12483	7813	339
12483	7813	5343
12483	7813	1631
12483	7813	7614
8067	7814	265
8067	7814	8250
8067	7814	1717
8067	7814	6032
8067	7814	6291
8067	7814	8859
8067	7814	995
422	7815	5942
422	7815	2652
422	7815	5180
422	7815	1939
13935	7816	4397
13935	7816	9524
13935	7816	3243
13935	7816	2168
13935	7816	3218
4152	7817	1587
4152	7817	1584
15051	7818	8809
15051	7818	8356
15051	7818	9182
15051	7818	7715
4222	7819	4757
4222	7819	1078
4222	7819	5614
4222	7819	5382
4222	7819	6371
4222	7819	7365
4222	7819	2837
4222	7819	4187
4222	7819	6474
10565	7820	6030
10565	7820	1478
10565	7820	6974
10565	7820	5855
10565	7820	1627
10565	7820	6413
10565	7820	7535
5832	7821	8188
5832	7821	1328
5832	7821	4332
5832	7821	5283
7229	7822	302
7229	7822	3659
7229	7822	5862
3432	7823	2327
3432	7823	7900
3432	7823	9142
3432	7823	2777
3432	7823	8269
19191	7824	5110
19191	7824	7680
19191	7824	886
19191	7824	8712
19191	7824	5886
19191	7824	2966
19191	7824	3002
7410	7825	821
7410	7825	5650
7410	7825	4528
7410	7825	7121
7410	7825	9392
7410	7825	2391
15001	7826	3519
15001	7826	7985
15001	7826	725
15001	7826	4600
15202	7827	1306
15202	7827	4868
15202	7827	1583
15202	7827	2088
15202	7827	8944
15202	7827	8906
15202	7827	8872
15202	7827	9716
15202	7827	8797
4630	7828	4545
4630	7828	1480
4630	7828	2321
4630	7828	6745
4630	7828	6174
4630	7828	4499
4630	7828	176
4525	7829	1471
684	7830	5751
684	7830	6920
684	7830	3505
684	7830	2987
684	7830	3456
684	7830	7193
684	7830	1562
684	7830	8320
5638	7831	8901
5638	7831	4425
11789	7832	6237
11789	7832	8227
11789	7832	5773
11789	7832	7364
11789	7832	9972
11789	7832	7327
11789	7832	4816
11789	7832	9202
11789	7832	8457
887	7833	2605
887	7833	3225
887	7833	333
5043	7834	7104
5043	7834	1147
5043	7834	7107
5043	7834	2154
5043	7834	8860
5043	7834	505
5043	7834	4001
5043	7834	52
5043	7834	7229
15139	7835	6810
15139	7835	2534
15139	7835	4339
15139	7835	9663
15139	7835	4618
11528	7836	4274
11528	7836	4219
11528	7836	1277
11528	7836	6808
11528	7836	4431
11528	7836	7734
11528	7836	1024
16155	7837	8355
16155	7837	3180
16155	7837	4130
16155	7837	766
16155	7837	9609
16155	7837	4511
17568	7838	1917
17568	7838	6882
2623	7839	2971
2623	7839	5966
2623	7839	4686
2623	7839	8236
2623	7839	777
9812	7840	3653
9812	7840	7298
9812	7840	3116
9812	7840	6947
9812	7840	7395
9812	7840	6485
8169	7841	9418
8169	7841	9782
8169	7841	756
17982	7842	406
17982	7842	3170
17982	7842	9740
17982	7842	8527
17982	7842	4985
17982	7842	2274
17982	7842	5804
17982	7842	795
16766	7843	1556
16766	7843	8091
16766	7843	1174
16766	7843	5804
16766	7843	7837
16766	7843	6924
16766	7843	6552
16766	7843	2904
16766	7843	6915
3798	7844	3830
3798	7844	5270
3798	7844	1166
3798	7844	3007
3798	7844	8748
3798	7844	3329
9005	7845	3163
9005	7845	5013
3128	7846	7854
3128	7846	6096
3128	7846	8993
3128	7846	6782
3128	7846	8045
18419	7847	6748
154	7848	4579
15483	7849	7828
15483	7849	9190
15483	7849	2480
15483	7849	5101
15483	7849	8224
15483	7849	7743
15483	7849	6915
8721	7850	4813
8721	7850	8333
8721	7850	1821
8721	7850	738
8721	7850	7716
8721	7850	4141
8721	7850	976
8721	7850	1582
8121	7851	2636
8121	7851	9169
8121	7851	436
8121	7851	6166
8121	7851	444
10512	7852	5082
10512	7852	9328
10512	7852	1125
10512	7852	9169
289	7853	309
289	7853	6452
289	7853	2285
2907	7854	7537
2907	7854	874
2907	7854	6792
2907	7854	3237
16636	7855	4137
6611	7856	3450
6611	7856	402
6611	7856	5255
6611	7856	1275
6611	7856	5941
6611	7856	8993
6611	7856	7604
6611	7856	1036
15654	7857	7524
15654	7857	6064
15654	7857	6153
15654	7857	7493
15654	7857	3505
15654	7857	1364
15654	7857	6352
3212	7858	9145
3212	7858	6207
7621	7859	2288
14903	7860	3446
14903	7860	8296
14903	7860	3183
14903	7860	2951
14903	7860	4094
14903	7860	3641
8705	7861	6338
8705	7861	9258
8705	7861	9332
8705	7861	6356
8705	7861	223
18098	7862	5399
7390	7863	9484
7390	7863	2943
7390	7863	6402
7390	7863	4021
7390	7863	936
7390	7863	7180
12875	7864	5660
12875	7864	596
12875	7864	4817
12875	7864	4931
12875	7864	3859
12875	7864	450
19173	7865	1674
19173	7865	7084
19173	7865	2715
19173	7865	556
15471	7866	4173
15471	7866	1040
15471	7866	6916
15471	7866	5714
1288	7867	973
1288	7867	6193
1288	7867	2679
1288	7867	8504
1288	7867	5513
1288	7867	2427
1288	7867	6692
1288	7867	1878
1288	7867	718
9781	7868	4722
9781	7868	985
9781	7868	2190
9781	7868	1079
9781	7868	5648
9781	7868	7925
9781	7868	7049
9781	7868	1222
9781	7868	4955
14764	7869	364
14764	7869	1699
14764	7869	9639
14764	7869	5972
14764	7869	9357
14764	7869	3640
14764	7869	1129
14764	7869	6728
4750	7870	4215
4750	7870	9188
4750	7870	6860
4750	7870	2170
4750	7870	1524
4750	7870	5830
4750	7870	3969
4750	7870	2970
17882	7871	9635
17882	7871	7234
17882	7871	6256
17882	7871	2971
17882	7871	6337
17882	7871	5501
17882	7871	8537
10793	7872	3395
10793	7872	5287
10793	7872	2241
10793	7872	6753
10793	7872	2862
10793	7872	4151
10793	7872	1182
10793	7872	77
12666	7873	3249
12666	7873	4749
12666	7873	9265
12666	7873	3437
12666	7873	8682
12666	7873	3408
12666	7873	2620
9721	7874	71
9721	7874	2343
9721	7874	460
9721	7874	8007
9721	7874	1940
9721	7874	6869
9721	7874	73
9721	7874	3031
4592	7875	7548
4592	7875	4570
4592	7875	8864
328	7876	8218
328	7876	8408
328	7876	6342
328	7876	4085
328	7876	9404
328	7876	6902
328	7876	342
6746	7877	5669
6746	7877	7559
6746	7877	6688
6746	7877	4172
6746	7877	9318
2735	7878	3488
2735	7878	4493
2735	7878	8695
2735	7878	4176
2156	7879	8052
2156	7879	8318
2156	7879	6015
2156	7879	9748
2156	7879	7202
2747	7880	5195
2747	7880	6387
2747	7880	1633
2747	7880	6441
2747	7880	9702
7756	7881	4956
7756	7881	4249
7756	7881	8362
7756	7881	2855
7756	7881	6552
7756	7881	7950
7756	7881	9038
7756	7881	5127
7756	7881	8671
10114	7882	4931
9265	7883	8510
9265	7883	487
9471	7884	7301
9471	7884	2084
9471	7884	1929
9471	7884	7606
9471	7884	3685
9471	7884	1989
9471	7884	3052
19971	7885	3361
19971	7885	6974
19971	7885	8728
18428	7886	3949
18428	7886	667
18428	7886	4749
13356	7887	7644
13356	7887	5439
13356	7887	8823
12467	7888	8575
12467	7888	8955
15365	7889	6897
15365	7889	280
15365	7889	5403
15365	7889	2096
15365	7889	3698
15365	7889	6829
15365	7889	9906
10689	7890	3835
10689	7890	8005
13159	7891	2128
13159	7891	2495
13159	7891	5174
13159	7891	3140
13159	7891	236
4662	7892	9529
18867	7893	4778
18867	7893	1296
18867	7893	8545
18867	7893	923
18867	7893	5880
18867	7893	9213
18867	7893	2923
18867	7893	1166
18867	7893	1098
2666	7894	3664
2666	7894	43
2666	7894	7062
2666	7894	2626
2666	7894	6145
2666	7894	1151
2666	7894	6015
2666	7894	6741
2666	7894	4096
6617	7895	5015
6617	7895	3024
6617	7895	6099
6617	7895	7445
6617	7895	6518
13121	7896	3180
13121	7896	4602
13121	7896	4329
13121	7896	6765
13121	7896	5447
13121	7896	7280
13121	7896	6125
13504	7897	8545
13504	7897	3978
13504	7897	3808
13504	7897	3589
13504	7897	2531
13504	7897	6886
13504	7897	1623
13504	7897	3757
16170	7898	8428
16170	7898	9659
16170	7898	6966
16170	7898	4993
16170	7898	2536
16170	7898	7681
3315	7899	3080
11221	7900	2442
11221	7900	7526
11221	7900	1234
11221	7900	4283
11221	7900	3069
11221	7900	634
11221	7900	8418
6821	7901	2617
18118	7902	9310
18118	7902	7159
18118	7902	5441
18118	7902	7346
18118	7902	5555
18118	7902	4081
18118	7902	1787
18118	7902	9999
1264	7903	8230
1264	7903	2902
1264	7903	7137
1264	7903	737
1264	7903	4577
1264	7903	7109
1264	7903	7318
1264	7903	3770
1264	7903	4813
734	7904	7155
734	7904	3086
734	7904	2628
734	7904	7785
734	7904	3651
13104	7905	2070
13104	7905	2698
13104	7905	9882
13104	7905	532
8603	7906	5417
8603	7906	9253
8603	7906	5321
8603	7906	9177
8603	7906	3561
8603	7906	2565
8603	7906	2012
8603	7906	7360
18034	7907	1411
18034	7907	1483
18034	7907	4253
18034	7907	8491
18034	7907	6316
3464	7908	3136
3464	7908	2872
3464	7908	2774
3464	7908	4115
3464	7908	7778
3464	7908	1553
8640	7909	9157
8640	7909	631
8640	7909	6855
8640	7909	2653
8640	7909	3209
8640	7909	3794
5682	7910	7209
5682	7910	6146
5682	7910	6190
5682	7910	5320
13746	7911	1193
698	7912	988
698	7912	2521
698	7912	1019
698	7912	2607
698	7912	6150
698	7912	7654
698	7912	7140
6569	7913	3545
6569	7913	2948
6569	7913	7037
6569	7913	753
6569	7913	5306
6569	7913	8578
6569	7913	5399
6569	7913	9798
6569	7913	3205
11621	7914	9116
11621	7914	2833
11621	7914	8144
11621	7914	9540
11621	7914	4607
11621	7914	3152
11621	7914	3014
11621	7914	9603
11621	7914	8417
13990	7915	6560
13990	7915	4844
13990	7915	9647
13990	7915	5574
13990	7915	8289
13990	7915	8558
13990	7915	945
968	7916	3568
968	7916	8907
17019	7917	3418
17019	7917	8440
9999	7918	4763
9999	7918	2132
9999	7918	6203
9999	7918	5026
11941	7919	6455
11941	7919	9642
11941	7919	3992
11941	7919	6603
11941	7919	7057
11941	7919	8466
11941	7919	8822
11941	7919	2924
8406	7920	5130
8406	7920	7004
8406	7920	3811
8406	7920	6092
8406	7920	8000
8406	7920	3641
8406	7920	8705
5392	7921	9716
16363	7922	5087
16363	7922	4466
16363	7922	6486
16363	7922	3658
16363	7922	9116
16363	7922	2947
16363	7922	2690
1378	7923	5142
1378	7923	5202
14063	7924	5918
14063	7924	5888
14063	7924	5566
14063	7924	7560
14063	7924	7965
14063	7924	5756
14063	7924	5660
17213	7925	7644
17213	7925	5661
17213	7925	7996
17213	7925	9529
17213	7925	419
2225	7926	9831
2225	7926	1424
2225	7926	2088
2225	7926	5427
2225	7926	3028
2225	7926	1674
7914	7927	8929
7914	7927	9927
7914	7927	9172
7914	7927	5393
11623	7928	6924
11623	7928	7495
17835	7929	7901
17835	7929	4698
17835	7929	8760
17835	7929	9616
17835	7929	328
18514	7930	3847
18514	7930	6514
18514	7930	9720
18514	7930	5050
18514	7930	8982
18514	7930	7385
18514	7930	8727
18514	7930	5393
6586	7931	4221
6586	7931	5657
6586	7931	2026
6586	7931	747
6586	7931	5241
6586	7931	9282
6586	7931	3613
6586	7931	8326
6586	7931	3428
4818	7932	8885
4818	7932	6600
4818	7932	4951
4818	7932	7571
4818	7932	474
4818	7932	617
5284	7933	3332
5284	7933	8969
5284	7933	6443
5284	7933	8408
5284	7933	5914
5284	7933	8143
6981	7934	7565
6981	7934	7406
6981	7934	9631
208	7935	6234
208	7935	9178
208	7935	8771
208	7935	5703
208	7935	5122
208	7935	320
12468	7936	1420
12468	7936	8545
12468	7936	2737
12468	7936	1705
12468	7936	8625
9089	7937	1080
9089	7937	4283
6105	7938	792
6105	7938	3868
1559	7939	5834
1559	7939	6390
1559	7939	2027
1559	7939	489
1559	7939	9268
1559	7939	5067
1559	7939	3658
9475	7940	4995
15522	7941	5649
15522	7941	5510
15522	7941	6568
15522	7941	3847
472	7942	9362
472	7942	7377
472	7942	6382
472	7942	3015
18575	7943	9842
18575	7943	3325
18575	7943	7531
6359	7944	246
6359	7944	6210
6359	7944	2
6359	7944	4328
7378	7945	2318
7378	7945	1293
7378	7945	470
7378	7945	4620
7378	7945	3367
7378	7945	5016
7378	7945	7911
7378	7945	1937
5939	7946	570
5939	7946	64
5939	7946	3152
5939	7946	7353
5939	7946	8081
5939	7946	3475
9534	7947	5008
9534	7947	7549
9534	7947	4812
5444	7948	8480
5444	7948	9971
5444	7948	6810
5444	7948	2916
5444	7948	1112
5444	7948	1264
5444	7948	692
8332	7949	8933
8332	7949	4003
3103	7950	4117
18456	7951	66
18456	7951	9427
4686	7952	8410
4686	7952	4468
4686	7952	4355
4686	7952	3268
4686	7952	6034
4686	7952	9568
10778	7953	6023
10778	7953	5835
10778	7953	4931
10778	7953	1212
10778	7953	4568
10778	7953	1871
10778	7953	2981
10778	7953	5465
19865	7954	4267
19865	7954	9080
19865	7954	5960
19865	7954	335
19865	7954	4036
115	7955	9435
115	7955	6604
115	7955	7552
115	7955	1285
115	7955	633
115	7955	5041
11341	7956	654
11341	7956	9909
11341	7956	595
11341	7956	8380
11341	7956	7968
11341	7956	2852
953	7957	3032
953	7957	2554
7676	7958	8104
7676	7958	9416
7676	7958	718
2743	7959	1104
2743	7959	5685
2743	7959	7263
2743	7959	1898
2743	7959	2175
2743	7959	591
2743	7959	6277
2743	7959	8600
2743	7959	4206
8425	7960	9260
19955	7961	1349
19955	7961	4257
19955	7961	1536
19955	7961	1936
7666	7962	8203
7666	7962	2854
7666	7962	3125
7666	7962	3310
7666	7962	2739
7666	7962	1544
1606	7963	781
1606	7963	5720
19953	7964	9918
19953	7964	6359
19953	7964	349
19953	7964	9282
19953	7964	4774
19953	7964	3032
19953	7964	3589
12653	7965	3668
12653	7965	7576
12653	7965	346
12653	7965	5850
12653	7965	485
12653	7965	6042
12653	7965	9435
11585	7966	1064
11585	7966	481
7023	7967	9852
7023	7967	803
7023	7967	5738
7023	7967	1236
7023	7967	9498
10696	7968	7223
10696	7968	7218
17595	7969	727
17595	7969	7873
17595	7969	9349
17595	7969	4719
17595	7969	3237
17595	7969	2049
17595	7969	6740
17595	7969	8510
17595	7969	1100
5536	7970	4921
5536	7970	891
5536	7970	7234
5536	7970	935
5536	7970	9658
5536	7970	3195
5536	7970	2868
15172	7971	2156
15172	7971	3567
15172	7971	5462
15172	7971	6871
15172	7971	84
15172	7971	9329
15172	7971	3629
15172	7971	4017
15172	7971	6388
14644	7972	8984
14644	7972	2246
14644	7972	6670
14644	7972	9437
14644	7972	8064
3260	7973	3707
3260	7973	1995
3260	7973	3784
3260	7973	7230
3260	7973	5573
3920	7974	9282
3920	7974	1707
3920	7974	7556
3920	7974	116
3920	7974	2490
3920	7974	6521
3920	7974	1146
3266	7975	8991
3266	7975	9679
3266	7975	5243
3266	7975	188
3266	7975	8154
3266	7975	2776
4115	7976	322
876	7977	9991
876	7977	7812
876	7977	8873
876	7977	2769
876	7977	5883
876	7977	4717
876	7977	4533
9441	7978	6840
11901	7979	6768
11901	7979	6985
11901	7979	6368
11901	7979	8797
11901	7979	5225
8193	7980	4894
19222	7981	9571
19222	7981	1274
19222	7981	1136
19222	7981	3897
19222	7981	4064
19222	7981	7758
9484	7982	7586
9484	7982	8160
11306	7983	5915
11306	7983	6860
11306	7983	1411
11306	7983	4488
11521	7984	3874
11521	7984	8960
11521	7984	4728
11521	7984	8768
11521	7984	1459
11521	7984	1963
245	7985	5775
3378	7986	9623
3378	7986	6213
3261	7987	8183
3261	7987	9501
3261	7987	1681
3261	7987	3859
10634	7988	4362
10634	7988	6475
10634	7988	3960
10634	7988	4977
10634	7988	3938
10634	7988	9717
11860	7989	7560
11485	7990	2885
11485	7990	8464
11485	7990	3413
11485	7990	2060
12841	7991	2636
12841	7991	7928
12841	7991	1250
12841	7991	3149
12841	7991	5426
12841	7991	6897
8912	7992	198
8912	7992	84
8912	7992	4887
8912	7992	9825
8912	7992	1399
8912	7992	3296
4356	7993	5019
12537	7994	7235
12537	7994	2355
6935	7995	9315
6935	7995	7152
6935	7995	1867
6935	7995	7945
6935	7995	337
7266	7996	5811
7266	7996	2817
2735	7997	3067
2735	7997	8006
2735	7997	8464
2735	7997	8889
2735	7997	7830
2735	7997	5835
15401	7998	9391
15401	7998	4890
15401	7998	990
15401	7998	4841
15401	7998	1062
2993	7999	8004
2993	7999	9058
2993	7999	7513
2993	7999	8609
2993	7999	4571
810	8000	8105
810	8000	7752
9922	8001	1376
9922	8001	9981
9922	8001	7410
9922	8001	2277
9922	8001	8945
9922	8001	4272
1039	8002	1626
1039	8002	6797
1039	8002	6441
1039	8002	1167
1039	8002	6650
1039	8002	4377
7980	8003	6876
7980	8003	4152
7980	8003	6419
7980	8003	8159
7980	8003	9010
1026	8004	7065
1026	8004	134
1026	8004	5371
1026	8004	9794
1026	8004	7818
4389	8005	6185
4389	8005	2537
4389	8005	822
4389	8005	7345
4389	8005	3118
4389	8005	2603
4389	8005	7933
4389	8005	2640
19408	8006	3566
19408	8006	6346
19408	8006	7362
19408	8006	9801
19408	8006	6358
19408	8006	99
19408	8006	484
19408	8006	5601
19408	8006	9324
4883	8007	4568
4883	8007	5267
9811	8008	4678
9811	8008	3542
9811	8008	3835
7271	8009	278
7271	8009	4086
19374	8010	2632
19374	8010	7534
19374	8010	1756
19374	8010	7460
19374	8010	9309
12438	8011	6695
12438	8011	7628
12438	8011	1881
12438	8011	4165
12438	8011	4359
12438	8011	8050
7636	8012	8910
7636	8012	7877
7636	8012	1842
7636	8012	8545
7636	8012	6654
7636	8012	4021
7636	8012	4072
1532	8013	1296
1532	8013	5627
1532	8013	9230
14559	8014	1097
14559	8014	2373
14559	8014	7322
14559	8014	6450
14559	8014	9881
13068	8015	5115
13068	8015	3941
13068	8015	7684
17958	8016	4439
17958	8016	8723
17958	8016	7198
17958	8016	9447
17958	8016	3710
17958	8016	8302
17958	8016	2069
17958	8016	193
17313	8017	1141
17313	8017	9509
17313	8017	3896
14013	8018	5744
14013	8018	2062
18519	8019	7554
18519	8019	6215
18519	8019	6357
18519	8019	607
703	8020	2943
703	8020	2310
703	8020	1427
703	8020	9643
703	8020	3212
703	8020	5026
703	8020	6422
703	8020	3422
10075	8021	364
10075	8021	9757
10075	8021	264
10075	8021	3269
16948	8022	4820
16948	8022	6107
16948	8022	7724
16948	8022	9129
8308	8023	1242
8308	8023	9354
8308	8023	8349
8308	8023	1490
8308	8023	7101
8308	8023	5431
8308	8023	1609
8308	8023	7860
14138	8024	8588
14138	8024	8238
14732	8025	1520
14732	8025	7379
14732	8025	445
14732	8025	350
14732	8025	1852
14732	8025	7505
14732	8025	3086
14732	8025	6317
14732	8025	1634
17612	8026	798
17612	8026	5081
17612	8026	6143
6775	8027	522
6775	8027	681
6775	8027	6422
6775	8027	9760
6775	8027	2871
6775	8027	7226
6775	8027	200
6775	8027	652
15337	8028	664
15337	8028	8796
15337	8028	472
15337	8028	8660
15337	8028	8326
15337	8028	4792
15337	8028	661
15337	8028	9815
15337	8028	6504
18748	8029	5331
18748	8029	6124
18748	8029	8871
19019	8030	946
19019	8030	58
19019	8030	6540
19019	8030	8289
6162	8031	8554
10114	8032	4431
10114	8032	5369
10114	8032	6980
11700	8033	5360
11700	8033	3705
11700	8033	9741
11700	8033	7722
11700	8033	2480
11700	8033	1146
11700	8033	9092
11700	8033	2519
11700	8033	8387
2979	8034	1431
2979	8034	6894
2979	8034	9600
2979	8034	4260
2979	8034	2028
2979	8034	3073
2979	8034	5924
7291	8035	9657
7291	8035	4144
13324	8036	6612
13324	8036	4974
13324	8036	6228
13324	8036	7458
14113	8037	1990
14113	8037	8692
14113	8037	3518
14113	8037	7875
14113	8037	8260
14113	8037	4988
14113	8037	7207
14113	8037	6665
14113	8037	5793
4809	8038	1755
18424	8039	6269
18424	8039	1052
19486	8040	4357
19486	8040	1574
19486	8040	8162
19486	8040	534
19486	8040	5692
19486	8040	7673
19486	8040	255
19486	8040	3889
11287	8041	4855
11287	8041	3367
8837	8042	4161
8837	8042	3150
8837	8042	3894
8837	8042	1135
8837	8042	1285
13952	8043	8461
13952	8043	8557
13952	8043	1527
13952	8043	7993
13952	8043	4168
15068	8044	1953
15068	8044	8737
15068	8044	6051
15068	8044	4631
11532	8045	7434
11532	8045	4870
11532	8045	4520
11532	8045	5418
11532	8045	5679
11532	8045	5856
11532	8045	9257
11532	8045	6518
976	8046	3839
976	8046	5622
976	8046	8627
976	8046	9833
976	8046	6019
976	8046	3130
976	8046	1256
976	8046	9750
976	8046	1328
14013	8047	677
14013	8047	4731
14013	8047	5226
14013	8047	7683
14013	8047	1796
14836	8048	7671
14836	8048	3833
14836	8048	3074
14836	8048	7141
14836	8048	4960
14836	8048	106
14836	8048	2058
14836	8048	3294
7942	8049	1166
7942	8049	683
7942	8049	3993
7942	8049	369
7942	8049	9896
7942	8049	2561
7942	8049	3020
7942	8049	1256
16792	8050	5286
16792	8050	4602
16792	8050	9486
16792	8050	1513
16792	8050	1867
16792	8050	1546
16792	8050	7813
16792	8050	1880
4496	8051	4026
4496	8051	2168
4496	8051	4722
4496	8051	3139
4496	8051	1819
14209	8052	4448
11921	8053	3010
1645	8054	2628
1645	8054	7913
1645	8054	9807
1645	8054	6725
1645	8054	8983
1645	8054	5397
14431	8055	4320
14431	8055	6905
14431	8055	3347
14431	8055	4728
14431	8055	6546
14431	8055	8344
17685	8056	4048
17685	8056	9583
12614	8057	7753
12614	8057	6950
12614	8057	8440
12614	8057	3187
12614	8057	2404
11502	8058	5823
11502	8058	3991
11502	8058	2759
11502	8058	3009
11502	8058	3736
11502	8058	2663
17018	8059	3338
17018	8059	7960
17018	8059	4652
17018	8059	2920
17018	8059	9158
17018	8059	7928
17018	8059	1075
13794	8060	1063
8142	8061	1127
8142	8061	530
8142	8061	8921
8142	8061	8771
8142	8061	7531
8142	8061	2546
8142	8061	3129
4572	8062	2969
4572	8062	1756
4572	8062	8761
4572	8062	830
4572	8062	6988
4572	8062	3895
4572	8062	1517
4572	8062	5150
8141	8063	6329
8141	8063	2556
8141	8063	1913
8141	8063	4341
8141	8063	7970
8141	8063	9878
3266	8064	9626
3266	8064	5579
3266	8064	5978
3266	8064	1351
3266	8064	4494
3266	8064	9540
3479	8065	1470
3479	8065	5774
3479	8065	5615
3479	8065	5313
3479	8065	5245
3479	8065	4523
3479	8065	6824
12898	8066	3062
12898	8066	3045
12898	8066	509
12898	8066	912
2964	8067	8381
2964	8067	6392
2964	8067	6640
2964	8067	4270
2964	8067	5591
2964	8067	7143
7932	8068	415
7932	8068	3317
7932	8068	5529
7932	8068	7888
7932	8068	3899
7932	8068	6086
7932	8068	281
7932	8068	9447
7932	8068	1131
15541	8069	9723
15541	8069	6600
15541	8069	3550
15541	8069	831
15541	8069	8097
15541	8069	1542
15541	8069	4721
5217	8070	1408
5217	8070	4657
8206	8071	9942
8206	8071	5968
8206	8071	252
8206	8071	1223
8206	8071	2556
8206	8071	5203
8206	8071	3799
8206	8071	4631
18702	8072	1959
18702	8072	4154
18702	8072	4713
3559	8073	9978
3559	8073	8570
3559	8073	640
3559	8073	1636
3559	8073	5673
1749	8074	4173
17766	8075	1366
17766	8075	3703
17766	8075	6883
17766	8075	4330
17766	8075	195
17766	8075	7340
17766	8075	96
17766	8075	6117
15505	8076	1944
19039	8077	1726
19039	8077	4333
19039	8077	3619
19039	8077	6800
19039	8077	1218
11095	8078	2789
11095	8078	6101
11095	8078	8868
11095	8078	3620
11095	8078	9971
11095	8078	4002
10559	8079	730
10559	8079	546
10559	8079	6442
10559	8079	761
10559	8079	1484
14438	8080	3149
14438	8080	5498
14438	8080	3198
13636	8081	3035
13636	8081	3350
9564	8082	7941
9564	8082	3034
9564	8082	8303
9564	8082	7622
9564	8082	5772
9564	8082	7006
9564	8082	7084
9564	8082	3611
13617	8083	3626
13322	8084	5144
13322	8084	437
13322	8084	2087
13322	8084	2876
13322	8084	2758
13322	8084	8914
9371	8085	7982
9371	8085	8124
9371	8085	4588
9371	8085	8401
9371	8085	8395
9371	8085	6441
9371	8085	8688
9371	8085	6354
13580	8086	5167
13580	8086	4632
13580	8086	6623
13580	8086	8304
13580	8086	8231
13580	8086	5558
13580	8086	5234
13580	8086	7805
13580	8086	1208
19204	8087	301
19204	8087	1105
19204	8087	751
19204	8087	3444
19204	8087	8043
19204	8087	8762
19204	8087	6534
19204	8087	6220
8900	8088	663
8900	8088	2211
8900	8088	3117
8900	8088	4673
8900	8088	3021
8900	8088	2264
8900	8088	9825
8900	8088	9976
6839	8089	2029
6839	8089	2615
6839	8089	8038
6839	8089	3400
6839	8089	3284
6839	8089	9538
6839	8089	4759
6839	8089	2414
6839	8089	5168
16376	8090	1509
16376	8090	7977
16376	8090	390
16376	8090	4904
16376	8090	9816
4860	8091	1264
4860	8091	5981
4860	8091	356
4860	8091	8493
4860	8091	7268
4870	8092	623
4870	8092	9943
4870	8092	7798
4870	8092	3616
4870	8092	7793
15217	8093	39
15217	8093	4376
15217	8093	9840
15217	8093	5849
15217	8093	5875
15217	8093	5311
15217	8093	5247
15217	8093	5577
15217	8093	3634
7152	8094	1494
7152	8094	7205
7152	8094	465
7152	8094	6895
7152	8094	9076
7152	8094	6862
7152	8094	8235
7152	8094	3806
7152	8094	6898
4416	8095	507
4416	8095	6910
4416	8095	4597
4416	8095	7717
18420	8096	8497
18420	8096	4025
18420	8096	1252
18420	8096	2325
1119	8097	4643
6133	8098	6738
6133	8098	1257
6133	8098	8568
12568	8099	5494
12568	8099	3277
12568	8099	8988
12568	8099	9382
12568	8099	401
12568	8099	8353
12568	8099	2266
12568	8099	7306
12568	8099	4881
17602	8100	3228
17602	8100	358
17602	8100	7309
17602	8100	8079
17602	8100	1059
17602	8100	9741
17602	8100	7563
13889	8101	8651
13889	8101	8987
12585	8102	3634
12585	8102	4170
12585	8102	4510
12585	8102	5289
12585	8102	9193
14542	8103	843
14542	8103	2395
14542	8103	7155
14542	8103	5350
14542	8103	6067
14542	8103	3443
14542	8103	4918
14542	8103	1346
9959	8104	8813
9959	8104	867
9959	8104	9916
9959	8104	6699
10770	8105	3812
10770	8105	6578
10770	8105	1402
10770	8105	7088
10770	8105	5928
10770	8105	2522
10770	8105	4462
10770	8105	3587
8253	8106	9175
8253	8106	1760
8253	8106	8156
8253	8106	6008
8253	8106	3843
8253	8106	3657
8253	8106	8355
19511	8107	7224
19511	8107	6238
19511	8107	8935
19511	8107	3613
19511	8107	4461
19511	8107	6648
11645	8108	4913
11645	8108	334
8354	8109	1832
8354	8109	7321
8354	8109	13
8354	8109	6159
8354	8109	7571
8354	8109	6982
8354	8109	3096
15113	8110	9248
15113	8110	1496
15113	8110	5045
15113	8110	6981
15113	8110	7328
15113	8110	9555
2772	8111	1837
2772	8111	4297
2772	8111	6736
2772	8111	392
2772	8111	8373
14798	8112	3072
14798	8112	532
14798	8112	9328
14798	8112	976
14798	8112	954
14798	8112	6718
14798	8112	7533
14040	8113	6520
14040	8113	1726
14040	8113	5193
14040	8113	6973
2567	8114	8646
2567	8114	6941
2567	8114	8603
2567	8114	4753
2567	8114	2577
2567	8114	7881
10826	8115	2433
10826	8115	1838
10826	8115	5861
10826	8115	2207
10826	8115	5681
10826	8115	4618
10826	8115	462
10826	8115	7936
9752	8116	1144
9752	8116	7798
9752	8116	8744
9752	8116	3014
9752	8116	1091
9752	8116	3065
9752	8116	9056
9752	8116	2476
9365	8117	3862
9365	8117	5433
9365	8117	6168
9365	8117	3431
3433	8118	4754
3433	8118	3108
3433	8118	7481
3433	8118	8455
3433	8118	2642
3433	8118	2095
3433	8118	6423
3433	8118	6613
3433	8118	9253
6227	8119	7437
6227	8119	7835
6227	8119	5120
6227	8119	2584
6227	8119	5466
17145	8120	4694
17145	8120	6981
17145	8120	809
17145	8120	9033
17145	8120	3646
17145	8120	2119
17145	8120	8225
17145	8120	6011
6895	8121	4315
6895	8121	9534
6895	8121	4971
6895	8121	4235
10139	8122	4359
10139	8122	5600
10139	8122	362
10139	8122	2398
10139	8122	277
10139	8122	6904
10139	8122	5671
10139	8122	9893
1236	8123	6464
2867	8124	7331
2867	8124	6879
2474	8125	6404
2474	8125	1347
2474	8125	7292
2474	8125	3319
2474	8125	125
2474	8125	7111
2474	8125	280
10051	8126	9306
10051	8126	8531
10051	8126	3532
10051	8126	1435
10051	8126	7499
10051	8126	1647
10051	8126	9265
1224	8127	2235
4719	8128	2376
4719	8128	5777
4719	8128	4463
7538	8129	2354
7538	8129	4499
7538	8129	5589
7538	8129	6338
7538	8129	2419
7538	8129	5286
7538	8129	6215
7538	8129	7124
4636	8130	4623
4636	8130	904
10734	8131	9136
10734	8131	4937
10734	8131	7150
10734	8131	5277
10734	8131	1432
10734	8131	9975
10520	8132	7398
10520	8132	1881
10520	8132	9417
10520	8132	1172
4151	8133	7443
4151	8133	8366
6606	8134	2738
6606	8134	6620
6606	8134	4956
6606	8134	8019
15987	8135	5092
15987	8135	8956
15987	8135	172
15987	8135	8547
15987	8135	2204
15987	8135	8109
15987	8135	7744
15987	8135	6223
15987	8135	9777
5029	8136	6684
5029	8136	1567
5029	8136	4759
5029	8136	2696
5029	8136	2671
3253	8137	1754
3253	8137	4059
3253	8137	3825
3253	8137	3603
3253	8137	8642
3253	8137	6043
3253	8137	4114
3253	8137	933
15233	8138	2319
10028	8139	2801
10028	8139	8654
10028	8139	5310
10028	8139	5938
10028	8139	4364
10028	8139	1536
10028	8139	1330
14745	8140	1769
14745	8140	3650
15962	8141	7071
15962	8141	4477
15962	8141	3461
15962	8141	3817
15962	8141	2374
15962	8141	2521
15962	8141	8495
15962	8141	8073
15962	8141	4851
5285	8142	4548
5285	8142	8331
5285	8142	9683
5285	8142	6178
5285	8142	4938
5285	8142	8193
5285	8142	9770
5285	8142	6693
18131	8143	7376
18131	8143	3174
18131	8143	1235
18131	8143	4851
18131	8143	667
18131	8143	243
17147	8144	4048
17147	8144	1611
17147	8144	2837
17147	8144	8401
17147	8144	1457
17147	8144	6192
17147	8144	4158
17147	8144	1513
17147	8144	108
2686	8145	2784
2686	8145	3457
7249	8146	3476
7249	8146	1588
8847	8147	7029
8847	8147	8127
8847	8147	1570
6164	8148	7768
6164	8148	3574
6164	8148	2632
12175	8149	9712
12175	8149	4442
12175	8149	6632
2531	8150	4299
2531	8150	9506
2531	8150	702
5648	8151	5055
5648	8151	9327
5648	8151	2401
5648	8151	4986
5648	8151	8045
5648	8151	8697
5648	8151	5354
5648	8151	943
18430	8152	2375
18430	8152	7101
18430	8152	9974
18430	8152	2955
18430	8152	626
18430	8152	3210
18430	8152	9034
18430	8152	4308
18430	8152	4494
5076	8153	294
5076	8153	9523
5076	8153	1001
5076	8153	452
5076	8153	8309
5076	8153	1800
3547	8154	6457
3547	8154	4771
3547	8154	9516
3547	8154	2203
3547	8154	5238
3547	8154	3116
3547	8154	9234
19054	8155	764
19054	8155	7523
19054	8155	1045
19054	8155	4042
19054	8155	1240
19054	8155	4617
19054	8155	6409
19054	8155	8286
15601	8156	1623
15601	8156	9638
15601	8156	3146
4913	8157	1289
4913	8157	4104
4913	8157	377
4913	8157	4642
4913	8157	7992
4913	8157	3167
4913	8157	332
17233	8158	6417
17233	8158	7364
17233	8158	5958
17233	8158	2778
8588	8159	1604
8588	8159	3431
8588	8159	1659
8588	8159	855
17694	8160	1456
17694	8160	967
3442	8161	7458
3442	8161	5585
3442	8161	3924
3442	8161	2518
3442	8161	2656
3442	8161	4064
3442	8161	6925
17167	8162	4884
14131	8163	9578
14131	8163	6261
11639	8164	2742
13330	8165	6460
13330	8165	1073
13330	8165	9113
13330	8165	8018
13330	8165	6581
13330	8165	9900
13330	8165	8845
19523	8166	1646
19523	8166	8814
19523	8166	2770
19523	8166	6313
19523	8166	901
19523	8166	2176
19523	8166	7787
19523	8166	7952
14128	8167	6143
14128	8167	6495
14128	8167	4901
14128	8167	5609
14128	8167	5101
14128	8167	1537
14128	8167	3249
12037	8168	1530
12037	8168	9100
12037	8168	1414
12037	8168	2341
12037	8168	5745
12037	8168	6429
12037	8168	8676
12037	8168	6037
1873	8169	4366
1873	8169	519
1873	8169	2355
1873	8169	6252
7332	8170	1981
7332	8170	5020
14721	8171	8859
14721	8171	6988
14721	8171	1759
14721	8171	2705
6426	8172	8822
6426	8172	4229
6426	8172	8877
6426	8172	5527
6426	8172	4146
6426	8172	9978
6426	8172	9945
6426	8172	9521
4560	8173	1468
4560	8173	8751
2910	8174	4668
2910	8174	5275
2910	8174	3296
2910	8174	4666
2910	8174	9983
2910	8174	836
2910	8174	8379
16646	8175	6912
16646	8175	2056
16646	8175	9385
16646	8175	9852
16646	8175	6749
16646	8175	9591
16646	8175	9788
16646	8175	8531
16646	8175	7748
4826	8176	2606
4826	8176	8678
4826	8176	5647
4826	8176	9307
4826	8176	8709
1529	8177	4288
1529	8177	7147
1529	8177	8796
1529	8177	1381
1529	8177	995
1529	8177	3647
1529	8177	1737
1529	8177	1155
1529	8177	2761
2875	8178	371
2875	8178	7674
2875	8178	268
2875	8178	9844
2875	8178	6310
2875	8178	2330
2252	8179	9710
2252	8179	6458
2252	8179	9928
2252	8179	1568
2252	8179	3930
2252	8179	4842
19169	8180	3635
19169	8180	5214
19169	8180	5686
19169	8180	276
19169	8180	9188
19169	8180	5450
11283	8181	6828
11283	8181	6795
11283	8181	5553
11283	8181	7836
5354	8182	2262
5354	8182	4589
5354	8182	3081
5354	8182	9798
5354	8182	4860
5354	8182	761
5354	8182	2678
5354	8182	8402
18604	8183	6661
18604	8183	5434
18604	8183	5004
18604	8183	1694
18604	8183	5946
18604	8183	6148
18604	8183	367
18604	8183	4103
7801	8184	3974
7801	8184	9446
7801	8184	9184
7801	8184	3059
7801	8184	7149
7617	8185	6021
7617	8185	8417
7617	8185	2245
7617	8185	3387
7617	8185	2570
13346	8186	573
13346	8186	5065
13346	8186	2385
13346	8186	1197
13346	8186	2356
13346	8186	2604
13346	8186	7161
13346	8186	3313
13346	8186	7466
11765	8187	246
11765	8187	1896
11765	8187	4186
11765	8187	9488
122	8188	4607
122	8188	264
122	8188	4748
122	8188	59
122	8188	2124
122	8188	9669
14268	8189	3017
14268	8189	8691
14268	8189	2250
14268	8189	6077
14268	8189	1611
4600	8190	8054
4600	8190	1797
4600	8190	6036
4600	8190	938
4600	8190	3895
4600	8190	3314
4600	8190	8498
4600	8190	697
7427	8191	6975
7427	8191	1706
6631	8192	5615
6631	8192	207
4006	8193	8547
4883	8194	6005
4883	8194	7155
4883	8194	7751
4883	8194	414
4883	8194	700
4883	8194	169
4883	8194	440
4883	8194	5721
4883	8194	5529
11471	8195	7739
11471	8195	8275
11471	8195	9914
11471	8195	8727
11471	8195	4789
11471	8195	382
11471	8195	1432
3691	8196	9234
3691	8196	4630
3691	8196	5074
1205	8197	6338
1205	8197	9791
16130	8198	2940
16130	8198	9491
16130	8198	3818
16130	8198	9672
2392	8199	3421
2392	8199	104
2392	8199	6002
2392	8199	8400
2392	8199	5779
2392	8199	6753
2392	8199	6773
2392	8199	6193
2392	8199	4609
15096	8200	5277
15096	8200	3405
15096	8200	4706
15096	8200	6144
19127	8201	7613
12024	8202	6096
12024	8202	3550
19484	8203	6295
19484	8203	4311
19484	8203	894
19484	8203	1392
19484	8203	4535
19484	8203	5704
19484	8203	7898
12050	8204	154
12050	8204	3865
12050	8204	3646
12050	8204	4623
12050	8204	2829
12050	8204	6937
12050	8204	3541
12050	8204	3507
8800	8205	8697
8800	8205	2655
8800	8205	2649
8800	8205	480
8800	8205	6577
8800	8205	743
9215	8206	4568
9215	8206	92
9215	8206	7142
1364	8207	8533
1364	8207	1449
1364	8207	1983
1364	8207	7942
1364	8207	4546
1364	8207	5189
1364	8207	3481
8446	8208	8830
8446	8208	4210
8601	8209	1329
8601	8209	2425
1915	8210	6928
1915	8210	2978
1915	8210	3634
17644	8211	588
17644	8211	3163
17644	8211	5925
17644	8211	3319
17644	8211	5390
17644	8211	4434
17644	8211	9664
17644	8211	519
17644	8211	7351
8730	8212	3361
8730	8212	4842
8730	8212	5235
8730	8212	5817
8730	8212	9242
8730	8212	2395
8730	8212	5486
8730	8212	4397
8730	8212	8453
5772	8213	8649
5772	8213	8476
5772	8213	8392
5772	8213	364
5772	8213	1494
5772	8213	838
12146	8214	3856
12146	8214	2939
12146	8214	8281
12146	8214	4569
12146	8214	7228
12146	8214	2464
16866	8215	4921
16866	8215	555
16866	8215	337
16866	8215	6438
16866	8215	4644
10724	8216	1898
10724	8216	678
10724	8216	3455
10724	8216	3259
10724	8216	1636
8197	8217	2531
8197	8217	1506
8197	8217	3596
8197	8217	764
8197	8217	2979
8197	8217	5762
8197	8217	4478
15652	8218	5030
15652	8218	9717
15652	8218	8363
15652	8218	6507
15652	8218	3462
15803	8219	2681
15803	8219	4079
15803	8219	8068
15803	8219	209
15803	8219	2044
15803	8219	8668
3304	8220	6533
3304	8220	8027
3304	8220	7862
3304	8220	9224
3304	8220	6387
3304	8220	1919
3304	8220	587
3304	8220	7110
2377	8221	6031
16149	8222	4596
17885	8223	8320
17885	8223	4641
17885	8223	8656
17885	8223	549
17885	8223	6550
17885	8223	5526
17885	8223	8887
17885	8223	404
19895	8224	9700
19895	8224	7928
19895	8224	3553
19895	8224	1039
19895	8224	1466
19895	8224	3804
19895	8224	7546
19895	8224	5966
19895	8224	2308
17714	8225	5993
17714	8225	9404
17714	8225	9180
17714	8225	6344
17714	8225	3081
17714	8225	4331
17714	8225	1464
5004	8226	7781
5004	8226	4782
5004	8226	5544
5004	8226	1527
5004	8226	7262
12486	8227	4110
12486	8227	9097
12486	8227	2169
10497	8228	6257
10497	8228	6490
10497	8228	5450
10497	8228	4785
10497	8228	6885
10497	8228	8556
10497	8228	314
10497	8228	279
13974	8229	9688
13974	8229	1333
13974	8229	1217
10983	8230	4097
10983	8230	8656
10983	8230	4793
10983	8230	371
10983	8230	7336
10983	8230	9143
18912	8231	7032
18912	8231	6949
18912	8231	1215
18912	8231	8777
18912	8231	5420
18912	8231	6048
18912	8231	5485
18912	8231	5353
18912	8231	9801
9187	8232	4170
6625	8233	2769
6625	8233	7437
6625	8233	6137
6625	8233	649
6625	8233	1021
6625	8233	9898
6625	8233	9418
9804	8234	4483
9804	8234	5447
7121	8235	9009
7121	8235	2617
7121	8235	451
7121	8235	7661
7121	8235	5185
7121	8235	2273
7121	8235	1148
7121	8235	5258
7121	8235	9734
11637	8236	7256
11637	8236	8273
11637	8236	8708
11637	8236	6262
11637	8236	2712
11637	8236	6869
11637	8236	5620
6560	8237	7077
6560	8237	1730
6560	8237	772
6560	8237	9270
6560	8237	1663
6560	8237	6324
7158	8238	6281
7158	8238	5669
7158	8238	7899
9534	8239	2086
9534	8239	6712
9534	8239	320
9534	8239	4771
11085	8240	6048
11085	8240	7541
3060	8241	3792
3060	8241	1243
3060	8241	4773
3060	8241	7841
3060	8241	3909
3060	8241	6018
3060	8241	5972
12582	8242	8340
12582	8242	3599
12582	8242	9811
12582	8242	8075
12582	8242	2018
12582	8242	8881
12582	8242	7250
12582	8242	198
9941	8243	7556
9941	8243	1523
9941	8243	7537
9941	8243	6304
9941	8243	3785
9941	8243	8879
9941	8243	1351
9941	8243	9501
9941	8243	2125
8283	8244	2109
8283	8244	65
8283	8244	3330
8283	8244	7276
8283	8244	2171
8283	8244	2505
8283	8244	8406
9418	8245	7531
9418	8245	7096
9418	8245	2220
9418	8245	43
9418	8245	4172
3521	8246	6598
19855	8247	891
6791	8248	3436
6791	8248	8121
6791	8248	228
6791	8248	4041
12521	8249	604
12521	8249	3128
12521	8249	9851
12521	8249	9683
12521	8249	5086
6587	8250	3672
6587	8250	661
6587	8250	1176
6587	8250	2999
6587	8250	8396
6587	8250	4948
6587	8250	549
8935	8251	2558
8935	8251	8390
8935	8251	6255
8935	8251	8857
8935	8251	654
8935	8251	4634
8935	8251	2498
8935	8251	1174
8935	8251	6047
18090	8252	2271
18090	8252	8087
18090	8252	6071
18090	8252	7287
18090	8252	6084
18090	8252	7304
7117	8253	4899
19063	8254	7837
19063	8254	1999
19063	8254	129
19063	8254	2928
19063	8254	4905
19063	8254	8365
19063	8254	8017
19063	8254	9774
11714	8255	330
11714	8255	5420
635	8256	9849
635	8256	3692
635	8256	460
635	8256	1568
635	8256	4944
19695	8257	2839
5224	8258	8469
5224	8258	1579
5224	8258	5561
5224	8258	1672
5224	8258	7316
5224	8258	8923
5224	8258	423
5224	8258	4849
5224	8258	8305
6495	8259	3095
6495	8259	4559
6495	8259	8311
6495	8259	8545
14028	8260	5812
14968	8261	5227
14968	8261	2494
14968	8261	652
14968	8261	6532
14968	8261	3759
9337	8262	5271
9337	8262	1232
9337	8262	6111
9337	8262	4904
9337	8262	6790
5204	8263	86
5204	8263	9906
5204	8263	6584
5204	8263	962
5204	8263	9742
6999	8264	8168
6999	8264	3694
6999	8264	3719
6999	8264	7019
6999	8264	4702
6999	8264	5377
6999	8264	6310
6999	8264	4093
8357	8265	9491
8357	8265	8821
8357	8265	8106
8357	8265	7944
8357	8265	2061
8357	8265	2692
12770	8266	1310
12770	8266	4314
12770	8266	2606
12770	8266	7503
12770	8266	1630
16291	8267	4567
16291	8267	9812
16291	8267	5715
16291	8267	1950
16291	8267	2213
16291	8267	7097
16291	8267	4239
16291	8267	1290
16291	8267	2346
13319	8268	6350
13319	8268	108
9526	8269	3705
9526	8269	8743
9526	8269	4078
9526	8269	1432
7289	8270	8549
7289	8270	3075
7289	8270	2179
7289	8270	2438
7289	8270	2080
16857	8271	6407
16857	8271	6829
1065	8272	4048
1065	8272	1547
1065	8272	3326
1065	8272	9124
1065	8272	4876
1065	8272	7638
1065	8272	7511
19896	8273	996
19896	8273	3878
19896	8273	4606
19896	8273	3023
19896	8273	2815
12071	8274	3334
12071	8274	1493
12071	8274	9668
12071	8274	23
12071	8274	8288
12071	8274	2492
11723	8275	1311
11723	8275	599
11723	8275	4897
11723	8275	5472
11723	8275	6637
11723	8275	9288
11723	8275	4321
11723	8275	4615
12215	8276	6723
12215	8276	1960
12215	8276	1997
12215	8276	809
12215	8276	313
12215	8276	7532
12215	8276	3296
16386	8277	6112
16386	8277	567
16386	8277	8571
6372	8278	9293
12031	8279	1026
3669	8280	8389
3669	8280	6655
3669	8280	8321
3669	8280	9878
3669	8280	5746
12624	8281	1199
7481	8282	596
7481	8282	8686
7481	8282	4003
17445	8283	3755
17445	8283	7825
17445	8283	1620
17445	8283	3875
17445	8283	7798
17445	8283	7486
17445	8283	5932
14261	8284	871
14261	8284	5660
14261	8284	2562
13128	8285	5287
13128	8285	5858
13128	8285	5536
13128	8285	9451
13128	8285	9828
13128	8285	8653
13128	8285	2945
13128	8285	7044
13311	8286	9644
13311	8286	7243
13311	8286	8342
13311	8286	9648
13311	8286	6368
13311	8286	9817
13311	8286	9306
13311	8286	695
291	8287	3470
291	8287	6809
291	8287	6787
291	8287	5290
291	8287	508
291	8287	212
291	8287	8171
291	8287	5455
291	8287	7259
7252	8288	5280
7252	8288	3597
7252	8288	2953
7252	8288	6120
7252	8288	2138
7252	8288	5597
7252	8288	6003
7252	8288	2800
6614	8289	3459
6614	8289	1847
6614	8289	7271
6614	8289	4017
5645	8290	934
5645	8290	3984
5645	8290	9846
5645	8290	8835
5645	8290	9692
5645	8290	929
5645	8290	6815
5645	8290	6987
19149	8291	333
15207	8292	2979
15207	8292	6246
15207	8292	7078
15207	8292	3167
6024	8293	4995
6024	8293	4332
6024	8293	6550
6024	8293	9651
6024	8293	2142
6024	8293	3111
6024	8293	7179
6024	8293	4763
6024	8293	1048
8051	8294	300
8051	8294	3432
8051	8294	8308
8051	8294	6478
8051	8294	4396
8051	8294	326
13751	8295	412
13751	8295	3731
13751	8295	9542
13751	8295	6966
13751	8295	7495
13751	8295	5405
13751	8295	2039
4676	8296	5805
4676	8296	1682
4676	8296	597
4676	8296	3755
4676	8296	4804
4676	8296	7798
4676	8296	8196
3852	8297	2836
3852	8297	536
3852	8297	6710
3852	8297	7831
3852	8297	1514
3852	8297	1086
13779	8298	9172
5853	8299	4076
5853	8299	6010
5399	8300	8932
5399	8300	3411
5399	8300	7361
5399	8300	5408
5399	8300	8868
19905	8301	6842
19905	8301	6001
19905	8301	2767
19905	8301	8940
19905	8301	3864
19747	8302	2573
19747	8302	2216
19747	8302	6515
19747	8302	972
19747	8302	5746
19747	8302	9067
19747	8302	3300
9105	8303	1264
9105	8303	7420
12720	8304	9375
12720	8304	3660
12720	8304	5792
12720	8304	4144
1315	8305	4533
1315	8305	5087
1315	8305	3992
1315	8305	9443
1315	8305	2939
1315	8305	9963
1315	8305	8228
1315	8305	8232
4010	8306	296
4010	8306	7778
4010	8306	1828
19128	8307	8272
19128	8307	7107
19128	8307	709
19128	8307	1744
19128	8307	9654
19128	8307	987
19128	8307	8884
14230	8308	9120
18830	8309	5502
18830	8309	3555
12265	8310	3242
12265	8310	7914
12265	8310	5528
12265	8310	4103
12265	8310	4338
6441	8311	336
6441	8311	2535
12782	8312	8025
12782	8312	2580
12782	8312	3968
12782	8312	7712
12782	8312	3421
12782	8312	5723
2500	8313	6431
2500	8313	4096
2500	8313	8548
2500	8313	3022
2500	8313	64
2500	8313	8338
2500	8313	1947
2500	8313	6888
2500	8313	1578
11090	8314	6837
11090	8314	216
11090	8314	3087
11090	8314	3809
11090	8314	4126
11090	8314	9404
11090	8314	1467
11090	8314	6619
11090	8314	6835
10343	8315	2378
10343	8315	1964
7029	8316	2777
7029	8316	4150
7029	8316	8895
5407	8317	2943
5407	8317	460
5407	8317	8667
11001	8318	672
11001	8318	935
11001	8318	6071
11001	8318	7005
11001	8318	6412
11001	8318	2533
11001	8318	2840
11001	8318	2182
11001	8318	3919
10460	8319	5945
10460	8319	1791
10460	8319	71
10460	8319	112
10460	8319	9633
10460	8319	5304
10460	8319	3833
1675	8320	7342
1675	8320	9064
1675	8320	725
1675	8320	1916
1675	8320	1539
1675	8320	9873
1675	8320	3736
1675	8320	7064
1675	8320	429
1080	8321	1324
1080	8321	6414
1080	8321	7643
1080	8321	5993
1080	8321	9752
1080	8321	3195
7838	8322	8562
7838	8322	1786
7838	8322	5670
7838	8322	4252
7838	8322	1047
14524	8323	3109
19045	8324	9400
19045	8324	3895
19045	8324	1026
19045	8324	7967
19045	8324	1008
19138	8325	8003
19138	8325	7278
16648	8326	5586
16648	8326	8726
16648	8326	8696
16648	8326	8217
16648	8326	569
16648	8326	8085
16648	8326	6767
16648	8326	1553
5120	8327	2129
5120	8327	5380
5120	8327	7679
5120	8327	2386
18639	8328	1473
18639	8328	5260
18639	8328	8151
18639	8328	561
18639	8328	1091
18639	8328	3183
9471	8329	7296
9471	8329	5029
816	8330	3065
816	8330	1117
816	8330	1261
816	8330	610
816	8330	7041
10383	8331	3911
10383	8331	2107
10383	8331	8291
10383	8331	1829
18248	8332	8549
18248	8332	6705
18248	8332	9370
18248	8332	46
18248	8332	3813
18248	8332	5202
4484	8333	7434
4484	8333	399
4484	8333	70
4484	8333	8437
4484	8333	2367
4484	8333	9239
4484	8333	9390
15876	8334	6042
15876	8334	6404
15876	8334	9280
15876	8334	7393
15876	8334	4639
15876	8334	6724
8313	8335	5500
8313	8335	1273
8313	8335	2994
8313	8335	4203
8313	8335	7275
8313	8335	7699
8313	8335	1530
8313	8335	3841
489	8336	461
489	8336	9679
489	8336	2482
489	8336	30
489	8336	559
12117	8337	9996
8396	8338	7790
8396	8338	9011
5704	8339	3097
5704	8339	393
5704	8339	1600
5704	8339	8657
5704	8339	6473
14062	8340	3089
14062	8340	5442
14062	8340	4734
14062	8340	7282
14062	8340	1778
1577	8341	3641
13473	8342	293
13473	8342	6278
13473	8342	7513
13473	8342	7637
13473	8342	9781
13473	8342	6994
4871	8343	2408
4871	8343	7351
4871	8343	8307
4871	8343	4973
4871	8343	9313
4871	8343	3979
4871	8343	5349
4871	8343	1333
15220	8344	360
15220	8344	9198
15220	8344	3146
15220	8344	3009
15220	8344	8627
15220	8344	4736
15220	8344	2197
1007	8345	3201
14359	8346	2990
14359	8346	9794
14359	8346	4161
14359	8346	8984
16361	8347	4372
16361	8347	6332
16361	8347	6631
16361	8347	4031
16361	8347	3154
16361	8347	9331
16361	8347	9439
16361	8347	4024
16361	8347	9710
5399	8348	4930
5399	8348	6573
6370	8349	2944
6370	8349	6801
6370	8349	9461
6370	8349	342
6370	8349	2259
6370	8349	2740
6370	8349	7428
6370	8349	4121
6370	8349	419
5624	8350	4999
5624	8350	6438
5624	8350	5371
5624	8350	4756
5624	8350	43
5624	8350	3927
6776	8351	6879
6776	8351	811
6776	8351	4122
6776	8351	1796
6776	8351	9690
6776	8351	2072
6776	8351	5027
51	8352	1596
51	8352	4215
51	8352	2892
13637	8353	207
14171	8354	6704
14171	8354	7389
14171	8354	6267
14171	8354	714
14171	8354	7461
14171	8354	6938
14171	8354	5765
14171	8354	7633
14171	8354	2425
10634	8355	2136
10634	8355	8788
10634	8355	8577
10634	8355	9427
10634	8355	6278
10634	8355	507
10634	8355	4629
10684	8356	1082
10684	8356	2532
10684	8356	9045
10684	8356	4207
10684	8356	2012
10684	8356	6787
10684	8356	5682
10684	8356	5319
7790	8357	6376
13765	8358	3656
13765	8358	6789
15740	8359	4716
15740	8359	3184
15740	8359	1329
16230	8360	7037
16230	8360	6991
16230	8360	2524
17799	8361	5782
17799	8361	7254
17799	8361	283
17799	8361	8203
17799	8361	1912
17799	8361	3791
13948	8362	2169
10957	8363	4108
10957	8363	3656
10957	8363	487
10957	8363	5531
10957	8363	8450
11405	8364	9744
11405	8364	5998
11405	8364	7970
11405	8364	8281
11405	8364	6762
17860	8365	4408
17860	8365	728
17860	8365	3026
17860	8365	5146
17860	8365	7026
10949	8366	1177
10949	8366	630
10949	8366	1688
10949	8366	2575
10949	8366	6415
6351	8367	2105
6351	8367	8925
6351	8367	2026
6351	8367	5028
346	8368	849
5672	8369	5572
5672	8369	8631
5672	8369	1678
5672	8369	6917
5672	8369	2061
5672	8369	1268
5672	8369	6972
11792	8370	5548
11792	8370	4723
11792	8370	5085
11792	8370	641
11792	8370	2305
11792	8370	8770
11792	8370	4885
11792	8370	1778
11792	8370	1601
17034	8371	1935
17034	8371	3526
17034	8371	6187
17034	8371	4803
17034	8371	843
17034	8371	983
17034	8371	9932
1144	8372	7746
1144	8372	7880
19316	8373	3114
19316	8373	5230
19316	8373	7646
19316	8373	7476
19316	8373	6071
19316	8373	2343
19316	8373	9733
1431	8374	6784
1431	8374	1726
18942	8375	2102
18942	8375	6289
18942	8375	1380
18942	8375	9111
18942	8375	4063
18942	8375	3773
19686	8376	716
3877	8377	3092
3877	8377	9801
17103	8378	5183
2942	8379	873
2942	8379	3424
2942	8379	503
2942	8379	6472
2942	8379	7040
2942	8379	8701
2942	8379	6602
4496	8380	4678
4496	8380	7602
4496	8380	2710
15783	8381	9362
15783	8381	8912
4671	8382	9532
4671	8382	5592
4671	8382	3310
4671	8382	4326
4671	8382	6447
4671	8382	2159
4671	8382	6803
8808	8383	6293
8808	8383	5563
8808	8383	1485
8808	8383	7483
8808	8383	5159
8808	8383	2732
8808	8383	1303
13789	8384	1187
13789	8384	5188
13789	8384	7177
13789	8384	8437
13789	8384	4183
13820	8385	6298
13820	8385	9245
13820	8385	1559
13820	8385	8179
13820	8385	869
4344	8386	9067
4344	8386	4288
4344	8386	5164
4344	8386	7886
4344	8386	6821
4344	8386	6319
4344	8386	9722
4344	8386	7913
4344	8386	9376
17240	8387	5348
17240	8387	5701
17240	8387	1081
17240	8387	8388
17240	8387	1755
17240	8387	6259
17240	8387	7707
17240	8387	5516
17240	8387	3763
162	8388	4782
162	8388	2428
19705	8389	8836
19705	8389	7624
19705	8389	4340
19705	8389	7280
19705	8389	2956
19705	8389	182
19705	8389	5076
1184	8390	2929
1184	8390	4479
1184	8390	7030
1184	8390	7519
5960	8391	433
5960	8391	4317
5960	8391	2681
5960	8391	6759
5960	8391	1383
5960	8391	8995
8141	8392	4663
8141	8392	3963
8141	8392	8325
8141	8392	3858
8141	8392	7702
8141	8392	4812
8141	8392	4356
8141	8392	7312
8141	8392	2266
9892	8393	4907
9892	8393	9317
9892	8393	3228
9892	8393	7972
9892	8393	7810
9892	8393	5610
9892	8393	224
9892	8393	215
9892	8393	9289
8200	8394	8220
8200	8394	4602
8200	8394	7973
8200	8394	5431
8200	8394	7049
8200	8394	9920
8200	8394	4239
8200	8394	4611
8200	8394	5827
2872	8395	5371
2872	8395	9149
2872	8395	2324
2872	8395	8759
2872	8395	4420
18042	8396	6467
18042	8396	3931
18042	8396	3232
18042	8396	9880
18042	8396	6999
18042	8396	9680
9047	8397	9591
17478	8398	3345
17478	8398	9192
17478	8398	28
17478	8398	6785
17478	8398	2571
17478	8398	386
17478	8398	6766
17478	8398	352
14700	8399	175
8870	8400	4066
8870	8400	3620
8870	8400	2493
8870	8400	1404
8870	8400	4729
3027	8401	4764
3027	8401	7650
16003	8402	5351
16003	8402	4779
16003	8402	7353
16003	8402	9961
8051	8403	2381
8051	8403	5534
8051	8403	5335
8051	8403	5216
8051	8403	1775
8051	8403	5061
8051	8403	3445
8051	8403	8068
12483	8404	5550
12483	8404	1587
12483	8404	5228
12483	8404	9403
12483	8404	5573
12483	8404	8746
8559	8405	4541
8559	8405	3458
8559	8405	1090
8559	8405	2855
8559	8405	1228
8559	8405	904
8559	8405	7164
8559	8405	8000
8559	8405	6443
3342	8406	1848
3342	8406	5578
3342	8406	4658
3342	8406	4873
3342	8406	9335
5585	8407	1311
5585	8407	8972
5585	8407	9506
5585	8407	4477
4952	8408	2062
4952	8408	9272
4952	8408	13
4952	8408	9900
4952	8408	1713
4952	8408	5379
4952	8408	953
8599	8409	8737
8599	8409	312
19635	8410	6487
19635	8410	8307
19635	8410	6341
19635	8410	865
19635	8410	3563
19635	8410	6733
16891	8411	5031
16891	8411	6559
8128	8412	2880
8128	8412	9714
14591	8413	6036
14591	8413	5242
14591	8413	8739
14591	8413	7990
14591	8413	6983
14591	8413	5764
14591	8413	3167
14591	8413	5295
14591	8413	2755
12050	8414	8032
12050	8414	5053
15877	8415	7311
15877	8415	1466
15877	8415	3453
2883	8416	6163
2883	8416	9090
2883	8416	2053
2883	8416	7527
2883	8416	6238
2883	8416	831
17725	8417	6608
17725	8417	1727
17725	8417	7077
17725	8417	2724
12352	8418	7618
7560	8419	3109
7560	8419	9363
7560	8419	6381
7560	8419	7387
7560	8419	7754
17409	8420	2686
17409	8420	4329
17409	8420	675
4528	8421	2511
4528	8421	8303
4528	8421	4626
4528	8421	3376
4528	8421	9399
4528	8421	8369
4528	8421	8338
12183	8422	4796
12183	8422	1745
12183	8422	3426
12183	8422	7242
12183	8422	3126
12183	8422	6364
12183	8422	2595
12183	8422	7201
12183	8422	7273
1298	8423	3387
1298	8423	3901
1298	8423	3683
1298	8423	7816
1298	8423	5955
1298	8423	7349
1298	8423	92
1298	8423	3773
13796	8424	3253
13796	8424	112
14768	8425	8033
14768	8425	3215
14768	8425	9764
14768	8425	3144
14768	8425	4006
19921	8426	7660
19921	8426	7129
19921	8426	995
19921	8426	8330
19921	8426	3240
19921	8426	9347
11435	8427	811
11435	8427	6149
11435	8427	187
11435	8427	1141
10292	8428	5107
10292	8428	4720
10292	8428	1521
10292	8428	4198
10292	8428	3850
10292	8428	6389
10292	8428	4109
10292	8428	440
2350	8429	9942
2350	8429	6289
2350	8429	2517
3750	8430	240
3750	8430	5605
3750	8430	446
3750	8430	6807
3750	8430	9641
3750	8430	7170
3750	8430	7746
16372	8431	9361
16372	8431	5481
16372	8431	4480
13993	8432	8872
13993	8432	633
13993	8432	9452
19796	8433	4541
3421	8434	2989
3421	8434	7464
3421	8434	4013
3421	8434	8286
3421	8434	6126
3421	8434	1262
3421	8434	9762
3421	8434	8442
3421	8434	2230
3364	8435	1580
3364	8435	2689
8442	8436	3499
1924	8437	7786
1924	8437	5013
1924	8437	2280
1924	8437	9465
1924	8437	6733
17926	8438	645
17926	8438	230
17926	8438	969
17926	8438	8345
17926	8438	7140
17926	8438	3358
17926	8438	6995
17926	8438	1600
18770	8439	3295
18770	8439	1672
18770	8439	2058
18770	8439	667
18770	8439	7367
16023	8440	236
16023	8440	4296
2870	8441	2073
2870	8441	1780
2870	8441	9973
2870	8441	3057
2870	8441	7561
2870	8441	7728
2870	8441	9111
19555	8442	7426
19555	8442	3015
19555	8442	5041
19555	8442	8278
19555	8442	1830
13169	8443	8334
13169	8443	6516
13169	8443	2695
512	8444	9488
512	8444	3529
512	8444	4812
512	8444	2127
10283	8445	8391
10283	8445	4085
10283	8445	9716
10283	8445	6804
10283	8445	7700
8430	8446	3787
8430	8446	1949
2873	8447	8561
2873	8447	2779
2873	8447	1791
2873	8447	5829
2873	8447	7235
2873	8447	9275
2873	8447	4439
2485	8448	6380
2485	8448	8089
2485	8448	8146
2485	8448	9285
4979	8449	9224
4979	8449	5883
4979	8449	778
4979	8449	4488
4979	8449	9068
4979	8449	824
10524	8450	6504
10524	8450	3090
10524	8450	1242
10524	8450	2708
10524	8450	3055
10524	8450	9482
10524	8450	4482
10524	8450	968
10524	8450	1102
3758	8451	8484
18616	8452	4570
18616	8452	4171
18616	8452	4053
18616	8452	3957
18616	8452	8439
2987	8453	6133
2987	8453	5175
2987	8453	6842
2987	8453	3951
16950	8454	2067
16950	8454	5947
16950	8454	9608
16950	8454	3264
16950	8454	1590
16950	8454	1038
18954	8455	970
18954	8455	1455
18954	8455	4004
18954	8455	4203
18954	8455	2906
18954	8455	3391
18954	8455	6628
17387	8456	2693
17387	8456	4162
17387	8456	4168
17387	8456	3273
11765	8457	3174
11765	8457	4374
11765	8457	2755
11765	8457	1258
8327	8458	5224
8327	8458	8742
8327	8458	430
6245	8459	9079
4701	8460	8233
4701	8460	1285
4701	8460	9621
4701	8460	6035
4701	8460	4034
4701	8460	9332
4701	8460	1455
13358	8461	9603
13358	8461	4132
13358	8461	9730
13358	8461	6902
13358	8461	8127
14828	8462	1383
14828	8462	797
14828	8462	8102
14828	8462	3378
14828	8462	4123
14828	8462	5391
14828	8462	7149
14828	8462	2256
14828	8462	5864
19991	8463	4041
19991	8463	8470
19991	8463	8313
19991	8463	9582
19991	8463	9019
19991	8463	1917
19991	8463	1967
19991	8463	6645
19991	8463	2155
15090	8464	8801
15090	8464	8528
15090	8464	458
15090	8464	4660
15090	8464	8123
13185	8465	6220
13185	8465	1202
6238	8466	3138
6238	8466	8724
6238	8466	2465
6238	8466	2837
3275	8467	6302
1922	8468	9662
1922	8468	3680
1922	8468	1500
1922	8468	978
1922	8468	5138
1922	8468	5821
1922	8468	5770
8985	8469	1269
8985	8469	3160
8985	8469	8723
8985	8469	3751
5432	8470	9804
5432	8470	4558
5432	8470	6175
5432	8470	3384
5432	8470	8759
9158	8471	3537
9158	8471	9804
9158	8471	4951
9158	8471	4872
9158	8471	4318
16137	8472	784
16137	8472	1901
16137	8472	250
16137	8472	4072
16137	8472	2516
16137	8472	3577
16137	8472	5977
9376	8473	5288
9376	8473	7176
9376	8473	9307
9376	8473	8350
9376	8473	5642
9376	8473	1692
9376	8473	4142
9376	8473	8864
9376	8473	3064
14269	8474	4590
14269	8474	6291
14269	8474	2235
14269	8474	5254
14269	8474	1534
17419	8475	757
17419	8475	1829
17419	8475	6156
17419	8475	658
17419	8475	5997
17419	8475	6341
17419	8475	8636
17419	8475	6195
1567	8476	1349
13204	8477	7142
13204	8477	2536
13204	8477	3292
13204	8477	7049
6408	8478	3502
19684	8479	8684
19684	8479	2678
19684	8479	675
19684	8479	2690
19684	8479	1489
19684	8479	8625
19684	8479	8809
19684	8479	2762
12105	8480	1173
19627	8481	4451
19627	8481	7283
19627	8481	3048
19627	8481	8039
19627	8481	8507
19627	8481	1692
19627	8481	737
18724	8482	5129
18724	8482	6331
18724	8482	9668
18724	8482	9552
18724	8482	5292
19929	8483	4508
19929	8483	3252
19929	8483	4181
19929	8483	3280
19929	8483	4
1482	8484	103
10463	8485	4048
10463	8485	2345
15272	8486	7601
15272	8486	8885
15272	8486	6236
15272	8486	9662
5883	8487	7912
5883	8487	4171
5883	8487	7048
5883	8487	5066
15371	8488	9973
15371	8488	7152
15371	8488	3455
15371	8488	6882
11533	8489	7903
11533	8489	8915
11533	8489	5766
11533	8489	4759
11533	8489	9003
11533	8489	9739
11533	8489	3204
11533	8489	8146
3240	8490	7439
3240	8490	5563
3240	8490	7655
19835	8491	8416
19835	8491	7935
19835	8491	7442
19835	8491	9348
19835	8491	7378
14232	8492	1920
14232	8492	7042
14232	8492	4165
14232	8492	6871
4865	8493	4877
4865	8493	4286
4865	8493	9556
4865	8493	9200
13283	8494	8842
13283	8494	7729
13283	8494	5684
13283	8494	4304
13283	8494	4674
13283	8494	2012
13283	8494	4647
13283	8494	442
13283	8494	1314
12381	8495	9278
16955	8496	5119
16955	8496	2126
16955	8496	4188
19744	8497	7475
19744	8497	9580
19744	8497	5494
19744	8497	8368
19744	8497	5589
19744	8497	8873
19744	8497	5872
19744	8497	1333
8098	8498	6797
8098	8498	3244
8098	8498	2706
8098	8498	8777
8098	8498	7303
8098	8498	4872
8098	8498	7415
5816	8499	8843
5816	8499	2314
5816	8499	5584
13834	8500	966
13834	8500	4790
13834	8500	5707
13834	8500	6685
13834	8500	5464
13834	8500	5048
13834	8500	6221
7270	8501	6543
7270	8501	4439
13504	8502	4938
13504	8502	9815
13504	8502	4239
18055	8503	7060
5046	8504	5289
5046	8504	4317
5046	8504	542
5046	8504	4640
18157	8505	5831
18157	8505	1947
18157	8505	2643
18157	8505	9039
18157	8505	2541
18157	8505	5909
18157	8505	5211
18157	8505	6309
18157	8505	5491
1558	8506	3611
1558	8506	1963
1558	8506	1528
7994	8507	9568
7994	8507	3926
7994	8507	6452
17985	8508	75
17985	8508	7967
17985	8508	7008
17985	8508	3378
17985	8508	4236
15692	8509	6096
15692	8509	4902
15293	8510	2338
15293	8510	9025
15293	8510	3472
15293	8510	7782
15293	8510	3114
15293	8510	3154
15293	8510	4238
15231	8511	4895
15231	8511	6618
15231	8511	6574
15231	8511	9868
15231	8511	6137
15231	8511	9122
15231	8511	3930
15231	8511	3227
13396	8512	7405
13396	8512	5885
13396	8512	5264
13396	8512	720
13396	8512	7738
13396	8512	8572
13396	8512	2218
13396	8512	9250
18234	8513	6232
18234	8513	6759
18234	8513	846
18234	8513	3116
8370	8514	8368
8370	8514	4646
8370	8514	5131
8370	8514	3432
4007	8515	7193
4007	8515	3222
4007	8515	3867
4007	8515	9135
11787	8516	5878
11787	8516	4813
11787	8516	7561
11787	8516	6648
2586	8517	6659
2586	8517	6942
2586	8517	4995
2586	8517	3302
13046	8518	10
5768	8519	6603
5768	8519	4792
4703	8520	8280
4703	8520	8689
4703	8520	8368
4703	8520	831
4703	8520	4219
4703	8520	7751
4703	8520	8012
10587	8521	1710
10587	8521	6937
10587	8521	8572
10587	8521	2209
5913	8522	352
18081	8523	4388
18081	8523	8277
18081	8523	8488
12997	8524	1792
7003	8525	7522
7003	8525	4700
19311	8526	9962
19311	8526	5765
15196	8527	261
15196	8527	5072
15196	8527	1835
15196	8527	5247
15196	8527	1368
15196	8527	9772
7790	8528	6590
7790	8528	7791
7790	8528	1106
7790	8528	4419
7790	8528	3514
7790	8528	5630
7790	8528	7782
7790	8528	2058
14257	8529	8327
19388	8530	5285
19388	8530	7271
19388	8530	7676
19388	8530	3486
9181	8531	5658
2574	8532	4447
2574	8532	6933
2574	8532	4234
2574	8532	4215
2574	8532	5760
2574	8532	2254
2574	8532	1196
2574	8532	4448
2574	8532	9573
6116	8533	7648
6116	8533	9761
6116	8533	2986
6116	8533	4592
6116	8533	9761
6116	8533	5138
6116	8533	2452
6116	8533	415
12348	8534	1008
12348	8534	1721
12348	8534	4147
12348	8534	7579
10334	8535	8697
10334	8535	5304
19792	8536	8934
19792	8536	2390
19792	8536	4223
19792	8536	8052
19792	8536	8979
19792	8536	335
4111	8537	3349
4111	8537	8839
4111	8537	8188
13768	8538	8566
13768	8538	4898
13768	8538	846
13768	8538	3133
13768	8538	5218
6539	8539	5807
6539	8539	5004
6539	8539	5897
6539	8539	6391
6539	8539	3466
3305	8540	8537
3305	8540	1645
3305	8540	3736
3305	8540	5383
3305	8540	374
3305	8540	7817
7712	8541	8874
7712	8541	3216
7712	8541	8693
7712	8541	4322
7712	8541	8357
7712	8541	312
7712	8541	9440
7712	8541	1943
7712	8541	8272
4015	8542	6589
8810	8543	8261
8810	8543	4219
8810	8543	9619
8810	8543	1011
8810	8543	6546
9804	8544	202
9804	8544	3391
9804	8544	536
9804	8544	5730
11716	8545	6360
4903	8546	7404
4903	8546	57
4903	8546	1544
16178	8547	2991
16178	8547	2432
16178	8547	2079
16178	8547	5336
16178	8547	7486
16178	8547	8228
16178	8547	6924
16178	8547	1415
12155	8548	9001
12155	8548	3351
12155	8548	160
12155	8548	125
12155	8548	2983
12155	8548	4220
12155	8548	6044
12155	8548	9166
12155	8548	2474
19920	8549	1116
19920	8549	3265
19920	8549	5774
19920	8549	8607
19920	8549	1855
19920	8549	4646
19920	8549	6665
19920	8549	100
19920	8549	298
9033	8550	1168
9033	8550	7480
9033	8550	2721
9033	8550	3601
9033	8550	7179
9033	8550	778
9033	8550	7246
9033	8550	3058
9033	8550	8059
5408	8551	7509
15612	8552	2323
6979	8553	7131
6979	8553	5279
6979	8553	1581
6979	8553	5447
6979	8553	2901
6979	8553	8911
6979	8553	8544
4007	8554	2128
18082	8555	9268
18082	8555	6852
18082	8555	799
18082	8555	5915
18082	8555	718
4596	8556	4657
4596	8556	6798
4596	8556	2509
4596	8556	536
417	8557	7390
417	8557	8513
417	8557	66
417	8557	9686
417	8557	6633
417	8557	4341
417	8557	8413
417	8557	3741
417	8557	7356
4025	8558	5580
4025	8558	3315
4025	8558	9830
4025	8558	6323
4025	8558	131
4025	8558	9760
4025	8558	6089
4025	8558	6425
6113	8559	5604
18687	8560	6735
18687	8560	5508
18687	8560	891
18687	8560	7128
13913	8561	1150
13913	8561	7236
13913	8561	3639
13913	8561	734
14950	8562	8557
14950	8562	26
14950	8562	8066
14950	8562	8193
14950	8562	4684
11148	8563	9780
11148	8563	9560
11148	8563	5513
5498	8564	6074
5498	8564	3340
5498	8564	9826
16764	8565	3079
2542	8566	4971
2542	8566	2575
2542	8566	6125
2542	8566	1747
2542	8566	6997
2542	8566	6393
2542	8566	9
12164	8567	1253
12164	8567	9710
12164	8567	8568
3292	8568	2917
3292	8568	1649
3292	8568	9706
3292	8568	7646
3292	8568	6576
7145	8569	208
7145	8569	5917
7145	8569	2742
7145	8569	3370
7145	8569	6462
7145	8569	5774
7145	8569	7970
7145	8569	6675
19183	8570	7479
19183	8570	8624
19183	8570	7825
19183	8570	4516
2336	8571	7828
2336	8571	9097
2336	8571	9437
2336	8571	4564
2336	8571	5546
2336	8571	928
2336	8571	8442
2336	8571	9622
2336	8571	7195
9346	8572	9797
9346	8572	9417
9346	8572	1068
9346	8572	5480
6616	8573	3878
6616	8573	8729
6616	8573	6809
6616	8573	8779
6616	8573	7790
6616	8573	5340
5067	8574	7206
5067	8574	8227
5067	8574	4956
5067	8574	1315
13590	8575	103
13590	8575	9260
13590	8575	6717
7051	8576	1262
7051	8576	8420
13668	8577	843
13668	8577	9
13668	8577	3343
13668	8577	6714
13668	8577	987
13668	8577	1452
13668	8577	5542
9603	8578	2790
9603	8578	1371
9603	8578	9152
9603	8578	5104
9603	8578	9233
9603	8578	4406
9603	8578	9350
9603	8578	4707
16097	8579	2705
8313	8580	5710
8313	8580	3920
8313	8580	9603
8313	8580	9196
8313	8580	1762
8313	8580	3605
8313	8580	5919
8313	8580	9432
8313	8580	1204
11820	8581	3959
11820	8581	922
11820	8581	7769
11820	8581	820
11820	8581	3616
11820	8581	155
11820	8581	7771
11820	8581	4245
11820	8581	731
8672	8582	7174
8672	8582	1556
14254	8583	7017
14254	8583	1682
14254	8583	4908
14254	8583	2436
14254	8583	7848
14254	8583	2256
14254	8583	3588
14254	8583	7760
14254	8583	6993
4612	8584	3538
4612	8584	9011
4612	8584	8376
4612	8584	2220
4612	8584	9316
4612	8584	908
4612	8584	7175
19221	8585	5662
19221	8585	6296
19221	8585	3825
19221	8585	7081
19221	8585	2545
19221	8585	3123
19221	8585	7626
19221	8585	5369
7489	8586	6407
7489	8586	3208
7489	8586	7043
7489	8586	3130
9344	8587	8470
9344	8587	4903
9344	8587	6133
9344	8587	3113
9344	8587	2901
9344	8587	4048
18833	8588	3161
18833	8588	8619
18833	8588	9940
18833	8588	6882
18833	8588	2207
4397	8589	7852
5509	8590	4737
5509	8590	7142
5509	8590	4795
5509	8590	8163
5509	8590	606
5509	8590	2336
5509	8590	9220
5509	8590	3335
432	8591	227
432	8591	7185
432	8591	867
432	8591	8063
432	8591	7792
5056	8592	165
5056	8592	9993
5056	8592	4552
5056	8592	3654
5056	8592	4366
5056	8592	7842
5056	8592	2032
5056	8592	7916
16285	8593	3052
16285	8593	7830
16285	8593	2849
9022	8594	3315
9022	8594	3556
9022	8594	6642
9022	8594	3907
9022	8594	4996
9022	8594	3168
9022	8594	5971
7773	8595	2029
7773	8595	1859
7773	8595	1805
7773	8595	6195
7773	8595	5310
7773	8595	9164
7773	8595	7511
7773	8595	1771
7773	8595	5787
19385	8596	7964
19385	8596	7006
19385	8596	7072
19385	8596	7821
19698	8597	4930
19698	8597	1078
12774	8598	9845
12774	8598	697
12774	8598	518
12774	8598	28
12774	8598	6175
12774	8598	3860
12774	8598	608
12774	8598	8073
11787	8599	5743
1343	8600	1795
1343	8600	9713
1343	8600	2390
6171	8601	9568
6171	8601	3396
6171	8601	9932
6171	8601	9881
15908	8602	3848
15908	8602	307
15908	8602	7055
15908	8602	261
15908	8602	5880
15908	8602	6344
15908	8602	5792
15908	8602	5149
15908	8602	1818
2772	8603	7129
2772	8603	3337
2772	8603	7989
2772	8603	4963
2772	8603	904
2772	8603	2545
19199	8604	1772
19199	8604	716
19199	8604	5236
19199	8604	6848
19199	8604	5488
19199	8604	6704
19199	8604	51
19199	8604	4254
15180	8605	9046
15180	8605	5866
15180	8605	7961
15180	8605	1160
15180	8605	8010
15180	8605	5021
15180	8605	4568
15180	8605	7896
15180	8605	2244
15463	8606	5904
15463	8606	1112
15463	8606	638
15463	8606	7748
15463	8606	2442
15463	8606	3977
15463	8606	6743
15804	8607	2825
15804	8607	4509
15804	8607	9054
15804	8607	7196
15804	8607	7148
1111	8608	4014
1111	8608	5091
1111	8608	8167
1111	8608	9478
1111	8608	9632
12748	8609	4276
12748	8609	363
12748	8609	7006
12748	8609	4493
12748	8609	7276
12748	8609	7357
12770	8610	1318
12770	8610	8729
12770	8610	3643
12770	8610	9247
17757	8611	5253
17757	8611	2056
17757	8611	5652
17757	8611	6629
17757	8611	7290
17757	8611	8716
12143	8612	2457
12143	8612	5225
7908	8613	850
7908	8613	9720
7908	8613	8308
7908	8613	4776
7908	8613	8257
7908	8613	3088
19432	8614	837
19432	8614	1104
19432	8614	1351
19432	8614	5527
19432	8614	4057
19432	8614	7582
15528	8615	7194
15528	8615	3910
15528	8615	9623
15528	8615	9061
15528	8615	5517
9532	8616	1306
9532	8616	3630
9532	8616	6347
9532	8616	2501
9532	8616	8788
9532	8616	2626
9532	8616	3569
9532	8616	4133
2652	8617	6827
2652	8617	5481
2652	8617	8012
2652	8617	8035
2652	8617	5763
2652	8617	8149
2652	8617	2600
17892	8618	820
17892	8618	8533
4203	8619	9282
4203	8619	7373
4203	8619	457
4203	8619	9925
4203	8619	86
4203	8619	6935
5393	8620	9764
5393	8620	7661
5393	8620	9564
5393	8620	1218
5393	8620	9965
5393	8620	3828
9205	8621	8264
9205	8621	924
1697	8622	8785
1697	8622	7702
1697	8622	4289
1697	8622	2402
1697	8622	6339
1697	8622	3294
1697	8622	4481
1697	8622	6285
1697	8622	4261
12223	8623	7244
12223	8623	9547
12223	8623	1699
12223	8623	9017
15601	8624	4320
15601	8624	2045
15601	8624	6291
15601	8624	6783
15601	8624	4285
15601	8624	4094
16709	8625	4466
16709	8625	6282
11657	8626	4871
6988	8627	9818
6988	8627	6617
6988	8627	7733
6988	8627	245
9059	8628	5098
9059	8628	4940
9059	8628	3520
9059	8628	1174
9059	8628	1114
9059	8628	5630
999	8629	3994
999	8629	427
999	8629	7591
999	8629	5674
999	8629	9952
999	8629	9839
11233	8630	7104
11233	8630	1324
11233	8630	3372
11233	8630	424
11233	8630	2044
3325	8631	7711
3325	8631	1938
3325	8631	4357
3325	8631	5181
3325	8631	4851
9378	8632	306
9378	8632	1941
9378	8632	569
9378	8632	8031
9378	8632	5762
9378	8632	8425
7803	8633	9262
2398	8634	727
2398	8634	5990
2398	8634	5628
2398	8634	267
2398	8634	8334
2398	8634	9804
746	8635	4313
746	8635	4465
746	8635	7104
746	8635	6639
746	8635	31
746	8635	3748
18125	8636	9558
18125	8636	3402
18125	8636	5523
18125	8636	8388
18125	8636	4240
18125	8636	4130
18125	8636	8564
18125	8636	8230
5390	8637	1667
5390	8637	640
5390	8637	8152
5390	8637	3332
1854	8638	4512
1854	8638	8194
1854	8638	145
8768	8639	6603
8768	8639	5687
8768	8639	6213
8768	8639	7527
8768	8639	6722
8768	8639	4079
8768	8639	891
8768	8639	1750
10399	8640	8208
12802	8641	2982
12802	8641	1559
12802	8641	1604
12802	8641	1091
12802	8641	2994
12802	8641	9942
12802	8641	9130
6417	8642	5439
5838	8643	3474
5838	8643	9637
5838	8643	5582
5838	8643	7680
5838	8643	2917
5838	8643	6317
5838	8643	7399
5838	8643	1810
5838	8643	4711
7680	8644	7049
4974	8645	5406
4974	8645	6033
4974	8645	8367
4974	8645	9383
4974	8645	5001
4974	8645	2511
17655	8646	6235
17655	8646	4091
17655	8646	5997
17655	8646	4785
3665	8647	4319
3665	8647	2916
3665	8647	4250
3665	8647	8603
3665	8647	4617
3665	8647	6564
3665	8647	5046
2689	8648	5043
2689	8648	4215
2689	8648	5080
2689	8648	4136
2689	8648	4623
2689	8648	1697
2689	8648	6624
2689	8648	6536
2689	8648	5740
8683	8649	2326
8683	8649	2723
8683	8649	9040
13881	8650	1076
13881	8650	2890
13881	8650	4652
13881	8650	6020
15433	8651	3732
15433	8651	2954
15433	8651	8067
15433	8651	3812
12275	8652	3508
12275	8652	7525
12275	8652	7412
12275	8652	5981
12275	8652	2190
12275	8652	4644
12275	8652	5895
5370	8653	6098
5370	8653	4143
5370	8653	1582
5370	8653	493
5370	8653	3677
5370	8653	1531
5370	8653	2307
19662	8654	7581
19662	8654	1481
19662	8654	2112
16013	8655	691
16013	8655	9587
16013	8655	7279
17721	8656	4254
17721	8656	1371
17721	8656	4725
17721	8656	823
17721	8656	3508
17721	8656	3299
9559	8657	904
9559	8657	1443
9559	8657	194
9559	8657	2859
274	8658	8998
274	8658	1094
274	8658	9063
274	8658	9036
274	8658	6141
19297	8659	737
19297	8659	2171
19297	8659	2704
19297	8659	9062
19297	8659	765
19297	8659	6280
19297	8659	9036
5089	8660	1992
5089	8660	6008
5089	8660	3520
19320	8661	9309
19320	8661	6326
19320	8661	2112
19320	8661	1639
19320	8661	1571
19320	8661	8962
19320	8661	9955
19320	8661	5959
19320	8661	443
810	8662	1461
810	8662	4580
810	8662	3526
810	8662	4640
7897	8663	3993
7897	8663	3176
7897	8663	8199
7897	8663	6331
7897	8663	7081
6078	8664	2757
6078	8664	3250
6078	8664	336
9830	8665	4336
9830	8665	5667
9830	8665	8279
9830	8665	7370
9830	8665	322
9830	8665	7902
9830	8665	5291
4744	8666	5411
4744	8666	927
4744	8666	2603
4744	8666	3399
4744	8666	8886
4744	8666	7853
4744	8666	4352
4744	8666	2906
2369	8667	3456
2369	8667	2793
2369	8667	5798
2956	8668	9561
2956	8668	1900
2956	8668	4033
2956	8668	4663
2956	8668	7440
2956	8668	4543
17788	8669	8912
17788	8669	6215
17788	8669	4604
17788	8669	3146
17788	8669	1027
13231	8670	2722
13231	8670	1798
13231	8670	469
13231	8670	9123
13231	8670	3261
13231	8670	8680
1609	8671	5835
1609	8671	1688
1609	8671	1476
1609	8671	1719
1609	8671	3687
1609	8671	3565
1609	8671	9361
1609	8671	5098
1609	8671	3968
8871	8672	9567
8871	8672	2387
8871	8672	3789
8871	8672	9050
8871	8672	3572
8871	8672	6093
15137	8673	2190
15137	8673	1398
15137	8673	4402
15137	8673	9741
15137	8673	2842
15137	8673	6394
15137	8673	8144
15137	8673	5371
15515	8674	1998
15515	8674	9377
15515	8674	9890
15515	8674	828
15515	8674	3038
15515	8674	5476
15515	8674	7615
15515	8674	982
15515	8674	7633
948	8675	19
948	8675	7027
948	8675	284
948	8675	3147
948	8675	1023
948	8675	1245
948	8675	712
948	8675	5869
17812	8676	4134
17812	8676	306
17812	8676	3546
17812	8676	5838
536	8677	2842
536	8677	3819
536	8677	2125
536	8677	9364
536	8677	2108
536	8677	3547
536	8677	1742
536	8677	4358
16547	8678	9804
16547	8678	7569
16547	8678	1375
19573	8679	8216
19573	8679	1371
6990	8680	6642
6990	8680	9612
6990	8680	3926
6990	8680	9603
6990	8680	1053
6990	8680	6557
6990	8680	377
6990	8680	7620
6990	8680	9710
16238	8681	9496
16238	8681	1540
16238	8681	9031
16238	8681	4361
16238	8681	184
19592	8682	1150
19592	8682	1344
19592	8682	8717
18186	8683	7038
18186	8683	2998
18186	8683	2089
18186	8683	3412
9902	8684	6131
9902	8684	5835
9902	8684	7813
9902	8684	6110
9902	8684	8032
9902	8684	9797
9902	8684	9460
9902	8684	7276
3072	8685	5506
3072	8685	3030
3072	8685	4624
3072	8685	9177
3072	8685	1392
15044	8686	3836
15044	8686	2007
15044	8686	5251
15044	8686	7204
15044	8686	9414
15044	8686	3560
15044	8686	2508
4710	8687	5201
4710	8687	1324
4710	8687	5278
4710	8687	3222
8848	8688	1461
6936	8689	3506
6936	8689	7108
1334	8690	1832
1334	8690	6700
1334	8690	1564
1334	8690	6475
3505	8691	8422
3505	8691	9369
3505	8691	6078
3505	8691	638
3505	8691	4297
15606	8692	723
15606	8692	2723
9108	8693	2193
9108	8693	8567
9108	8693	2617
9108	8693	420
9108	8693	5234
9108	8693	1520
15195	8694	485
15195	8694	699
8965	8695	104
8965	8695	8584
8965	8695	4764
8965	8695	6736
8965	8695	6476
8965	8695	5623
8965	8695	5592
8965	8695	5097
13233	8696	4214
13233	8696	8426
13233	8696	587
13233	8696	131
13233	8696	3607
13233	8696	6370
9905	8697	1700
9905	8697	9547
9905	8697	5817
2816	8698	2233
2816	8698	8981
2816	8698	2431
1713	8699	9981
1713	8699	7222
1713	8699	5640
1713	8699	7297
1713	8699	8544
1713	8699	6058
1713	8699	1591
1713	8699	8420
1713	8699	775
3973	8700	8082
1025	8701	1369
1025	8701	6332
1025	8701	6139
1025	8701	4936
1025	8701	7145
1025	8701	5245
1025	8701	3308
9796	8702	2305
9796	8702	38
9796	8702	9668
9796	8702	2166
1746	8703	8100
1746	8703	3463
1746	8703	978
1746	8703	7984
1746	8703	1379
13246	8704	7925
13246	8704	6351
17310	8705	9774
17310	8705	9225
8690	8706	9691
8690	8706	7817
8690	8706	5342
8690	8706	2754
8690	8706	4708
8690	8706	8454
8690	8706	755
8690	8706	4305
1312	8707	9311
1312	8707	8253
1312	8707	8202
1312	8707	1023
1312	8707	1823
1312	8707	6318
1312	8707	4746
174	8708	3413
174	8708	1553
174	8708	487
174	8708	1137
174	8708	987
174	8708	5448
174	8708	4272
5050	8709	3
5050	8709	6850
5050	8709	8700
5050	8709	3338
5050	8709	7301
5050	8709	3532
5050	8709	5425
5050	8709	7864
16701	8710	3142
16701	8710	7102
16701	8710	4766
16701	8710	3348
16701	8710	3898
16701	8710	4007
16701	8710	2054
16701	8710	5725
16701	8710	4024
2649	8711	1553
2649	8711	4673
2649	8711	9468
2649	8711	7767
2649	8711	3430
2649	8711	9020
2649	8711	9498
5689	8712	33
5689	8712	9703
5689	8712	3934
5689	8712	2839
5689	8712	4491
5689	8712	9281
1667	8713	250
1667	8713	2920
1667	8713	2266
1667	8713	8924
1667	8713	6880
1667	8713	5071
1667	8713	1265
1667	8713	4587
1667	8713	7219
2304	8714	9109
2304	8714	3258
2304	8714	5763
2304	8714	9223
2304	8714	7459
2304	8714	3327
11185	8715	6878
11185	8715	4831
11185	8715	2391
11185	8715	6090
11185	8715	7394
11185	8715	1266
1962	8716	5187
1962	8716	1958
1962	8716	8277
1962	8716	760
8172	8717	9678
8172	8717	4550
8172	8717	6447
8172	8717	8504
8172	8717	5477
8172	8717	5815
8172	8717	7901
8172	8717	3646
1289	8718	900
1289	8718	4197
1289	8718	9067
19437	8719	7858
4815	8720	1789
14529	8721	134
14529	8721	2044
14529	8721	8634
14529	8721	4424
14529	8721	3352
15095	8722	2504
15095	8722	1234
18183	8723	1499
18183	8723	4612
18183	8723	9318
18183	8723	552
1370	8724	4465
17777	8725	4212
17777	8725	1769
17777	8725	1120
17777	8725	8125
17121	8726	2862
17121	8726	1621
17121	8726	6230
17121	8726	1233
17121	8726	8627
17121	8726	7466
3860	8727	819
3860	8727	5812
15162	8728	1853
15162	8728	5415
15162	8728	427
6576	8729	761
6576	8729	6308
6576	8729	2812
6576	8729	1948
6576	8729	7522
5406	8730	5041
5406	8730	8056
5406	8730	7652
19008	8731	7174
19008	8731	2317
19008	8731	7379
19008	8731	6294
19008	8731	8149
1919	8732	1236
1919	8732	4748
18013	8733	9077
18013	8733	9781
18013	8733	6320
19967	8734	4074
19967	8734	4329
19967	8734	9717
19967	8734	9592
19447	8735	1803
13100	8736	5556
13100	8736	6370
13100	8736	4490
13100	8736	1361
15187	8737	999
15187	8737	8858
17148	8738	6439
17148	8738	5634
17148	8738	9927
17148	8738	5322
17148	8738	3986
17148	8738	9310
11359	8739	1830
11359	8739	4090
11359	8739	3128
8252	8740	9453
8252	8740	6495
8252	8740	1977
8252	8740	4570
8252	8740	8195
8252	8740	5045
8252	8740	235
8252	8740	2339
2258	8741	4410
2258	8741	8280
2258	8741	4859
7845	8742	1843
7845	8742	9194
7845	8742	386
9911	8743	9452
9911	8743	2979
9911	8743	2855
9911	8743	9230
9911	8743	6446
9911	8743	4170
9911	8743	1507
9911	8743	9354
9911	8743	3857
18778	8744	4375
18778	8744	467
3470	8745	1199
3470	8745	8828
3470	8745	8853
3470	8745	9494
3470	8745	3108
14555	8746	9727
14555	8746	407
14555	8746	8880
14555	8746	2972
14692	8747	2106
14692	8747	5025
14692	8747	1022
19698	8748	1531
19698	8748	7921
19698	8748	5832
19698	8748	1915
19698	8748	4499
19698	8748	8773
19698	8748	5224
19698	8748	5600
19698	8748	2393
4374	8749	8205
4374	8749	9466
4374	8749	2960
4374	8749	9075
4374	8749	292
4374	8749	3252
4374	8749	5243
14315	8750	8798
14315	8750	8072
14315	8750	8134
1052	8751	2713
1052	8751	5401
1052	8751	543
1052	8751	143
1052	8751	5320
1052	8751	6862
1052	8751	9823
10131	8752	2223
10131	8752	5659
10131	8752	1387
19040	8753	46
19040	8753	5012
19040	8753	3302
19040	8753	3675
19040	8753	5280
19040	8753	7347
19040	8753	3036
5716	8754	7923
291	8755	1166
291	8755	1914
291	8755	5329
291	8755	3463
291	8755	8811
291	8755	8132
291	8755	8888
291	8755	5956
6604	8756	7510
6604	8756	1518
6604	8756	1009
6604	8756	5346
6604	8756	9586
6604	8756	1716
6604	8756	5576
6604	8756	6957
839	8757	8894
839	8757	3866
19642	8758	3123
19642	8758	500
4034	8759	1458
4034	8759	2230
4034	8759	7575
4034	8759	1793
4034	8759	7575
4034	8759	4054
4034	8759	9169
4034	8759	2274
12278	8760	5960
18165	8761	9714
18165	8761	5312
18165	8761	892
6242	8762	7067
6242	8762	706
6242	8762	8353
6242	8762	5160
6242	8762	5090
6242	8762	5583
6242	8762	3572
19063	8763	8614
19063	8763	6873
19063	8763	5916
19063	8763	503
969	8764	8041
969	8764	6366
969	8764	1635
969	8764	3505
969	8764	2239
969	8764	4227
969	8764	8423
18412	8765	2785
18412	8765	2185
18412	8765	4271
18412	8765	1841
18412	8765	4907
18412	8765	5258
18412	8765	7554
18412	8765	1827
6923	8766	255
6923	8766	4143
6923	8766	8698
6923	8766	2280
6923	8766	1772
9111	8767	4212
9111	8767	6694
9111	8767	4595
9111	8767	6844
9111	8767	6434
9111	8767	3150
9111	8767	8317
9111	8767	1722
3953	8768	6458
3953	8768	7451
3953	8768	4474
3953	8768	8345
3953	8768	3777
15977	8769	4041
15977	8769	7769
15977	8769	8164
15977	8769	5282
15977	8769	2463
15977	8769	6508
14500	8770	2135
14500	8770	4912
14500	8770	1354
14500	8770	8807
14500	8770	267
14500	8770	3595
14500	8770	571
14500	8770	5912
7361	8771	7883
7361	8771	5101
7361	8771	4376
7361	8771	4528
1375	8772	3305
9315	8773	4356
9315	8773	1967
9315	8773	7617
9315	8773	5262
9315	8773	7149
9315	8773	7209
9315	8773	4672
9315	8773	3421
9315	8773	5436
19927	8774	651
7910	8775	8613
7910	8775	1193
6317	8776	5696
6317	8776	884
6317	8776	7064
6317	8776	5487
6317	8776	3183
6317	8776	1509
6317	8776	6704
18856	8777	5465
18856	8777	3187
18856	8777	6168
18856	8777	1590
18856	8777	4767
18856	8777	518
18856	8777	8686
18856	8777	1862
18856	8777	9056
9086	8778	3450
306	8779	9581
306	8779	7273
306	8779	2544
306	8779	4769
306	8779	2257
306	8779	6071
306	8779	7687
306	8779	2707
9136	8780	3494
9136	8780	6400
19698	8781	2
19698	8781	1945
19698	8781	9564
19698	8781	4628
18791	8782	5753
18791	8782	8955
3322	8783	6229
3322	8783	8133
3322	8783	9355
3322	8783	3876
3322	8783	4381
3322	8783	7702
19294	8784	8864
19294	8784	3248
8131	8785	954
8131	8785	7180
8131	8785	1086
8131	8785	706
17676	8786	3370
17676	8786	5897
7198	8787	3246
7198	8787	3824
7198	8787	4689
5351	8788	6416
5351	8788	543
3257	8789	8943
3257	8789	6062
3257	8789	5430
3257	8789	6889
3257	8789	7182
3257	8789	4925
3257	8789	680
9008	8790	1575
5422	8791	4801
5422	8791	2786
5422	8791	4215
5422	8791	8542
5422	8791	6703
5422	8791	9135
5422	8791	4034
5422	8791	3459
5422	8791	4019
9398	8792	9203
9398	8792	6041
9398	8792	7760
9398	8792	3488
9398	8792	8007
9398	8792	2391
13210	8793	9762
13210	8793	2750
13210	8793	3000
13210	8793	4920
13210	8793	7999
13210	8793	4842
13210	8793	3637
13210	8793	4469
1019	8794	9326
1019	8794	5791
1019	8794	5393
1019	8794	8125
1019	8794	4787
1019	8794	3146
11792	8795	2679
11792	8795	2615
11792	8795	7302
11792	8795	9205
11792	8795	8852
11792	8795	3778
14787	8796	4498
14787	8796	840
14787	8796	7040
14787	8796	4888
16067	8797	3930
16067	8797	567
16067	8797	8182
16067	8797	7285
12979	8798	163
12979	8798	6569
12979	8798	7592
12979	8798	7852
12979	8798	8495
12979	8798	1979
12979	8798	7656
12979	8798	7360
12979	8798	4899
17656	8799	5436
17656	8799	7068
17656	8799	7216
17656	8799	9210
18744	8800	3716
18744	8800	3399
18744	8800	3517
18744	8800	258
15827	8801	6823
15827	8801	8520
15827	8801	6087
15827	8801	4028
15827	8801	3803
2036	8802	4655
2036	8802	2826
2036	8802	9756
2036	8802	9918
6869	8803	8929
6869	8803	6279
6869	8803	7260
6869	8803	8548
6869	8803	3243
6869	8803	7849
6869	8803	6158
6869	8803	8366
14331	8804	3159
14331	8804	5815
14331	8804	3221
14331	8804	6068
14331	8804	9167
14331	8804	9694
14331	8804	3588
1694	8805	6626
1694	8805	2567
1694	8805	9587
1694	8805	6127
1694	8805	9126
1694	8805	5117
1694	8805	6120
1694	8805	9659
5757	8806	4207
5757	8806	8372
5757	8806	4928
5757	8806	9873
5757	8806	2806
5757	8806	2244
5757	8806	1263
1697	8807	8801
7834	8808	2193
7834	8808	6881
7834	8808	8176
7834	8808	639
7834	8808	1380
12615	8809	620
12615	8809	5101
12615	8809	3205
12615	8809	7674
12615	8809	7212
12615	8809	7142
11937	8810	915
11937	8810	4806
11937	8810	5502
11937	8810	2343
11937	8810	5364
11937	8810	5150
11937	8810	30
11937	8810	7800
11937	8810	9892
6192	8811	206
6192	8811	2394
12526	8812	5771
12526	8812	4534
12526	8812	2025
8733	8813	8088
8733	8813	567
8733	8813	7445
8733	8813	8766
8733	8813	1268
8733	8813	432
8733	8813	3462
8733	8813	7005
8733	8813	7983
2595	8814	5526
2595	8814	8465
2595	8814	6474
2595	8814	1917
2595	8814	944
2595	8814	3977
2595	8814	8122
2595	8814	9877
2288	8815	1675
2288	8815	9823
2288	8815	8481
2288	8815	8170
2288	8815	9103
2288	8815	8487
2288	8815	6512
2288	8815	2179
2288	8815	8975
19837	8816	1429
19837	8816	1032
19837	8816	9107
19837	8816	2449
19837	8816	8975
19837	8816	895
19837	8816	2802
19837	8816	6603
19837	8816	9974
16921	8817	5412
16921	8817	542
16921	8817	6609
16921	8817	4305
16921	8817	5790
16921	8817	2928
16921	8817	7038
18974	8818	3610
18974	8818	4380
18974	8818	574
18974	8818	7383
18974	8818	6688
18974	8818	9008
8838	8819	8806
8838	8819	2704
8838	8819	6851
8838	8819	8843
8838	8819	5314
8838	8819	1813
4235	8820	3317
4235	8820	5389
4235	8820	2867
4235	8820	4438
4235	8820	1200
4235	8820	6577
4235	8820	7864
4235	8820	3710
4235	8820	2254
18208	8821	8882
18208	8821	4502
18208	8821	2142
18208	8821	2812
18208	8821	8846
18208	8821	1532
18208	8821	18
18208	8821	7006
16409	8822	5388
18193	8823	5510
18193	8823	7997
18193	8823	829
18193	8823	635
18193	8823	7574
18193	8823	5199
18193	8823	2423
18193	8823	6513
18193	8823	8278
10567	8824	3488
10567	8824	2833
10567	8824	4646
14152	8825	9285
14152	8825	3896
14152	8825	3240
14152	8825	5444
1284	8826	4686
1284	8826	3683
1284	8826	4241
1284	8826	8247
1284	8826	4339
1284	8826	4109
1284	8826	609
1284	8826	6642
1284	8826	5830
10228	8827	5227
10228	8827	486
10228	8827	5420
10228	8827	1312
10228	8827	7520
10228	8827	4328
17136	8828	3793
17136	8828	8942
17136	8828	4746
17136	8828	6656
17136	8828	8131
17136	8828	6394
17136	8828	7600
5653	8829	3497
5653	8829	4423
5653	8829	4405
5653	8829	806
5653	8829	3145
5653	8829	7300
2185	8830	8994
2185	8830	5468
2185	8830	89
2185	8830	8134
2185	8830	3790
2185	8830	4243
13221	8831	4397
13221	8831	6864
15339	8832	7437
15339	8832	2457
15339	8832	5924
15339	8832	328
15339	8832	5114
15339	8832	566
17400	8833	4433
17400	8833	3118
17400	8833	2538
13869	8834	5736
13869	8834	9581
14034	8835	1428
14034	8835	8552
7331	8836	8868
7331	8836	8207
7331	8836	125
7331	8836	6481
7331	8836	5632
7331	8836	2928
7331	8836	5953
7331	8836	2591
7331	8836	7209
13784	8837	9031
13784	8837	7079
13784	8837	2370
19839	8838	6862
13973	8839	229
13973	8839	6165
13973	8839	2682
13973	8839	6758
13973	8839	3805
13973	8839	7443
13973	8839	858
19777	8840	7471
19777	8840	4913
19777	8840	9534
19777	8840	8834
19777	8840	4170
19777	8840	3382
19777	8840	6648
19777	8840	2543
19777	8840	6765
7043	8841	7488
7043	8841	7495
7043	8841	4568
7043	8841	8234
7043	8841	8204
7043	8841	1426
7043	8841	4423
7043	8841	3555
15448	8842	8264
1613	8843	6030
13051	8844	4463
13051	8844	463
17392	8845	4400
17644	8846	2078
17644	8846	5282
17644	8846	1317
17644	8846	4236
17644	8846	4353
17644	8846	6771
17644	8846	3596
18949	8847	2849
18949	8847	400
2483	8848	3509
2483	8848	5900
2483	8848	7983
2483	8848	7316
2483	8848	2809
2483	8848	6811
2483	8848	4294
2128	8849	2465
2128	8849	6565
2128	8849	9822
2128	8849	9966
2128	8849	4946
2128	8849	1463
2128	8849	9720
11238	8850	3596
11238	8850	3036
11238	8850	7654
11238	8850	3449
11238	8850	1009
11238	8850	3011
11238	8850	4033
11238	8850	1005
11238	8850	1459
2849	8851	4067
2849	8851	6319
2849	8851	7483
2849	8851	9406
2849	8851	7880
1831	8852	762
1831	8852	7811
1831	8852	9796
1831	8852	4322
1831	8852	6297
1831	8852	4424
8865	8853	9387
8865	8853	9714
8865	8853	7032
8865	8853	3814
8865	8853	6384
8865	8853	9438
8865	8853	2608
6738	8854	5139
6738	8854	9088
6738	8854	5318
6738	8854	4787
6738	8854	3139
6738	8854	4174
6738	8854	8142
6738	8854	5564
5191	8855	9032
5191	8855	4771
5191	8855	6027
12967	8856	4750
12967	8856	497
12967	8856	5346
12967	8856	9221
12967	8856	5556
12967	8856	1072
12967	8856	4677
12967	8856	3289
12967	8856	7069
4237	8857	3553
4237	8857	336
15296	8858	6654
15296	8858	4412
15296	8858	4649
15296	8858	2965
15296	8858	9889
15296	8858	6228
15296	8858	8250
15296	8858	174
14484	8859	9361
14484	8859	5845
14484	8859	121
14484	8859	2491
17106	8860	9365
8027	8861	7883
8220	8862	5014
8220	8862	8905
8220	8862	8856
8220	8862	136
8220	8862	2716
8220	8862	1128
8220	8862	2161
11978	8863	6472
11978	8863	7998
11978	8863	5549
11978	8863	4702
11978	8863	9071
11978	8863	7542
11978	8863	1187
183	8864	3087
11604	8865	8639
18749	8866	6536
18749	8866	7647
18749	8866	3553
18749	8866	3123
18749	8866	6627
18749	8866	2074
6521	8867	3352
6521	8867	5806
6521	8867	4284
6521	8867	2240
6521	8867	5323
18525	8868	5374
18525	8868	8527
18525	8868	1321
18525	8868	6217
18525	8868	333
18525	8868	6635
18525	8868	7012
18525	8868	5667
18525	8868	4164
19940	8869	4971
19940	8869	2565
19940	8869	8575
19940	8869	9556
9858	8870	7950
9858	8870	8347
9858	8870	1378
9858	8870	7009
9858	8870	1086
9858	8870	7350
3027	8871	1483
3027	8871	377
3027	8871	8923
3027	8871	6747
3027	8871	1605
3027	8871	6325
3027	8871	1231
18360	8872	3345
18360	8872	2639
18360	8872	8263
18360	8872	4374
4255	8873	9052
4255	8873	7474
4255	8873	5061
4255	8873	2369
4255	8873	3894
4255	8873	8109
18678	8874	8519
18678	8874	2893
18678	8874	1281
18678	8874	2217
18678	8874	9256
18678	8874	5155
18678	8874	8718
18678	8874	5979
18678	8874	887
11896	8875	7755
11896	8875	3539
11896	8875	3958
11896	8875	5202
11896	8875	5791
11896	8875	7144
11896	8875	5584
11896	8875	4214
11896	8875	7967
6242	8876	5400
6242	8876	876
6242	8876	2632
4959	8877	6220
4959	8877	5853
4959	8877	8033
4959	8877	6292
4959	8877	4775
4959	8877	2505
4959	8877	1859
4959	8877	8158
4959	8877	188
6777	8878	2568
6777	8878	4631
6777	8878	4604
6777	8878	7678
6777	8878	6854
6777	8878	3416
6777	8878	4076
6777	8878	3761
17069	8879	8892
17069	8879	4495
17069	8879	5485
17069	8879	9598
17069	8879	8070
17069	8879	6774
17069	8879	1784
12774	8880	8627
12774	8880	7412
12774	8880	7830
12774	8880	3491
17522	8881	6537
17522	8881	1318
17522	8881	6066
17522	8881	5713
17522	8881	5232
17522	8881	916
5399	8882	9086
15426	8883	9755
15426	8883	2670
9050	8884	182
9050	8884	5365
9050	8884	9573
9050	8884	8301
9050	8884	7094
9050	8884	9067
6973	8885	3743
6973	8885	629
6973	8885	7508
6973	8885	8695
6973	8885	2067
6973	8885	507
6973	8885	5889
6973	8885	4640
6973	8885	1054
1253	8886	5911
1253	8886	9404
1253	8886	6538
1253	8886	8464
1253	8886	3889
1253	8886	7041
9097	8887	1811
9097	8887	9777
9097	8887	2308
9097	8887	4830
9097	8887	1737
9097	8887	6951
9097	8887	6510
9097	8887	5177
9160	8888	9521
9160	8888	696
9160	8888	8067
9160	8888	7927
19754	8889	3894
19754	8889	6412
19754	8889	1641
19754	8889	3149
197	8890	8483
197	8890	6053
197	8890	2440
197	8890	8844
19077	8891	7275
19077	8891	5164
19077	8891	3174
19077	8891	3654
19077	8891	7335
19077	8891	3269
19077	8891	1306
16858	8892	2062
16858	8892	2894
16858	8892	392
16858	8892	1565
16858	8892	7292
5323	8893	5958
5323	8893	5607
5323	8893	4779
5323	8893	6198
5323	8893	9326
5323	8893	1089
6881	8894	8475
6881	8894	7395
6881	8894	9235
1600	8895	1676
1600	8895	6653
1600	8895	1844
1600	8895	3349
16256	8896	242
16256	8896	7404
16256	8896	6667
16256	8896	4771
16256	8896	5682
16256	8896	6846
16256	8896	4613
16256	8896	863
15768	8897	3679
15768	8897	8487
15768	8897	4567
15768	8897	2973
15768	8897	9964
15768	8897	4245
15768	8897	5719
15768	8897	1535
12612	8898	9551
8327	8899	5476
8327	8899	2438
8327	8899	6474
8327	8899	2737
8327	8899	1638
9221	8900	4293
9221	8900	6964
9221	8900	9503
9221	8900	2396
9221	8900	4804
9221	8900	5050
9221	8900	5462
12996	8901	4415
12996	8901	4773
12996	8901	1847
12996	8901	5848
5286	8902	9402
5286	8902	6277
5286	8902	2400
5286	8902	4864
5286	8902	213
5286	8902	5301
5286	8902	4022
5286	8902	4003
14593	8903	3027
14593	8903	2561
16817	8904	1052
16817	8904	2047
16817	8904	8842
16817	8904	6819
3363	8905	1349
3363	8905	9577
3363	8905	2098
3363	8905	7910
8885	8906	5747
8885	8906	8776
8885	8906	2000
8885	8906	8186
466	8907	8556
466	8907	3670
466	8907	2004
6704	8908	8723
6704	8908	126
6704	8908	2495
6704	8908	1075
6704	8908	4903
6704	8908	7116
18230	8909	2166
18230	8909	9801
18230	8909	6829
18230	8909	5992
18230	8909	1014
18230	8909	202
18230	8909	1347
18230	8909	4532
18230	8909	4380
13748	8910	398
13748	8910	4597
13748	8910	4239
13748	8910	6629
13748	8910	5546
13748	8910	9452
13748	8910	4464
909	8911	8449
909	8911	2701
909	8911	8221
909	8911	9864
909	8911	1889
15094	8912	8108
15094	8912	7385
15094	8912	4915
15094	8912	7398
15094	8912	2807
15094	8912	5807
15094	8912	3129
15094	8912	7725
15094	8912	4225
13850	8913	4157
13850	8913	7703
13850	8913	2397
13850	8913	3592
13850	8913	7047
8861	8914	8443
2499	8915	8519
2499	8915	6363
2499	8915	1326
2499	8915	2416
2499	8915	7512
2499	8915	3311
2499	8915	4216
13225	8916	3349
13225	8916	3005
14102	8917	8495
14102	8917	9357
14102	8917	7508
14102	8917	8208
14102	8917	4119
14102	8917	4457
14102	8917	7741
14102	8917	4919
18268	8918	5747
18268	8918	2656
11321	8919	2711
11321	8919	3260
11321	8919	8377
11321	8919	7992
11321	8919	491
9218	8920	1143
9218	8920	6178
9218	8920	4523
9218	8920	5195
1882	8921	36
1882	8921	9480
1882	8921	7480
1882	8921	5872
8496	8922	132
8496	8922	7586
6635	8923	6789
6635	8923	5658
6635	8923	85
6635	8923	7900
6635	8923	1793
6635	8923	5069
6635	8923	7067
6635	8923	9978
6635	8923	6739
267	8924	1521
267	8924	2484
267	8924	113
267	8924	2424
267	8924	534
267	8924	4477
267	8924	525
267	8924	7044
17672	8925	664
1284	8926	6492
1284	8926	2299
7639	8927	2926
7639	8927	2120
5308	8928	8845
5308	8928	176
5308	8928	3511
5308	8928	4724
5308	8928	6866
5308	8928	6903
3358	8929	1739
3358	8929	9110
3358	8929	576
7003	8930	8851
7003	8930	6395
7003	8930	9608
7003	8930	8499
4018	8931	8683
4018	8931	1239
4018	8931	4927
4018	8931	7264
4018	8931	9790
4018	8931	6141
13433	8932	218
18137	8933	2481
18137	8933	6436
15125	8934	3414
15125	8934	9474
15125	8934	7256
15125	8934	1921
15125	8934	3784
15125	8934	3523
15125	8934	610
10872	8935	3121
10872	8935	5927
10872	8935	23
10872	8935	6088
10872	8935	9388
10872	8935	4020
10872	8935	3998
6941	8936	7871
6941	8936	5823
18690	8937	2309
18690	8937	1760
18690	8937	5079
18690	8937	5160
18690	8937	9681
18690	8937	9413
17600	8938	1176
17600	8938	3092
17600	8938	394
17600	8938	6525
17600	8938	9182
17600	8938	9918
2994	8939	9717
2994	8939	333
2994	8939	7862
2994	8939	5800
10425	8940	4013
10425	8940	7973
10425	8940	3160
7105	8941	1817
7105	8941	9281
7105	8941	319
7105	8941	3231
7105	8941	4973
7105	8941	4521
7105	8941	7742
7083	8942	8754
7083	8942	3784
3511	8943	2820
3511	8943	6183
3511	8943	5297
9154	8944	5550
9154	8944	6341
9154	8944	5910
9154	8944	5826
9154	8944	3244
6337	8945	6404
6337	8945	8711
6337	8945	3631
6337	8945	8505
6337	8945	5026
6337	8945	5510
19982	8946	4792
19982	8946	5381
19982	8946	970
13590	8947	3418
13590	8947	8406
13590	8947	8080
13590	8947	3386
13590	8947	683
18375	8948	3875
18375	8948	8801
18375	8948	8967
18375	8948	8978
18375	8948	4148
18375	8948	4890
18375	8948	5650
18375	8948	1912
10657	8949	6838
447	8950	7240
447	8950	5204
447	8950	9527
447	8950	9681
447	8950	5638
447	8950	2027
12348	8951	1291
12348	8951	4178
12348	8951	5215
12348	8951	8531
12348	8951	6823
12348	8951	8744
12348	8951	5592
5662	8952	3536
5662	8952	2453
5662	8952	5238
5662	8952	1864
8536	8953	1562
8536	8953	6302
3032	8954	9456
3032	8954	1828
3032	8954	1014
3032	8954	4536
3032	8954	250
3032	8954	2560
10024	8955	3102
10024	8955	1333
10024	8955	3133
10024	8955	7485
7573	8956	5303
7573	8956	3888
7573	8956	1327
7573	8956	2956
7573	8956	3135
7573	8956	1525
7573	8956	9413
16488	8957	2313
16488	8957	3036
16488	8957	8004
16488	8957	8415
15826	8958	5341
15826	8958	3763
10179	8959	7430
10179	8959	9782
10179	8959	1461
17260	8960	2801
17260	8960	4333
4672	8961	7824
4672	8961	9722
10124	8962	4290
10124	8962	3011
10124	8962	3299
10124	8962	7310
10124	8962	9394
10124	8962	2275
10124	8962	7400
10124	8962	4567
17798	8963	1235
17798	8963	4666
17798	8963	902
10120	8964	2981
10120	8964	8840
10120	8964	2971
10120	8964	6432
10120	8964	5218
10120	8964	9051
10120	8964	8258
10120	8964	7204
13331	8965	9522
13331	8965	723
13331	8965	2015
16343	8966	6003
16343	8966	1760
16343	8966	5657
16343	8966	6979
16343	8966	5010
16343	8966	7913
16343	8966	9689
16343	8966	510
14319	8967	9845
1134	8968	2191
1134	8968	3860
1134	8968	3860
1134	8968	8540
1134	8968	4703
1134	8968	350
10718	8969	9419
10718	8969	366
10718	8969	458
10718	8969	7088
13864	8970	7499
13864	8970	9438
13864	8970	197
13864	8970	8564
14206	8971	1299
14206	8971	9543
14206	8971	5385
14206	8971	1777
14206	8971	6986
14206	8971	4731
14206	8971	1502
14206	8971	1458
17102	8972	2910
17102	8972	5939
17102	8972	8061
17102	8972	7163
17102	8972	1606
17102	8972	9079
17241	8973	2041
17241	8973	7051
17241	8973	4403
11807	8974	7481
11807	8974	6478
11807	8974	8600
11807	8974	7571
11807	8974	2493
11807	8974	9041
11807	8974	6849
11807	8974	6494
6715	8975	5605
6715	8975	6294
6715	8975	5614
6715	8975	4437
16073	8976	387
16073	8976	6887
16073	8976	5874
16073	8976	3525
5132	8977	3212
5132	8977	2863
5132	8977	7872
5132	8977	795
5132	8977	3998
5132	8977	6133
5132	8977	7784
8765	8978	8462
8765	8978	8191
8129	8979	2431
8129	8979	4070
14562	8980	4042
14562	8980	7099
14562	8980	6316
14562	8980	1924
14562	8980	707
14562	8980	3016
14562	8980	4090
14562	8980	4104
14562	8980	613
17183	8981	95
17183	8981	7596
17183	8981	9241
17183	8981	1445
17183	8981	4112
17183	8981	7046
17183	8981	322
4491	8982	1953
4491	8982	5414
4491	8982	445
2115	8983	9649
2115	8983	4198
2115	8983	6958
2115	8983	3908
2115	8983	6216
2115	8983	405
14901	8984	811
14901	8984	3406
10717	8985	1401
10717	8985	1788
10717	8985	6945
13186	8986	6337
489	8987	5597
489	8987	9019
489	8987	2776
489	8987	7595
489	8987	4401
489	8987	206
489	8987	6359
489	8987	3530
10634	8988	8916
10634	8988	5072
10634	8988	4922
10634	8988	9406
10634	8988	1652
10634	8988	6090
10634	8988	9653
10634	8988	3683
2555	8989	2278
17271	8990	6394
17271	8990	169
17271	8990	1880
17271	8990	8384
17271	8990	9765
18341	8991	3498
6300	8992	5578
3185	8993	7813
3185	8993	3131
3185	8993	3802
3185	8993	3081
3185	8993	3670
4106	8994	5359
4106	8994	1989
4106	8994	277
15069	8995	8475
15069	8995	2318
15069	8995	5806
15069	8995	5186
15069	8995	8897
5397	8996	6669
5397	8996	1337
5397	8996	3562
5397	8996	2540
5397	8996	3514
5397	8996	4981
15670	8997	2589
15670	8997	2863
15670	8997	490
15670	8997	4853
15670	8997	2286
15670	8997	3992
15670	8997	6448
15670	8997	1961
6594	8998	6544
6594	8998	5820
6594	8998	9906
6594	8998	3847
6594	8998	8636
6594	8998	8569
6594	8998	4970
10918	8999	1135
10251	9000	6956
10251	9000	4298
1490	9001	1697
1490	9001	5227
1490	9001	2409
1490	9001	7020
1490	9001	2166
1490	9001	5555
1490	9001	2850
10911	9002	5711
10911	9002	9041
10911	9002	4408
4550	9003	3020
4550	9003	3550
4550	9003	4226
4550	9003	9580
4550	9003	5002
4550	9003	4635
378	9004	3704
378	9004	5354
378	9004	4909
378	9004	6855
378	9004	1119
378	9004	2226
378	9004	3537
378	9004	5220
378	9004	2237
12926	9005	3097
15463	9006	7920
15463	9006	4397
15463	9006	6402
15463	9006	977
15463	9006	816
3868	9007	1317
3868	9007	1658
3868	9007	9186
3868	9007	5306
3868	9007	357
3868	9007	1308
3868	9007	5400
10228	9008	9719
10228	9008	728
10228	9008	7402
10228	9008	7431
10228	9008	9535
10228	9008	151
10228	9008	175
10228	9008	1258
10228	9008	8003
6617	9009	6160
6617	9009	9535
6617	9009	964
6617	9009	6673
6617	9009	9824
6617	9009	1869
18541	9010	7488
18541	9010	2633
18541	9010	417
18541	9010	9105
18541	9010	4638
18541	9010	2117
18541	9010	416
18541	9010	6444
18541	9010	5223
12372	9011	404
12372	9011	1199
12372	9011	7072
12372	9011	1543
12372	9011	3653
12570	9012	9091
12570	9012	3206
10644	9013	8338
10644	9013	9872
10644	9013	6513
6421	9014	9731
13605	9015	6128
13605	9015	2993
13605	9015	7658
13605	9015	8773
3957	9016	7301
3957	9016	1609
3957	9016	5103
3957	9016	9199
3957	9016	9485
3957	9016	4826
3957	9016	9095
3957	9016	6307
8055	9017	5401
8055	9017	4728
8055	9017	8133
8055	9017	9808
8055	9017	5479
8055	9017	1879
8055	9017	4853
19909	9018	1570
19909	9018	6561
19909	9018	6749
19909	9018	951
19909	9018	7172
19909	9018	7084
19909	9018	9794
9043	9019	8022
9043	9019	2822
9043	9019	5635
9043	9019	6279
9043	9019	8188
9043	9019	442
9043	9019	2311
9043	9019	7607
9043	9019	8405
18711	9020	1664
18711	9020	4349
10944	9021	4728
10944	9021	7870
10944	9021	7500
7557	9022	8474
1568	9023	9656
1568	9023	5552
5926	9024	7457
5926	9024	7323
5926	9024	5701
5926	9024	6955
5926	9024	7303
5926	9024	7977
451	9025	662
451	9025	6749
451	9025	7838
14985	9026	1674
15108	9027	7783
15108	9027	5855
5617	9028	7632
5617	9028	832
5617	9028	2112
5617	9028	8277
5617	9028	6466
5617	9028	7025
4945	9029	3473
4945	9029	8488
4945	9029	1023
4945	9029	8856
4945	9029	2016
4945	9029	2287
12394	9030	8083
12394	9030	1109
12394	9030	7016
12394	9030	2967
12394	9030	4410
5247	9031	8873
5247	9031	3046
5247	9031	3372
5247	9031	3950
5247	9031	2873
5247	9031	6937
5247	9031	6708
5247	9031	1356
5247	9031	9605
1427	9032	99
1427	9032	1580
1427	9032	2591
1427	9032	7131
1427	9032	8941
1427	9032	990
1427	9032	3364
1427	9032	6055
17854	9033	4086
17854	9033	7978
17854	9033	3465
17854	9033	4880
9026	9034	7112
9026	9034	2902
9026	9034	3590
9026	9034	4756
9026	9034	6036
9026	9034	4517
9026	9034	106
9026	9034	6713
19980	9035	9975
19980	9035	9026
19980	9035	5777
19980	9035	7988
1270	9036	4862
1270	9036	5233
1270	9036	5400
1270	9036	983
1270	9036	5733
11676	9037	2530
11676	9037	7537
11676	9037	9153
11676	9037	940
11676	9037	951
11676	9037	2085
11676	9037	788
6507	9038	8621
6507	9038	2887
6507	9038	1252
6507	9038	5457
12584	9039	3840
12584	9039	1007
12584	9039	8098
12584	9039	8888
12584	9039	8338
844	9040	925
844	9040	9794
844	9040	2785
844	9040	8221
844	9040	2435
844	9040	9540
17816	9041	4346
17816	9041	4629
17816	9041	9398
17816	9041	5512
17816	9041	1764
17816	9041	8124
17816	9041	4272
17816	9041	4057
17816	9041	5251
16070	9042	3706
6491	9043	2154
6491	9043	5578
6491	9043	4796
6491	9043	1851
6491	9043	2933
6491	9043	2479
1205	9044	7503
1205	9044	680
1205	9044	118
1205	9044	788
1205	9044	3204
6095	9045	9348
6095	9045	6443
6095	9045	6391
6095	9045	5132
6095	9045	5431
6095	9045	5605
6095	9045	2760
6095	9045	8512
6095	9045	2301
5961	9046	5812
5961	9046	3738
1634	9047	487
1634	9047	1679
16139	9048	6311
16139	9048	9530
4578	9049	7260
16997	9050	9854
16997	9050	4358
16997	9050	8840
16997	9050	4408
16997	9050	194
3744	9051	9942
3744	9051	113
3744	9051	3590
3744	9051	8167
3744	9051	1932
3744	9051	5117
3744	9051	7930
3744	9051	7689
15086	9052	1134
11084	9053	437
11084	9053	782
11084	9053	2466
11084	9053	2253
11084	9053	6975
11084	9053	2221
11084	9053	940
11084	9053	2039
11084	9053	3343
2064	9054	8575
2064	9054	3470
2064	9054	4279
11570	9055	9604
11570	9055	7948
11570	9055	2599
11570	9055	4647
11570	9055	6042
11570	9055	4713
13502	9056	6719
13502	9056	5395
13502	9056	3404
13502	9056	2301
13159	9057	2364
13159	9057	4613
13159	9057	2030
13159	9057	4036
13159	9057	2760
13159	9057	4201
13159	9057	5550
13159	9057	5781
13159	9057	5664
4765	9058	1009
4765	9058	295
4765	9058	9337
4765	9058	9889
4765	9058	2898
4765	9058	8549
1158	9059	5207
1158	9059	6937
1158	9059	1630
1158	9059	8320
1158	9059	9056
1158	9059	6228
1158	9059	6366
1158	9059	6315
13219	9060	581
13219	9060	5483
13219	9060	2826
13219	9060	989
13219	9060	4610
13219	9060	5299
13219	9060	3889
11036	9061	2928
11036	9061	1528
11036	9061	3765
11036	9061	4443
11036	9061	5268
11036	9061	6689
11036	9061	9281
9526	9062	8794
9526	9062	6396
9526	9062	2796
9526	9062	3221
9526	9062	3930
9526	9062	2202
9526	9062	9988
9526	9062	2427
9526	9062	4284
17453	9063	920
17453	9063	628
17453	9063	229
17453	9063	4963
17453	9063	6505
5800	9064	4595
5800	9064	2193
5800	9064	2825
5800	9064	7174
5800	9064	9523
7614	9065	2534
7614	9065	8409
7614	9065	5023
7614	9065	3653
17231	9066	2372
17231	9066	5593
17231	9066	4450
13283	9067	1036
13283	9067	5550
13283	9067	5485
2553	9068	3339
2553	9068	351
2553	9068	1055
2553	9068	3612
2553	9068	2618
2553	9068	9938
2553	9068	8780
6458	9069	9871
6458	9069	7172
6458	9069	313
6458	9069	1464
11656	9070	2726
11656	9070	8226
11656	9070	8773
11656	9070	7079
11656	9070	6525
11656	9070	2224
2008	9071	4233
2008	9071	3641
2008	9071	2139
2008	9071	5009
2008	9071	3534
2008	9071	8248
2008	9071	2300
2008	9071	2339
2008	9071	5732
9009	9072	6890
9009	9072	4875
9009	9072	2833
9009	9072	117
9009	9072	8766
4813	9073	3219
4813	9073	7125
4813	9073	9932
4813	9073	2884
4813	9073	692
12847	9074	928
12847	9074	536
12847	9074	2001
12847	9074	6930
12847	9074	4970
7471	9075	6142
7471	9075	6869
7986	9076	9365
7986	9076	5470
7986	9076	4217
6	9077	5634
6	9077	5225
6	9077	4029
6	9077	2469
6	9077	9200
6	9077	2733
6	9077	4322
2380	9078	5183
2380	9078	6985
2380	9078	3340
2380	9078	4604
2167	9079	8491
2167	9079	1881
2167	9079	829
6594	9080	5424
6594	9080	5663
6594	9080	6513
6594	9080	935
6594	9080	9851
13671	9081	9290
13671	9081	9988
13671	9081	6351
9684	9082	8557
9684	9082	5520
9684	9082	4867
9684	9082	9494
9684	9082	8064
9684	9082	36
9684	9082	1261
9684	9082	9322
9684	9082	7087
15502	9083	3019
15502	9083	1705
15502	9083	8376
15502	9083	4212
15502	9083	9046
15502	9083	686
15502	9083	7193
13373	9084	1843
13373	9084	7629
13373	9084	6846
7866	9085	1684
7866	9085	9396
2200	9086	535
2200	9086	4524
2200	9086	1051
2200	9086	4145
2200	9086	761
13204	9087	2479
13204	9087	9876
13204	9087	6766
13204	9087	3257
13204	9087	6250
13204	9087	8331
13204	9087	9643
7429	9088	1997
7429	9088	6859
7429	9088	504
7429	9088	1290
7429	9088	138
7429	9088	7866
7429	9088	2991
5732	9089	6955
5732	9089	1035
5732	9089	7866
5732	9089	8850
5732	9089	4728
5732	9089	1222
5732	9089	2873
5732	9089	793
5732	9089	6266
15111	9090	3774
13529	9091	9631
13529	9091	4247
13529	9091	3364
13529	9091	9790
13529	9091	4646
18747	9092	4872
18747	9092	3178
18747	9092	6837
18747	9092	6961
18747	9092	6999
18747	9092	8446
18747	9092	9947
18747	9092	7537
18747	9092	6984
2461	9093	6511
2461	9093	5748
2461	9093	2180
2461	9093	531
2461	9093	4443
15240	9094	7063
8122	9095	4833
8122	9095	8015
8122	9095	8212
8122	9095	9536
8122	9095	6229
8122	9095	3886
19266	9096	4117
19266	9096	5420
19266	9096	9828
19266	9096	6179
19266	9096	9291
19266	9096	8921
19266	9096	7302
19266	9096	3587
19266	9096	3964
4351	9097	1543
4351	9097	7327
4351	9097	5569
4351	9097	5061
18355	9098	7737
18355	9098	7520
18355	9098	4612
18355	9098	7156
18355	9098	4027
18355	9098	2
18355	9098	6592
18355	9098	9216
11631	9099	8645
11631	9099	3111
11631	9099	6617
11631	9099	3677
11631	9099	7348
11631	9099	8363
11631	9099	1285
11793	9100	9430
11793	9100	613
11793	9100	4332
11793	9100	3397
11793	9100	8300
11793	9100	9363
16014	9101	2220
11792	9102	3463
11792	9102	932
11792	9102	6536
11792	9102	644
11792	9102	6086
11792	9102	5947
558	9103	3826
558	9103	2437
558	9103	5635
3059	9104	4040
3059	9104	9310
3059	9104	4334
3059	9104	6983
7037	9105	2747
7037	9105	8235
7037	9105	7980
7037	9105	8973
7037	9105	638
7037	9105	4083
7037	9105	5987
7037	9105	2730
5431	9106	1201
5431	9106	1616
5431	9106	2677
5431	9106	800
5431	9106	2118
9728	9107	3558
9728	9107	4328
9728	9107	7138
9728	9107	5328
9728	9107	8040
9728	9107	937
4366	9108	7469
4366	9108	8995
4366	9108	219
4366	9108	7683
4366	9108	1866
4366	9108	7013
4366	9108	4664
4366	9108	6813
4366	9108	9547
13368	9109	7904
13368	9109	7393
13368	9109	4914
13368	9109	1024
13368	9109	4979
13368	9109	3082
6600	9110	4318
6600	9110	5059
6600	9110	7732
6600	9110	5620
6600	9110	7943
17386	9111	4771
17386	9111	5934
1693	9112	9243
1693	9112	8111
1693	9112	7004
1693	9112	5624
1693	9112	945
1693	9112	159
1693	9112	1271
1693	9112	5726
1693	9112	2434
16235	9113	9907
16235	9113	3661
16235	9113	9296
16235	9113	6686
11857	9114	8253
11857	9114	5670
11857	9114	29
11857	9114	3818
11857	9114	2618
11857	9114	8077
11857	9114	1979
11857	9114	2012
11857	9114	8628
17068	9115	4373
17068	9115	3858
11461	9116	5714
11461	9116	5902
11461	9116	9115
11461	9116	7997
11461	9116	6116
11461	9116	8021
11461	9116	8958
11461	9116	4702
6658	9117	1863
6658	9117	3579
14872	9118	3166
14872	9118	4309
14872	9118	9519
14872	9118	262
14872	9118	6140
14872	9118	1566
19172	9119	9585
19172	9119	8798
19172	9119	4478
19172	9119	5596
19172	9119	982
19172	9119	2575
19172	9119	6610
19172	9119	4411
17439	9120	8930
17439	9120	2300
17439	9120	7175
17439	9120	7324
7542	9121	4920
7542	9121	6655
7542	9121	6813
15588	9122	6418
15588	9122	8180
15588	9122	7810
15588	9122	9547
15588	9122	5994
15588	9122	5380
15588	9122	3545
15588	9122	2159
11220	9123	8645
11220	9123	5151
11220	9123	8956
9385	9124	3004
9385	9124	7006
9385	9124	7001
9385	9124	3511
9385	9124	1278
9385	9124	5024
9385	9124	7798
9385	9124	9212
9385	9124	9436
8151	9125	3634
8151	9125	9510
8151	9125	7401
8151	9125	7282
571	9126	1468
571	9126	7850
571	9126	6877
3800	9127	468
3800	9127	2238
3800	9127	2809
6193	9128	8535
6193	9128	202
6193	9128	8583
6193	9128	3091
6193	9128	7769
6193	9128	7648
6193	9128	6750
7252	9129	5526
7252	9129	978
7252	9129	5406
7252	9129	5897
7252	9129	1019
7252	9129	1311
7252	9129	7487
7252	9129	4557
6278	9130	7751
6278	9130	5290
6278	9130	2178
6278	9130	895
6278	9130	5665
6278	9130	5090
6278	9130	5928
6278	9130	7183
6158	9131	2954
880	9132	8129
880	9132	1029
880	9132	5351
880	9132	6241
880	9132	4178
880	9132	2678
880	9132	4810
880	9132	592
13038	9133	7852
13038	9133	9794
13038	9133	5550
13038	9133	8256
13038	9133	3187
13038	9133	6773
13038	9133	5438
1575	9134	1427
8210	9135	2447
8210	9135	3983
8210	9135	2941
8210	9135	8694
16976	9136	1236
8844	9137	5737
8844	9137	4202
8844	9137	1627
8844	9137	1208
8844	9137	1540
8844	9137	7159
19211	9138	1585
19211	9138	8495
19211	9138	7524
19211	9138	8767
19211	9138	4439
19211	9138	2160
19211	9138	4424
19211	9138	469
9341	9139	5453
13985	9140	4363
16310	9141	4887
16310	9141	1707
946	9142	475
946	9142	6005
12946	9143	1144
12946	9143	6273
12946	9143	7290
12946	9143	3588
12946	9143	9592
12946	9143	6255
3131	9144	5371
5737	9145	4805
5737	9145	1811
19311	9146	5901
19311	9146	9042
19311	9146	5022
19311	9146	1526
2235	9147	554
2235	9147	3641
18023	9148	1880
18023	9148	8585
18023	9148	552
18023	9148	7494
18023	9148	50
18023	9148	2440
18023	9148	3202
16445	9149	6831
16445	9149	767
16445	9149	5709
16445	9149	6054
16445	9149	2738
16445	9149	8361
16445	9149	6767
16445	9149	3760
16445	9149	6924
8835	9150	9193
8835	9150	1746
8835	9150	7197
8835	9150	617
8835	9150	9517
8835	9150	8643
8702	9151	3700
8702	9151	6600
8702	9151	1066
8702	9151	2299
8702	9151	8718
8702	9151	9136
8702	9151	3640
5666	9152	5227
5666	9152	1872
2778	9153	1672
2778	9153	3327
2778	9153	1018
2778	9153	7614
2778	9153	9086
2778	9153	984
2778	9153	3505
2778	9153	608
2778	9153	4165
8846	9154	6427
8846	9154	8506
8846	9154	8150
2880	9155	5567
2880	9155	4632
4491	9156	925
4491	9156	8641
4491	9156	4886
4491	9156	7068
4491	9156	3496
4491	9156	3474
4491	9156	5300
7611	9157	2646
924	9158	1606
924	9158	4623
924	9158	6120
924	9158	7031
924	9158	4009
924	9158	1472
924	9158	4919
924	9158	7945
2835	9159	1317
2835	9159	9764
2835	9159	2905
2835	9159	7400
2835	9159	2871
2835	9159	3416
16077	9160	6863
16077	9160	3680
16077	9160	6952
16077	9160	9765
16077	9160	3691
16077	9160	284
18545	9161	1145
8097	9162	9425
8097	9162	3999
8097	9162	9828
8097	9162	879
8097	9162	1151
8097	9162	5359
8097	9162	8612
16753	9163	6086
16753	9163	8021
16753	9163	3736
16753	9163	5655
11225	9164	2970
13936	9165	1483
13936	9165	136
13936	9165	9812
13936	9165	7465
13936	9165	7805
13936	9165	6800
5769	9166	8096
5769	9166	7467
5769	9166	5062
5769	9166	9363
5769	9166	6746
5769	9166	2341
5769	9166	9300
5769	9166	9035
5769	9166	5604
10831	9167	3839
1276	9168	3523
1276	9168	8581
1276	9168	1082
1276	9168	5368
1276	9168	1913
1276	9168	132
1276	9168	7062
1276	9168	1635
1276	9168	6006
3220	9169	7026
1728	9170	1502
1728	9170	9207
1728	9170	2327
1728	9170	6642
1728	9170	3835
1728	9170	9552
1728	9170	6740
1728	9170	4406
1728	9170	2156
16324	9171	9772
16324	9171	7864
16324	9171	1054
16324	9171	7661
16324	9171	9066
16324	9171	9454
16324	9171	4187
1656	9172	2838
1656	9172	5642
1656	9172	4423
1656	9172	3378
1656	9172	6087
1656	9172	4741
1656	9172	844
1656	9172	9344
1656	9172	1309
17938	9173	8132
17938	9173	5347
17938	9173	9658
17938	9173	3146
17938	9173	1302
17938	9173	9585
17938	9173	5560
17874	9174	2477
17874	9174	5871
17874	9174	9838
2293	9175	115
16493	9176	564
16493	9176	3863
16493	9176	6417
12003	9177	9
12003	9177	4187
12003	9177	2172
12003	9177	5920
12003	9177	9984
4020	9178	2045
4020	9178	2904
4020	9178	5265
4020	9178	1610
4020	9178	6387
4020	9178	9537
4020	9178	636
4020	9178	8804
17625	9179	9407
17625	9179	5328
17625	9179	2051
17625	9179	1084
17625	9179	7321
17625	9179	4176
17625	9179	5006
17625	9179	8520
260	9180	5602
260	9180	1085
260	9180	4863
260	9180	8980
260	9180	8701
260	9180	8005
260	9180	4827
260	9180	3433
9033	9181	2504
9033	9181	5330
9033	9181	3438
9033	9181	7780
9033	9181	3979
9033	9181	3614
9396	9182	4586
9396	9182	3716
9396	9182	5616
9396	9182	1393
9651	9183	9342
9651	9183	9660
9651	9183	5862
9651	9183	9355
14269	9184	1013
14269	9184	2397
14269	9184	2943
15058	9185	816
15058	9185	337
15058	9185	9069
15058	9185	7034
15058	9185	9085
15058	9185	5890
15058	9185	8221
15058	9185	3734
5142	9186	5387
5142	9186	3927
5142	9186	6247
5142	9186	5998
5142	9186	4399
5142	9186	9764
201	9187	5490
201	9187	3093
201	9187	829
201	9187	3319
201	9187	733
201	9187	6624
201	9187	9623
10019	9188	2793
10019	9188	8259
5314	9189	7870
5314	9189	4312
5314	9189	2143
5314	9189	9745
1147	9190	9623
1147	9190	4746
1147	9190	6733
1147	9190	7578
1147	9190	9378
1147	9190	5585
1147	9190	7932
4759	9191	6591
4759	9191	4197
4759	9191	9661
4759	9191	704
4759	9191	1574
4759	9191	9979
4759	9191	2773
4759	9191	741
14946	9192	1669
14946	9192	8057
14946	9192	3435
14946	9192	1097
15195	9193	1968
15195	9193	5861
15195	9193	3689
15195	9193	1034
15195	9193	1643
8832	9194	1934
8832	9194	9267
1870	9195	8189
1870	9195	3928
1870	9195	2916
1870	9195	6883
1870	9195	7253
1870	9195	3421
1870	9195	478
1870	9195	9678
2642	9196	5737
2642	9196	5219
2642	9196	9595
2642	9196	1491
13152	9197	5097
13152	9197	2893
13152	9197	3640
13152	9197	4082
15004	9198	4612
15004	9198	612
15004	9198	5005
15004	9198	409
15004	9198	6269
15004	9198	8411
15004	9198	112
15004	9198	5340
15004	9198	6478
3147	9199	9585
3147	9199	1808
864	9200	9534
864	9200	6324
864	9200	2763
6342	9201	8798
6342	9201	5409
6342	9201	380
6342	9201	4442
6342	9201	3506
6342	9201	8430
6342	9201	5614
6342	9201	5349
6342	9201	1681
5697	9202	8628
5697	9202	7532
5697	9202	4273
5697	9202	4561
5697	9202	356
5697	9202	6820
5697	9202	2267
13417	9203	290
11806	9204	3325
11806	9204	6957
11806	9204	5029
7313	9205	5046
7313	9205	6905
7313	9205	7138
7313	9205	2964
7313	9205	3025
7313	9205	1156
10423	9206	7697
10423	9206	8131
10423	9206	157
14228	9207	693
14228	9207	9063
14228	9207	7294
14228	9207	8013
14228	9207	3715
13356	9208	1908
13356	9208	4021
13356	9208	5474
13356	9208	6074
13356	9208	759
1831	9209	8029
1831	9209	7152
12428	9210	322
12428	9210	982
12428	9210	9099
12428	9210	714
12428	9210	6924
12428	9210	8467
12428	9210	6468
5083	9211	6746
5083	9211	6194
5083	9211	222
5083	9211	697
5083	9211	2944
17760	9212	2829
17760	9212	7945
17760	9212	391
17760	9212	133
17198	9213	2539
17198	9213	289
17198	9213	8057
17198	9213	8126
17198	9213	9440
17198	9213	8473
17198	9213	5720
18614	9214	3216
18614	9214	5243
18614	9214	5052
18614	9214	9819
18614	9214	2948
18614	9214	3783
18614	9214	8847
18270	9215	6170
18270	9215	6288
9520	9216	6175
9520	9216	7469
9520	9216	3360
9520	9216	9595
9520	9216	1845
9520	9216	4236
9520	9216	9830
9520	9216	2762
3215	9217	743
3215	9217	4407
3215	9217	9999
4880	9218	602
4880	9218	4333
4880	9218	8099
4880	9218	8754
4880	9218	6295
4880	9218	2339
4880	9218	2261
4880	9218	7713
12199	9219	8469
12199	9219	1619
12199	9219	4283
12199	9219	3569
12199	9219	4057
12199	9219	5069
18802	9220	7093
18802	9220	6443
18802	9220	2080
18802	9220	3917
18802	9220	950
18802	9220	9362
18802	9220	7729
18802	9220	2446
8129	9221	5682
8129	9221	4447
8129	9221	1663
8129	9221	4396
8129	9221	8916
8129	9221	1063
8129	9221	8606
1369	9222	5025
1369	9222	4941
1369	9222	3966
12824	9223	477
12824	9223	1381
12824	9223	576
12824	9223	5895
581	9224	7414
581	9224	267
581	9224	3118
581	9224	6704
3456	9225	6114
3456	9225	581
3456	9225	7016
3456	9225	227
3456	9225	7382
3456	9225	3650
3456	9225	7436
3456	9225	196
9494	9226	360
9494	9226	3268
9494	9226	6963
9494	9226	2880
9494	9226	1699
9494	9226	7848
9494	9226	122
14275	9227	4630
14275	9227	6137
14275	9227	3214
14275	9227	7823
14275	9227	6350
6771	9228	688
6771	9228	1993
6771	9228	8145
6771	9228	7586
6771	9228	4391
6771	9228	7656
6771	9228	3861
6771	9228	1650
12557	9229	4557
12557	9229	6193
12557	9229	3612
3534	9230	283
3534	9230	3116
3534	9230	4266
3534	9230	7148
3534	9230	1104
17517	9231	715
17517	9231	2878
19735	9232	70
19735	9232	914
19735	9232	8556
19735	9232	5448
19735	9232	5893
19735	9232	1098
19735	9232	8005
19735	9232	269
2743	9233	130
2743	9233	5641
2743	9233	437
2743	9233	8045
2743	9233	8386
16911	9234	2136
16911	9234	4810
16911	9234	6917
16911	9234	3314
2637	9235	6470
2637	9235	1349
2637	9235	5086
2637	9235	5897
2637	9235	2323
2637	9235	9246
2637	9235	747
2637	9235	8233
2637	9235	6086
16444	9236	5806
16444	9236	3064
16444	9236	9474
5699	9237	3439
5699	9237	66
5699	9237	5578
5699	9237	9251
5699	9237	2296
5699	9237	8268
5699	9237	6127
4425	9238	435
4425	9238	6649
4425	9238	4615
4425	9238	5359
11591	9239	2703
11591	9239	9335
11591	9239	8899
11591	9239	8731
11591	9239	2812
2159	9240	7579
2159	9240	4985
2159	9240	5090
3476	9241	1450
3476	9241	8044
3476	9241	2812
3476	9241	9170
17009	9242	3417
17009	9242	2404
17009	9242	8038
17009	9242	7308
9771	9243	1074
9771	9243	2223
9771	9243	9736
9771	9243	4371
9771	9243	897
9771	9243	5120
9771	9243	7394
5497	9244	7003
5497	9244	4515
5497	9244	2439
5497	9244	8454
5497	9244	4658
5497	9244	4631
5497	9244	7079
18603	9245	3183
18603	9245	6483
18603	9245	2903
18603	9245	7788
18603	9245	5892
17372	9246	4896
14669	9247	7080
14669	9247	8180
14669	9247	3802
14669	9247	7414
14669	9247	4560
14669	9247	4662
14669	9247	4021
14669	9247	1822
19217	9248	6618
19217	9248	7324
19217	9248	309
19217	9248	155
19217	9248	9554
19217	9248	7667
19217	9248	7969
19217	9248	8344
11514	9249	9289
11514	9249	3408
11514	9249	6939
11514	9249	233
11514	9249	4837
11514	9249	8322
11292	9250	7866
11292	9250	7783
11292	9250	4470
11292	9250	4052
11292	9250	1296
11292	9250	4209
11292	9250	8152
11292	9250	8066
2945	9251	6701
2945	9251	7760
2945	9251	8433
2945	9251	2991
2945	9251	1727
2945	9251	4167
2945	9251	8310
2945	9251	7011
2125	9252	3458
2125	9252	1094
2125	9252	4769
2125	9252	9051
2125	9252	632
2125	9252	3981
2125	9252	783
2125	9252	8869
3718	9253	7432
3718	9253	9139
3718	9253	1477
3718	9253	8520
3718	9253	7211
3718	9253	7568
3718	9253	3164
3718	9253	2278
3718	9253	7820
16901	9254	5783
16901	9254	9557
16901	9254	1126
16901	9254	6510
16901	9254	6924
16901	9254	6013
16901	9254	9681
16901	9254	2210
18842	9255	89
18842	9255	2592
18842	9255	3033
18842	9255	3693
9641	9256	6731
9641	9256	9294
9641	9256	1620
9641	9256	4342
9641	9256	9744
18848	9257	7624
18848	9257	6235
18848	9257	8138
18848	9257	4663
18848	9257	8689
18848	9257	1140
18848	9257	4566
18505	9258	3496
18505	9258	1788
18505	9258	9740
18505	9258	3658
16524	9259	5076
16524	9259	8534
16524	9259	6092
16524	9259	7633
12643	9260	8703
12643	9260	8539
12643	9260	2267
12643	9260	9837
12643	9260	7119
12643	9260	877
12643	9260	7754
12643	9260	6341
10495	9261	1778
10495	9261	9182
10495	9261	3767
10495	9261	8624
10495	9261	3136
10495	9261	9704
10495	9261	87
10495	9261	7743
15160	9262	9204
15160	9262	5401
15160	9262	3527
15160	9262	1194
15160	9262	6989
15160	9262	4194
15160	9262	6853
15160	9262	6636
10518	9263	2332
10518	9263	5162
10518	9263	9730
2307	9264	9696
2307	9264	1880
2307	9264	6646
15679	9265	7596
15679	9265	2594
15679	9265	9298
15679	9265	5068
13703	9266	8340
13703	9266	9237
13703	9266	876
13703	9266	9223
13703	9266	6896
13703	9266	1048
13703	9266	4015
1705	9267	4680
1705	9267	1832
1705	9267	7577
1705	9267	6501
1705	9267	615
1705	9267	9495
15668	9268	5903
15668	9268	1051
15668	9268	3630
15668	9268	4043
15668	9268	6722
15668	9268	2371
15668	9268	8910
7178	9269	861
7178	9269	9772
7178	9269	1252
7178	9269	8350
7178	9269	3810
7178	9269	8581
7178	9269	3199
7178	9269	7475
2208	9270	5782
2208	9270	1708
2208	9270	9819
2208	9270	6056
14173	9271	5694
14173	9271	2428
14173	9271	5430
14173	9271	7692
14173	9271	6934
263	9272	4381
263	9272	3022
17606	9273	6955
17606	9273	6337
17606	9273	1943
17606	9273	96
17606	9273	5609
17606	9273	2260
15379	9274	6929
2743	9275	3289
2743	9275	7815
2743	9275	6836
2743	9275	5113
2743	9275	7548
2743	9275	7642
2743	9275	5077
10345	9276	963
7395	9277	4124
7395	9277	2632
7395	9277	5046
7395	9277	8275
7395	9277	8769
7395	9277	4644
7395	9277	7917
10928	9278	9348
10928	9278	5159
10928	9278	2072
10928	9278	3809
10928	9278	1014
10928	9278	6731
1709	9279	1676
1709	9279	9906
17350	9280	4280
17350	9280	9216
17350	9280	9420
17350	9280	7789
17350	9280	7938
17350	9280	2541
17350	9280	4904
17350	9280	3043
17350	9280	8229
13986	9281	8389
13986	9281	1594
13986	9281	2255
13986	9281	6970
13986	9281	5868
10165	9282	6121
10165	9282	437
5955	9283	9327
5955	9283	5019
5955	9283	6883
5955	9283	4548
5955	9283	3810
5955	9283	9814
5955	9283	1231
5955	9283	1811
5955	9283	362
5222	9284	4280
5222	9284	4161
5222	9284	2938
14009	9285	4113
14009	9285	4574
14009	9285	1176
14009	9285	8506
14009	9285	2059
14009	9285	387
14009	9285	387
1497	9286	3359
15277	9287	2354
15277	9287	6368
15277	9287	1457
15277	9287	7065
15277	9287	6306
15277	9287	6565
15277	9287	761
15277	9287	2466
5704	9288	5049
5704	9288	4524
5704	9288	8536
5704	9288	7559
18147	9289	3527
18147	9289	7921
18147	9289	589
18147	9289	553
18147	9289	6624
18147	9289	4375
18147	9289	2188
18147	9289	204
12624	9290	3909
12624	9290	9665
12624	9290	1759
12624	9290	4829
12624	9290	6297
19645	9291	4806
19645	9291	8059
19645	9291	9466
7681	9292	681
7681	9292	241
7681	9292	8583
7681	9292	5113
7681	9292	3470
10457	9293	2508
10457	9293	4986
10457	9293	8119
10457	9293	736
10457	9293	9540
10457	9293	8283
10457	9293	3477
10457	9293	2846
10457	9293	5422
11325	9294	5255
11325	9294	8889
11325	9294	3789
11325	9294	3953
11325	9294	3589
11325	9294	4085
4407	9295	5128
4407	9295	3651
4407	9295	4088
4407	9295	4168
4407	9295	2672
973	9296	6884
973	9296	3369
973	9296	9231
973	9296	9597
6369	9297	1759
6369	9297	9234
6369	9297	8624
6369	9297	2384
6369	9297	7770
6369	9297	9402
6369	9297	3405
7729	9298	8222
7729	9298	7284
7729	9298	5216
7729	9298	8747
7729	9298	9697
7729	9298	7997
7729	9298	8722
15911	9299	2316
15911	9299	4004
6811	9300	5479
6811	9300	3181
6811	9300	325
6811	9300	7483
6811	9300	2992
6811	9300	4122
6811	9300	7510
6811	9300	3431
6811	9300	3160
12532	9301	7996
12532	9301	1757
12532	9301	2508
9060	9302	8078
16805	9303	6011
16805	9303	9103
16805	9303	6297
16805	9303	3951
16805	9303	2118
16805	9303	1880
3974	9304	4410
3974	9304	3370
17550	9305	9659
17550	9305	6269
17550	9305	7927
17550	9305	4986
17550	9305	2394
17550	9305	4070
16040	9306	5130
16040	9306	197
16040	9306	2284
13386	9307	3610
13386	9307	2021
13386	9307	6566
5668	9308	670
5668	9308	6446
5668	9308	9332
62	9309	2849
6089	9310	2936
6089	9310	9444
6089	9310	5290
14620	9311	8988
14620	9311	4140
9619	9312	7872
9619	9312	2159
1386	9313	4357
1386	9313	9746
1386	9313	3015
1386	9313	8570
1386	9313	6960
1386	9313	5512
1386	9313	1169
313	9314	9403
313	9314	1955
313	9314	3156
313	9314	7716
313	9314	9452
313	9314	6008
313	9314	8270
16032	9315	698
16032	9315	4985
16032	9315	9318
971	9316	642
971	9316	9510
971	9316	1943
10197	9317	413
10197	9317	3222
2984	9318	9508
2984	9318	2028
2984	9318	9133
2984	9318	7862
2984	9318	7508
2984	9318	8936
2984	9318	9583
2984	9318	2056
2984	9318	9622
7119	9319	5213
7119	9319	2589
5157	9320	2080
5157	9320	6387
5157	9320	9640
15002	9321	4721
15002	9321	252
15002	9321	2481
15002	9321	3394
15002	9321	6305
15002	9321	5662
15002	9321	5795
15002	9321	4908
1673	9322	3549
1673	9322	8670
1673	9322	7148
1673	9322	5455
1673	9322	5810
1673	9322	6894
1673	9322	2327
1673	9322	4832
1673	9322	9453
11513	9323	1157
11513	9323	3446
11513	9323	6352
14624	9324	353
15000	9325	5767
15000	9325	5261
15000	9325	5308
15000	9325	9806
15000	9325	2396
15000	9325	8366
1080	9326	8509
1080	9326	2235
1080	9326	8079
1080	9326	2171
1080	9326	9584
1080	9326	728
19393	9327	4475
19393	9327	8451
19393	9327	8655
19393	9327	9922
19393	9327	7514
19393	9327	357
4469	9328	7558
4469	9328	2194
4469	9328	69
4469	9328	5705
4469	9328	6888
4469	9328	9621
4469	9328	6129
1206	9329	385
1206	9329	9406
13840	9330	9448
13840	9330	8789
13840	9330	4755
13840	9330	9080
13840	9330	1982
13840	9330	1314
16402	9331	5112
16402	9331	3847
16402	9331	849
16402	9331	8962
16402	9331	5487
16402	9331	1541
16402	9331	5287
16402	9331	8240
14056	9332	3374
14056	9332	9257
14056	9332	1110
19821	9333	8332
19821	9333	7406
19821	9333	1694
19821	9333	2518
19821	9333	9488
19821	9333	9022
19821	9333	9689
15856	9334	4956
15856	9334	1023
15856	9334	3887
15856	9334	3685
15856	9334	850
15856	9334	4906
15856	9334	3885
15856	9334	3504
10393	9335	5852
10393	9335	5936
10393	9335	59
10393	9335	9183
10393	9335	3553
10393	9335	9935
10393	9335	151
10393	9335	6837
1043	9336	7247
1043	9336	1709
10423	9337	408
10423	9337	522
10423	9337	996
2108	9338	2274
4416	9339	3165
4416	9339	2728
4416	9339	1501
4416	9339	6490
4416	9339	5698
4416	9339	9879
4416	9339	3409
4416	9339	5462
11966	9340	2440
11966	9340	6313
11966	9340	1522
11966	9340	155
11966	9340	793
7916	9341	8361
7916	9341	3239
17872	9342	1809
17872	9342	7700
17872	9342	273
17872	9342	3253
17872	9342	7222
7068	9343	2120
7068	9343	3138
7068	9343	4664
19879	9344	6715
19879	9344	80
19879	9344	5543
19879	9344	7637
19879	9344	9582
19708	9345	202
19708	9345	3566
19708	9345	8055
19708	9345	4833
19708	9345	4146
19708	9345	3087
19708	9345	9860
19708	9345	8749
10926	9346	7699
10926	9346	8393
10926	9346	2730
10926	9346	673
10926	9346	7829
16059	9347	9786
16059	9347	2566
16059	9347	722
16059	9347	2589
16059	9347	5521
16059	9347	3765
16059	9347	5677
16059	9347	9732
14861	9348	2767
14861	9348	584
14861	9348	970
12385	9349	4981
12385	9349	4451
12385	9349	846
12385	9349	4258
19556	9350	4047
19556	9350	1697
19556	9350	7071
15922	9351	1580
15922	9351	7413
15922	9351	7518
15922	9351	8742
7443	9352	1268
7443	9352	2350
7443	9352	4465
7443	9352	5302
7443	9352	4075
7443	9352	1906
7443	9352	3126
8669	9353	8309
11443	9354	4544
11443	9354	790
11443	9354	3528
11443	9354	4447
11443	9354	2007
11443	9354	319
11443	9354	8125
4400	9355	7971
4400	9355	7700
4400	9355	2429
4400	9355	9861
4400	9355	3152
4400	9355	6459
4400	9355	6004
4400	9355	4024
15102	9356	2346
15102	9356	9513
15102	9356	6248
6132	9357	1790
6132	9357	1349
6132	9357	7463
14647	9358	6497
14647	9358	1492
14647	9358	1975
14647	9358	9293
14647	9358	3066
14647	9358	2964
14647	9358	6838
6170	9359	6151
6170	9359	9614
6170	9359	7760
6170	9359	7429
6170	9359	4739
6170	9359	2545
18083	9360	1542
1669	9361	7896
1669	9361	4309
1669	9361	7885
1669	9361	7818
1669	9361	8744
1669	9361	7950
1669	9361	1908
1669	9361	9318
1669	9361	931
6952	9362	2517
6952	9362	33
6952	9362	5732
6952	9362	4893
6952	9362	4764
6952	9362	3585
6952	9362	7521
6952	9362	1456
6952	9362	9467
14833	9363	3126
14833	9363	551
2878	9364	1154
2878	9364	8769
2878	9364	4107
2878	9364	7052
2878	9364	2676
12521	9365	7730
12521	9365	4646
12521	9365	2544
12521	9365	4613
12521	9365	5166
12521	9365	8971
12521	9365	1794
12521	9365	7155
12521	9365	6134
9805	9366	9402
9805	9366	2479
9805	9366	8362
9805	9366	8339
12135	9367	3264
12135	9367	2168
12135	9367	5236
12135	9367	5614
12135	9367	3050
12135	9367	5105
12135	9367	6733
12135	9367	8513
16013	9368	4553
16013	9368	7620
16013	9368	6329
16013	9368	2165
16013	9368	2026
10578	9369	3165
17558	9370	6187
5839	9371	9026
5839	9371	7389
5839	9371	5362
5839	9371	675
5839	9371	4856
5839	9371	8940
5839	9371	6902
5839	9371	778
5839	9371	6254
18836	9372	8197
18836	9372	3582
18836	9372	1583
10524	9373	5082
10524	9373	4939
10524	9373	3164
10524	9373	3425
10524	9373	2616
10524	9373	5039
11633	9374	4490
11633	9374	9000
11633	9374	2752
11633	9374	5436
11633	9374	1580
11633	9374	785
11633	9374	2280
11633	9374	5209
11633	9374	5842
18011	9375	7025
18011	9375	3592
13840	9376	6502
13840	9376	2263
13840	9376	8664
8197	9377	1116
8197	9377	3158
8197	9377	6750
8197	9377	756
17118	9378	9787
17118	9378	2646
17118	9378	685
17118	9378	298
13599	9379	2301
13599	9379	243
13599	9379	3695
13599	9379	9274
13599	9379	3720
940	9380	3062
940	9380	7520
940	9380	3579
940	9380	3279
940	9380	684
940	9380	6763
940	9380	2527
940	9380	7780
940	9380	4958
10399	9381	6789
10399	9381	1562
10399	9381	6783
10399	9381	979
10399	9381	8728
10399	9381	6888
10399	9381	8697
3950	9382	5938
3950	9382	5216
3950	9382	3183
3950	9382	1924
9959	9383	1730
9959	9383	2505
9959	9383	636
9959	9383	3058
9959	9383	6866
9959	9383	5653
9959	9383	8032
9959	9383	4220
1821	9384	4364
1821	9384	726
1821	9384	4030
14211	9385	5259
14211	9385	9152
14211	9385	2648
14211	9385	7050
14211	9385	1400
14211	9385	7491
14211	9385	7669
14211	9385	1401
14211	9385	7105
5847	9386	3958
5847	9386	4709
5847	9386	3360
5847	9386	5093
5847	9386	9418
5847	9386	344
5847	9386	8114
10326	9387	9078
10326	9387	6808
10326	9387	1709
10326	9387	8633
10326	9387	5933
10326	9387	1737
10326	9387	8593
10326	9387	6629
10326	9387	3681
17548	9388	9125
17548	9388	1682
17548	9388	4311
6016	9389	9195
6016	9389	8224
13714	9390	8288
13761	9391	182
13761	9391	3274
13761	9391	9602
17453	9392	5965
17453	9392	8708
17453	9392	2885
17453	9392	9844
17453	9392	5101
17453	9392	2984
17453	9392	4924
17453	9392	647
14608	9393	590
14608	9393	2129
3460	9394	456
3460	9394	9809
17033	9395	7017
17033	9395	8521
17033	9395	2697
17033	9395	2025
17033	9395	4205
17033	9395	833
1849	9396	1198
10695	9397	6486
10695	9397	6216
10695	9397	393
10357	9398	9808
10357	9398	3944
11937	9399	8640
17227	9400	9178
17227	9400	242
17227	9400	8426
17227	9400	6142
17227	9400	7731
17227	9400	1205
17227	9400	2128
17227	9400	3301
6217	9401	5613
6217	9401	7755
12787	9402	5007
12787	9402	6996
12787	9402	1655
12787	9402	7788
12787	9402	997
12787	9402	4992
12787	9402	6286
12787	9402	6849
299	9403	3258
17740	9404	4607
17740	9404	5986
17740	9404	7412
17740	9404	9877
17740	9404	5177
17740	9404	1645
17740	9404	1611
17740	9404	6893
17740	9404	1368
16432	9405	8366
16432	9405	5061
16432	9405	8167
16432	9405	493
16432	9405	6493
4957	9406	3472
4957	9406	7982
4957	9406	7807
4957	9406	1612
17008	9407	1683
17008	9407	1851
17008	9407	3826
17008	9407	1618
19568	9408	7077
19568	9408	7429
19568	9408	4757
16455	9409	6875
16455	9409	4422
16455	9409	7329
16455	9409	6991
16455	9409	324
4347	9410	2389
4347	9410	4877
4347	9410	3348
4347	9410	6557
4347	9410	2940
4347	9410	3664
956	9411	5274
956	9411	5830
956	9411	1285
956	9411	6385
956	9411	6507
956	9411	6948
956	9411	8881
956	9411	4662
19075	9412	200
19075	9412	6228
19075	9412	6038
19075	9412	836
19075	9412	369
19075	9412	1770
15200	9413	759
14530	9414	5937
14530	9414	4959
14530	9414	8579
14530	9414	136
14530	9414	3219
14530	9414	6127
4329	9415	6016
4329	9415	1069
4329	9415	5347
4329	9415	5386
12288	9416	3409
18691	9417	9943
18691	9417	9026
4488	9418	1689
4488	9418	9086
4488	9418	8196
4488	9418	730
4488	9418	2888
4488	9418	9890
4488	9418	6759
18325	9419	9995
18325	9419	7171
18325	9419	211
18325	9419	4856
18325	9419	7192
18325	9419	1480
18325	9419	2572
18325	9419	1491
19371	9420	8949
19371	9420	999
19371	9420	7920
19371	9420	199
19371	9420	6919
13826	9421	5049
13826	9421	4445
13826	9421	191
13826	9421	5554
13826	9421	9240
13826	9421	4838
13826	9421	9783
13084	9422	6189
13084	9422	8203
13084	9422	2709
13084	9422	6444
13084	9422	547
13084	9422	6540
13084	9422	3937
13084	9422	2246
13084	9422	1492
14092	9423	5171
14092	9423	9986
14092	9423	7975
14092	9423	1496
14092	9423	9766
14092	9423	6880
14092	9423	1793
14092	9423	6370
14092	9423	9215
11509	9424	7343
11509	9424	7158
11509	9424	2888
11509	9424	5881
11509	9424	6431
11509	9424	5937
11509	9424	6005
11509	9424	6817
13165	9425	4550
13165	9425	2305
13165	9425	5213
107	9426	8831
107	9426	6492
107	9426	3451
107	9426	3163
107	9426	6373
107	9426	382
12772	9427	3886
12772	9427	9408
12772	9427	4775
14160	9428	8599
14160	9428	1313
286	9429	6132
286	9429	4621
286	9429	3270
286	9429	8886
286	9429	3302
19043	9430	1580
19043	9430	2993
19043	9430	1084
19043	9430	3434
4066	9431	7906
4066	9431	1753
15768	9432	7178
15768	9432	8277
15768	9432	9254
15768	9432	958
15768	9432	1100
15768	9432	3214
15768	9432	5804
13774	9433	2847
13774	9433	4499
13774	9433	7153
17811	9434	6789
17811	9434	8883
14318	9435	8737
14318	9435	7277
14318	9435	9663
14318	9435	2516
14318	9435	6696
14318	9435	2353
14318	9435	4014
14318	9435	7484
9272	9436	3542
9272	9436	7254
9272	9436	4845
9272	9436	4297
9272	9436	3296
9272	9436	1564
17682	9437	9331
17682	9437	441
17682	9437	5932
17682	9437	7968
17682	9437	7993
9418	9438	363
9418	9438	1089
9418	9438	3958
9418	9438	3753
9418	9438	9510
9418	9438	2580
9418	9438	9080
9418	9438	9915
9418	9438	2866
6613	9439	6099
6613	9439	1208
19331	9440	9040
19331	9440	2405
19331	9440	6779
19331	9440	6061
19331	9440	4617
19331	9440	7579
19331	9440	6644
19331	9440	5088
15906	9441	1259
15906	9441	4202
15906	9441	4314
6006	9442	1780
8367	9443	546
8367	9443	6722
8367	9443	5873
8367	9443	2358
8367	9443	959
8367	9443	9075
9755	9444	5952
9755	9444	4015
9755	9444	1114
9755	9444	3269
9755	9444	5712
9755	9444	302
9087	9445	4846
9087	9445	4938
9087	9445	2335
9087	9445	3234
9087	9445	4740
9087	9445	1858
9087	9445	7185
9087	9445	6794
9087	9445	9066
357	9446	6366
357	9446	1718
357	9446	7107
357	9446	1211
357	9446	725
357	9446	6455
357	9446	6774
13	9447	2314
13	9447	7835
13	9447	7302
13	9447	2636
13	9447	5436
13	9447	6545
13	9447	2708
8852	9448	5374
12197	9449	1761
12197	9449	4460
12197	9449	3626
12197	9449	2416
12197	9449	484
12197	9449	5438
16147	9450	4111
13638	9451	1245
13638	9451	6507
13638	9451	3975
13638	9451	2717
13638	9451	1393
13638	9451	4439
16128	9452	4003
16128	9452	1862
13482	9453	7056
13482	9453	5510
13482	9453	8444
13482	9453	4788
13482	9453	2302
12552	9454	7096
12552	9454	3501
12552	9454	4260
12552	9454	9598
12552	9454	4309
12552	9454	9532
12552	9454	3041
12552	9454	2911
12552	9454	5008
1034	9455	9633
3869	9456	8211
3869	9456	5640
3869	9456	546
3869	9456	6841
3869	9456	1838
3869	9456	1460
1982	9457	1185
1982	9457	3635
1982	9457	5194
8472	9458	8066
8472	9458	8276
8472	9458	3363
8472	9458	5327
8472	9458	1793
8472	9458	8144
19962	9459	6128
19962	9459	3128
8624	9460	504
8624	9460	7637
8144	9461	818
8144	9461	4355
19362	9462	5554
12462	9463	8368
12462	9463	8919
12462	9463	5878
12462	9463	5807
12619	9464	3521
12619	9464	640
12619	9464	2680
12619	9464	8902
12619	9464	5638
12619	9464	6715
4535	9465	8498
4535	9465	9870
4535	9465	8888
4535	9465	8360
4535	9465	5896
4535	9465	4314
5454	9466	4241
5454	9466	1069
5454	9466	3491
5454	9466	3954
1336	9467	2935
1336	9467	566
1336	9467	9547
1336	9467	8298
1336	9467	9223
10238	9468	9946
10238	9468	240
10238	9468	5295
10238	9468	3374
10238	9468	1400
10238	9468	6333
10238	9468	5991
7877	9469	2032
7877	9469	388
7877	9469	9025
7877	9469	14
7877	9469	5343
7877	9469	3366
7877	9469	725
7877	9469	7465
7877	9469	4651
16048	9470	4888
16048	9470	2197
16048	9470	8972
16048	9470	4816
16048	9470	7174
16048	9470	5585
16048	9470	8427
16880	9471	1652
16880	9471	7756
10440	9472	7978
10440	9472	2208
10440	9472	5628
10440	9472	2553
3049	9473	8520
3049	9473	9637
3049	9473	777
14046	9474	8613
14046	9474	7791
14647	9475	1507
14647	9475	2656
14647	9475	6664
14647	9475	809
17562	9476	1569
17562	9476	5363
12278	9477	3162
12278	9477	3646
2873	9478	8760
2873	9478	8329
2873	9478	9293
2873	9478	3980
2873	9478	9266
10745	9479	7521
10745	9479	5176
10745	9479	6343
10745	9479	9023
10745	9479	618
10745	9479	1382
10614	9480	9764
10614	9480	1827
2239	9481	7077
2239	9481	3493
2239	9481	3713
2239	9481	8165
2239	9481	2200
2239	9481	4117
2239	9481	1881
2239	9481	4153
11067	9482	841
11067	9482	1379
11067	9482	6921
11067	9482	8696
11067	9482	4325
11067	9482	351
11067	9482	6112
11067	9482	3651
11067	9482	905
6208	9483	1646
6208	9483	8312
6208	9483	9535
6208	9483	1331
6208	9483	2915
8587	9484	7499
8587	9484	7324
8587	9484	9241
8587	9484	3225
8587	9484	1517
8587	9484	5177
12467	9485	1407
12467	9485	884
12467	9485	2968
12467	9485	3354
12536	9486	561
12536	9486	1151
12536	9486	715
12536	9486	9883
12536	9486	6148
15328	9487	85
11219	9488	2780
11219	9488	7843
11219	9488	3823
11219	9488	45
11219	9488	7463
11219	9488	6009
11219	9488	5758
11219	9488	6083
11932	9489	9074
11932	9489	9444
19057	9490	5138
19057	9490	7058
19057	9490	3655
19057	9490	3663
19057	9490	6095
19057	9490	8014
19057	9490	221
19057	9490	1581
19057	9490	1181
13625	9491	8593
13625	9491	610
13625	9491	1758
13625	9491	7565
13625	9491	1761
13625	9491	9738
13625	9491	619
13625	9491	3718
19623	9492	3369
19623	9492	2904
19623	9492	4186
19623	9492	2612
19623	9492	896
19623	9492	5511
19623	9492	8942
19623	9492	7524
10176	9493	7790
16816	9494	2689
16816	9494	3054
16816	9494	3066
11939	9495	53
11939	9495	9707
11939	9495	222
18326	9496	9862
18326	9496	3048
18326	9496	992
18326	9496	9971
18326	9496	9245
18326	9496	3759
18326	9496	7470
18326	9496	2611
2992	9497	4568
2992	9497	8587
2992	9497	7506
2992	9497	9491
2992	9497	7971
15664	9498	7879
15664	9498	9785
15664	9498	2619
15664	9498	1135
15664	9498	963
15664	9498	3190
15664	9498	9140
15664	9498	5069
15664	9498	1030
19233	9499	8425
19233	9499	7649
19233	9499	4227
19233	9499	4227
19233	9499	2498
19233	9499	7439
19233	9499	9954
19233	9499	1311
19233	9499	6435
19249	9500	6049
19249	9500	4475
19249	9500	549
19249	9500	6695
19249	9500	6384
19249	9500	7857
19249	9500	1514
19249	9500	7581
157	9501	2360
157	9501	4916
157	9501	8887
157	9501	5944
157	9501	975
14047	9502	4102
14047	9502	8560
9887	9503	8975
9887	9503	7650
9887	9503	3170
9887	9503	6634
9887	9503	9928
9887	9503	8814
15401	9504	6279
15401	9504	399
15401	9504	4191
15401	9504	5570
15401	9504	6354
15401	9504	9090
15401	9504	9073
15401	9504	9631
14559	9505	2349
14559	9505	6620
14559	9505	231
14559	9505	7119
14559	9505	3134
14559	9505	1504
3804	9506	5004
3804	9506	2963
3804	9506	2797
3804	9506	5421
3804	9506	7057
18981	9507	5095
18981	9507	5756
18981	9507	6955
18981	9507	7147
18981	9507	8881
770	9508	2287
770	9508	2534
770	9508	1457
770	9508	8647
770	9508	7548
770	9508	6122
770	9508	9118
770	9508	4094
18376	9509	902
18376	9509	2298
18376	9509	7153
18376	9509	8327
18376	9509	1564
18376	9509	2401
9868	9510	430
9868	9510	6516
9868	9510	3853
5941	9511	4418
5941	9511	5863
5941	9511	5543
5941	9511	3624
5941	9511	4811
5941	9511	9020
5941	9511	5313
15427	9512	2647
15427	9512	4225
1481	9513	3378
1481	9513	2180
1481	9513	308
1481	9513	1284
1481	9513	7141
1481	9513	2934
1481	9513	4668
1481	9513	1540
1481	9513	882
4073	9514	3999
4073	9514	4272
4073	9514	289
4073	9514	8964
4073	9514	8838
4073	9514	4976
4073	9514	4394
4073	9514	7614
9508	9515	5518
9508	9515	2131
9508	9515	858
9508	9515	3909
16948	9516	5686
16948	9516	7269
16948	9516	7725
16948	9516	7316
16948	9516	8573
16948	9516	7579
16948	9516	7575
16948	9516	8643
16948	9516	9947
10928	9517	2521
10928	9517	8559
10928	9517	4301
10928	9517	4903
10928	9517	2653
19844	9518	6154
19844	9518	511
19844	9518	6170
19844	9518	7693
12671	9519	7482
12671	9519	8691
12671	9519	1736
588	9520	3901
588	9520	7402
588	9520	3131
588	9520	6475
588	9520	7574
588	9520	3571
588	9520	7355
588	9520	6172
588	9520	3484
12513	9521	2446
12513	9521	4663
12513	9521	2582
12513	9521	4474
12513	9521	8912
12513	9521	2765
12513	9521	4928
12513	9521	9938
15021	9522	5594
15021	9522	8897
15021	9522	6430
15021	9522	1219
15021	9522	8637
15021	9522	6674
15021	9522	5270
15021	9522	5262
15021	9522	973
19768	9523	6197
12268	9524	3644
12268	9524	1476
12268	9524	9852
12564	9525	4093
12564	9525	6120
2779	9526	9241
2779	9526	7469
2779	9526	2960
2779	9526	8152
2779	9526	8616
2779	9526	5290
2779	9526	7203
17357	9527	9051
17357	9527	7656
3497	9528	2515
3497	9528	8905
3497	9528	3395
3497	9528	7694
3497	9528	5459
3497	9528	6442
3497	9528	9809
10196	9529	4032
10196	9529	4375
10196	9529	1008
10196	9529	1376
10196	9529	5229
10196	9529	413
5855	9530	7545
5855	9530	7335
5855	9530	8340
5855	9530	5891
5855	9530	6404
5855	9530	9838
5855	9530	797
5855	9530	595
5855	9530	7582
17180	9531	7254
17180	9531	1176
17180	9531	2044
17180	9531	594
17180	9531	651
17180	9531	3604
17180	9531	3376
17180	9531	779
14364	9532	2080
14364	9532	4510
14364	9532	589
14364	9532	7644
14364	9532	682
14364	9532	6023
14397	9533	8660
14397	9533	7833
2871	9534	3379
2871	9534	6974
2871	9534	5255
2871	9534	6664
2871	9534	7699
2871	9534	9
2871	9534	3265
7893	9535	1882
7893	9535	9126
15571	9536	7095
15571	9536	4327
15571	9536	5718
5382	9537	4630
5382	9537	5052
5382	9537	5644
5382	9537	616
5382	9537	2714
5382	9537	2855
5382	9537	8448
15147	9538	5359
15147	9538	7708
15147	9538	3907
15147	9538	6843
15147	9538	9739
15091	9539	2016
15091	9539	9272
15091	9539	7135
15091	9539	6568
15091	9539	6407
15091	9539	6253
15091	9539	4160
12758	9540	2276
12758	9540	238
12758	9540	568
12758	9540	5806
12758	9540	6386
12758	9540	7852
12758	9540	5064
12758	9540	5482
5233	9541	2465
5233	9541	3517
5233	9541	5483
5233	9541	4727
11107	9542	4088
11107	9542	2512
11107	9542	3013
11107	9542	4962
11107	9542	6438
11107	9542	2806
16575	9543	904
6736	9544	2085
6736	9544	5496
6736	9544	4079
6736	9544	2365
6736	9544	5880
6736	9544	5705
6736	9544	1108
6736	9544	6710
6293	9545	4648
969	9546	543
2459	9547	7399
2459	9547	2375
2459	9547	8938
2459	9547	1250
2459	9547	1191
2459	9547	3210
19837	9548	3065
19837	9548	4709
19837	9548	8813
19837	9548	8197
17478	9549	9968
17478	9549	3070
17478	9549	9937
17478	9549	8844
17478	9549	183
17478	9549	3692
17478	9549	7049
5440	9550	6508
5440	9550	9288
16200	9551	8684
16200	9551	4530
16200	9551	6667
16200	9551	5890
16200	9551	1865
16200	9551	5181
10727	9552	6737
10727	9552	5292
10727	9552	570
10727	9552	2447
10727	9552	1993
10727	9552	8293
10727	9552	9835
10727	9552	5378
19816	9553	4405
19816	9553	8988
19816	9553	5573
19816	9553	6978
19816	9553	9532
19816	9553	8663
19816	9553	5629
19816	9553	6677
19816	9553	6064
16111	9554	7643
16111	9554	4991
15151	9555	6827
15151	9555	2815
15151	9555	3602
1158	9556	8358
1158	9556	5782
1158	9556	1276
1158	9556	184
1158	9556	1583
1158	9556	5394
1158	9556	5024
1158	9556	3133
1158	9556	6057
17968	9557	6317
17968	9557	230
17968	9557	6610
17968	9557	498
17710	9558	2841
17710	9558	7965
17710	9558	1203
17710	9558	6481
17710	9558	1988
10239	9559	7462
10239	9559	4672
10239	9559	3525
10239	9559	1095
10239	9559	907
10239	9559	3965
7377	9560	9194
7377	9560	9427
7377	9560	6124
7377	9560	6706
7377	9560	7227
7377	9560	4109
11256	9561	4737
11256	9561	4144
10477	9562	2943
10477	9562	518
10477	9562	9668
10477	9562	1477
10477	9562	3877
10477	9562	6020
10477	9562	1534
10477	9562	2604
10477	9562	1417
10457	9563	6502
10457	9563	5383
10457	9563	5339
10457	9563	5884
10457	9563	2703
10457	9563	3332
10457	9563	4741
10457	9563	3997
15746	9564	7873
15746	9564	604
15746	9564	7414
15746	9564	7189
15746	9564	7250
15746	9564	1196
15746	9564	6606
15746	9564	4397
560	9565	9106
560	9565	6089
560	9565	5627
14974	9566	5367
14974	9566	5837
14974	9566	6307
14974	9566	7991
14974	9566	6282
14974	9566	3024
14974	9566	8991
6774	9567	3667
6774	9567	7091
6774	9567	3497
6774	9567	6617
13358	9568	3862
13358	9568	7055
6723	9569	6857
6723	9569	1178
6723	9569	6706
6723	9569	9510
6723	9569	3555
6723	9569	4982
4143	9570	5251
4143	9570	4572
4143	9570	3289
4143	9570	9739
4143	9570	3159
2210	9571	7043
2210	9571	9025
2210	9571	6891
2210	9571	8387
2210	9571	6491
2210	9571	7483
2210	9571	9163
2210	9571	3543
2210	9571	4883
18908	9572	636
18908	9572	6202
18908	9572	3839
18908	9572	4900
18908	9572	2845
18908	9572	1003
18908	9572	161
18908	9572	7600
18908	9572	4294
3553	9573	1211
3553	9573	8806
3553	9573	7898
3553	9573	5547
3553	9573	3622
3553	9573	2253
3553	9573	9977
3553	9573	2873
3553	9573	84
2174	9574	8981
2174	9574	5525
2174	9574	9276
2174	9574	5051
2174	9574	5664
2174	9574	3942
2174	9574	2353
15798	9575	4082
15798	9575	2483
15798	9575	5388
10942	9576	6558
10942	9576	2727
10942	9576	3844
10942	9576	8812
10942	9576	4264
10942	9576	7956
3794	9577	3736
3794	9577	374
3794	9577	6094
17151	9578	3931
17151	9578	934
17151	9578	3195
17151	9578	3660
17151	9578	3029
3679	9579	5701
3679	9579	8363
3679	9579	473
3679	9579	8297
3679	9579	6192
3679	9579	4988
3679	9579	3124
3679	9579	860
9580	9580	9792
9580	9580	8951
3959	9581	3819
3959	9581	801
3959	9581	150
1246	9582	4832
1246	9582	2307
1246	9582	397
1246	9582	4883
10817	9583	6869
10817	9583	8416
10817	9583	9288
10817	9583	7799
10817	9583	8975
10817	9583	1815
3929	9584	2588
3929	9584	114
3929	9584	8971
3929	9584	7237
3929	9584	7850
3929	9584	624
13338	9585	2507
13338	9585	215
13338	9585	6081
13338	9585	2035
7698	9586	5813
16800	9587	5818
16800	9587	9777
16800	9587	2967
16800	9587	5174
16800	9587	2539
16800	9587	259
16800	9587	7096
14620	9588	5323
14620	9588	4201
14620	9588	443
14620	9588	5717
14620	9588	2802
14620	9588	4656
14620	9588	316
14620	9588	1030
14620	9588	3528
17403	9589	1402
16994	9590	5807
16994	9590	6059
16994	9590	1764
16994	9590	6081
16994	9590	9291
16994	9590	8461
16994	9590	4757
10144	9591	5163
5760	9592	3135
5760	9592	9980
1182	9593	5761
1182	9593	2652
17464	9594	529
17464	9594	1595
17464	9594	1306
17464	9594	357
17464	9594	1668
17464	9594	2012
17464	9594	8400
17464	9594	8350
17464	9594	5049
1529	9595	2287
1529	9595	2367
1529	9595	2204
3866	9596	123
3866	9596	9485
3866	9596	4795
3866	9596	6323
16668	9597	6163
16668	9597	5294
16668	9597	9357
16668	9597	1976
8525	9598	9201
8525	9598	1170
8525	9598	7094
8525	9598	7070
8525	9598	6931
8525	9598	8645
8525	9598	6395
8525	9598	8187
1729	9599	1892
1729	9599	675
1729	9599	4619
1729	9599	9525
1729	9599	6913
1729	9599	9432
1729	9599	7643
1729	9599	8984
1729	9599	3855
1570	9600	2510
1393	9601	1561
1393	9601	8329
1393	9601	7078
1393	9601	4700
1393	9601	1653
1393	9601	2538
1393	9601	6707
1393	9601	4678
7323	9602	9714
7323	9602	7210
7323	9602	1637
7323	9602	1320
7323	9602	416
7323	9602	6065
8787	9603	3396
8787	9603	7117
8787	9603	4352
8787	9603	3615
8787	9603	1624
8389	9604	620
8389	9604	5532
8389	9604	3987
8389	9604	7549
8389	9604	4369
866	9605	4827
866	9605	1146
866	9605	5496
866	9605	3271
866	9605	7917
866	9605	907
12627	9606	807
12627	9606	8797
12627	9606	2183
12627	9606	3507
12627	9606	8089
12627	9606	7695
12627	9606	8308
6267	9607	1356
6267	9607	602
6267	9607	8347
18506	9608	5567
18506	9608	3818
18506	9608	6146
18506	9608	2712
18506	9608	5398
18506	9608	8059
18506	9608	4093
4800	9609	5534
13778	9610	1515
13778	9610	1607
13778	9610	2490
16111	9611	4428
16111	9611	6147
16111	9611	5930
16111	9611	3357
14898	9612	9849
14898	9612	4133
14898	9612	9520
14898	9612	2271
7571	9613	6812
7571	9613	980
4871	9614	38
4871	9614	9757
4871	9614	7747
5552	9615	6761
5552	9615	2826
5552	9615	5793
5552	9615	7514
5552	9615	6755
5552	9615	1849
5552	9615	8538
5552	9615	4535
5552	9615	5186
10486	9616	1447
10486	9616	7957
15823	9617	7608
15823	9617	9187
15823	9617	9623
15823	9617	2779
15823	9617	3043
15823	9617	4359
15823	9617	3933
15823	9617	3551
17473	9618	3979
17473	9618	6355
17473	9618	1631
17473	9618	4619
13175	9619	5317
13175	9619	264
13175	9619	2783
13175	9619	2076
13175	9619	2575
13175	9619	716
13175	9619	9331
13175	9619	4973
13175	9619	3003
13964	9620	2407
13964	9620	6775
13964	9620	4170
5575	9621	592
5575	9621	3869
5575	9621	2133
5575	9621	9200
5575	9621	2378
5575	9621	1214
5575	9621	4182
5575	9621	3452
5575	9621	2350
10091	9622	9372
10091	9622	3599
10091	9622	7796
10091	9622	6329
10091	9622	6140
10091	9622	5714
15692	9623	2553
15692	9623	9408
15692	9623	39
15692	9623	9953
15692	9623	775
15692	9623	3052
15692	9623	7348
15692	9623	1515
15692	9623	3875
3341	9624	8294
3341	9624	3508
3341	9624	8472
3341	9624	1853
3341	9624	3294
3341	9624	2755
5586	9625	6284
5586	9625	427
5586	9625	2007
5586	9625	4411
5586	9625	4494
5586	9625	8634
5586	9625	9957
5586	9625	1343
9701	9626	8652
9701	9626	2317
9701	9626	8513
9701	9626	4648
9701	9626	7864
9701	9626	4809
9701	9626	8005
9701	9626	3483
15787	9627	6180
15787	9627	2258
15787	9627	3124
15787	9627	4385
15787	9627	8451
15787	9627	438
15787	9627	749
18523	9628	5946
18523	9628	4634
18523	9628	9836
18523	9628	5990
17999	9629	6504
17999	9629	8349
17999	9629	3527
17999	9629	2361
17999	9629	4017
17999	9629	4552
10599	9630	4561
10599	9630	656
10599	9630	721
10599	9630	1261
10599	9630	7926
10599	9630	3875
10599	9630	6249
5505	9631	1513
5505	9631	6577
5505	9631	3914
5505	9631	4686
5505	9631	5048
4510	9632	7287
4510	9632	8831
4510	9632	5503
4510	9632	8563
4510	9632	7341
4510	9632	4003
4510	9632	7523
4510	9632	6342
15709	9633	1729
15709	9633	3035
15709	9633	8382
4291	9634	471
4291	9634	8785
4291	9634	5630
4291	9634	9393
4291	9634	7715
4291	9634	6629
4291	9634	323
4291	9634	2477
16681	9635	782
7631	9636	1897
7631	9636	597
7631	9636	242
7631	9636	9855
7631	9636	368
7631	9636	3314
7631	9636	9677
7631	9636	6493
13630	9637	3479
13630	9637	3562
13630	9637	4762
13630	9637	4243
13630	9637	8159
110	9638	2288
110	9638	4945
110	9638	7842
110	9638	7627
14605	9639	3608
14605	9639	8380
3715	9640	9854
3715	9640	8054
3715	9640	8266
3715	9640	997
19140	9641	8385
19140	9641	696
19140	9641	5684
19140	9641	7380
19140	9641	5624
19140	9641	2320
19140	9641	4489
19140	9641	3296
3936	9642	5402
3936	9642	6505
3936	9642	2613
17758	9643	7432
16255	9644	6449
16255	9644	7451
16255	9644	8623
16255	9644	1304
16255	9644	470
16255	9644	7748
16255	9644	6567
3937	9645	5637
3937	9645	9442
13026	9646	1968
13026	9646	9547
11991	9647	8068
11991	9647	6421
11991	9647	4442
11991	9647	3971
11991	9647	9917
11991	9647	8285
1562	9648	5890
1562	9648	8993
1562	9648	3246
1562	9648	1297
1562	9648	2990
1562	9648	8863
1562	9648	6838
1562	9648	8841
10523	9649	2152
10523	9649	9534
10523	9649	8785
10523	9649	7420
10523	9649	8600
10523	9649	9431
10523	9649	1445
9381	9650	9904
9381	9650	6505
9381	9650	4089
9381	9650	338
9381	9650	8249
9381	9650	8190
683	9651	2410
19658	9652	4541
19658	9652	1024
19658	9652	8701
19658	9652	676
19658	9652	1052
19658	9652	9508
7192	9653	6525
7192	9653	2924
7192	9653	1672
7192	9653	5056
7192	9653	3626
7192	9653	2001
7192	9653	7293
7192	9653	8097
7192	9653	3124
3648	9654	9433
3648	9654	9073
3648	9654	3117
3648	9654	2536
3648	9654	8102
3648	9654	3161
3648	9654	3774
3648	9654	4533
16316	9655	9719
16316	9655	2124
16316	9655	5420
16316	9655	6936
16316	9655	7070
16316	9655	1731
16316	9655	7007
16316	9655	5443
16316	9655	9222
14647	9656	8348
14647	9656	2131
14647	9656	9641
14647	9656	1038
14647	9656	8684
14647	9656	9520
14647	9656	8573
11016	9657	6954
11016	9657	9625
11016	9657	711
19865	9658	7256
19865	9658	5519
19865	9658	895
19865	9658	8484
19865	9658	7056
19865	9658	6469
19865	9658	278
19865	9658	6546
5196	9659	5721
5196	9659	9012
5196	9659	5271
5196	9659	413
5196	9659	9655
5196	9659	7575
5196	9659	3540
5196	9659	2514
5196	9659	743
15598	9660	3538
15598	9660	7426
16706	9661	7457
16706	9661	5314
16706	9661	3746
16706	9661	6191
11690	9662	2755
11690	9662	607
11690	9662	5588
11690	9662	6266
11690	9662	9149
11690	9662	1993
11690	9662	7578
14446	9663	1226
14446	9663	3851
14446	9663	1696
14446	9663	7123
14446	9663	1755
18739	9664	524
18739	9664	1754
18739	9664	6531
18739	9664	6667
18739	9664	4802
18739	9664	8365
2269	9665	6584
2269	9665	1073
2269	9665	7366
2269	9665	8032
2269	9665	653
2269	9665	1550
12248	9666	1305
12248	9666	5790
12248	9666	642
12248	9666	3513
12248	9666	1115
12248	9666	7823
12248	9666	3013
12248	9666	5037
12248	9666	8253
11238	9667	108
11238	9667	7848
11238	9667	3913
11238	9667	7781
11238	9667	6681
11238	9667	7405
11238	9667	6920
11238	9667	4927
12084	9668	5233
12084	9668	8738
13980	9669	2609
13980	9669	3011
13980	9669	4784
13980	9669	4374
13980	9669	7860
9082	9670	7012
3877	9671	7980
3877	9671	3729
3877	9671	6222
2280	9672	6089
2280	9672	5112
2280	9672	4781
2280	9672	9956
2280	9672	8591
2280	9672	1308
2280	9672	2357
2280	9672	2951
2280	9672	704
18587	9673	194
18587	9673	2498
18587	9673	490
18587	9673	7555
18587	9673	5837
18587	9673	2010
18587	9673	2742
18587	9673	844
18587	9673	5944
14502	9674	9797
14502	9674	2238
14502	9674	6331
1250	9675	8649
1250	9675	6402
1250	9675	1305
1250	9675	9083
1250	9675	7599
1250	9675	8089
1250	9675	7883
1250	9675	3038
1250	9675	8367
19737	9676	4321
1302	9677	1276
1302	9677	1155
15112	9678	1513
15112	9678	8801
13780	9679	5822
13780	9679	944
13780	9679	6038
13780	9679	4057
13780	9679	2895
13780	9679	1114
13780	9679	9028
606	9680	227
606	9680	4147
606	9680	358
606	9680	7430
606	9680	4769
606	9680	6048
3738	9681	6057
3738	9681	6747
3738	9681	5203
3738	9681	8490
3738	9681	3909
18689	9682	5935
18689	9682	6669
18689	9682	7333
18689	9682	5739
18689	9682	6184
18689	9682	1428
18689	9682	4727
18689	9682	4100
313	9683	269
313	9683	6323
313	9683	5697
313	9683	6276
313	9683	9576
313	9683	3297
313	9683	2141
18948	9684	4237
18948	9684	1836
13125	9685	7997
13125	9685	9660
13125	9685	7494
13125	9685	1558
13125	9685	8687
13125	9685	4048
13125	9685	2581
13125	9685	9058
13125	9685	9133
9446	9686	6052
9446	9686	6005
9446	9686	573
2893	9687	2257
2893	9687	4623
2893	9687	500
18374	9688	4149
18374	9688	1236
18374	9688	1893
18374	9688	4405
18374	9688	5092
18374	9688	566
18374	9688	9985
1114	9689	2003
1114	9689	5925
1114	9689	9462
1114	9689	4009
15150	9690	5188
12848	9691	6793
12848	9691	5805
12848	9691	5985
12848	9691	3027
12848	9691	2941
12848	9691	6526
12848	9691	5534
12848	9691	9810
18544	9692	9234
18544	9692	4371
18544	9692	8893
18544	9692	1679
18544	9692	5983
18544	9692	3141
18544	9692	9091
10149	9693	1044
10149	9693	9740
10149	9693	9175
10149	9693	6097
10149	9693	6732
10149	9693	8257
10149	9693	5681
103	9694	9610
103	9694	1431
103	9694	5733
103	9694	8367
103	9694	3516
103	9694	9898
1881	9695	8509
9210	9696	3489
9210	9696	1191
9210	9696	990
13723	9697	4412
13723	9697	4421
13723	9697	1020
13723	9697	4968
13723	9697	5812
13723	9697	3366
13723	9697	5805
13723	9697	6970
5384	9698	5147
5384	9698	5454
12887	9699	3305
15432	9700	7861
15432	9700	6831
15432	9700	2017
15432	9700	7692
6992	9701	7809
6992	9701	8825
6992	9701	4497
6992	9701	9132
6992	9701	308
6992	9701	6394
19395	9702	7414
19395	9702	5167
3995	9703	4640
3995	9703	6659
4982	9704	5034
4982	9704	3824
4982	9704	2731
4982	9704	9480
4982	9704	3662
4982	9704	8341
4982	9704	5571
5968	9705	8258
5968	9705	3448
16176	9706	1891
16176	9706	5117
16176	9706	8538
4722	9707	5317
4722	9707	6356
4722	9707	5033
1206	9708	3587
3688	9709	8202
3688	9709	3410
3688	9709	7070
3688	9709	1793
3688	9709	7127
15428	9710	1032
15428	9710	1177
12419	9711	6812
12419	9711	1548
6842	9712	8743
6842	9712	7137
6842	9712	797
5178	9713	2919
5178	9713	2293
5178	9713	745
5178	9713	3615
5178	9713	712
5589	9714	3229
5589	9714	5341
5589	9714	6691
5589	9714	141
5589	9714	8026
17644	9715	1411
17644	9715	9615
17644	9715	6603
17644	9715	9938
17644	9715	5231
11884	9716	8737
11884	9716	2341
11884	9716	9143
11884	9716	9412
11884	9716	5263
11884	9716	1267
11884	9716	6829
16623	9717	6186
16623	9717	7850
16623	9717	5409
16623	9717	136
18808	9718	6803
18808	9718	1364
18808	9718	7283
18808	9718	6823
18808	9718	6340
15212	9719	6457
15212	9719	1386
15212	9719	1006
17710	9720	6642
17710	9720	9894
17710	9720	9899
17710	9720	3471
17710	9720	1793
17710	9720	5844
17710	9720	5340
17710	9720	5769
17710	9720	4752
252	9721	7611
252	9721	6086
252	9721	4047
252	9721	7470
252	9721	9185
252	9721	4902
9601	9722	1501
9601	9722	397
9601	9722	6419
9601	9722	11
9601	9722	7416
9601	9722	4202
18581	9723	5766
18581	9723	1114
18581	9723	8458
15284	9724	6719
15284	9724	3920
15284	9724	350
15284	9724	9615
15284	9724	2764
15284	9724	6482
15284	9724	8220
15284	9724	7536
15284	9724	597
6077	9725	1566
6077	9725	7289
6077	9725	4618
6077	9725	7665
6077	9725	626
6077	9725	2099
6077	9725	6654
12537	9726	2301
12537	9726	5503
12537	9726	3571
8335	9727	7206
8335	9727	2129
8335	9727	6419
8335	9727	8795
8335	9727	924
3099	9728	6095
12118	9729	8788
12118	9729	5763
12118	9729	6585
12118	9729	7330
12118	9729	3500
12118	9729	4178
12612	9730	5723
12612	9730	630
12612	9730	4729
12612	9730	8196
12612	9730	9425
12612	9730	3067
12612	9730	349
12612	9730	8407
12612	9730	2895
18959	9731	9005
6363	9732	9488
6363	9732	6317
6363	9732	5454
6363	9732	1857
6363	9732	5924
6363	9732	5754
6363	9732	4343
9383	9733	3828
9383	9733	243
9383	9733	8025
9383	9733	8011
9383	9733	747
9383	9733	210
19394	9734	4907
19394	9734	1543
19394	9734	1274
19394	9734	6816
19394	9734	2813
959	9735	6553
959	9735	43
16134	9736	5096
16134	9736	6500
16134	9736	9741
16134	9736	5003
16134	9736	9377
1837	9737	8384
1837	9737	4769
1837	9737	4647
1837	9737	1676
1837	9737	2113
1837	9737	173
1837	9737	5024
11127	9738	6850
11127	9738	623
11127	9738	3326
11127	9738	1968
11127	9738	5534
4413	9739	5695
4413	9739	3201
9753	9740	3105
9753	9740	5829
9753	9740	8114
9753	9740	3692
1083	9741	7132
1083	9741	7617
6301	9742	5357
6301	9742	359
6301	9742	4658
6301	9742	1392
6301	9742	8436
6301	9742	9893
6301	9742	3237
6301	9742	9668
6719	9743	3901
6719	9743	5132
6719	9743	2247
13959	9744	5333
13959	9744	1377
13959	9744	2305
13959	9744	9250
13959	9744	2254
13959	9744	5924
13959	9744	9225
17786	9745	2253
17786	9745	2779
17786	9745	2235
17786	9745	7186
17786	9745	659
17786	9745	1460
17786	9745	4982
17786	9745	7811
17786	9745	2484
3468	9746	9419
3468	9746	6791
3468	9746	8894
3468	9746	7537
3468	9746	4296
14149	9747	4985
14149	9747	8140
14149	9747	444
14149	9747	2200
19	9748	124
19	9748	610
19	9748	8820
19	9748	3668
19	9748	8673
19	9748	268
19	9748	1966
19	9748	5998
3880	9749	5067
3880	9749	2266
3880	9749	4786
3880	9749	935
3880	9749	4474
3880	9749	54
1326	9750	692
1326	9750	1322
1326	9750	4762
1326	9750	5573
1326	9750	6153
1326	9750	116
14327	9751	2350
14327	9751	4087
14327	9751	1143
14327	9751	8313
14327	9751	7738
14327	9751	214
14327	9751	9029
14327	9751	339
3320	9752	3249
3320	9752	2433
3320	9752	6226
3320	9752	7191
3320	9752	9711
3320	9752	8311
4795	9753	7419
4795	9753	5039
4795	9753	5874
4795	9753	9784
4795	9753	3998
4795	9753	4622
4795	9753	1782
4795	9753	648
4795	9753	8361
9172	9754	4321
9172	9754	3224
3009	9755	928
3009	9755	4102
3009	9755	7602
3009	9755	1219
3009	9755	4877
3009	9755	7507
18578	9756	4319
17499	9757	371
17499	9757	4851
17499	9757	3102
17499	9757	5099
17499	9757	8843
17499	9757	578
17499	9757	1992
17499	9757	2918
17499	9757	5565
6142	9758	2360
6142	9758	9389
6142	9758	2060
6142	9758	5428
6142	9758	2786
6142	9758	8680
6142	9758	9393
6142	9758	9886
17455	9759	1672
9178	9760	2383
9178	9760	7303
9178	9760	2728
9178	9760	171
4459	9761	439
4459	9761	7567
13919	9762	1451
13919	9762	4425
13919	9762	1299
13919	9762	4476
13919	9762	685
13919	9762	4198
3001	9763	1163
3001	9763	9183
3001	9763	5143
3001	9763	9271
3001	9763	2750
3001	9763	4698
3001	9763	3797
10493	9764	7214
10493	9764	4780
10493	9764	7671
10493	9764	1884
10493	9764	8532
10493	9764	3368
10493	9764	3289
10493	9764	4187
18658	9765	4910
18658	9765	8141
3874	9766	7183
3874	9766	1297
3874	9766	9315
13970	9767	8853
13970	9767	4191
13970	9767	1347
13970	9767	6751
13970	9767	9951
13970	9767	4862
13970	9767	87
13970	9767	6788
10285	9768	7756
10285	9768	6193
10285	9768	1744
10285	9768	5130
10285	9768	2492
2688	9769	3564
2688	9769	7468
2688	9769	3621
2688	9769	9098
2688	9769	4413
2688	9769	8254
2688	9769	7413
2688	9769	6343
2688	9769	2214
16812	9770	3913
16812	9770	4496
16812	9770	4950
16812	9770	7747
16812	9770	282
16812	9770	9779
6798	9771	1881
268	9772	7766
268	9772	4897
268	9772	1219
268	9772	8385
268	9772	6486
268	9772	2650
268	9772	8700
12893	9773	7758
12893	9773	9305
8943	9774	4051
8943	9774	4482
8943	9774	7334
8943	9774	1950
6338	9775	7539
377	9776	7788
377	9776	8052
11618	9777	5192
11618	9777	6119
339	9778	4999
339	9778	9689
339	9778	4873
339	9778	117
339	9778	2523
339	9778	5456
339	9778	7844
11262	9779	2709
11262	9779	895
11262	9779	9750
11262	9779	7468
11262	9779	1383
13385	9780	9336
8416	9781	1130
8416	9781	5756
8416	9781	7425
8416	9781	1555
8416	9781	9230
8416	9781	9544
8416	9781	5416
8416	9781	793
16520	9782	8689
16520	9782	4599
16520	9782	8108
16520	9782	4118
16520	9782	8142
16520	9782	4193
16520	9782	5587
16520	9782	5855
14819	9783	4723
14819	9783	4714
14819	9783	7450
7946	9784	1879
7946	9784	3408
7946	9784	9013
7946	9784	411
7946	9784	7608
7946	9784	6722
4615	9785	5318
4615	9785	1087
4615	9785	8072
4615	9785	9798
14494	9786	1220
14494	9786	7585
1985	9787	2508
1985	9787	6654
1985	9787	8537
1985	9787	1917
7331	9788	8961
14065	9789	9818
14065	9789	830
14065	9789	4124
14065	9789	165
9349	9790	8198
9349	9790	4708
9349	9790	5324
9349	9790	8226
9349	9790	9602
19274	9791	759
19274	9791	6898
19274	9791	2275
19274	9791	563
19274	9791	4823
19274	9791	5154
19274	9791	6394
19274	9791	9662
19274	9791	5023
19460	9792	2974
19460	9792	6863
19460	9792	4843
19460	9792	2212
19460	9792	7633
19460	9792	8442
19460	9792	658
19460	9792	1246
19460	9792	3821
17948	9793	9275
17948	9793	1393
17948	9793	8577
2573	9794	2222
2573	9794	9575
2573	9794	9946
2573	9794	6813
2573	9794	4757
2573	9794	2109
2573	9794	5971
19582	9795	8765
19582	9795	4842
19582	9795	1196
19544	9796	1058
19544	9796	3363
19544	9796	9419
19544	9796	343
19544	9796	4723
19544	9796	6943
18102	9797	2405
18102	9797	8172
18102	9797	4069
18102	9797	2306
18102	9797	4975
18102	9797	5144
18102	9797	3273
18102	9797	3674
14071	9798	9973
14071	9798	3094
14071	9798	5108
14071	9798	4175
18135	9799	596
18135	9799	3319
11249	9800	9126
11249	9800	3291
11249	9800	5789
11249	9800	6729
11249	9800	4000
11249	9800	3829
13846	9801	6959
13846	9801	4917
13846	9801	1908
13846	9801	7537
13846	9801	4884
13846	9801	7167
13846	9801	6481
11211	9802	8004
11211	9802	2123
11211	9802	5347
11211	9802	9071
11211	9802	94
17520	9803	1601
17520	9803	9102
17520	9803	4491
18749	9804	5263
18749	9804	3919
18749	9804	9580
15166	9805	2315
15166	9805	536
15166	9805	3148
15166	9805	2746
3012	9806	5183
19347	9807	9048
8622	9808	1442
8622	9808	982
8622	9808	6674
8622	9808	8146
8622	9808	3580
8622	9808	372
8622	9808	9310
17396	9809	9687
17396	9809	9678
17396	9809	9479
17396	9809	4690
17396	9809	3257
17396	9809	2838
17396	9809	5979
17396	9809	1858
17062	9810	7518
17062	9810	4838
17062	9810	6874
17062	9810	1008
17062	9810	2845
17062	9810	1119
1593	9811	8516
1593	9811	3443
1593	9811	9779
1593	9811	4540
1593	9811	559
17141	9812	4727
17141	9812	9433
17141	9812	335
17141	9812	3712
17141	9812	9152
17141	9812	6974
17141	9812	9089
17141	9812	1067
17141	9812	7325
1535	9813	7047
1535	9813	2743
1535	9813	2290
1535	9813	6176
1535	9813	4746
1535	9813	9662
1535	9813	467
8357	9814	735
8357	9814	9906
8357	9814	722
8357	9814	5626
8357	9814	554
8357	9814	8814
8357	9814	9817
8357	9814	7801
8357	9814	3465
19280	9815	542
19280	9815	6942
19280	9815	6965
16606	9816	6615
16606	9816	5745
16606	9816	7937
16606	9816	5382
16606	9816	4201
16606	9816	397
16395	9817	8287
16395	9817	3159
16395	9817	7358
16395	9817	2562
19051	9818	7828
19051	9818	5817
19051	9818	5748
19051	9818	1778
19051	9818	2931
19051	9818	2174
19051	9818	1354
19051	9818	1148
19051	9818	767
18108	9819	4647
18108	9819	1784
18108	9819	3973
18108	9819	6734
18108	9819	6387
18108	9819	4480
18108	9819	9004
18108	9819	3763
13387	9820	3825
13387	9820	8654
13387	9820	701
13387	9820	2696
13387	9820	8475
13387	9820	3710
10986	9821	1984
10986	9821	4356
10986	9821	1625
10986	9821	573
10986	9821	9062
10986	9821	1409
10986	9821	1029
10986	9821	9057
15421	9822	7131
15421	9822	4968
15421	9822	7533
15421	9822	8727
15421	9822	4170
15421	9822	879
15421	9822	6119
15421	9822	4524
15421	9822	4070
6262	9823	6104
6262	9823	9128
6262	9823	5312
6262	9823	2870
6262	9823	7111
6262	9823	7657
6262	9823	5606
6262	9823	756
6262	9823	7408
16573	9824	3521
16573	9824	7250
16573	9824	698
16573	9824	721
16573	9824	5399
16573	9824	588
16573	9824	1984
16573	9824	2296
16573	9824	1036
17383	9825	3880
2575	9826	9574
2575	9826	7684
2575	9826	3846
2575	9826	684
2575	9826	553
2575	9826	4671
2575	9826	8228
2575	9826	478
5547	9827	2180
5547	9827	885
9529	9828	6052
9529	9828	3344
9529	9828	1314
9529	9828	8719
9529	9828	5961
13028	9829	2465
13028	9829	9632
13028	9829	9245
13028	9829	5716
15792	9830	1561
15792	9830	8631
15792	9830	9769
15792	9830	536
3699	9831	7009
3699	9831	8426
3699	9831	6616
3699	9831	1083
3699	9831	8266
3699	9831	2023
3699	9831	1504
3699	9831	1820
3699	9831	5635
14390	9832	4660
14390	9832	1663
14390	9832	3530
14390	9832	7045
14390	9832	993
14390	9832	7772
14390	9832	764
3693	9833	2561
3693	9833	4426
3693	9833	3229
3693	9833	8549
3693	9833	2291
3693	9833	6058
3693	9833	3881
11086	9834	7511
11086	9834	4555
11086	9834	7012
11086	9834	7922
11086	9834	6714
11086	9834	9622
11086	9834	3487
15823	9835	4156
15823	9835	7764
15823	9835	1694
15823	9835	9384
15823	9835	4540
15823	9835	1117
15823	9835	9624
15823	9835	3411
15823	9835	7131
10105	9836	1624
10105	9836	3400
10105	9836	9999
12489	9837	1038
12489	9837	3623
12489	9837	9557
12489	9837	8306
12489	9837	5746
12489	9837	4549
12489	9837	8050
10361	9838	233
10361	9838	9271
10361	9838	4394
10361	9838	6966
10361	9838	1742
10361	9838	636
3348	9839	4406
5421	9840	2133
5421	9840	4907
5421	9840	1607
5421	9840	5363
5421	9840	507
5421	9840	6563
5421	9840	7451
5421	9840	2448
5421	9840	5348
11967	9841	7657
11967	9841	2350
12284	9842	5680
12284	9842	7102
12284	9842	7087
12284	9842	5041
11095	9843	5325
11095	9843	6213
11095	9843	9909
11095	9843	1962
11095	9843	7543
10399	9844	7262
10399	9844	4365
10399	9844	3020
10399	9844	8938
10399	9844	631
10399	9844	8829
10399	9844	8473
10399	9844	1218
13085	9845	4315
13085	9845	552
13085	9845	6226
13085	9845	2140
13085	9845	3294
13085	9845	321
13085	9845	6919
13085	9845	2588
13085	9845	4729
10718	9846	1030
10718	9846	6410
10718	9846	2537
10718	9846	8790
10718	9846	8181
10718	9846	6461
10718	9846	9381
10718	9846	6827
240	9847	675
240	9847	9791
240	9847	5729
240	9847	4788
240	9847	9878
1815	9848	3155
3890	9849	5050
3890	9849	7186
3890	9849	4587
3890	9849	5952
3890	9849	4132
3890	9849	4476
3890	9849	615
3890	9849	8069
5712	9850	5194
5712	9850	9571
5712	9850	7890
5712	9850	4448
5712	9850	4671
5712	9850	6617
5712	9850	1788
5712	9850	4151
205	9851	4926
205	9851	6752
9640	9852	7676
9640	9852	1936
9640	9852	822
17423	9853	6874
6980	9854	7292
6980	9854	8918
6980	9854	2876
15603	9855	3342
15603	9855	8623
15603	9855	2641
15603	9855	9242
127	9856	8775
127	9856	6456
127	9856	9215
127	9856	9138
127	9856	9754
127	9856	611
6972	9857	1287
6972	9857	2391
6972	9857	7585
6972	9857	9855
6972	9857	7312
6972	9857	4801
6972	9857	9160
6972	9857	2067
17046	9858	5734
10976	9859	4159
10976	9859	2343
10976	9859	9272
10976	9859	5707
10976	9859	8258
10976	9859	2676
10976	9859	3517
10976	9859	7208
12735	9860	4301
12735	9860	7057
12735	9860	804
12735	9860	602
12735	9860	8278
12735	9860	7907
12735	9860	436
12735	9860	9928
11269	9861	8926
11269	9861	249
14913	9862	3824
16248	9863	6007
16248	9863	8879
16248	9863	205
16248	9863	6359
16248	9863	9593
16248	9863	8361
4480	9864	4377
4480	9864	1917
4480	9864	6522
4480	9864	2081
4480	9864	6450
4480	9864	7238
4480	9864	4028
4480	9864	1572
902	9865	7607
902	9865	7058
902	9865	9795
902	9865	6719
902	9865	7658
902	9865	4168
902	9865	5953
902	9865	6659
902	9865	2035
16969	9866	3967
16969	9866	4580
16969	9866	8705
16969	9866	5989
16969	9866	2269
16969	9866	8348
16969	9866	796
15028	9867	9387
15028	9867	4436
15028	9867	4691
13451	9868	5210
13451	9868	4560
13451	9868	3148
13451	9868	4714
13451	9868	2461
13451	9868	7200
13451	9868	4299
10188	9869	2608
10188	9869	1201
10188	9869	6733
10188	9869	7335
10188	9869	6731
10188	9869	8149
10188	9869	2717
10188	9869	1041
8376	9870	6040
8376	9870	7950
8376	9870	3605
8376	9870	8786
8376	9870	7343
8376	9870	6458
8376	9870	600
14664	9871	8755
14664	9871	4428
14664	9871	6590
14664	9871	260
14664	9871	4420
14664	9871	1817
14664	9871	40
14664	9871	9710
14664	9871	1096
19762	9872	2355
19762	9872	7531
19762	9872	5089
19762	9872	286
19762	9872	8756
19762	9872	8409
19762	9872	5943
12405	9873	8996
12405	9873	5580
12405	9873	2301
12405	9873	7025
12405	9873	8604
19153	9874	7007
19153	9874	8586
19153	9874	1850
19153	9874	480
19153	9874	7912
19153	9874	3788
8228	9875	8860
8228	9875	956
8228	9875	8087
8228	9875	9729
8228	9875	6653
8228	9875	2373
14432	9876	9590
14432	9876	7011
14432	9876	3018
14432	9876	2045
14432	9876	6377
524	9877	6774
524	9877	3890
524	9877	3245
524	9877	986
524	9877	7086
18918	9878	6675
18918	9878	4127
18918	9878	7276
18918	9878	7705
18918	9878	8626
18918	9878	1221
18918	9878	5582
18918	9878	5265
18918	9878	841
9460	9879	6706
9460	9879	552
9460	9879	8393
9460	9879	3250
9460	9879	1068
9460	9879	9090
9460	9879	6189
7787	9880	3643
7787	9880	9959
7787	9880	3881
7787	9880	4753
7787	9880	7262
14059	9881	7784
14059	9881	9947
14059	9881	9072
14059	9881	2136
14059	9881	3121
14059	9881	5333
3325	9882	6618
3325	9882	2124
3325	9882	6071
3325	9882	1799
18119	9883	6089
7744	9884	48
7744	9884	9474
7744	9884	3003
7744	9884	3408
7744	9884	1904
7744	9884	9998
13230	9885	3191
13230	9885	3371
13230	9885	8846
13230	9885	4049
13230	9885	4270
13230	9885	5330
13230	9885	4009
8112	9886	6239
8112	9886	8945
8112	9886	3322
8112	9886	645
8112	9886	5955
8112	9886	9933
6247	9887	8113
6247	9887	721
6247	9887	3530
6247	9887	2298
6247	9887	5591
6247	9887	7981
19930	9888	4951
19930	9888	6247
19930	9888	8612
19930	9888	1590
19930	9888	2779
19930	9888	2474
16807	9889	3178
16807	9889	4919
16807	9889	8371
7923	9890	6430
7923	9890	3513
7923	9890	484
7923	9890	3012
3247	9891	6190
3247	9891	9848
3247	9891	2433
3247	9891	7067
3247	9891	7252
3247	9891	8472
3247	9891	6953
3247	9891	9387
5816	9892	6791
5816	9892	2482
5816	9892	8042
5816	9892	4004
5816	9892	7117
5816	9892	3102
5816	9892	4025
12915	9893	1549
12915	9893	9282
12915	9893	6865
12915	9893	6863
12915	9893	8753
12915	9893	9159
12915	9893	4899
12915	9893	4399
12915	9893	3223
14454	9894	4852
14454	9894	3296
14454	9894	3268
14454	9894	5334
14454	9894	4302
14454	9894	5404
14454	9894	6904
14454	9894	9817
14454	9894	8519
15354	9895	3626
15354	9895	3710
15354	9895	228
15354	9895	4076
15354	9895	6573
15354	9895	7764
2063	9896	1742
2063	9896	21
2063	9896	3019
5669	9897	1404
5669	9897	5608
5669	9897	8450
5669	9897	2580
5669	9897	6083
5669	9897	8742
5669	9897	253
5669	9897	9085
13778	9898	27
93	9899	6970
93	9899	5604
93	9899	5278
1772	9900	120
1772	9900	386
1772	9900	7185
1772	9900	6359
1772	9900	4441
1772	9900	5453
1772	9900	2333
1772	9900	9939
19379	9901	2459
19379	9901	570
19379	9901	7033
13620	9902	5037
13620	9902	1246
13620	9902	3053
13620	9902	4549
13620	9902	5867
13620	9902	4856
13620	9902	8613
17101	9903	8240
1395	9904	8760
1395	9904	748
1395	9904	5167
1395	9904	696
1395	9904	4333
14771	9905	6797
3304	9906	8840
3304	9906	6324
3304	9906	4487
3304	9906	335
3304	9906	5261
3304	9906	3720
3304	9906	17
10365	9907	5385
10365	9907	484
10365	9907	3666
10365	9907	1181
10365	9907	7092
10365	9907	2115
10365	9907	8117
10365	9907	8028
5028	9908	1333
5028	9908	1333
5028	9908	8284
5028	9908	9520
5028	9908	6531
5028	9908	4675
5028	9908	7749
5028	9908	2925
5028	9908	6013
6209	9909	7754
6209	9909	4946
6209	9909	7004
6209	9909	8295
19254	9910	4680
19254	9910	6639
19254	9910	4686
19254	9910	5668
19254	9910	5085
16019	9911	2115
13124	9912	9126
13124	9912	7168
10924	9913	5089
10924	9913	9175
10924	9913	961
10924	9913	3967
19268	9914	3050
19268	9914	2076
19268	9914	52
19268	9914	4588
10574	9915	931
10574	9915	6007
10574	9915	7702
10574	9915	4744
10574	9915	549
10574	9915	2558
10574	9915	9730
10574	9915	7156
10574	9915	6158
18416	9916	7088
18416	9916	9042
18416	9916	5422
18416	9916	6962
18416	9916	9669
11350	9917	3818
8732	9918	5876
8732	9918	2305
8732	9918	5852
8732	9918	5193
8732	9918	7671
8732	9918	3481
5044	9919	2314
5044	9919	4529
5044	9919	1288
5044	9919	7658
2949	9920	5841
3432	9921	4748
3432	9921	7468
3432	9921	2567
3432	9921	6818
3432	9921	9896
3432	9921	8569
3432	9921	9466
3432	9921	9723
3432	9921	2865
1045	9922	1997
1045	9922	9870
1045	9922	5526
1045	9922	9553
1045	9922	5574
1045	9922	7549
1045	9922	4241
1045	9922	8179
1045	9922	6162
9461	9923	5613
9461	9923	9950
9461	9923	5135
9461	9923	9000
9461	9923	156
9461	9923	764
12579	9924	9901
12579	9924	2686
12579	9924	5207
12579	9924	7565
12579	9924	7986
12579	9924	1459
12579	9924	8457
12579	9924	431
760	9925	1585
760	9925	1303
760	9925	2542
760	9925	1764
760	9925	8356
16514	9926	5706
16514	9926	9372
16514	9926	9116
1148	9927	6435
1148	9927	9521
1148	9927	2641
1148	9927	1540
1148	9927	3613
12307	9928	7527
12307	9928	6086
12307	9928	1521
12307	9928	9731
12307	9928	2339
12307	9928	497
12307	9928	6459
16579	9929	551
16579	9929	4882
16579	9929	4532
16579	9929	7417
16579	9929	9263
16579	9929	4298
16579	9929	1109
16579	9929	7436
17912	9930	6183
17912	9930	7943
17912	9930	7595
17912	9930	4171
17912	9930	2690
17912	9930	8085
17912	9930	9581
17912	9930	6432
7695	9931	7229
7695	9931	2821
7695	9931	8378
7695	9931	5531
7695	9931	9212
7695	9931	6328
7695	9931	5474
7695	9931	2074
12489	9932	3360
12489	9932	4602
2066	9933	4881
2066	9933	1779
2066	9933	5861
8477	9934	1726
8477	9934	5309
8477	9934	9462
8477	9934	2324
8477	9934	3850
8477	9934	7779
2275	9935	4077
2275	9935	7991
2275	9935	4185
2275	9935	437
2275	9935	4980
2275	9935	563
2275	9935	535
4521	9936	314
4521	9936	7490
4521	9936	480
4521	9936	3633
4521	9936	7880
4521	9936	9395
4521	9936	2947
1874	9937	3808
17573	9938	4211
17573	9938	2377
17573	9938	4129
17573	9938	2319
17573	9938	806
17573	9938	7081
17573	9938	1149
18056	9939	4222
18056	9939	2410
18056	9939	585
18056	9939	906
18056	9939	2046
18056	9939	3179
18056	9939	4263
18056	9939	5248
18056	9939	3000
10637	9940	5127
10637	9940	591
10637	9940	1611
10637	9940	5303
10637	9940	9071
10637	9940	7961
10637	9940	9996
10637	9940	8490
10637	9940	2937
12229	9941	3503
12229	9941	9107
12229	9941	8538
4711	9942	3254
4711	9942	3223
4711	9942	7637
4711	9942	3177
4711	9942	8049
4711	9942	8188
4711	9942	9682
5236	9943	8732
5236	9943	9618
5236	9943	288
5236	9943	8737
5236	9943	6331
5236	9943	1181
5236	9943	7505
1453	9944	9252
1453	9944	5091
1453	9944	3613
1453	9944	5345
1453	9944	9955
1453	9944	5912
1453	9944	1441
1453	9944	8294
17163	9945	7407
17163	9945	6173
17163	9945	9355
17163	9945	3022
17163	9945	4404
17163	9945	8484
7149	9946	6853
7149	9946	1704
7149	9946	590
7149	9946	3975
7149	9946	2259
7149	9946	3088
7149	9946	849
7149	9946	4753
1850	9947	4602
1850	9947	8435
1850	9947	2185
1850	9947	2660
1850	9947	494
1850	9947	5390
1850	9947	9914
1850	9947	4153
16254	9948	395
16254	9948	6104
16254	9948	8490
16254	9948	9499
16254	9948	1781
16254	9948	5804
16254	9948	6205
16777	9949	5369
16777	9949	1661
16777	9949	8996
16777	9949	7851
16777	9949	2079
16777	9949	1276
16777	9949	9525
16777	9949	234
17447	9950	6194
17447	9950	8752
17447	9950	4647
69	9951	8081
69	9951	9044
69	9951	9472
69	9951	1317
69	9951	1188
69	9951	9880
69	9951	8008
16482	9952	6965
16482	9952	9457
16482	9952	9779
16482	9952	5154
16482	9952	3164
16482	9952	4460
16482	9952	8783
15652	9953	5865
15652	9953	2014
15652	9953	6994
15652	9953	9516
15652	9953	1297
12655	9954	7842
15242	9955	2047
15242	9955	9906
15242	9955	8029
15242	9955	9047
15242	9955	6514
15242	9955	7943
15242	9955	4928
15242	9955	9432
17894	9956	2595
17894	9956	9473
17894	9956	369
7462	9957	2247
7462	9957	3315
2687	9958	4593
2687	9958	3864
2687	9958	9734
18330	9959	8112
18330	9959	7484
18330	9959	7798
18330	9959	3995
14863	9960	9226
14863	9960	6186
14863	9960	6297
14863	9960	3884
14863	9960	2209
14863	9960	4492
14863	9960	1012
14863	9960	4864
14863	9960	3390
3002	9961	2208
3002	9961	2281
3002	9961	9175
3002	9961	3633
3002	9961	5755
3882	9962	1615
3882	9962	8649
6280	9963	7365
6280	9963	2270
6280	9963	334
6280	9963	2255
6280	9963	5435
6280	9963	4554
6280	9963	664
6280	9963	4266
41	9964	1962
7152	9965	7399
14585	9966	2050
4767	9967	5928
4767	9967	8151
4767	9967	3891
4767	9967	4210
18019	9968	9025
1105	9969	729
1105	9969	4244
1105	9969	8403
1105	9969	4725
1105	9969	3233
7945	9970	147
7945	9970	9245
7945	9970	6814
7945	9970	2193
7945	9970	2463
7945	9970	190
7945	9970	506
7945	9970	2040
5535	9971	6812
5535	9971	4509
15483	9972	1714
15483	9972	5784
15483	9972	5541
15483	9972	5898
15483	9972	8482
15483	9972	2278
15483	9972	8459
17928	9973	3182
17928	9973	7238
17928	9973	5044
17928	9973	2244
17928	9973	5584
6557	9974	820
6557	9974	867
6557	9974	4261
6557	9974	8715
6557	9974	4853
6557	9974	3686
6557	9974	3460
6557	9974	2275
6557	9974	587
15648	9975	1872
15648	9975	6669
15648	9975	2639
15648	9975	734
15648	9975	2968
15648	9975	5320
15648	9975	7915
13257	9976	7621
13257	9976	8762
13257	9976	2125
13257	9976	17
13257	9976	6493
920	9977	6671
920	9977	9863
920	9977	9839
5613	9978	6640
14475	9979	2688
14475	9979	8624
14475	9979	5393
10818	9980	7500
10818	9980	9436
10818	9980	6401
10818	9980	2585
10818	9980	5415
10818	9980	6859
10818	9980	5230
10818	9980	1524
10818	9980	9071
11526	9981	75
11526	9981	3243
11453	9982	4703
11453	9982	1257
11453	9982	5083
11453	9982	245
11453	9982	3920
11453	9982	91
11453	9982	6469
15986	9983	9811
15986	9983	4619
15986	9983	8089
15986	9983	7300
15986	9983	161
15986	9983	7057
15986	9983	8368
15986	9983	9412
8989	9984	2162
8989	9984	1803
8989	9984	1979
8989	9984	7572
8989	9984	6264
8989	9984	620
10478	9985	9933
10478	9985	473
10478	9985	8721
10478	9985	1130
10478	9985	9290
10478	9985	6712
10478	9985	5036
10478	9985	1331
10478	9985	5193
14342	9986	8935
14342	9986	1780
14342	9986	3743
14342	9986	4793
14342	9986	1977
14342	9986	1677
14342	9986	4818
11895	9987	6488
11895	9987	4456
11895	9987	8189
11895	9987	8720
11895	9987	8920
11895	9987	553
11895	9987	5189
11895	9987	7993
11895	9987	9042
7668	9988	8559
7668	9988	4227
8412	9989	3474
8412	9989	9548
8412	9989	7335
8412	9989	3716
8412	9989	1119
3343	9990	1159
3343	9990	6380
3343	9990	2685
3343	9990	4034
3343	9990	7960
3343	9990	5948
3343	9990	5969
3343	9990	6392
3343	9990	9165
17424	9991	6449
17424	9991	4495
17424	9991	4144
17424	9991	9238
17424	9991	8130
17424	9991	8053
17424	9991	595
17424	9991	691
17301	9992	837
17301	9992	8976
17301	9992	8482
17301	9992	7094
17301	9992	6852
6600	9993	866
6600	9993	1239
6600	9993	7644
11393	9994	6434
11298	9995	811
11298	9995	6132
11298	9995	1284
16753	9996	3264
16753	9996	8078
16753	9996	4747
16753	9996	202
16753	9996	9047
19092	9997	640
19092	9997	3801
19092	9997	5624
19092	9997	9305
19092	9997	1075
19092	9997	6222
19092	9997	49
19092	9997	734
19092	9997	8926
14007	9998	5948
14007	9998	7206
5119	9999	1791
5119	9999	5223
5119	9999	1542
5119	9999	2611
5119	9999	7281
7004	10000	7650
7004	10000	580
7004	10000	774
7004	10000	3579
7004	10000	8275
7004	10000	8293
12934	10001	6941
12934	10001	5365
12934	10001	7332
12934	10001	6645
12934	10001	240
12934	10001	6731
12934	10001	4020
12934	10001	4615
2761	10002	6378
2761	10002	2423
2761	10002	4496
2761	10002	9165
2761	10002	2507
2761	10002	9548
2761	10002	6104
2761	10002	4499
2761	10002	7799
16077	10003	7161
16077	10003	8585
16213	10004	7127
16213	10004	706
10403	10005	6016
10403	10005	5432
10403	10005	7541
10403	10005	475
16547	10006	6312
6944	10007	5247
6944	10007	9336
12923	10008	6011
12923	10008	1082
12923	10008	6171
12923	10008	9694
12923	10008	2660
12923	10008	3137
16213	10009	8549
16213	10009	4959
16213	10009	1191
12874	10010	4838
12874	10010	8218
8457	10011	5827
8457	10011	3362
8457	10011	3014
8457	10011	2754
8457	10011	9155
8457	10011	4256
5608	10012	3997
5608	10012	243
5608	10012	5907
5608	10012	8174
5608	10012	3675
5608	10012	3516
5608	10012	620
5608	10012	5124
5608	10012	169
6365	10013	9332
6365	10013	6748
6365	10013	4221
6365	10013	6392
6365	10013	671
1826	10014	5285
1826	10014	8620
1826	10014	1371
1826	10014	7817
1826	10014	893
1826	10014	8437
1826	10014	1425
1826	10014	4244
7152	10015	7164
7152	10015	3101
7543	10016	4684
7543	10016	6156
7543	10016	5727
7543	10016	8927
7543	10016	6911
7543	10016	9088
7543	10016	9684
7543	10016	8866
6220	10017	6686
6220	10017	4922
6220	10017	435
13489	10018	5024
13489	10018	2094
15640	10019	4917
15640	10019	2116
15640	10019	669
15640	10019	1529
15640	10019	2907
19887	10020	6569
19887	10020	3178
19887	10020	5451
19887	10020	3749
19887	10020	1927
19887	10020	3721
19887	10020	9951
19887	10020	1839
19887	10020	5538
15305	10021	9451
15305	10021	8973
15305	10021	1745
15305	10021	2301
15305	10021	946
15305	10021	1680
15305	10021	5873
15305	10021	4704
15305	10021	4374
16189	10022	8261
16189	10022	4249
16189	10022	9245
16189	10022	1450
16189	10022	2456
16189	10022	2293
16189	10022	3258
16189	10022	3045
7979	10023	8113
7979	10023	7099
7979	10023	9922
7979	10023	9447
7979	10023	9567
7979	10023	6658
7979	10023	2585
7979	10023	1624
7979	10023	3924
12759	10024	7808
12759	10024	8164
12759	10024	2790
12759	10024	4841
5906	10025	5770
5906	10025	4991
5906	10025	5752
5906	10025	5312
15792	10026	9725
15792	10026	7080
15792	10026	3618
15792	10026	5684
7694	10027	300
13440	10028	239
13440	10028	3246
13440	10028	1054
13440	10028	9787
13440	10028	1407
13440	10028	4261
7971	10029	5543
7971	10029	4309
7971	10029	7003
18556	10030	6395
18556	10030	2092
18556	10030	7768
18556	10030	2302
18556	10030	7560
14692	10031	9516
14692	10031	6138
16195	10032	3675
16195	10032	4735
16195	10032	5848
16195	10032	9955
12698	10033	2813
12698	10033	9602
12698	10033	255
12698	10033	8469
12698	10033	4508
12698	10033	1681
12698	10033	2169
270	10034	3644
270	10034	1913
270	10034	267
270	10034	8187
270	10034	7277
270	10034	6571
270	10034	637
270	10034	7995
16498	10035	8514
16498	10035	1152
16498	10035	5930
11285	10036	4301
11285	10036	3517
11285	10036	5477
11285	10036	3974
2502	10037	3
15994	10038	6246
15994	10038	7418
15994	10038	7211
15994	10038	4953
15994	10038	1890
10690	10039	2443
10690	10039	9296
10690	10039	4192
16393	10040	8772
16393	10040	6276
16393	10040	2520
16393	10040	3183
16393	10040	9484
16393	10040	3524
16393	10040	9170
16393	10040	9835
17233	10041	1699
17233	10041	8740
17233	10041	6766
17233	10041	4265
17233	10041	1128
17233	10041	6959
17233	10041	3308
17233	10041	8629
3622	10042	2411
3622	10042	3593
3622	10042	6591
3622	10042	2639
3622	10042	2043
3622	10042	6363
3622	10042	7888
9308	10043	3002
9308	10043	7784
9308	10043	9059
9308	10043	3196
9308	10043	6918
9308	10043	9498
9308	10043	7509
9308	10043	9625
9308	10043	3488
12251	10044	5167
12251	10044	310
12251	10044	5709
12251	10044	7709
12251	10044	4045
12251	10044	2901
3919	10045	9647
3919	10045	4477
3919	10045	1346
3919	10045	1052
9077	10046	664
9077	10046	4181
9077	10046	2037
9077	10046	8886
9077	10046	9536
9077	10046	1487
9077	10046	7305
15951	10047	1843
15951	10047	8163
15951	10047	5137
15951	10047	8304
15951	10047	478
15951	10047	726
15951	10047	9001
15951	10047	9091
2255	10048	8873
2255	10048	2699
2255	10048	789
2255	10048	4747
2255	10048	7979
2255	10048	4523
5370	10049	2193
5370	10049	8410
18270	10050	525
18270	10050	8015
18270	10050	548
18270	10050	3849
18270	10050	2896
7368	10051	9880
7368	10051	5619
7368	10051	4350
7368	10051	7088
7368	10051	4927
6672	10052	2471
5989	10053	739
5989	10053	9298
5989	10053	1669
5989	10053	1135
15371	10054	2215
15371	10054	159
15371	10054	4298
15371	10054	7055
15371	10054	6525
15371	10054	2560
10061	10055	8025
10061	10055	1959
10061	10055	4703
10061	10055	3350
10061	10055	3449
10061	10055	7820
10061	10055	2170
10061	10055	5082
10479	10056	2485
10479	10056	8909
10479	10056	9990
10479	10056	7484
10479	10056	6499
10479	10056	1089
10479	10056	691
10479	10056	3287
10479	10056	4304
15505	10057	7078
15505	10057	3379
15505	10057	7676
15505	10057	7399
15505	10057	8451
15505	10057	6628
15505	10057	8892
15505	10057	8828
15505	10057	9358
893	10058	3494
893	10058	696
893	10058	9772
893	10058	5550
893	10058	2045
10848	10059	4190
10848	10059	483
14220	10060	3727
6170	10061	3532
6170	10061	7247
15885	10062	403
15885	10062	7798
15885	10062	2998
15885	10062	7871
15885	10062	3839
15885	10062	9966
15885	10062	4701
9398	10063	3525
9398	10063	8242
9398	10063	2267
9398	10063	1676
9398	10063	8797
7237	10064	3989
7237	10064	305
7237	10064	5495
7237	10064	4768
7237	10064	236
7237	10064	3653
7237	10064	6766
7237	10064	9635
6318	10065	834
6318	10065	254
6318	10065	1856
6318	10065	1320
6318	10065	2669
6318	10065	7168
6318	10065	550
6318	10065	3643
16822	10066	3145
16822	10066	820
16822	10066	4113
16822	10066	9664
16822	10066	3613
16822	10066	2834
6174	10067	2138
6174	10067	3250
6174	10067	5311
6174	10067	1464
10212	10068	3517
10212	10068	9422
10212	10068	6311
10212	10068	6570
12467	10069	5974
12467	10069	8755
12467	10069	695
12467	10069	1997
10492	10070	5664
10492	10070	5157
10492	10070	4207
10492	10070	7092
10492	10070	4342
10492	10070	4383
10492	10070	6755
10492	10070	1075
10492	10070	7186
6320	10071	1217
6427	10072	8460
8246	10073	7677
8246	10073	1723
8246	10073	5650
8246	10073	1281
8246	10073	6716
15579	10074	3639
15579	10074	1331
15579	10074	7757
15579	10074	1246
15579	10074	5761
15579	10074	4191
15579	10074	2848
15579	10074	8343
12038	10075	787
4135	10076	103
4135	10076	650
4135	10076	9332
1324	10077	3210
17941	10078	3191
17941	10078	2455
17941	10078	270
17941	10078	7552
17941	10078	893
17941	10078	4908
17941	10078	405
17941	10078	9898
1093	10079	4834
1093	10079	6238
1093	10079	9515
1093	10079	8843
1093	10079	8418
1093	10079	2842
10592	10080	6109
10592	10080	8432
10592	10080	9029
10592	10080	4039
7871	10081	4482
7871	10081	244
7871	10081	4962
7871	10081	5531
7871	10081	5929
8693	10082	5955
8693	10082	6696
5608	10083	9805
5608	10083	2906
5608	10083	8249
5608	10083	7778
5608	10083	5996
5608	10083	4225
5608	10083	1575
5608	10083	2720
5608	10083	3662
4440	10084	3620
4440	10084	3015
4440	10084	8044
4440	10084	3120
4440	10084	3716
13243	10085	7950
13243	10085	3082
13243	10085	6804
13243	10085	184
13243	10085	6492
306	10086	2373
306	10086	2509
306	10086	3496
306	10086	6308
306	10086	9674
306	10086	9368
306	10086	2351
18236	10087	3663
18236	10087	1905
18236	10087	1291
18236	10087	8845
18236	10087	4992
18236	10087	7935
18236	10087	1290
18236	10087	1091
9173	10088	6126
9173	10088	2035
9173	10088	2385
4791	10089	356
4791	10089	6394
4791	10089	7632
12952	10090	805
12952	10090	5883
12952	10090	3707
12952	10090	5893
12952	10090	1561
12952	10090	2613
12952	10090	4211
12952	10090	3179
12952	10090	9033
5071	10091	9701
5071	10091	1605
5071	10091	1171
5071	10091	3808
5071	10091	5292
5071	10091	36
5071	10091	6706
5071	10091	8149
5071	10091	3748
12721	10092	1008
12721	10092	8618
15216	10093	6954
15216	10093	5836
15216	10093	9607
6828	10094	8026
6828	10094	978
6828	10094	7418
6828	10094	7328
6828	10094	8835
6828	10094	7526
6828	10094	7163
6828	10094	6802
6828	10094	8573
2296	10095	3423
6060	10096	6444
6060	10096	3213
6060	10096	4565
6060	10096	9199
13053	10097	1666
13053	10097	8380
10361	10098	7239
10361	10098	8925
10361	10098	8337
10361	10098	1888
10361	10098	5377
10361	10098	646
10361	10098	24
9176	10099	6570
9176	10099	2014
9176	10099	3517
9176	10099	388
9176	10099	2508
14231	10100	5111
14231	10100	5960
14231	10100	8642
14231	10100	683
2657	10101	5187
2657	10101	1593
2657	10101	7615
2657	10101	4601
2657	10101	7879
2657	10101	3308
2657	10101	13
14176	10102	1402
14176	10102	1521
14176	10102	1488
14176	10102	5209
14176	10102	4180
36	10103	2145
36	10103	1920
36	10103	8951
36	10103	9387
36	10103	4638
36	10103	5095
36	10103	8508
36	10103	1737
6278	10104	500
6278	10104	9862
6278	10104	3136
6278	10104	7898
6278	10104	4059
6278	10104	5318
6278	10104	7882
6278	10104	5963
6278	10104	3758
16790	10105	3045
16790	10105	1707
16790	10105	7988
16790	10105	7920
16790	10105	9586
16790	10105	8431
16790	10105	4128
16790	10105	3489
15094	10106	3751
15094	10106	753
15094	10106	3833
15094	10106	5061
6205	10107	9652
6205	10107	731
6205	10107	7840
6205	10107	5105
6205	10107	7071
6205	10107	6873
722	10108	7908
722	10108	6815
722	10108	9344
6352	10109	669
6352	10109	9533
6352	10109	933
6352	10109	4871
6352	10109	6824
6352	10109	314
14768	10110	8583
14768	10110	7369
14768	10110	3862
14768	10110	4149
14768	10110	6935
14768	10110	8243
14768	10110	6668
14673	10111	4252
14673	10111	3452
14673	10111	7899
14673	10111	1832
3935	10112	8976
3935	10112	8231
3935	10112	5985
3935	10112	1621
3935	10112	2769
3935	10112	3626
3935	10112	6859
3187	10113	5861
3187	10113	2871
3187	10113	1003
3187	10113	9589
3187	10113	8982
3187	10113	4803
7556	10114	122
7556	10114	9783
7556	10114	4874
7556	10114	298
7556	10114	3562
7556	10114	8792
7556	10114	8749
9218	10115	3922
9218	10115	5167
9218	10115	2139
9218	10115	5302
9523	10116	2452
9523	10116	2221
9523	10116	2583
9523	10116	4785
9523	10116	5593
9523	10116	36
9523	10116	3240
9533	10117	9164
9533	10117	8409
9533	10117	824
9533	10117	8478
9533	10117	7488
9533	10117	887
9533	10117	4683
9533	10117	9045
9533	10117	5572
713	10118	8703
713	10118	3975
713	10118	3326
713	10118	6708
713	10118	3884
713	10118	4032
713	10118	202
713	10118	2840
713	10118	980
3732	10119	5204
1550	10120	1131
1550	10120	1055
10058	10121	9808
10058	10121	8296
4655	10122	7183
4655	10122	3233
4655	10122	9150
4655	10122	29
4655	10122	9676
14282	10123	8605
14282	10123	8171
14282	10123	6971
14282	10123	4688
14282	10123	8000
12590	10124	8622
12590	10124	6135
18735	10125	8480
18735	10125	9822
10157	10126	9539
10157	10126	2370
10157	10126	3559
10157	10126	4133
10157	10126	8086
10625	10127	6893
6055	10128	2395
6055	10128	228
6055	10128	813
6055	10128	9029
6055	10128	5127
6055	10128	5271
6055	10128	8224
6055	10128	2375
13015	10129	8639
13015	10129	378
13015	10129	3695
13015	10129	4114
13015	10129	298
5385	10130	3566
5385	10130	7153
5385	10130	4636
5385	10130	6918
5385	10130	6945
5385	10130	7546
5385	10130	6924
13904	10131	9721
13904	10131	1531
13904	10131	7240
13904	10131	2206
13904	10131	2610
12788	10132	991
12788	10132	6390
12788	10132	5617
12788	10132	5533
6156	10133	7604
6156	10133	2325
6156	10133	2171
6156	10133	7165
6156	10133	5461
15332	10134	6748
15332	10134	8349
18680	10135	4966
18680	10135	5665
18680	10135	4447
12653	10136	4033
12653	10136	8376
11080	10137	9945
11080	10137	6982
11080	10137	1204
11080	10137	4059
11080	10137	6662
11080	10137	8892
11080	10137	2383
11080	10137	4818
11080	10137	4356
15864	10138	9112
15864	10138	3459
14629	10139	6631
14629	10139	4981
14629	10139	4857
14629	10139	7342
14629	10139	5737
14629	10139	8941
2647	10140	9371
2647	10140	1018
13217	10141	6232
13217	10141	7372
13217	10141	3953
13217	10141	7790
13217	10141	3369
13217	10141	4196
13217	10141	8955
13217	10141	7140
13217	10141	5541
4952	10142	4229
4952	10142	649
4952	10142	8306
4952	10142	1855
4952	10142	1308
4952	10142	8125
4952	10142	145
4952	10142	9078
4891	10143	670
4891	10143	8394
4891	10143	4350
4891	10143	3889
4891	10143	6410
4891	10143	1476
4891	10143	8064
12739	10144	7856
12739	10144	5826
12739	10144	3534
12739	10144	8057
12739	10144	3904
12739	10144	5056
12739	10144	7574
11934	10145	9902
11934	10145	2284
11934	10145	8714
11934	10145	6950
11934	10145	5884
11934	10145	3147
11934	10145	574
11934	10145	4285
15637	10146	429
15637	10146	5754
15637	10146	881
15637	10146	1210
15637	10146	9295
18391	10147	5507
18391	10147	9805
18391	10147	7657
18391	10147	5291
18391	10147	5118
18391	10147	1804
17569	10148	3822
17569	10148	904
17569	10148	3134
17569	10148	2903
17569	10148	6931
1383	10149	6737
1383	10149	2135
19583	10150	594
19583	10150	510
19583	10150	6749
19583	10150	1182
19583	10150	7404
16614	10151	92
16614	10151	9097
16614	10151	9677
16614	10151	7713
16614	10151	9440
3149	10152	1366
3149	10152	1966
3149	10152	564
3149	10152	4357
3149	10152	5247
3149	10152	1282
3149	10152	542
10238	10153	2599
4550	10154	3343
4550	10154	231
4550	10154	5947
4550	10154	8629
4550	10154	4439
4550	10154	9271
7255	10155	9166
7255	10155	965
7255	10155	6496
7255	10155	4826
7255	10155	2969
7255	10155	898
7255	10155	9700
7255	10155	6820
14101	10156	8271
14101	10156	3462
14101	10156	3573
14101	10156	7711
14101	10156	6361
14101	10156	4957
11843	10157	7843
1623	10158	1849
1623	10158	993
1623	10158	223
1623	10158	5719
1623	10158	7346
1616	10159	3541
1616	10159	7766
5445	10160	8644
5445	10160	8170
5445	10160	717
5445	10160	7297
5445	10160	7598
5445	10160	5380
5445	10160	7814
5445	10160	9786
14263	10161	7939
14263	10161	8851
14263	10161	8625
14263	10161	1380
14263	10161	9339
14263	10161	1110
14263	10161	7465
16363	10162	6380
16363	10162	911
17450	10163	2257
17450	10163	4819
17450	10163	5264
17450	10163	3995
17450	10163	4237
17450	10163	731
17450	10163	5677
13573	10164	6066
13573	10164	8069
13573	10164	4285
13573	10164	7094
13573	10164	6208
13573	10164	3921
13573	10164	2683
13573	10164	1106
13573	10164	5954
19897	10165	2568
19897	10165	112
19897	10165	1284
19897	10165	5030
19897	10165	2422
981	10166	4939
981	10166	1336
981	10166	965
981	10166	4715
981	10166	1432
981	10166	1149
2814	10167	5902
2814	10167	3888
2814	10167	8146
6352	10168	4272
6298	10169	9119
6298	10169	7544
6298	10169	9091
6298	10169	3731
6298	10169	8079
6298	10169	7909
10486	10170	5145
10486	10170	8201
13496	10171	7717
13496	10171	2870
13496	10171	3888
13496	10171	5574
13496	10171	9206
13496	10171	3089
13639	10172	1698
13639	10172	3723
13639	10172	1971
13639	10172	171
16741	10173	5119
16741	10173	2008
16741	10173	7611
16741	10173	2011
16741	10173	248
18907	10174	7750
18907	10174	4412
18907	10174	9529
18907	10174	3297
18907	10174	4093
18907	10174	9918
18907	10174	2382
5575	10175	9660
5575	10175	587
5575	10175	5798
5575	10175	8769
5575	10175	182
5575	10175	5498
5575	10175	864
10551	10176	1385
10551	10176	9738
10551	10176	8379
10551	10176	9740
10551	10176	3069
10551	10176	3548
6415	10177	478
18493	10178	2518
18493	10178	4372
18493	10178	3490
18493	10178	8657
82	10179	5518
82	10179	7209
82	10179	5558
82	10179	7631
82	10179	2260
82	10179	2313
82	10179	8465
3546	10180	5263
3546	10180	8847
3546	10180	7936
3546	10180	964
3546	10180	5643
3546	10180	6633
3546	10180	6334
3546	10180	6858
4831	10181	1521
4831	10181	2793
4831	10181	1242
4831	10181	6623
4831	10181	3031
16585	10182	7927
16585	10182	4890
16585	10182	7741
8747	10183	6524
8747	10183	7546
8747	10183	1866
8747	10183	8970
3525	10184	3020
3525	10184	3788
3525	10184	2500
3525	10184	4342
3525	10184	48
3525	10184	6862
3525	10184	1159
3525	10184	5471
16126	10185	7514
16126	10185	9431
16126	10185	1742
16126	10185	2764
16126	10185	163
6365	10186	9232
6365	10186	9155
18406	10187	4141
18406	10187	3498
18406	10187	5829
18406	10187	7674
18406	10187	7971
18406	10187	9037
18406	10187	4566
18406	10187	5803
18406	10187	9964
15673	10188	9497
15673	10188	7456
18980	10189	8386
18980	10189	4797
18980	10189	1607
18980	10189	4355
18980	10189	9286
18980	10189	4467
18980	10189	9727
18980	10189	9099
18126	10190	6900
18126	10190	4805
18126	10190	9021
18126	10190	5048
5804	10191	4898
13007	10192	5783
13007	10192	8697
13007	10192	1798
13007	10192	9281
13007	10192	3953
13007	10192	9960
13717	10193	3254
13717	10193	6377
13717	10193	6084
13717	10193	1204
12201	10194	2604
16772	10195	8636
16772	10195	3769
16772	10195	8780
16772	10195	3558
16772	10195	3168
18511	10196	4365
18511	10196	7152
18511	10196	1491
18511	10196	5301
18511	10196	4456
18511	10196	28
18511	10196	6329
18511	10196	5445
8159	10197	1996
8159	10197	3510
8159	10197	7814
8159	10197	8423
8159	10197	5932
8159	10197	2261
18826	10198	7768
4446	10199	9282
9452	10200	8805
9452	10200	4526
9452	10200	7877
9452	10200	6353
9452	10200	4711
9452	10200	9101
9452	10200	184
9452	10200	939
3364	10201	7726
3364	10201	765
3364	10201	9276
3364	10201	3580
3364	10201	4772
3364	10201	4730
3364	10201	885
3364	10201	4377
1458	10202	5504
1458	10202	2642
7160	10203	5262
7160	10203	4230
7160	10203	3101
7160	10203	477
7160	10203	5040
7160	10203	8370
6198	10204	2354
6198	10204	5785
6198	10204	8493
6198	10204	1641
6198	10204	3788
6198	10204	9684
6198	10204	7862
6247	10205	6111
6247	10205	3611
6247	10205	3673
6247	10205	643
6247	10205	8462
6247	10205	5141
6247	10205	3806
6247	10205	9612
16210	10206	2101
16210	10206	3059
16210	10206	2315
16210	10206	6114
16210	10206	4044
16210	10206	5320
16210	10206	5603
16210	10206	6742
14769	10207	4166
14769	10207	7890
14769	10207	3951
14769	10207	7562
14769	10207	5607
14769	10207	9862
5839	10208	3840
5839	10208	17
5839	10208	9912
11030	10209	4791
11030	10209	2163
11030	10209	7889
11030	10209	2564
11030	10209	4301
3724	10210	9250
3724	10210	6593
3724	10210	380
3724	10210	3565
3724	10210	1689
3724	10210	2102
3724	10210	8919
3724	10210	7116
3811	10211	8013
3811	10211	3409
3811	10211	8698
3811	10211	7090
3811	10211	9571
3811	10211	864
3811	10211	2149
5057	10212	6748
5057	10212	6216
5057	10212	6830
7889	10213	5850
7889	10213	984
7889	10213	6270
7889	10213	4438
3055	10214	6216
3055	10214	490
19119	10215	2194
19119	10215	4035
19119	10215	6489
19119	10215	3543
19119	10215	4808
19119	10215	9381
19119	10215	5212
19119	10215	4520
17916	10216	485
17916	10216	8527
17916	10216	1204
17916	10216	5066
17916	10216	8576
17916	10216	5275
17916	10216	3599
176	10217	5564
176	10217	4582
176	10217	5639
316	10218	9116
19201	10219	6302
19201	10219	4463
19201	10219	8789
19201	10219	7326
19201	10219	3807
5968	10220	5704
5968	10220	8525
5968	10220	1520
5968	10220	79
2704	10221	9074
2704	10221	3037
2704	10221	9256
2704	10221	2511
2598	10222	5362
2598	10222	8954
2598	10222	3545
2598	10222	2278
2598	10222	6542
2598	10222	9534
2598	10222	4966
2598	10222	4888
3556	10223	5587
9684	10224	8560
9684	10224	4037
9684	10224	3830
5567	10225	2749
5567	10225	8667
5567	10225	1213
5567	10225	7351
5567	10225	7813
5567	10225	5465
5567	10225	4016
5567	10225	8813
5567	10225	3946
18083	10226	4842
18083	10226	8318
18083	10226	5214
6691	10227	3755
6691	10227	3494
6691	10227	478
6691	10227	1145
13218	10228	4796
13218	10228	6699
13218	10228	4919
13218	10228	7783
13218	10228	4147
13218	10228	2512
13218	10228	1296
5500	10229	6954
893	10230	1290
893	10230	1311
893	10230	7545
4681	10231	1081
4681	10231	9310
4681	10231	5869
4681	10231	1487
4681	10231	5919
4681	10231	6104
4681	10231	5532
4681	10231	2839
10764	10232	8403
10764	10232	2725
539	10233	2610
7380	10234	2553
7380	10234	992
7380	10234	5763
7380	10234	6821
7380	10234	9484
7380	10234	9040
7380	10234	4838
15538	10235	1991
15538	10235	5821
15538	10235	5820
15538	10235	644
15538	10235	6253
15538	10235	2119
9343	10236	8711
9343	10236	4309
9343	10236	2781
9343	10236	7884
9343	10236	6115
9343	10236	2858
9343	10236	491
4961	10237	3064
4961	10237	9655
4961	10237	5481
4961	10237	2577
4961	10237	3675
4961	10237	2271
1962	10238	6513
8792	10239	7118
15215	10240	88
15215	10240	84
15215	10240	1168
15215	10240	6857
18867	10241	8417
18867	10241	8146
18867	10241	7499
18867	10241	5488
18867	10241	407
18867	10241	8407
18867	10241	564
18867	10241	1946
18867	10241	3131
6437	10242	6369
6437	10242	9138
6437	10242	6757
6437	10242	2659
6437	10242	4102
6437	10242	7522
6437	10242	5874
6437	10242	133
6437	10242	9032
14877	10243	2962
14877	10243	6871
12373	10244	5586
9446	10245	9505
9446	10245	8868
9446	10245	2640
9446	10245	5853
9446	10245	1410
9446	10245	9873
9446	10245	6525
9446	10245	7880
1683	10246	6934
1683	10246	6151
1683	10246	2100
1683	10246	1925
1683	10246	6459
1683	10246	1071
1683	10246	2394
1683	10246	9569
1683	10246	6328
15474	10247	8178
15474	10247	4620
15474	10247	9743
15474	10247	6898
7664	10248	77
7664	10248	5565
7664	10248	5192
7664	10248	2832
10450	10249	258
10450	10249	2977
10450	10249	265
10450	10249	7221
10450	10249	2316
10450	10249	4500
10450	10249	9554
14463	10250	1060
13250	10251	8649
13250	10251	4170
13250	10251	5365
13250	10251	4190
13250	10251	2898
13250	10251	9425
13250	10251	1550
13250	10251	1606
12210	10252	7503
12210	10252	5270
12210	10252	7499
12210	10252	8038
12210	10252	2954
12210	10252	8120
12210	10252	5485
12210	10252	8237
4852	10253	9592
4852	10253	8719
4852	10253	2540
4852	10253	5008
4852	10253	6429
4852	10253	9063
8665	10254	662
8665	10254	5412
8665	10254	45
8665	10254	5217
8665	10254	5819
16953	10255	4033
16953	10255	8742
16953	10255	6613
3241	10256	2553
3241	10256	3435
3241	10256	5701
3241	10256	5452
3241	10256	4797
3241	10256	9977
3241	10256	4393
3241	10256	369
3241	10256	8647
9052	10257	9997
9052	10257	5471
9052	10257	9615
3840	10258	3288
17977	10259	5351
17977	10259	7348
17977	10259	1218
17977	10259	521
17977	10259	1951
17977	10259	8332
15848	10260	6258
15848	10260	300
15848	10260	7375
15848	10260	7791
2158	10261	68
10835	10262	745
10835	10262	5918
10835	10262	7671
10835	10262	433
8251	10263	7816
8251	10263	693
16134	10264	3491
16134	10264	4925
16134	10264	6300
16134	10264	8889
7512	10265	9841
7512	10265	2418
5701	10266	6976
5701	10266	1462
5701	10266	7625
5701	10266	2906
5701	10266	221
5701	10266	7525
5701	10266	5504
5701	10266	4111
5701	10266	7442
15701	10267	9004
15701	10267	5464
15701	10267	4107
15242	10268	5062
15242	10268	6039
17889	10269	8494
17889	10269	3702
17889	10269	6340
17889	10269	5801
17889	10269	812
17889	10269	1631
17889	10269	2973
17889	10269	4163
17889	10269	2056
12655	10270	7575
12655	10270	8758
17054	10271	8516
4435	10272	29
1681	10273	8408
1681	10273	6277
1681	10273	2992
1681	10273	839
1681	10273	4660
1681	10273	9126
15766	10274	6410
15766	10274	1319
10421	10275	5442
10421	10275	5353
10421	10275	8012
10421	10275	5095
10421	10275	1492
8965	10276	2465
8965	10276	6556
8965	10276	6596
8965	10276	9472
8965	10276	5553
8965	10276	846
8965	10276	807
8965	10276	2081
8965	10276	4802
309	10277	7090
309	10277	9551
309	10277	3441
6288	10278	7506
6288	10278	7117
6288	10278	9157
6288	10278	6544
6288	10278	2470
6552	10279	1225
6552	10279	1183
6552	10279	2644
6552	10279	9478
18056	10280	7567
18056	10280	6811
18056	10280	6904
18056	10280	854
21	10281	4720
21	10281	2350
21	10281	6354
21	10281	9960
21	10281	2528
10343	10282	4905
10343	10282	2429
10343	10282	3192
10343	10282	4596
2999	10283	5520
2999	10283	6791
2999	10283	7698
2999	10283	9204
2999	10283	7810
2999	10283	85
2999	10283	3135
14117	10284	459
14117	10284	7737
14117	10284	5907
14117	10284	2882
14117	10284	931
14117	10284	2002
14117	10284	5589
14117	10284	7986
11366	10285	5731
11366	10285	8409
11366	10285	9469
16761	10286	6592
16761	10286	8899
16761	10286	1948
16761	10286	5257
16761	10286	5308
16761	10286	3637
18449	10287	1604
18449	10287	5104
18449	10287	1329
18449	10287	7192
18449	10287	6650
18449	10287	1281
18449	10287	5041
18449	10287	1288
18449	10287	8943
1781	10288	5719
1781	10288	7404
17679	10289	8261
17679	10289	915
17679	10289	5676
5734	10290	9527
9135	10291	6200
9135	10291	7398
9135	10291	2977
9135	10291	3376
9135	10291	2689
9135	10291	8050
9135	10291	9619
15757	10292	1243
15757	10292	5892
15757	10292	5353
15757	10292	6289
4426	10293	9425
4426	10293	6362
4426	10293	7805
4426	10293	9212
3799	10294	2196
3799	10294	2710
3799	10294	9456
3799	10294	8577
3799	10294	2007
3799	10294	6140
4856	10295	4641
4856	10295	7747
4856	10295	7331
4856	10295	887
196	10296	1998
196	10296	7559
537	10297	9790
537	10297	7
537	10297	2166
537	10297	9156
537	10297	8574
537	10297	7977
537	10297	3080
537	10297	7279
537	10297	9831
6553	10298	4754
6553	10298	137
19977	10299	9297
19977	10299	1272
19977	10299	4166
19977	10299	5448
8041	10300	7235
8041	10300	1643
8041	10300	8205
8041	10300	2679
8041	10300	4750
8041	10300	5611
11493	10301	5735
11493	10301	9230
11493	10301	6764
11493	10301	4333
11493	10301	3939
11493	10301	4250
17928	10302	6758
9924	10303	8712
9924	10303	9167
9924	10303	5168
9924	10303	69
9924	10303	6025
9924	10303	1377
9924	10303	834
9924	10303	5755
19386	10304	1575
19386	10304	2283
19386	10304	9782
10657	10305	3554
10657	10305	5401
10657	10305	7036
10657	10305	3090
10657	10305	7552
10657	10305	2907
10657	10305	4367
10657	10305	7069
10657	10305	8907
7706	10306	2600
7706	10306	765
19167	10307	9319
19167	10307	7494
19167	10307	3984
19167	10307	5289
19167	10307	1632
9077	10308	8279
14369	10309	1038
7275	10310	6019
7275	10310	2224
7275	10310	1722
18430	10311	3744
18430	10311	6048
18430	10311	4390
18430	10311	9913
18430	10311	2789
18430	10311	4992
18430	10311	5376
18430	10311	3952
18430	10311	4392
1112	10312	7499
1112	10312	9796
1112	10312	2235
1112	10312	8435
1112	10312	3761
1112	10312	47
8872	10313	593
8872	10313	5657
8872	10313	8295
8872	10313	5548
8872	10313	7445
8872	10313	8074
8872	10313	495
15985	10314	7213
15985	10314	8143
15985	10314	7966
15985	10314	7825
10755	10315	2843
10755	10315	8585
10755	10315	8623
10755	10315	9531
13950	10316	4469
13950	10316	3740
13950	10316	2595
13950	10316	1388
13950	10316	443
13950	10316	5454
13950	10316	1433
6286	10317	6897
6286	10317	1906
6286	10317	9997
6286	10317	2359
6286	10317	4699
6286	10317	6502
6286	10317	8681
6286	10317	3410
12010	10318	5812
2531	10319	4544
2531	10319	4493
2777	10320	6869
2777	10320	9964
2777	10320	4220
2777	10320	711
2777	10320	3469
2777	10320	1691
2777	10320	1811
2777	10320	2883
2777	10320	1078
1990	10321	2344
1990	10321	9946
14950	10322	6910
14950	10322	7091
14950	10322	4321
10062	10323	4422
10062	10323	1881
10062	10323	4413
10062	10323	1436
10062	10323	3457
6832	10324	7919
6832	10324	5666
6832	10324	9178
6832	10324	8019
6832	10324	8983
6832	10324	2961
6832	10324	6420
6832	10324	8334
5510	10325	8987
5510	10325	6141
19194	10326	3013
19194	10326	7389
19194	10326	4356
19194	10326	6552
19194	10326	6943
19194	10326	9622
19194	10326	9679
19194	10326	9228
15122	10327	316
15122	10327	7951
15122	10327	3305
15122	10327	9723
15122	10327	3688
15122	10327	3939
2654	10328	4381
2654	10328	1161
2654	10328	8752
2654	10328	7249
2654	10328	3364
2654	10328	4528
2654	10328	4038
8706	10329	3655
8706	10329	9054
8706	10329	4479
8706	10329	3996
8706	10329	9442
14145	10330	1255
14145	10330	5448
14145	10330	6834
14145	10330	8437
5930	10331	2041
5930	10331	7563
5930	10331	2612
3331	10332	4407
3331	10332	9833
19154	10333	3702
18300	10334	1846
18300	10334	3830
18300	10334	3583
18300	10334	4229
3581	10335	3007
3581	10335	6392
3581	10335	1813
3581	10335	6189
3581	10335	4646
11131	10336	7740
11131	10336	4074
11131	10336	3222
11131	10336	539
11131	10336	6938
2332	10337	2956
2332	10337	8358
2332	10337	3602
2332	10337	3563
19501	10338	1793
9164	10339	4171
9164	10339	3418
9164	10339	3197
9164	10339	4443
11918	10340	9590
11918	10340	1028
11918	10340	218
11918	10340	2696
11918	10340	42
11918	10340	3531
11918	10340	8434
11918	10340	5381
17171	10341	5863
17171	10341	1467
17171	10341	5062
17171	10341	9193
985	10342	4748
985	10342	9405
4201	10343	343
4201	10343	3760
4201	10343	7599
4201	10343	2968
4201	10343	7725
4201	10343	1579
6091	10344	8954
6091	10344	9961
6091	10344	2332
6091	10344	2278
6091	10344	2912
6091	10344	2045
6091	10344	3783
8250	10345	2901
8250	10345	9087
8250	10345	8168
8250	10345	6523
8250	10345	399
8250	10345	2792
8250	10345	5105
8250	10345	4885
8250	10345	2567
9688	10346	6526
9688	10346	8428
9688	10346	7129
9688	10346	4433
9688	10346	4562
9688	10346	857
9688	10346	3202
9688	10346	460
9688	10346	8771
3125	10347	3308
3125	10347	8177
3125	10347	6003
595	10348	6636
595	10348	7552
595	10348	6107
595	10348	3957
595	10348	9319
595	10348	4317
595	10348	3838
5218	10349	4172
14958	10350	3353
14958	10350	5704
17534	10351	259
17534	10351	5024
17961	10352	3795
15264	10353	241
15264	10353	5184
15264	10353	1295
15264	10353	1891
15264	10353	86
11578	10354	4556
11578	10354	9831
11578	10354	9493
11578	10354	1179
11578	10354	3834
11578	10354	511
11578	10354	9560
11578	10354	5260
11001	10355	9913
11001	10355	1861
11001	10355	8357
4605	10356	873
4605	10356	6987
4605	10356	7105
4605	10356	5557
4605	10356	6822
4605	10356	6494
12107	10357	1738
12107	10357	7779
12107	10357	1978
7676	10358	5784
7676	10358	8574
7676	10358	2899
7676	10358	5809
7676	10358	150
7676	10358	6365
6374	10359	520
6374	10359	3743
6374	10359	4391
6374	10359	9714
6374	10359	4659
6374	10359	9860
6374	10359	5529
2626	10360	4832
2626	10360	6867
2626	10360	8677
2626	10360	3554
2626	10360	2721
2626	10360	8228
2626	10360	2440
12365	10361	1663
12365	10361	6489
12365	10361	1204
12365	10361	8896
15483	10362	5162
15483	10362	383
18118	10363	4100
18118	10363	1821
18118	10363	9580
18118	10363	1075
18118	10363	442
18118	10363	3828
18118	10363	386
3178	10364	8322
3178	10364	5063
3178	10364	3955
3178	10364	9243
3178	10364	2252
3178	10364	3396
3178	10364	9830
3300	10365	5910
3300	10365	2146
3300	10365	1772
4314	10366	3746
4314	10366	4202
4314	10366	5314
4314	10366	8434
4314	10366	9488
4314	10366	3606
4314	10366	436
530	10367	1915
530	10367	8728
530	10367	5220
530	10367	4176
530	10367	6846
530	10367	9148
5787	10368	4961
5787	10368	2977
5787	10368	668
5787	10368	1069
3009	10369	1769
3009	10369	3326
3009	10369	94
3009	10369	1509
3009	10369	2927
3009	10369	2304
3009	10369	8315
15654	10370	1541
15654	10370	390
15654	10370	2699
15654	10370	6982
15654	10370	5330
15654	10370	5272
15654	10370	8419
15654	10370	2376
15654	10370	724
4465	10371	7916
4465	10371	6496
4465	10371	1537
4465	10371	4058
4465	10371	8393
4465	10371	5186
4465	10371	116
14193	10372	8280
14193	10372	1772
14193	10372	3963
14193	10372	8442
14193	10372	6617
8797	10373	4484
8797	10373	1066
8797	10373	4860
8797	10373	1900
8797	10373	721
1673	10374	7933
1673	10374	7041
17625	10375	2960
17625	10375	2190
17625	10375	3590
17625	10375	3975
17625	10375	3943
17625	10375	8010
17625	10375	4477
12753	10376	3462
16862	10377	5051
16862	10377	5832
16862	10377	5884
16862	10377	6097
16862	10377	94
16862	10377	8420
16862	10377	7395
16862	10377	6235
16862	10377	852
10656	10378	1705
10656	10378	7326
10656	10378	1394
10656	10378	3597
10656	10378	8633
10656	10378	8495
8757	10379	3222
8757	10379	1623
8757	10379	6983
8757	10379	4035
9772	10380	214
9772	10380	3172
9772	10380	7812
9772	10380	7084
9772	10380	9510
9772	10380	629
9772	10380	9328
13136	10381	9905
13136	10381	9114
13136	10381	8364
13136	10381	544
13136	10381	9314
13136	10381	7284
14995	10382	9415
12997	10383	7179
13013	10384	3075
13013	10384	7336
12899	10385	2546
12899	10385	9104
12899	10385	5947
12899	10385	8635
12899	10385	3885
12899	10385	4307
12899	10385	9149
15034	10386	6513
15034	10386	3482
15034	10386	6782
15034	10386	6252
15034	10386	9535
15034	10386	567
15034	10386	1300
806	10387	6791
806	10387	8576
806	10387	3590
806	10387	3974
806	10387	8453
9593	10388	55
9593	10388	1401
9593	10388	785
9593	10388	953
9593	10388	2246
9593	10388	4359
9593	10388	4630
19200	10389	3205
13588	10390	9533
13588	10390	9159
13588	10390	3191
13588	10390	6557
13588	10390	4134
9837	10391	5238
19193	10392	3045
19193	10392	6783
19193	10392	6085
19193	10392	8587
19193	10392	6781
19193	10392	2884
19193	10392	6923
227	10393	3359
227	10393	614
227	10393	999
12471	10394	5832
12471	10394	4210
12471	10394	820
12471	10394	403
12471	10394	979
12471	10394	4402
12471	10394	7517
8879	10395	4553
15824	10396	1352
15824	10396	9664
15824	10396	4588
15824	10396	2854
14126	10397	8055
18065	10398	6791
18065	10398	8623
15899	10399	9223
15899	10399	3107
15899	10399	7306
15899	10399	4928
15899	10399	285
6275	10400	200
6275	10400	9953
6275	10400	8926
6275	10400	7287
6275	10400	8227
6275	10400	3815
6275	10400	4940
6275	10400	4799
6275	10400	9652
5517	10401	7217
5517	10401	4111
5517	10401	5038
5517	10401	639
5517	10401	4739
5517	10401	4199
5517	10401	9093
12759	10402	457
12759	10402	6656
12759	10402	9007
12759	10402	1370
12759	10402	5474
12759	10402	1417
12759	10402	8348
12759	10402	1593
12759	10402	6134
13545	10403	7611
13545	10403	6704
16568	10404	8091
16568	10404	4207
16568	10404	8937
16568	10404	6200
16568	10404	1871
16568	10404	1513
16568	10404	7743
16568	10404	1921
16568	10404	2318
19185	10405	1606
19185	10405	3366
19185	10405	9141
19185	10405	6594
19185	10405	1946
19185	10405	5764
19185	10405	9430
11257	10406	7302
11257	10406	4523
12886	10407	4498
12886	10407	8289
12886	10407	7913
12886	10407	1761
12886	10407	8204
12886	10407	3566
12886	10407	3126
12886	10407	9481
17819	10408	4538
3678	10409	6883
3678	10409	3228
3678	10409	188
3678	10409	1609
3678	10409	7049
3678	10409	8370
3678	10409	799
8729	10410	9875
8729	10410	1725
8729	10410	9760
8594	10411	6136
8594	10411	1611
8594	10411	515
8594	10411	4281
8594	10411	2563
19222	10412	8420
19222	10412	4122
19222	10412	572
19222	10412	966
19222	10412	6342
19222	10412	1984
19222	10412	8005
3826	10413	936
3826	10413	9552
3826	10413	5823
3826	10413	2153
3826	10413	9721
3826	10413	7996
12830	10414	4545
12830	10414	8493
12830	10414	2355
8678	10415	8887
8678	10415	8119
8678	10415	7865
8678	10415	9245
8678	10415	505
8678	10415	1248
1938	10416	6099
1938	10416	7863
4814	10417	7918
4814	10417	9194
4814	10417	6039
4814	10417	2326
888	10418	9498
888	10418	6741
888	10418	7496
888	10418	2659
888	10418	8957
888	10418	2396
888	10418	9514
888	10418	2492
888	10418	2665
1164	10419	6702
1164	10419	9063
1164	10419	4499
1164	10419	9470
1164	10419	9847
1164	10419	112
1164	10419	8970
1164	10419	4575
1164	10419	8556
1901	10420	1208
1901	10420	3169
1901	10420	2915
1901	10420	4454
1901	10420	1844
1901	10420	6024
1901	10420	182
1901	10420	1428
2548	10421	7861
2548	10421	5924
2548	10421	9217
2548	10421	5967
2548	10421	5430
2548	10421	5278
2548	10421	5633
2548	10421	510
9926	10422	6118
9926	10422	4104
9926	10422	1543
19495	10423	8064
19495	10423	2157
19495	10423	7101
19495	10423	8467
19495	10423	8863
8281	10424	2587
8281	10424	1800
8281	10424	6005
4245	10425	8421
4245	10425	6774
7158	10426	8244
7158	10426	1159
7158	10426	2468
7158	10426	8411
7158	10426	3522
7158	10426	5471
7158	10426	9284
2166	10427	7880
11395	10428	5059
11395	10428	6016
9908	10429	6049
9908	10429	4320
9908	10429	2123
9908	10429	9847
9908	10429	8761
9908	10429	9698
9908	10429	3374
9908	10429	9127
9908	10429	5896
18238	10430	764
18238	10430	2041
18238	10430	1929
18238	10430	1732
18238	10430	1748
12135	10431	8798
12135	10431	3530
12135	10431	1461
12135	10431	5602
12135	10431	8022
12135	10431	206
12135	10431	1734
12135	10431	3035
7596	10432	577
7596	10432	4414
12324	10433	2229
12324	10433	1043
12324	10433	2529
7979	10434	8824
7979	10434	8913
7979	10434	9738
7979	10434	3744
6689	10435	4986
6689	10435	1407
6689	10435	9454
6689	10435	5562
6689	10435	1956
6689	10435	5928
6689	10435	8817
14800	10436	1585
14800	10436	1192
14800	10436	299
14800	10436	1142
14800	10436	3701
541	10437	7417
541	10437	1772
541	10437	3710
11331	10438	8665
11331	10438	798
11331	10438	1340
5848	10439	3421
5848	10439	3726
5848	10439	8854
12480	10440	8613
12480	10440	9201
12480	10440	1982
12480	10440	7718
5682	10441	6780
5682	10441	3474
5682	10441	4775
5682	10441	1043
5682	10441	7877
5682	10441	4099
5682	10441	9025
19622	10442	4101
19622	10442	1835
19622	10442	8188
19622	10442	6210
19622	10442	2210
19622	10442	8746
19622	10442	2024
10996	10443	578
10996	10443	8537
10996	10443	9150
10996	10443	55
10996	10443	5587
10996	10443	7985
10996	10443	5805
10996	10443	2582
10996	10443	5386
3191	10444	6380
3191	10444	6608
3191	10444	945
3191	10444	3902
8957	10445	2932
8957	10445	1504
8957	10445	6600
8957	10445	2069
8957	10445	1868
8957	10445	6670
8957	10445	5513
8957	10445	5218
3782	10446	7310
16509	10447	2843
16509	10447	6813
16509	10447	7521
18049	10448	6114
18049	10448	1727
18049	10448	2673
18049	10448	2430
18049	10448	450
18049	10448	5151
18049	10448	9538
13694	10449	5102
13694	10449	4898
13694	10449	9993
15027	10450	6538
5302	10451	632
5302	10451	7869
5302	10451	9842
5302	10451	707
5302	10451	2419
5302	10451	774
5302	10451	7091
5302	10451	9111
5302	10451	5133
10249	10452	2638
18350	10453	1826
18350	10453	8023
18350	10453	1998
18350	10453	5518
18350	10453	4211
18350	10453	6831
18350	10453	6468
18350	10453	3177
4574	10454	6295
4574	10454	1653
4574	10454	6082
4574	10454	9184
4574	10454	3466
4574	10454	5433
6910	10455	9347
6910	10455	4717
6910	10455	9489
11912	10456	9514
11912	10456	5649
11912	10456	7076
11912	10456	1149
14461	10457	4114
14461	10457	3680
14461	10457	1776
19047	10458	2789
19047	10458	5904
19047	10458	3701
5703	10459	3398
5703	10459	3010
5703	10459	7041
5703	10459	9202
5703	10459	1389
5703	10459	4135
5703	10459	8704
959	10460	3
959	10460	398
959	10460	1967
959	10460	5068
959	10460	2389
959	10460	8520
959	10460	1047
959	10460	6936
7951	10461	4971
7951	10461	3812
5031	10462	2995
5994	10463	5788
5994	10463	4901
5994	10463	6741
5994	10463	4155
5994	10463	9127
5994	10463	7177
5994	10463	9257
5994	10463	37
10015	10464	4113
10015	10464	7484
10015	10464	2329
10015	10464	325
10015	10464	3475
18526	10465	118
18526	10465	1319
18526	10465	2502
18526	10465	9474
17460	10466	6200
17460	10466	1552
17460	10466	5371
17460	10466	5447
17460	10466	6695
17460	10466	3333
13615	10467	6070
13615	10467	1466
13615	10467	4193
13615	10467	460
13615	10467	3230
13615	10467	6373
13615	10467	8663
9724	10468	8133
9724	10468	3495
9724	10468	4243
9724	10468	1355
9724	10468	7209
9724	10468	4382
9724	10468	7096
9724	10468	608
9602	10469	1496
9602	10469	7030
9602	10469	4310
9602	10469	3484
9602	10469	554
9602	10469	8421
9602	10469	889
10262	10470	2706
10262	10470	3281
10262	10470	2971
10262	10470	7538
8351	10471	1273
16606	10472	3995
16606	10472	9751
16606	10472	725
16606	10472	3235
16606	10472	87
16606	10472	6745
16606	10472	9121
16606	10472	1505
16606	10472	6536
8147	10473	8249
8147	10473	1993
13691	10474	6007
13691	10474	5269
13691	10474	6368
13691	10474	3929
8031	10475	6207
8031	10475	3801
8031	10475	6625
8031	10475	2187
478	10476	6670
478	10476	2180
478	10476	9953
11919	10477	1717
11919	10477	8280
11919	10477	7793
5791	10478	7119
5791	10478	3580
5791	10478	4374
5791	10478	3145
5791	10478	6005
5791	10478	1442
7244	10479	3626
7244	10479	3278
7244	10479	4952
7244	10479	3641
7244	10479	641
7244	10479	9118
7244	10479	4329
2893	10480	5190
2893	10480	5515
2893	10480	6549
2893	10480	2593
2893	10480	4192
2893	10480	1613
2893	10480	7278
2893	10480	2504
2893	10480	688
8657	10481	5762
8657	10481	6492
8657	10481	9158
8657	10481	1536
8657	10481	2410
8657	10481	316
13729	10482	4855
13729	10482	7612
13729	10482	3474
13729	10482	1705
13729	10482	5444
13729	10482	3433
13729	10482	6721
4964	10483	2572
4964	10483	6336
4964	10483	5631
4964	10483	833
11784	10484	3544
11784	10484	9747
11784	10484	4131
11784	10484	6044
11784	10484	9197
11784	10484	8229
9898	10485	7431
9898	10485	3337
9898	10485	3751
9898	10485	4109
9898	10485	8417
9898	10485	5326
9898	10485	833
9898	10485	1198
9898	10485	5799
19858	10486	5765
19858	10486	3061
11082	10487	5203
11082	10487	3406
11082	10487	6374
966	10488	5425
966	10488	1714
966	10488	9997
966	10488	634
966	10488	3855
966	10488	5724
2977	10489	5481
8844	10490	794
8844	10490	83
16588	10491	4922
16588	10491	9061
16588	10491	9332
16588	10491	9546
16588	10491	4851
16588	10491	6129
16588	10491	1417
5588	10492	159
5588	10492	1965
5588	10492	2551
5588	10492	3767
5588	10492	9927
5588	10492	928
5588	10492	1628
1376	10493	9744
1376	10493	9946
1376	10493	5430
1376	10493	5170
1376	10493	9943
1376	10493	9640
1376	10493	4775
1376	10493	5618
1376	10493	59
7651	10494	8255
7651	10494	7001
7651	10494	7579
7651	10494	570
7651	10494	7632
7651	10494	2092
7651	10494	4908
7651	10494	3653
7651	10494	4368
8014	10495	3806
8014	10495	8823
16641	10496	7745
16641	10496	4522
16641	10496	5826
12789	10497	6708
3231	10498	1693
3231	10498	4852
6113	10499	6879
6113	10499	7819
6113	10499	8227
6113	10499	1662
12366	10500	8283
12366	10500	3671
12366	10500	3138
12366	10500	4697
12366	10500	1994
12366	10500	1999
12366	10500	2612
5520	10501	6714
5520	10501	3676
5520	10501	5654
5520	10501	40
2982	10502	8768
2982	10502	1698
2982	10502	2224
2982	10502	2816
2982	10502	5577
2982	10502	3392
2982	10502	8494
2982	10502	4425
8661	10503	1116
8661	10503	9
8661	10503	526
8661	10503	4085
8661	10503	1539
612	10504	2744
612	10504	3517
612	10504	8506
612	10504	369
612	10504	6668
612	10504	7900
612	10504	42
612	10504	5423
13076	10505	3307
13076	10505	2196
7470	10506	4041
7470	10506	8204
7470	10506	5921
7470	10506	2344
7470	10506	814
7470	10506	6324
7470	10506	1574
7470	10506	8574
7470	10506	887
6052	10507	5174
14739	10508	1104
14739	10508	6420
14739	10508	539
14739	10508	1929
14739	10508	6344
14739	10508	886
14739	10508	6984
17115	10509	174
17115	10509	7207
17115	10509	5345
1037	10510	7888
1037	10510	8260
9359	10511	9302
9359	10511	6013
9359	10511	336
9359	10511	2802
9359	10511	4108
9359	10511	5877
9359	10511	651
9359	10511	7860
9359	10511	2829
19659	10512	1191
19659	10512	9988
19659	10512	601
19659	10512	4130
19659	10512	8555
19659	10512	799
19659	10512	9077
3757	10513	9318
3757	10513	1114
3757	10513	378
3757	10513	7825
3757	10513	2177
3757	10513	3036
8453	10514	3677
15613	10515	1239
15613	10515	2709
15613	10515	4775
15613	10515	2194
15613	10515	9747
15613	10515	7556
15613	10515	1479
15613	10515	9832
4016	10516	7906
4016	10516	8401
4016	10516	3909
4016	10516	3520
12724	10517	3
12724	10517	1437
7260	10518	5141
7260	10518	9124
7260	10518	3495
7260	10518	5924
7260	10518	963
7260	10518	8809
7260	10518	1973
7260	10518	4281
15602	10519	4163
15602	10519	293
15602	10519	5356
15602	10519	8943
15602	10519	5360
15602	10519	2137
15602	10519	2509
15602	10519	7120
15602	10519	216
2356	10520	47
2356	10520	6655
2356	10520	9546
2356	10520	2128
2356	10520	5113
2356	10520	9933
2356	10520	456
2356	10520	7135
2356	10520	9161
2595	10521	2558
2595	10521	4857
2595	10521	3157
2595	10521	3951
2595	10521	4939
2595	10521	8514
2595	10521	8324
2595	10521	7535
5295	10522	8053
5295	10522	2199
5295	10522	6595
5295	10522	7682
5295	10522	2657
5295	10522	1794
5295	10522	789
7891	10523	8795
7891	10523	5933
8512	10524	4708
8512	10524	8857
8512	10524	9258
8512	10524	8646
8512	10524	2097
8512	10524	2816
10944	10525	686
10944	10525	6625
10944	10525	5186
10944	10525	608
10944	10525	5849
10944	10525	1289
10944	10525	796
10944	10525	732
10944	10525	9002
16518	10526	9715
16518	10526	838
16518	10526	8370
16518	10526	8003
16518	10526	8993
16518	10526	63
10498	10527	9230
10498	10527	4506
10498	10527	4757
10498	10527	7173
10498	10527	804
10498	10527	5076
10498	10527	4433
10498	10527	3353
8380	10528	3208
8380	10528	7358
8380	10528	3368
8380	10528	7818
8380	10528	2669
8380	10528	8693
8380	10528	2437
8380	10528	2416
19177	10529	5763
19177	10529	7060
19177	10529	9330
19177	10529	4342
19177	10529	4601
19177	10529	8030
19177	10529	5699
19177	10529	9
19177	10529	2807
10952	10530	7374
10952	10530	1684
10952	10530	9658
10952	10530	9377
10952	10530	9488
10952	10530	96
10952	10530	5334
10952	10530	6958
3117	10531	9368
3117	10531	2337
3117	10531	5460
3117	10531	7202
3117	10531	619
3117	10531	3737
3117	10531	9696
18706	10532	1692
18706	10532	2297
18706	10532	1638
18706	10532	1212
18706	10532	7306
18706	10532	154
18706	10532	7081
18833	10533	4560
18833	10533	5105
18833	10533	3329
18833	10533	3170
18833	10533	4262
18833	10533	2377
18833	10533	8108
18833	10533	4958
18833	10533	5855
14132	10534	7197
14132	10534	3339
14132	10534	4864
14132	10534	3693
14132	10534	7585
5379	10535	1532
5379	10535	6212
5379	10535	7550
11313	10536	6060
8187	10537	9432
8187	10537	7744
8187	10537	7049
1484	10538	8994
1484	10538	777
1484	10538	9414
1484	10538	9023
1484	10538	8101
1484	10538	4214
1484	10538	2229
1484	10538	4376
3173	10539	3987
3461	10540	4338
1411	10541	6932
12691	10542	1971
12691	10542	8530
1515	10543	9046
1515	10543	4076
1515	10543	9386
6225	10544	3888
6225	10544	2908
6225	10544	4835
6225	10544	5915
6225	10544	27
6225	10544	8112
6225	10544	807
6225	10544	637
17501	10545	1240
17501	10545	7750
17501	10545	566
17501	10545	3378
17501	10545	248
17501	10545	1628
17501	10545	7300
17501	10545	9540
17501	10545	614
1280	10546	6921
1280	10546	2094
16718	10547	7678
16718	10547	3677
16718	10547	2862
16718	10547	2563
16718	10547	8047
19348	10548	4209
19348	10548	8842
19348	10548	1940
19348	10548	5462
19348	10548	4754
19348	10548	1353
19348	10548	9939
12492	10549	3793
12492	10549	8310
12492	10549	8253
12597	10550	5973
12597	10550	9010
12597	10550	7113
18103	10551	5294
13293	10552	2444
13293	10552	9031
13293	10552	284
17188	10553	9467
17188	10553	1341
17188	10553	4673
17188	10553	3777
17188	10553	7494
4991	10554	2960
4991	10554	7474
19337	10555	7070
19337	10555	7103
19337	10555	445
19337	10555	5947
10827	10556	8562
4676	10557	3226
4676	10557	7575
4676	10557	4308
4676	10557	8399
4676	10557	6340
9860	10558	2551
9860	10558	5872
9860	10558	5596
9860	10558	2918
9860	10558	7232
9860	10558	4804
9860	10558	2176
9860	10558	8131
2714	10559	4523
2714	10559	5579
2714	10559	1092
2714	10559	3200
2714	10559	6848
18797	10560	2394
18797	10560	8751
18797	10560	9632
18797	10560	522
18797	10560	1776
18797	10560	6825
18797	10560	5521
1049	10561	9835
1049	10561	8707
1049	10561	6835
1049	10561	3468
1049	10561	9709
1049	10561	3080
10947	10562	785
2613	10563	4004
2613	10563	7874
2613	10563	9500
2613	10563	49
2613	10563	4923
2613	10563	3755
2613	10563	810
2613	10563	5535
10486	10564	4457
10486	10564	2825
10486	10564	475
10486	10564	2720
10486	10564	4916
10486	10564	4635
10486	10564	6307
11613	10565	4645
11613	10565	8375
11613	10565	197
11613	10565	8990
11613	10565	3461
11613	10565	974
11613	10565	612
11613	10565	2531
6010	10566	9672
6010	10566	8024
6010	10566	881
6010	10566	6815
6010	10566	137
6010	10566	7816
6010	10566	5028
10448	10567	955
10448	10567	5431
12086	10568	9480
12086	10568	6635
12086	10568	8486
12086	10568	8488
18737	10569	8693
18737	10569	5886
18737	10569	5759
18737	10569	2698
18737	10569	6137
18737	10569	1110
18737	10569	6905
16009	10570	1634
16009	10570	7943
16009	10570	8589
16009	10570	4574
16009	10570	2938
16009	10570	6445
10274	10571	1645
10274	10571	9409
10274	10571	9453
10274	10571	2414
10274	10571	2638
10274	10571	7103
10274	10571	7323
10274	10571	8038
11960	10572	2408
10690	10573	9123
10690	10573	8995
10690	10573	8089
10690	10573	4389
7683	10574	4404
7683	10574	6713
7683	10574	7339
7683	10574	1193
7683	10574	2992
7683	10574	1356
7683	10574	3279
1383	10575	4549
1383	10575	8588
1383	10575	2107
1383	10575	4182
1383	10575	4174
1383	10575	336
1383	10575	6557
1383	10575	2898
1383	10575	6246
14875	10576	379
7313	10577	4348
7313	10577	1520
7313	10577	8068
348	10578	6669
348	10578	5784
348	10578	8173
348	10578	1745
348	10578	5610
348	10578	1306
13836	10579	3885
13836	10579	9462
13836	10579	6244
13836	10579	4454
13836	10579	2706
13836	10579	7870
9305	10580	5609
9305	10580	6369
9305	10580	9891
9305	10580	4852
9305	10580	6103
9305	10580	8415
9305	10580	3076
9305	10580	7334
9305	10580	5343
3173	10581	9349
3173	10581	8550
3173	10581	8454
3173	10581	1871
3173	10581	610
3173	10581	7771
15323	10582	3162
15323	10582	2271
15323	10582	2722
15323	10582	3201
15323	10582	2307
15323	10582	6849
14904	10583	761
14904	10583	6696
14904	10583	9705
14904	10583	9435
14904	10583	6045
14904	10583	7293
14904	10583	4866
14904	10583	3419
14904	10583	3577
12596	10584	6353
12596	10584	1348
12596	10584	7223
14266	10585	5593
14266	10585	629
126	10586	7268
126	10586	9567
126	10586	5288
17727	10587	5162
17727	10587	2571
17727	10587	3052
17727	10587	4715
17727	10587	5396
17727	10587	7408
17727	10587	6783
17727	10587	4001
17727	10587	8299
7820	10588	6814
7820	10588	6875
7820	10588	5028
7820	10588	965
7820	10588	6802
18745	10589	3291
18745	10589	6740
18745	10589	7723
18745	10589	5036
18745	10589	7147
18745	10589	1916
18779	10590	4131
18779	10590	3771
17598	10591	2502
17598	10591	5361
17598	10591	4216
17598	10591	2379
17598	10591	5355
17598	10591	6192
17598	10591	3265
17598	10591	7583
17598	10591	264
19031	10592	1244
19031	10592	1380
19031	10592	4023
19031	10592	3813
19031	10592	8885
8490	10593	7245
8490	10593	8629
9641	10594	6048
9641	10594	7401
9641	10594	2758
9641	10594	5827
9641	10594	8467
9641	10594	4663
9641	10594	2084
11792	10595	2211
11792	10595	2624
11792	10595	8778
11792	10595	9046
11792	10595	2469
11792	10595	2226
11792	10595	9760
11792	10595	1405
8323	10596	5807
937	10597	9154
937	10597	5459
937	10597	6603
937	10597	7558
937	10597	2108
937	10597	9095
937	10597	3741
937	10597	3923
937	10597	9708
2224	10598	5274
2224	10598	9234
2224	10598	138
2224	10598	1548
2224	10598	6276
2224	10598	7088
2224	10598	604
2224	10598	9404
3021	10599	2663
3021	10599	3574
6563	10600	4394
6563	10600	7264
6563	10600	2364
6563	10600	746
6563	10600	3211
6563	10600	1366
6563	10600	2996
6563	10600	1221
1248	10601	2134
1248	10601	7070
1248	10601	4491
1248	10601	1382
1248	10601	3924
16634	10602	7984
16634	10602	893
16634	10602	7622
16634	10602	1024
8038	10603	7618
8038	10603	5434
8038	10603	4644
8038	10603	5632
8038	10603	2365
7493	10604	5395
7493	10604	4596
7493	10604	343
7493	10604	3273
7493	10604	1309
7493	10604	5339
17857	10605	3739
17857	10605	6907
17857	10605	3345
17857	10605	6740
17857	10605	3262
17857	10605	9098
17857	10605	2850
16490	10606	6397
16490	10606	9070
16490	10606	5437
16490	10606	563
16490	10606	2710
16490	10606	9704
6884	10607	2614
6884	10607	6221
6884	10607	5348
6884	10607	8458
6884	10607	5099
13987	10608	3484
13987	10608	419
13987	10608	5617
13987	10608	2932
13987	10608	6632
13987	10608	6623
8775	10609	9059
8775	10609	4102
8775	10609	1745
8775	10609	4761
8775	10609	3895
8775	10609	1509
8775	10609	6853
673	10610	2890
673	10610	8744
673	10610	8805
10853	10611	9814
10853	10611	3893
10853	10611	3877
10853	10611	4151
10853	10611	7444
10853	10611	5823
14661	10612	8391
14661	10612	5959
14661	10612	2949
14661	10612	8025
14661	10612	4670
14661	10612	7067
17551	10613	262
17551	10613	940
10182	10614	4003
10182	10614	2965
1111	10615	617
1111	10615	6701
9450	10616	1553
9450	10616	4005
9450	10616	1099
9450	10616	5876
9450	10616	2488
9450	10616	5499
9450	10616	1907
9450	10616	8296
2521	10617	1816
2521	10617	5052
2521	10617	1433
2521	10617	5997
2506	10618	3576
2506	10618	1837
2506	10618	2813
2506	10618	6034
2506	10618	4528
2506	10618	1970
2506	10618	6790
2506	10618	2342
2047	10619	8102
2047	10619	5773
2047	10619	8182
2047	10619	4170
13358	10620	3192
13358	10620	1271
13358	10620	2237
13358	10620	1305
13358	10620	8838
13358	10620	3198
11079	10621	6563
11079	10621	8407
11079	10621	1061
11079	10621	4198
11079	10621	5948
17939	10622	5566
17939	10622	1112
17939	10622	4242
17939	10622	4142
17939	10622	112
17939	10622	8821
4721	10623	7426
4721	10623	6491
15103	10624	6794
15103	10624	2639
15103	10624	4930
15103	10624	7280
16782	10625	1739
3700	10626	5159
3700	10626	6891
3700	10626	4917
3700	10626	9417
3700	10626	150
324	10627	6123
324	10627	6444
324	10627	4087
324	10627	1547
324	10627	2115
324	10627	174
11768	10628	414
11768	10628	7861
11768	10628	4868
11768	10628	1622
11768	10628	4184
6285	10629	8894
6285	10629	3940
6285	10629	9106
6285	10629	9061
6285	10629	8035
6285	10629	9532
6285	10629	5029
1462	10630	1592
1462	10630	1810
1462	10630	5326
1462	10630	743
1462	10630	5202
14269	10631	5189
14269	10631	6882
11886	10632	7119
11886	10632	263
8709	10633	8860
8709	10633	1597
8709	10633	928
8709	10633	4101
8709	10633	6431
8709	10633	6188
8709	10633	6437
8709	10633	627
8709	10633	4237
16514	10634	312
1149	10635	4929
1149	10635	8756
1149	10635	61
1149	10635	4458
1149	10635	7274
1149	10635	2658
1149	10635	7861
1149	10635	2786
1149	10635	7087
2647	10636	9580
2647	10636	2709
16109	10637	7761
16109	10637	3246
16109	10637	9182
16109	10637	6868
16109	10637	4293
16109	10637	2198
16109	10637	7844
1259	10638	4041
1259	10638	4204
1259	10638	2120
9658	10639	2884
9658	10639	1921
9658	10639	9534
9658	10639	7160
8054	10640	8168
8054	10640	9714
8054	10640	4611
17933	10641	9245
2729	10642	6194
2729	10642	9236
2729	10642	4192
2729	10642	9720
2729	10642	6322
9585	10643	7556
9585	10643	9348
9585	10643	5085
9585	10643	2778
9585	10643	2926
4339	10644	3534
4339	10644	3013
4339	10644	187
4339	10644	8803
4339	10644	3404
4339	10644	8103
4339	10644	5402
4339	10644	4517
4145	10645	9342
4145	10645	8646
4145	10645	2191
4145	10645	3286
4145	10645	3740
14546	10646	7000
14546	10646	7900
14546	10646	1744
14546	10646	4325
14546	10646	1027
14546	10646	389
11455	10647	414
11455	10647	1882
8144	10648	8667
8144	10648	9406
8144	10648	1642
17282	10649	4444
17282	10649	6160
17282	10649	5541
17282	10649	8495
17282	10649	2730
690	10650	7302
690	10650	1129
3516	10651	6127
15535	10652	6409
15535	10652	3687
15535	10652	4377
15535	10652	9620
15535	10652	7032
15535	10652	5846
15535	10652	2643
15535	10652	107
14816	10653	3786
5051	10654	671
5051	10654	6352
5051	10654	9579
5051	10654	4083
5051	10654	3612
5051	10654	3111
5051	10654	8376
5051	10654	1344
7973	10655	2574
17977	10656	7301
17977	10656	3729
8798	10657	9800
8798	10657	2148
8798	10657	9772
8798	10657	2342
8798	10657	8990
8798	10657	3025
8798	10657	4938
8798	10657	4319
8798	10657	2938
712	10658	1560
712	10658	4399
712	10658	9361
712	10658	9687
712	10658	6824
712	10658	2797
712	10658	3369
712	10658	4731
712	10658	5451
16950	10659	1403
16950	10659	8023
11951	10660	5923
11951	10660	4326
7372	10661	9975
7372	10661	716
8167	10662	9793
8167	10662	2000
8167	10662	9265
8167	10662	7582
8167	10662	4423
8167	10662	5008
8167	10662	1580
8167	10662	829
10309	10663	8840
10309	10663	8732
10309	10663	160
10309	10663	1586
10309	10663	3531
10309	10663	1992
10309	10663	7714
13956	10664	7645
13956	10664	2727
13956	10664	4151
13956	10664	2357
13956	10664	1808
13956	10664	134
13956	10664	5819
9101	10665	3998
9101	10665	9082
9101	10665	6298
9101	10665	851
9101	10665	5065
10215	10666	9573
10215	10666	1288
10215	10666	4546
10215	10666	8704
10215	10666	1961
10215	10666	5986
10215	10666	7811
10215	10666	2330
12653	10667	3854
12653	10667	6722
12653	10667	5281
12653	10667	5095
12653	10667	6894
12653	10667	4905
12384	10668	9836
12384	10668	3749
12384	10668	7730
12384	10668	9575
12384	10668	930
12384	10668	1138
12384	10668	8231
4169	10669	6788
4169	10669	1653
4169	10669	8930
4169	10669	4492
4169	10669	5013
4169	10669	27
4169	10669	4735
4169	10669	4095
4169	10669	1658
2465	10670	3136
2465	10670	6643
2465	10670	4611
2465	10670	3451
2465	10670	9656
2465	10670	4648
2465	10670	2121
2465	10670	9855
2465	10670	7412
14875	10671	7300
14875	10671	7169
14875	10671	5988
14875	10671	189
14875	10671	4531
14875	10671	1852
14875	10671	4691
14875	10671	961
1233	10672	1925
1233	10672	6676
1233	10672	7112
2128	10673	9750
2128	10673	878
2128	10673	7781
2128	10673	2303
2128	10673	216
2128	10673	1295
2128	10673	8006
17933	10674	9583
17933	10674	80
17933	10674	3005
17933	10674	3287
17933	10674	843
17933	10674	1180
17933	10674	6647
15050	10675	4390
15050	10675	6941
15050	10675	6983
15050	10675	6673
15050	10675	4220
15050	10675	3954
15050	10675	2183
15050	10675	850
15050	10675	5044
16659	10676	8262
16659	10676	2227
16659	10676	6080
16659	10676	2433
16659	10676	2388
16659	10676	4077
16659	10676	1427
16659	10676	7563
16659	10676	6048
2	10677	3538
2	10677	7747
2	10677	4831
2	10677	6910
2	10677	6624
17701	10678	2268
9311	10679	3984
9311	10679	9092
9311	10679	8860
9311	10679	3328
9311	10679	5140
9311	10679	7645
9311	10679	4431
9311	10679	7258
8334	10680	9338
8334	10680	7630
8334	10680	2039
8334	10680	1928
8334	10680	4553
8334	10680	4026
8334	10680	2021
8334	10680	81
6817	10681	6863
6817	10681	2073
6817	10681	6076
6817	10681	554
17228	10682	624
17228	10682	2251
17228	10682	4537
18177	10683	7624
18177	10683	5800
18177	10683	8337
2754	10684	2062
2754	10684	9268
2754	10684	8853
2754	10684	6368
2754	10684	8434
2754	10684	5184
2754	10684	8017
2754	10684	1721
753	10685	3059
753	10685	4507
753	10685	6969
753	10685	2914
753	10685	4221
753	10685	6056
753	10685	9889
17484	10686	1091
12548	10687	3708
12548	10687	4733
12746	10688	5638
12746	10688	6647
12746	10688	9718
12746	10688	687
12746	10688	9926
12746	10688	219
12746	10688	2064
12746	10688	8556
19294	10689	5921
19294	10689	1765
19294	10689	7770
19294	10689	4947
19294	10689	2870
19294	10689	289
19294	10689	4187
19294	10689	1112
19294	10689	6496
12844	10690	6237
12844	10690	2697
12844	10690	7808
12844	10690	4439
12844	10690	7703
12844	10690	2005
12844	10690	9988
12844	10690	5963
17664	10691	7339
17664	10691	9497
17664	10691	337
16355	10692	6237
16355	10692	9390
16355	10692	3442
16355	10692	7051
16355	10692	5786
16355	10692	8241
16355	10692	4220
16355	10692	7564
19674	10693	2398
19674	10693	1841
19674	10693	4803
19674	10693	7886
19674	10693	354
13181	10694	5523
13181	10694	424
13181	10694	272
17024	10695	6740
17024	10695	1730
1489	10696	7098
1489	10696	5692
1489	10696	9326
1489	10696	6951
1577	10697	4015
1577	10697	5218
1577	10697	4367
3386	10698	3240
3386	10698	6209
3386	10698	642
3386	10698	5714
3386	10698	1406
14193	10699	674
14193	10699	2105
14193	10699	2450
12929	10700	903
12929	10700	8083
12929	10700	6226
18931	10701	4435
18931	10701	11
18931	10701	9417
5032	10702	4941
5032	10702	9331
5032	10702	3736
5032	10702	5419
5032	10702	8245
5032	10702	3706
5032	10702	119
12688	10703	5810
12688	10703	9292
12688	10703	163
12688	10703	392
12688	10703	718
12688	10703	2095
12688	10703	1020
701	10704	2131
701	10704	3261
13932	10705	8754
13932	10705	1545
13932	10705	7106
13932	10705	9322
13932	10705	7598
15978	10706	1340
15978	10706	5646
15978	10706	8191
15978	10706	2709
15978	10706	6209
15978	10706	1768
13702	10707	2052
13702	10707	4951
13702	10707	7815
13702	10707	951
13702	10707	8453
8305	10708	569
8305	10708	6837
8305	10708	235
8305	10708	275
8305	10708	7297
8305	10708	7782
5991	10709	7730
5991	10709	7578
5991	10709	1564
5027	10710	1062
5027	10710	7341
5027	10710	4826
3325	10711	6690
3325	10711	8652
3325	10711	882
3325	10711	3051
3325	10711	9429
3325	10711	9223
13601	10712	2192
13601	10712	1009
13601	10712	7762
13601	10712	3865
13601	10712	9668
13601	10712	3011
13601	10712	353
13601	10712	850
19002	10713	5934
19002	10713	9250
19002	10713	3045
19954	10714	8473
19954	10714	6931
19954	10714	2183
12094	10715	4737
12094	10715	6361
14422	10716	6712
14422	10716	3887
6273	10717	1609
13762	10718	4346
13762	10718	8212
13762	10718	4507
13762	10718	2575
13762	10718	982
13762	10718	7105
13762	10718	2401
13762	10718	4554
2530	10719	3911
2530	10719	5539
2530	10719	5211
10939	10720	4200
10939	10720	5144
10939	10720	4901
10939	10720	2175
10939	10720	3950
2108	10721	8098
2108	10721	1721
2108	10721	6317
2108	10721	9015
2108	10721	4340
2108	10721	2145
2108	10721	1700
11455	10722	4101
11455	10722	1630
11455	10722	4712
11455	10722	6477
11455	10722	6960
11455	10722	9715
11455	10722	8453
11455	10722	2510
11455	10722	4425
6879	10723	7993
6879	10723	3473
6879	10723	5785
6879	10723	5420
19040	10724	8521
19040	10724	3145
19040	10724	4137
19040	10724	6261
19040	10724	7562
19040	10724	1663
19040	10724	4885
19040	10724	8897
19040	10724	9527
15039	10725	7212
15039	10725	356
16132	10726	7406
16132	10726	6873
2017	10727	4860
2017	10727	6643
3055	10728	5996
3055	10728	5132
3055	10728	9656
3055	10728	6251
3055	10728	9207
3055	10728	9499
3055	10728	4672
4154	10729	2627
4154	10729	9117
4154	10729	9921
4154	10729	1496
4154	10729	499
4154	10729	8091
4154	10729	6966
4154	10729	5246
9802	10730	1769
9802	10730	1330
9802	10730	5421
9802	10730	2918
9802	10730	8078
1408	10731	3985
1408	10731	7857
1408	10731	9716
1408	10731	5263
4457	10732	4326
4457	10732	1610
4457	10732	5090
4457	10732	6281
4457	10732	4645
4457	10732	2419
4457	10732	8357
6242	10733	7001
6242	10733	9186
6242	10733	665
6242	10733	3213
6242	10733	6708
6242	10733	8156
4962	10734	3181
4962	10734	6372
4962	10734	474
5786	10735	3389
5786	10735	2640
5786	10735	7414
5786	10735	9773
5786	10735	4498
5786	10735	5500
5786	10735	6364
5786	10735	2386
5786	10735	808
19547	10736	3829
8606	10737	7196
1167	10738	5172
1167	10738	2603
1167	10738	8123
7245	10739	5830
7245	10739	6264
6526	10740	3444
6526	10740	863
6526	10740	4542
6526	10740	3890
6526	10740	7743
6526	10740	2320
6526	10740	7176
19556	10741	6878
19556	10741	5120
1898	10742	7586
1898	10742	9086
1898	10742	7577
1898	10742	4234
1898	10742	5615
1898	10742	3453
2390	10743	3047
2390	10743	323
2390	10743	671
15097	10744	9236
15097	10744	3987
15097	10744	5956
10082	10745	7570
10082	10745	3982
10082	10745	8576
10082	10745	2689
10082	10745	8629
3349	10746	8096
3349	10746	4999
3349	10746	5518
9507	10747	2872
9507	10747	4612
9507	10747	6700
8539	10748	7454
285	10749	6549
285	10749	8099
285	10749	1802
285	10749	1816
285	10749	2209
285	10749	2372
16150	10750	9735
16150	10750	5797
16150	10750	9092
16150	10750	704
16150	10750	2539
669	10751	6758
669	10751	4831
669	10751	8695
669	10751	1050
669	10751	3432
11606	10752	3878
11606	10752	4889
11606	10752	7734
11606	10752	46
11606	10752	2862
11606	10752	5897
11606	10752	8907
11606	10752	5735
11606	10752	8793
7247	10753	256
7375	10754	9490
7375	10754	9033
7375	10754	4997
7375	10754	6980
7375	10754	4605
7375	10754	9555
7375	10754	7774
7375	10754	2866
7375	10754	8975
15535	10755	1391
15535	10755	6687
15535	10755	6837
15535	10755	5333
15535	10755	7047
15535	10755	4669
19331	10756	2395
19331	10756	2195
19331	10756	2071
19331	10756	7400
19331	10756	6648
1067	10757	6472
1067	10757	3066
1067	10757	7178
1067	10757	1103
1067	10757	8396
6128	10758	2729
6128	10758	692
6128	10758	8834
6128	10758	7073
6128	10758	2854
19004	10759	35
19004	10759	4000
19004	10759	519
19004	10759	9665
19004	10759	6968
19004	10759	207
19004	10759	8916
19004	10759	8427
19004	10759	3062
7508	10760	6640
7508	10760	7110
7508	10760	7825
7508	10760	8996
7508	10760	2322
7508	10760	3659
8355	10761	1874
8355	10761	5967
8355	10761	5718
8355	10761	9619
8355	10761	8028
10802	10762	1608
10802	10762	4931
5511	10763	1427
5511	10763	592
12256	10764	1328
12256	10764	4051
12256	10764	3215
12256	10764	2178
410	10765	5606
410	10765	791
410	10765	5022
410	10765	5931
410	10765	8477
410	10765	9151
410	10765	1583
410	10765	4988
410	10765	5870
14395	10766	4492
14395	10766	9406
14395	10766	1433
14395	10766	6874
14395	10766	2530
14395	10766	8895
14395	10766	9693
14395	10766	9042
14395	10766	1504
1308	10767	396
1308	10767	6692
1308	10767	6658
1308	10767	3463
1308	10767	1918
2647	10768	4642
2647	10768	9021
15829	10769	1830
15829	10769	9291
15829	10769	7053
15829	10769	3988
8766	10770	648
8766	10770	6281
8766	10770	5582
8766	10770	2064
13374	10771	8184
13374	10771	1333
13374	10771	5232
13374	10771	5829
10239	10772	7628
10239	10772	2885
10239	10772	8765
10239	10772	8938
10239	10772	3306
10239	10772	3522
10239	10772	3415
10239	10772	5110
6813	10773	723
11908	10774	3015
11908	10774	3564
11908	10774	24
11908	10774	7792
11908	10774	6129
11908	10774	2675
11908	10774	5968
11908	10774	284
7397	10775	6634
7397	10775	3384
7397	10775	7803
7397	10775	2160
7397	10775	60
7397	10775	8864
7397	10775	4027
7397	10775	6484
7397	10775	3619
19495	10776	4814
19495	10776	5613
19495	10776	6287
19495	10776	8796
19495	10776	458
19495	10776	8708
19495	10776	9159
19495	10776	7947
19495	10776	6929
11585	10777	8220
11585	10777	1810
11585	10777	1840
11585	10777	1586
11585	10777	8402
11585	10777	9468
11585	10777	1496
583	10778	5720
583	10778	8792
583	10778	2334
583	10778	6198
583	10778	4744
11649	10779	3389
11649	10779	5113
11649	10779	8267
13335	10780	682
13335	10780	3121
13335	10780	4885
13335	10780	127
13335	10780	6060
13335	10780	5483
13335	10780	5657
801	10781	6225
801	10781	5983
801	10781	8796
14124	10782	3730
14124	10782	105
14124	10782	5482
732	10783	970
732	10783	8632
732	10783	7912
732	10783	8132
732	10783	4688
732	10783	8275
732	10783	9038
732	10783	526
732	10783	5352
6287	10784	4033
6287	10784	3035
6287	10784	1433
6287	10784	9881
6287	10784	2333
6287	10784	4413
6287	10784	7303
6287	10784	5252
19879	10785	852
19879	10785	423
19879	10785	2046
19879	10785	6743
19879	10785	8918
19879	10785	5565
17198	10786	1219
17198	10786	9380
17198	10786	3195
17198	10786	4516
17198	10786	6118
8016	10787	174
1192	10788	6370
1192	10788	4304
1192	10788	3524
1192	10788	8237
1192	10788	8468
1192	10788	1066
1192	10788	3045
12479	10789	6736
12479	10789	7521
12479	10789	4363
12479	10789	3771
12479	10789	7785
12479	10789	5132
12479	10789	6452
1510	10790	623
1510	10790	8499
19127	10791	9
19127	10791	5010
19127	10791	9768
19127	10791	4600
19127	10791	4412
19127	10791	4514
19127	10791	3498
19127	10791	7271
7444	10792	4477
10199	10793	4190
5932	10794	4980
9494	10795	2035
9494	10795	8211
9494	10795	5791
9494	10795	8846
9494	10795	338
9494	10795	6783
9494	10795	1276
9494	10795	7388
9494	10795	6359
1096	10796	3514
1096	10796	5240
1096	10796	4891
1096	10796	3241
1096	10796	9138
14697	10797	9058
14697	10797	4545
2656	10798	2587
2656	10798	6416
2656	10798	6582
7164	10799	7023
7164	10799	1500
7164	10799	822
19919	10800	7308
19919	10800	7179
19919	10800	2504
19919	10800	5760
19919	10800	3051
19919	10800	6840
6510	10801	4112
6510	10801	3036
6510	10801	7082
6510	10801	738
6510	10801	1972
6510	10801	3322
6510	10801	1519
6510	10801	7666
6510	10801	5173
15351	10802	1709
17097	10803	1803
17097	10803	8899
17097	10803	3913
17097	10803	5719
17097	10803	1993
17097	10803	9577
17097	10803	8015
17097	10803	5935
17097	10803	6235
2814	10804	9083
2814	10804	4499
2814	10804	4629
2814	10804	9339
2284	10805	7057
2284	10805	1349
2284	10805	4630
2284	10805	9231
2284	10805	7305
2284	10805	7105
2284	10805	6779
2284	10805	6840
2284	10805	4746
7656	10806	4619
7656	10806	4256
7656	10806	4808
9058	10807	8163
9058	10807	4931
8322	10808	1407
8322	10808	9420
8322	10808	7442
8322	10808	3322
8322	10808	1543
8322	10808	6015
1267	10809	4591
1267	10809	4218
1267	10809	6096
1267	10809	1846
1267	10809	3938
1267	10809	7051
1267	10809	937
1267	10809	8994
1267	10809	8151
11185	10810	7780
11185	10810	5856
11185	10810	8051
11185	10810	4428
18038	10811	8709
18038	10811	3114
18038	10811	6730
18038	10811	7330
18038	10811	9865
17716	10812	7271
17716	10812	1572
17716	10812	4984
17716	10812	8156
17716	10812	3145
17716	10812	1886
4758	10813	7089
4758	10813	9865
4758	10813	5854
4758	10813	7254
4758	10813	375
4758	10813	1450
4758	10813	5976
6492	10814	5188
6492	10814	5103
6492	10814	9018
6492	10814	9550
6492	10814	5820
6492	10814	3282
741	10815	573
741	10815	4418
741	10815	6747
741	10815	4943
741	10815	2994
741	10815	255
741	10815	4164
741	10815	2928
16061	10816	6278
4194	10817	4508
4194	10817	5198
4194	10817	8593
4194	10817	5781
4194	10817	3596
17076	10818	9456
7239	10819	2971
11332	10820	7911
11332	10820	7302
11332	10820	3072
11332	10820	1492
11332	10820	4026
19613	10821	2334
19613	10821	6173
19613	10821	1690
19613	10821	4037
19613	10821	9248
19613	10821	558
19613	10821	4519
2435	10822	9462
2435	10822	6516
2435	10822	3801
2435	10822	803
2435	10822	8091
2435	10822	7633
19932	10823	3024
19932	10823	4277
19932	10823	3428
19932	10823	5525
19932	10823	5743
19932	10823	3469
19932	10823	1261
19932	10823	9421
11872	10824	3944
11872	10824	1776
11872	10824	8901
11872	10824	3218
10592	10825	9064
10592	10825	9458
10592	10825	7828
7139	10826	7196
7139	10826	8102
7139	10826	7010
7139	10826	2552
7139	10826	2202
7139	10826	4324
7139	10826	8528
7139	10826	3385
7139	10826	4603
9258	10827	8932
9258	10827	8595
9258	10827	9595
9258	10827	329
9258	10827	5013
9258	10827	909
15835	10828	8183
15835	10828	3185
15835	10828	7544
15835	10828	5732
15835	10828	3459
15835	10828	3686
15835	10828	4963
7789	10829	654
7789	10829	268
7789	10829	7668
7789	10829	8506
7789	10829	8395
19522	10830	3328
19522	10830	7183
19522	10830	4234
19522	10830	1799
19522	10830	3247
16419	10831	2104
16419	10831	9993
16419	10831	823
16419	10831	3739
16419	10831	5540
7869	10832	3695
7869	10832	8235
7869	10832	6745
7869	10832	7894
19384	10833	5176
19384	10833	9786
3778	10834	4646
3778	10834	1905
14889	10835	1379
14889	10835	7213
14889	10835	9741
14889	10835	2095
19977	10836	9681
19977	10836	770
19977	10836	2992
19977	10836	4356
19977	10836	2445
19977	10836	6291
19977	10836	9731
19977	10836	5474
19977	10836	5639
14035	10837	2091
14035	10837	2634
14035	10837	7845
14035	10837	4174
14035	10837	2691
14035	10837	1440
14035	10837	8710
6130	10838	4697
6130	10838	3551
6130	10838	3561
6130	10838	746
6130	10838	5126
6130	10838	6218
16615	10839	2493
13331	10840	519
13331	10840	185
13331	10840	7125
13331	10840	2293
13331	10840	661
13331	10840	1567
13331	10840	1416
4322	10841	2880
4322	10841	5103
4322	10841	8852
4322	10841	1322
4322	10841	9151
4322	10841	8009
4322	10841	2081
4322	10841	3097
443	10842	6422
15978	10843	3117
15978	10843	612
15978	10843	2931
15978	10843	7988
15978	10843	4275
15978	10843	1238
15978	10843	8183
15978	10843	952
6065	10844	5298
6065	10844	4110
6065	10844	2518
6065	10844	8890
453	10845	4798
453	10845	9079
14133	10846	3906
14133	10846	1975
14133	10846	7386
14133	10846	8278
14133	10846	5959
14133	10846	2065
12347	10847	6705
12347	10847	7537
12347	10847	2137
12347	10847	6860
12347	10847	4154
12347	10847	4662
12347	10847	3005
12347	10847	2638
9225	10848	7539
9225	10848	2983
9225	10848	270
9225	10848	4755
9225	10848	1220
15848	10849	3148
15848	10849	6795
1897	10850	7207
1897	10850	3838
1897	10850	5860
1897	10850	4457
3990	10851	5493
3990	10851	4095
3990	10851	8137
3990	10851	8022
3990	10851	3238
3990	10851	3112
3990	10851	9526
3990	10851	6393
3990	10851	855
16123	10852	7906
16123	10852	6791
16123	10852	2005
16123	10852	4357
16123	10852	1903
11994	10853	1311
11994	10853	6531
11994	10853	5822
11994	10853	934
11994	10853	9550
808	10854	8466
808	10854	854
808	10854	8099
808	10854	8732
808	10854	500
4805	10855	8400
19420	10856	4258
19420	10856	1626
2350	10857	1579
2350	10857	1263
2350	10857	3131
2350	10857	6415
2350	10857	9761
2350	10857	1333
11145	10858	6350
11145	10858	4201
10694	10859	2315
10694	10859	220
10694	10859	6585
10694	10859	570
10694	10859	4917
16095	10860	9277
16095	10860	9768
16095	10860	3968
16095	10860	6182
16095	10860	9171
6742	10861	8718
6742	10861	3490
6742	10861	3527
6742	10861	5661
6742	10861	6446
6742	10861	8274
6742	10861	8061
6742	10861	9410
17373	10862	9296
10954	10863	8008
10954	10863	1411
10954	10863	2465
10954	10863	456
10954	10863	1161
10954	10863	9664
10954	10863	4093
10954	10863	3050
2221	10864	3119
2221	10864	5568
2221	10864	818
2221	10864	8518
2221	10864	340
2221	10864	7727
2221	10864	8834
2597	10865	7253
2597	10865	5125
18435	10866	1584
861	10867	380
861	10867	3360
861	10867	7812
861	10867	884
861	10867	6709
11084	10868	6840
11084	10868	8328
11084	10868	7440
11084	10868	1009
11084	10868	2670
11084	10868	4983
11084	10868	4533
3826	10869	4861
3826	10869	6259
3826	10869	6152
3826	10869	823
3826	10869	5753
7000	10870	514
7000	10870	9334
7000	10870	6286
7000	10870	2640
7000	10870	4377
17820	10871	823
17820	10871	2954
17820	10871	9198
17820	10871	8356
17820	10871	6355
17820	10871	8208
17820	10871	6500
17820	10871	5607
12240	10872	4074
12240	10872	1525
11804	10873	4812
11804	10873	178
11804	10873	3269
4931	10874	7814
4931	10874	8851
4931	10874	806
4931	10874	2630
4931	10874	6356
4931	10874	2532
4931	10874	5662
4931	10874	317
4931	10874	3318
15305	10875	5997
15305	10875	3533
15305	10875	4989
15305	10875	1731
15305	10875	4523
15305	10875	6031
15305	10875	5565
15305	10875	8724
10158	10876	5273
10158	10876	2384
10158	10876	5520
10158	10876	4984
10158	10876	3354
10158	10876	6506
77	10877	4889
77	10877	844
77	10877	9889
77	10877	2785
3018	10878	6588
3018	10878	2738
3018	10878	4653
3018	10878	7449
3018	10878	823
3018	10878	8778
3018	10878	9098
15241	10879	1132
15241	10879	2488
4753	10880	7830
4753	10880	3915
4753	10880	9520
4514	10881	7378
4514	10881	2619
4514	10881	2245
2683	10882	8962
2683	10882	8047
2683	10882	2212
2683	10882	2069
2683	10882	2910
2683	10882	4239
16308	10883	8657
16308	10883	5256
16308	10883	2460
10156	10884	6475
10156	10884	4416
10156	10884	9116
14324	10885	7695
14324	10885	9198
14324	10885	6458
14324	10885	1344
14324	10885	1590
14324	10885	2936
14324	10885	3571
12060	10886	1108
12060	10886	5170
19170	10887	2962
19170	10887	1147
19170	10887	3256
19170	10887	1971
16856	10888	8365
2599	10889	9490
2599	10889	3950
2599	10889	1087
2599	10889	1972
2599	10889	2639
2599	10889	5841
2599	10889	826
2599	10889	9264
5038	10890	4973
5038	10890	5633
5038	10890	1049
5038	10890	8343
5038	10890	5296
5038	10890	3317
5038	10890	5060
12293	10891	2402
12293	10891	3912
12293	10891	8334
12293	10891	7044
12293	10891	6710
12293	10891	117
12293	10891	9482
10228	10892	9110
10228	10892	4230
10228	10892	363
10228	10892	9192
10228	10892	4813
10228	10892	1569
10228	10892	1362
10228	10892	2096
860	10893	8027
860	10893	1533
860	10893	4245
860	10893	3232
860	10893	6128
860	10893	860
860	10893	3478
860	10893	9644
860	10893	2637
14898	10894	4584
13360	10895	7110
13360	10895	6269
13360	10895	6492
13360	10895	3279
13360	10895	8815
13360	10895	2764
13360	10895	5694
18342	10896	3011
18342	10896	8659
18342	10896	8798
18342	10896	3106
18342	10896	6271
18342	10896	62
18342	10896	4921
18342	10896	5802
18342	10896	2307
11171	10897	2097
11171	10897	2748
11171	10897	9418
11171	10897	6961
11171	10897	2751
11171	10897	9480
11171	10897	2246
11171	10897	3193
18927	10898	5494
18927	10898	8892
2395	10899	6783
2395	10899	6163
2395	10899	2414
2395	10899	6669
2395	10899	1838
2395	10899	9961
2395	10899	3602
2395	10899	5997
18380	10900	8653
18380	10900	1097
18380	10900	2635
18380	10900	5443
18380	10900	1186
18380	10900	361
18380	10900	5652
18380	10900	6848
18380	10900	5434
14542	10901	1859
14542	10901	9296
14542	10901	6595
14542	10901	7046
14542	10901	6389
14542	10901	2248
14542	10901	9845
14542	10901	7473
14542	10901	6885
14492	10902	3770
14492	10902	8037
14492	10902	6990
14492	10902	6475
14492	10902	7788
14492	10902	4883
14492	10902	6189
14492	10902	4095
14492	10902	9269
3031	10903	6398
3031	10903	4066
3031	10903	4099
3031	10903	528
3031	10903	8357
3031	10903	4198
3031	10903	3500
3031	10903	4324
4222	10904	9194
6577	10905	3772
3480	10906	7181
3480	10906	2143
3480	10906	7891
3480	10906	2004
3480	10906	6967
3480	10906	2640
3480	10906	7388
3480	10906	441
17495	10907	3244
17495	10907	1556
17495	10907	5541
17495	10907	7637
17495	10907	7068
17495	10907	6866
17495	10907	2584
17495	10907	5527
15061	10908	3732
15061	10908	9110
15061	10908	6324
15061	10908	3828
15061	10908	8298
15061	10908	3665
15061	10908	1333
15061	10908	2514
301	10909	3228
301	10909	1863
301	10909	751
301	10909	6285
301	10909	4920
301	10909	1072
301	10909	2366
17378	10910	4086
17378	10910	338
17378	10910	9569
17378	10910	2971
7036	10911	1133
7036	10911	5164
7036	10911	1271
7036	10911	384
10606	10912	3954
10606	10912	9593
10606	10912	1616
10606	10912	7321
10606	10912	7353
10606	10912	3451
10606	10912	9328
10606	10912	9003
10606	10912	9939
2143	10913	4066
2143	10913	2369
2143	10913	5521
2143	10913	9752
2143	10913	121
2143	10913	9008
1246	10914	6324
1246	10914	2407
1246	10914	3310
1246	10914	6196
1246	10914	9606
1795	10915	7353
19441	10916	430
19441	10916	9810
19441	10916	9175
19441	10916	264
18602	10917	5691
18602	10917	5539
18602	10917	5491
18602	10917	1313
18602	10917	7869
18602	10917	5993
6690	10918	3066
6690	10918	7039
6690	10918	7534
13417	10919	3311
13417	10919	3608
13417	10919	872
13417	10919	8418
7817	10920	9004
7817	10920	4472
7817	10920	1086
7817	10920	8342
7817	10920	2885
7817	10920	9494
7817	10920	4901
7817	10920	6772
7817	10920	3735
14092	10921	1707
14092	10921	6158
14092	10921	4828
14092	10921	4033
14092	10921	4067
14092	10921	8984
14092	10921	8033
12749	10922	7781
5363	10923	1626
5363	10923	130
5363	10923	4800
5363	10923	1738
5363	10923	6094
5363	10923	6631
5363	10923	2352
12836	10924	4957
12836	10924	2947
12836	10924	8106
11773	10925	8568
11773	10925	2676
11773	10925	9212
11773	10925	5072
11773	10925	481
13149	10926	7495
13149	10926	7810
13149	10926	3473
13149	10926	4264
13149	10926	3240
13149	10926	1498
13149	10926	7656
10187	10927	6551
10187	10927	5994
10187	10927	6026
10187	10927	9773
10187	10927	7874
10187	10927	3081
1151	10928	1963
1151	10928	6754
1151	10928	1535
1151	10928	3437
1151	10928	1338
17139	10929	4369
17139	10929	2359
17139	10929	8498
17139	10929	1427
17139	10929	4891
17139	10929	8559
17139	10929	1878
17139	10929	8547
17139	10929	1241
15987	10930	7986
15987	10930	9181
15987	10930	1265
15987	10930	7894
15987	10930	6912
15987	10930	186
17366	10931	6953
17366	10931	3351
17366	10931	516
17366	10931	1507
5493	10932	740
5493	10932	7503
13367	10933	4458
13367	10933	5194
13367	10933	8204
13367	10933	639
13367	10933	4061
13367	10933	4878
13367	10933	838
2708	10934	417
2708	10934	777
2708	10934	1547
2708	10934	6296
2708	10934	242
2708	10934	5734
2708	10934	520
2708	10934	4232
4871	10935	3263
4871	10935	492
2658	10936	2683
2658	10936	721
2658	10936	19
3132	10937	616
3132	10937	2159
3132	10937	1545
3132	10937	6539
3132	10937	8392
3132	10937	8212
3132	10937	296
3132	10937	4636
3132	10937	9615
11968	10938	5809
11968	10938	7898
11968	10938	5710
11968	10938	7393
11968	10938	368
5052	10939	5205
5052	10939	9297
5052	10939	8994
5052	10939	3080
15429	10940	8516
15429	10940	4581
15429	10940	6990
15429	10940	6218
15429	10940	6217
15429	10940	5871
15429	10940	650
15429	10940	1618
11949	10941	6870
11949	10941	7564
11949	10941	2952
11949	10941	5152
10454	10942	7418
10454	10942	8879
10454	10942	5501
10454	10942	9294
10454	10942	7024
10454	10942	5326
10454	10942	1402
329	10943	4132
329	10943	1889
329	10943	5650
329	10943	2339
329	10943	6773
329	10943	6028
6890	10944	7852
6890	10944	1543
6890	10944	9633
6890	10944	2309
6890	10944	6240
6890	10944	1902
9638	10945	4606
9638	10945	9702
9638	10945	9710
9638	10945	1056
9638	10945	2735
9638	10945	3786
9638	10945	528
9638	10945	6749
16583	10946	6858
16583	10946	8707
16583	10946	1543
16583	10946	9635
5234	10947	7488
14395	10948	3680
14395	10948	8425
17905	10949	7332
17905	10949	3241
17905	10949	1530
17905	10949	690
17905	10949	3195
5658	10950	5446
5658	10950	6302
5658	10950	4193
5658	10950	131
5658	10950	7931
5658	10950	7254
10909	10951	404
10909	10951	2724
10909	10951	5496
10909	10951	3743
10909	10951	4490
10667	10952	1603
10667	10952	7133
10667	10952	8145
10667	10952	4494
10667	10952	682
10667	10952	2086
6722	10953	8303
6722	10953	6725
6722	10953	7438
6722	10953	5280
19538	10954	5102
19538	10954	2883
19538	10954	3096
19538	10954	4610
19538	10954	1341
19538	10954	9515
19538	10954	1526
608	10955	4390
608	10955	7141
608	10955	4289
608	10955	3333
3473	10956	8556
3473	10956	1759
3473	10956	1143
3473	10956	1454
5588	10957	4816
5588	10957	7209
5588	10957	6684
5588	10957	8120
5588	10957	5433
5588	10957	2186
11038	10958	7255
11038	10958	9472
11038	10958	3063
11038	10958	7249
11038	10958	6085
11038	10958	9957
9623	10959	1191
9623	10959	1084
9623	10959	7166
9623	10959	8948
9623	10959	4463
9623	10959	2319
3214	10960	232
3214	10960	9717
3214	10960	598
3214	10960	7499
14911	10961	2267
14911	10961	3472
14911	10961	1643
14911	10961	1332
14911	10961	3758
14911	10961	1406
14911	10961	1413
16129	10962	1971
16129	10962	1784
16129	10962	8855
12706	10963	3808
12706	10963	1480
12706	10963	4571
12706	10963	9532
1727	10964	1143
1727	10964	1482
1727	10964	150
10959	10965	1040
10959	10965	4277
10959	10965	584
19295	10966	7571
4283	10967	8355
4283	10967	6524
4283	10967	6446
4283	10967	9802
4283	10967	221
4283	10967	1930
16697	10968	6551
16697	10968	6364
16697	10968	636
16697	10968	6781
16697	10968	2666
16697	10968	6612
580	10969	3474
580	10969	8223
580	10969	8645
580	10969	7848
580	10969	7974
6807	10970	9873
6807	10970	840
6807	10970	1809
17180	10971	2942
17180	10971	307
9523	10972	5741
9523	10972	9652
9523	10972	528
9523	10972	3251
9523	10972	7276
9523	10972	1905
9523	10972	6089
9523	10972	77
9523	10972	8014
13720	10973	8372
13720	10973	3732
13720	10973	2851
13720	10973	3440
13720	10973	9724
13720	10973	9636
13720	10973	3565
13630	10974	9770
13630	10974	9552
13630	10974	2346
13630	10974	2788
2382	10975	8954
2382	10975	5405
16509	10976	5386
16509	10976	6889
16509	10976	1776
16509	10976	5184
16509	10976	7268
16509	10976	2800
16509	10976	4415
13521	10977	7119
13521	10977	6875
13521	10977	5480
13521	10977	9928
13521	10977	8513
13521	10977	9138
9047	10978	9544
9047	10978	9246
9047	10978	4013
9047	10978	8574
9047	10978	3552
9047	10978	9163
9047	10978	9749
9047	10978	2131
18011	10979	4833
6689	10980	4533
16241	10981	3484
16241	10981	8928
16241	10981	1786
16241	10981	4308
6940	10982	4611
18488	10983	9357
18488	10983	9444
18488	10983	1097
18488	10983	486
18488	10983	2005
18488	10983	3750
18488	10983	9344
18488	10983	3302
10173	10984	424
10173	10984	2505
10173	10984	6504
10173	10984	6123
10173	10984	6360
10173	10984	1922
10173	10984	6795
10173	10984	6068
10173	10984	6138
16284	10985	6172
16284	10985	4503
16284	10985	9312
16284	10985	4560
16284	10985	8266
16284	10985	1349
16284	10985	7190
6625	10986	2355
6625	10986	9962
6625	10986	4750
6625	10986	7042
1123	10987	7832
1123	10987	5319
1123	10987	4674
1123	10987	1564
19657	10988	599
16970	10989	2731
5383	10990	8721
5383	10990	9398
5383	10990	3826
5383	10990	5581
5383	10990	3627
5383	10990	3990
5383	10990	5530
5383	10990	7535
3502	10991	3157
3502	10991	4464
3502	10991	5604
3502	10991	4949
3502	10991	9886
3502	10991	7877
14549	10992	5701
14549	10992	9918
14549	10992	6389
14549	10992	7629
14549	10992	9461
14549	10992	7162
14549	10992	6913
14549	10992	821
10569	10993	2479
10569	10993	3664
10569	10993	4067
10569	10993	970
1756	10994	6367
1756	10994	3842
1756	10994	590
1756	10994	4673
1756	10994	6632
7090	10995	3615
7090	10995	996
7090	10995	8299
7090	10995	4455
7090	10995	5838
7090	10995	3501
4630	10996	6829
4630	10996	470
4630	10996	6807
4630	10996	2141
17545	10997	2317
17545	10997	1711
17545	10997	2618
17545	10997	7493
17545	10997	6181
17545	10997	2878
12756	10998	8693
12756	10998	1280
12756	10998	563
12756	10998	6192
12756	10998	2808
12756	10998	8848
12756	10998	7104
18842	10999	5353
18842	10999	4333
1027	11000	2532
1027	11000	3569
1027	11000	2752
1027	11000	7869
1027	11000	7783
1027	11000	5780
1027	11000	5800
4497	11001	7259
4497	11001	618
4497	11001	7328
4497	11001	1387
4497	11001	3472
4497	11001	8008
4497	11001	5368
4497	11001	7533
4497	11001	8538
11426	11002	5650
11426	11002	6126
11426	11002	6751
11638	11003	8467
11638	11003	9904
11638	11003	6427
11638	11003	1953
11638	11003	2340
11638	11003	601
11638	11003	4331
11638	11003	5758
11638	11003	8024
14033	11004	9068
14033	11004	4294
14033	11004	4433
14033	11004	1637
206	11005	5897
206	11005	7369
206	11005	3626
206	11005	7810
206	11005	7415
206	11005	2359
765	11006	7399
765	11006	7817
765	11006	7408
765	11006	2284
7841	11007	4024
7841	11007	970
7841	11007	8430
7841	11007	7769
7841	11007	8046
10922	11008	8634
10922	11008	9022
10922	11008	6313
10922	11008	96
10922	11008	2887
10922	11008	6240
10922	11008	9345
10922	11008	9092
6230	11009	3035
1607	11010	6382
1607	11010	2660
1607	11010	6850
1607	11010	6825
1607	11010	7141
1607	11010	2293
1607	11010	7267
7012	11011	8461
7012	11011	829
7012	11011	2557
7012	11011	9122
16550	11012	5475
16550	11012	2288
16550	11012	6876
16550	11012	9428
13136	11013	3805
13136	11013	2481
13136	11013	7610
13136	11013	2631
13136	11013	2273
13136	11013	4376
13136	11013	5733
15762	11014	1959
15762	11014	9588
15762	11014	5380
15762	11014	3383
15762	11014	163
15762	11014	1375
15762	11014	5693
16347	11015	1004
16347	11015	4783
16347	11015	9814
16347	11015	8104
16347	11015	2655
16347	11015	3427
16347	11015	5335
16347	11015	1672
14103	11016	1859
14103	11016	1405
14103	11016	8549
19304	11017	8365
19304	11017	8492
16609	11018	3851
16609	11018	6177
16609	11018	9385
16609	11018	2662
16609	11018	6435
16609	11018	8108
16609	11018	5306
13421	11019	3808
13421	11019	7568
13421	11019	3748
13421	11019	5353
13421	11019	9079
13421	11019	544
13421	11019	2558
13421	11019	6341
11449	11020	6781
11449	11020	6625
11449	11020	4501
11449	11020	4853
16103	11021	9663
16103	11021	1526
16103	11021	5283
8722	11022	5743
8722	11022	586
8722	11022	3075
8722	11022	7808
8722	11022	6589
8722	11022	2
9004	11023	8370
9004	11023	2380
9004	11023	6231
9004	11023	9504
9574	11024	9148
9780	11025	6973
9780	11025	133
9780	11025	7153
9780	11025	9368
9780	11025	9935
9780	11025	1657
9780	11025	3171
9780	11025	8860
10180	11026	2846
10180	11026	4470
10180	11026	4142
10180	11026	3897
10180	11026	8507
10180	11026	9310
10180	11026	8485
10180	11026	259
10180	11026	6164
12197	11027	1176
12197	11027	4475
12197	11027	7189
12197	11027	5126
12197	11027	4336
17611	11028	2422
17611	11028	3396
5410	11029	2147
5410	11029	8124
5410	11029	6293
9523	11030	6401
9523	11030	5620
9523	11030	4491
9523	11030	8369
9523	11030	8716
9523	11030	7633
108	11031	983
108	11031	4252
12797	11032	4709
12797	11032	9041
12797	11032	5111
12797	11032	4702
12797	11032	4242
12797	11032	5100
12797	11032	1065
12797	11032	7560
10383	11033	5246
10383	11033	9356
10383	11033	4978
10383	11033	3618
10383	11033	6
10383	11033	3105
10383	11033	8024
10383	11033	3832
17065	11034	8853
19836	11035	9698
19836	11035	2274
19836	11035	677
19836	11035	1107
19836	11035	3747
19836	11035	3640
19836	11035	1064
8337	11036	6314
8337	11036	6196
8337	11036	723
19152	11037	9494
19152	11037	259
19152	11037	6663
14679	11038	7373
14679	11038	26
14679	11038	1163
14679	11038	4657
6032	11039	5207
6032	11039	4433
16171	11040	1262
16171	11040	675
16171	11040	4189
16171	11040	4053
16171	11040	4677
16171	11040	967
16171	11040	7902
18129	11041	5266
18129	11041	733
18129	11041	8908
18129	11041	9986
18129	11041	1869
18129	11041	1426
18129	11041	3163
7674	11042	1174
7674	11042	3585
7674	11042	2363
7674	11042	7899
7674	11042	5544
7674	11042	9329
9187	11043	9122
9187	11043	5347
9187	11043	7211
9187	11043	5390
9187	11043	4589
9187	11043	1324
9187	11043	2389
9187	11043	3520
9187	11043	3790
12304	11044	6417
12304	11044	8268
12304	11044	4824
12304	11044	338
12304	11044	6350
12304	11044	3657
12304	11044	8566
7910	11045	2507
7910	11045	460
7910	11045	6357
7910	11045	8457
15736	11046	5178
15736	11046	9940
15736	11046	8459
17594	11047	8256
17594	11047	8433
17594	11047	9074
17594	11047	777
17594	11047	844
17594	11047	9404
17594	11047	8178
13268	11048	4502
13268	11048	9106
13268	11048	4920
13268	11048	3124
13268	11048	3809
13268	11048	2175
862	11049	7253
862	11049	6024
862	11049	4215
862	11049	1312
862	11049	8171
862	11049	9379
862	11049	6123
862	11049	9819
17849	11050	7970
17849	11050	5788
17849	11050	6936
14365	11051	5862
14365	11051	2337
14365	11051	3674
14365	11051	8754
14365	11051	169
14365	11051	4475
14365	11051	378
392	11052	9120
392	11052	4730
392	11052	4950
3772	11053	9068
3772	11053	5701
3772	11053	2517
3772	11053	6816
3772	11053	4588
3772	11053	1176
3772	11053	2494
3772	11053	4302
3772	11053	6248
14937	11054	8993
14937	11054	9275
16282	11055	7143
16282	11055	2052
16282	11055	9826
16282	11055	879
16282	11055	759
3868	11056	7584
3868	11056	7575
3868	11056	3656
3868	11056	1300
3868	11056	2828
4205	11057	244
4205	11057	3174
4205	11057	4958
4205	11057	228
4205	11057	9793
4205	11057	1425
4205	11057	6573
4205	11057	2485
136	11058	3899
136	11058	6555
136	11058	82
136	11058	5491
136	11058	1485
136	11058	9368
5081	11059	7765
5081	11059	9527
5081	11059	447
5081	11059	8108
5081	11059	4586
5849	11060	8838
5849	11060	101
5849	11060	9757
5849	11060	4775
5849	11060	1556
1846	11061	3464
1846	11061	9501
1846	11061	6441
1846	11061	8785
1846	11061	9978
9126	11062	7488
9126	11062	2848
9126	11062	2701
9126	11062	1718
9126	11062	3131
9126	11062	7703
9126	11062	2752
1477	11063	7839
1477	11063	300
1477	11063	5959
1477	11063	1165
1477	11063	5977
1477	11063	499
1477	11063	2789
1477	11063	1602
1477	11063	4311
12057	11064	2521
12057	11064	6401
4019	11065	1082
4019	11065	1497
4019	11065	8127
4019	11065	466
4019	11065	3391
7778	11066	1875
7778	11066	2787
7778	11066	5806
7778	11066	2214
7778	11066	3086
7778	11066	7025
7778	11066	6
12032	11067	9865
12032	11067	3959
12032	11067	7676
2131	11068	4955
2131	11068	8795
3162	11069	2952
3162	11069	642
3162	11069	9961
3162	11069	5524
3162	11069	1826
3162	11069	5982
3162	11069	9597
3162	11069	772
16893	11070	9512
16893	11070	2762
3113	11071	3137
3113	11071	9964
1209	11072	8271
1209	11072	9462
1209	11072	4671
1209	11072	647
1209	11072	1290
1209	11072	7822
1209	11072	9864
1209	11072	6245
1209	11072	4647
8522	11073	6147
8522	11073	9444
8522	11073	9788
8522	11073	6714
8522	11073	8475
15874	11074	3381
15874	11074	8502
15874	11074	7144
15874	11074	9796
12080	11075	5047
12080	11075	1032
12080	11075	5360
12080	11075	9308
12080	11075	3288
12080	11075	3782
12080	11075	1010
1149	11076	4809
6621	11077	9634
6621	11077	9944
6621	11077	4079
18249	11078	4733
18249	11078	6740
18249	11078	6713
18249	11078	3135
18249	11078	29
18249	11078	2750
18249	11078	4718
18249	11078	5081
18249	11078	6516
9516	11079	2796
9516	11079	4230
9516	11079	81
13262	11080	8541
10505	11081	5747
10505	11081	2049
10505	11081	4132
10505	11081	1439
10505	11081	6294
10505	11081	86
10505	11081	2711
10505	11081	1602
11661	11082	8590
11661	11082	4359
11661	11082	9110
11661	11082	9971
11661	11082	8151
11661	11082	1785
11661	11082	8176
4614	11083	1519
4614	11083	1784
4614	11083	6024
4614	11083	5499
6293	11084	875
6293	11084	761
6293	11084	2955
5850	11085	1984
5850	11085	180
5850	11085	9367
5850	11085	2466
5850	11085	6403
5850	11085	6861
5768	11086	509
7929	11087	6009
7929	11087	341
7929	11087	5694
7929	11087	1889
7929	11087	4755
9868	11088	7506
9868	11088	4310
9868	11088	481
9868	11088	2096
9555	11089	7460
9555	11089	8527
9555	11089	6498
9555	11089	8349
9555	11089	3499
10775	11090	9259
6579	11091	9785
6579	11091	6413
6579	11091	8284
4676	11092	6901
4676	11092	4881
4676	11092	3269
4676	11092	9963
6924	11093	8849
6924	11093	3593
6924	11093	7605
6924	11093	1397
2364	11094	1447
2364	11094	6017
2364	11094	8144
2364	11094	1271
2364	11094	48
2364	11094	471
2364	11094	7529
11491	11095	9273
5731	11096	1457
5731	11096	7748
5731	11096	3430
5731	11096	60
5731	11096	1076
5731	11096	2658
5731	11096	5379
10853	11097	8743
10853	11097	5167
10853	11097	3354
10853	11097	4269
10853	11097	1806
5314	11098	4906
5314	11098	9500
5314	11098	4362
5314	11098	3212
5314	11098	5637
5314	11098	4656
5314	11098	9798
19754	11099	7486
19754	11099	8859
19754	11099	7879
19754	11099	3466
19754	11099	7131
16949	11100	7566
16949	11100	5581
16949	11100	4964
16949	11100	7364
16949	11100	4662
16949	11100	1615
16949	11100	938
9176	11101	3405
9176	11101	2661
12251	11102	5083
12251	11102	830
12251	11102	553
12268	11103	4927
12268	11103	1956
7140	11104	1625
9727	11105	6961
9727	11105	9919
9727	11105	8990
9727	11105	4541
9727	11105	4193
9727	11105	5059
9727	11105	3765
9727	11105	880
11611	11106	5394
11611	11106	8331
11611	11106	2121
11611	11106	7823
11611	11106	4819
3560	11107	3966
3560	11107	6789
3560	11107	3952
3560	11107	3876
3560	11107	5727
3560	11107	461
6533	11108	8027
6533	11108	4978
6533	11108	7245
6533	11108	6313
2264	11109	2912
13754	11110	5383
13754	11110	4107
13754	11110	6825
14571	11111	552
14571	11111	2128
14571	11111	6655
14571	11111	4936
14571	11111	4203
14571	11111	8966
14571	11111	2381
14571	11111	9085
10843	11112	8548
10843	11112	7722
10843	11112	6811
10843	11112	2488
10843	11112	1833
10843	11112	2338
10843	11112	7778
10843	11112	963
10843	11112	1570
11545	11113	4424
11545	11113	9357
11545	11113	4820
11545	11113	8930
11545	11113	5307
11545	11113	4541
11545	11113	131
5237	11114	1546
5237	11114	1791
5237	11114	1863
5237	11114	3756
5237	11114	8652
5237	11114	9204
5237	11114	9385
5237	11114	5326
5237	11114	7135
12128	11115	3541
12128	11115	2477
12128	11115	3026
12128	11115	6289
12128	11115	9458
12128	11115	5485
12128	11115	7158
12128	11115	4002
12128	11115	778
19963	11116	3609
19963	11116	1126
19963	11116	3921
2110	11117	2729
11509	11118	3841
18650	11119	6671
18650	11119	6210
18650	11119	4602
18650	11119	7431
18650	11119	1594
5439	11120	7986
5402	11121	9892
5402	11121	287
5402	11121	3258
5402	11121	3835
5402	11121	3452
245	11122	7571
245	11122	2114
245	11122	1386
16427	11123	8963
16427	11123	6409
16427	11123	7114
16427	11123	5298
16427	11123	8294
16427	11123	4140
16427	11123	9711
16427	11123	2949
19287	11124	2548
19287	11124	1823
19287	11124	5856
19287	11124	8370
9592	11125	9209
12644	11126	3328
12644	11126	2031
12644	11126	1311
12644	11126	5442
12644	11126	4903
12644	11126	3902
12899	11127	1111
18960	11128	4276
18960	11128	5523
18960	11128	2630
18960	11128	9807
18960	11128	3119
10300	11129	6892
10300	11129	9424
10300	11129	1240
10300	11129	9981
10300	11129	9775
1772	11130	366
1772	11130	9290
1772	11130	7214
1772	11130	8126
15864	11131	1066
15864	11131	9752
15864	11131	2959
15864	11131	7708
15864	11131	8438
16836	11132	7440
16836	11132	6368
16836	11132	3458
16836	11132	2064
16836	11132	1375
19001	11133	7432
19001	11133	3644
19001	11133	854
19001	11133	164
19001	11133	39
19001	11133	6195
19001	11133	6819
19001	11133	6894
19001	11133	7385
7504	11134	486
7504	11134	1201
7504	11134	7031
7504	11134	1361
7504	11134	7800
7504	11134	9213
7504	11134	7289
7504	11134	4838
9752	11135	3352
492	11136	4579
492	11136	3111
492	11136	1284
492	11136	8021
492	11136	5456
492	11136	1243
492	11136	1204
492	11136	5608
492	11136	484
10643	11137	198
10643	11137	4433
10643	11137	7813
10643	11137	3795
16746	11138	8640
16746	11138	2472
16746	11138	2242
16746	11138	1712
16746	11138	4743
16746	11138	2526
16746	11138	3331
16746	11138	3247
7191	11139	9267
7191	11139	2076
7191	11139	9011
7191	11139	2725
7191	11139	4243
7191	11139	3653
7191	11139	958
7191	11139	9544
2509	11140	4170
2509	11140	9146
2509	11140	2217
2509	11140	1311
2509	11140	5988
2509	11140	9074
2509	11140	2087
2509	11140	2334
10118	11141	6258
10118	11141	4146
7378	11142	4943
7378	11142	8497
7378	11142	6305
7378	11142	6612
7378	11142	34
7378	11142	9068
7378	11142	7405
7378	11142	1275
7378	11142	9291
12620	11143	7573
12620	11143	5986
12620	11143	2140
12620	11143	5407
12620	11143	1338
12620	11143	9651
11909	11144	4476
11909	11144	3995
11909	11144	3528
11909	11144	1684
11909	11144	889
11909	11144	8411
14155	11145	2003
14155	11145	6574
14155	11145	5558
14155	11145	6696
14155	11145	2329
3580	11146	7862
3580	11146	1711
3580	11146	319
3580	11146	3255
8287	11147	5619
8287	11147	5529
8287	11147	5115
8287	11147	7477
8287	11147	1674
8287	11147	3667
8287	11147	9931
8287	11147	4716
14031	11148	3791
14031	11148	7503
14031	11148	7812
14031	11148	6111
14031	11148	4900
14031	11148	6305
3667	11149	9365
3667	11149	6146
3667	11149	4586
3667	11149	9407
3667	11149	5808
7184	11150	9238
7184	11150	4610
4842	11151	274
4842	11151	4235
4842	11151	2916
4842	11151	8412
4842	11151	8038
8366	11152	3996
8366	11152	7640
8366	11152	2342
6958	11153	8408
6958	11153	9372
6958	11153	7880
16307	11154	4732
16307	11154	405
16307	11154	9169
16307	11154	918
16307	11154	2625
16307	11154	832
16307	11154	7952
586	11155	3772
586	11155	2449
586	11155	3593
586	11155	9623
586	11155	8689
586	11155	9625
586	11155	9042
586	11155	135
586	11155	7499
16833	11156	8148
12198	11157	6392
12198	11157	3373
12198	11157	1734
12198	11157	2342
3929	11158	4180
3929	11158	4284
3929	11158	779
3929	11158	2669
3929	11158	3721
3929	11158	6693
9681	11159	939
9681	11159	1759
9681	11159	8489
9681	11159	7494
9681	11159	952
9681	11159	5548
9681	11159	1799
9681	11159	4921
18409	11160	3622
18409	11160	7822
18409	11160	2425
18409	11160	8075
18409	11160	9355
18409	11160	1698
18409	11160	1539
18409	11160	7624
18409	11160	8587
19076	11161	8130
19076	11161	8141
19076	11161	2729
19076	11161	2255
19076	11161	6453
19076	11161	3797
12442	11162	9716
12442	11162	7943
18962	11163	9509
18962	11163	1178
18962	11163	2994
18962	11163	5553
18962	11163	2880
18962	11163	4174
12856	11164	2304
12856	11164	1328
12856	11164	7554
12856	11164	6816
12856	11164	8261
12856	11164	8682
12856	11164	4239
7493	11165	3504
7493	11165	65
7493	11165	1124
7493	11165	2749
6700	11166	404
6700	11166	7422
6700	11166	9552
6700	11166	1848
6700	11166	2245
6700	11166	1124
10725	11167	9109
10725	11167	3499
10725	11167	1485
10725	11167	1668
10725	11167	6508
10725	11167	7906
10725	11167	7767
10725	11167	1149
10725	11167	3660
6421	11168	9577
6421	11168	1856
17322	11169	8224
17322	11169	2676
8321	11170	6768
8321	11170	3867
8321	11170	6854
8321	11170	4304
8321	11170	9802
8321	11170	6572
8321	11170	1173
8321	11170	1451
8321	11170	5905
5240	11171	3812
5240	11171	2683
5240	11171	1913
5240	11171	648
5240	11171	9916
5240	11171	8993
5240	11171	2089
12785	11172	4355
12785	11172	4918
12785	11172	535
12785	11172	6277
12785	11172	9675
3282	11173	1831
3282	11173	9359
3282	11173	8386
16602	11174	2083
16602	11174	5782
16602	11174	5903
16602	11174	2712
16602	11174	49
16602	11174	5784
16602	11174	3998
16602	11174	7022
16602	11174	9786
10047	11175	2944
10047	11175	887
10047	11175	8315
10047	11175	9630
10047	11175	1765
10047	11175	5246
10047	11175	9209
3841	11176	9550
3841	11176	7806
3841	11176	9249
3841	11176	7220
3841	11176	908
3841	11176	4058
3841	11176	9676
1125	11177	2392
1125	11177	2216
1125	11177	9674
1125	11177	1702
1125	11177	8610
1125	11177	802
704	11178	3900
704	11178	8733
704	11178	5487
704	11178	3651
6652	11179	3888
6652	11179	4143
6652	11179	2838
6652	11179	436
6652	11179	3820
6652	11179	1392
6652	11179	1014
14226	11180	1019
14226	11180	6099
14226	11180	7564
14226	11180	9391
14226	11180	1129
14226	11180	4540
14226	11180	6550
14226	11180	2551
14226	11180	4708
10285	11181	7279
16584	11182	5405
16584	11182	5392
16584	11182	473
16584	11182	6174
16584	11182	3076
16584	11182	9250
7580	11183	2218
13850	11184	2067
13850	11184	9616
13850	11184	7006
13850	11184	7638
13850	11184	8661
13850	11184	2517
13850	11184	9466
13850	11184	5543
17236	11185	2822
9402	11186	9130
9402	11186	3207
9402	11186	7093
9402	11186	6663
9402	11186	4619
9402	11186	9624
16568	11187	2336
16568	11187	7661
16568	11187	403
16568	11187	6497
16568	11187	8960
6048	11188	9306
6048	11188	2260
6048	11188	2097
6048	11188	7786
4810	11189	4661
4810	11189	3967
4810	11189	9255
4810	11189	4724
4810	11189	4181
4810	11189	5601
9120	11190	7584
9120	11190	7900
9120	11190	7163
9120	11190	9402
14376	11191	9593
14376	11191	1254
14376	11191	5027
14376	11191	4213
14376	11191	1522
14376	11191	1196
13592	11192	1356
17880	11193	5830
17880	11193	2839
17880	11193	6812
9659	11194	5274
9659	11194	6265
955	11195	9414
955	11195	1618
955	11195	2573
955	11195	4267
955	11195	4373
955	11195	2868
17395	11196	3929
17395	11196	6912
17395	11196	3956
17395	11196	8358
17395	11196	4006
16797	11197	4314
16797	11197	9887
16797	11197	7989
16797	11197	3929
16603	11198	3064
16603	11198	7953
16603	11198	7586
16603	11198	4505
16603	11198	8228
16603	11198	9331
16603	11198	7690
16603	11198	1209
16603	11198	1734
12094	11199	1978
12094	11199	3676
127	11200	9320
127	11200	5388
127	11200	2650
14309	11201	5615
14309	11201	3967
14309	11201	137
14309	11201	524
14309	11201	1484
14309	11201	7918
14309	11201	3069
13489	11202	6808
13489	11202	4544
19861	11203	2904
19861	11203	7083
19861	11203	9933
19861	11203	7177
19861	11203	6002
19861	11203	9075
19861	11203	9184
19861	11203	8379
19861	11203	2864
7958	11204	6158
7958	11204	2806
7958	11204	1126
9050	11205	7077
9050	11205	3911
9050	11205	9791
9050	11205	910
19969	11206	543
19969	11206	4686
19969	11206	2145
19969	11206	7386
19969	11206	4480
19969	11206	5336
19969	11206	4245
9751	11207	8411
9751	11207	4475
9751	11207	5072
9751	11207	3409
9751	11207	58
9751	11207	5965
9751	11207	9394
8159	11208	5762
8159	11208	5554
8159	11208	842
8159	11208	7525
8159	11208	7350
16669	11209	6397
16669	11209	694
16669	11209	1014
16669	11209	7449
16669	11209	5911
16669	11209	3448
16669	11209	9921
16669	11209	9384
10291	11210	5386
10291	11210	8180
10291	11210	3061
10291	11210	7804
10291	11210	3863
10291	11210	1395
10291	11210	6826
15678	11211	8910
15678	11211	2589
15678	11211	7405
15678	11211	8878
15678	11211	2343
15678	11211	1934
15678	11211	7907
15678	11211	7451
15678	11211	230
16068	11212	8112
16068	11212	5737
16068	11212	7015
16068	11212	2776
16068	11212	6640
18456	11213	1737
18456	11213	9498
18456	11213	3535
2883	11214	7527
18283	11215	4619
18283	11215	9978
18283	11215	62
18283	11215	7819
18283	11215	196
11000	11216	8210
11000	11216	1484
11000	11216	9502
11000	11216	9139
11000	11216	6460
11000	11216	4063
11000	11216	6870
11000	11216	3128
15491	11217	8101
11838	11218	377
11838	11218	3294
11838	11218	4995
11838	11218	9484
11838	11218	9210
11838	11218	1496
11838	11218	2042
11838	11218	6238
6214	11219	6991
6214	11219	2814
6214	11219	2919
6214	11219	5071
6214	11219	6832
14417	11220	1271
14417	11220	3108
4634	11221	666
4634	11221	4332
4634	11221	7884
4634	11221	10
4634	11221	1341
4634	11221	1878
9591	11222	5312
9591	11222	5050
9591	11222	9107
9591	11222	5227
9591	11222	6863
9591	11222	1132
9591	11222	650
9591	11222	8121
4905	11223	8725
130	11224	4219
130	11224	6772
4166	11225	5705
4166	11225	9804
13332	11226	8410
13332	11226	2668
10635	11227	5851
10635	11227	7673
10635	11227	7772
10635	11227	7925
10635	11227	1125
10635	11227	1275
10635	11227	6779
10635	11227	8766
10635	11227	2747
6826	11228	5211
6826	11228	2592
6826	11228	174
18311	11229	6863
18311	11229	4996
18311	11229	3839
18311	11229	6624
18311	11229	7617
18311	11229	2384
18311	11229	355
18311	11229	6879
18311	11229	9718
9904	11230	8596
9904	11230	9604
5598	11231	1846
5598	11231	3590
5598	11231	9420
12088	11232	3942
12088	11232	1772
12088	11232	5922
12088	11232	7398
12088	11232	8944
12088	11232	591
12088	11232	5636
10478	11233	8038
10478	11233	9513
10478	11233	665
10478	11233	6724
10478	11233	531
10478	11233	6129
10478	11233	3861
11265	11234	4284
11265	11234	9256
11265	11234	5674
11265	11234	5142
5241	11235	9483
5241	11235	2866
5241	11235	4469
5241	11235	2098
5241	11235	3616
5241	11235	7676
5241	11235	5549
6486	11236	6859
6486	11236	5942
6486	11236	4679
6486	11236	5960
9984	11237	1979
9984	11237	4060
9984	11237	919
9984	11237	8376
9984	11237	9721
9984	11237	5645
9984	11237	1735
9984	11237	8933
9984	11237	4436
2589	11238	7409
2589	11238	3285
12419	11239	5683
12419	11239	6418
12419	11239	5183
12419	11239	8270
12419	11239	353
11993	11240	7190
11993	11240	8832
11993	11240	421
11993	11240	2920
11993	11240	6228
11993	11240	207
11993	11240	3696
4110	11241	2394
4110	11241	1145
18828	11242	7404
5580	11243	7109
5580	11243	5669
5580	11243	7355
5580	11243	5504
11419	11244	7969
11419	11244	4665
11419	11244	217
2723	11245	775
2723	11245	9258
2723	11245	2450
2723	11245	969
2723	11245	157
2723	11245	9212
2723	11245	5607
2723	11245	4413
6654	11246	5937
6654	11246	2055
6654	11246	9510
14804	11247	5802
14804	11247	8062
14804	11247	2587
7110	11248	1633
7110	11248	7152
3128	11249	4891
3128	11249	6091
3128	11249	9955
18929	11250	6867
18929	11250	1382
18929	11250	8457
18929	11250	7726
18929	11250	9955
18929	11250	4598
18929	11250	224
18929	11250	3017
18929	11250	3469
3633	11251	6984
3633	11251	4657
3633	11251	2806
3633	11251	6403
6537	11252	5936
6537	11252	6000
6537	11252	6771
6537	11252	2558
6537	11252	2834
6537	11252	7598
2132	11253	2883
2132	11253	2927
2132	11253	4799
2132	11253	6804
2132	11253	3670
2132	11253	827
2132	11253	6474
2132	11253	5400
2132	11253	3827
1195	11254	1966
1195	11254	1411
1195	11254	6035
1195	11254	630
1195	11254	665
1195	11254	7742
1195	11254	3377
1195	11254	1175
9687	11255	3687
18172	11256	485
18172	11256	3492
18172	11256	6968
16755	11257	9946
16755	11257	1658
16755	11257	9161
16755	11257	4201
10750	11258	219
10750	11258	3055
4247	11259	5018
4247	11259	6569
4247	11259	1310
4247	11259	3967
4247	11259	1913
4247	11259	3384
4247	11259	4637
4247	11259	2468
13336	11260	2043
13336	11260	8464
13336	11260	5154
13336	11260	6166
13336	11260	3642
13336	11260	9345
11825	11261	9448
11825	11261	3270
11825	11261	124
11825	11261	3218
11370	11262	2353
11370	11262	2515
11370	11262	3945
11370	11262	6656
11370	11262	2498
11370	11262	213
19114	11263	5470
19114	11263	8547
19114	11263	3106
19114	11263	6277
19114	11263	8470
330	11264	6300
330	11264	1442
330	11264	1927
330	11264	9794
330	11264	4484
330	11264	1402
6756	11265	7984
6756	11265	5198
6756	11265	4640
1832	11266	411
1832	11266	6982
1832	11266	6070
1832	11266	3122
1832	11266	2096
1832	11266	2897
1832	11266	3631
10065	11267	8410
10065	11267	5837
10065	11267	6052
1381	11268	1607
1381	11268	8087
10137	11269	8349
10137	11269	3971
10137	11269	5778
10137	11269	2333
10137	11269	4247
10137	11269	4441
5701	11270	9244
5701	11270	5990
5701	11270	9394
5701	11270	3439
5701	11270	6195
13168	11271	3044
14028	11272	3881
14028	11272	6539
14028	11272	4230
14028	11272	4450
14028	11272	3829
14028	11272	8305
14028	11272	5804
10393	11273	6196
10393	11273	205
10393	11273	2399
10393	11273	9837
10393	11273	1741
10393	11273	2456
10393	11273	8320
10393	11273	4846
18150	11274	2424
18150	11274	6012
18150	11274	2739
18150	11274	5022
18150	11274	7012
18150	11274	6658
18150	11274	456
18150	11274	2420
18150	11274	3661
10801	11275	2527
14743	11276	6447
14743	11276	461
12945	11277	8288
12945	11277	2842
12945	11277	9260
12945	11277	8506
12945	11277	6362
44	11278	5422
15897	11279	5320
15897	11279	254
15897	11279	7474
15897	11279	636
15897	11279	7187
15897	11279	4461
15897	11279	4851
15897	11279	773
18557	11280	204
18557	11280	3186
18557	11280	7261
17756	11281	7582
17756	11281	3418
17756	11281	3641
17756	11281	8549
17756	11281	489
17756	11281	4508
17756	11281	1210
17756	11281	2252
18106	11282	2217
18106	11282	3689
18106	11282	4850
18106	11282	4009
18106	11282	9828
18106	11282	3265
18106	11282	2439
12158	11283	355
12158	11283	9529
12158	11283	3011
12158	11283	4221
15378	11284	4983
15378	11284	5443
15378	11284	1933
15378	11284	9622
18899	11285	6859
18899	11285	5100
18899	11285	5021
18899	11285	5898
18899	11285	734
18899	11285	238
18899	11285	6164
18899	11285	9006
6641	11286	9852
6641	11286	5802
6641	11286	8598
6641	11286	7724
6641	11286	4872
6641	11286	2169
6641	11286	3169
16379	11287	3565
16379	11287	5158
16379	11287	4419
16379	11287	8260
16379	11287	205
16379	11287	6745
16379	11287	7537
16379	11287	1373
16379	11287	8379
12204	11288	330
12204	11288	5364
12204	11288	3157
12204	11288	1687
10502	11289	9053
10502	11289	5409
10502	11289	1614
10502	11289	7720
10514	11290	8595
14711	11291	988
14711	11291	9634
14711	11291	3261
14711	11291	5549
8956	11292	8565
8956	11292	7849
8956	11292	6564
8956	11292	9586
8956	11292	7821
8956	11292	9541
8956	11292	8319
8956	11292	6107
8956	11292	5490
12954	11293	2828
12954	11293	4510
794	11294	56
794	11294	2960
794	11294	5391
794	11294	7368
10377	11295	7963
10377	11295	1482
10377	11295	9903
10377	11295	9609
9822	11296	3474
9822	11296	4652
9822	11296	8616
9822	11296	693
9822	11296	8924
9822	11296	6576
7886	11297	9131
7886	11297	329
7886	11297	4092
7886	11297	1162
7886	11297	8781
7886	11297	5984
7886	11297	5681
18310	11298	6139
18310	11298	661
18310	11298	5197
3543	11299	5714
3543	11299	642
3543	11299	5720
3543	11299	1938
6199	11300	3870
6199	11300	3790
4586	11301	5448
4586	11301	3916
4586	11301	1675
4586	11301	5692
4586	11301	884
4586	11301	5818
4586	11301	2778
16994	11302	8308
16994	11302	6479
16994	11302	1771
16994	11302	1901
2763	11303	8772
2763	11303	3445
2763	11303	9408
2763	11303	1800
2763	11303	7278
2763	11303	4689
2763	11303	9280
2763	11303	9555
13968	11304	7193
13968	11304	6384
13968	11304	926
13968	11304	4523
4748	11305	5674
4748	11305	1124
4748	11305	7989
4748	11305	180
4748	11305	5606
4748	11305	8363
4748	11305	2336
4748	11305	5605
19409	11306	283
19409	11306	1056
11157	11307	7953
11157	11307	5339
11157	11307	4325
11157	11307	8706
11157	11307	9386
11157	11307	7580
11157	11307	3755
12180	11308	4389
12180	11308	5184
12180	11308	851
12180	11308	5911
12180	11308	6674
17407	11309	159
17407	11309	9063
17407	11309	1850
17407	11309	6796
17407	11309	6655
818	11310	6499
818	11310	1579
818	11310	2933
818	11310	7846
818	11310	2228
818	11310	5690
6350	11311	8612
6350	11311	2340
6350	11311	2244
6350	11311	5443
6350	11311	5425
6350	11311	3414
6350	11311	2505
18007	11312	9891
18007	11312	6090
18007	11312	4619
18007	11312	1492
18007	11312	7217
18007	11312	3483
18007	11312	5347
18007	11312	2582
18007	11312	9769
10421	11313	7307
10421	11313	8951
10421	11313	1008
10421	11313	8815
10421	11313	6028
10421	11313	9748
10421	11313	6441
15863	11314	6326
15863	11314	2470
15863	11314	252
15863	11314	9358
15863	11314	9877
15863	11314	5230
15863	11314	8535
14969	11315	4184
14969	11315	937
1367	11316	5049
1367	11316	4237
1367	11316	411
1367	11316	7880
1367	11316	2234
1367	11316	7931
15614	11317	1547
15614	11317	5917
15614	11317	8844
15614	11317	4590
11052	11318	6209
11052	11318	5596
11052	11318	8328
11052	11318	981
11052	11318	395
11052	11318	1618
11052	11318	6993
11052	11318	4221
11052	11318	7356
17805	11319	1467
17805	11319	2703
17805	11319	278
17805	11319	1582
15582	11320	9049
15582	11320	6846
15582	11320	6149
15582	11320	8890
15582	11320	9870
15582	11320	7315
15582	11320	1025
19096	11321	3988
19096	11321	6792
19096	11321	1095
19096	11321	8817
19096	11321	585
19096	11321	467
19096	11321	7247
19096	11321	7078
19096	11321	9545
16869	11322	4316
16869	11322	5291
12853	11323	5969
12853	11323	1586
12853	11323	5566
12853	11323	9828
12853	11323	5356
12853	11323	4617
3726	11324	5955
3726	11324	382
3726	11324	3316
3726	11324	8487
3726	11324	9680
3726	11324	2973
3726	11324	204
12343	11325	8931
17516	11326	9170
17516	11326	4646
17516	11326	3165
17516	11326	6406
17516	11326	4865
17516	11326	6404
17516	11326	8161
17516	11326	5813
17570	11327	6646
17570	11327	5041
17570	11327	483
17570	11327	5685
17570	11327	2730
17570	11327	2773
17570	11327	3671
17570	11327	1148
15106	11328	4340
15106	11328	446
15106	11328	7247
11827	11329	4783
19648	11330	3795
13049	11331	8424
13049	11331	5151
13049	11331	3629
13049	11331	7124
13049	11331	4816
13049	11331	1939
13049	11331	3964
8606	11332	5136
8606	11332	8249
8606	11332	9705
8606	11332	6677
8606	11332	4073
8606	11332	24
16893	11333	8018
16893	11333	7075
16893	11333	7202
16893	11333	6605
16893	11333	7150
17336	11334	5229
17336	11334	3304
17336	11334	5672
17336	11334	6795
1736	11335	8064
1736	11335	4978
1736	11335	7883
1736	11335	9674
1736	11335	8136
1736	11335	6847
7992	11336	2664
7992	11336	7762
7992	11336	188
7992	11336	1369
16327	11337	9031
14189	11338	9149
14189	11338	5084
6440	11339	7961
6440	11339	9236
6440	11339	6051
6440	11339	3450
6440	11339	9791
2318	11340	9322
2318	11340	9533
2318	11340	9899
2318	11340	5447
2318	11340	8735
2318	11340	8891
2318	11340	3418
2318	11340	7038
2318	11340	2524
3518	11341	3658
3518	11341	690
3518	11341	5355
3518	11341	4608
3518	11341	4520
3518	11341	2555
3518	11341	2283
15458	11342	2325
15458	11342	3249
15458	11342	4081
15458	11342	4857
15458	11342	5285
15458	11342	8363
15458	11342	2561
15458	11342	5270
15458	11342	5470
155	11343	4007
155	11343	7389
155	11343	483
155	11343	4018
12684	11344	2084
13881	11345	2624
13881	11345	9887
13881	11345	6254
13881	11345	8434
13881	11345	5780
13881	11345	1800
11613	11346	2096
11613	11346	6061
11613	11346	8156
11613	11346	2455
11613	11346	4341
11613	11346	2608
11613	11346	1479
11613	11346	1726
3225	11347	6768
3225	11347	687
3225	11347	4970
3225	11347	3802
3225	11347	8293
3225	11347	3532
3225	11347	2853
3225	11347	6501
3225	11347	3168
15017	11348	2900
15017	11348	5435
15017	11348	9073
15017	11348	6237
15017	11348	7109
15017	11348	6076
15017	11348	5553
18709	11349	2440
18709	11349	8962
18709	11349	9724
18709	11349	6301
18709	11349	4417
18709	11349	400
18709	11349	7608
18709	11349	2880
3903	11350	309
3903	11350	7166
3903	11350	6090
3903	11350	7429
8060	11351	4162
8060	11351	9804
8060	11351	9367
8060	11351	6778
8060	11351	6755
8723	11352	7404
8723	11352	6524
8723	11352	2561
8723	11352	6885
8723	11352	3216
1290	11353	4675
1290	11353	9027
1290	11353	8193
1290	11353	2723
1290	11353	4935
3378	11354	6050
3378	11354	7607
3378	11354	5552
16224	11355	7838
16224	11355	1901
16224	11355	4822
16224	11355	4796
16224	11355	5531
16224	11355	8334
16224	11355	2652
16224	11355	1283
16224	11355	555
14461	11356	4382
14461	11356	8778
14461	11356	7397
14461	11356	8045
14461	11356	9748
3295	11357	2891
3295	11357	6853
3295	11357	4782
3295	11357	2145
3295	11357	6241
3295	11357	5020
3295	11357	6052
3424	11358	4979
3424	11358	8340
3424	11358	9217
3424	11358	732
3424	11358	2268
3424	11358	612
3424	11358	623
3424	11358	9391
8343	11359	1605
8343	11359	7495
8343	11359	5697
8343	11359	918
1072	11360	8932
16298	11361	7113
16298	11361	6609
16298	11361	3552
16298	11361	1226
6299	11362	7218
6299	11362	6268
6299	11362	5341
6299	11362	8259
6299	11362	1686
6299	11362	6794
6299	11362	3754
12730	11363	9708
12730	11363	4256
12730	11363	8710
12730	11363	3547
12730	11363	750
12730	11363	3085
12730	11363	5618
12730	11363	6580
12730	11363	5015
6546	11364	6791
6546	11364	5348
6546	11364	696
6546	11364	6909
6546	11364	765
10041	11365	2828
10041	11365	4201
10041	11365	4729
10041	11365	1439
16035	11366	9937
16035	11366	5875
16035	11366	1613
13921	11367	8590
13921	11367	8348
13921	11367	6733
13921	11367	4375
14403	11368	778
14403	11368	9653
14403	11368	1218
6896	11369	9528
2280	11370	8101
2280	11370	5147
6989	11371	7397
6989	11371	8104
6989	11371	7620
6989	11371	7932
6989	11371	5117
6989	11371	615
6989	11371	4825
6989	11371	9782
18617	11372	449
18617	11372	670
18617	11372	352
18617	11372	5239
18617	11372	9311
18617	11372	496
18617	11372	1702
18617	11372	2271
18617	11372	2845
15922	11373	4294
15922	11373	9181
15922	11373	7276
15922	11373	3384
15922	11373	9501
15922	11373	6420
15922	11373	2381
15922	11373	5988
10597	11374	2006
10597	11374	7924
10597	11374	9926
10597	11374	4478
10597	11374	8729
10597	11374	5978
10597	11374	4873
10597	11374	7098
10597	11374	5357
9716	11375	5029
9716	11375	2997
9716	11375	4315
9716	11375	6314
9716	11375	1150
9716	11375	3822
7494	11376	1391
7494	11376	9335
7494	11376	1592
7494	11376	2527
7494	11376	6356
7494	11376	9172
7494	11376	2741
15538	11377	8785
15538	11377	7208
15538	11377	7711
15538	11377	3418
15538	11377	7431
14544	11378	5842
14544	11378	4038
14544	11378	6627
14544	11378	6123
14544	11378	4447
14544	11378	9143
14544	11378	8779
17916	11379	3452
17916	11379	8839
17916	11379	2477
17916	11379	2694
15945	11380	4642
15945	11380	3772
797	11381	3381
797	11381	1869
797	11381	6877
797	11381	4053
797	11381	9605
797	11381	5573
8824	11382	6669
8824	11382	7466
8824	11382	4885
8824	11382	6290
8824	11382	7664
8824	11382	8206
8824	11382	460
7681	11383	6364
7681	11383	7206
7681	11383	1848
7681	11383	1380
7681	11383	9867
7681	11383	1833
17002	11384	3438
17002	11384	6131
7588	11385	1910
7588	11385	7060
7588	11385	4089
7588	11385	3158
727	11386	7174
727	11386	9482
2628	11387	9815
2628	11387	4218
2628	11387	8002
6816	11388	7019
6816	11388	3016
6816	11388	2651
11618	11389	6172
11618	11389	6550
11618	11389	669
11618	11389	387
11618	11389	7345
14318	11390	411
14318	11390	6675
14318	11390	5042
14318	11390	6157
14318	11390	6869
14318	11390	6140
831	11391	4905
831	11391	2252
831	11391	4846
831	11391	7485
9658	11392	1988
9658	11392	733
9658	11392	2010
9658	11392	5788
3888	11393	1116
3888	11393	4613
3888	11393	5667
3888	11393	1221
3888	11393	1441
12574	11394	1519
12574	11394	4338
12574	11394	3097
12574	11394	8637
12574	11394	8724
12574	11394	1237
12574	11394	7697
12574	11394	6455
12574	11394	4553
18331	11395	9106
18331	11395	8297
18331	11395	9654
18331	11395	6834
18331	11395	9831
18331	11395	4736
18331	11395	6614
10501	11396	5897
10501	11396	3727
10501	11396	2359
10501	11396	402
10501	11396	7751
10501	11396	6078
10501	11396	188
10501	11396	8893
10501	11396	5730
5125	11397	915
5125	11397	2804
5125	11397	7161
5125	11397	2779
5125	11397	2513
5125	11397	1722
5125	11397	2268
5125	11397	6420
8341	11398	6882
8341	11398	2252
8341	11398	3802
8341	11398	4321
8341	11398	544
8341	11398	1243
8341	11398	8239
10799	11399	4222
10799	11399	438
5411	11400	5375
5411	11400	6683
5411	11400	8083
669	11401	8316
669	11401	2230
669	11401	2570
669	11401	316
669	11401	7518
669	11401	6208
669	11401	1065
669	11401	4714
669	11401	6373
12790	11402	7409
12790	11402	86
12790	11402	3566
12790	11402	5827
12790	11402	5531
12790	11402	6562
12790	11402	3000
12790	11402	1233
12790	11402	9940
12295	11403	6577
12295	11403	5183
12295	11403	9130
12295	11403	9344
13505	11404	2245
13505	11404	4965
13505	11404	8919
13505	11404	2212
13505	11404	8257
13505	11404	4612
13505	11404	8527
13505	11404	8240
13505	11404	699
14550	11405	224
19135	11406	6320
19135	11406	7424
19135	11406	216
19135	11406	6635
19135	11406	2884
19135	11406	4615
19135	11406	4057
19135	11406	629
17736	11407	717
17736	11407	1750
17736	11407	8553
17736	11407	191
17736	11407	1541
15720	11408	6424
15720	11408	6126
15720	11408	5492
15720	11408	1905
11923	11409	8545
4539	11410	817
18739	11411	7317
18739	11411	3384
19051	11412	5883
19051	11412	185
19051	11412	2502
19051	11412	1479
19051	11412	8050
19051	11412	3428
19051	11412	3916
2993	11413	826
2993	11413	9049
2993	11413	6129
2993	11413	4971
2993	11413	9996
2993	11413	9038
2993	11413	2799
2993	11413	857
2993	11413	6294
15545	11414	8582
15545	11414	9716
15545	11414	2510
11891	11415	632
11891	11415	6947
11891	11415	3673
11891	11415	6272
11891	11415	7590
777	11416	3372
777	11416	5247
2512	11417	693
2512	11417	5374
2512	11417	9860
16235	11418	5425
16235	11418	6539
16235	11418	3051
16235	11418	2767
16235	11418	8120
16235	11418	1028
16235	11418	5688
16235	11418	4871
16235	11418	2843
8816	11419	5689
8816	11419	6085
8816	11419	6781
1935	11420	2101
1935	11420	8188
1935	11420	4361
1935	11420	5790
1935	11420	4753
1935	11420	830
1935	11420	1218
1935	11420	1374
1935	11420	4865
13810	11421	4319
13810	11421	9705
13810	11421	7763
13810	11421	2067
8334	11422	9317
10214	11423	1925
10214	11423	6792
10214	11423	7694
10214	11423	7203
10214	11423	1729
10214	11423	9463
7562	11424	4881
7562	11424	2902
7562	11424	1241
7562	11424	1114
7562	11424	6007
7562	11424	4249
7562	11424	5537
7562	11424	3959
7562	11424	7408
10202	11425	7659
10202	11425	3478
10202	11425	8820
10202	11425	902
10202	11425	2838
10202	11425	7992
10202	11425	2728
10202	11425	1099
14211	11426	4712
14211	11426	4457
14211	11426	7270
14211	11426	9422
14211	11426	6966
14211	11426	5680
14211	11426	8982
14211	11426	1745
14211	11426	2463
10599	11427	1038
10599	11427	4548
10599	11427	4996
10599	11427	9242
10599	11427	8387
5687	11428	4708
5687	11428	4219
5687	11428	382
5687	11428	6298
5687	11428	9056
5687	11428	7165
8979	11429	9806
8979	11429	270
8979	11429	9991
8979	11429	3696
8979	11429	4532
8979	11429	3186
8979	11429	4926
8979	11429	9952
8979	11429	7855
16473	11430	7600
16473	11430	5646
16473	11430	4640
16473	11430	9254
16473	11430	5448
16473	11430	9312
16473	11430	3412
14214	11431	9189
14214	11431	9122
14214	11431	7530
14214	11431	3747
14214	11431	3242
14618	11432	432
14618	11432	5984
10475	11433	4297
15416	11434	4815
15416	11434	2298
15416	11434	5396
15416	11434	8117
15416	11434	492
15416	11434	8309
15416	11434	6917
19146	11435	7876
19146	11435	6544
6144	11436	8911
6144	11436	6373
6144	11436	5178
6144	11436	7727
6144	11436	5191
6144	11436	8894
6144	11436	6047
6144	11436	5170
4173	11437	1660
4173	11437	5633
4173	11437	8562
4173	11437	2045
9278	11438	3034
9278	11438	8211
9278	11438	9157
9278	11438	5687
9161	11439	3966
9161	11439	9462
9161	11439	4910
9161	11439	1243
9161	11439	5174
7471	11440	6666
7471	11440	2787
7471	11440	8460
7471	11440	6231
7471	11440	4031
7471	11440	2609
7471	11440	9733
7471	11440	4297
16525	11441	5346
16525	11441	1980
16525	11441	1687
16525	11441	3464
16525	11441	889
16525	11441	5937
17447	11442	4543
17447	11442	1947
17447	11442	7433
17447	11442	8291
17447	11442	6223
5996	11443	9234
5996	11443	9878
5996	11443	2784
5996	11443	8368
5996	11443	9353
10580	11444	4013
10580	11444	855
10580	11444	4673
10580	11444	7130
10580	11444	7356
10580	11444	9271
7644	11445	8582
7644	11445	5053
7644	11445	7024
7644	11445	24
7644	11445	4084
7644	11445	4647
7644	11445	4667
7644	11445	8426
18562	11446	2082
18562	11446	861
18562	11446	9784
18562	11446	3015
18562	11446	3954
18562	11446	6649
18562	11446	5401
18562	11446	995
2038	11447	396
2038	11447	6468
2038	11447	3918
2038	11447	3742
1953	11448	5341
1953	11448	5692
1953	11448	7748
1953	11448	2916
1953	11448	8297
1953	11448	4236
10461	11449	6250
13291	11450	1708
10899	11451	6426
10899	11451	6212
10899	11451	2685
10899	11451	6890
10899	11451	609
10899	11451	2133
10899	11451	9369
10899	11451	2603
10899	11451	1599
15695	11452	4493
15695	11452	6749
15695	11452	9368
15695	11452	1650
15695	11452	2488
15695	11452	2751
10871	11453	5868
10871	11453	6533
10871	11453	115
10871	11453	4368
10871	11453	6535
10871	11453	1440
10871	11453	3813
16610	11454	4506
12309	11455	4229
12309	11455	4294
12309	11455	8387
12309	11455	797
12309	11455	6104
12309	11455	2254
13241	11456	2586
13241	11456	7736
13241	11456	4474
13241	11456	4704
13241	11456	2140
13241	11456	147
13241	11456	5363
13241	11456	842
13241	11456	3299
3372	11457	5940
3372	11457	1785
3372	11457	2351
3372	11457	4813
3372	11457	4781
5032	11458	4079
5032	11458	3762
5032	11458	7708
5032	11458	1466
5032	11458	4255
5032	11458	2661
12640	11459	776
12640	11459	3602
12640	11459	3371
12640	11459	7576
12640	11459	7240
12640	11459	5583
12640	11459	4873
17903	11460	5170
17903	11460	2705
17903	11460	8657
17903	11460	8941
17903	11460	4514
17903	11460	7637
17903	11460	3852
17903	11460	8931
4604	11461	486
4604	11461	904
4604	11461	9547
4604	11461	5447
4604	11461	4727
4604	11461	3380
4604	11461	8912
4604	11461	6531
10943	11462	1854
10943	11462	1309
10943	11462	4932
10943	11462	3158
10943	11462	2542
10943	11462	4451
10943	11462	7210
13513	11463	1339
13513	11463	7867
13513	11463	5752
13513	11463	803
13513	11463	4345
6457	11464	9749
6457	11464	5312
6457	11464	2952
6457	11464	585
6457	11464	5034
6457	11464	8520
6457	11464	389
6457	11464	9000
6457	11464	2155
42	11465	6799
42	11465	5408
42	11465	9707
2218	11466	3821
2218	11466	8801
2218	11466	6549
2218	11466	2265
1568	11467	8398
1568	11467	6325
1568	11467	3165
1568	11467	574
1568	11467	6823
4460	11468	5391
4460	11468	4897
4460	11468	7005
4460	11468	6239
5575	11469	4370
5575	11469	8538
5575	11469	4414
5575	11469	1023
5575	11469	7488
5575	11469	4435
5575	11469	2410
12982	11470	279
12982	11470	6832
12982	11470	7037
12982	11470	3893
18765	11471	7136
18765	11471	4436
18765	11471	8629
18765	11471	2609
18765	11471	9587
8044	11472	5279
8044	11472	2738
8044	11472	7538
8044	11472	7644
8044	11472	8192
8044	11472	8206
15691	11473	2674
15691	11473	4450
15691	11473	4277
15691	11473	5959
11091	11474	9567
11091	11474	2813
11091	11474	8730
11091	11474	3612
11091	11474	8567
11091	11474	637
17685	11475	6688
17685	11475	7907
17685	11475	8913
17685	11475	6471
4858	11476	7975
4858	11476	4728
4858	11476	2194
4858	11476	2387
4858	11476	3091
4858	11476	7192
4858	11476	7254
4858	11476	8416
14517	11477	7568
14517	11477	2719
14517	11477	7342
14517	11477	9669
19483	11478	6797
19483	11478	7134
19483	11478	3204
19483	11478	9914
19483	11478	5519
19483	11478	7951
19483	11478	4934
19483	11478	5960
19483	11478	3625
2385	11479	7672
2385	11479	6869
2385	11479	8139
2385	11479	7082
2385	11479	8079
2385	11479	4738
2385	11479	2868
5563	11480	9887
9639	11481	6423
9639	11481	2019
9639	11481	3369
9639	11481	9063
9639	11481	5406
9639	11481	8380
9639	11481	4418
9639	11481	2620
9639	11481	9339
4413	11482	4988
4413	11482	2688
4413	11482	1718
539	11483	2446
539	11483	7498
539	11483	6748
539	11483	6854
539	11483	2492
539	11483	5698
16633	11484	5674
1942	11485	504
1942	11485	2100
1942	11485	7944
1942	11485	2490
1942	11485	7907
1942	11485	9338
1942	11485	749
15203	11486	2835
15203	11486	1366
15203	11486	2251
15203	11486	3561
15203	11486	7881
14859	11487	9666
14859	11487	1619
14859	11487	6919
14859	11487	241
14859	11487	9044
14859	11487	230
14859	11487	5662
14859	11487	7393
14859	11487	6653
16036	11488	8788
13336	11489	4098
13336	11489	6301
13336	11489	1268
13336	11489	1372
13336	11489	2028
13336	11489	3011
13336	11489	1190
13701	11490	749
13701	11490	8482
13701	11490	106
13701	11490	8666
13701	11490	9553
13701	11490	5561
13701	11490	3577
13701	11490	8810
155	11491	8263
155	11491	6404
155	11491	895
155	11491	4514
155	11491	4444
10385	11492	3775
10385	11492	731
10385	11492	1037
10385	11492	9114
10385	11492	2951
10385	11492	6255
10385	11492	2568
10385	11492	1837
200	11493	1374
11775	11494	5838
11775	11494	8101
11775	11494	1345
4151	11495	2358
10617	11496	7069
10617	11496	3582
10617	11496	9050
10617	11496	9005
757	11497	6266
757	11497	292
757	11497	6008
757	11497	9978
757	11497	267
757	11497	9429
757	11497	1051
17406	11498	2610
17406	11498	2814
17406	11498	3068
17406	11498	4240
6320	11499	544
6320	11499	4575
1166	11500	7936
14728	11501	9150
14728	11501	545
6307	11502	9344
6307	11502	889
6307	11502	5548
6307	11502	6744
6307	11502	3406
6307	11502	6715
6307	11502	8123
6307	11502	8564
6307	11502	8328
18238	11503	961
3010	11504	4658
3010	11504	8236
3010	11504	3138
3010	11504	7586
3010	11504	1113
3010	11504	6684
3010	11504	1616
3010	11504	2499
3010	11504	931
18517	11505	8377
18517	11505	4846
18517	11505	4437
18517	11505	842
11000	11506	9502
11000	11506	4416
11000	11506	5180
11000	11506	1416
11000	11506	46
5090	11507	3608
5090	11507	5450
5090	11507	3783
5090	11507	2594
5090	11507	3164
5090	11507	6473
7056	11508	8820
7056	11508	575
7056	11508	6094
7056	11508	8762
17615	11509	1352
17615	11509	9070
17615	11509	3160
13884	11510	5570
13884	11510	5753
13884	11510	5516
13884	11510	5570
13884	11510	557
13884	11510	4028
13884	11510	7623
13884	11510	6885
9003	11511	7380
9003	11511	1476
9003	11511	1504
9003	11511	968
9003	11511	1578
9003	11511	6354
9003	11511	823
9003	11511	9189
9516	11512	9146
9516	11512	268
9516	11512	5509
9516	11512	3154
9516	11512	1654
9516	11512	1310
9516	11512	4890
9516	11512	5482
9516	11512	7421
17996	11513	6145
10665	11514	90
18472	11515	6005
18316	11516	7503
18316	11516	8308
18316	11516	2414
18316	11516	8785
18316	11516	239
18316	11516	8832
18316	11516	3185
18316	11516	2589
18316	11516	308
796	11517	9634
796	11517	7399
796	11517	4648
796	11517	4796
796	11517	4294
796	11517	2595
796	11517	4691
6949	11518	6283
6949	11518	2631
6949	11518	8649
6949	11518	5135
6949	11518	733
6949	11518	9354
17975	11519	4626
17975	11519	1214
17975	11519	7611
17975	11519	1720
17975	11519	8108
17975	11519	5214
112	11520	3730
112	11520	5634
112	11520	8976
112	11520	1335
112	11520	2632
112	11520	237
467	11521	4878
467	11521	3722
467	11521	4340
467	11521	2694
15815	11522	7964
15815	11522	7901
7070	11523	4303
13868	11524	8361
11962	11525	4814
11962	11525	8343
11962	11525	9233
11962	11525	1602
11962	11525	8943
11962	11525	2818
1438	11526	4254
1438	11526	9239
1438	11526	8073
1438	11526	5490
1438	11526	491
1438	11526	9934
1438	11526	9831
1438	11526	7323
11330	11527	6701
11330	11527	4111
11330	11527	3944
1116	11528	8997
1116	11528	3815
3774	11529	6052
3774	11529	9796
3774	11529	9940
3774	11529	5989
3774	11529	4270
3774	11529	2927
19253	11530	5270
19253	11530	3851
19253	11530	7969
19253	11530	8964
19253	11530	3399
19253	11530	5201
19253	11530	4664
1432	11531	6702
1432	11531	9223
1432	11531	8856
1432	11531	2475
1432	11531	1561
1432	11531	1409
1432	11531	2207
1432	11531	2438
1432	11531	4495
6916	11532	6235
1798	11533	1615
1798	11533	4207
1798	11533	9000
1798	11533	1008
1798	11533	6923
16966	11534	3510
11895	11535	6354
11895	11535	5674
3816	11536	2807
8844	11537	2739
8844	11537	2594
8844	11537	6307
8844	11537	7227
8844	11537	7998
8844	11537	6987
8844	11537	6967
8844	11537	7455
8844	11537	6924
5193	11538	4505
5193	11538	4466
5193	11538	5873
5193	11538	1734
8943	11539	8217
8943	11539	694
17383	11540	199
17383	11540	7723
17383	11540	2400
1962	11541	5100
1962	11541	2820
1962	11541	9058
1962	11541	8987
1962	11541	4019
1962	11541	5263
1962	11541	8749
1962	11541	7882
1962	11541	8924
721	11542	8764
721	11542	5986
721	11542	9292
721	11542	2145
721	11542	6442
721	11542	8281
721	11542	6809
721	11542	7954
3943	11543	9768
3943	11543	6871
3943	11543	1556
3943	11543	1559
16965	11544	3129
16965	11544	6081
16965	11544	1454
16965	11544	8955
16965	11544	5469
4553	11545	8071
4553	11545	7080
4553	11545	6094
4553	11545	3549
4553	11545	4498
12112	11546	4539
12112	11546	9828
12112	11546	6819
12112	11546	88
12112	11546	4133
19202	11547	1877
19202	11547	8431
19202	11547	3554
19294	11548	2611
19294	11548	36
19294	11548	2911
19294	11548	6279
19294	11548	7642
8921	11549	2733
8921	11549	4246
8921	11549	5748
8921	11549	2222
8921	11549	1374
9854	11550	4574
9854	11550	3886
9854	11550	5375
9854	11550	8553
9854	11550	8750
9854	11550	5734
9854	11550	938
9854	11550	852
9854	11550	6052
594	11551	820
594	11551	2472
594	11551	5358
594	11551	7120
594	11551	8998
5767	11552	6805
5767	11552	3699
5767	11552	2262
5767	11552	1945
5767	11552	282
12667	11553	6630
12667	11553	96
12667	11553	3569
12667	11553	9642
12667	11553	2611
3217	11554	4492
2592	11555	6850
2592	11555	9031
2592	11555	223
2592	11555	1590
2592	11555	5646
2592	11555	1623
2592	11555	6833
2592	11555	9724
2592	11555	4286
13794	11556	8506
13794	11556	260
13794	11556	1915
13794	11556	4293
13794	11556	5758
13794	11556	3702
13794	11556	9937
13794	11556	4101
13794	11556	298
3840	11557	3639
3840	11557	6731
3840	11557	1111
3840	11557	4821
3840	11557	5834
3840	11557	1820
7468	11558	412
8226	11559	8038
8226	11559	3221
5432	11560	9045
5432	11560	410
5432	11560	1818
5432	11560	1835
5432	11560	8758
5432	11560	9964
5432	11560	3761
5432	11560	4311
9444	11561	8835
9444	11561	353
9444	11561	3720
9444	11561	5207
9444	11561	6289
9444	11561	9030
9444	11561	9355
9444	11561	1108
5885	11562	610
5885	11562	294
5885	11562	4060
5885	11562	384
5885	11562	9326
5885	11562	9619
5885	11562	1228
5885	11562	5033
5885	11562	3544
19663	11563	5165
19663	11563	3781
19663	11563	6228
19663	11563	9215
19648	11564	4194
19648	11564	9354
19648	11564	6832
19648	11564	8984
19648	11564	6840
3744	11565	2112
3744	11565	9797
3744	11565	4812
3744	11565	2868
3744	11565	1233
3744	11565	3333
3744	11565	3134
3744	11565	271
3744	11565	2539
3784	11566	571
3784	11566	4099
3784	11566	8237
3784	11566	9283
3784	11566	486
3784	11566	3866
3784	11566	9206
4146	11567	1169
4146	11567	6923
4146	11567	8391
4146	11567	9248
4146	11567	1658
4146	11567	2820
6782	11568	802
6782	11568	2331
5634	11569	3099
5634	11569	2900
5634	11569	2756
5634	11569	4818
3481	11570	8934
3481	11570	89
3481	11570	7537
3481	11570	1291
3481	11570	6300
3481	11570	7060
3481	11570	6978
3481	11570	7184
3481	11570	2207
10611	11571	3648
10611	11571	4625
10611	11571	6023
10611	11571	206
10611	11571	4556
9288	11572	7552
9288	11572	4507
9288	11572	1037
9288	11572	952
9288	11572	956
9288	11572	5349
9288	11572	6797
9288	11572	8468
9288	11572	1361
11969	11573	1380
11969	11573	8508
11969	11573	9924
11969	11573	578
16260	11574	1981
16260	11574	5560
16260	11574	9726
16260	11574	1068
15728	11575	4003
15728	11575	260
15728	11575	9323
15728	11575	6500
15728	11575	1624
15728	11575	6636
15728	11575	5237
15728	11575	1201
3750	11576	3587
3750	11576	257
3750	11576	793
3750	11576	8385
3750	11576	9188
3750	11576	8615
3750	11576	3701
6045	11577	3724
6045	11577	6938
4347	11578	6897
4347	11578	5960
4347	11578	240
4347	11578	9890
1364	11579	1152
1364	11579	1604
10609	11580	8327
10609	11580	1559
10609	11580	9693
10609	11580	2410
10609	11580	669
10609	11580	6662
10609	11580	2898
10609	11580	3179
10609	11580	2167
10047	11581	6265
10047	11581	6462
10047	11581	4669
10047	11581	3173
10047	11581	288
3692	11582	342
3692	11582	3933
1187	11583	3215
1187	11583	1976
1187	11583	4821
1187	11583	404
1187	11583	1064
1187	11583	3473
1187	11583	4537
1187	11583	8185
16945	11584	318
16945	11584	4470
16945	11584	8715
9309	11585	3493
10936	11586	1077
10936	11586	5389
10936	11586	4662
10936	11586	9666
10936	11586	7001
10936	11586	6906
10936	11586	6323
13281	11587	7300
13281	11587	4436
13281	11587	2238
13281	11587	9212
13281	11587	5642
13281	11587	1198
4549	11588	4415
4549	11588	2274
4549	11588	5084
4549	11588	1931
16506	11589	4893
16506	11589	5323
16506	11589	4556
16506	11589	1160
16506	11589	3190
16506	11589	2523
16506	11589	1579
16506	11589	2062
16506	11589	5995
820	11590	4490
820	11590	4565
820	11590	6245
820	11590	4673
820	11590	1579
13802	11591	6659
13802	11591	2667
13802	11591	3290
13802	11591	8679
13802	11591	8911
13802	11591	4472
14978	11592	2779
14978	11592	7455
14978	11592	6225
1795	11593	464
1795	11593	8112
9541	11594	4619
9541	11594	3095
9541	11594	3296
9541	11594	4038
9541	11594	6910
9541	11594	5257
9541	11594	1264
9541	11594	2029
16507	11595	9151
16507	11595	6224
16507	11595	9826
16507	11595	1835
16507	11595	9106
7448	11596	7022
7448	11596	8067
7448	11596	6466
7448	11596	9124
7448	11596	7201
7448	11596	9757
10272	11597	148
10272	11597	1983
3617	11598	6872
3617	11598	5057
3617	11598	3534
3617	11598	5901
3617	11598	9156
3617	11598	1614
3617	11598	8943
3617	11598	7343
14200	11599	2236
4765	11600	8753
4765	11600	5543
4765	11600	3818
4765	11600	9269
5605	11601	3358
5605	11601	2119
5605	11601	4108
5605	11601	5709
5605	11601	7205
5605	11601	8551
5605	11601	7065
5605	11601	5431
9838	11602	654
9838	11602	1379
1294	11603	3450
1294	11603	913
1294	11603	1163
10541	11604	6721
10541	11604	4321
10541	11604	3874
10541	11604	6057
10541	11604	202
10541	11604	4223
10541	11604	1145
5047	11605	3171
5047	11605	4115
10056	11606	8059
10056	11606	1800
10056	11606	2691
10056	11606	3449
10056	11606	3792
10056	11606	8397
17198	11607	1352
4397	11608	3553
4397	11608	7765
4397	11608	2530
4397	11608	2696
4397	11608	9663
2924	11609	9983
2924	11609	861
2924	11609	3676
2924	11609	3622
5386	11610	2910
5386	11610	1406
5386	11610	1947
5386	11610	1559
5386	11610	2627
5386	11610	2844
5386	11610	44
5386	11610	6077
5386	11610	3968
7901	11611	7724
7901	11611	5171
7901	11611	9314
7901	11611	4039
7901	11611	2235
7901	11611	7337
18567	11612	8995
18567	11612	8243
18567	11612	6547
18567	11612	4344
16623	11613	2262
16623	11613	455
16623	11613	5954
16623	11613	1331
16623	11613	8652
1772	11614	4526
1772	11614	2350
1772	11614	9068
14621	11615	5597
10172	11616	9628
10172	11616	2066
10172	11616	8085
10172	11616	5707
10172	11616	3287
18033	11617	2083
18033	11617	2015
18033	11617	2893
18033	11617	5777
18033	11617	8393
18033	11617	8137
18033	11617	6485
4644	11618	421
4644	11618	8784
4644	11618	6863
4644	11618	7921
4644	11618	8848
4644	11618	9166
4644	11618	9808
4644	11618	3861
13506	11619	3994
13506	11619	416
13800	11620	9222
13800	11620	3061
13800	11620	9407
13800	11620	8148
12138	11621	8775
12138	11621	9273
12138	11621	6833
12138	11621	403
12138	11621	9886
7759	11622	6010
7759	11622	1285
7759	11622	4244
7759	11622	358
19528	11623	6033
19528	11623	4365
19528	11623	663
19528	11623	8035
19528	11623	1721
19528	11623	3069
19528	11623	7380
19528	11623	5430
62	11624	9916
62	11624	2638
62	11624	7525
15347	11625	5970
668	11626	3473
668	11626	6692
668	11626	4143
668	11626	7317
668	11626	2714
668	11626	2871
668	11626	2777
5384	11627	6852
5384	11627	8022
5384	11627	821
5384	11627	8926
5384	11627	9572
1628	11628	91
8467	11629	5756
8467	11629	5851
8467	11629	484
5747	11630	7901
5747	11630	6001
5747	11630	6485
10821	11631	429
10821	11631	7089
10821	11631	1331
10821	11631	667
10821	11631	1413
10821	11631	225
12150	11632	4703
12043	11633	4192
1354	11634	6087
1354	11634	9986
1354	11634	3046
1354	11634	8718
18769	11635	8275
18769	11635	2832
18769	11635	7794
18769	11635	8416
18769	11635	1649
18769	11635	8518
5419	11636	3386
5419	11636	3404
5419	11636	411
5419	11636	5988
5419	11636	463
5419	11636	7832
5419	11636	4089
5419	11636	381
5419	11636	1046
17679	11637	1336
17679	11637	483
17679	11637	1010
17679	11637	2563
17679	11637	2862
17679	11637	8512
17679	11637	5421
17679	11637	9655
234	11638	4833
10425	11639	8425
522	11640	3746
9511	11641	5167
9511	11641	9119
9511	11641	4692
8691	11642	4463
8691	11642	5188
8691	11642	2262
8691	11642	4507
8691	11642	5304
9447	11643	5479
9447	11643	2171
9447	11643	1693
9447	11643	9257
9447	11643	6162
9447	11643	537
9447	11643	2914
9447	11643	5199
9447	11643	8115
6605	11644	8026
6605	11644	8010
6605	11644	6393
19168	11645	6522
19168	11645	9618
19168	11645	5550
19168	11645	5074
11220	11646	8747
13724	11647	165
13724	11647	3125
13724	11647	9839
13724	11647	1519
13724	11647	7004
13724	11647	5815
13724	11647	3102
13724	11647	460
13724	11647	550
11246	11648	1233
11246	11648	9002
11246	11648	8046
11246	11648	6842
11246	11648	7967
11246	11648	1845
11246	11648	5195
11246	11648	2225
18457	11649	1875
18457	11649	6065
18457	11649	2104
18457	11649	8343
12126	11650	6347
12126	11650	3450
12126	11650	9562
12126	11650	9860
3409	11651	3388
3409	11651	9203
3409	11651	72
3892	11652	4280
5246	11653	8686
5246	11653	3418
5246	11653	4744
5246	11653	9424
5246	11653	7158
5246	11653	1833
5246	11653	987
5246	11653	6944
5246	11653	1295
2733	11654	3312
15183	11655	215
15183	11655	9462
15183	11655	7354
15183	11655	3931
15183	11655	9746
15183	11655	6402
15183	11655	2637
15183	11655	1357
15183	11655	8685
19960	11656	1346
19960	11656	4384
19960	11656	2582
19960	11656	2250
4927	11657	1363
4927	11657	8042
4927	11657	9657
4927	11657	8648
4927	11657	4692
12096	11658	4348
12096	11658	2956
12096	11658	6582
1930	11659	7152
1930	11659	3512
1930	11659	3672
1930	11659	8016
1930	11659	1279
1930	11659	328
1930	11659	3846
17074	11660	4585
17074	11660	4260
14431	11661	1518
14431	11661	5619
14431	11661	47
14431	11661	1685
14431	11661	5624
7278	11662	9697
7278	11662	9489
7278	11662	9693
7278	11662	2078
7278	11662	7764
7278	11662	5119
7278	11662	5594
7278	11662	9240
1513	11663	1233
1513	11663	6235
1513	11663	9516
1513	11663	8273
17326	11664	9380
17326	11664	8735
17326	11664	1314
17326	11664	9024
17326	11664	7475
6135	11665	6384
4591	11666	8253
4591	11666	5246
4591	11666	6735
4463	11667	7425
4463	11667	4739
4463	11667	633
4463	11667	6971
4463	11667	5131
4463	11667	3797
4463	11667	7512
4463	11667	6573
4463	11667	6307
9897	11668	9826
9897	11668	2213
9897	11668	8761
9897	11668	8792
12431	11669	2374
12431	11669	7469
5198	11670	8831
5198	11670	7713
5198	11670	5196
5198	11670	3072
5198	11670	8968
5198	11670	5830
16085	11671	4814
16085	11671	8012
16085	11671	359
16085	11671	2907
16085	11671	3647
16085	11671	2077
16085	11671	2974
3608	11672	7207
555	11673	3346
555	11673	2511
555	11673	7619
555	11673	8728
13479	11674	7253
13479	11674	5098
13479	11674	7205
357	11675	1983
18377	11676	9466
18377	11676	9553
18377	11676	5886
18377	11676	4468
18377	11676	9926
18377	11676	5936
19719	11677	6689
19719	11677	8085
19719	11677	6567
19719	11677	4072
19719	11677	5770
19719	11677	9807
19719	11677	5243
9417	11678	7520
9417	11678	4303
9417	11678	8067
8005	11679	3862
8005	11679	2303
8005	11679	9851
8005	11679	4444
8005	11679	5805
3149	11680	8428
3149	11680	8197
3149	11680	4521
3149	11680	3355
3149	11680	1438
3149	11680	4027
18418	11681	4325
18418	11681	8501
18418	11681	7917
18418	11681	7014
18418	11681	4768
18418	11681	877
18418	11681	4394
18418	11681	6618
9628	11682	1689
9628	11682	1818
9628	11682	4946
9628	11682	2629
9628	11682	5054
9628	11682	4874
9628	11682	3501
9628	11682	6005
9628	11682	1726
12986	11683	7282
12986	11683	101
12986	11683	3052
12986	11683	8713
12986	11683	5137
13909	11684	2799
13909	11684	6053
13909	11684	2290
13909	11684	7230
13909	11684	4301
13909	11684	7207
13909	11684	6254
13909	11684	2519
13909	11684	5640
11479	11685	1098
11479	11685	2361
11479	11685	2814
11479	11685	3189
11479	11685	5860
3825	11686	2839
3825	11686	574
3825	11686	4305
3825	11686	3166
3825	11686	8766
8809	11687	144
8809	11687	345
8809	11687	1596
8809	11687	7477
8809	11687	9343
10405	11688	7115
10405	11688	8030
10405	11688	1564
11737	11689	6427
18151	11690	4046
18151	11690	611
4414	11691	6616
4414	11691	9082
4414	11691	1640
4414	11691	611
4414	11691	6229
4414	11691	8708
4414	11691	7243
4414	11691	3660
172	11692	9161
172	11692	3428
8077	11693	6245
8077	11693	7384
8077	11693	1130
8077	11693	227
8077	11693	2200
8077	11693	1523
8077	11693	9476
8077	11693	6220
8077	11693	6030
4176	11694	4089
4176	11694	7452
4176	11694	2333
4176	11694	1555
4176	11694	4448
4176	11694	4621
4176	11694	660
4176	11694	8297
4176	11694	8519
82	11695	271
82	11695	7917
16523	11696	7383
16523	11696	4113
16523	11696	9994
16523	11696	315
16523	11696	6375
1990	11697	6745
10527	11698	5305
10527	11698	3811
10527	11698	9455
8954	11699	9464
7154	11700	22
7154	11700	4280
7154	11700	7283
7753	11701	8767
7753	11701	9399
7753	11701	7136
7753	11701	8464
15837	11702	2396
15837	11702	2414
10307	11703	7886
10307	11703	4759
10307	11703	1853
18487	11704	3379
18487	11704	3946
18487	11704	8837
18487	11704	7480
18487	11704	2028
18487	11704	5219
18487	11704	9909
18487	11704	7362
18487	11704	9473
9818	11705	367
9818	11705	7526
9818	11705	6433
9818	11705	1463
9818	11705	2740
13369	11706	7766
13369	11706	3170
13369	11706	2856
13369	11706	4494
13369	11706	6002
13369	11706	5086
5122	11707	7922
5122	11707	3274
5122	11707	2969
5122	11707	8764
5122	11707	2056
5122	11707	9273
5122	11707	8188
5122	11707	4958
16254	11708	6515
16254	11708	7608
16254	11708	2094
16254	11708	7991
16254	11708	5254
6351	11709	8623
6351	11709	3204
6351	11709	6522
6351	11709	8889
14153	11710	3029
14153	11710	7432
14153	11710	9518
14153	11710	9013
14153	11710	6463
14153	11710	9819
14153	11710	2450
14153	11710	2827
14153	11710	8248
13740	11711	4256
13740	11711	4636
13740	11711	6355
13740	11711	221
13740	11711	8288
13740	11711	3713
13740	11711	2024
13740	11711	9665
13740	11711	356
348	11712	5246
348	11712	7269
348	11712	5355
348	11712	363
348	11712	2819
14910	11713	6438
14910	11713	5351
14910	11713	1234
14910	11713	444
14910	11713	2293
14910	11713	4295
12877	11714	1032
12877	11714	222
12877	11714	1561
12877	11714	1742
12877	11714	4971
12877	11714	6542
12877	11714	2016
16906	11715	3179
16906	11715	5651
16906	11715	6780
16906	11715	3731
16906	11715	591
16906	11715	7513
17088	11716	6844
17088	11716	2579
17088	11716	4963
17088	11716	3147
17088	11716	2476
17088	11716	5808
17088	11716	3615
13586	11717	415
13586	11717	3895
13586	11717	9471
13586	11717	4112
13586	11717	7898
13586	11717	5527
4741	11718	956
8205	11719	9264
5758	11720	9672
5758	11720	464
5758	11720	2802
5758	11720	4232
5758	11720	8843
13481	11721	6118
13481	11721	7151
13481	11721	7606
13481	11721	5915
13481	11721	2210
2947	11722	4352
8046	11723	4109
8046	11723	9672
8046	11723	1753
8046	11723	6683
8046	11723	5255
2744	11724	9907
2744	11724	1045
2744	11724	6286
4826	11725	2752
15206	11726	2918
15206	11726	8542
15206	11726	5550
15206	11726	1104
15206	11726	1301
15206	11726	8152
15206	11726	7730
15206	11726	26
15206	11726	1859
16288	11727	557
16288	11727	4180
16288	11727	8128
16288	11727	912
7657	11728	6417
7657	11728	4458
7657	11728	6221
7657	11728	3878
3213	11729	9242
3213	11729	3941
3213	11729	5575
12264	11730	9440
702	11731	4179
702	11731	7297
702	11731	9098
10635	11732	9689
10635	11732	3600
5682	11733	5538
5682	11733	5435
5682	11733	4400
5682	11733	3258
5682	11733	8190
5682	11733	4190
5682	11733	3902
2397	11734	2953
2397	11734	4385
2397	11734	9074
2397	11734	824
2397	11734	9335
2397	11734	5513
2397	11734	1224
2397	11734	295
2397	11734	3359
13233	11735	7385
13233	11735	2457
13233	11735	1091
13233	11735	2485
13233	11735	1494
13233	11735	7136
13233	11735	5903
13454	11736	781
13454	11736	1313
13454	11736	5444
13454	11736	8663
13454	11736	6300
13454	11736	5419
13454	11736	5666
13454	11736	7555
13454	11736	4090
13149	11737	2012
13149	11737	7921
15745	11738	7158
16941	11739	77
12753	11740	1209
12753	11740	7788
12753	11740	7944
12753	11740	7408
12753	11740	8452
927	11741	8378
927	11741	6329
927	11741	4917
927	11741	8440
927	11741	1956
927	11741	1000
927	11741	1953
927	11741	8409
19235	11742	8381
19235	11742	5214
19235	11742	2368
19235	11742	1897
7684	11743	7833
7684	11743	5525
7684	11743	1172
6256	11744	5161
6256	11744	4550
6256	11744	7892
6256	11744	3187
3133	11745	7355
3133	11745	2313
3133	11745	2967
3133	11745	3093
3133	11745	8947
3133	11745	2011
3133	11745	3674
3133	11745	8436
16531	11746	48
16531	11746	5040
16452	11747	9792
16452	11747	7372
16452	11747	9525
16452	11747	6398
16452	11747	6125
16452	11747	6816
16452	11747	416
16452	11747	9543
15957	11748	6244
15957	11748	9791
15957	11748	6581
15957	11748	4231
15957	11748	3056
15957	11748	593
15957	11748	5454
15957	11748	9994
12782	11749	5881
12782	11749	8845
12782	11749	3112
12782	11749	385
2264	11750	2521
2264	11750	8900
2264	11750	8060
2231	11751	3963
2231	11751	9528
14351	11752	949
14351	11752	1308
14351	11752	2524
14351	11752	8180
14351	11752	9540
14351	11752	4040
14351	11752	7154
12108	11753	9185
12108	11753	5385
12108	11753	8194
12108	11753	2885
4878	11754	9462
4878	11754	9877
4878	11754	5638
4878	11754	5189
9457	11755	7709
9457	11755	5908
9457	11755	1571
9457	11755	8189
9457	11755	8199
9457	11755	9063
9457	11755	2921
9457	11755	4113
9457	11755	4386
7696	11756	4618
7696	11756	2149
7696	11756	4310
7696	11756	4535
7696	11756	6804
7696	11756	8190
7696	11756	6161
7696	11756	4278
7696	11756	515
19154	11757	1524
11820	11758	9758
11820	11758	6686
11820	11758	7337
11820	11758	4181
11820	11758	6291
11820	11758	4319
11820	11758	957
14235	11759	1466
18775	11760	229
18775	11760	4409
12798	11761	3244
12798	11761	3923
12798	11761	9752
12798	11761	2225
12798	11761	6818
12798	11761	9137
12798	11761	9051
12798	11761	4893
12798	11761	5023
15164	11762	9009
15164	11762	338
15164	11762	3268
15164	11762	9816
15164	11762	9678
15164	11762	8415
16332	11763	4208
16332	11763	2407
16332	11763	6297
16332	11763	8285
16332	11763	2774
16332	11763	7547
6584	11764	9266
6584	11764	3316
6584	11764	3795
6584	11764	32
6584	11764	6190
6584	11764	7073
6584	11764	6612
6584	11764	5692
6584	11764	7299
7191	11765	4784
7191	11765	5755
7191	11765	9199
5053	11766	6192
5053	11766	7421
5053	11766	2988
5053	11766	3459
5053	11766	5898
5019	11767	3329
5019	11767	2796
5019	11767	203
5019	11767	9939
5019	11767	4677
7751	11768	6402
7751	11768	7826
7751	11768	8737
3449	11769	903
3449	11769	6571
3449	11769	1105
3449	11769	4606
3449	11769	2487
3449	11769	1925
3727	11770	7558
3727	11770	8302
3727	11770	7929
3727	11770	8775
15023	11771	9236
15023	11771	5916
15023	11771	2295
15023	11771	46
15023	11771	8366
15023	11771	7833
15023	11771	2052
15023	11771	3541
15023	11771	1621
18355	11772	9073
18355	11772	9234
18355	11772	9887
18355	11772	5359
18355	11772	6407
4646	11773	4809
4646	11773	279
4646	11773	9429
4646	11773	4026
4646	11773	7868
4646	11773	3282
4646	11773	8781
9970	11774	9118
9970	11774	5585
9970	11774	9803
9970	11774	9891
9970	11774	5537
9970	11774	8533
9970	11774	1355
3267	11775	9744
3267	11775	5954
3267	11775	8108
3267	11775	7100
3267	11775	8745
5569	11776	6058
11721	11777	2071
11721	11777	4358
11721	11777	5835
11721	11777	3945
11721	11777	7346
11721	11777	5354
11721	11777	1002
11721	11777	4701
11721	11777	542
18574	11778	2072
18574	11778	8858
18574	11778	155
18574	11778	3989
18574	11778	8734
18574	11778	5751
18574	11778	6662
18574	11778	8805
12300	11779	3239
12300	11779	9126
12300	11779	1175
12300	11779	9741
12300	11779	8955
12300	11779	5041
12300	11779	8373
12300	11779	9154
6285	11780	9201
6285	11780	4574
6756	11781	9528
6756	11781	6331
6756	11781	9599
6756	11781	706
6756	11781	5125
6756	11781	7945
6756	11781	7751
6756	11781	5104
8516	11782	7401
8516	11782	1114
8516	11782	7821
8516	11782	2463
8516	11782	9065
8516	11782	2379
8516	11782	6463
8516	11782	1359
8516	11782	4166
18581	11783	3369
18581	11783	7763
18581	11783	6385
18581	11783	2731
18581	11783	4277
10779	11784	1077
10779	11784	6080
16915	11785	7167
16915	11785	648
16915	11785	2157
16915	11785	623
16915	11785	2259
44	11786	4667
44	11786	2347
13478	11787	8952
13478	11787	1252
18753	11788	3964
18753	11788	4376
18753	11788	1988
18753	11788	2092
8701	11789	4372
8701	11789	7441
8701	11789	4262
8701	11789	7981
8701	11789	6526
8701	11789	1644
5791	11790	2272
5791	11790	7555
5791	11790	4651
13277	11791	9249
13277	11791	7287
13277	11791	5791
6464	11792	3019
6464	11792	8766
6464	11792	990
6464	11792	5022
6464	11792	3306
6464	11792	1983
6464	11792	9526
6464	11792	1812
6464	11792	1468
19862	11793	9594
10769	11794	8616
3270	11795	1180
3270	11795	9186
3270	11795	3610
3270	11795	1731
3270	11795	8068
3270	11795	5129
3270	11795	5433
3270	11795	2535
16253	11796	1005
16253	11796	1506
16253	11796	3056
16253	11796	774
16253	11796	1756
16253	11796	1842
2054	11797	3518
2054	11797	8784
2054	11797	2123
15110	11798	3802
15110	11798	2124
15110	11798	3158
15110	11798	2336
10782	11799	8457
10782	11799	4126
10782	11799	9474
10782	11799	1325
10782	11799	6899
10782	11799	9476
10782	11799	6427
10782	11799	9595
10782	11799	9153
5909	11800	3066
5909	11800	7139
5909	11800	4961
5909	11800	792
18497	11801	9546
18497	11801	3084
18497	11801	4367
18497	11801	5713
18497	11801	5665
18497	11801	5441
18497	11801	28
18497	11801	5364
18497	11801	7548
1226	11802	6015
1226	11802	8871
1226	11802	7506
7579	11803	9547
7579	11803	6471
7579	11803	6565
7579	11803	7757
7579	11803	4322
7579	11803	7489
5704	11804	5356
5704	11804	5950
5704	11804	5251
5704	11804	5918
5704	11804	8770
9649	11805	425
9649	11805	8324
9776	11806	7118
9776	11806	1626
9776	11806	7748
9776	11806	7458
9776	11806	4752
9776	11806	6200
9776	11806	969
9776	11806	2666
2871	11807	6260
2871	11807	5557
2871	11807	4281
2871	11807	3578
5311	11808	6054
5311	11808	491
5311	11808	4423
5311	11808	7813
5311	11808	762
5311	11808	9877
5084	11809	3977
472	11810	6920
994	11811	3153
994	11811	8935
994	11811	4072
16988	11812	7669
15090	11813	87
8126	11814	4299
8126	11814	6577
8126	11814	4581
8126	11814	1715
8126	11814	3911
8126	11814	9325
6792	11815	1890
6792	11815	7897
6792	11815	7776
6792	11815	7104
6792	11815	3019
6792	11815	6120
6792	11815	1253
11102	11816	6769
11102	11816	7952
11102	11816	2220
11102	11816	3350
11102	11816	4708
11102	11816	4941
11102	11816	4501
4794	11817	5124
4794	11817	2034
4794	11817	682
4794	11817	2485
5999	11818	92
5999	11818	1014
5999	11818	2737
5999	11818	9906
5999	11818	4779
5999	11818	3508
5999	11818	1589
5999	11818	6551
5999	11818	405
11057	11819	3670
11057	11819	2787
11057	11819	9048
11057	11819	9154
11057	11819	3520
9068	11820	7768
9068	11820	9608
9068	11820	1805
9068	11820	2266
17633	11821	1756
17633	11821	7056
1451	11822	6880
1451	11822	6086
19210	11823	4139
19210	11823	5187
9587	11824	7909
9587	11824	4956
13113	11825	757
13113	11825	5477
13113	11825	8338
13113	11825	1213
13113	11825	5125
13113	11825	1250
13113	11825	6903
2082	11826	2947
2082	11826	7648
2082	11826	413
10737	11827	1925
10737	11827	6940
10737	11827	2756
10737	11827	2273
10737	11827	3194
10737	11827	6310
10737	11827	782
10737	11827	4322
10737	11827	4087
6357	11828	2028
6357	11828	9071
6374	11829	2838
6374	11829	7778
6374	11829	2414
9372	11830	8171
9372	11830	3705
9372	11830	5496
9372	11830	6637
9372	11830	16
9721	11831	7352
9721	11831	7228
9721	11831	9290
9721	11831	8034
9721	11831	4769
14365	11832	1868
14365	11832	9487
14365	11832	5905
14365	11832	8991
11254	11833	989
11254	11833	6094
6891	11834	8845
6891	11834	793
6891	11834	5542
6891	11834	2688
6891	11834	2743
6891	11834	1546
2064	11835	4223
2064	11835	4305
2064	11835	9267
509	11836	8276
509	11836	6212
509	11836	3312
8208	11837	9665
8208	11837	8801
692	11838	1378
11200	11839	1040
11200	11839	3147
11200	11839	4828
11200	11839	480
11200	11839	9728
11200	11839	5502
11200	11839	1748
11200	11839	7143
13615	11840	9215
13615	11840	1815
6385	11841	8793
6385	11841	4028
6385	11841	7778
6385	11841	7546
6385	11841	9348
6385	11841	5708
2419	11842	2524
2419	11842	147
2419	11842	6065
2419	11842	6662
2419	11842	408
2419	11842	1511
18819	11843	2615
785	11844	2998
785	11844	5863
785	11844	8809
785	11844	9914
785	11844	7044
785	11844	181
785	11844	7630
785	11844	5640
12095	11845	9065
12095	11845	2444
12095	11845	4896
10376	11846	3026
10376	11846	1579
773	11847	1310
773	11847	9503
773	11847	3700
773	11847	7735
773	11847	1422
773	11847	5388
773	11847	2292
9470	11848	9793
9470	11848	8706
9470	11848	6005
9470	11848	3689
1681	11849	7906
14816	11850	4539
11920	11851	148
11920	11851	9476
11920	11851	4786
11920	11851	2288
11920	11851	6335
4678	11852	9922
4678	11852	4350
4678	11852	3429
4678	11852	7168
15871	11853	6437
15871	11853	162
15871	11853	4982
15871	11853	4247
18065	11854	3611
18065	11854	2359
10163	11855	8424
10163	11855	3116
10163	11855	3545
10163	11855	1877
10163	11855	8219
9311	11856	8852
9311	11856	7878
9311	11856	1593
9311	11856	2131
9311	11856	8323
9311	11856	1190
9311	11856	9172
12222	11857	7401
12222	11857	6037
12222	11857	5120
12222	11857	4152
3119	11858	9129
3119	11858	9400
3119	11858	9942
4145	11859	7813
4145	11859	2966
4145	11859	6900
17240	11860	3456
17151	11861	1913
17151	11861	7151
17151	11861	9234
17151	11861	6751
17151	11861	3285
17151	11861	9624
17679	11862	9244
17679	11862	3562
17679	11862	1225
17679	11862	4764
17679	11862	7152
17679	11862	3084
19887	11863	6913
19887	11863	8613
19887	11863	7612
19887	11863	4779
19887	11863	2056
19887	11863	8145
19887	11863	3242
19887	11863	7397
1917	11864	7615
1917	11864	5534
17236	11865	8562
17236	11865	7112
17236	11865	8874
17236	11865	1620
17236	11865	1088
17236	11865	7382
17236	11865	800
17236	11865	3962
2718	11866	2317
2718	11866	4775
2718	11866	8547
2718	11866	4698
16111	11867	5596
16111	11867	2961
16111	11867	1397
16111	11867	955
16111	11867	979
16111	11867	5627
16111	11867	3863
14130	11868	442
14130	11868	7502
14130	11868	3196
15785	11869	5948
15785	11869	1937
15785	11869	439
15785	11869	6012
15785	11869	9479
913	11870	2235
913	11870	9535
913	11870	6230
913	11870	401
913	11870	3746
913	11870	1886
913	11870	3949
913	11870	4834
913	11870	1860
7594	11871	8695
7594	11871	7195
7594	11871	5302
7594	11871	8630
7594	11871	1461
1990	11872	1477
1990	11872	2669
1990	11872	7220
1990	11872	2164
1990	11872	1965
1990	11872	1322
12484	11873	1601
17590	11874	309
17590	11874	4344
17590	11874	3982
17590	11874	2764
8482	11875	9464
8482	11875	7335
8482	11875	606
3855	11876	8169
3855	11876	6505
3855	11876	7061
3855	11876	8564
3855	11876	8681
3855	11876	4667
17297	11877	1548
17297	11877	7647
17297	11877	26
17297	11877	3203
7617	11878	5736
7617	11878	3766
7617	11878	527
7617	11878	3674
7617	11878	5212
7617	11878	9137
7617	11878	1111
3504	11879	5157
3504	11879	1299
3504	11879	7765
3504	11879	9913
17300	11880	6013
17300	11880	5124
17300	11880	4415
17300	11880	47
17300	11880	3238
4748	11881	6177
4748	11881	3188
16690	11882	1148
16690	11882	2741
2847	11883	6765
2847	11883	6645
2847	11883	5500
2847	11883	7539
2847	11883	9148
2847	11883	805
19912	11884	6024
19912	11884	7954
19912	11884	2443
19912	11884	7560
19912	11884	971
19912	11884	4651
19912	11884	1724
19912	11884	8462
19912	11884	83
11164	11885	1128
11164	11885	8692
11164	11885	4787
11164	11885	1889
11164	11885	1167
11164	11885	9794
11164	11885	4054
11164	11885	9699
1339	11886	2998
2919	11887	6565
2919	11887	501
2919	11887	419
2919	11887	8043
2919	11887	3562
10899	11888	3361
10899	11888	1237
1871	11889	1605
1871	11889	6855
1871	11889	4579
1871	11889	6061
1871	11889	6610
1871	11889	9208
19252	11890	8735
19252	11890	6227
19252	11890	7750
19252	11890	1802
6076	11891	3973
6076	11891	2
6076	11891	8494
6076	11891	179
12479	11892	8866
12479	11892	2268
12479	11892	8610
12479	11892	7619
12479	11892	3306
2111	11893	2165
2111	11893	1869
2111	11893	5288
2111	11893	8242
2111	11893	1418
2111	11893	2146
2111	11893	9807
2111	11893	7836
13402	11894	922
13402	11894	9125
13402	11894	4521
13402	11894	2386
13402	11894	3486
13402	11894	381
13402	11894	2647
13402	11894	6340
9163	11895	1316
9163	11895	1104
9163	11895	6064
9163	11895	706
9163	11895	5641
9163	11895	33
9163	11895	6449
9163	11895	5103
9163	11895	1588
10146	11896	723
10146	11896	5148
10146	11896	9051
4549	11897	7645
4549	11897	4083
4549	11897	2788
16858	11898	4991
16858	11898	4810
16858	11898	1479
16858	11898	7581
16858	11898	1470
16858	11898	6896
4087	11899	5280
4087	11899	8491
4087	11899	3859
4087	11899	1873
4087	11899	9843
4087	11899	2730
13581	11900	7301
13581	11900	8173
13581	11900	2324
13581	11900	2777
13581	11900	1803
13581	11900	5986
13581	11900	1716
13581	11900	5185
7352	11901	9811
7352	11901	7940
7352	11901	1553
7352	11901	5116
7352	11901	7460
7352	11901	2722
7352	11901	2159
7352	11901	3539
7352	11901	6647
16899	11902	7418
16899	11902	9502
16899	11902	4699
16899	11902	6278
12177	11903	5741
12177	11903	4248
12177	11903	2805
12177	11903	7090
18497	11904	3731
4012	11905	6267
4012	11905	10
4012	11905	1536
15627	11906	3902
15627	11906	626
15627	11906	9200
15627	11906	500
15627	11906	6580
15627	11906	7532
15627	11906	6837
1134	11907	2573
1134	11907	1678
1134	11907	7469
1134	11907	4606
1134	11907	6396
1134	11907	6817
1134	11907	3062
1134	11907	1860
1134	11907	361
1719	11908	8448
1719	11908	8186
1719	11908	4548
1719	11908	5851
1719	11908	607
4568	11909	3972
4568	11909	6573
4568	11909	7882
4568	11909	1190
4568	11909	4108
4568	11909	4630
4568	11909	4109
14345	11910	7768
14345	11910	9059
14345	11910	7750
14345	11910	3881
7964	11911	1551
16246	11912	1513
11240	11913	88
11240	11913	9105
11240	11913	497
11240	11913	9190
11240	11913	3947
11240	11913	580
8921	11914	8442
8921	11914	7086
8921	11914	5302
8921	11914	8115
8921	11914	9891
8921	11914	6448
11329	11915	8989
11329	11915	749
11329	11915	3630
11329	11915	7750
11329	11915	8186
2687	11916	7835
2687	11916	15
2687	11916	1223
2687	11916	4468
2687	11916	5596
2687	11916	8965
2687	11916	5535
2687	11916	7708
2687	11916	9546
589	11917	232
589	11917	29
589	11917	2261
10100	11918	6281
10100	11918	2515
10100	11918	3953
10100	11918	6841
10100	11918	1340
10100	11918	1593
10100	11918	18
19126	11919	9857
19126	11919	778
19126	11919	6111
19126	11919	8506
19126	11919	106
19126	11919	3422
19126	11919	5861
19126	11919	7366
2638	11920	868
2638	11920	9852
2638	11920	3570
2638	11920	1760
15513	11921	9935
15513	11921	9377
15513	11921	2980
15513	11921	4417
15513	11921	6148
15513	11921	1815
15513	11921	7540
15513	11921	382
15513	11921	499
2733	11922	3827
2733	11922	8510
2733	11922	9074
2733	11922	3343
2733	11922	7229
2733	11922	2645
2733	11922	9323
2733	11922	4487
1269	11923	2642
6047	11924	8761
2386	11925	7196
2386	11925	983
2386	11925	7742
2386	11925	6739
2386	11925	7602
13848	11926	663
13848	11926	6697
13848	11926	4241
13848	11926	1354
13848	11926	2362
13848	11926	4149
11438	11927	1115
11438	11927	8956
11438	11927	5779
11438	11927	6422
11438	11927	1667
11438	11927	1900
11438	11927	948
11438	11927	9305
11438	11927	624
9728	11928	8810
9728	11928	416
9728	11928	8822
9728	11928	8677
9728	11928	7434
12777	11929	3085
12777	11929	8942
12777	11929	2335
12777	11929	7994
12777	11929	7748
12777	11929	4891
17479	11930	3942
17479	11930	6336
17479	11930	5003
17479	11930	2636
17479	11930	6294
17479	11930	3472
17479	11930	6458
17479	11930	3364
4610	11931	3146
4610	11931	9287
4610	11931	9584
4610	11931	9265
4610	11931	2917
4610	11931	1518
15707	11932	3011
15707	11932	3226
15707	11932	3920
15707	11932	6243
15707	11932	2057
15707	11932	9919
15707	11932	1911
15707	11932	1733
15707	11932	6500
12166	11933	8965
12166	11933	7716
12166	11933	4969
12166	11933	8336
12166	11933	1807
10065	11934	1730
10065	11934	4329
10065	11934	6500
10065	11934	9514
2493	11935	2265
2493	11935	1042
2493	11935	4633
2493	11935	5572
2493	11935	488
17647	11936	170
17647	11936	1448
17647	11936	707
17647	11936	7712
17647	11936	6963
17647	11936	9282
15483	11937	2700
15483	11937	5505
15483	11937	7447
15483	11937	3747
15483	11937	2487
15483	11937	3558
560	11938	7035
560	11938	4046
560	11938	8135
10195	11939	1575
10195	11939	9799
4996	11940	6239
19972	11941	4221
19972	11941	9903
19972	11941	3587
1243	11942	8363
1243	11942	6309
1243	11942	1602
1243	11942	3196
1243	11942	868
11091	11943	5728
11091	11943	8489
16475	11944	1545
16475	11944	3216
16475	11944	2170
16475	11944	5753
16475	11944	8272
16475	11944	7044
17292	11945	1822
17292	11945	1443
17292	11945	3272
17292	11945	6052
17292	11945	8665
17292	11945	5047
17292	11945	2778
17292	11945	6319
19068	11946	3255
19068	11946	5369
19068	11946	9319
19068	11946	6107
19068	11946	1058
5760	11947	7174
5760	11947	1396
5760	11947	2962
5760	11947	7766
5760	11947	441
13518	11948	6293
13518	11948	9399
13518	11948	9520
13518	11948	1073
13518	11948	7180
16475	11949	1117
16475	11949	891
16475	11949	4798
16475	11949	1516
16475	11949	2346
16475	11949	5768
15356	11950	2248
15356	11950	9002
15356	11950	5385
15356	11950	6413
15356	11950	7359
1535	11951	7197
1535	11951	4616
1535	11951	1236
1535	11951	373
5436	11952	5505
5436	11952	618
5436	11952	6543
11088	11953	4065
11088	11953	2730
11088	11953	4516
11088	11953	2191
11088	11953	147
11088	11953	9289
1049	11954	3276
1049	11954	563
1049	11954	4288
1049	11954	7165
1049	11954	1117
1049	11954	7771
1049	11954	9250
1049	11954	8277
2012	11955	7372
2012	11955	4064
2012	11955	6314
2012	11955	2280
2012	11955	3878
2012	11955	1632
2012	11955	7803
4182	11956	6997
4182	11956	3332
4182	11956	1381
4182	11956	7049
4182	11956	5896
4182	11956	663
4182	11956	7974
4182	11956	7561
4182	11956	5552
15663	11957	4287
15663	11957	6420
15663	11957	1486
15663	11957	4180
15663	11957	8507
15663	11957	9122
15663	11957	5943
15663	11957	4420
15663	11957	158
1640	11958	8854
1640	11958	3255
17290	11959	7912
8663	11960	3213
3439	11961	3558
3439	11961	191
3439	11961	2900
3439	11961	8294
3439	11961	1168
3439	11961	7361
3439	11961	7752
3439	11961	4427
3439	11961	9261
14344	11962	1503
14344	11962	340
14344	11962	4588
14344	11962	6435
14344	11962	596
14344	11962	8462
14344	11962	7970
14344	11962	1133
14344	11962	7504
9729	11963	5480
9729	11963	3393
9729	11963	3412
13194	11964	8394
13194	11964	8130
13194	11964	4336
13194	11964	1534
19991	11965	1356
19991	11965	8790
19991	11965	9150
2943	11966	8220
2943	11966	3945
2943	11966	4518
2943	11966	8229
2943	11966	9271
2943	11966	1037
2943	11966	9603
2943	11966	1965
2943	11966	303
12037	11967	2868
12037	11967	1348
12037	11967	2134
19372	11968	631
19372	11968	3340
3135	11969	8190
3135	11969	745
3135	11969	9163
3135	11969	8929
121	11970	2548
121	11970	6120
121	11970	367
121	11970	8966
121	11970	7940
121	11970	5563
121	11970	1460
121	11970	3717
12943	11971	262
12943	11971	6451
12943	11971	2334
12943	11971	8889
12943	11971	5440
12943	11971	9846
12943	11971	2722
12943	11971	1882
1695	11972	4088
1695	11972	727
8887	11973	915
8887	11973	536
13972	11974	2365
13972	11974	3482
6655	11975	9292
6655	11975	9669
6655	11975	8520
6655	11975	5667
6655	11975	9117
6655	11975	8155
18473	11976	9197
18473	11976	2926
7050	11977	3013
7050	11977	91
7050	11977	7506
13595	11978	307
13595	11978	9731
13595	11978	4683
5675	11979	2074
5675	11979	4952
5675	11979	4709
9262	11980	6918
14017	11981	2891
14017	11981	9228
14017	11981	7856
15172	11982	6433
15172	11982	6040
15172	11982	1077
12057	11983	3906
12057	11983	6917
12057	11983	178
10205	11984	7533
13522	11985	6296
13522	11985	1186
13522	11985	1900
13522	11985	9678
1509	11986	6783
1377	11987	5997
11438	11988	6727
11438	11988	8609
11438	11988	4438
11438	11988	6071
11438	11988	7484
18765	11989	7321
18765	11989	2969
19502	11990	439
19502	11990	2782
19502	11990	8709
17705	11991	6529
17705	11991	1353
17705	11991	9087
17705	11991	1699
17705	11991	4679
17705	11991	5953
17705	11991	6449
17705	11991	7849
14287	11992	9724
14287	11992	9115
14287	11992	6043
14287	11992	9321
14287	11992	6675
6407	11993	4169
6407	11993	5854
6407	11993	6971
6407	11993	102
6407	11993	84
6407	11993	6196
6407	11993	5968
6407	11993	5076
9598	11994	7304
9598	11994	5223
9598	11994	8983
9598	11994	7637
9598	11994	5101
9598	11994	4491
9598	11994	9351
12643	11995	9245
12643	11995	1788
12643	11995	8892
12643	11995	8279
12643	11995	2892
15270	11996	8421
15270	11996	2693
15270	11996	1085
15270	11996	3464
15270	11996	9280
15270	11996	5454
1180	11997	5828
1180	11997	133
1180	11997	9635
1180	11997	5370
1180	11997	2991
1180	11997	4478
1180	11997	5896
1180	11997	7824
1180	11997	7629
17427	11998	4898
17427	11998	3138
17427	11998	8755
17427	11998	942
17427	11998	610
1485	11999	9767
1485	11999	5449
1485	11999	8014
1485	11999	4512
1485	11999	8368
1485	11999	8225
1485	11999	2851
7393	12000	3821
7393	12000	9960
7393	12000	9702
7393	12000	6281
7393	12000	7670
7393	12000	1054
7393	12000	1717
7393	12000	1807
7393	12000	3576
\.


--
-- Data for Name: customers; Type: TABLE DATA; Schema: public; Owner: chriskl
--

COPY customers (customerid, firstname, lastname, address1, address2, city, state, zip, country, region, email, phone, creditcardtype, creditcard, creditcardexpiration, username, "password", age, income, gender) FROM stdin;
1	VKUUXF	ITHOMQJNYX	4608499546 Dell Way	\N	QSDPAGD	SD	24101	US	1	ITHOMQJNYX@dell.com	4608499546	1	1979279217775911	2012/03	user1	password	55	100000	M
2	HQNMZH	UNUKXHJVXB	5119315633 Dell Way	\N	YNCERXJ	AZ	11802	US	1	UNUKXHJVXB@dell.com	5119315633	1	3144519586581737	2012/11	user2	password	80	40000	M
3	JTNRNB	LYYSHTQJRE	6297761196 Dell Way	\N	LWVIFXJ	OH	96082	US	1	LYYSHTQJRE@dell.com	6297761196	4	8728086929768325	2010/12	user3	password	47	100000	M
4	XMFYXD	WQLQHUHLFE	9862764981 Dell Way	\N	HOKEXCD	MS	78442	US	1	WQLQHUHLFE@dell.com	9862764981	5	7160005148965866	2009/09	user4	password	44	40000	F
5	PGDTDU	ETBYBNEGUT	2841895775 Dell Way	\N	RZQTCDN	AZ	16291	US	1	ETBYBNEGUT@dell.com	2841895775	3	8377095518168063	2010/10	user5	password	21	20000	M
6	FXDZBW	BAXPEEKXVJ	6192740010 Dell Way	\N	OPLRCNT	IN	99300	US	1	BAXPEEKXVJ@dell.com	6192740010	5	7730283664073796	2011/01	user6	password	72	100000	M
7	WVZTXZ	RMEVXCQGQF	9743191382 Dell Way	\N	SIIGBQF	NV	55961	US	1	RMEVXCQGQF@dell.com	9743191382	2	5914961899630726	2011/02	user7	password	52	60000	M
8	LIWLAI	PVGRMMHSEQ	7576564107 Dell Way	\N	BKSRQJE	NJ	66444	US	1	PVGRMMHSEQ@dell.com	7576564107	2	7663945967331529	2009/12	user8	password	67	80000	F
9	NCGWRC	CJOPRHUHIE	7291678624 Dell Way	\N	ZAVIELY	VT	78838	US	1	CJOPRHUHIE@dell.com	7291678624	1	7172072122339160	2009/10	user9	password	86	100000	M
10	FUOHXX	WMOEHWMMWM	2603867587 Dell Way	\N	HERSDPM	TN	75182	US	1	WMOEHWMMWM@dell.com	2603867587	2	5486729339230806	2008/02	user10	password	44	40000	M
11	XQVVMI	KRPGDBCQJH	2415449050 Dell Way	\N	ICLYPGR	PA	53868	US	1	KRPGDBCQJH@dell.com	2415449050	5	6630987872369588	2010/03	user11	password	58	60000	M
12	KGISQZ	IXDKAUUHCW	1896033667 Dell Way	\N	SBLZSFM	UT	18452	US	1	IXDKAUUHCW@dell.com	1896033667	2	3715867913328111	2011/10	user12	password	27	20000	F
13	LURLDP	PNPJHXMEPN	3029418206 Dell Way	\N	QPGVBCY	DE	53356	US	1	PNPJHXMEPN@dell.com	3029418206	5	3617457962129265	2009/11	user13	password	43	100000	M
14	AGUQVI	FFPCRUSFKI	3748672054 Dell Way	\N	LGKNEOA	MA	44395	US	1	FFPCRUSFKI@dell.com	3748672054	4	3344003576319665	2011/07	user14	password	85	80000	M
15	SIQANV	QQNKJSURDA	3354132892 Dell Way	\N	BREQSOA	AK	37471	US	1	QQNKJSURDA@dell.com	3354132892	4	8717996907886119	2008/05	user15	password	66	100000	M
16	IXEENV	RXEKSWOTYG	6914808178 Dell Way	\N	YOYMOYU	SD	63504	US	1	RXEKSWOTYG@dell.com	6914808178	5	9422665674239398	2009/11	user16	password	61	80000	M
17	UUGPME	UWWRKPPQOD	1436497137 Dell Way	\N	PASNVNC	MO	55931	US	1	UWWRKPPQOD@dell.com	1436497137	5	4461925670970231	2011/06	user17	password	28	60000	F
18	KASOVP	LMZBBQPFFQ	4002123087 Dell Way	\N	YTMLWYY	VA	79031	US	1	LMZBBQPFFQ@dell.com	4002123087	3	2972224516794085	2010/12	user18	password	52	100000	M
19	ELUTXG	TZIKOOQEMJ	6334227072 Dell Way	\N	RXFPWCJ	GA	68186	US	1	TZIKOOQEMJ@dell.com	6334227072	4	6367064577993006	2008/07	user19	password	59	40000	F
20	IAYPUX	YELMUQZEHW	7467996902 Dell Way	\N	JXTMHYD	UT	66087	US	1	YELMUQZEHW@dell.com	7467996902	5	2656596019398421	2009/03	user20	password	32	80000	F
21	DFYAED	MQXCPBKMLH	9981729052 Dell Way	\N	GXOEALV	PA	42074	US	1	MQXCPBKMLH@dell.com	9981729052	1	5711935373954475	2009/08	user21	password	69	40000	M
22	QIBTUS	RXITHVEPBC	5221450049 Dell Way	\N	EGDPBXY	AR	93269	US	1	RXITHVEPBC@dell.com	5221450049	2	6283100841101260	2008/08	user22	password	52	100000	M
23	NPSFGQ	NAYJFNKHRQ	8606105897 Dell Way	\N	LGSIFTG	NY	11455	US	1	NAYJFNKHRQ@dell.com	8606105897	5	6406863798853011	2009/09	user23	password	56	100000	F
24	GBNXPN	VYTIJBAAMH	1759698957 Dell Way	\N	SVNMCEM	WA	13905	US	1	VYTIJBAAMH@dell.com	1759698957	2	7402193841524423	2011/02	user24	password	88	100000	F
25	MTUAPT	TXCUYCHGVC	7232171147 Dell Way	\N	THEYTCZ	TX	40738	US	1	TXCUYCHGVC@dell.com	7232171147	3	4909582856111229	2011/04	user25	password	61	20000	F
26	JDRCWP	FRNIYTDANK	1757661798 Dell Way	\N	FLEILAQ	CT	51575	US	1	FRNIYTDANK@dell.com	1757661798	4	8073390801902861	2011/11	user26	password	81	20000	F
27	NEYCKP	QSOKVPXFUJ	6716835282 Dell Way	\N	JCVKTYW	TN	74298	US	1	QSOKVPXFUJ@dell.com	6716835282	3	6621923426631839	2010/07	user27	password	67	20000	M
28	PDDFUV	TERICXCMHF	6049066172 Dell Way	\N	HRYFNUY	DC	36514	US	1	TERICXCMHF@dell.com	6049066172	4	8860724361613394	2009/09	user28	password	63	100000	M
29	UAPQTU	HBWEEJLJQC	3449703700 Dell Way	\N	IWPCUTK	LA	45481	US	1	HBWEEJLJQC@dell.com	3449703700	3	1614113333169371	2012/06	user29	password	82	80000	F
30	MHFGOH	DTMMFWDHEA	2016678561 Dell Way	\N	XHVQREB	WI	79755	US	1	DTMMFWDHEA@dell.com	2016678561	5	2865310022607446	2012/07	user30	password	66	60000	M
31	XSKFVE	RIJNLQSLOA	4837704029 Dell Way	\N	GESLGQF	KY	56291	US	1	RIJNLQSLOA@dell.com	4837704029	2	1454196398146450	2008/10	user31	password	82	100000	M
32	HEJLWR	UKDLCPZCWE	1184575169 Dell Way	\N	UIKLNTZ	WI	17967	US	1	UKDLCPZCWE@dell.com	1184575169	1	9080948004499080	2012/01	user32	password	48	20000	F
33	UQBLKL	PVOFURBZMJ	1806894893 Dell Way	\N	JYXCXWE	VT	93580	US	1	PVOFURBZMJ@dell.com	1806894893	5	9715552329085768	2010/01	user33	password	31	40000	M
34	GTASJW	HORYQQLAZJ	7282866423 Dell Way	\N	YCGUHES	MA	10625	US	1	HORYQQLAZJ@dell.com	7282866423	5	1105126248672604	2012/03	user34	password	64	20000	M
35	RWHOEV	FCLWOLWXKY	4409192440 Dell Way	\N	EEGJXQJ	NJ	56565	US	1	FCLWOLWXKY@dell.com	4409192440	3	7246819562744350	2008/08	user35	password	63	80000	M
36	XGRSMU	EIIQEGADKF	3021789304 Dell Way	\N	KUDADTN	MT	32229	US	1	EIIQEGADKF@dell.com	3021789304	3	9073497921694072	2012/03	user36	password	48	80000	F
37	CMYWQG	FHLLHPWNZQ	5803405046 Dell Way	\N	QZUKNIQ	OR	87777	US	1	FHLLHPWNZQ@dell.com	5803405046	3	1896664091385901	2012/04	user37	password	60	20000	M
38	NYLUDS	GPAVMNUDEU	2906073166 Dell Way	\N	YOHGFAC	OR	65430	US	1	GPAVMNUDEU@dell.com	2906073166	4	9456843751948328	2011/09	user38	password	71	40000	M
39	ECUWIJ	WDWKYZOSXC	6284773018 Dell Way	\N	AEIAGAQ	MO	74187	US	1	WDWKYZOSXC@dell.com	6284773018	2	4912659454625100	2009/07	user39	password	23	60000	M
40	WIZGFD	CPBCDTZGTD	7725075074 Dell Way	\N	OUKPLXI	AL	24179	US	1	CPBCDTZGTD@dell.com	7725075074	2	7576088857371361	2012/10	user40	password	46	80000	F
41	JYINBY	ODBICICGXX	5021884093 Dell Way	\N	RMJOUKS	NC	76640	US	1	ODBICICGXX@dell.com	5021884093	2	6023778205737472	2012/01	user41	password	69	40000	F
42	BSBZHE	AQHJTNGQFT	7225708050 Dell Way	\N	ATNKMCD	WA	51342	US	1	AQHJTNGQFT@dell.com	7225708050	4	5741442908532918	2009/12	user42	password	56	60000	M
43	PKATLQ	AUKOBAUUAO	4599311991 Dell Way	\N	ILAKOYW	ID	74576	US	1	AUKOBAUUAO@dell.com	4599311991	4	7362957327160985	2012/02	user43	password	49	60000	F
44	LGYCHT	MWUNQPOEYZ	6118785825 Dell Way	\N	FINDFUW	NJ	49850	US	1	MWUNQPOEYZ@dell.com	6118785825	3	5789964983239770	2012/01	user44	password	20	60000	F
45	ZNPSZM	NNCDBHBAMK	3934871591 Dell Way	\N	OQPJMFU	AR	78641	US	1	NNCDBHBAMK@dell.com	3934871591	1	8396578761748970	2009/06	user45	password	28	40000	M
46	TBZFPM	ISOQTOCDDS	5928516639 Dell Way	\N	TMFZGGS	NH	38220	US	1	ISOQTOCDDS@dell.com	5928516639	5	8143781044054777	2011/04	user46	password	75	60000	F
47	URXHAP	VQJJTNNMGZ	1468092885 Dell Way	\N	RFGYYVG	MO	79543	US	1	VQJJTNNMGZ@dell.com	1468092885	1	1439432312734425	2012/08	user47	password	45	80000	F
48	HXIXSY	GCSTPEAPVF	5164479008 Dell Way	\N	VUEQBRK	CO	85154	US	1	GCSTPEAPVF@dell.com	5164479008	5	5145818285178393	2012/07	user48	password	73	20000	F
49	CAFAHI	TAYXBNTGIN	4483097562 Dell Way	\N	LZPCJRY	TX	65999	US	1	TAYXBNTGIN@dell.com	4483097562	4	2767849665600806	2008/10	user49	password	67	40000	M
50	XGCFAD	DXERQLZEWY	3309250755 Dell Way	\N	TYILWEB	ID	87593	US	1	DXERQLZEWY@dell.com	3309250755	3	7016217195894570	2012/08	user50	password	53	100000	M
51	PBXSEV	WWMHVQDUKC	8443500542 Dell Way	\N	DWZHXGE	DE	70302	US	1	WWMHVQDUKC@dell.com	8443500542	1	3863717397209257	2009/12	user51	password	35	100000	M
52	EPEZLA	LTVCXQNZTJ	3004564116 Dell Way	\N	ZBGGFLX	AL	57677	US	1	LTVCXQNZTJ@dell.com	3004564116	2	5146914470475167	2010/03	user52	password	49	80000	M
53	PPHQAA	MDYCQYVZXX	7102610410 Dell Way	\N	GDCRBDF	ID	52077	US	1	MDYCQYVZXX@dell.com	7102610410	4	7402909262105823	2008/05	user53	password	58	80000	M
54	WIZWUC	VXTTSTQPZU	1023603196 Dell Way	\N	SRVVXDH	NE	86106	US	1	VXTTSTQPZU@dell.com	1023603196	4	2668283766135573	2010/05	user54	password	26	60000	M
55	BHNECK	XVDQMTQHMH	3574669247 Dell Way	\N	DHFGOUC	NE	51427	US	1	XVDQMTQHMH@dell.com	3574669247	1	8774650241713972	2009/07	user55	password	61	60000	M
56	DQXOOT	REGLVOXDRF	4761523925 Dell Way	\N	IYUCBJO	KS	53642	US	1	REGLVOXDRF@dell.com	4761523925	4	1167002467904239	2008/03	user56	password	79	20000	M
57	TSKNJP	UVKITNAYWY	6110351941 Dell Way	\N	SYABMIO	VT	15705	US	1	UVKITNAYWY@dell.com	6110351941	5	3408206243067980	2010/01	user57	password	26	20000	M
58	NRECLZ	NUTBURXTJV	4833048217 Dell Way	\N	TLICZGE	ND	25277	US	1	NUTBURXTJV@dell.com	4833048217	5	3229167290963232	2010/02	user58	password	19	20000	M
59	EEGERB	XSWOPPYLJK	4842132323 Dell Way	\N	UMKAQZE	AR	94176	US	1	XSWOPPYLJK@dell.com	4842132323	3	1609264146536588	2010/08	user59	password	82	80000	M
60	DUNFRG	BGWRFHAPBM	9649127091 Dell Way	\N	ZBCYGEX	NY	77389	US	1	BGWRFHAPBM@dell.com	9649127091	1	4611537483520806	2012/09	user60	password	34	100000	M
61	TEFZGL	VXQCXGEKGG	8449346521 Dell Way	\N	NFNRCEL	AR	37621	US	1	VXQCXGEKGG@dell.com	8449346521	5	1476791314315050	2008/11	user61	password	60	80000	F
62	UTHGOF	WRDDWNJCBO	2219900888 Dell Way	\N	PSQUDRC	WV	61548	US	1	WRDDWNJCBO@dell.com	2219900888	1	5048757464159280	2011/10	user62	password	55	60000	M
63	VTDAQU	DTQRCTSRIL	1055097560 Dell Way	\N	HCPZFOO	KS	64664	US	1	DTQRCTSRIL@dell.com	1055097560	1	4810401593800634	2010/07	user63	password	90	40000	F
64	DJYXMR	OEUIWLRITU	5734550591 Dell Way	\N	XSZMHHC	IL	41518	US	1	OEUIWLRITU@dell.com	5734550591	5	9145867860410364	2010/02	user64	password	32	80000	M
65	DOAUDE	PLBACKUWHM	4563891355 Dell Way	\N	VUUDXBM	MI	89266	US	1	PLBACKUWHM@dell.com	4563891355	5	1298333559185266	2010/07	user65	password	57	80000	F
66	ONGTCS	UDVEXRMKNH	2559052903 Dell Way	\N	ERFGEQD	ND	62223	US	1	UDVEXRMKNH@dell.com	2559052903	1	2450195379555225	2011/11	user66	password	39	40000	F
67	OANHVR	CAOUMZIUEZ	4337782111 Dell Way	\N	ZLDQOSF	OR	87650	US	1	CAOUMZIUEZ@dell.com	4337782111	3	7699506011325867	2011/09	user67	password	29	40000	M
68	RNOIPO	XKBWSWASWL	2521982461 Dell Way	\N	WMAORTL	AZ	29353	US	1	XKBWSWASWL@dell.com	2521982461	4	9546184672508390	2009/12	user68	password	69	100000	F
69	GICVFN	XCFTCYPOUC	5621417868 Dell Way	\N	PIUJUVO	WA	61844	US	1	XCFTCYPOUC@dell.com	5621417868	2	5908201500773430	2009/04	user69	password	20	60000	M
70	DIUQFW	WYZUOOOQDX	4579724741 Dell Way	\N	LMRHBQW	ND	90023	US	1	WYZUOOOQDX@dell.com	4579724741	4	2270859372802078	2010/03	user70	password	69	60000	M
71	MFTJBS	IWHWKYZIJM	7151078438 Dell Way	\N	AQNQNCO	VA	86660	US	1	IWHWKYZIJM@dell.com	7151078438	2	1909482368268072	2009/11	user71	password	66	100000	F
72	LGDDOA	LLKJKTTXUK	5076143849 Dell Way	\N	KLXNZVJ	NV	22494	US	1	LLKJKTTXUK@dell.com	5076143849	1	1294616055209189	2008/12	user72	password	27	60000	F
73	HRTHDE	SNPLGMGRXR	5940442139 Dell Way	\N	OKQJTHN	GA	42285	US	1	SNPLGMGRXR@dell.com	5940442139	2	3680636959616095	2011/11	user73	password	52	100000	M
74	FGRJYE	YKLKQCIHRS	9144738893 Dell Way	\N	YAMGORP	CO	97924	US	1	YKLKQCIHRS@dell.com	9144738893	4	8466012486256660	2009/09	user74	password	45	60000	M
75	AYXFXH	QIYSQFJJEK	3559184079 Dell Way	\N	VKZMABL	WA	86608	US	1	QIYSQFJJEK@dell.com	3559184079	2	6260699358303100	2011/11	user75	password	58	80000	M
76	LXTTNB	RGSXQBBBWM	5843842130 Dell Way	\N	AJNCULY	CA	77025	US	1	RGSXQBBBWM@dell.com	5843842130	4	6731045445892960	2008/06	user76	password	53	60000	F
77	FIWHZC	ZXTBZUYMVH	8203956428 Dell Way	\N	ZYCKXEE	ME	91924	US	1	ZXTBZUYMVH@dell.com	8203956428	3	4091474133078009	2009/01	user77	password	67	60000	F
78	NUJQUH	KWGFUTABSZ	5901074984 Dell Way	\N	DDWHHHF	CA	83709	US	1	KWGFUTABSZ@dell.com	5901074984	2	9049576921388508	2009/11	user78	password	38	80000	M
79	RKMYUI	FZCYADRAHU	8947035148 Dell Way	\N	WOCETEZ	IN	60391	US	1	FZCYADRAHU@dell.com	8947035148	3	5019842551089823	2008/04	user79	password	27	100000	M
80	QULYZL	BYMFPMMKJA	7038885902 Dell Way	\N	MNURNCF	MD	66172	US	1	BYMFPMMKJA@dell.com	7038885902	3	9086241888813676	2012/05	user80	password	59	60000	F
81	AJEMKC	ZPSLCCVCPI	5684336516 Dell Way	\N	XGWZMGQ	DC	85073	US	1	ZPSLCCVCPI@dell.com	5684336516	5	3071253094356507	2008/05	user81	password	47	20000	M
82	OPEROU	KAWNVYDEWJ	4250067926 Dell Way	\N	AWWHMAD	WY	98473	US	1	KAWNVYDEWJ@dell.com	4250067926	1	4282251605298370	2011/03	user82	password	26	40000	M
83	HAJBLJ	XZEWCJSMJP	7328085613 Dell Way	\N	IRBJVBI	DE	23592	US	1	XZEWCJSMJP@dell.com	7328085613	5	4187984682153911	2012/04	user83	password	29	20000	F
84	NDTWBS	BYVKQHUGPM	8804140647 Dell Way	\N	HZHJHLN	AK	45455	US	1	BYVKQHUGPM@dell.com	8804140647	5	7080934641417117	2008/12	user84	password	90	60000	F
85	TKDMLB	HWSORYEDGE	9566648908 Dell Way	\N	LPMWCMH	WV	36979	US	1	HWSORYEDGE@dell.com	9566648908	5	2994280820246786	2012/07	user85	password	39	80000	M
86	KEKMMG	EAYCFBIJMY	8481905861 Dell Way	\N	VJAIQAP	NH	10347	US	1	EAYCFBIJMY@dell.com	8481905861	3	5738052499946207	2008/03	user86	password	50	60000	F
87	VAWCEX	AGDCPNPNJZ	1912388650 Dell Way	\N	ORQOHFO	CO	79369	US	1	AGDCPNPNJZ@dell.com	1912388650	2	1135459203738719	2010/10	user87	password	49	40000	M
88	IMYGNF	JPVWEIGDXX	7842002899 Dell Way	\N	TMEZBHT	DC	54656	US	1	JPVWEIGDXX@dell.com	7842002899	4	3349915018305182	2008/02	user88	password	20	60000	M
89	ZTBECR	ZZVIFZFDSR	3881306276 Dell Way	\N	HSTOLWB	GA	61593	US	1	ZZVIFZFDSR@dell.com	3881306276	2	6911563112400473	2009/11	user89	password	34	40000	M
90	HMTYMT	UVZTACMSJE	6012148553 Dell Way	\N	LYPIAUX	KS	27127	US	1	UVZTACMSJE@dell.com	6012148553	4	1807652772404253	2011/12	user90	password	71	20000	F
91	MAZFUU	ENVGZNQDZP	8338619980 Dell Way	\N	TIPNFXS	RI	61453	US	1	ENVGZNQDZP@dell.com	8338619980	3	6087300324812532	2010/08	user91	password	22	20000	M
92	BFKVKY	QQXEHBEWUM	5313838823 Dell Way	\N	LISIBMX	UT	12099	US	1	QQXEHBEWUM@dell.com	5313838823	3	6740367790218443	2010/06	user92	password	36	60000	M
93	RKAPBR	MGZOKVIXHR	7656402342 Dell Way	\N	PQSCNPC	AK	98954	US	1	MGZOKVIXHR@dell.com	7656402342	3	4691996377892792	2012/02	user93	password	21	80000	M
94	CGPUTV	THGPQDWHTM	1007417866 Dell Way	\N	AVAPYAP	NY	61905	US	1	THGPQDWHTM@dell.com	1007417866	4	7348126735538245	2008/05	user94	password	35	20000	M
95	VXIRRQ	XGHBCPUPPQ	9091236773 Dell Way	\N	PFOQUGF	SD	91490	US	1	XGHBCPUPPQ@dell.com	9091236773	5	3153780541848391	2008/01	user95	password	78	100000	M
96	EQPUNV	CPYRKNHACN	9652656132 Dell Way	\N	PSIVXDS	SD	97822	US	1	CPYRKNHACN@dell.com	9652656132	5	9816991902422160	2011/12	user96	password	83	100000	M
97	MTCIVR	GNBTVBWIQP	7278548154 Dell Way	\N	QMMTEHS	DC	32789	US	1	GNBTVBWIQP@dell.com	7278548154	5	2557797038927674	2010/11	user97	password	70	20000	M
98	UKMMQA	NKVPGDGVTS	1547526094 Dell Way	\N	INXQFBX	WA	99947	US	1	NKVPGDGVTS@dell.com	1547526094	3	9011170953046532	2011/08	user98	password	57	60000	F
99	ABRAPB	WEIZKETDNH	9885368844 Dell Way	\N	ADNCALC	CA	95338	US	1	WEIZKETDNH@dell.com	9885368844	5	6015513976104558	2010/06	user99	password	59	60000	M
100	FPCHLG	QLRUFUHMVL	9250484007 Dell Way	\N	ZYLKBNJ	AL	45808	US	1	QLRUFUHMVL@dell.com	9250484007	3	8659899443387986	2010/02	user100	password	44	80000	M
101	LADSQO	JKUESHADGZ	4081060163 Dell Way	\N	ORACABM	WI	63156	US	1	JKUESHADGZ@dell.com	4081060163	3	7210860711988062	2011/02	user101	password	45	20000	F
102	NWTCGE	WLWDLZKLNB	7874303452 Dell Way	\N	LQCMDBB	MN	52679	US	1	WLWDLZKLNB@dell.com	7874303452	1	6542575670871884	2008/04	user102	password	73	80000	F
103	NSKRPV	OTHNDSBFER	4941352913 Dell Way	\N	HQVJSHV	MO	49863	US	1	OTHNDSBFER@dell.com	4941352913	4	7841232322156430	2008/04	user103	password	86	80000	M
104	IKPEYI	MMMENRIFZZ	5599346700 Dell Way	\N	AISIDET	NE	82321	US	1	MMMENRIFZZ@dell.com	5599346700	4	1622023951262235	2010/06	user104	password	22	80000	M
105	QZWZLI	LPWCYBCYCK	7270570272 Dell Way	\N	QKOVEDQ	NY	92320	US	1	LPWCYBCYCK@dell.com	7270570272	1	4695855054073036	2011/11	user105	password	40	60000	M
106	EKHMVX	IYWKAUNLLY	5127891259 Dell Way	\N	ZGCDXUB	NH	90730	US	1	IYWKAUNLLY@dell.com	5127891259	2	8246030778624118	2011/10	user106	password	67	100000	F
107	ZKZXTY	TEZORKZQKG	2817086674 Dell Way	\N	SNDMPTK	AR	17360	US	1	TEZORKZQKG@dell.com	2817086674	5	8563901439309121	2012/09	user107	password	90	100000	F
108	ZTXXMC	WAUGAKRHDF	1721490290 Dell Way	\N	LQUEAVG	HI	68232	US	1	WAUGAKRHDF@dell.com	1721490290	1	4522647375240922	2008/12	user108	password	58	20000	M
109	MYEOUF	IBGSTNWYYM	6452446201 Dell Way	\N	TCMOJSF	ME	83040	US	1	IBGSTNWYYM@dell.com	6452446201	3	7893348607234658	2008/07	user109	password	51	80000	F
110	QEHWNI	DGCQCAPOTS	4109508464 Dell Way	\N	BIBTNMP	DC	98040	US	1	DGCQCAPOTS@dell.com	4109508464	2	5642515898682178	2012/12	user110	password	90	60000	F
111	GIQPLW	RCYSRNLJOU	4645878337 Dell Way	\N	LIIXXLX	ID	77448	US	1	RCYSRNLJOU@dell.com	4645878337	1	7074275085236878	2009/07	user111	password	75	80000	M
112	KHHGYJ	FRBSDKHXWQ	1754146260 Dell Way	\N	FTORQVK	AR	90684	US	1	FRBSDKHXWQ@dell.com	1754146260	3	4792518061585725	2012/02	user112	password	37	40000	F
113	ONJXTA	ZMDJUAGKGZ	2079674498 Dell Way	\N	ZXQUHSS	MA	24662	US	1	ZMDJUAGKGZ@dell.com	2079674498	2	3534821788780391	2009/07	user113	password	67	100000	F
114	AWUAVH	EFBFLMLLLI	3189182691 Dell Way	\N	CGQUYAZ	AZ	36056	US	1	EFBFLMLLLI@dell.com	3189182691	3	8334010239224882	2012/05	user114	password	81	100000	F
115	RZCYDH	ZISMUEXDGE	9050788475 Dell Way	\N	TBCUAEC	ID	66758	US	1	ZISMUEXDGE@dell.com	9050788475	1	1235684926621615	2011/02	user115	password	38	60000	F
116	JKGQKO	JWJNTMUYFV	8858951903 Dell Way	\N	BAWFCCW	WY	35427	US	1	JWJNTMUYFV@dell.com	8858951903	4	4559770044870675	2008/03	user116	password	53	60000	M
117	SEZHNV	QBPCVNIROJ	3862314451 Dell Way	\N	NULQQLX	MS	28694	US	1	QBPCVNIROJ@dell.com	3862314451	4	4628714819438756	2012/03	user117	password	89	60000	F
118	YUWULX	JOTWXLLHZF	8102950769 Dell Way	\N	SPVENIK	TN	99033	US	1	JOTWXLLHZF@dell.com	8102950769	4	2408726370427757	2011/02	user118	password	53	80000	M
119	IMKGWZ	ZTXLEEKKXZ	7448935926 Dell Way	\N	GBNOLJO	IA	10295	US	1	ZTXLEEKKXZ@dell.com	7448935926	1	2482879911083728	2008/09	user119	password	27	60000	F
120	OUCOUV	LFAPPKNPQO	6595474595 Dell Way	\N	CFALUHL	MO	37519	US	1	LFAPPKNPQO@dell.com	6595474595	4	1476338486187160	2011/03	user120	password	39	40000	M
121	KWTFHZ	GXOQKDHZFM	6798147794 Dell Way	\N	ARGHDTP	PA	49164	US	1	GXOQKDHZFM@dell.com	6798147794	3	6879583658184857	2012/10	user121	password	65	40000	M
122	KOZJVW	YLGBTFHGFZ	4065978990 Dell Way	\N	NNDGCWR	OR	45437	US	1	YLGBTFHGFZ@dell.com	4065978990	4	2960724868346006	2012/01	user122	password	83	60000	M
123	WUKSSW	YUPECVKBIX	7123033009 Dell Way	\N	EPZBGTM	NJ	47412	US	1	YUPECVKBIX@dell.com	7123033009	3	4887257677968592	2010/01	user123	password	19	60000	M
124	KDNGCI	VGKRRMZORP	2220276636 Dell Way	\N	OTWHFLS	UT	14819	US	1	VGKRRMZORP@dell.com	2220276636	3	1511949831619858	2008/11	user124	password	79	60000	F
125	JVCRQJ	CIAOIPFXDY	3776657381 Dell Way	\N	TLDFDAG	ID	53111	US	1	CIAOIPFXDY@dell.com	3776657381	3	4190435957163572	2008/12	user125	password	44	60000	M
126	MFLVHT	WVBLBZPASA	1160092385 Dell Way	\N	EXDEEKR	MN	84486	US	1	WVBLBZPASA@dell.com	1160092385	4	8194721666630358	2009/02	user126	password	60	100000	F
127	ARPTOL	VZMUPMMPQK	8003738523 Dell Way	\N	TVODMAZ	MT	68240	US	1	VZMUPMMPQK@dell.com	8003738523	5	8104929108172656	2009/09	user127	password	27	40000	F
128	TDZEYZ	RTOEGDVRWQ	7115704372 Dell Way	\N	FADGAQX	SC	58787	US	1	RTOEGDVRWQ@dell.com	7115704372	1	3566918413620442	2012/07	user128	password	69	60000	M
129	RSPQKJ	EOPIJGFAMG	6569254887 Dell Way	\N	DSGUPAI	IL	25921	US	1	EOPIJGFAMG@dell.com	6569254887	1	7207910898141564	2009/08	user129	password	42	20000	F
130	YRUHWI	XESDJSQQWJ	7879493371 Dell Way	\N	WQZXZGB	NH	42082	US	1	XESDJSQQWJ@dell.com	7879493371	5	1020454077515751	2008/12	user130	password	45	20000	M
131	DILMFQ	EJAXZQTJMJ	9370650948 Dell Way	\N	IJJOLYY	HI	89715	US	1	EJAXZQTJMJ@dell.com	9370650948	2	8417101474478842	2009/05	user131	password	48	60000	M
132	WYWMCG	MZFCTOPDXZ	2364824409 Dell Way	\N	MLLLKQI	KS	97547	US	1	MZFCTOPDXZ@dell.com	2364824409	4	3896020112093538	2010/01	user132	password	90	60000	F
133	WXDCKC	IMWXCZUBLG	4938118819 Dell Way	\N	MXQDFYD	MA	61179	US	1	IMWXCZUBLG@dell.com	4938118819	5	6804848136845977	2010/05	user133	password	65	40000	F
134	UJRXSE	TPHSJIEQVB	4649670859 Dell Way	\N	GZHECRT	MT	64118	US	1	TPHSJIEQVB@dell.com	4649670859	5	9834340581204744	2008/03	user134	password	38	100000	M
135	ZSHELX	LEHTIXPJDO	9021567530 Dell Way	\N	QIQICEX	MS	19756	US	1	LEHTIXPJDO@dell.com	9021567530	3	4042470287531614	2008/05	user135	password	87	20000	F
136	GHODSS	LMAICKLQBU	9031787945 Dell Way	\N	HJWLGJO	DE	93829	US	1	LMAICKLQBU@dell.com	9031787945	2	3841774760745466	2012/06	user136	password	48	20000	M
137	ZGMRRZ	RZBCLRDFZM	7600041415 Dell Way	\N	CKTMZXK	TX	31046	US	1	RZBCLRDFZM@dell.com	7600041415	4	7242152146063746	2008/10	user137	password	50	20000	F
138	XUSWLR	YODPRJPEMA	7706483551 Dell Way	\N	XYZVJVB	CO	57975	US	1	YODPRJPEMA@dell.com	7706483551	2	3907713198103011	2008/05	user138	password	43	20000	F
139	BZPTXD	WNVFDZRDWQ	8008482630 Dell Way	\N	CSZXTCL	MO	41216	US	1	WNVFDZRDWQ@dell.com	8008482630	4	7346554525196553	2008/10	user139	password	79	20000	M
140	LXSOUG	JZJIRMFHOX	4891437624 Dell Way	\N	HMRJYDS	OK	84489	US	1	JZJIRMFHOX@dell.com	4891437624	5	6533029990736396	2009/01	user140	password	46	80000	M
141	CHSIQS	RZJDFQSDYE	4451610678 Dell Way	\N	UIDYBVT	MO	71554	US	1	RZJDFQSDYE@dell.com	4451610678	4	7439413087442518	2011/06	user141	password	66	100000	M
142	JEJCWJ	LZPCSSAWNI	3047343803 Dell Way	\N	ZLJVFWN	NJ	63033	US	1	LZPCSSAWNI@dell.com	3047343803	2	1315480657387524	2012/04	user142	password	73	40000	F
143	DJHMUH	CXZVXWIGVU	1903096573 Dell Way	\N	QRAMEQB	ME	12305	US	1	CXZVXWIGVU@dell.com	1903096573	2	3506011716555804	2012/07	user143	password	70	100000	M
144	AMSHOQ	HKNDSUZNKQ	5440590231 Dell Way	\N	OXVEYGF	AR	59430	US	1	HKNDSUZNKQ@dell.com	5440590231	5	2107666220050305	2009/11	user144	password	21	40000	F
145	UNYKUI	YXBSWPDNDA	3522341788 Dell Way	\N	JIZPOAE	AR	95317	US	1	YXBSWPDNDA@dell.com	3522341788	2	8590224726591260	2009/06	user145	password	34	20000	M
146	EMUNLR	PDOFHCJHLR	1861340140 Dell Way	\N	GBGHFHG	MS	60245	US	1	PDOFHCJHLR@dell.com	1861340140	5	1319741338025778	2009/12	user146	password	19	60000	F
147	UAWMPA	BUHDDOPVVR	9813855180 Dell Way	\N	CDXKKKY	MS	31000	US	1	BUHDDOPVVR@dell.com	9813855180	5	2573778084479272	2008/04	user147	password	62	100000	F
148	MHXMIS	UMWICSETUI	5060410082 Dell Way	\N	QESBDFH	CO	11100	US	1	UMWICSETUI@dell.com	5060410082	1	3798310699407011	2008/11	user148	password	63	60000	F
149	NBNGVZ	CEBVIVPQMU	9064342289 Dell Way	\N	JNXOUAP	IA	19326	US	1	CEBVIVPQMU@dell.com	9064342289	2	1060866510029882	2010/11	user149	password	32	20000	M
150	SHSSKW	UGFPVWBQFO	6713663457 Dell Way	\N	NUJNJPQ	IL	89840	US	1	UGFPVWBQFO@dell.com	6713663457	4	7678243461530656	2012/11	user150	password	64	60000	F
151	JGOFAU	LPQHQGNFUI	7969281022 Dell Way	\N	OHSDYZA	ND	79849	US	1	LPQHQGNFUI@dell.com	7969281022	2	6614301770459861	2010/12	user151	password	74	80000	F
152	IAEDLT	TSKAGQUOEC	6712504583 Dell Way	\N	GIAGJPA	CT	97902	US	1	TSKAGQUOEC@dell.com	6712504583	3	9115279169287532	2010/04	user152	password	22	80000	F
153	FWTZQM	JQSZLHENNM	1207147861 Dell Way	\N	OTWDUZD	MD	57064	US	1	JQSZLHENNM@dell.com	1207147861	5	8568743811454625	2008/07	user153	password	29	40000	F
154	XHBKRS	CQEJVSXIGR	5570075807 Dell Way	\N	EKLDNVR	NC	69460	US	1	CQEJVSXIGR@dell.com	5570075807	4	2965509313158691	2011/12	user154	password	65	60000	F
155	SZWLBN	PLIHJROAVY	2624904403 Dell Way	\N	LZMHQAZ	DC	67409	US	1	PLIHJROAVY@dell.com	2624904403	5	6121233948506415	2012/05	user155	password	74	60000	F
156	QZLEOW	NWGEKGZJSZ	1288064537 Dell Way	\N	VAPVZTM	DC	60252	US	1	NWGEKGZJSZ@dell.com	1288064537	5	9553356157615782	2012/07	user156	password	40	60000	M
157	TQBQDY	WHICHRVGMV	2061304593 Dell Way	\N	WIUPUYE	SD	92565	US	1	WHICHRVGMV@dell.com	2061304593	4	4973234752193093	2010/02	user157	password	86	20000	M
158	AUVYQD	HTLYOSLKOU	5235986700 Dell Way	\N	EEOCIJA	MN	99500	US	1	HTLYOSLKOU@dell.com	5235986700	5	1709392597433179	2010/01	user158	password	75	60000	M
159	QJNUQG	FPVXBFMVJQ	8270375752 Dell Way	\N	JMZTNLS	WY	40268	US	1	FPVXBFMVJQ@dell.com	8270375752	3	4545490718446672	2010/11	user159	password	35	40000	F
160	TZVAFL	VDMAPHKGRX	4736229063 Dell Way	\N	GKLRDLA	WA	85709	US	1	VDMAPHKGRX@dell.com	4736229063	3	7071166023612023	2011/09	user160	password	81	60000	M
161	SKYDGB	QHRXRXPPDZ	9937922485 Dell Way	\N	BVCMWAI	ID	60078	US	1	QHRXRXPPDZ@dell.com	9937922485	5	3754587507341057	2012/05	user161	password	21	60000	M
162	ATZBJG	THYQWOUVPQ	8539709012 Dell Way	\N	YBMZKTN	MA	70518	US	1	THYQWOUVPQ@dell.com	8539709012	2	1063123161438852	2012/11	user162	password	72	100000	M
163	TZYZSF	YJCMDYBUWD	7051157108 Dell Way	\N	GWNZJXR	HI	25077	US	1	YJCMDYBUWD@dell.com	7051157108	1	1011314923875033	2010/01	user163	password	59	20000	M
164	MDRSBA	UOETQYPTEL	4485849114 Dell Way	\N	HEVFVBK	MT	25714	US	1	UOETQYPTEL@dell.com	4485849114	5	2577017887029797	2012/02	user164	password	28	60000	F
165	UEHVZW	ZSMXIGCUOH	1355972789 Dell Way	\N	QTCRDQW	NC	60279	US	1	ZSMXIGCUOH@dell.com	1355972789	3	6849177487194539	2008/12	user165	password	82	100000	F
166	EVCAUU	NSDTVXHCNB	1234921125 Dell Way	\N	FFFVCTJ	CT	32046	US	1	NSDTVXHCNB@dell.com	1234921125	2	2738955661188811	2012/04	user166	password	40	20000	F
167	KDXFQP	IKKGSMTURZ	2577301920 Dell Way	\N	ZNBTWEZ	VT	53841	US	1	IKKGSMTURZ@dell.com	2577301920	5	7954928710591049	2010/11	user167	password	81	100000	F
168	TCRJLC	TRUGLOYLOL	9521375513 Dell Way	\N	NHIRGFE	MI	12756	US	1	TRUGLOYLOL@dell.com	9521375513	5	9429098135326060	2012/10	user168	password	89	60000	M
169	RXJTRB	NYNCWYQHLX	8166259560 Dell Way	\N	PDEVIPW	ID	58146	US	1	NYNCWYQHLX@dell.com	8166259560	1	4229035379830748	2011/08	user169	password	39	60000	M
170	REGTSE	GUAFKIRIYU	9938818816 Dell Way	\N	MTCCQJQ	ME	49451	US	1	GUAFKIRIYU@dell.com	9938818816	1	1698986183851957	2009/08	user170	password	64	100000	M
171	WSMAYG	BERJVZIPMB	6383758055 Dell Way	\N	SOSCFCN	GA	36927	US	1	BERJVZIPMB@dell.com	6383758055	3	9211614733561874	2009/06	user171	password	68	20000	F
172	EDCKFG	CPBBXROZKC	9827637124 Dell Way	\N	RMIUZNB	NH	10719	US	1	CPBBXROZKC@dell.com	9827637124	5	5090842019300908	2011/12	user172	password	61	100000	F
173	SGHYIW	AKTSYSCBJO	4240752714 Dell Way	\N	JDOXFEX	DE	99123	US	1	AKTSYSCBJO@dell.com	4240752714	5	9316775482147932	2012/09	user173	password	90	80000	M
174	GPHCQR	WIQOKRXZBA	6616090950 Dell Way	\N	OYFSWKS	HI	32573	US	1	WIQOKRXZBA@dell.com	6616090950	1	9422093743458392	2011/11	user174	password	82	100000	F
175	EABVWK	MKUDIUFIIE	2453803311 Dell Way	\N	OBAZTGF	LA	49960	US	1	MKUDIUFIIE@dell.com	2453803311	5	3537283960264176	2008/11	user175	password	70	20000	M
176	UATEND	ZRLUWUCBJD	1612266074 Dell Way	\N	CIXIOGU	OK	32358	US	1	ZRLUWUCBJD@dell.com	1612266074	4	2124531744979322	2011/12	user176	password	18	60000	M
177	TTMWTE	INACQBMUEU	3690125030 Dell Way	\N	RMJYHCE	KY	87228	US	1	INACQBMUEU@dell.com	3690125030	1	8344086087308825	2009/09	user177	password	77	20000	F
178	IXGMFT	MIKOUESPVF	7778050487 Dell Way	\N	ZTMCYWY	HI	99138	US	1	MIKOUESPVF@dell.com	7778050487	3	7467364052310587	2010/07	user178	password	33	100000	F
179	LISFVB	QKWUCLPILJ	4419226889 Dell Way	\N	VNHRLNR	GA	15976	US	1	QKWUCLPILJ@dell.com	4419226889	4	6736056394875050	2010/08	user179	password	26	20000	M
180	VHVWXF	SRIEHQQRMD	2864315572 Dell Way	\N	ZDPNUVO	FL	63957	US	1	SRIEHQQRMD@dell.com	2864315572	4	3229760578833520	2009/10	user180	password	34	20000	F
181	BAZGTR	OXZFNQRRPU	9615864405 Dell Way	\N	HCPCRUS	UT	59176	US	1	OXZFNQRRPU@dell.com	9615864405	2	4315120882354677	2008/05	user181	password	52	40000	F
182	MMCDAA	CGOTXGISNL	9977305070 Dell Way	\N	HQCCIZQ	IN	28214	US	1	CGOTXGISNL@dell.com	9977305070	3	6033942591864616	2010/09	user182	password	86	100000	F
183	BBFBEM	PXJWFCJRKZ	5815056834 Dell Way	\N	UMIUCQZ	CA	20953	US	1	PXJWFCJRKZ@dell.com	5815056834	3	8543319231830538	2010/06	user183	password	20	60000	M
184	GOSSEP	CAVEKMOKGA	4027881849 Dell Way	\N	TBDJAFM	ND	80573	US	1	CAVEKMOKGA@dell.com	4027881849	1	3435135567095131	2009/07	user184	password	77	80000	F
185	NJHDLI	YQTLFDSFWT	6721374519 Dell Way	\N	JGTPTIJ	CA	40114	US	1	YQTLFDSFWT@dell.com	6721374519	3	8799941331148148	2010/01	user185	password	88	100000	F
186	GCXPBN	IMSMFYIYHP	2990152133 Dell Way	\N	SWJAGLJ	UT	90374	US	1	IMSMFYIYHP@dell.com	2990152133	2	9778463285882028	2008/04	user186	password	48	60000	F
187	HBMVKY	NWDMFCUUUR	5063134523 Dell Way	\N	DVXPEUM	MD	21340	US	1	NWDMFCUUUR@dell.com	5063134523	3	4950456544756890	2012/01	user187	password	80	20000	F
188	IZMHNJ	LAONUIILMD	7440923984 Dell Way	\N	JBIDOSH	WY	37322	US	1	LAONUIILMD@dell.com	7440923984	5	4178096932359040	2010/01	user188	password	51	100000	F
189	YENHPO	WDIELURPDT	3449626268 Dell Way	\N	XHHQOHX	IL	24443	US	1	WDIELURPDT@dell.com	3449626268	5	2682829477824271	2011/09	user189	password	32	80000	M
190	TZNHVQ	PABKSQOLOV	4651647065 Dell Way	\N	TEKBCRF	KY	58823	US	1	PABKSQOLOV@dell.com	4651647065	1	3582177852746099	2011/10	user190	password	32	40000	M
191	SQPIGQ	JQIAEUOAOS	9312927970 Dell Way	\N	KPUCVDQ	HI	30690	US	1	JQIAEUOAOS@dell.com	9312927970	5	9968570222612472	2008/03	user191	password	72	100000	M
192	IDBYNR	HNWBCWQVGF	9945151528 Dell Way	\N	QJBTZHZ	VT	20452	US	1	HNWBCWQVGF@dell.com	9945151528	1	3657055824529380	2011/11	user192	password	25	20000	M
193	DBNVIB	RKDNAZUGPD	9899340102 Dell Way	\N	HJDPJBS	KY	17662	US	1	RKDNAZUGPD@dell.com	9899340102	1	9476211321074516	2008/03	user193	password	86	40000	F
194	LBOMSY	QGZQAFFENO	4313723413 Dell Way	\N	HCXIUGL	RI	41702	US	1	QGZQAFFENO@dell.com	4313723413	5	5750362674240023	2009/02	user194	password	72	80000	F
195	HGWGXC	FNCLSHYHOA	4104551268 Dell Way	\N	FXVMIPV	OH	50286	US	1	FNCLSHYHOA@dell.com	4104551268	1	5839422373566777	2008/10	user195	password	67	40000	F
196	NQXPVL	SGEZFLOFRL	6541135995 Dell Way	\N	BDUQYMC	IL	54277	US	1	SGEZFLOFRL@dell.com	6541135995	2	3270581658463925	2009/10	user196	password	37	100000	F
197	ELFQEM	UDRGSXYEZB	2696203470 Dell Way	\N	YPALRHY	IL	71710	US	1	UDRGSXYEZB@dell.com	2696203470	3	5081255959346891	2010/05	user197	password	79	80000	M
198	BHZOCD	GJVEHADJZT	8223866562 Dell Way	\N	JKKRIRJ	NC	34094	US	1	GJVEHADJZT@dell.com	8223866562	5	6962987584527583	2011/08	user198	password	53	80000	M
199	MHAPOJ	LSQLWAKPJV	6475307981 Dell Way	\N	ZAERJSY	FL	71865	US	1	LSQLWAKPJV@dell.com	6475307981	5	3916127920616418	2008/07	user199	password	35	60000	M
200	GEJPQC	GCYGMOQINQ	2739437763 Dell Way	\N	MFAEDFW	PA	12572	US	1	GCYGMOQINQ@dell.com	2739437763	5	6217044524848462	2010/06	user200	password	48	80000	M
201	UHFXOI	WVUKLDYCPD	9292288565 Dell Way	\N	CUHIQBI	TX	91453	US	1	WVUKLDYCPD@dell.com	9292288565	2	4009823579341173	2009/12	user201	password	86	20000	F
202	EBVMXQ	HHBKFEAJGU	9389964211 Dell Way	\N	QPLSXHP	TN	60828	US	1	HHBKFEAJGU@dell.com	9389964211	1	5774560738354922	2012/04	user202	password	75	20000	F
203	PNHGUP	HFULFESZVH	8229181451 Dell Way	\N	LNFSCBH	AL	32047	US	1	HFULFESZVH@dell.com	8229181451	5	6141538870055229	2010/12	user203	password	86	20000	F
204	FLHUTM	PERTXRPFCC	3734459121 Dell Way	\N	LVEMCFT	VA	22085	US	1	PERTXRPFCC@dell.com	3734459121	3	1788752209395170	2009/09	user204	password	59	60000	F
205	WGVIWA	AQYSFDUHOP	9479539791 Dell Way	\N	MBSSUPW	CA	15183	US	1	AQYSFDUHOP@dell.com	9479539791	2	7613272601738573	2010/10	user205	password	79	40000	F
206	RRYSSO	QKUUFCIVPJ	8896107254 Dell Way	\N	NHECEGD	CO	62598	US	1	QKUUFCIVPJ@dell.com	8896107254	4	4463152668438852	2011/12	user206	password	50	60000	M
207	JCJYTT	TNZVWUKGHS	6620438987 Dell Way	\N	KJWRNZG	MA	62527	US	1	TNZVWUKGHS@dell.com	6620438987	1	5915406333282590	2008/07	user207	password	32	60000	M
208	OKJIDX	HZTBJZICJS	1608915044 Dell Way	\N	ZAFYHQN	VT	75419	US	1	HZTBJZICJS@dell.com	1608915044	5	3160989703610539	2009/06	user208	password	80	100000	M
209	FDZDKY	WLIVUKFNJG	3792013392 Dell Way	\N	SINIVLB	VA	47264	US	1	WLIVUKFNJG@dell.com	3792013392	1	8617610038723797	2008/12	user209	password	67	60000	F
210	RNMPJY	YFTILGSRZA	9294354440 Dell Way	\N	FHVRJTB	OH	91125	US	1	YFTILGSRZA@dell.com	9294354440	5	8862436947878451	2011/04	user210	password	88	40000	M
211	LWEKUJ	DDUJVMIWSQ	2891817942 Dell Way	\N	SJALLSI	LA	60840	US	1	DDUJVMIWSQ@dell.com	2891817942	5	8434869633987547	2008/03	user211	password	62	80000	F
212	TAXDEB	YOXKWTDNLM	6715788093 Dell Way	\N	OWYGFIV	ME	35406	US	1	YOXKWTDNLM@dell.com	6715788093	3	5721002531237901	2009/03	user212	password	64	20000	F
213	ODLPBZ	MMWGPKRCYN	2254211018 Dell Way	\N	AETIZEP	NJ	77374	US	1	MMWGPKRCYN@dell.com	2254211018	5	9806594968773426	2011/11	user213	password	36	40000	M
214	RYARLN	NRCXJEWXFA	5600068507 Dell Way	\N	QNZUDPN	IL	50786	US	1	NRCXJEWXFA@dell.com	5600068507	1	3759584844112396	2011/05	user214	password	39	60000	F
215	IDUVRM	YPVCLSILJV	8129480423 Dell Way	\N	LDZARHM	FL	41801	US	1	YPVCLSILJV@dell.com	8129480423	5	7870392904616893	2008/05	user215	password	26	60000	M
216	YGEKET	GHEZPPILBM	8348967875 Dell Way	\N	KCDSOIB	LA	32561	US	1	GHEZPPILBM@dell.com	8348967875	3	6714487021323294	2012/11	user216	password	28	100000	F
217	HHGBNN	FNCVVNWHYY	6630870131 Dell Way	\N	LQNTSWZ	MT	38083	US	1	FNCVVNWHYY@dell.com	6630870131	3	2411882798187434	2011/04	user217	password	35	20000	M
218	MCDAIQ	DELQBTPAEG	8816522961 Dell Way	\N	NYYKXLS	NC	90322	US	1	DELQBTPAEG@dell.com	8816522961	2	2886030686553567	2008/05	user218	password	76	80000	F
219	YQVOTZ	AJAUZBYFOW	7071810956 Dell Way	\N	DZUORIM	NC	67869	US	1	AJAUZBYFOW@dell.com	7071810956	4	1136976864654570	2010/04	user219	password	54	60000	M
220	IZPIZZ	JUZKTEYQHX	4715606254 Dell Way	\N	KWPTIDK	AK	82093	US	1	JUZKTEYQHX@dell.com	4715606254	3	1535790319554507	2012/11	user220	password	86	40000	M
221	OOWOXQ	NHJSGZZEKW	8024583176 Dell Way	\N	UEFXOGS	WV	76164	US	1	NHJSGZZEKW@dell.com	8024583176	5	6799417681992055	2011/02	user221	password	56	40000	M
222	KVPBIW	LADLAHVXCA	7707627258 Dell Way	\N	DAPJSOC	MS	51144	US	1	LADLAHVXCA@dell.com	7707627258	2	6317456409800798	2009/06	user222	password	38	80000	F
223	WSQTDR	WPSELQGLTG	6681761544 Dell Way	\N	ADZPFMB	WV	74144	US	1	WPSELQGLTG@dell.com	6681761544	2	2820148667786270	2012/11	user223	password	55	80000	M
224	ENUVKJ	OOUEVFYCGB	5551250048 Dell Way	\N	CVGPWFH	MS	50947	US	1	OOUEVFYCGB@dell.com	5551250048	3	4249738764483482	2008/03	user224	password	90	20000	M
225	UACDOR	XTNDRQKSSF	1099968377 Dell Way	\N	ZHCFPPQ	CO	11112	US	1	XTNDRQKSSF@dell.com	1099968377	1	2746653990820050	2008/04	user225	password	83	80000	F
226	ZXXQVQ	DZITJAMPAU	5399641553 Dell Way	\N	RFKHVNH	TX	67610	US	1	DZITJAMPAU@dell.com	5399641553	5	9522778161801400	2009/08	user226	password	37	40000	M
227	EAIUEI	DYRDKGDFYI	7172292935 Dell Way	\N	PFECNBT	WY	90665	US	1	DYRDKGDFYI@dell.com	7172292935	2	5701220414135606	2012/09	user227	password	21	20000	M
228	KYXSBV	JEGQILORAT	3775013622 Dell Way	\N	WCHXWHU	NC	68429	US	1	JEGQILORAT@dell.com	3775013622	3	4475123568437994	2009/08	user228	password	27	80000	M
229	ALPWVT	CLCNZTNTPQ	4128732778 Dell Way	\N	BNMIHAY	NH	56647	US	1	CLCNZTNTPQ@dell.com	4128732778	5	2197880040388554	2010/09	user229	password	67	60000	F
230	GJZALL	CYLWMFMCGZ	3326815737 Dell Way	\N	POHPNWD	TX	83829	US	1	CYLWMFMCGZ@dell.com	3326815737	2	5715942581649870	2012/11	user230	password	67	20000	F
231	RFQCIO	NFASRDZRSN	2425690554 Dell Way	\N	YIAVLXQ	OH	29790	US	1	NFASRDZRSN@dell.com	2425690554	4	1508830762002617	2012/10	user231	password	35	60000	F
232	WPILDO	MWFPVXHJVP	5860990967 Dell Way	\N	JRBGHTM	MN	43816	US	1	MWFPVXHJVP@dell.com	5860990967	2	2722737114410847	2011/10	user232	password	33	80000	F
233	OCOCOL	IDGFLPBBZT	4646948505 Dell Way	\N	CGAVTMF	IL	79997	US	1	IDGFLPBBZT@dell.com	4646948505	1	6232737744227052	2011/09	user233	password	90	20000	M
234	OHJZPN	GVYVXZVQCC	5718193571 Dell Way	\N	RXVEDCY	NC	24319	US	1	GVYVXZVQCC@dell.com	5718193571	1	8901934914756567	2010/04	user234	password	68	20000	M
235	BBFOHB	NCZMYQOAIM	9853886479 Dell Way	\N	WMQYKEC	WI	37824	US	1	NCZMYQOAIM@dell.com	9853886479	3	6780904320999981	2011/07	user235	password	36	80000	M
236	MHVNUY	NHXDWYLIUY	1565292418 Dell Way	\N	YSICVHK	SD	76908	US	1	NHXDWYLIUY@dell.com	1565292418	3	3436183401383460	2009/03	user236	password	79	80000	M
237	RIHQWO	NZLLLTGJSY	1059322345 Dell Way	\N	SVUZGPT	KS	17902	US	1	NZLLLTGJSY@dell.com	1059322345	4	3707163629587740	2012/06	user237	password	76	60000	M
238	CDPRRP	CDBWJKPIDK	1863348993 Dell Way	\N	CCRSWZU	TX	67106	US	1	CDBWJKPIDK@dell.com	1863348993	4	1597759217489510	2012/03	user238	password	78	100000	F
239	LRBBTE	CQNNFWQQYT	1035903769 Dell Way	\N	HRPHMLY	ND	22996	US	1	CQNNFWQQYT@dell.com	1035903769	3	4281205979641527	2012/06	user239	password	71	40000	F
240	UIWYLM	MYRIOIHHPZ	8532190868 Dell Way	\N	WXLIWZM	TX	50462	US	1	MYRIOIHHPZ@dell.com	8532190868	4	9071420274209232	2010/12	user240	password	18	40000	F
241	WHSIUR	ADFILNYKKW	2585578940 Dell Way	\N	VSSVEPH	AL	34847	US	1	ADFILNYKKW@dell.com	2585578940	3	3266492069233209	2008/12	user241	password	58	20000	F
242	HKAYKE	ETPRSZBOVU	4533164555 Dell Way	\N	HRZWYZD	CT	63213	US	1	ETPRSZBOVU@dell.com	4533164555	2	5839909839909524	2012/05	user242	password	75	40000	M
243	VEDZIW	OZPOBDKVLB	9216089902 Dell Way	\N	UHAULDJ	SD	47729	US	1	OZPOBDKVLB@dell.com	9216089902	4	7840317948721350	2011/01	user243	password	53	60000	F
244	QMNNBN	CQOFAKRCEY	4593760254 Dell Way	\N	CZJFJFQ	ID	97140	US	1	CQOFAKRCEY@dell.com	4593760254	5	9782808824907988	2012/06	user244	password	29	60000	M
245	RAAFCR	UIREZUJYWI	5091884392 Dell Way	\N	ICRNTYM	DC	92098	US	1	UIREZUJYWI@dell.com	5091884392	1	4461169376038015	2011/07	user245	password	43	40000	M
246	JNRAHA	SLANVYKEGM	1953241795 Dell Way	\N	WUGVGJS	OK	45758	US	1	SLANVYKEGM@dell.com	1953241795	2	9423395997844636	2010/08	user246	password	54	100000	F
247	EWKEPW	FCSDMWKZSE	9178639777 Dell Way	\N	FNLOGEZ	LA	53760	US	1	FCSDMWKZSE@dell.com	9178639777	5	2033070211298763	2010/08	user247	password	36	60000	M
248	RTCNYE	FCRCNQVSWI	9242159193 Dell Way	\N	ELPIKYU	IN	77168	US	1	FCRCNQVSWI@dell.com	9242159193	4	4464414094574750	2008/04	user248	password	82	100000	F
249	ZJZEPC	VRQMMIIVMT	5333657757 Dell Way	\N	KUDJPLC	MT	25089	US	1	VRQMMIIVMT@dell.com	5333657757	4	5085826066322625	2009/07	user249	password	54	40000	M
250	MNLPJD	FVQOELAXWV	2265148245 Dell Way	\N	BFLNIYR	SC	65884	US	1	FVQOELAXWV@dell.com	2265148245	1	2131060719490051	2011/07	user250	password	90	20000	F
251	LTJPYF	FNJRNHOJIT	5319693184 Dell Way	\N	UWCTOXJ	OH	14869	US	1	FNJRNHOJIT@dell.com	5319693184	2	6145804445724935	2010/06	user251	password	62	100000	F
252	ZNEFSR	OKFWYOFSJB	3726352094 Dell Way	\N	UCPRLHT	WA	67533	US	1	OKFWYOFSJB@dell.com	3726352094	3	1990017764270305	2012/04	user252	password	41	100000	M
253	MCOERY	JNWYSPIUJK	4994618101 Dell Way	\N	KBWSUUI	CA	28395	US	1	JNWYSPIUJK@dell.com	4994618101	5	5730263859499246	2011/11	user253	password	43	40000	M
254	XKQVUD	STWHBQRMAS	8840514968 Dell Way	\N	ISMDAOI	MO	60334	US	1	STWHBQRMAS@dell.com	8840514968	2	4976068728137762	2009/07	user254	password	48	20000	M
255	BYSEQL	AXNROZRHIJ	3996292216 Dell Way	\N	TMKIVXX	OH	22516	US	1	AXNROZRHIJ@dell.com	3996292216	5	6752039397601039	2011/01	user255	password	58	80000	M
256	HZPSAN	GRCFIJOSDA	8146984087 Dell Way	\N	DMVAJNE	OH	49564	US	1	GRCFIJOSDA@dell.com	8146984087	3	5128881895449013	2009/03	user256	password	48	80000	F
257	AJFNPX	QVFZJYDKBP	7152320561 Dell Way	\N	GCYUGQF	AL	15207	US	1	QVFZJYDKBP@dell.com	7152320561	2	3552331936545670	2008/01	user257	password	53	20000	F
258	SQYPGT	VGDTJOVYUX	8619782804 Dell Way	\N	WPDNVEO	MS	58628	US	1	VGDTJOVYUX@dell.com	8619782804	3	5877144973725081	2009/09	user258	password	83	20000	F
259	VQPPLW	SFFHAEBXAR	3671714553 Dell Way	\N	BOMFCYT	WI	59568	US	1	SFFHAEBXAR@dell.com	3671714553	2	3291495500132442	2008/04	user259	password	61	20000	M
260	FPKBIP	GPQKRNLIPZ	6159762535 Dell Way	\N	VUCTOBI	TX	40758	US	1	GPQKRNLIPZ@dell.com	6159762535	1	6974036936182529	2008/01	user260	password	62	40000	M
261	AKAPRQ	FCITORIOMD	7365676672 Dell Way	\N	QGSSOOB	CT	65180	US	1	FCITORIOMD@dell.com	7365676672	2	7112545191310347	2009/09	user261	password	43	40000	F
262	JXTZDW	IXKZGYLJPR	9540433463 Dell Way	\N	CHFRIJH	AR	68569	US	1	IXKZGYLJPR@dell.com	9540433463	2	3890195515006781	2009/09	user262	password	48	80000	M
263	ERTBZQ	LYWKKGABIH	6566542046 Dell Way	\N	HAQQHSH	HI	16226	US	1	LYWKKGABIH@dell.com	6566542046	3	7873327853158117	2008/03	user263	password	45	40000	M
264	DGWUSV	QCFXCHGKPG	6326537996 Dell Way	\N	BFNTNTV	DC	33931	US	1	QCFXCHGKPG@dell.com	6326537996	1	5189834399614483	2012/05	user264	password	42	20000	M
265	FWIANL	GLONRZCYAI	9446080135 Dell Way	\N	MUWFPZM	GA	24944	US	1	GLONRZCYAI@dell.com	9446080135	1	5925173651892692	2009/04	user265	password	31	60000	F
266	NNSYTD	NGVMJUNSGH	3319631964 Dell Way	\N	OLXOYCS	UT	36223	US	1	NGVMJUNSGH@dell.com	3319631964	1	6190924708265812	2010/08	user266	password	72	100000	F
267	LXWPLD	LXMFKFMSTX	6351986862 Dell Way	\N	PHWSASA	ID	87142	US	1	LXMFKFMSTX@dell.com	6351986862	4	5325801098253578	2009/08	user267	password	62	80000	M
268	MKZPVX	CBIHNABLQI	3979425513 Dell Way	\N	HJIZJPW	WV	36049	US	1	CBIHNABLQI@dell.com	3979425513	2	9462667724583300	2012/02	user268	password	54	60000	F
269	MAIKCJ	SKWSLIJUPS	9490352484 Dell Way	\N	DPCSLBA	RI	44691	US	1	SKWSLIJUPS@dell.com	9490352484	4	5419349465984851	2010/02	user269	password	90	100000	F
270	IIGRBQ	OUCWDXMWAB	9235048020 Dell Way	\N	ZSMBSGL	NY	96633	US	1	OUCWDXMWAB@dell.com	9235048020	1	1688433615025133	2012/01	user270	password	32	40000	F
271	LXLCLG	EIJCUGCVFU	6672575523 Dell Way	\N	IGNPRFO	NH	38590	US	1	EIJCUGCVFU@dell.com	6672575523	3	4426763960160315	2012/09	user271	password	75	40000	M
272	GJBMOJ	WQEDSAINIP	9556971297 Dell Way	\N	BYHGMWO	CT	42373	US	1	WQEDSAINIP@dell.com	9556971297	5	1611147962510585	2011/03	user272	password	66	100000	M
273	SMDCIT	GLMGUZPJBO	9460061874 Dell Way	\N	QHANWDW	SD	19353	US	1	GLMGUZPJBO@dell.com	9460061874	3	3943755624815822	2011/07	user273	password	84	40000	F
274	BKIURU	HYPHOYICPP	7503574506 Dell Way	\N	DDMHZHK	WA	86553	US	1	HYPHOYICPP@dell.com	7503574506	3	4485530681908131	2011/11	user274	password	46	80000	F
275	SMYNTX	CAMBJORYSU	9755488057 Dell Way	\N	LZUTKSP	CO	32947	US	1	CAMBJORYSU@dell.com	9755488057	4	2083347867242992	2009/06	user275	password	47	20000	M
276	JPRHSS	TUBHLAAFLA	1906662633 Dell Way	\N	AEKSUNZ	PA	33723	US	1	TUBHLAAFLA@dell.com	1906662633	1	7219346944708378	2010/03	user276	password	61	100000	M
277	HDNZWH	AETBEZNEZS	1513486435 Dell Way	\N	PSMCRFJ	RI	40104	US	1	AETBEZNEZS@dell.com	1513486435	2	5840217979624868	2011/02	user277	password	43	100000	F
278	WXEEYJ	XANWNSWFIO	8074536088 Dell Way	\N	RKGXUAG	TN	38533	US	1	XANWNSWFIO@dell.com	8074536088	3	5271383880171925	2008/06	user278	password	74	20000	F
279	YFHHCI	VZVOWBWKTG	5305716901 Dell Way	\N	RQBRXWA	NY	43325	US	1	VZVOWBWKTG@dell.com	5305716901	5	8190472083631904	2009/11	user279	password	28	20000	F
280	LMDTHD	PWZQSKJZBA	1505129548 Dell Way	\N	ATXXTPG	HI	46923	US	1	PWZQSKJZBA@dell.com	1505129548	3	3246493724174797	2009/09	user280	password	38	80000	F
281	LKMOZI	OPAYZZAZAT	2223535093 Dell Way	\N	XXNMDTX	GA	30341	US	1	OPAYZZAZAT@dell.com	2223535093	3	9097498407587410	2010/01	user281	password	22	100000	F
282	NKLVZB	WYAWYZWSXT	1924203953 Dell Way	\N	FJXZGCF	MA	54346	US	1	WYAWYZWSXT@dell.com	1924203953	5	5873693423345686	2008/08	user282	password	90	80000	F
283	LNBMKZ	MGXMCQJWWT	8764344763 Dell Way	\N	TVZVBJI	DC	25809	US	1	MGXMCQJWWT@dell.com	8764344763	2	8467443868052215	2012/12	user283	password	83	40000	M
284	YTXXGE	VTGMCDIWWE	2921405410 Dell Way	\N	VRFFAJJ	UT	71047	US	1	VTGMCDIWWE@dell.com	2921405410	4	7058159681968392	2008/01	user284	password	32	20000	M
285	CZAHUT	OHWRPSNUOF	7536785773 Dell Way	\N	ATFJDBB	KY	81900	US	1	OHWRPSNUOF@dell.com	7536785773	3	8235087835229934	2012/07	user285	password	59	20000	F
286	OIHIWO	ENEWBYKGZE	2193997890 Dell Way	\N	LIINKRI	CO	20694	US	1	ENEWBYKGZE@dell.com	2193997890	1	6729655596427620	2011/01	user286	password	27	40000	F
287	KPGZTT	DQVCBBBFNK	9512775433 Dell Way	\N	NBUEJXI	MS	95962	US	1	DQVCBBBFNK@dell.com	9512775433	1	1267902967520058	2008/06	user287	password	48	60000	F
288	RMULQL	GTMHUSVFGW	9218394410 Dell Way	\N	ALFYTSW	OH	92838	US	1	GTMHUSVFGW@dell.com	9218394410	4	4492166974116117	2009/04	user288	password	50	100000	M
289	GLIRRB	EZWXUCDQCP	8941537579 Dell Way	\N	WAJOXBM	TN	83213	US	1	EZWXUCDQCP@dell.com	8941537579	1	1610873518045991	2009/02	user289	password	75	60000	M
290	DGGFLF	CIZEMQHBMH	4139329435 Dell Way	\N	KBFMOBH	MI	27849	US	1	CIZEMQHBMH@dell.com	4139329435	4	4138480763882399	2008/04	user290	password	85	40000	M
291	EMAKOI	KSVAZXNHIO	1933757302 Dell Way	\N	NUCOBOT	ME	37155	US	1	KSVAZXNHIO@dell.com	1933757302	3	6636056853458286	2008/10	user291	password	32	40000	F
292	FPWOZP	JZPHNWPBKK	6812486108 Dell Way	\N	EYMSSXA	SD	49956	US	1	JZPHNWPBKK@dell.com	6812486108	5	3440863080788404	2012/01	user292	password	59	20000	M
293	LQPAAP	PHCMXEWHIV	4270815277 Dell Way	\N	TBNQCIC	OR	25764	US	1	PHCMXEWHIV@dell.com	4270815277	3	2944905824027955	2012/08	user293	password	79	40000	F
294	LJHBZO	ELMJHURDNT	4386977421 Dell Way	\N	QEVZHOE	NM	22039	US	1	ELMJHURDNT@dell.com	4386977421	3	8001161888707430	2009/12	user294	password	21	80000	F
295	ITHXYS	JHADZDRSUW	1149060316 Dell Way	\N	OUDCYTG	KS	40469	US	1	JHADZDRSUW@dell.com	1149060316	3	3476236413698643	2008/03	user295	password	60	40000	M
296	WHXPRE	QVDUNWOJKJ	8891680955 Dell Way	\N	MNHGTQP	RI	25612	US	1	QVDUNWOJKJ@dell.com	8891680955	5	4629932022653520	2010/03	user296	password	45	40000	M
297	HYFMOA	QIOMWXXGKK	7717197769 Dell Way	\N	OREEGYI	DC	81292	US	1	QIOMWXXGKK@dell.com	7717197769	4	1234501875471323	2008/12	user297	password	58	60000	M
298	UXKUNS	JAPGXVQIKI	3569018616 Dell Way	\N	NOPMXSG	NV	40267	US	1	JAPGXVQIKI@dell.com	3569018616	4	3514434749726206	2012/03	user298	password	28	80000	F
299	OKPHTQ	XANTRWDZKR	9254136228 Dell Way	\N	OWPHCFQ	MD	10505	US	1	XANTRWDZKR@dell.com	9254136228	2	2839149499312043	2008/11	user299	password	39	80000	F
300	XXBNUB	BNSYQSIIHE	4098719533 Dell Way	\N	XPHDGSD	DC	94562	US	1	BNSYQSIIHE@dell.com	4098719533	2	8165997060481460	2011/11	user300	password	23	60000	M
301	CCNEEB	XDSQLAXQYN	4294433532 Dell Way	\N	YBTQFXO	ND	19201	US	1	XDSQLAXQYN@dell.com	4294433532	1	9450068387202920	2010/10	user301	password	67	60000	M
302	FSAHQD	ZGPAEFYRDA	4081031166 Dell Way	\N	KUFHJUK	OK	97571	US	1	ZGPAEFYRDA@dell.com	4081031166	1	7549268234055490	2008/09	user302	password	60	40000	F
303	PNBSMI	IMMNLDRLOM	2243459966 Dell Way	\N	RWVLGNK	NH	71916	US	1	IMMNLDRLOM@dell.com	2243459966	4	4559870145749301	2011/11	user303	password	78	40000	F
304	XBWFJI	RXUVOFJAWG	5180039471 Dell Way	\N	WINJSCB	UT	76700	US	1	RXUVOFJAWG@dell.com	5180039471	3	6458090835250915	2009/11	user304	password	89	20000	M
305	VJHEBE	YWTEGUBMQJ	5159175581 Dell Way	\N	AACCBZW	NC	58805	US	1	YWTEGUBMQJ@dell.com	5159175581	5	4901917542796582	2010/01	user305	password	44	40000	F
306	RLLVKI	OPPJQCZACZ	1472697085 Dell Way	\N	CFBBBPQ	MT	48652	US	1	OPPJQCZACZ@dell.com	1472697085	5	4990246432367712	2010/03	user306	password	79	20000	M
307	HXCPMS	EVJGUJJUMO	3766494931 Dell Way	\N	VOPLECW	HI	15233	US	1	EVJGUJJUMO@dell.com	3766494931	4	3613013172987849	2008/09	user307	password	89	60000	M
308	CBCUGY	DNSNWNAKIO	4932828367 Dell Way	\N	ZUTCQZD	WI	66930	US	1	DNSNWNAKIO@dell.com	4932828367	1	4214093363378197	2010/07	user308	password	89	60000	M
309	CIUAMH	SZDGZOOONJ	3531801684 Dell Way	\N	IQZHTYY	GA	12546	US	1	SZDGZOOONJ@dell.com	3531801684	4	5970230807084591	2009/02	user309	password	26	40000	F
310	XJXFCX	JIXXXLLGUB	7757414799 Dell Way	\N	GBVEZAF	ID	68624	US	1	JIXXXLLGUB@dell.com	7757414799	3	8083655754104257	2012/11	user310	password	35	80000	F
311	DAIBKQ	YHOKTUEVAG	2058246426 Dell Way	\N	QEGRKNI	CT	13945	US	1	YHOKTUEVAG@dell.com	2058246426	1	9332935007754714	2009/10	user311	password	29	60000	M
312	MOFDNN	RYGLDBMJSR	1912545777 Dell Way	\N	QKBDTEE	TX	27155	US	1	RYGLDBMJSR@dell.com	1912545777	2	9884611359797420	2009/09	user312	password	76	80000	F
313	ZXUMOT	TAWVMGODWY	5962735780 Dell Way	\N	EZRJENO	ID	75744	US	1	TAWVMGODWY@dell.com	5962735780	3	4982919144444168	2009/04	user313	password	70	40000	F
314	NVTGOT	DKFJYJFWOF	3284500294 Dell Way	\N	OYKCNRV	AR	29065	US	1	DKFJYJFWOF@dell.com	3284500294	3	5543105227872730	2012/09	user314	password	67	60000	M
315	KTDEWN	KFMULIIRXH	5130357361 Dell Way	\N	BZUTUVY	AR	30496	US	1	KFMULIIRXH@dell.com	5130357361	1	9687519971746952	2008/07	user315	password	56	60000	F
316	RSCFDI	RXUAFLXMNX	3632549888 Dell Way	\N	HGRCFTI	NY	77759	US	1	RXUAFLXMNX@dell.com	3632549888	5	3363321579061449	2012/05	user316	password	55	60000	F
317	QSGZJD	TJJFHWSEDZ	6617857897 Dell Way	\N	WFFPOXJ	TN	74673	US	1	TJJFHWSEDZ@dell.com	6617857897	4	1920309088192880	2008/02	user317	password	33	80000	M
318	LTFOMP	XRXTKBXKYC	3978165483 Dell Way	\N	PORNXMF	NC	24160	US	1	XRXTKBXKYC@dell.com	3978165483	4	3824727247934789	2010/06	user318	password	30	100000	F
319	JORZMI	WGTYDDXGTL	8701239216 Dell Way	\N	XHJJNXO	TN	63293	US	1	WGTYDDXGTL@dell.com	8701239216	2	1406037268228828	2008/05	user319	password	34	60000	M
320	XJKGGQ	ZETDBZXNXE	4765436836 Dell Way	\N	WHRUVMJ	NY	88654	US	1	ZETDBZXNXE@dell.com	4765436836	4	3121728072874248	2011/02	user320	password	29	60000	F
321	OUSETX	YXYYUMVZIC	3162309773 Dell Way	\N	QDXDMOA	VT	33656	US	1	YXYYUMVZIC@dell.com	3162309773	3	4204171595629305	2009/02	user321	password	78	100000	M
322	OCQLBO	KZJWUIEXYI	9936746621 Dell Way	\N	UBUJBSQ	KS	34603	US	1	KZJWUIEXYI@dell.com	9936746621	4	4385146947577596	2012/08	user322	password	36	40000	M
323	XUVLEU	UBPDGNBOHD	7395355168 Dell Way	\N	JRFBINI	IN	30863	US	1	UBPDGNBOHD@dell.com	7395355168	1	8913109336979688	2012/06	user323	password	64	100000	F
324	LIMGDN	WGTJIHRLQI	3628955565 Dell Way	\N	RSREAZK	OR	18202	US	1	WGTJIHRLQI@dell.com	3628955565	4	6241616962477565	2012/08	user324	password	81	40000	M
325	IQCWNJ	PWRXNDNWUG	2426902854 Dell Way	\N	NZGMJAO	NY	75145	US	1	PWRXNDNWUG@dell.com	2426902854	4	3864944910164923	2008/12	user325	password	36	40000	M
326	IFDRVZ	JSNMGKGMXG	8308951018 Dell Way	\N	TKPUZHM	CT	89643	US	1	JSNMGKGMXG@dell.com	8308951018	1	8887495858594776	2008/07	user326	password	55	60000	M
327	QCPQLI	EYPOFCLLVW	1771878486 Dell Way	\N	BPVICYF	VT	20089	US	1	EYPOFCLLVW@dell.com	1771878486	5	6783226095605642	2010/05	user327	password	47	40000	F
328	ZWYIBW	XPBZBMVXNL	4884960135 Dell Way	\N	SWORBMU	DC	51208	US	1	XPBZBMVXNL@dell.com	4884960135	4	8608122009318323	2012/12	user328	password	41	100000	M
329	GEXCBM	EBNQXLEIEA	7064518587 Dell Way	\N	XVCJQFV	AR	97634	US	1	EBNQXLEIEA@dell.com	7064518587	5	9608518044929952	2012/09	user329	password	77	40000	M
330	SIYFMA	TDXEHGIIDE	6102770832 Dell Way	\N	KNUQIVP	AK	75728	US	1	TDXEHGIIDE@dell.com	6102770832	1	5066645417828113	2009/03	user330	password	42	20000	M
331	HICHBF	EFNKOWOSGB	5839084352 Dell Way	\N	NXJJNKC	AZ	45472	US	1	EFNKOWOSGB@dell.com	5839084352	3	6756219666451216	2012/07	user331	password	34	20000	M
332	IKYNPD	BZSXNLEPYB	4452663315 Dell Way	\N	YIOJKPT	WA	16107	US	1	BZSXNLEPYB@dell.com	4452663315	5	6627232364844531	2011/12	user332	password	54	100000	F
333	KLYONX	HKLSOARPZZ	5191289053 Dell Way	\N	EIKUCIV	MN	21469	US	1	HKLSOARPZZ@dell.com	5191289053	1	1602543503046035	2012/12	user333	password	48	40000	F
334	JYYHGJ	SZYTQOTQSB	6028678077 Dell Way	\N	AMDJIPM	RI	71763	US	1	SZYTQOTQSB@dell.com	6028678077	4	7147648865822703	2012/02	user334	password	27	40000	F
335	CPILIH	KBYYUOQWPC	9893963170 Dell Way	\N	AZKQMFH	AL	94745	US	1	KBYYUOQWPC@dell.com	9893963170	1	1547435238957405	2008/04	user335	password	27	40000	M
336	LRGSBH	QZCFQYVTYU	4260390964 Dell Way	\N	EPGJXHH	UT	36740	US	1	QZCFQYVTYU@dell.com	4260390964	5	6641835723072291	2010/03	user336	password	58	100000	M
337	UQYCHY	ENODIHCDLR	6602347009 Dell Way	\N	KVOSDLZ	MO	49398	US	1	ENODIHCDLR@dell.com	6602347009	5	6800323426257820	2008/11	user337	password	56	100000	M
338	LBWKGJ	YKRGNVSFFN	3605916651 Dell Way	\N	TYQFXDQ	NC	17981	US	1	YKRGNVSFFN@dell.com	3605916651	4	9953626471105964	2012/09	user338	password	58	40000	M
339	KRATPK	LWYGODMCXK	9329606369 Dell Way	\N	SCIVTXY	AL	64826	US	1	LWYGODMCXK@dell.com	9329606369	5	3703636562451720	2010/02	user339	password	22	100000	M
340	BQKMBG	LIVOVXLGQN	4523716839 Dell Way	\N	PMGMKHC	KS	22391	US	1	LIVOVXLGQN@dell.com	4523716839	5	3233503010589629	2010/09	user340	password	19	60000	F
341	KAJRLS	MZOKLUAZJM	9247578219 Dell Way	\N	GWXNYGR	KY	13669	US	1	MZOKLUAZJM@dell.com	9247578219	4	7501876194961370	2012/04	user341	password	20	40000	F
342	KAUDMU	RWGLWFVJLS	3477728459 Dell Way	\N	HYQNQZO	NC	81760	US	1	RWGLWFVJLS@dell.com	3477728459	3	2103398712351918	2009/10	user342	password	52	80000	M
343	HVHBME	HYBMULXMSW	1321186344 Dell Way	\N	DFNDUBX	AR	57819	US	1	HYBMULXMSW@dell.com	1321186344	2	4206207036040723	2010/01	user343	password	31	80000	M
344	MWKRDI	SQCDOOWLRC	9018709599 Dell Way	\N	YUWASYN	PA	35511	US	1	SQCDOOWLRC@dell.com	9018709599	2	4209969127550721	2008/01	user344	password	37	60000	M
345	RFAZYR	CCGRZRJBQD	5464307220 Dell Way	\N	YQWWEPD	AR	88481	US	1	CCGRZRJBQD@dell.com	5464307220	1	9166661614552140	2011/09	user345	password	75	60000	M
346	VKWMNZ	SEYKNAARYQ	9370768462 Dell Way	\N	NUVDYWA	MI	10477	US	1	SEYKNAARYQ@dell.com	9370768462	1	7329671544954181	2011/08	user346	password	64	60000	F
347	NANMTR	LDFLDWKUKE	2758153718 Dell Way	\N	PODMPOM	MT	77996	US	1	LDFLDWKUKE@dell.com	2758153718	2	4278092387598008	2012/10	user347	password	45	40000	M
348	XVNPGR	VSURCPCHFR	1900375179 Dell Way	\N	KSHZFUT	MA	12930	US	1	VSURCPCHFR@dell.com	1900375179	2	8283417826052756	2010/07	user348	password	62	40000	F
349	DZQUUI	PMLFPSLGDD	2527048894 Dell Way	\N	NDIIWSJ	WI	93712	US	1	PMLFPSLGDD@dell.com	2527048894	3	5332548341713846	2011/10	user349	password	80	100000	M
350	MSPVIC	GNRZYYDCMG	5743836143 Dell Way	\N	KUDDECB	KS	57319	US	1	GNRZYYDCMG@dell.com	5743836143	1	4183805213775486	2009/01	user350	password	29	100000	M
351	TSBVZP	NYNLCPXJAS	4966356843 Dell Way	\N	MDWOEFC	OH	37320	US	1	NYNLCPXJAS@dell.com	4966356843	1	3903849002439529	2011/12	user351	password	22	40000	M
352	CFPRSO	FERVBAVUMZ	5342618657 Dell Way	\N	RBDWDVE	NE	93321	US	1	FERVBAVUMZ@dell.com	5342618657	1	8900803357828409	2010/07	user352	password	56	80000	M
353	DIMSOQ	JJSJFMWEDX	9758801231 Dell Way	\N	IABEEQC	NV	84274	US	1	JJSJFMWEDX@dell.com	9758801231	1	4386899176053703	2010/11	user353	password	27	80000	F
354	PISGSC	YCILYMPWVQ	7942490020 Dell Way	\N	YZUOCLK	AR	66755	US	1	YCILYMPWVQ@dell.com	7942490020	3	5195883271284402	2012/03	user354	password	64	60000	M
355	JTGLSI	TEGGUDBKBB	7577906167 Dell Way	\N	FQDQAFG	SC	77644	US	1	TEGGUDBKBB@dell.com	7577906167	4	9515341184102000	2009/03	user355	password	53	80000	M
356	SESBXX	HDRLFCNGHD	3632031204 Dell Way	\N	KXEPEZJ	VT	70854	US	1	HDRLFCNGHD@dell.com	3632031204	2	9114507246296854	2011/12	user356	password	83	60000	F
357	PNBNVF	EHKHUROYBM	6760008357 Dell Way	\N	CRQBAOT	IN	85330	US	1	EHKHUROYBM@dell.com	6760008357	1	8435384907294066	2010/07	user357	password	88	20000	F
358	AQYFVF	QCAHRYJDAB	1039379857 Dell Way	\N	UCBIVJE	MO	51456	US	1	QCAHRYJDAB@dell.com	1039379857	1	1342018307652324	2012/02	user358	password	28	100000	M
359	CFQIWS	IEKHNNIPHK	5797678580 Dell Way	\N	RQGAVSM	SD	76251	US	1	IEKHNNIPHK@dell.com	5797678580	4	8974270416423679	2011/10	user359	password	67	80000	F
360	HCWALA	LTOYBDGMUW	1777718754 Dell Way	\N	TVSMINF	TX	38262	US	1	LTOYBDGMUW@dell.com	1777718754	3	1958312905393541	2011/04	user360	password	26	20000	F
361	ZCXZNQ	NMSRSELPXH	3124822499 Dell Way	\N	HJPVPLD	NV	99151	US	1	NMSRSELPXH@dell.com	3124822499	3	3768307211808860	2009/07	user361	password	71	40000	M
362	QHEGVQ	YMJDYYAGGK	6261663562 Dell Way	\N	VBZHFQH	MI	17419	US	1	YMJDYYAGGK@dell.com	6261663562	4	6298322129994631	2009/02	user362	password	33	100000	F
363	JEGZDT	JGSIHYORTQ	9999927052 Dell Way	\N	RBWIIHK	VT	16931	US	1	JGSIHYORTQ@dell.com	9999927052	2	2709896927233785	2009/03	user363	password	62	60000	F
364	WOMPXT	HGAGVSZLKB	8735286854 Dell Way	\N	HSJPDHR	CT	56177	US	1	HGAGVSZLKB@dell.com	8735286854	2	7151354987174273	2010/11	user364	password	21	40000	F
365	NYKHGQ	HMLAMXKNFD	4410586962 Dell Way	\N	XUGEMKS	KS	75146	US	1	HMLAMXKNFD@dell.com	4410586962	4	6676866185851396	2010/02	user365	password	25	100000	F
366	NFHDNU	PNGMYURBRM	1455873704 Dell Way	\N	IWYSOHK	WI	17898	US	1	PNGMYURBRM@dell.com	1455873704	2	2907655410002917	2008/04	user366	password	37	80000	M
367	OUBJJP	QWOKOPCAXY	6290136627 Dell Way	\N	ZPNHAMJ	AZ	84771	US	1	QWOKOPCAXY@dell.com	6290136627	2	2355790163390338	2012/11	user367	password	69	60000	M
368	UUBJKX	XULNXMLWMA	8402587396 Dell Way	\N	JTBVDDR	OR	42716	US	1	XULNXMLWMA@dell.com	8402587396	3	3245471953414380	2010/01	user368	password	85	40000	M
369	ZRFWPA	ICXUNTHODB	4322463798 Dell Way	\N	QZETQXD	MO	55153	US	1	ICXUNTHODB@dell.com	4322463798	5	5706963019445539	2009/04	user369	password	42	40000	M
370	ODOOLR	MGEGNTJOJJ	7236657544 Dell Way	\N	TDARGME	NJ	53848	US	1	MGEGNTJOJJ@dell.com	7236657544	5	7993865395896138	2008/03	user370	password	71	60000	F
371	HDUYPA	DVOXFDHPXK	4140722931 Dell Way	\N	PORCTHO	ME	28877	US	1	DVOXFDHPXK@dell.com	4140722931	3	4572375999763608	2008/01	user371	password	70	40000	F
372	NITOLP	CIVGPKDAZS	6257334598 Dell Way	\N	RBLZQWE	WY	39633	US	1	CIVGPKDAZS@dell.com	6257334598	1	4145796103402972	2009/06	user372	password	54	100000	M
373	GJFVMO	RTEBWFBPXD	6442399032 Dell Way	\N	BWTYBTG	NM	85344	US	1	RTEBWFBPXD@dell.com	6442399032	5	3620588372461498	2008/10	user373	password	22	40000	F
374	HFPWWI	AXFGYVDBWZ	7443495141 Dell Way	\N	VUBPBRL	NV	67561	US	1	AXFGYVDBWZ@dell.com	7443495141	4	4629723208490759	2011/02	user374	password	56	20000	F
375	DXEMYC	REAMHCJHYD	1735684435 Dell Way	\N	JNEBYVR	NV	62724	US	1	REAMHCJHYD@dell.com	1735684435	3	7239370234310628	2011/07	user375	password	18	80000	F
376	EFJGWN	HJVJSDIWMV	2464967654 Dell Way	\N	BNUWFLM	IL	89059	US	1	HJVJSDIWMV@dell.com	2464967654	5	4421099658589810	2008/08	user376	password	75	40000	M
377	DOSRWC	NGUQORDJSQ	8670228408 Dell Way	\N	EPVPBDM	HI	11011	US	1	NGUQORDJSQ@dell.com	8670228408	2	6753233018331230	2011/09	user377	password	52	80000	F
378	EMEGZK	BQYSUILLMA	1386296926 Dell Way	\N	HBCKNIK	MA	75057	US	1	BQYSUILLMA@dell.com	1386296926	1	5031183911487460	2010/10	user378	password	72	80000	F
379	XYHHZY	FSSNDDZELB	7959889125 Dell Way	\N	HVPPFYI	ID	98829	US	1	FSSNDDZELB@dell.com	7959889125	4	8297181698959322	2010/06	user379	password	26	60000	F
380	KSKJYC	CMGGMLRNSM	8674097456 Dell Way	\N	CHSBQZB	MD	76853	US	1	CMGGMLRNSM@dell.com	8674097456	5	2840031786821782	2012/05	user380	password	62	40000	F
381	ATADVM	JCYUTMNGOV	8893245345 Dell Way	\N	YQLYRWR	MT	80262	US	1	JCYUTMNGOV@dell.com	8893245345	3	2222663085907697	2010/11	user381	password	33	60000	M
382	FPLSZO	RUIDHORCNH	3807279390 Dell Way	\N	OMZKDME	AK	96166	US	1	RUIDHORCNH@dell.com	3807279390	3	8383920805528761	2010/12	user382	password	49	80000	M
383	XLOLCJ	UGQIYSWGHI	5126499498 Dell Way	\N	FRMRVMQ	DC	99661	US	1	UGQIYSWGHI@dell.com	5126499498	4	9864839225541800	2012/06	user383	password	60	80000	M
384	DGZMAF	DJDWFKDOPU	5801655211 Dell Way	\N	BHQOXUO	LA	51257	US	1	DJDWFKDOPU@dell.com	5801655211	2	8890351350884885	2008/01	user384	password	72	40000	F
385	STHYWQ	CTWMWLCQMJ	4522183122 Dell Way	\N	HBGBPQN	CT	89283	US	1	CTWMWLCQMJ@dell.com	4522183122	2	9343711226712912	2008/06	user385	password	33	100000	F
386	MVDDXW	ZKSLMJYVQZ	5680364181 Dell Way	\N	CROSFRP	NH	93327	US	1	ZKSLMJYVQZ@dell.com	5680364181	4	4822750995401293	2011/08	user386	password	67	40000	F
387	VJIRJT	KUGTSBKREC	3441283382 Dell Way	\N	GWHXMXW	WY	65995	US	1	KUGTSBKREC@dell.com	3441283382	4	3029052692931145	2012/12	user387	password	65	80000	F
388	ZLQTVL	ZPDBZUFBBC	1900316417 Dell Way	\N	JYOGUOW	AZ	35701	US	1	ZPDBZUFBBC@dell.com	1900316417	1	3063468502368778	2011/10	user388	password	56	80000	F
389	EMBPMR	TNROTSPWCO	5657291052 Dell Way	\N	LJJAFLH	KS	51380	US	1	TNROTSPWCO@dell.com	5657291052	1	3250254617072642	2008/10	user389	password	53	40000	F
390	OVTFOH	WCBPSXRGJA	7648048803 Dell Way	\N	PJGAQPM	DE	68696	US	1	WCBPSXRGJA@dell.com	7648048803	2	5156824692152441	2009/06	user390	password	73	80000	F
391	NZVVVY	WLQUDWDEMM	2087995519 Dell Way	\N	LMDAZHR	OK	53058	US	1	WLQUDWDEMM@dell.com	2087995519	5	9124726902693512	2012/09	user391	password	29	40000	M
392	ZFNXBZ	NWCKZGWLRJ	3069822747 Dell Way	\N	ORJWJBI	MN	11376	US	1	NWCKZGWLRJ@dell.com	3069822747	2	7516995991580189	2009/09	user392	password	47	40000	M
393	YGAXUW	ZEWGBIYKWQ	6122061129 Dell Way	\N	TSZVBLV	IL	80785	US	1	ZEWGBIYKWQ@dell.com	6122061129	4	5754062341526151	2012/01	user393	password	52	100000	F
394	NVBJVG	GBHOASLQLE	4183120554 Dell Way	\N	PHFBDMV	OH	25392	US	1	GBHOASLQLE@dell.com	4183120554	4	2777767871040851	2012/08	user394	password	52	40000	F
395	OSGUYH	CMHUXYGBNN	2370918144 Dell Way	\N	HORUKJY	OR	13392	US	1	CMHUXYGBNN@dell.com	2370918144	3	6711411399301142	2011/11	user395	password	21	20000	M
396	HZPPBC	WVZVBBIPJX	3428771862 Dell Way	\N	GDHPCAQ	IA	64755	US	1	WVZVBBIPJX@dell.com	3428771862	5	5702685076277704	2009/01	user396	password	29	80000	F
397	TEBVBW	VWYWFNGCTJ	6046930359 Dell Way	\N	KJMLZSA	ID	62800	US	1	VWYWFNGCTJ@dell.com	6046930359	3	6741783560719342	2011/03	user397	password	65	60000	F
398	SHLPCI	NZNBFQVPAE	9872167209 Dell Way	\N	BMETNLJ	AZ	13421	US	1	NZNBFQVPAE@dell.com	9872167209	4	3066665519494563	2011/03	user398	password	62	40000	M
399	BYPJMO	XNUNJJOOKA	4962798750 Dell Way	\N	SEOENPF	MS	44723	US	1	XNUNJJOOKA@dell.com	4962798750	1	6593742118682713	2008/06	user399	password	27	20000	F
400	SLXHJL	BXULLIWMBA	6830864688 Dell Way	\N	AGOQLBA	VA	27719	US	1	BXULLIWMBA@dell.com	6830864688	5	7238008170854301	2011/01	user400	password	27	60000	F
401	BUWMWT	HIFQESSESY	6995234320 Dell Way	\N	SJKUKHZ	AR	30644	US	1	HIFQESSESY@dell.com	6995234320	5	3345355732366443	2011/04	user401	password	72	100000	F
402	PIAIQI	NHMFZRYYJI	2104070194 Dell Way	\N	IESQDTW	SC	62359	US	1	NHMFZRYYJI@dell.com	2104070194	3	9170686969067902	2012/06	user402	password	20	60000	M
403	AVKJJR	VORMNQWWYA	8412834151 Dell Way	\N	OPDILYX	NE	57972	US	1	VORMNQWWYA@dell.com	8412834151	3	9736720310058446	2012/12	user403	password	72	100000	M
404	EGCWBR	NOFDKBCKQS	1090605100 Dell Way	\N	OYENWTB	OH	27341	US	1	NOFDKBCKQS@dell.com	1090605100	3	2091208441182971	2011/06	user404	password	81	100000	M
405	YTUQHI	VLSWODMHSL	5380234430 Dell Way	\N	LFIEGAJ	ID	62295	US	1	VLSWODMHSL@dell.com	5380234430	1	1305581101682037	2009/12	user405	password	71	40000	M
406	NXAVTM	OPASCHKOTQ	5647370127 Dell Way	\N	WXXXHEM	PA	27853	US	1	OPASCHKOTQ@dell.com	5647370127	1	2292535816784948	2009/05	user406	password	80	80000	F
407	WOBIDR	JVURGIKWFI	3569905887 Dell Way	\N	UCPYPJD	CO	51789	US	1	JVURGIKWFI@dell.com	3569905887	2	8908742939587683	2008/02	user407	password	33	20000	M
408	HJVZSQ	TKWCUTHCNK	4613596908 Dell Way	\N	SMABPDN	VA	53225	US	1	TKWCUTHCNK@dell.com	4613596908	1	6353552803397179	2011/01	user408	password	38	100000	F
409	CWDTQN	QTHJAKXLDJ	6840234973 Dell Way	\N	LEZOSXB	CO	94492	US	1	QTHJAKXLDJ@dell.com	6840234973	4	9949641735292972	2012/08	user409	password	47	20000	M
410	NUEAKX	IUXTRJXBVB	9070701781 Dell Way	\N	BKUZLXX	CO	65480	US	1	IUXTRJXBVB@dell.com	9070701781	1	3266028830781579	2009/01	user410	password	74	100000	M
411	YWGVEA	TYSCVUYXWI	5072135530 Dell Way	\N	SVUPTWF	NM	92321	US	1	TYSCVUYXWI@dell.com	5072135530	5	9875021984800696	2009/09	user411	password	79	20000	M
412	CZUDST	WVPRTMNCEJ	6829156070 Dell Way	\N	WUCTZSR	ME	68976	US	1	WVPRTMNCEJ@dell.com	6829156070	4	4601656510494650	2010/10	user412	password	90	60000	M
413	USMNOH	CGBPTDUDAO	1087313727 Dell Way	\N	FTNYLYP	AZ	63387	US	1	CGBPTDUDAO@dell.com	1087313727	3	4533396830782294	2008/02	user413	password	29	80000	M
414	QHKYKR	AZLEUOEIUY	8037583475 Dell Way	\N	WTJUILK	KY	10277	US	1	AZLEUOEIUY@dell.com	8037583475	2	2266294944565743	2012/02	user414	password	90	60000	F
415	KOWBOW	MTQBXZVWVO	8462120693 Dell Way	\N	GPXRAGR	RI	65155	US	1	MTQBXZVWVO@dell.com	8462120693	4	7819508424028755	2012/04	user415	password	33	40000	M
416	BHLYUE	OVCNRYIFFY	7813864146 Dell Way	\N	DXYKOTZ	MD	52054	US	1	OVCNRYIFFY@dell.com	7813864146	2	8096668172627688	2012/06	user416	password	66	20000	M
417	CZOGNK	JBBIKHNJLK	3810626171 Dell Way	\N	IVZBVJN	ND	64273	US	1	JBBIKHNJLK@dell.com	3810626171	3	1510483975056558	2012/07	user417	password	77	20000	M
418	JIBTRD	VANCNXNYFJ	9536917778 Dell Way	\N	XGEHUSX	CO	33490	US	1	VANCNXNYFJ@dell.com	9536917778	1	8489999142009766	2011/02	user418	password	44	20000	F
419	LWEOSE	CVRZJQESNL	7149566096 Dell Way	\N	WVGPSIW	NV	46926	US	1	CVRZJQESNL@dell.com	7149566096	3	5912056656554342	2008/07	user419	password	18	60000	F
420	EBDIDY	ACHQHAETWZ	3593208357 Dell Way	\N	ZLSIIJT	WY	80043	US	1	ACHQHAETWZ@dell.com	3593208357	1	3887392376083881	2009/07	user420	password	72	60000	M
421	WUSVVV	CMDDQWZQWL	8206199304 Dell Way	\N	IFTSYTM	HI	80392	US	1	CMDDQWZQWL@dell.com	8206199304	3	3793879392556846	2010/01	user421	password	82	60000	M
422	PGQKJC	NMTKLKHXTM	5228943743 Dell Way	\N	QLLJXRE	OK	26792	US	1	NMTKLKHXTM@dell.com	5228943743	2	2694170025177300	2009/09	user422	password	90	100000	M
423	QJGTXS	MIEXPBQBSB	5714388115 Dell Way	\N	MCZDGSI	OK	97570	US	1	MIEXPBQBSB@dell.com	5714388115	1	6908576745074243	2010/01	user423	password	59	20000	F
424	VWGOJO	TGEUXFNYSP	3466645412 Dell Way	\N	YWVQFOQ	OR	64385	US	1	TGEUXFNYSP@dell.com	3466645412	2	6520642610732467	2012/05	user424	password	89	80000	F
425	GGQVZX	ZUUFHTYXRU	5332728242 Dell Way	\N	SIAGYTW	HI	99126	US	1	ZUUFHTYXRU@dell.com	5332728242	1	4463067512493581	2010/09	user425	password	66	80000	M
426	HNZFMU	ASBTQZLLRT	5988391059 Dell Way	\N	LYREVXE	IN	97156	US	1	ASBTQZLLRT@dell.com	5988391059	4	7428146196063609	2009/06	user426	password	69	60000	M
427	RSMLTF	NMVNXGFQRD	9306078493 Dell Way	\N	IWZGBHF	NH	14361	US	1	NMVNXGFQRD@dell.com	9306078493	5	5707804776262492	2011/04	user427	password	55	40000	F
428	AUUFIG	AVEHAUZEDW	9946852355 Dell Way	\N	DJXKPMM	MT	36293	US	1	AVEHAUZEDW@dell.com	9946852355	1	6578951697330923	2010/06	user428	password	67	60000	F
429	MTOSTJ	XBJSAOVWRF	2466119587 Dell Way	\N	TCVGPIO	NE	51815	US	1	XBJSAOVWRF@dell.com	2466119587	1	9316690799780192	2012/08	user429	password	29	40000	F
430	SADBYE	LQFAMCRRWU	2815718090 Dell Way	\N	MCKVQYH	SD	14548	US	1	LQFAMCRRWU@dell.com	2815718090	4	7009949590079487	2009/12	user430	password	19	20000	M
431	DDXIPO	NPAPHRLCEO	2499889428 Dell Way	\N	MZELGZM	MN	67460	US	1	NPAPHRLCEO@dell.com	2499889428	5	6319277139380575	2008/11	user431	password	60	40000	F
432	MQRAEG	BTOSFRXTEX	2397241436 Dell Way	\N	YPEYCQO	ID	51764	US	1	BTOSFRXTEX@dell.com	2397241436	3	4308119931258261	2011/10	user432	password	48	40000	F
433	BHPIII	XBNOYHTVFI	5219679666 Dell Way	\N	ADLQSSC	TX	25119	US	1	XBNOYHTVFI@dell.com	5219679666	3	9576522681862116	2012/10	user433	password	45	100000	F
434	ZHKHFL	VUKDNGIWGM	2155900749 Dell Way	\N	HXEAZBE	MN	67818	US	1	VUKDNGIWGM@dell.com	2155900749	2	5247320039663464	2010/04	user434	password	59	60000	M
435	ZTVLPP	VSDCBZINHF	8939317808 Dell Way	\N	SHFTMRK	NH	10659	US	1	VSDCBZINHF@dell.com	8939317808	1	3838333876337856	2010/07	user435	password	85	60000	F
436	TWYJSR	NVTMDHUJZB	6040002900 Dell Way	\N	OTOGEDG	AR	32018	US	1	NVTMDHUJZB@dell.com	6040002900	3	8368855524808169	2010/12	user436	password	29	40000	M
437	CPOUCJ	NPNUJWULLN	2770612726 Dell Way	\N	ZRSDYTJ	MS	33114	US	1	NPNUJWULLN@dell.com	2770612726	5	2831711025442928	2009/03	user437	password	20	60000	M
438	PGYYTO	LNYIHJUVJM	7649998153 Dell Way	\N	NNKHXXN	CA	88442	US	1	LNYIHJUVJM@dell.com	7649998153	3	1854508491232991	2011/11	user438	password	85	40000	F
439	WHXLTL	JCTTWODICQ	6409782306 Dell Way	\N	TJNQXPN	NM	14147	US	1	JCTTWODICQ@dell.com	6409782306	3	9582933257799596	2010/10	user439	password	25	60000	F
440	AVVLEX	EYUSBDVRWE	8187906714 Dell Way	\N	FNCUASV	NJ	22668	US	1	EYUSBDVRWE@dell.com	8187906714	1	9169754721224308	2012/07	user440	password	89	100000	F
441	UIPSNN	NGORBGOGLB	2005243923 Dell Way	\N	IGCBCSF	UT	88115	US	1	NGORBGOGLB@dell.com	2005243923	4	4867074742447585	2008/09	user441	password	78	100000	F
442	KQOYDU	MVWTJCELLK	5766364146 Dell Way	\N	NNMGSJC	SD	24388	US	1	MVWTJCELLK@dell.com	5766364146	5	8669170716777445	2009/10	user442	password	82	80000	F
443	LRPGEK	CXTFCFQMSD	4419787111 Dell Way	\N	ZYWJBRN	NE	61595	US	1	CXTFCFQMSD@dell.com	4419787111	5	4393765941262245	2009/09	user443	password	76	80000	F
444	KYOUBM	OGOTXBLABK	5428765767 Dell Way	\N	WKLOYAC	KS	95817	US	1	OGOTXBLABK@dell.com	5428765767	3	6814049802720547	2009/04	user444	password	20	80000	F
445	PMHBAO	QULRGMTQIE	7382638454 Dell Way	\N	CWCCZLB	MO	13265	US	1	QULRGMTQIE@dell.com	7382638454	4	4118944840040058	2011/06	user445	password	62	40000	M
446	XKZMAT	XSZJLPSPSP	5812497051 Dell Way	\N	SVPDWBE	NE	87747	US	1	XSZJLPSPSP@dell.com	5812497051	2	4056446377653629	2008/08	user446	password	39	20000	F
447	GNBAKT	ZUFPMUICND	9513022971 Dell Way	\N	RRZTWOP	MD	89971	US	1	ZUFPMUICND@dell.com	9513022971	3	5792569684796036	2009/08	user447	password	59	60000	F
448	QNNJNI	ODUJLWXOOO	5720156738 Dell Way	\N	NHKCXVZ	TN	41068	US	1	ODUJLWXOOO@dell.com	5720156738	1	9392286601942034	2008/07	user448	password	20	80000	F
449	OCPWQS	RAEOXSCMGK	9893423698 Dell Way	\N	XIHSIDB	TX	28562	US	1	RAEOXSCMGK@dell.com	9893423698	5	8084700528997929	2008/08	user449	password	82	60000	M
450	MLJFDK	JRICUVIESQ	6138431824 Dell Way	\N	LKZPMVU	MN	79945	US	1	JRICUVIESQ@dell.com	6138431824	3	4867122217547149	2010/01	user450	password	29	100000	M
451	OERYOI	HQCCYHUPSF	6604051126 Dell Way	\N	PHSKCEF	NV	68024	US	1	HQCCYHUPSF@dell.com	6604051126	1	7466856284998358	2011/01	user451	password	36	40000	F
452	XHUGPL	IRJQMZISOQ	9226197560 Dell Way	\N	KZSOEJF	SC	53409	US	1	IRJQMZISOQ@dell.com	9226197560	3	5895488932263107	2008/12	user452	password	75	20000	F
453	OHUAQL	KGYJPQYGAY	4164974275 Dell Way	\N	YPCIUXV	OH	54358	US	1	KGYJPQYGAY@dell.com	4164974275	5	4702158094383776	2008/12	user453	password	63	80000	F
454	KSWWCD	UMSLLYMJXB	3440838278 Dell Way	\N	LGVJBNW	MD	42717	US	1	UMSLLYMJXB@dell.com	3440838278	3	3529527749400586	2012/03	user454	password	54	40000	M
455	JEBMZN	FKZEWICYUI	9186165180 Dell Way	\N	TDJGAUQ	ID	38125	US	1	FKZEWICYUI@dell.com	9186165180	1	5971509152092040	2010/06	user455	password	54	80000	M
456	OHPCMA	BRXJUVECPH	2199065451 Dell Way	\N	MVHGMOP	MA	76402	US	1	BRXJUVECPH@dell.com	2199065451	4	2818439777940512	2011/07	user456	password	78	40000	M
457	LIILJA	JTUEXXTFJP	1194404120 Dell Way	\N	NQBCFLV	LA	32370	US	1	JTUEXXTFJP@dell.com	1194404120	5	8371335092931987	2012/03	user457	password	66	40000	M
458	ZTXACQ	UHORATBQHS	3026419807 Dell Way	\N	SJXEEHK	FL	34225	US	1	UHORATBQHS@dell.com	3026419807	1	5241489319596440	2012/05	user458	password	89	100000	F
459	WXENRL	BJMVKCCCVL	1261248101 Dell Way	\N	AZPHJUO	NH	86882	US	1	BJMVKCCCVL@dell.com	1261248101	3	2748689154628664	2008/05	user459	password	38	100000	F
460	LKYXLH	KHSNJVIUVH	3449564917 Dell Way	\N	KDRFRGC	OH	77685	US	1	KHSNJVIUVH@dell.com	3449564917	4	2118578267749399	2010/08	user460	password	46	20000	M
461	IYLQIS	JVBEDWZLHC	3119988639 Dell Way	\N	CNUJPMC	TX	27803	US	1	JVBEDWZLHC@dell.com	3119988639	3	8121473342180253	2011/06	user461	password	74	100000	F
462	FPRXYM	YCQVCBCFEP	5154418805 Dell Way	\N	ZNEMQBR	UT	50210	US	1	YCQVCBCFEP@dell.com	5154418805	3	8782755215186627	2009/06	user462	password	33	60000	F
463	WIAJHC	ADFBFLGVKT	4304473639 Dell Way	\N	AXKBOGN	AL	78133	US	1	ADFBFLGVKT@dell.com	4304473639	2	2900047345086932	2010/09	user463	password	37	60000	F
464	GVIJVL	PXRADMLXNI	5612265253 Dell Way	\N	HOXOBXH	ME	24484	US	1	PXRADMLXNI@dell.com	5612265253	1	8651900027412922	2011/06	user464	password	81	20000	F
465	FLCQAZ	HBCUMAHVHV	6670155902 Dell Way	\N	SVXQDIU	NM	39138	US	1	HBCUMAHVHV@dell.com	6670155902	3	7984929809346796	2010/06	user465	password	21	80000	M
466	DIXDQZ	GKMGSHNNZJ	8633640168 Dell Way	\N	LQMTKDB	AL	58275	US	1	GKMGSHNNZJ@dell.com	8633640168	3	9989792715292424	2012/03	user466	password	82	20000	M
467	UDFUKP	GQHNDVNMGD	6555883346 Dell Way	\N	ZAOCCOQ	WA	19134	US	1	GQHNDVNMGD@dell.com	6555883346	5	4027621041983366	2010/11	user467	password	84	40000	F
468	CCKSIA	AVDWJQDNPD	1488210421 Dell Way	\N	BRFQHES	WA	98420	US	1	AVDWJQDNPD@dell.com	1488210421	3	8546595864463598	2012/09	user468	password	79	20000	M
469	GUDGVZ	KSJBVWQZXI	2499934665 Dell Way	\N	ENQIGOI	IL	99361	US	1	KSJBVWQZXI@dell.com	2499934665	2	7571868996601553	2008/04	user469	password	58	40000	F
470	RMYRXQ	AYMWPLUYPH	8769643940 Dell Way	\N	OYNDHVD	MN	17033	US	1	AYMWPLUYPH@dell.com	8769643940	3	4637106206733734	2010/09	user470	password	56	20000	F
471	MTDCUB	OQRZLPPSEO	6037939678 Dell Way	\N	GIWCLIE	IN	80660	US	1	OQRZLPPSEO@dell.com	6037939678	4	5516545524820686	2008/10	user471	password	70	60000	M
472	VRJXGA	OGLEWEILLQ	9089558440 Dell Way	\N	HNCPRKK	HI	21886	US	1	OGLEWEILLQ@dell.com	9089558440	2	9592497667297722	2011/11	user472	password	57	60000	M
473	XJUYYA	KCWPLIACPN	7179982472 Dell Way	\N	EFEPPKT	MT	73632	US	1	KCWPLIACPN@dell.com	7179982472	1	6154545987024904	2009/08	user473	password	25	20000	M
474	XCWXMZ	UBKCCMSPRX	5075990246 Dell Way	\N	UHNEABW	OK	25530	US	1	UBKCCMSPRX@dell.com	5075990246	5	7809401596430690	2010/02	user474	password	69	60000	F
475	OJRODT	YGWLYLDWFL	4325578714 Dell Way	\N	KKLLHDP	OK	18150	US	1	YGWLYLDWFL@dell.com	4325578714	2	2624908875674009	2008/09	user475	password	44	80000	F
476	BEGVDM	RPLCSHIERS	1219514173 Dell Way	\N	PDZTTSV	CO	99819	US	1	RPLCSHIERS@dell.com	1219514173	1	7583394109271467	2009/10	user476	password	78	60000	F
477	BGEOYT	ZBMGJQYCGC	5658317512 Dell Way	\N	BZVUVYU	TX	20726	US	1	ZBMGJQYCGC@dell.com	5658317512	2	9521514900028708	2009/09	user477	password	88	40000	M
478	DYXWXY	JEIZDKGFMF	1254962830 Dell Way	\N	AGBZBXC	ND	25781	US	1	JEIZDKGFMF@dell.com	1254962830	5	8890676463954152	2012/04	user478	password	79	20000	F
479	TZDRJI	ZILKPQWURD	8567400825 Dell Way	\N	WQEUSTZ	OR	67669	US	1	ZILKPQWURD@dell.com	8567400825	4	9500717210583390	2011/11	user479	password	31	60000	M
480	IDFRDO	CNDTJYLNUB	1015133241 Dell Way	\N	RPUKONB	MA	33215	US	1	CNDTJYLNUB@dell.com	1015133241	1	2002972008194774	2008/07	user480	password	87	60000	M
481	DFTSHG	VBQTMDNOVC	2951314740 Dell Way	\N	IGQWHAC	IL	19580	US	1	VBQTMDNOVC@dell.com	2951314740	3	6475452049169690	2008/01	user481	password	34	40000	F
482	ZANFVP	WOBZCQUFYB	6511380046 Dell Way	\N	WUIXXQA	CO	19518	US	1	WOBZCQUFYB@dell.com	6511380046	2	2086995839141309	2012/08	user482	password	42	100000	M
483	WAMLWB	MWDCRJBSFV	9077292325 Dell Way	\N	BCTRDWU	OR	22508	US	1	MWDCRJBSFV@dell.com	9077292325	3	7773784693796188	2009/05	user483	password	46	20000	F
484	WNHXAE	BDVKEOQAPS	5564731786 Dell Way	\N	THVQBOT	WI	23264	US	1	BDVKEOQAPS@dell.com	5564731786	1	5768670037388802	2012/04	user484	password	86	80000	M
485	GRUKSX	GCCVSCLLWS	5885918860 Dell Way	\N	HMTWGSA	PA	91656	US	1	GCCVSCLLWS@dell.com	5885918860	4	2571706337854266	2010/05	user485	password	87	80000	F
486	TDTQJW	TFOVQASIHE	9099534032 Dell Way	\N	CELVEES	OK	83770	US	1	TFOVQASIHE@dell.com	9099534032	2	2926598221994936	2012/12	user486	password	37	60000	F
487	AGLWZQ	KVHLNPSSSW	4171341277 Dell Way	\N	DNBIGUD	DC	98076	US	1	KVHLNPSSSW@dell.com	4171341277	5	9171558934263886	2011/08	user487	password	88	80000	M
488	KMUBXP	IIDYBVQYZD	6845923351 Dell Way	\N	ZHKTLNT	RI	57119	US	1	IIDYBVQYZD@dell.com	6845923351	2	1995700648520142	2011/01	user488	password	86	20000	M
489	TCKILT	MJUHZSHDSO	7179681205 Dell Way	\N	NMABFUO	TX	26351	US	1	MJUHZSHDSO@dell.com	7179681205	3	2841045158915222	2011/07	user489	password	69	40000	M
490	DSAWEK	QMJITNBIAN	5412031754 Dell Way	\N	ICSCROH	LA	12768	US	1	QMJITNBIAN@dell.com	5412031754	5	5845343613997102	2008/05	user490	password	28	40000	F
491	EEFOUR	YDLLETMRCP	5536661794 Dell Way	\N	JEGYMPZ	WV	62404	US	1	YDLLETMRCP@dell.com	5536661794	1	9278850119560958	2011/06	user491	password	88	100000	M
492	EJLWIO	HUTBHKDWUI	2975233808 Dell Way	\N	CSUSRTH	FL	93403	US	1	HUTBHKDWUI@dell.com	2975233808	5	4623740637674928	2008/08	user492	password	21	40000	F
493	MFJAND	TPKETHYCKR	9797268110 Dell Way	\N	WCJQKOO	NJ	43777	US	1	TPKETHYCKR@dell.com	9797268110	5	1246180749963969	2008/02	user493	password	22	60000	F
494	KNXOHN	ZMGGLIQCFT	4612665025 Dell Way	\N	LWDZLTJ	ME	61275	US	1	ZMGGLIQCFT@dell.com	4612665025	3	7582592489197851	2010/12	user494	password	26	100000	F
495	ALTNKF	URQDHTIAFF	3138704129 Dell Way	\N	EFQYPBN	WV	52597	US	1	URQDHTIAFF@dell.com	3138704129	3	4578872687183321	2009/04	user495	password	80	40000	M
496	PXEVSV	MVDFEEKJIQ	9050628209 Dell Way	\N	ZGFATEM	AK	65919	US	1	MVDFEEKJIQ@dell.com	9050628209	2	9505492435302586	2011/09	user496	password	69	40000	M
497	WEJSQF	VVJZGSIXSP	8512424773 Dell Way	\N	CSJGFJX	CO	75008	US	1	VVJZGSIXSP@dell.com	8512424773	5	5177079452201724	2010/03	user497	password	27	60000	F
498	MDZSZV	BZCTIZMXBE	8227653510 Dell Way	\N	GIKQGNI	AZ	43112	US	1	BZCTIZMXBE@dell.com	8227653510	4	6101825974415988	2012/01	user498	password	85	60000	F
499	XDETEE	WYMVKJXPQG	4906055374 Dell Way	\N	ZGMMPOW	MA	26149	US	1	WYMVKJXPQG@dell.com	4906055374	2	2977268813177943	2009/09	user499	password	47	40000	M
500	PAATXY	FTJPQYFXYL	4397972592 Dell Way	\N	KLAZHKE	OR	75698	US	1	FTJPQYFXYL@dell.com	4397972592	1	5186796776950360	2011/05	user500	password	41	40000	F
501	ICHHIA	RXRPDPOOAZ	2946257016 Dell Way	\N	PZHADAT	MT	20591	US	1	RXRPDPOOAZ@dell.com	2946257016	2	5474903957452625	2010/09	user501	password	84	100000	M
502	FECGVA	YLDOZROZHO	9034768449 Dell Way	\N	GISHBFK	IL	58290	US	1	YLDOZROZHO@dell.com	9034768449	5	2889723526779562	2012/09	user502	password	90	20000	M
503	CHSCFD	FTDXICEWJN	5902283307 Dell Way	\N	OQOUBWI	WA	69520	US	1	FTDXICEWJN@dell.com	5902283307	4	4134279376827180	2010/10	user503	password	33	80000	F
504	XSGBXA	EVJHAFRNUH	9388716007 Dell Way	\N	BPJXYHP	MO	12225	US	1	EVJHAFRNUH@dell.com	9388716007	1	8089316803496332	2008/08	user504	password	78	20000	F
505	CCGDHB	MOBRFPMNQB	9799860008 Dell Way	\N	WOAEEME	CA	52851	US	1	MOBRFPMNQB@dell.com	9799860008	2	1898555966559797	2012/04	user505	password	49	100000	F
506	RAQTMF	VELKQYBSVQ	7910768997 Dell Way	\N	SAUEEWR	DE	19694	US	1	VELKQYBSVQ@dell.com	7910768997	5	4452671706210822	2009/11	user506	password	72	100000	M
507	KQJPLN	AVEZXXUNPU	7009531685 Dell Way	\N	HUZEMEH	IA	22528	US	1	AVEZXXUNPU@dell.com	7009531685	3	1094039153307676	2010/04	user507	password	83	100000	M
508	GKKUKG	YJDVEQLZYG	3527564669 Dell Way	\N	ZDTDKZH	CA	47614	US	1	YJDVEQLZYG@dell.com	3527564669	3	7667672787792981	2008/04	user508	password	68	60000	M
509	CFCIEL	MAQDMPBTOF	6436506512 Dell Way	\N	MSPLZRW	IA	26399	US	1	MAQDMPBTOF@dell.com	6436506512	3	5337320041842759	2009/11	user509	password	30	40000	F
510	GSFSFG	JISYJLNOXF	5806805224 Dell Way	\N	EJEWFLB	SD	87569	US	1	JISYJLNOXF@dell.com	5806805224	1	7443238030653448	2011/07	user510	password	74	100000	F
511	ARKGBT	YZCJNRHSWQ	9365813081 Dell Way	\N	XTWJURF	KS	79863	US	1	YZCJNRHSWQ@dell.com	9365813081	1	3514822006225586	2011/01	user511	password	55	80000	M
512	YYTRXS	UHGLOZIFWB	7964452312 Dell Way	\N	BGWSLFM	MA	30576	US	1	UHGLOZIFWB@dell.com	7964452312	1	3092459636274725	2009/10	user512	password	85	40000	M
513	RWRKQY	QCNPLTMMUS	1179305634 Dell Way	\N	JNEOAOU	RI	66794	US	1	QCNPLTMMUS@dell.com	1179305634	1	4904414826072753	2012/04	user513	password	32	80000	F
514	WAUVQW	JGHCSUWLEK	3026303076 Dell Way	\N	QSKENEU	MT	30864	US	1	JGHCSUWLEK@dell.com	3026303076	3	5497306550852955	2010/01	user514	password	64	40000	F
515	KCTHLZ	ONSJKENUUF	1841764017 Dell Way	\N	EYSJSGP	WI	74845	US	1	ONSJKENUUF@dell.com	1841764017	2	8231240931432695	2011/08	user515	password	83	20000	M
516	QKFPZT	IIDMVYGBDE	6160230518 Dell Way	\N	UMXBCWU	FL	29965	US	1	IIDMVYGBDE@dell.com	6160230518	5	8879571703728289	2010/01	user516	password	64	20000	F
517	VSKOAT	SMPRSRUXMH	7828871303 Dell Way	\N	VNJRHOW	TX	51321	US	1	SMPRSRUXMH@dell.com	7828871303	2	5515436917543412	2009/06	user517	password	87	40000	F
518	JUDDNQ	SEJJYGVFBJ	1988879401 Dell Way	\N	PTQDPMP	MA	83078	US	1	SEJJYGVFBJ@dell.com	1988879401	4	3066815991420299	2008/12	user518	password	43	60000	M
519	MOHCHL	LRKSMQUWFN	1167546989 Dell Way	\N	MJDZZNU	CA	34142	US	1	LRKSMQUWFN@dell.com	1167546989	1	3282043772749603	2009/07	user519	password	20	100000	F
520	IYKTKB	DDOUXKZLXJ	6332860658 Dell Way	\N	OWIBRLI	OH	62083	US	1	DDOUXKZLXJ@dell.com	6332860658	1	2448126235511154	2011/11	user520	password	39	100000	M
521	SSHUVK	JPITPTRZIO	5332132435 Dell Way	\N	IKGTSXI	KS	98222	US	1	JPITPTRZIO@dell.com	5332132435	5	9002970522269607	2011/11	user521	password	73	60000	M
522	AHKLQA	TKQNBPVQXF	6881823059 Dell Way	\N	WRYUZGT	MN	27875	US	1	TKQNBPVQXF@dell.com	6881823059	2	1697349298745393	2010/09	user522	password	65	60000	F
523	BWQCQB	TDCIYTGEPX	6675365582 Dell Way	\N	CKXJEJO	SD	64831	US	1	TDCIYTGEPX@dell.com	6675365582	2	4141277612186968	2009/08	user523	password	44	40000	M
524	ALDBEH	ENFXTKNRMX	9220551698 Dell Way	\N	PVBYKXO	AL	19167	US	1	ENFXTKNRMX@dell.com	9220551698	2	7800085416994990	2009/08	user524	password	38	40000	F
525	LJGSNU	YLOIZFVWVQ	7263151068 Dell Way	\N	YUBVIBY	IA	44336	US	1	YLOIZFVWVQ@dell.com	7263151068	3	1300222395919263	2012/10	user525	password	27	60000	F
526	KCSEBD	SJCYEZTVYN	4280212388 Dell Way	\N	WTWYSDI	MD	69328	US	1	SJCYEZTVYN@dell.com	4280212388	2	5378637849818915	2010/10	user526	password	66	100000	M
527	JAYMTH	PRMOLHMYEG	1898320070 Dell Way	\N	VCYYLJP	SD	75879	US	1	PRMOLHMYEG@dell.com	1898320070	2	5609910131897778	2011/03	user527	password	47	20000	F
528	IPYQFQ	CTBJGANMVQ	1287946185 Dell Way	\N	LUCUKXN	MS	28429	US	1	CTBJGANMVQ@dell.com	1287946185	2	4427233878988773	2010/05	user528	password	61	80000	F
529	OJFELY	FVEGJQCACW	6479095339 Dell Way	\N	DWHAKUF	ME	16528	US	1	FVEGJQCACW@dell.com	6479095339	5	5178630540147424	2009/08	user529	password	51	80000	M
530	RYLPEH	UKRLMRNJUK	9985353642 Dell Way	\N	RVULBFN	NV	16365	US	1	UKRLMRNJUK@dell.com	9985353642	5	7201109880581499	2010/08	user530	password	68	20000	M
531	DSSLNC	CYPULYPVQK	6433684003 Dell Way	\N	QCMVPDX	NJ	98952	US	1	CYPULYPVQK@dell.com	6433684003	1	6442407858558000	2009/03	user531	password	28	60000	M
532	WWLYZJ	OTVNIRDTHF	9345819061 Dell Way	\N	FDVIBLI	NV	55788	US	1	OTVNIRDTHF@dell.com	9345819061	5	7394811262376607	2008/05	user532	password	64	100000	F
533	BWFLKZ	GXIYBBFGHJ	7413613036 Dell Way	\N	BPLMYCA	UT	13192	US	1	GXIYBBFGHJ@dell.com	7413613036	5	4782208425458521	2009/11	user533	password	67	60000	M
534	XWEWDC	FBDHHJOQLE	6531485591 Dell Way	\N	BYCEYYF	NM	90957	US	1	FBDHHJOQLE@dell.com	6531485591	5	7870020546950401	2009/06	user534	password	54	20000	F
535	RCKTHM	WOTGCKRGMP	9883492937 Dell Way	\N	JQNIVEF	MI	25528	US	1	WOTGCKRGMP@dell.com	9883492937	4	6310668271034957	2010/12	user535	password	81	20000	M
536	HXHTUV	MAYWSFJIOZ	8240960758 Dell Way	\N	WWUBCFF	CA	95745	US	1	MAYWSFJIOZ@dell.com	8240960758	3	8847476927097888	2011/09	user536	password	81	100000	M
537	DSLZEM	XBFCKNRKJO	3117344073 Dell Way	\N	ELQKQTJ	MI	40113	US	1	XBFCKNRKJO@dell.com	3117344073	1	1721048015169799	2008/01	user537	password	71	40000	M
538	EFZRDA	WGLJXVTLAE	3361397571 Dell Way	\N	CLVWUGE	AL	43594	US	1	WGLJXVTLAE@dell.com	3361397571	1	5052918312139809	2012/05	user538	password	34	20000	M
539	FVTGRZ	RBXNUIOZLA	8687727068 Dell Way	\N	UHUALVK	OK	98752	US	1	RBXNUIOZLA@dell.com	8687727068	4	4403396597132087	2008/11	user539	password	90	40000	M
540	TNKTFL	QTGYHFJHZR	3876772345 Dell Way	\N	CADYKWY	ID	61232	US	1	QTGYHFJHZR@dell.com	3876772345	2	5193465046118945	2009/08	user540	password	32	20000	F
541	PUJBKC	HJKMTSMKUM	4775679874 Dell Way	\N	NTXJSEY	AL	58605	US	1	HJKMTSMKUM@dell.com	4775679874	2	2578747601713985	2011/05	user541	password	41	40000	F
542	RGPTNZ	EASWNDRZRL	8285028345 Dell Way	\N	XBDCADQ	MI	54361	US	1	EASWNDRZRL@dell.com	8285028345	1	9051867611706258	2008/04	user542	password	24	100000	M
543	SOBRTB	KPPOGPGRMH	4083141733 Dell Way	\N	UPIYFTL	AL	82272	US	1	KPPOGPGRMH@dell.com	4083141733	1	1529673659242689	2010/12	user543	password	59	20000	M
544	PVHRGW	GUCVAUIIPX	3391119599 Dell Way	\N	QODKZEF	KY	38228	US	1	GUCVAUIIPX@dell.com	3391119599	4	3548917145002633	2012/11	user544	password	78	60000	M
545	CDZZKT	CFUWODLMUA	4117881331 Dell Way	\N	PEZTKIB	NV	18500	US	1	CFUWODLMUA@dell.com	4117881331	3	1013331127818673	2008/12	user545	password	71	40000	F
546	SGLMIR	GFFJRRERHI	1786411093 Dell Way	\N	RASZCJC	MI	87030	US	1	GFFJRRERHI@dell.com	1786411093	4	8018295098096133	2012/11	user546	password	78	60000	F
547	GZMXGS	DQJVUBCCSD	8608460642 Dell Way	\N	VSFFURB	UT	34395	US	1	DQJVUBCCSD@dell.com	8608460642	4	2494224980473518	2011/03	user547	password	40	100000	F
548	UWLNZB	WVVXXYPAUH	4176217240 Dell Way	\N	GZCXBYE	VA	68219	US	1	WVVXXYPAUH@dell.com	4176217240	3	8690111082978547	2011/07	user548	password	21	60000	F
549	MZJNVE	JTBHJCBRJB	2922957890 Dell Way	\N	THDSMAJ	TN	62997	US	1	JTBHJCBRJB@dell.com	2922957890	3	1857369343750178	2009/12	user549	password	51	80000	M
550	VGUZPN	BXWEZNNAHV	8578047300 Dell Way	\N	DAHEJCT	NE	64364	US	1	BXWEZNNAHV@dell.com	8578047300	5	6104162769392133	2009/07	user550	password	54	20000	M
551	HCKUDI	RHHFUHMQLM	2666043187 Dell Way	\N	XPWAJLQ	FL	34223	US	1	RHHFUHMQLM@dell.com	2666043187	3	8499905239790679	2011/08	user551	password	65	100000	M
552	BTUJKB	QPWYCMKPKZ	9865638896 Dell Way	\N	LKIWAND	GA	11229	US	1	QPWYCMKPKZ@dell.com	9865638896	5	6458213747479022	2011/11	user552	password	38	80000	M
553	BBADSP	ARSNBHXBTI	5826766571 Dell Way	\N	KQIXUOY	PA	50720	US	1	ARSNBHXBTI@dell.com	5826766571	2	3771926630754024	2012/02	user553	password	84	100000	F
554	XAXNAO	GNQNLRHTBX	4663509759 Dell Way	\N	CZRQXLC	MI	85581	US	1	GNQNLRHTBX@dell.com	4663509759	2	9423926337622108	2009/02	user554	password	25	40000	F
555	ZTEOZS	ENEVUXXRAW	6252876314 Dell Way	\N	JRUVTGQ	DE	54120	US	1	ENEVUXXRAW@dell.com	6252876314	3	6638033788185567	2011/09	user555	password	74	80000	F
556	ZGLRKZ	WGTTELUBUL	2713660841 Dell Way	\N	VPEBGIO	TN	83719	US	1	WGTTELUBUL@dell.com	2713660841	3	5721934351604432	2012/03	user556	password	89	100000	F
557	LQWKMD	DGHPAIKLEZ	3878244283 Dell Way	\N	QGGZVCU	AK	66533	US	1	DGHPAIKLEZ@dell.com	3878244283	5	8579542519059033	2009/11	user557	password	39	80000	M
558	EDAHHG	OWHXGTBGJI	1589262687 Dell Way	\N	MIDPDDF	MN	19011	US	1	OWHXGTBGJI@dell.com	1589262687	4	1089796430896967	2009/06	user558	password	57	60000	M
559	OUXVJU	CGAVIGFQTO	1031187485 Dell Way	\N	TJRXODZ	NM	91059	US	1	CGAVIGFQTO@dell.com	1031187485	5	4598433664534241	2010/07	user559	password	20	20000	F
560	YYRSBX	SWGZCWTQQC	7807680557 Dell Way	\N	IORLNIJ	NC	38119	US	1	SWGZCWTQQC@dell.com	7807680557	1	8455759067554028	2011/03	user560	password	28	80000	F
561	ULESEB	ZEDWXUMZCA	2115582085 Dell Way	\N	ROOZXCH	NY	27101	US	1	ZEDWXUMZCA@dell.com	2115582085	3	4506037339102477	2009/03	user561	password	56	20000	M
562	SUUTTY	XPWSCWUDNJ	4422150548 Dell Way	\N	SNHUVYZ	WA	46467	US	1	XPWSCWUDNJ@dell.com	4422150548	1	6341231112368405	2012/04	user562	password	34	80000	F
563	AJVZHK	VANSVQGEIT	4553612845 Dell Way	\N	LDOKDMU	MT	71571	US	1	VANSVQGEIT@dell.com	4553612845	3	9512955359183252	2011/01	user563	password	90	80000	F
564	VQSFMS	TENJKSSDDW	8457119957 Dell Way	\N	SOZFJNW	OR	92891	US	1	TENJKSSDDW@dell.com	8457119957	2	9562816132791340	2012/01	user564	password	44	80000	M
565	BWCUPH	IZRARVEOOS	9202910047 Dell Way	\N	NTBBQUY	MI	24525	US	1	IZRARVEOOS@dell.com	9202910047	2	2477357510942966	2009/11	user565	password	75	40000	M
566	XDJELI	VMARQOFJCY	5901896855 Dell Way	\N	KDOFCAJ	AK	35440	US	1	VMARQOFJCY@dell.com	5901896855	2	2740323214791715	2009/08	user566	password	88	40000	M
567	IKGQFS	RWJFCSIADM	1608803083 Dell Way	\N	PJOPSOW	IL	86616	US	1	RWJFCSIADM@dell.com	1608803083	4	5347693208605051	2008/11	user567	password	36	40000	F
568	MALFRI	OXKGFLKRAT	2370665233 Dell Way	\N	GPMVMTR	ND	42656	US	1	OXKGFLKRAT@dell.com	2370665233	3	2810789183247834	2010/12	user568	password	49	100000	M
569	WCPFQN	PXTBHKBBRR	8573287452 Dell Way	\N	NMEHETQ	IN	38704	US	1	PXTBHKBBRR@dell.com	8573287452	4	3306907494086772	2009/08	user569	password	32	20000	M
570	UIJIYG	BZOMBQDTDQ	3105599572 Dell Way	\N	YKURBCZ	VT	83696	US	1	BZOMBQDTDQ@dell.com	3105599572	1	4899111214559525	2010/04	user570	password	28	40000	M
571	MOPTPO	IBQYFJCVHN	9819180517 Dell Way	\N	QZOSYMO	FL	67215	US	1	IBQYFJCVHN@dell.com	9819180517	4	9462278049904854	2008/11	user571	password	60	80000	F
572	EJZSRB	JQGTSCBFTA	8301268513 Dell Way	\N	TLYGADW	WY	75927	US	1	JQGTSCBFTA@dell.com	8301268513	1	6179567045066506	2009/09	user572	password	88	60000	F
573	YGUAQK	HJCKKHDKBP	8015090051 Dell Way	\N	IHPMEOF	WY	71008	US	1	HJCKKHDKBP@dell.com	8015090051	2	4572015347424895	2011/12	user573	password	53	80000	F
574	GSUQAD	TKOBNYCCHK	3855667237 Dell Way	\N	RTPGYPX	OR	96371	US	1	TKOBNYCCHK@dell.com	3855667237	3	8892685212194920	2011/03	user574	password	22	20000	M
575	WSXALI	OMVMPXTAPN	1249084786 Dell Way	\N	PVMETFD	AR	73612	US	1	OMVMPXTAPN@dell.com	1249084786	5	9099538960959764	2008/11	user575	password	77	100000	M
576	TYBBMN	WZCUTDJGSE	6185343647 Dell Way	\N	TXXZBZR	CA	84608	US	1	WZCUTDJGSE@dell.com	6185343647	1	7631118432153017	2009/02	user576	password	42	20000	F
577	JEOXBO	AVHDEOWIHU	8143220080 Dell Way	\N	GHWFYYB	MT	21613	US	1	AVHDEOWIHU@dell.com	8143220080	5	3291921049356461	2008/01	user577	password	41	60000	F
578	XKGLKC	SOGHKPPEWW	4234403691 Dell Way	\N	ACUZDIC	WA	32616	US	1	SOGHKPPEWW@dell.com	4234403691	1	3680054614320397	2011/07	user578	password	55	60000	M
579	UAKWTY	DAJSPOOMOQ	2392116795 Dell Way	\N	HOUPQSW	AK	80665	US	1	DAJSPOOMOQ@dell.com	2392116795	4	4262152384035289	2011/04	user579	password	43	60000	F
580	TIBSLB	BERPTDEKKT	1554380525 Dell Way	\N	FAJXWKS	AL	18587	US	1	BERPTDEKKT@dell.com	1554380525	4	4377513954881579	2010/02	user580	password	67	20000	F
581	SWYUYD	LOWPTHZMMA	7529691616 Dell Way	\N	WKWGCXJ	DC	63909	US	1	LOWPTHZMMA@dell.com	7529691616	3	7846320481039584	2009/09	user581	password	36	20000	M
582	FXOIIC	FXWMXIZXEJ	1432616828 Dell Way	\N	ULLRUPH	MT	23938	US	1	FXWMXIZXEJ@dell.com	1432616828	5	8957147059962154	2009/01	user582	password	53	60000	M
583	BVGEBE	AOCJNANWUZ	9553397132 Dell Way	\N	IMUXTHB	SD	29172	US	1	AOCJNANWUZ@dell.com	9553397132	1	3191599139943719	2010/08	user583	password	29	60000	F
584	KQNPRB	RAPROMMNUZ	1525700146 Dell Way	\N	HRTPTOV	OK	70039	US	1	RAPROMMNUZ@dell.com	1525700146	1	3654962071217597	2009/08	user584	password	73	80000	F
585	HGYJYZ	YPNKCBFBJX	3702384247 Dell Way	\N	UYQIUJA	TN	55254	US	1	YPNKCBFBJX@dell.com	3702384247	1	2274615919683128	2008/09	user585	password	49	40000	M
586	JSWJRM	WCOYHQHELG	8290660557 Dell Way	\N	VTAETWR	AZ	91999	US	1	WCOYHQHELG@dell.com	8290660557	1	6483030555304140	2009/06	user586	password	57	80000	F
587	KZWXWZ	MUGCBKNHFH	7299034490 Dell Way	\N	IKBEBCC	UT	32224	US	1	MUGCBKNHFH@dell.com	7299034490	1	7618499384727330	2009/09	user587	password	86	80000	M
588	VOOUAI	ACKLQSRXAB	1384802236 Dell Way	\N	YFDBHAH	WY	20460	US	1	ACKLQSRXAB@dell.com	1384802236	2	8670015658717603	2012/11	user588	password	59	100000	F
589	DPLMQO	WBEOTBPVAU	9324925177 Dell Way	\N	YBCYJCB	ME	39036	US	1	WBEOTBPVAU@dell.com	9324925177	3	2990862856153399	2010/03	user589	password	66	80000	M
590	CCLRYN	VNGXCCXXAZ	6381786221 Dell Way	\N	ZZJBBUJ	WY	29436	US	1	VNGXCCXXAZ@dell.com	6381786221	3	4906844479963184	2009/02	user590	password	35	40000	F
591	RBDFWQ	LUTNSQOSPO	5738860754 Dell Way	\N	BQQWAPC	NJ	18414	US	1	LUTNSQOSPO@dell.com	5738860754	5	2715140000451356	2011/04	user591	password	45	60000	F
592	MQEDCY	WQQMFJCUKS	3698441781 Dell Way	\N	KHTAKJC	VT	32557	US	1	WQQMFJCUKS@dell.com	3698441781	4	5592316764406860	2011/02	user592	password	77	20000	M
593	ZHXYEN	PRTYTNJLXR	4013266659 Dell Way	\N	FYBOBYV	KY	68116	US	1	PRTYTNJLXR@dell.com	4013266659	1	8075527122709901	2008/03	user593	password	59	20000	F
594	MBRZRI	TPBGZNEQSD	1603135135 Dell Way	\N	RHEQDNH	MN	57533	US	1	TPBGZNEQSD@dell.com	1603135135	4	7442775806412102	2011/09	user594	password	33	20000	M
595	WCMFWC	GCBUHSNKJV	4019764084 Dell Way	\N	PAYCHKQ	LA	10429	US	1	GCBUHSNKJV@dell.com	4019764084	5	7692074578255416	2010/02	user595	password	58	60000	F
596	BQBDWE	FRMXEWHZMH	1649049759 Dell Way	\N	YOPIEYI	MT	94217	US	1	FRMXEWHZMH@dell.com	1649049759	1	1384241407271474	2011/06	user596	password	36	80000	F
597	IUZMAQ	YXVVEVHMTW	9699514169 Dell Way	\N	BBAZKOY	MN	64268	US	1	YXVVEVHMTW@dell.com	9699514169	1	1712959084659814	2009/10	user597	password	30	60000	M
598	EAOUZM	QVRLDDEAEG	3406211245 Dell Way	\N	AEQPCCE	AZ	25394	US	1	QVRLDDEAEG@dell.com	3406211245	2	9356453538406640	2010/10	user598	password	53	80000	M
599	BKVNAR	EMVIQVNWWR	7122843050 Dell Way	\N	MLUPQVT	VA	21874	US	1	EMVIQVNWWR@dell.com	7122843050	2	9621427546255292	2008/12	user599	password	77	40000	F
600	RTJIYW	EGMZUJVLWG	2583836946 Dell Way	\N	GLXCFUF	VA	22039	US	1	EGMZUJVLWG@dell.com	2583836946	1	1682416950818151	2012/04	user600	password	48	80000	F
601	UZZRDG	DDANYMKFSW	2028746289 Dell Way	\N	CUBXAYB	GA	99677	US	1	DDANYMKFSW@dell.com	2028746289	1	3471184778958559	2010/11	user601	password	40	40000	M
602	HAZNDC	ORAACGTYJO	2809006289 Dell Way	\N	ZGOYHTY	ME	95595	US	1	ORAACGTYJO@dell.com	2809006289	5	8110707881394775	2010/04	user602	password	63	80000	F
603	PILRWD	SWFYPDIDDO	2924845708 Dell Way	\N	SBWMZHL	FL	31890	US	1	SWFYPDIDDO@dell.com	2924845708	4	5857963767834008	2012/06	user603	password	79	60000	M
604	HCQKUN	QTDTBGXQZY	6366406481 Dell Way	\N	NLYVWDB	CA	83655	US	1	QTDTBGXQZY@dell.com	6366406481	5	3691676609218121	2010/05	user604	password	24	80000	F
605	TDGGTZ	JNBQLSPKGB	6111220046 Dell Way	\N	IBXLCZG	OK	91741	US	1	JNBQLSPKGB@dell.com	6111220046	1	3190620259381831	2011/11	user605	password	67	40000	F
606	XQTXZH	ZPSSFDYGLZ	3693789003 Dell Way	\N	EXCDEVB	OR	96457	US	1	ZPSSFDYGLZ@dell.com	3693789003	2	8401516322977842	2012/10	user606	password	78	100000	F
607	PUKXUA	QMFTKLEKPB	2213239618 Dell Way	\N	NTFJVYI	CO	40374	US	1	QMFTKLEKPB@dell.com	2213239618	1	2012057194951921	2012/12	user607	password	55	60000	M
608	XLOXBA	DULPYWFAKY	6858174370 Dell Way	\N	GTUFBXN	GA	97998	US	1	DULPYWFAKY@dell.com	6858174370	1	9577024648897352	2008/09	user608	password	70	20000	F
609	HAFIDZ	TTYQYZBXFU	5425480342 Dell Way	\N	RKWOYCO	NH	32433	US	1	TTYQYZBXFU@dell.com	5425480342	4	9632491733878852	2009/11	user609	password	25	60000	M
610	HUAHOT	FFREGOKBGV	3009042328 Dell Way	\N	YUTAIJG	TN	23155	US	1	FFREGOKBGV@dell.com	3009042328	1	1052710981108248	2009/07	user610	password	81	80000	F
611	WXXQDD	HIJWSKDNIY	8313102101 Dell Way	\N	HJHRQDU	TX	25357	US	1	HIJWSKDNIY@dell.com	8313102101	1	7474497772753239	2011/10	user611	password	23	60000	M
612	ZFVCND	MJVWNJFLQP	7497615367 Dell Way	\N	SIFVCBA	WA	29914	US	1	MJVWNJFLQP@dell.com	7497615367	4	1158831407316029	2011/03	user612	password	70	80000	F
613	OWWRIG	NFTWLFNAXV	5550034631 Dell Way	\N	FTYGTWM	MO	53464	US	1	NFTWLFNAXV@dell.com	5550034631	2	6994646560866386	2009/01	user613	password	21	80000	M
614	YLGEYM	YVXDIXBEDV	2034334558 Dell Way	\N	CKOZXBL	MD	37431	US	1	YVXDIXBEDV@dell.com	2034334558	4	4122011564671993	2008/05	user614	password	37	20000	M
615	NGTZFO	XJXVKBYGEJ	5434170514 Dell Way	\N	UDGVORD	OH	35381	US	1	XJXVKBYGEJ@dell.com	5434170514	5	7006590223871172	2011/12	user615	password	53	40000	F
616	GHKVET	TZEUYLYIFC	2728265298 Dell Way	\N	PBRGFIN	OK	27484	US	1	TZEUYLYIFC@dell.com	2728265298	3	2137942287139594	2011/09	user616	password	41	100000	F
617	TTFNME	RHDDGMJIBK	6860014110 Dell Way	\N	ZHQIVIN	AK	82902	US	1	RHDDGMJIBK@dell.com	6860014110	4	6008907531853766	2012/08	user617	password	60	80000	F
618	UFWYXE	CAKOJTPUSX	2195112122 Dell Way	\N	KBSTOSO	HI	47573	US	1	CAKOJTPUSX@dell.com	2195112122	2	1315088665112853	2011/11	user618	password	47	60000	F
619	HLALNB	VCKOSFHQQI	5758638906 Dell Way	\N	IKXBZDM	CA	40757	US	1	VCKOSFHQQI@dell.com	5758638906	5	3254560145083815	2012/04	user619	password	44	40000	M
620	KRGLMJ	VBBBJSRSBB	4261718017 Dell Way	\N	QDAUPCC	DC	92705	US	1	VBBBJSRSBB@dell.com	4261718017	1	2831384537741542	2011/04	user620	password	85	20000	M
621	EOLNKN	PLXICPJDGM	4601139858 Dell Way	\N	EACHDGF	MO	38678	US	1	PLXICPJDGM@dell.com	4601139858	2	6580141081009061	2009/05	user621	password	60	60000	M
622	ABHOQS	LZVBIZHUDI	1564422020 Dell Way	\N	XKLDPXL	AK	21112	US	1	LZVBIZHUDI@dell.com	1564422020	2	5117742974776775	2011/10	user622	password	43	80000	M
623	QGNIRM	ETUDBPGJMQ	3621265617 Dell Way	\N	UPGSBGV	CO	62539	US	1	ETUDBPGJMQ@dell.com	3621265617	4	4713987759314478	2011/06	user623	password	38	40000	M
624	UPJHTC	CWERDOETIU	3487113982 Dell Way	\N	ABVHWYW	DE	74020	US	1	CWERDOETIU@dell.com	3487113982	5	2257307327352464	2010/01	user624	password	76	40000	M
625	DQKGTH	LKKZPEIJFJ	1168664406 Dell Way	\N	FMGEIKW	NJ	30499	US	1	LKKZPEIJFJ@dell.com	1168664406	1	3670120965223759	2012/07	user625	password	88	100000	F
626	KGXRRI	CQXGYHLHNY	5432877979 Dell Way	\N	ORHZOXF	NE	16331	US	1	CQXGYHLHNY@dell.com	5432877979	2	6441195873077959	2010/05	user626	password	75	100000	M
627	RNGAPX	YWVFIDSGSK	1952519321 Dell Way	\N	NRYLWNN	LA	91475	US	1	YWVFIDSGSK@dell.com	1952519321	5	3396113126538694	2012/08	user627	password	80	60000	F
628	DPUANQ	WTZAMFSWTJ	5640897692 Dell Way	\N	VFGISPG	SC	47611	US	1	WTZAMFSWTJ@dell.com	5640897692	4	1675709672272205	2009/04	user628	password	36	60000	M
629	ANKRJD	QKQWCNQMIV	8525394724 Dell Way	\N	TRNIYIT	MI	12792	US	1	QKQWCNQMIV@dell.com	8525394724	5	3715628186706454	2008/04	user629	password	30	20000	M
630	OUFSLQ	JITWZFFVZX	1308740220 Dell Way	\N	JIVSBHT	VT	18804	US	1	JITWZFFVZX@dell.com	1308740220	5	4812636971939355	2009/02	user630	password	37	80000	M
631	MMJDVS	WSSCXNBUXJ	4780390227 Dell Way	\N	QPKXIIZ	LA	38910	US	1	WSSCXNBUXJ@dell.com	4780390227	3	4949445636942983	2011/04	user631	password	44	20000	M
632	THRLEJ	EGHRHCOQSE	2234783301 Dell Way	\N	BQMJQVS	AL	45528	US	1	EGHRHCOQSE@dell.com	2234783301	4	7523930532857776	2010/11	user632	password	57	40000	F
633	FSJPWP	WOWZDNSHOI	7447795187 Dell Way	\N	TYYPQZZ	RI	72252	US	1	WOWZDNSHOI@dell.com	7447795187	2	6410791323985905	2009/07	user633	password	77	60000	F
634	EBBUYQ	RXTEPASXUR	1944452757 Dell Way	\N	VJHVJBN	CA	40672	US	1	RXTEPASXUR@dell.com	1944452757	2	8661611367482693	2012/10	user634	password	22	20000	M
635	DXVTOS	MSINLGHDCR	7130760395 Dell Way	\N	KXAMKCV	MT	50996	US	1	MSINLGHDCR@dell.com	7130760395	3	3475706304423511	2011/07	user635	password	29	100000	F
636	ZQZSDR	AQDHXGJORH	4963711837 Dell Way	\N	PERSZEE	NY	65656	US	1	AQDHXGJORH@dell.com	4963711837	3	2353744111489504	2010/04	user636	password	59	60000	M
637	NHBFHR	JOPQYEIFTM	8608153516 Dell Way	\N	XMMBQES	AZ	62064	US	1	JOPQYEIFTM@dell.com	8608153516	4	8902248414698989	2010/03	user637	password	76	100000	M
638	WEVNOK	CEIHMOAZLN	1479823275 Dell Way	\N	LNDPFFE	AR	89098	US	1	CEIHMOAZLN@dell.com	1479823275	3	2064039306715130	2012/05	user638	password	63	80000	M
639	LGDVJI	DQUSRTDEFQ	5539127784 Dell Way	\N	HUVNZWK	AL	40635	US	1	DQUSRTDEFQ@dell.com	5539127784	5	7764933466911317	2008/08	user639	password	42	60000	M
640	MKFUOV	PGMJJROZYJ	8193701350 Dell Way	\N	VMISWJB	LA	32239	US	1	PGMJJROZYJ@dell.com	8193701350	3	8655332035385073	2008/01	user640	password	68	80000	F
641	XKZTZG	GIPXXPWGLI	1205174120 Dell Way	\N	ODEYENE	WV	11895	US	1	GIPXXPWGLI@dell.com	1205174120	1	1720915375743061	2011/09	user641	password	56	80000	F
642	NJDTPL	JMIZIPKRDN	5150349307 Dell Way	\N	VBSJGRJ	ID	81953	US	1	JMIZIPKRDN@dell.com	5150349307	5	5787653799168766	2012/08	user642	password	66	60000	M
643	UHOGRA	PQJEAAHOVJ	3315249126 Dell Way	\N	GFQYPWS	AR	88127	US	1	PQJEAAHOVJ@dell.com	3315249126	1	5259515189100057	2012/07	user643	password	49	80000	M
644	ZYNAND	JREJZSFJYL	2807492195 Dell Way	\N	ZWAWPBS	TX	19012	US	1	JREJZSFJYL@dell.com	2807492195	4	6967356123495848	2011/06	user644	password	55	80000	F
645	AQYEZQ	IJQBPZZAZW	8769402202 Dell Way	\N	BVMCOIF	PA	18873	US	1	IJQBPZZAZW@dell.com	8769402202	2	6272400956135244	2009/01	user645	password	19	60000	M
646	ZPPQYZ	GZOGYPFVQA	3577327936 Dell Way	\N	HTPPYIS	SC	75131	US	1	GZOGYPFVQA@dell.com	3577327936	1	7516555765643717	2009/08	user646	password	43	40000	F
647	YXCYEB	MKACPWSQDL	1034191140 Dell Way	\N	FTKOLEH	OK	42754	US	1	MKACPWSQDL@dell.com	1034191140	1	9592650502920152	2009/04	user647	password	27	40000	F
648	GFJISU	IUKENAIZGB	8891370774 Dell Way	\N	JUMOCFX	CA	31675	US	1	IUKENAIZGB@dell.com	8891370774	3	5987750267144293	2008/09	user648	password	74	40000	M
649	EORYXM	ICAJKZPMJK	9823079410 Dell Way	\N	ZXMEVOL	OK	99097	US	1	ICAJKZPMJK@dell.com	9823079410	4	7468018289189786	2011/12	user649	password	66	100000	M
650	IWLVEO	VNZUDLDNKB	3433798687 Dell Way	\N	APXOAPO	AK	39729	US	1	VNZUDLDNKB@dell.com	3433798687	4	3736073693726212	2012/09	user650	password	79	40000	M
651	HCSVXG	USJFVXQXXG	1372744466 Dell Way	\N	UMGKAHT	IN	13006	US	1	USJFVXQXXG@dell.com	1372744466	2	7387360940687359	2012/07	user651	password	35	20000	M
652	YZNFUF	PAAMQYKXTW	2591652924 Dell Way	\N	EDXLXFM	WA	48646	US	1	PAAMQYKXTW@dell.com	2591652924	5	9480743139516564	2010/12	user652	password	57	40000	M
653	BOTGET	HQKFBIYYMC	4585359890 Dell Way	\N	VXZAJXL	ND	75715	US	1	HQKFBIYYMC@dell.com	4585359890	5	7364507472142578	2012/05	user653	password	67	100000	M
654	LFCENT	PSUXRSKUOH	2363040145 Dell Way	\N	UPRSAFL	MI	27491	US	1	PSUXRSKUOH@dell.com	2363040145	2	5822438827250153	2012/05	user654	password	51	40000	M
655	NLCGBV	BZNUJIIRDX	3666543141 Dell Way	\N	IVYOHJT	ME	78452	US	1	BZNUJIIRDX@dell.com	3666543141	2	2136786104179919	2011/07	user655	password	70	40000	M
656	VOARPZ	EJJNSAQQJL	8570999871 Dell Way	\N	OYSYSDS	WY	46656	US	1	EJJNSAQQJL@dell.com	8570999871	4	9278490246739240	2010/01	user656	password	82	40000	M
657	XBEXFO	GTGHJXQVMO	1133879047 Dell Way	\N	NKGRDGC	WV	99631	US	1	GTGHJXQVMO@dell.com	1133879047	3	1165932744275778	2012/12	user657	password	61	80000	M
658	TRFIYY	PFHMWCYLQJ	9673863491 Dell Way	\N	SIMYKMY	MI	10029	US	1	PFHMWCYLQJ@dell.com	9673863491	2	9322134896181524	2010/02	user658	password	83	40000	M
659	CQTAFY	ISVLQGBAYK	9054051956 Dell Way	\N	NWVZVGZ	SC	63133	US	1	ISVLQGBAYK@dell.com	9054051956	2	7456713318824769	2011/08	user659	password	56	100000	F
660	HYNGGG	BRXHTXFEKB	5962680350 Dell Way	\N	ZJXGJRV	IA	11858	US	1	BRXHTXFEKB@dell.com	5962680350	1	7101527376566083	2008/12	user660	password	89	40000	M
661	NPCTQU	QXONCTYESI	5114308988 Dell Way	\N	BYRTUYU	KY	96640	US	1	QXONCTYESI@dell.com	5114308988	3	9010088354814800	2010/10	user661	password	72	100000	F
662	WRARIX	FWAYUERDGQ	6239652080 Dell Way	\N	UALSUUR	ID	28229	US	1	FWAYUERDGQ@dell.com	6239652080	4	9879485260229560	2009/08	user662	password	44	20000	F
663	JVPGBL	HAGMRJSIET	7463679405 Dell Way	\N	TXONPVT	FL	55711	US	1	HAGMRJSIET@dell.com	7463679405	3	2221383592579514	2008/09	user663	password	50	60000	M
664	BSPNZP	TLHDEQIYJG	9563070192 Dell Way	\N	MXVIQAV	LA	59098	US	1	TLHDEQIYJG@dell.com	9563070192	3	3148834577761590	2009/11	user664	password	74	60000	M
665	JYOZSA	HWFXFDHLQE	1934551148 Dell Way	\N	HYVITEW	OK	65870	US	1	HWFXFDHLQE@dell.com	1934551148	1	5478530287276954	2012/07	user665	password	24	40000	M
666	RFFRMC	XJHARTRVAP	9773627988 Dell Way	\N	RIJWFCM	IN	26079	US	1	XJHARTRVAP@dell.com	9773627988	1	7519264134578408	2008/06	user666	password	34	80000	M
667	LKCOHM	VIDPZZPPRY	9387014510 Dell Way	\N	YNDAZMF	WV	68382	US	1	VIDPZZPPRY@dell.com	9387014510	1	1620483361650258	2008/09	user667	password	68	80000	F
668	UEKHAT	LPSLEHCDGQ	5230410492 Dell Way	\N	HHQTMPK	ME	67423	US	1	LPSLEHCDGQ@dell.com	5230410492	3	4467417129315436	2008/03	user668	password	56	100000	F
669	YHJRSY	KEDRGGYXOF	2401415234 Dell Way	\N	NHSDSCU	DE	71770	US	1	KEDRGGYXOF@dell.com	2401415234	2	8848354030400515	2011/04	user669	password	33	80000	M
670	OIINSM	QKTXIQLOET	9259577043 Dell Way	\N	GHMJBQB	HI	98244	US	1	QKTXIQLOET@dell.com	9259577043	5	3680593495257199	2008/07	user670	password	82	80000	M
671	FFORWY	KTHAFWFZCM	4087362289 Dell Way	\N	LLOBMTB	ME	70296	US	1	KTHAFWFZCM@dell.com	4087362289	3	2831858056597411	2009/04	user671	password	21	60000	F
672	PCIOMC	WNHSSGVFRG	4531897123 Dell Way	\N	TTTNUEE	DC	75980	US	1	WNHSSGVFRG@dell.com	4531897123	2	9942522469442340	2010/10	user672	password	52	20000	M
673	UQJXMX	EFPLAVDHOW	9611847558 Dell Way	\N	BCRFHUZ	NV	25519	US	1	EFPLAVDHOW@dell.com	9611847558	1	9699487942270936	2010/02	user673	password	80	40000	M
674	FDHDHN	TTNOWVCSWE	4042362601 Dell Way	\N	KCLFBDJ	AL	30802	US	1	TTNOWVCSWE@dell.com	4042362601	3	4574944969266653	2008/09	user674	password	32	60000	M
675	MNCZGV	NVRIXKFCUI	3850775340 Dell Way	\N	OZJRJKX	OK	86216	US	1	NVRIXKFCUI@dell.com	3850775340	5	5707335259765387	2010/04	user675	password	40	100000	M
676	KZCFNX	XWVHCYCKNC	5899135672 Dell Way	\N	UFMEDEA	MI	16811	US	1	XWVHCYCKNC@dell.com	5899135672	5	4472773928195238	2012/12	user676	password	34	40000	M
677	IMLGJI	CRKBUUOXOT	1038863515 Dell Way	\N	JTWOTHQ	IN	32217	US	1	CRKBUUOXOT@dell.com	1038863515	1	2685472438577562	2009/06	user677	password	26	60000	M
678	OVHWYZ	HZUBNRQHAJ	8988970531 Dell Way	\N	DODLELS	FL	63447	US	1	HZUBNRQHAJ@dell.com	8988970531	3	1165898784995079	2008/01	user678	password	85	60000	M
679	FLUFST	ZUHQKORUSF	9610651088 Dell Way	\N	XEKIWPY	PA	12830	US	1	ZUHQKORUSF@dell.com	9610651088	4	1296436122618615	2012/05	user679	password	81	20000	M
680	QHNKGI	RXTGONYULD	8792338035 Dell Way	\N	FUAUSTV	NY	57063	US	1	RXTGONYULD@dell.com	8792338035	3	8755494659300894	2011/09	user680	password	65	40000	M
681	EUGNLD	GSSTRMFURZ	9442151499 Dell Way	\N	UMSOIKB	DE	97301	US	1	GSSTRMFURZ@dell.com	9442151499	5	6741745951119811	2010/04	user681	password	62	80000	F
682	VHNZNF	RHXEMRVMMH	3079851171 Dell Way	\N	FAPQCUP	AR	72531	US	1	RHXEMRVMMH@dell.com	3079851171	4	9874864241573960	2012/05	user682	password	21	80000	M
683	PRFUIM	SMZJIMWQSX	7309202254 Dell Way	\N	GIZAYBS	DC	71218	US	1	SMZJIMWQSX@dell.com	7309202254	5	1863939946983009	2011/09	user683	password	75	40000	F
684	ZDRMVE	MFMZBDRYJA	7933483749 Dell Way	\N	YJYZCCR	SC	17493	US	1	MFMZBDRYJA@dell.com	7933483749	3	7820603176020087	2010/11	user684	password	25	60000	F
685	UBWYNC	LNDOFCYFBH	1665133009 Dell Way	\N	DBKGSFI	MS	76833	US	1	LNDOFCYFBH@dell.com	1665133009	1	6643355173524470	2008/08	user685	password	65	100000	M
686	NXFPJS	TXXWVCXDGZ	2015549242 Dell Way	\N	OMSTUFM	UT	32925	US	1	TXXWVCXDGZ@dell.com	2015549242	1	8826947655528785	2011/12	user686	password	56	40000	M
687	TWGLPD	ILZLJDSISE	4152499501 Dell Way	\N	ALZFYWM	AR	91258	US	1	ILZLJDSISE@dell.com	4152499501	5	9042544559109956	2012/02	user687	password	75	80000	M
688	ABOEKA	EWKIOTATTL	4529363115 Dell Way	\N	TZJPMKM	SD	30071	US	1	EWKIOTATTL@dell.com	4529363115	4	3770095671061426	2008/04	user688	password	37	20000	F
689	VJUWNQ	GVFZWYTHST	6699126299 Dell Way	\N	RHFCUAI	FL	76547	US	1	GVFZWYTHST@dell.com	6699126299	2	1543178937863558	2012/07	user689	password	50	80000	M
690	FPLWWH	CVDAPLTIDA	4568996688 Dell Way	\N	OFVPOZI	FL	41401	US	1	CVDAPLTIDA@dell.com	4568996688	1	9074480339419098	2012/10	user690	password	76	20000	F
691	GYGNAC	RBSCUBFVPL	8754686115 Dell Way	\N	QFAQOEZ	WA	34272	US	1	RBSCUBFVPL@dell.com	8754686115	4	1741074594669044	2011/11	user691	password	53	100000	M
692	TLUVCW	OFQPLLFWBK	4789565728 Dell Way	\N	WRYBQWI	MS	69322	US	1	OFQPLLFWBK@dell.com	4789565728	1	5492251974064857	2012/02	user692	password	38	80000	M
693	BMQXAV	OQHZVDBFAT	2964422993 Dell Way	\N	ECKBLXS	TX	16704	US	1	OQHZVDBFAT@dell.com	2964422993	4	2507232973352074	2010/06	user693	password	69	60000	M
694	IMYEAO	LAKPCQQVVT	4124350144 Dell Way	\N	FWECPBE	SD	83292	US	1	LAKPCQQVVT@dell.com	4124350144	2	3106989020016044	2008/11	user694	password	28	40000	F
695	COJRAJ	BQLSHHNAMK	3711682644 Dell Way	\N	FPZGUUB	CT	18166	US	1	BQLSHHNAMK@dell.com	3711682644	1	9585844095796348	2010/07	user695	password	39	60000	F
696	RFEBHV	NACUNDHXIW	7603219150 Dell Way	\N	XPQRQTU	WI	93510	US	1	NACUNDHXIW@dell.com	7603219150	2	5411412164103240	2008/12	user696	password	63	80000	F
697	USLQFL	SAZVHXEDUT	9618143474 Dell Way	\N	UMKOHIM	AK	76453	US	1	SAZVHXEDUT@dell.com	9618143474	1	7129502426832915	2010/09	user697	password	79	40000	F
698	HARTSR	TOZQSCLLXY	6407127296 Dell Way	\N	VLFEXGX	TX	34472	US	1	TOZQSCLLXY@dell.com	6407127296	3	9940640832763166	2010/11	user698	password	50	80000	M
699	DMOUGC	UXVXJGUHCF	1324970715 Dell Way	\N	NHDUFZB	SD	48948	US	1	UXVXJGUHCF@dell.com	1324970715	2	3417355098761618	2010/12	user699	password	25	60000	F
700	RKSTEQ	PBZVWHYCVF	9018267172 Dell Way	\N	FPLEQGQ	NY	53966	US	1	PBZVWHYCVF@dell.com	9018267172	1	5285569304134697	2012/09	user700	password	88	80000	F
701	RLIIAK	HWGPUIKAOZ	7026632280 Dell Way	\N	MTQSJHF	IA	49635	US	1	HWGPUIKAOZ@dell.com	7026632280	2	2665786445140838	2011/11	user701	password	42	40000	F
702	RQJBYF	INARXAFXMY	4975576735 Dell Way	\N	NFHVKNG	AZ	79545	US	1	INARXAFXMY@dell.com	4975576735	4	7119575747288764	2011/01	user702	password	19	60000	M
703	JNPOVC	OMAPRXCQLH	8976089637 Dell Way	\N	XGRLNTF	WI	50220	US	1	OMAPRXCQLH@dell.com	8976089637	4	5166940174065531	2012/02	user703	password	26	40000	M
704	SVMUKZ	UARSCHDKEJ	7869126684 Dell Way	\N	CQXWVVH	OK	59518	US	1	UARSCHDKEJ@dell.com	7869126684	4	7387633331585676	2012/11	user704	password	45	60000	M
705	WJDVEE	NXHUARZKUP	4526329423 Dell Way	\N	HQLDYDR	OK	78484	US	1	NXHUARZKUP@dell.com	4526329423	3	6873391992412508	2011/03	user705	password	46	80000	M
706	NMTSZQ	ZTRRTBMIJC	3936078652 Dell Way	\N	UNBXETR	NE	41799	US	1	ZTRRTBMIJC@dell.com	3936078652	2	5707653830759228	2011/12	user706	password	23	40000	F
707	UYKLYE	CPYDCHNEBA	8998925378 Dell Way	\N	GYFAQUJ	WI	21226	US	1	CPYDCHNEBA@dell.com	8998925378	4	1862469865940511	2012/12	user707	password	57	80000	M
708	YEVDHK	BKNIYSJZYI	2560678934 Dell Way	\N	EYYYIXC	GA	62368	US	1	BKNIYSJZYI@dell.com	2560678934	1	5499265418387950	2011/12	user708	password	45	80000	F
709	EUKPWV	CFTUPSTXXR	8905079184 Dell Way	\N	WVAUXFJ	CA	44448	US	1	CFTUPSTXXR@dell.com	8905079184	5	3825001575052738	2009/06	user709	password	49	60000	F
710	VADQDJ	KYYCRWZJTV	3632136195 Dell Way	\N	JOTPYVZ	SC	67629	US	1	KYYCRWZJTV@dell.com	3632136195	1	1966524178162217	2011/06	user710	password	45	60000	M
711	NFRWPP	VSHSSRLNBZ	8797536642 Dell Way	\N	HQXDPST	VT	78945	US	1	VSHSSRLNBZ@dell.com	8797536642	4	3256055686157197	2009/03	user711	password	74	80000	F
712	LRZBMR	IEJZQXAPER	3227628733 Dell Way	\N	NHHGBEZ	VT	83220	US	1	IEJZQXAPER@dell.com	3227628733	1	1022748640272766	2008/12	user712	password	46	60000	M
713	JMBAVG	KVWHVMMNZU	7968418382 Dell Way	\N	UFVYFTU	MN	92080	US	1	KVWHVMMNZU@dell.com	7968418382	3	8665387465152890	2008/12	user713	password	50	60000	F
714	NOHUZC	QGYDTLCNFI	8622979050 Dell Way	\N	IEOCYAZ	OK	56241	US	1	QGYDTLCNFI@dell.com	8622979050	5	5113536835182458	2009/05	user714	password	83	100000	M
715	EPXGGE	EJYPMLVVUZ	4291328787 Dell Way	\N	JWYKWQX	OH	56236	US	1	EJYPMLVVUZ@dell.com	4291328787	5	9209596861619504	2009/10	user715	password	81	60000	F
716	URQZWA	XMMIHHDHQZ	3463276717 Dell Way	\N	FBVWYNJ	KS	58128	US	1	XMMIHHDHQZ@dell.com	3463276717	3	4128510221838951	2008/01	user716	password	72	100000	M
717	KXOKVB	WEIDHQUGVW	5581886257 Dell Way	\N	CRUQBDE	KS	73933	US	1	WEIDHQUGVW@dell.com	5581886257	3	7550868804566563	2009/05	user717	password	49	80000	F
718	ZBDBXH	JBOAWUVSWN	1786602058 Dell Way	\N	NNOQRWJ	FL	39855	US	1	JBOAWUVSWN@dell.com	1786602058	3	7520463991444559	2010/02	user718	password	20	60000	F
719	DOBKYD	YYATUSQHGD	8097903078 Dell Way	\N	WXVTGZB	KY	49803	US	1	YYATUSQHGD@dell.com	8097903078	5	5864932406693698	2012/05	user719	password	68	100000	M
720	TJWXIV	XCPQSXWWTT	6951212293 Dell Way	\N	RNAROJD	LA	31134	US	1	XCPQSXWWTT@dell.com	6951212293	1	6528382828924806	2009/02	user720	password	58	20000	M
721	LZVGXX	WNQUJMODEB	4567977227 Dell Way	\N	EVPOYZU	NJ	22206	US	1	WNQUJMODEB@dell.com	4567977227	5	3386559944599867	2012/01	user721	password	73	40000	F
722	PQZNNM	DHWPVAUWEP	8585649615 Dell Way	\N	MSOLNFP	VT	25272	US	1	DHWPVAUWEP@dell.com	8585649615	5	3232887439429760	2011/03	user722	password	41	40000	M
723	HSJTVQ	QLMQFIVVVO	1188672876 Dell Way	\N	KGBPVYU	NY	83503	US	1	QLMQFIVVVO@dell.com	1188672876	2	1482396938372403	2009/06	user723	password	85	80000	F
724	HKAYAM	KQSTLNOZYV	8808952505 Dell Way	\N	AORZIIV	KY	65975	US	1	KQSTLNOZYV@dell.com	8808952505	4	2015813930425793	2011/04	user724	password	40	20000	M
725	JBSVMJ	NFUBUUAQVO	4218810669 Dell Way	\N	HVWQQFG	MS	90336	US	1	NFUBUUAQVO@dell.com	4218810669	2	2827999179251492	2011/05	user725	password	84	20000	F
726	QWXZKD	UMYOMOKAVF	2917231478 Dell Way	\N	XMWDSJA	AZ	68546	US	1	UMYOMOKAVF@dell.com	2917231478	4	1396841381676495	2008/10	user726	password	53	80000	M
727	KSANMM	LBYALZWQXI	5865155218 Dell Way	\N	MABVACM	HI	86790	US	1	LBYALZWQXI@dell.com	5865155218	2	6541241975966842	2008/02	user727	password	35	60000	M
728	GYHSKI	RKTQHKNPXN	3067899096 Dell Way	\N	QTOTGUP	SC	20380	US	1	RKTQHKNPXN@dell.com	3067899096	5	2790997657459229	2010/03	user728	password	90	80000	F
729	HKOPCZ	JSGUGWSUNL	4775911105 Dell Way	\N	IHSCXNF	CT	39075	US	1	JSGUGWSUNL@dell.com	4775911105	3	6002273670397699	2010/04	user729	password	71	80000	M
730	HHUHRN	OMULEPYQXG	7671924311 Dell Way	\N	JADWGGE	NV	86516	US	1	OMULEPYQXG@dell.com	7671924311	1	2315066644921899	2010/10	user730	password	81	80000	F
731	RBTFQF	ZBKOABMGKM	6708576656 Dell Way	\N	JHSQLKM	GA	51441	US	1	ZBKOABMGKM@dell.com	6708576656	4	3033300021197647	2010/06	user731	password	39	20000	M
732	BJDHIE	RXFTJLEWVL	7118731320 Dell Way	\N	PLXZYCL	NE	79441	US	1	RXFTJLEWVL@dell.com	7118731320	1	2965484376996755	2012/03	user732	password	71	20000	M
733	WHYBZW	GTGSXCNISZ	3834820610 Dell Way	\N	FSXIEMC	TX	61666	US	1	GTGSXCNISZ@dell.com	3834820610	5	8338098315522076	2008/11	user733	password	48	100000	F
734	JZDFFW	LXTOLCHKIZ	2786477347 Dell Way	\N	IQEVTZJ	AR	83501	US	1	LXTOLCHKIZ@dell.com	2786477347	1	6916486956644804	2011/01	user734	password	76	100000	M
735	YFFUQC	OFNQMYZMGP	1984642080 Dell Way	\N	QBJQLKL	NM	55167	US	1	OFNQMYZMGP@dell.com	1984642080	2	5615254676435143	2012/03	user735	password	53	100000	F
736	RQBUEH	IVUGUGMKXO	2409998797 Dell Way	\N	TNZDZPQ	CA	86438	US	1	IVUGUGMKXO@dell.com	2409998797	5	1665171080268919	2011/10	user736	password	54	40000	F
737	ODQVLL	PRGWEQTSJH	2953250876 Dell Way	\N	RNGHEJD	KS	41696	US	1	PRGWEQTSJH@dell.com	2953250876	5	2634168653283268	2011/04	user737	password	64	40000	F
738	HCWSSO	ZPSPJLZQDN	8175982266 Dell Way	\N	XLRGOAQ	SC	97138	US	1	ZPSPJLZQDN@dell.com	8175982266	3	3391533577349037	2010/10	user738	password	67	80000	M
739	OLPCKF	VAOGAFKNCV	4949260799 Dell Way	\N	FJKFZFE	RI	73672	US	1	VAOGAFKNCV@dell.com	4949260799	2	5337655074894428	2008/12	user739	password	44	80000	F
740	ZTTEOU	TVUYGIBCNK	8954476707 Dell Way	\N	MSKSXEK	KY	44392	US	1	TVUYGIBCNK@dell.com	8954476707	3	3708977976348251	2009/02	user740	password	65	40000	M
741	KKLFEH	ZCNHDPVNCO	7974728010 Dell Way	\N	YULCEUM	AZ	33590	US	1	ZCNHDPVNCO@dell.com	7974728010	2	4482210706453771	2010/07	user741	password	37	100000	M
742	SADZAF	NIJDEXFSVA	6651257183 Dell Way	\N	EXFZJHG	DC	63915	US	1	NIJDEXFSVA@dell.com	6651257183	3	2417053313460201	2012/06	user742	password	27	80000	F
743	GPMMDV	VGZSMRNMWL	7403936271 Dell Way	\N	RWUYCYO	OK	57770	US	1	VGZSMRNMWL@dell.com	7403936271	4	9563819890841844	2012/03	user743	password	47	20000	M
744	XPYSKF	RDRJRDGCVC	3923714892 Dell Way	\N	XUEVIXJ	AR	55170	US	1	RDRJRDGCVC@dell.com	3923714892	5	7448877873830498	2011/01	user744	password	56	80000	M
745	MIARAD	IJUMPXIRUD	9731872296 Dell Way	\N	WQLTZNG	KS	47165	US	1	IJUMPXIRUD@dell.com	9731872296	1	4738316048868001	2010/09	user745	password	18	100000	F
746	AQADZJ	YMZVVRPYNG	7551879226 Dell Way	\N	KGFXNOI	MS	64134	US	1	YMZVVRPYNG@dell.com	7551879226	5	3503180544357747	2011/12	user746	password	38	80000	M
747	HXPQVC	QRXHHVUNFB	2634646384 Dell Way	\N	TCPHLBX	DC	16047	US	1	QRXHHVUNFB@dell.com	2634646384	5	1368470697198063	2010/08	user747	password	66	80000	M
748	HKJJAA	HHICCVIDPL	9228959376 Dell Way	\N	TXWUUAW	WV	92177	US	1	HHICCVIDPL@dell.com	9228959376	3	5864291983190924	2010/03	user748	password	22	100000	M
749	KGPLNX	TQZPYDEKWB	7675998301 Dell Way	\N	GRWHOVF	MO	35206	US	1	TQZPYDEKWB@dell.com	7675998301	1	5191109496634454	2011/11	user749	password	21	40000	F
750	QQROKH	OZFSDQOFXG	6981709939 Dell Way	\N	CEVXJHF	CO	41204	US	1	OZFSDQOFXG@dell.com	6981709939	5	3312946060206741	2011/02	user750	password	47	40000	M
751	BYDIMD	OEHETMBAOG	7515719725 Dell Way	\N	VMQDRTM	KY	68803	US	1	OEHETMBAOG@dell.com	7515719725	1	7971280148252846	2008/06	user751	password	57	20000	F
752	RNVVCZ	CGTOITDPOQ	4406485332 Dell Way	\N	FRHYERP	VA	74647	US	1	CGTOITDPOQ@dell.com	4406485332	1	2337987005244940	2012/03	user752	password	54	80000	M
753	IKUIMB	BBKVFZJVFB	6918974831 Dell Way	\N	DDGUTDN	CT	21164	US	1	BBKVFZJVFB@dell.com	6918974831	1	3792705083731562	2008/08	user753	password	18	60000	F
754	UVOVWQ	GRVFBRKDUO	9404874640 Dell Way	\N	JPHMCLQ	PA	52136	US	1	GRVFBRKDUO@dell.com	9404874640	5	2008436271455139	2012/05	user754	password	30	80000	F
755	SPCJVU	EAWVLAQZKF	3671925744 Dell Way	\N	HXHSNBE	MI	96293	US	1	EAWVLAQZKF@dell.com	3671925744	2	4220383147709072	2010/02	user755	password	59	20000	M
756	RNNLSO	HOZIEZSJGP	1393298141 Dell Way	\N	RZCSEOR	MN	93642	US	1	HOZIEZSJGP@dell.com	1393298141	5	1505547151435166	2011/02	user756	password	73	40000	M
757	HSJVAX	VICUBMBQDA	3200910612 Dell Way	\N	SWEGOQE	NH	62359	US	1	VICUBMBQDA@dell.com	3200910612	2	7302473333664239	2008/06	user757	password	44	40000	F
758	SCGQYP	SSQETGIUZF	9229515561 Dell Way	\N	ZGTQLJF	NY	60827	US	1	SSQETGIUZF@dell.com	9229515561	4	1513669119216501	2009/12	user758	password	38	100000	F
759	NQADJS	TOMAWGZCGF	8269394864 Dell Way	\N	VWQECIT	WY	98699	US	1	TOMAWGZCGF@dell.com	8269394864	2	9524072562344372	2008/04	user759	password	19	80000	M
760	ATGTMV	FMSMMUSSPP	6314656606 Dell Way	\N	JURRORQ	LA	93459	US	1	FMSMMUSSPP@dell.com	6314656606	3	2727810873184353	2011/01	user760	password	24	80000	M
761	JJHEPT	WBGQUYGJHB	8085674099 Dell Way	\N	AYPRPYP	FL	44591	US	1	WBGQUYGJHB@dell.com	8085674099	5	4912610466592014	2012/06	user761	password	33	40000	M
762	MKKGGM	NXGLEPTFPS	6048828596 Dell Way	\N	UHITWND	NV	37414	US	1	NXGLEPTFPS@dell.com	6048828596	3	7744273370597512	2011/10	user762	password	59	40000	F
763	ZNLMAJ	SMNIGSYYNF	8293853463 Dell Way	\N	GGCTKTB	WI	36101	US	1	SMNIGSYYNF@dell.com	8293853463	4	1599746772088110	2009/12	user763	password	36	40000	M
764	SWOBOA	OXGHVFVBLB	3242083426 Dell Way	\N	DFLXHKE	CA	21871	US	1	OXGHVFVBLB@dell.com	3242083426	3	2124991672579199	2010/11	user764	password	64	20000	M
765	EGHFVE	MDARYBDAFI	2224286853 Dell Way	\N	MCQWHSA	NC	26555	US	1	MDARYBDAFI@dell.com	2224286853	1	1311663618311286	2011/03	user765	password	71	100000	F
766	AEIFQL	FHJHKKNTWQ	3807670619 Dell Way	\N	JTXCTMH	VA	55264	US	1	FHJHKKNTWQ@dell.com	3807670619	4	7654159458354116	2008/08	user766	password	34	20000	M
767	OGKZMS	JTDUHWQXGK	5724616162 Dell Way	\N	VJDHQBU	WI	74481	US	1	JTDUHWQXGK@dell.com	5724616162	5	4113819369114935	2011/01	user767	password	27	40000	F
768	OHUGRO	JLVGBTNMOW	7472550505 Dell Way	\N	PVNRQMJ	DC	51236	US	1	JLVGBTNMOW@dell.com	7472550505	5	5638543144799769	2012/03	user768	password	78	60000	F
769	QREEAP	AHRTVDHSTD	6852249437 Dell Way	\N	FKTRUXD	MS	81688	US	1	AHRTVDHSTD@dell.com	6852249437	2	9987411529757084	2010/10	user769	password	53	20000	F
770	QGLGHT	XAOBHGUKMF	8742006450 Dell Way	\N	EEZBHMW	WI	83063	US	1	XAOBHGUKMF@dell.com	8742006450	3	6119507536292077	2009/07	user770	password	90	20000	M
771	LGBFEB	TFJAZUNEYR	9998010127 Dell Way	\N	EAZQWXL	OR	40487	US	1	TFJAZUNEYR@dell.com	9998010127	1	8738408346660436	2012/02	user771	password	65	60000	F
772	SQNUKS	DLSXYXWQBW	7410848219 Dell Way	\N	PRTNCMW	CO	62886	US	1	DLSXYXWQBW@dell.com	7410848219	1	7127542167901993	2009/07	user772	password	19	20000	F
773	NVOFZZ	YXYVTOWQEO	2451859660 Dell Way	\N	KRQXNTM	IA	85684	US	1	YXYVTOWQEO@dell.com	2451859660	3	4258567238692194	2008/09	user773	password	55	80000	M
774	BYMBWJ	ZSDNOTRDEJ	7560051317 Dell Way	\N	UBXNNDJ	OH	74871	US	1	ZSDNOTRDEJ@dell.com	7560051317	5	4491319450549781	2009/07	user774	password	83	40000	M
775	JIJTIC	WVQQNUUXOW	1117011271 Dell Way	\N	UBKXLCQ	DE	96635	US	1	WVQQNUUXOW@dell.com	1117011271	3	5898016650229693	2012/09	user775	password	22	40000	F
776	LBJNYF	EOTYJQMGLO	2997405120 Dell Way	\N	QIASYER	WV	63013	US	1	EOTYJQMGLO@dell.com	2997405120	5	3716124751605094	2009/03	user776	password	44	80000	F
777	SGDYKS	RJCIWITKYC	5497822758 Dell Way	\N	LRAPJAF	NE	89083	US	1	RJCIWITKYC@dell.com	5497822758	5	1418509825132787	2012/07	user777	password	36	60000	M
778	KNGCFP	FNLOHWNJIE	3969060183 Dell Way	\N	KXNKDCH	NJ	96783	US	1	FNLOHWNJIE@dell.com	3969060183	3	5914548789151013	2010/01	user778	password	45	100000	M
779	PCUFII	RWPOJZWNJU	7094782559 Dell Way	\N	BUXEBND	MA	10776	US	1	RWPOJZWNJU@dell.com	7094782559	5	1590785658452659	2008/12	user779	password	64	80000	F
780	LWJTOG	IDPHZDRUEL	3748357955 Dell Way	\N	SINGMXG	DC	89339	US	1	IDPHZDRUEL@dell.com	3748357955	2	8647617402952165	2012/11	user780	password	85	40000	M
781	HCIOLL	DTKGLFKXXT	1330879366 Dell Way	\N	KDGHJKE	NY	63402	US	1	DTKGLFKXXT@dell.com	1330879366	4	5131163554266095	2012/12	user781	password	33	40000	F
782	NUOYYI	JETOPQMJAP	1430059941 Dell Way	\N	PIZZNQP	ND	34469	US	1	JETOPQMJAP@dell.com	1430059941	3	3409878097474575	2009/10	user782	password	45	80000	M
783	YSNGBS	ZQHPCRQSGZ	8699107526 Dell Way	\N	RGNIWBP	VA	63749	US	1	ZQHPCRQSGZ@dell.com	8699107526	1	4449909077025950	2009/12	user783	password	89	20000	M
784	MKSFJJ	MZLEQDLPVR	2550461302 Dell Way	\N	DDNESLU	NE	62989	US	1	MZLEQDLPVR@dell.com	2550461302	5	5609423382207752	2008/12	user784	password	28	80000	F
785	WVSFIR	QMIUXXQPAT	7142969626 Dell Way	\N	DFMPABE	FL	86365	US	1	QMIUXXQPAT@dell.com	7142969626	2	8258642869070173	2012/12	user785	password	29	80000	M
786	WXEOOQ	WIOUYEVSIB	8910211298 Dell Way	\N	EXBFCGB	PA	62540	US	1	WIOUYEVSIB@dell.com	8910211298	3	6044713526032866	2008/04	user786	password	45	100000	F
787	NLSEIB	TDAYYTGZXE	5006114435 Dell Way	\N	BDGHFAW	CA	64585	US	1	TDAYYTGZXE@dell.com	5006114435	1	8984876440837980	2012/01	user787	password	22	40000	F
788	UOUVHY	WGWPMWNRXQ	4874907765 Dell Way	\N	XFWYCYO	NC	15020	US	1	WGWPMWNRXQ@dell.com	4874907765	2	1677089987322688	2010/09	user788	password	58	40000	F
789	JCOHZU	DOHZBYXSWC	6630884536 Dell Way	\N	OUEMJSO	RI	16264	US	1	DOHZBYXSWC@dell.com	6630884536	2	8016718860249967	2008/07	user789	password	20	60000	M
790	OVPJZE	QZGOWYLYNG	7383902458 Dell Way	\N	DAPWOJY	FL	67823	US	1	QZGOWYLYNG@dell.com	7383902458	2	2618006969336420	2011/11	user790	password	78	40000	M
791	LRRPHQ	WWNUHMIOQI	4053121083 Dell Way	\N	DMWNKBE	CT	46144	US	1	WWNUHMIOQI@dell.com	4053121083	5	3682824565097690	2008/03	user791	password	19	60000	M
792	SFDJBZ	WWHJEVZMZL	1773597694 Dell Way	\N	INWKRZU	AK	84787	US	1	WWHJEVZMZL@dell.com	1773597694	1	1005562708713114	2008/10	user792	password	78	100000	M
793	YEAYAX	GJBCJNBUWO	5079893543 Dell Way	\N	QGGQBGL	CT	46821	US	1	GJBCJNBUWO@dell.com	5079893543	2	2558702121023088	2009/01	user793	password	28	40000	F
794	EFGBLQ	CNZQPTNEKU	3160050532 Dell Way	\N	KAVRMYB	WA	27183	US	1	CNZQPTNEKU@dell.com	3160050532	2	3103714918717742	2009/06	user794	password	50	60000	M
795	RQCHTQ	HJGAXKLRVM	8809453492 Dell Way	\N	MMZLOXQ	SC	21954	US	1	HJGAXKLRVM@dell.com	8809453492	1	6466352286282927	2009/09	user795	password	38	100000	F
796	KHBAOL	GPIRBAMOMY	2386014233 Dell Way	\N	NYNKOHO	MI	51091	US	1	GPIRBAMOMY@dell.com	2386014233	4	2652814599219709	2010/09	user796	password	56	100000	F
797	PVPBCF	KTHKGVXFIV	6694293239 Dell Way	\N	STKZHVL	MI	63190	US	1	KTHKGVXFIV@dell.com	6694293239	5	3953370531089604	2008/09	user797	password	44	80000	M
798	ZVQEFK	LQQGNVOJOH	5671465311 Dell Way	\N	TNPPZAE	NJ	89204	US	1	LQQGNVOJOH@dell.com	5671465311	4	6100912380497903	2012/07	user798	password	25	100000	F
799	TAPDMF	TSSPHBDPVR	6765409057 Dell Way	\N	ELRFQHB	DC	16993	US	1	TSSPHBDPVR@dell.com	6765409057	1	6628377663902939	2011/11	user799	password	90	60000	M
800	PPIUJB	NZJPDYKVDW	5420927644 Dell Way	\N	MIMUKQW	AL	67412	US	1	NZJPDYKVDW@dell.com	5420927644	4	5515760165639222	2010/03	user800	password	46	20000	M
801	SWFUJE	DZICKDFGQO	5247962210 Dell Way	\N	SKYIHZZ	PA	78297	US	1	DZICKDFGQO@dell.com	5247962210	2	1068047877401113	2012/04	user801	password	80	60000	F
802	BJOGNN	OQXSVDIKWS	1771118126 Dell Way	\N	IEZIETC	NM	10093	US	1	OQXSVDIKWS@dell.com	1771118126	3	3866477750707418	2012/01	user802	password	54	20000	F
803	BGZOVP	LNLPVVLOEQ	6583209729 Dell Way	\N	OMUHOLH	NM	92123	US	1	LNLPVVLOEQ@dell.com	6583209729	3	9836328010074796	2008/08	user803	password	49	20000	M
804	KSSZEF	KUBGFQKWEW	9879227189 Dell Way	\N	RMLCUBA	MD	69007	US	1	KUBGFQKWEW@dell.com	9879227189	3	3261769759468734	2010/09	user804	password	26	100000	F
805	VUOBFI	DLOTVLYSCK	1933571027 Dell Way	\N	DFFFFPW	FL	20395	US	1	DLOTVLYSCK@dell.com	1933571027	4	8139498687814922	2009/05	user805	password	31	20000	F
806	TCKCFV	RYRDWJFHMK	9856443420 Dell Way	\N	MRQBNUE	NM	46650	US	1	RYRDWJFHMK@dell.com	9856443420	5	8350958015769721	2008/11	user806	password	19	100000	M
807	KAEGSC	XVZGBGSMTK	2046962348 Dell Way	\N	CVYXAOH	WY	46218	US	1	XVZGBGSMTK@dell.com	2046962348	1	3562139090150595	2008/02	user807	password	35	60000	F
808	KUWNRR	MYSTRFMBHH	2966617337 Dell Way	\N	ZEHNMHY	NH	50515	US	1	MYSTRFMBHH@dell.com	2966617337	4	5899786602240056	2010/04	user808	password	67	100000	F
809	NJTFWR	YPIDBJKJJP	9570400736 Dell Way	\N	RWBYVRK	AL	44404	US	1	YPIDBJKJJP@dell.com	9570400736	3	6847422920167447	2011/05	user809	password	69	20000	M
810	LJPCHE	LKGUVQDKHA	2526610672 Dell Way	\N	MGVDRWN	NJ	44151	US	1	LKGUVQDKHA@dell.com	2526610672	2	7710008225869388	2012/05	user810	password	53	40000	M
811	BKAGVL	NQGDURLVES	6955792508 Dell Way	\N	RHJNVZX	WY	31205	US	1	NQGDURLVES@dell.com	6955792508	5	6697997181676329	2008/03	user811	password	45	40000	M
812	KMKWAB	DDVVPQZIHH	5879617618 Dell Way	\N	RVCRTCX	ME	94527	US	1	DDVVPQZIHH@dell.com	5879617618	3	1989278597757220	2012/10	user812	password	68	40000	F
813	CFGEIK	ADAQDIYKAU	6444241634 Dell Way	\N	MRNOPYM	DC	55811	US	1	ADAQDIYKAU@dell.com	6444241634	1	3604313926771283	2009/05	user813	password	58	60000	M
814	VPYFPC	GFFOEPPYBH	3081338367 Dell Way	\N	MQWLCAY	OK	16513	US	1	GFFOEPPYBH@dell.com	3081338367	1	5296962875407189	2011/06	user814	password	24	60000	F
815	AVPCBV	HQZXGYYNKO	9448952294 Dell Way	\N	JWRKUKL	AL	48227	US	1	HQZXGYYNKO@dell.com	9448952294	5	8692994818091393	2008/05	user815	password	81	20000	F
816	LEHGMY	GJEEIRPXBL	3343974197 Dell Way	\N	OLGZXGK	TX	15913	US	1	GJEEIRPXBL@dell.com	3343974197	5	5174827239010483	2008/11	user816	password	67	60000	F
817	ZVNXCX	BHFTWCUIRG	4204556513 Dell Way	\N	OQDVBZX	IN	87159	US	1	BHFTWCUIRG@dell.com	4204556513	3	7959212558809669	2008/01	user817	password	79	20000	M
818	JXYHZG	MTCONLFUZW	5887997346 Dell Way	\N	XVXXSFU	AZ	68453	US	1	MTCONLFUZW@dell.com	5887997346	1	6941841526422650	2009/02	user818	password	55	80000	F
819	MBASNT	VBHGHBGEZB	6361772642 Dell Way	\N	BXUHRWY	HI	97334	US	1	VBHGHBGEZB@dell.com	6361772642	4	1867817017249763	2008/05	user819	password	28	60000	F
820	EHYYCA	GIIIOMIQOF	4151572491 Dell Way	\N	LVXHTDG	LA	75963	US	1	GIIIOMIQOF@dell.com	4151572491	3	2028062057681381	2010/01	user820	password	57	80000	F
821	MPLMVT	UDIHMZVRKQ	5949554680 Dell Way	\N	PRKSYTL	IL	30008	US	1	UDIHMZVRKQ@dell.com	5949554680	4	3463046416174620	2008/06	user821	password	62	60000	F
822	ABXUWB	DDNCYENOTF	2961968964 Dell Way	\N	ZMDSXLY	MN	30606	US	1	DDNCYENOTF@dell.com	2961968964	3	7085031891707332	2012/02	user822	password	70	100000	F
823	PRARUD	EXCJKQDQQP	2141252304 Dell Way	\N	UIMFHYL	MS	54836	US	1	EXCJKQDQQP@dell.com	2141252304	2	6451601305976511	2012/03	user823	password	73	60000	M
824	UDQXHN	AQYQTOGIJP	9074522634 Dell Way	\N	VOXUAKH	DC	75257	US	1	AQYQTOGIJP@dell.com	9074522634	1	9223628821317108	2011/06	user824	password	73	60000	M
825	KJWXJN	WAGLHPUXLJ	8409233759 Dell Way	\N	UGJENNX	ME	57627	US	1	WAGLHPUXLJ@dell.com	8409233759	1	9970497234724464	2010/07	user825	password	60	100000	M
826	MXHZTH	GEPWZMHIGO	7907514467 Dell Way	\N	SLBGJNU	FL	63594	US	1	GEPWZMHIGO@dell.com	7907514467	4	2207871700637042	2009/09	user826	password	20	100000	M
827	IUJPBO	EXNREWXSOJ	1312715890 Dell Way	\N	UVSHPXX	LA	69118	US	1	EXNREWXSOJ@dell.com	1312715890	4	4455487539526075	2008/07	user827	password	90	40000	F
828	JZJXEG	LVLHTEWDZS	8107164054 Dell Way	\N	WHHTEQK	HI	40984	US	1	LVLHTEWDZS@dell.com	8107164054	2	8870204302482308	2011/09	user828	password	32	20000	M
829	OBWVNS	HUMMRQLJMT	5606049808 Dell Way	\N	RFYHQDQ	MD	50238	US	1	HUMMRQLJMT@dell.com	5606049808	1	2242894087452441	2011/05	user829	password	78	40000	F
830	SDXLKS	XWKNHUZALF	7243662112 Dell Way	\N	YTVCJGO	VA	49891	US	1	XWKNHUZALF@dell.com	7243662112	3	8106942642480136	2010/11	user830	password	32	40000	M
831	CQKVOG	GCOACPLHOF	6508331350 Dell Way	\N	DROJFLV	VT	13995	US	1	GCOACPLHOF@dell.com	6508331350	3	9339430412743242	2012/08	user831	password	85	100000	F
832	ITWOZZ	DABSLJHQMY	6720564257 Dell Way	\N	FWERSBS	IN	55316	US	1	DABSLJHQMY@dell.com	6720564257	1	2486765015404671	2010/01	user832	password	53	100000	M
833	JLUIOU	KHGTOXGNCD	4602486633 Dell Way	\N	RUVTMDG	CT	32809	US	1	KHGTOXGNCD@dell.com	4602486633	4	3648450216744095	2012/07	user833	password	24	40000	F
834	WOPQZW	XSLUZYXCQR	6386307223 Dell Way	\N	XJEBPHH	WY	97129	US	1	XSLUZYXCQR@dell.com	6386307223	5	5761311258655042	2011/02	user834	password	57	60000	M
835	DFQACJ	LWIKTKALIJ	4439897107 Dell Way	\N	PJYXRYW	IL	82694	US	1	LWIKTKALIJ@dell.com	4439897107	5	9199770295526832	2012/07	user835	password	60	20000	M
836	FBUOMR	XXKHYWQHLA	9301909259 Dell Way	\N	GISFFZA	NE	96016	US	1	XXKHYWQHLA@dell.com	9301909259	3	5261891743633896	2010/07	user836	password	31	80000	M
837	ZHCQEZ	BMXXDFJDMS	3407659034 Dell Way	\N	WRXVSMU	NJ	98651	US	1	BMXXDFJDMS@dell.com	3407659034	1	5749153857119382	2010/11	user837	password	26	60000	F
838	FBIFDV	DBZIKDVDZN	1305150137 Dell Way	\N	AVFNPVN	UT	96745	US	1	DBZIKDVDZN@dell.com	1305150137	2	8367902665864677	2008/10	user838	password	88	40000	M
839	IOYERZ	DAKGVNFJOA	2696490156 Dell Way	\N	OCQKPMJ	NJ	83741	US	1	DAKGVNFJOA@dell.com	2696490156	4	6166955298278481	2008/02	user839	password	47	60000	M
840	JQJITJ	TAFGFOVGDX	7792034930 Dell Way	\N	WOMJXDE	CO	90506	US	1	TAFGFOVGDX@dell.com	7792034930	2	1225551469717174	2008/09	user840	password	69	60000	F
841	BVDLOD	RVJFRPJOLX	1981571048 Dell Way	\N	BVVEZYC	PA	28876	US	1	RVJFRPJOLX@dell.com	1981571048	5	9576540032401682	2012/05	user841	password	41	100000	F
842	LIUPZQ	YFHNPWZMYU	4935532788 Dell Way	\N	IDUHFNM	KS	47577	US	1	YFHNPWZMYU@dell.com	4935532788	1	8335607972461731	2011/01	user842	password	21	40000	F
843	WVIMTO	UGDRGQQAYT	5835751741 Dell Way	\N	UFZHSHS	DC	50517	US	1	UGDRGQQAYT@dell.com	5835751741	5	5346759950742126	2010/02	user843	password	79	60000	M
844	EYRTTY	WKEMAFLUZR	9989257715 Dell Way	\N	THJBANN	ND	50716	US	1	WKEMAFLUZR@dell.com	9989257715	1	6311969075351954	2012/07	user844	password	57	20000	M
845	FTGEQQ	JCROOMOFFW	2543467102 Dell Way	\N	PHWDVKP	SD	59771	US	1	JCROOMOFFW@dell.com	2543467102	4	2142626446671784	2011/09	user845	password	64	100000	F
846	WDBNMD	FBRRQXXMME	4977290662 Dell Way	\N	IPZTEUI	LA	50020	US	1	FBRRQXXMME@dell.com	4977290662	1	2045144577510655	2008/01	user846	password	57	100000	F
847	PMQSRS	KIIHFUUKDK	7719789814 Dell Way	\N	KXPEFYQ	NY	11931	US	1	KIIHFUUKDK@dell.com	7719789814	4	1296712536830455	2009/09	user847	password	30	100000	F
848	UPVMAE	VIJQCUUMER	1678803013 Dell Way	\N	BIXAZOB	OK	38590	US	1	VIJQCUUMER@dell.com	1678803013	1	1080195208080112	2009/11	user848	password	30	20000	F
849	ZNNDJV	NZXHTKLKMU	3046911502 Dell Way	\N	INUXOMF	NJ	55634	US	1	NZXHTKLKMU@dell.com	3046911502	5	4566414693836123	2009/11	user849	password	83	40000	F
850	KNUFBT	DIMOUXAPGN	7833621939 Dell Way	\N	JDBWJRJ	NE	59384	US	1	DIMOUXAPGN@dell.com	7833621939	5	5031894546002150	2011/05	user850	password	82	20000	M
851	RHYKKH	XZCUZRANBE	3450093597 Dell Way	\N	PXNHHCV	AL	16864	US	1	XZCUZRANBE@dell.com	3450093597	4	4973295143805444	2008/09	user851	password	43	100000	F
852	HFKPCJ	SXJKYWLCMJ	3207466769 Dell Way	\N	QTQSOQU	TX	39306	US	1	SXJKYWLCMJ@dell.com	3207466769	5	1484423711895942	2010/10	user852	password	21	100000	F
853	MMDWFA	FPZCABOJSI	1220878047 Dell Way	\N	ZLXQGTZ	MO	75476	US	1	FPZCABOJSI@dell.com	1220878047	1	5774158226791770	2008/12	user853	password	57	60000	F
854	RKQSPG	RSHTHQLPQW	5268365544 Dell Way	\N	MHDFGPY	IL	69943	US	1	RSHTHQLPQW@dell.com	5268365544	2	6624991680961103	2008/12	user854	password	23	80000	F
855	SKXZBQ	GVXXGMODZV	2329311211 Dell Way	\N	GFCWDKN	NJ	78189	US	1	GVXXGMODZV@dell.com	2329311211	4	7072082614060492	2009/04	user855	password	90	100000	M
856	XYUNEP	LBWYPAYLGD	4166077455 Dell Way	\N	NDGXQWR	SC	56928	US	1	LBWYPAYLGD@dell.com	4166077455	1	8674194284714759	2009/12	user856	password	60	40000	M
857	JUBZFD	VESVCDCFRF	7577601250 Dell Way	\N	MPWJHQW	NJ	68803	US	1	VESVCDCFRF@dell.com	7577601250	5	6616520183626563	2009/03	user857	password	55	80000	M
858	PQFSLJ	KHLOJRFPDV	4122659376 Dell Way	\N	LNCBJSS	CO	69658	US	1	KHLOJRFPDV@dell.com	4122659376	3	8819677113089711	2012/02	user858	password	80	60000	M
859	BDELOM	XCWOILSDWF	4993920492 Dell Way	\N	FYPXRSO	AK	20913	US	1	XCWOILSDWF@dell.com	4993920492	5	2907235841266811	2009/04	user859	password	86	40000	F
860	DVZPSC	LHKXANTFTR	8652687725 Dell Way	\N	VRJNFJQ	NY	30346	US	1	LHKXANTFTR@dell.com	8652687725	5	5879573713988066	2011/05	user860	password	90	100000	F
861	ZNWCZD	MWEAQJUIEL	8115439071 Dell Way	\N	RSRAIIG	FL	37006	US	1	MWEAQJUIEL@dell.com	8115439071	5	6779200116638095	2011/11	user861	password	76	80000	F
862	RWKVJH	ZKXIEFNPXG	5689650504 Dell Way	\N	GXPPEUW	WI	78153	US	1	ZKXIEFNPXG@dell.com	5689650504	4	6935680307913572	2009/07	user862	password	24	100000	F
863	MUTTTE	RCIXQYUWFR	6880903254 Dell Way	\N	MUVGQUZ	DE	57697	US	1	RCIXQYUWFR@dell.com	6880903254	3	1467243010643869	2011/06	user863	password	50	40000	F
864	FZAKRD	SOURIRWADQ	3116385150 Dell Way	\N	WJHQJLE	AK	95127	US	1	SOURIRWADQ@dell.com	3116385150	4	4711448788642883	2011/12	user864	password	67	100000	M
865	SHQVAF	QRNHOOKEKU	3643828108 Dell Way	\N	MBDYGDW	MO	90525	US	1	QRNHOOKEKU@dell.com	3643828108	1	8869603005703540	2012/01	user865	password	80	80000	F
866	MNJRDB	FKQTVUDPHF	6786183323 Dell Way	\N	SFLWCXT	MD	16169	US	1	FKQTVUDPHF@dell.com	6786183323	2	2140186361502856	2010/01	user866	password	52	100000	M
867	VRRXWB	NQXIUMPZFV	5794405292 Dell Way	\N	LCYIWIK	MS	72356	US	1	NQXIUMPZFV@dell.com	5794405292	5	7498718384187669	2008/12	user867	password	36	100000	M
868	XTNZHE	WPYJFXOBIQ	7531532219 Dell Way	\N	ZRMICZA	NJ	98118	US	1	WPYJFXOBIQ@dell.com	7531532219	4	9573150591924788	2012/06	user868	password	61	100000	F
869	DWNHTC	FCIDQJMHJD	7277793716 Dell Way	\N	URGTRWT	MA	53945	US	1	FCIDQJMHJD@dell.com	7277793716	2	9701257538050414	2009/04	user869	password	32	60000	F
870	SRWVXY	DAPNMWWQRN	2831185815 Dell Way	\N	XKETEOG	UT	93976	US	1	DAPNMWWQRN@dell.com	2831185815	1	2771164829842746	2010/07	user870	password	42	20000	F
871	FYEEBE	TORQKIHYFS	8209424052 Dell Way	\N	CYXRETP	MD	91560	US	1	TORQKIHYFS@dell.com	8209424052	4	5295336346141994	2008/11	user871	password	71	40000	M
872	XNXBGM	TXXBFVGYYF	9500991344 Dell Way	\N	VPKOFVM	AK	64698	US	1	TXXBFVGYYF@dell.com	9500991344	1	5651618415024132	2011/06	user872	password	43	60000	M
873	GQGSJE	PLJKSHIXCY	3418960027 Dell Way	\N	IRDDDDT	CA	35237	US	1	PLJKSHIXCY@dell.com	3418960027	4	7828197817318142	2011/05	user873	password	72	100000	M
874	ZPJEEU	NPMVYKYWTQ	2849586226 Dell Way	\N	AXTEQVL	VT	64941	US	1	NPMVYKYWTQ@dell.com	2849586226	3	9514565317425878	2012/05	user874	password	85	100000	M
875	GCEBQT	OMSYKPRAPP	2793685188 Dell Way	\N	UUFQFDG	ME	68754	US	1	OMSYKPRAPP@dell.com	2793685188	2	1450526976957917	2008/04	user875	password	20	40000	F
876	ELBYZN	QYYGQZVFUP	3159148945 Dell Way	\N	KLVNRGE	VA	66369	US	1	QYYGQZVFUP@dell.com	3159148945	1	9497629040852190	2009/05	user876	password	44	60000	M
877	LKVZBT	XHJXDOSTZD	4629052861 Dell Way	\N	PNVVSSL	WA	74625	US	1	XHJXDOSTZD@dell.com	4629052861	2	1988913540728390	2011/08	user877	password	86	40000	F
878	TEDMCL	WAOKSIJWXW	3023624404 Dell Way	\N	RTOKFNC	NH	74277	US	1	WAOKSIJWXW@dell.com	3023624404	2	4409796364605427	2008/07	user878	password	51	100000	M
879	PKVAHV	PROYBKVYCP	2152647493 Dell Way	\N	NMUAPJT	TN	77131	US	1	PROYBKVYCP@dell.com	2152647493	1	3875681566540152	2010/12	user879	password	22	20000	F
880	XFQTVI	ITJSPIVEWI	4552039134 Dell Way	\N	YXYIQUB	PA	80347	US	1	ITJSPIVEWI@dell.com	4552039134	2	7395308996550740	2010/07	user880	password	22	40000	M
881	RCOZKI	JDYSZCOHBL	5470896116 Dell Way	\N	FKCALVU	TX	27354	US	1	JDYSZCOHBL@dell.com	5470896116	2	7473966892343015	2010/09	user881	password	51	40000	M
882	AGEIQI	GIHJXPLIVV	2517279786 Dell Way	\N	KVHGPDL	CO	50025	US	1	GIHJXPLIVV@dell.com	2517279786	4	2054833462461829	2011/11	user882	password	83	80000	F
883	CZTKGC	SQZHBHCWSX	8547822363 Dell Way	\N	DZNHKQS	NH	34519	US	1	SQZHBHCWSX@dell.com	8547822363	2	2538483558222651	2011/11	user883	password	40	100000	M
884	BFDEYT	DFVLIREGVD	8324122413 Dell Way	\N	TCOJVDQ	NV	42054	US	1	DFVLIREGVD@dell.com	8324122413	2	3000564624089748	2008/03	user884	password	23	20000	F
885	FJJYMP	TYXLCDHFXJ	5415042860 Dell Way	\N	UHFXXWG	OR	33392	US	1	TYXLCDHFXJ@dell.com	5415042860	5	5261783055495471	2010/01	user885	password	84	80000	F
886	HSXXMW	UYYYFEWPYD	4377207613 Dell Way	\N	UWBQDUX	NJ	69348	US	1	UYYYFEWPYD@dell.com	4377207613	1	7465159628540278	2009/12	user886	password	28	60000	M
887	BMEXHD	WGIBCXZGRW	5412494686 Dell Way	\N	IIZCFPU	NH	82126	US	1	WGIBCXZGRW@dell.com	5412494686	5	7919376709032805	2011/06	user887	password	51	80000	M
888	QPFTML	CNOZNVRJDA	5800982047 Dell Way	\N	JGFZAVT	MS	75031	US	1	CNOZNVRJDA@dell.com	5800982047	1	2774918543640524	2012/10	user888	password	28	80000	F
889	JKXVNK	KNXFEHIEQO	2526422326 Dell Way	\N	KPOGJBZ	VA	26656	US	1	KNXFEHIEQO@dell.com	2526422326	5	9983394590672108	2009/07	user889	password	48	80000	M
890	HNMSXZ	PCEXKJNYTD	7829903685 Dell Way	\N	NAMOZJT	DE	33596	US	1	PCEXKJNYTD@dell.com	7829903685	3	8204243630170823	2008/02	user890	password	73	60000	M
891	FENEUQ	IRAREZLHMM	2861284529 Dell Way	\N	UBLDVQK	NH	17908	US	1	IRAREZLHMM@dell.com	2861284529	4	3118789905682206	2012/03	user891	password	82	20000	F
892	KJEBSV	BKABWIOICP	7612372712 Dell Way	\N	UGLKQAM	TX	81687	US	1	BKABWIOICP@dell.com	7612372712	5	1260741314385086	2011/12	user892	password	49	20000	F
893	PCBLDM	MEIUSRWILC	6777991513 Dell Way	\N	UWTVJPP	CO	46187	US	1	MEIUSRWILC@dell.com	6777991513	4	4516005919780582	2008/10	user893	password	72	80000	M
894	VDZHPE	QJXHFGTIBQ	5184442287 Dell Way	\N	CWZRMCB	CO	83776	US	1	QJXHFGTIBQ@dell.com	5184442287	1	6266507019754500	2009/11	user894	password	49	20000	M
895	LIOPYX	NFDUZMVPOR	1755597658 Dell Way	\N	PGDRHGM	RI	49803	US	1	NFDUZMVPOR@dell.com	1755597658	5	3692809578496963	2010/01	user895	password	38	100000	F
896	VOGTCM	XWMJSBYKQE	5872856938 Dell Way	\N	OIMUVGG	VT	29690	US	1	XWMJSBYKQE@dell.com	5872856938	3	3059632373508066	2012/05	user896	password	58	80000	M
897	VKAIHX	URPVPAMTOU	9078145749 Dell Way	\N	FIQLPNR	CT	96087	US	1	URPVPAMTOU@dell.com	9078145749	5	3935472510755062	2010/08	user897	password	36	40000	M
898	HPGEJX	UFNURGIMMR	9393165834 Dell Way	\N	DXGQPJP	MO	38888	US	1	UFNURGIMMR@dell.com	9393165834	5	9154695056378842	2008/03	user898	password	82	60000	M
899	DREBLJ	OGBVPNHHQE	2250020348 Dell Way	\N	NHUXXGG	TN	26742	US	1	OGBVPNHHQE@dell.com	2250020348	1	4526692716404796	2008/06	user899	password	31	20000	F
900	IFPSUW	TPLGXTXCGF	7190683899 Dell Way	\N	WECCKYH	NC	96477	US	1	TPLGXTXCGF@dell.com	7190683899	3	5112753248773515	2012/09	user900	password	62	40000	M
901	FXTCQJ	OXGHUIOAFS	5116391979 Dell Way	\N	CIDBPRA	IN	30718	US	1	OXGHUIOAFS@dell.com	5116391979	1	9681554378475996	2008/05	user901	password	85	40000	F
902	RJXBYU	IFPRTPWMSE	5017821376 Dell Way	\N	PTUGTCM	GA	32637	US	1	IFPRTPWMSE@dell.com	5017821376	2	6627568449825049	2009/07	user902	password	83	20000	M
903	UDWPLC	FDVUZINEXG	9368859111 Dell Way	\N	ZDZBQEH	CA	51480	US	1	FDVUZINEXG@dell.com	9368859111	3	1196529461070895	2012/07	user903	password	88	80000	M
904	VGCYLF	UGFCTKZAJD	7099979624 Dell Way	\N	AKTFSVR	NV	36980	US	1	UGFCTKZAJD@dell.com	7099979624	3	8386782085523010	2011/02	user904	password	52	60000	F
905	OKUUEB	AGVKGVUJVF	1969235124 Dell Way	\N	DAXZROH	LA	14671	US	1	AGVKGVUJVF@dell.com	1969235124	1	2521049773786217	2010/06	user905	password	56	20000	M
906	IYCKZI	FJPBEZWJCX	1572134628 Dell Way	\N	HCPVJYX	MO	97065	US	1	FJPBEZWJCX@dell.com	1572134628	1	5102580757346004	2010/03	user906	password	43	100000	F
907	LIDUNN	JPRIMALJHN	4271859591 Dell Way	\N	ZDXYAKX	CA	51916	US	1	JPRIMALJHN@dell.com	4271859591	4	7135870674159378	2011/08	user907	password	79	20000	M
908	ZYMMHB	DQNEBXLPWP	1426653460 Dell Way	\N	NVPXTSJ	CA	44467	US	1	DQNEBXLPWP@dell.com	1426653460	5	9929929275996984	2012/12	user908	password	85	100000	M
909	KIELMV	ZQWWCMTRZP	4313412357 Dell Way	\N	HWIZFKJ	IL	30807	US	1	ZQWWCMTRZP@dell.com	4313412357	1	2782912817317992	2009/01	user909	password	24	80000	F
910	HDWCCN	ZZQLTHKIPH	5554496468 Dell Way	\N	RPNBYUI	KS	95465	US	1	ZZQLTHKIPH@dell.com	5554496468	4	9867172189988196	2011/04	user910	password	44	100000	F
911	GZOTZN	JKHRVQGCHV	3703021200 Dell Way	\N	PJUJRDI	DE	77007	US	1	JKHRVQGCHV@dell.com	3703021200	4	1439014952629804	2011/08	user911	password	53	100000	M
912	AQQOAA	WRVMYXTUNC	5401944699 Dell Way	\N	OWUSEYL	MO	75106	US	1	WRVMYXTUNC@dell.com	5401944699	1	4461487905122340	2012/01	user912	password	20	20000	M
913	QOSRLK	NXILQCYTRV	6330477243 Dell Way	\N	NJAMVNF	IN	69206	US	1	NXILQCYTRV@dell.com	6330477243	2	7417874291073532	2011/04	user913	password	48	40000	M
914	DYHOME	WXVZWPRRDA	6076505598 Dell Way	\N	RPWFVDW	MD	48885	US	1	WXVZWPRRDA@dell.com	6076505598	1	7488330150954426	2012/04	user914	password	60	20000	F
915	WRTBNQ	WNNMEEPFWE	4251581727 Dell Way	\N	BBZFXKQ	MO	48490	US	1	WNNMEEPFWE@dell.com	4251581727	3	7640374479815365	2012/08	user915	password	18	100000	F
916	TWUKTH	XFMCURYZSA	5807007437 Dell Way	\N	ZYYJPLU	WA	91122	US	1	XFMCURYZSA@dell.com	5807007437	5	5393345608841628	2010/09	user916	password	71	40000	M
917	NRIUON	GRIYPHRQGP	4771948020 Dell Way	\N	PQEALDY	WV	10419	US	1	GRIYPHRQGP@dell.com	4771948020	3	7351155779324473	2008/10	user917	password	38	80000	F
918	PMADTR	LRHTIYAYOQ	9658047993 Dell Way	\N	DOCGNBG	WA	59866	US	1	LRHTIYAYOQ@dell.com	9658047993	1	4084074723068625	2009/09	user918	password	76	100000	F
919	VYYNKQ	VDZUDXIUBX	8340004448 Dell Way	\N	WHKXOIM	MT	47143	US	1	VDZUDXIUBX@dell.com	8340004448	4	2389324489980936	2011/07	user919	password	44	60000	M
920	HZYYVB	XPFUYAVWWD	2458393052 Dell Way	\N	GURPGFA	CA	95476	US	1	XPFUYAVWWD@dell.com	2458393052	4	5777647525072098	2010/02	user920	password	22	100000	F
921	ZTZBQP	HLNHHKDLQY	8145498642 Dell Way	\N	CGFIGHG	MD	99027	US	1	HLNHHKDLQY@dell.com	8145498642	5	2370110745541751	2012/10	user921	password	40	100000	M
922	HXEWEQ	KLXVPILOLS	2668417138 Dell Way	\N	TTYBAJA	SD	36463	US	1	KLXVPILOLS@dell.com	2668417138	4	1568322996143251	2010/07	user922	password	61	80000	F
923	TRQKCC	HXSQJGCBAW	7335244575 Dell Way	\N	ZBWJCSQ	IL	44903	US	1	HXSQJGCBAW@dell.com	7335244575	4	9306676546111704	2009/07	user923	password	45	20000	F
924	ALHCTE	VKNBMPCIOD	3081142114 Dell Way	\N	FXGXONI	ID	35443	US	1	VKNBMPCIOD@dell.com	3081142114	3	8488864295184613	2011/08	user924	password	21	80000	F
925	ISVNNF	BPRQSZFVFD	7340203511 Dell Way	\N	BDRPLYW	NY	55135	US	1	BPRQSZFVFD@dell.com	7340203511	2	2049331895541399	2011/11	user925	password	31	20000	M
926	ZQDERT	WILWOHBRJF	9350859435 Dell Way	\N	JYQIVIV	NC	63507	US	1	WILWOHBRJF@dell.com	9350859435	2	5369647273793817	2008/05	user926	password	25	20000	M
927	GHRZDA	LZOTBGCGPB	3654581956 Dell Way	\N	XXWFSKV	NM	71239	US	1	LZOTBGCGPB@dell.com	3654581956	4	1445206941105425	2009/11	user927	password	20	80000	F
928	SQGSCG	HVHNXOCYLA	9600998685 Dell Way	\N	VRTFMJX	RI	21609	US	1	HVHNXOCYLA@dell.com	9600998685	1	9798400246072562	2012/10	user928	password	25	80000	F
929	JLNQSI	YFFMIEYJAP	6126410951 Dell Way	\N	CFCMDWP	CA	13312	US	1	YFFMIEYJAP@dell.com	6126410951	1	8561772951390595	2011/10	user929	password	38	20000	F
930	URYCPE	IBNNAWNQYT	5162844181 Dell Way	\N	SKWPAZQ	NE	14758	US	1	IBNNAWNQYT@dell.com	5162844181	2	8630390077363701	2011/04	user930	password	23	60000	M
931	AQOFZQ	SMQPAGOTZY	5547804479 Dell Way	\N	QOZPFOR	NV	82566	US	1	SMQPAGOTZY@dell.com	5547804479	2	1978523199446499	2010/12	user931	password	23	80000	M
932	QVOGNA	XCBEQUEPLT	1422786615 Dell Way	\N	PBYDSPY	GA	98195	US	1	XCBEQUEPLT@dell.com	1422786615	4	9119152450934052	2008/05	user932	password	51	80000	F
933	AATAYV	CDMWHCIARJ	4780426059 Dell Way	\N	YVBNTGN	SD	14857	US	1	CDMWHCIARJ@dell.com	4780426059	5	5056715431623161	2012/09	user933	password	65	100000	M
934	KYRGAU	SXBVFCNOBJ	4576243191 Dell Way	\N	QPCXCXY	MT	86405	US	1	SXBVFCNOBJ@dell.com	4576243191	2	5865937116090209	2008/04	user934	password	36	60000	F
935	XRFSKC	TGHWUWXDMM	5824787038 Dell Way	\N	FKODICZ	OR	52970	US	1	TGHWUWXDMM@dell.com	5824787038	4	7874632856808604	2011/03	user935	password	89	80000	M
936	EKIHEO	PAILXLYJRI	3372430587 Dell Way	\N	YVRAVKM	KY	28300	US	1	PAILXLYJRI@dell.com	3372430587	1	4913382930215448	2009/11	user936	password	43	60000	F
937	RSLFHM	NTKZSUQBSM	8144011332 Dell Way	\N	TTHEGQJ	MS	80766	US	1	NTKZSUQBSM@dell.com	8144011332	4	6837406034581364	2008/02	user937	password	85	80000	M
938	JAEWNY	GNQAESSQLM	1047949850 Dell Way	\N	YPSOYFJ	PA	95425	US	1	GNQAESSQLM@dell.com	1047949850	5	2007787055335939	2012/09	user938	password	89	40000	M
939	DDFCKT	SKXKDOWPML	6266149787 Dell Way	\N	IBKNKDM	ME	12796	US	1	SKXKDOWPML@dell.com	6266149787	2	7352097217924894	2010/08	user939	password	45	80000	M
940	PUFINP	GYTUUIGGRI	5761335440 Dell Way	\N	QESURDV	IA	52758	US	1	GYTUUIGGRI@dell.com	5761335440	5	2077637238893658	2012/07	user940	password	85	60000	F
941	CVWSCU	LWPUDVLLMQ	9057929307 Dell Way	\N	EGHHCNU	NJ	40824	US	1	LWPUDVLLMQ@dell.com	9057929307	3	8868735139258207	2012/01	user941	password	33	100000	M
942	BQZWCV	LWYGIKTZOA	1083937597 Dell Way	\N	GWCUQSD	NC	31438	US	1	LWYGIKTZOA@dell.com	1083937597	2	3499994067475200	2009/04	user942	password	29	40000	M
943	DDZYOW	XVFIPEWPLT	9187624871 Dell Way	\N	RGKKJYQ	MA	36364	US	1	XVFIPEWPLT@dell.com	9187624871	3	6143052042461932	2008/11	user943	password	53	20000	F
944	MDPJBL	OJATGPEAHL	2811182235 Dell Way	\N	KRUIIEQ	HI	78267	US	1	OJATGPEAHL@dell.com	2811182235	2	6680488957557828	2011/06	user944	password	64	20000	M
945	FNRQCB	RWHGBHOMSG	8399335112 Dell Way	\N	GBOLRUE	UT	16700	US	1	RWHGBHOMSG@dell.com	8399335112	3	6066359539516271	2010/09	user945	password	32	80000	F
946	WIJYZG	GGHOVTGBAH	1281824365 Dell Way	\N	PMYKRVM	MO	44324	US	1	GGHOVTGBAH@dell.com	1281824365	5	1984454531688243	2009/08	user946	password	45	20000	M
947	TBYZHF	GVAACCBJSN	6779560002 Dell Way	\N	ICEDOQN	NH	62850	US	1	GVAACCBJSN@dell.com	6779560002	5	2857153408229351	2008/12	user947	password	29	80000	M
948	CTHIZC	IAFLCODPXF	2958190524 Dell Way	\N	UBULPJA	HI	27886	US	1	IAFLCODPXF@dell.com	2958190524	2	2194954043719917	2009/12	user948	password	26	60000	M
949	KUSNDT	SOVHRLEXFF	4415622340 Dell Way	\N	RQVBQAG	TX	34789	US	1	SOVHRLEXFF@dell.com	4415622340	2	3444420515559614	2010/09	user949	password	18	100000	F
950	SKPMCE	HKVSOSYUKO	2744048698 Dell Way	\N	PLEQRBX	AZ	34327	US	1	HKVSOSYUKO@dell.com	2744048698	3	9774570805486292	2008/06	user950	password	52	100000	M
951	CKZGSJ	BLXUJSEXIQ	4470906980 Dell Way	\N	CZIDXJK	CA	94874	US	1	BLXUJSEXIQ@dell.com	4470906980	2	4577408159151673	2012/03	user951	password	36	100000	M
952	FEHOGS	MBCFFZOWCN	8970942235 Dell Way	\N	EGLOQNM	AL	82752	US	1	MBCFFZOWCN@dell.com	8970942235	5	1171856725588440	2008/10	user952	password	63	40000	M
953	YXGRKH	TQNTEJVSNB	5224085345 Dell Way	\N	DBSQOTL	MI	65845	US	1	TQNTEJVSNB@dell.com	5224085345	3	4905130745377392	2008/12	user953	password	48	20000	M
954	RRGYLX	LEBUATHBXJ	6193759048 Dell Way	\N	UNXNZJD	MI	93125	US	1	LEBUATHBXJ@dell.com	6193759048	3	8660897296387703	2012/07	user954	password	69	80000	F
955	ZPRWAW	YUWSCYPLSC	5393178251 Dell Way	\N	JGCSKOQ	WV	18190	US	1	YUWSCYPLSC@dell.com	5393178251	5	6954795753583313	2008/08	user955	password	85	20000	F
956	PAFMYA	IQCHFOAIXG	7555902556 Dell Way	\N	LQQZGPB	OR	61529	US	1	IQCHFOAIXG@dell.com	7555902556	5	2718922736588865	2011/02	user956	password	46	40000	F
957	PSBPBR	SIXGIGDPRT	6359110105 Dell Way	\N	FQAVSTK	MI	72881	US	1	SIXGIGDPRT@dell.com	6359110105	1	8101105615030975	2012/05	user957	password	83	60000	F
958	YEDQWL	ODUUGJMAPD	3660725974 Dell Way	\N	BLVVVHN	MI	43518	US	1	ODUUGJMAPD@dell.com	3660725974	3	7462105250451715	2008/01	user958	password	75	20000	F
959	XUCJIF	ECMOOMDRNP	8983988763 Dell Way	\N	NIKUWWE	DC	35065	US	1	ECMOOMDRNP@dell.com	8983988763	2	3596295555122197	2011/06	user959	password	53	60000	F
960	OYOUCR	GQFSUXGJLP	2867877625 Dell Way	\N	UFLQKPX	IL	92882	US	1	GQFSUXGJLP@dell.com	2867877625	5	4518216860480607	2011/07	user960	password	64	40000	F
961	EBPWHF	BAAZGJKWEQ	2847531767 Dell Way	\N	HUAXSIV	WA	34026	US	1	BAAZGJKWEQ@dell.com	2847531767	4	8189608458429576	2012/11	user961	password	38	20000	M
962	WWFCYF	CYMLIIQZQK	4582422146 Dell Way	\N	ANDIJBP	ND	71092	US	1	CYMLIIQZQK@dell.com	4582422146	2	6097412969451398	2011/05	user962	password	54	60000	F
963	SPFXSE	JENSUMJENX	6625454952 Dell Way	\N	IVGJLUB	TN	25790	US	1	JENSUMJENX@dell.com	6625454952	3	6301025838591159	2008/01	user963	password	81	100000	M
964	CSIGCM	UVHGELUBUQ	8702825449 Dell Way	\N	HEBCFXG	TX	47558	US	1	UVHGELUBUQ@dell.com	8702825449	5	5139071905054152	2011/10	user964	password	26	100000	M
965	LCQYWL	FDQRXSMOAQ	4484273404 Dell Way	\N	PCWNJSY	HI	69160	US	1	FDQRXSMOAQ@dell.com	4484273404	5	4974192992318422	2010/10	user965	password	87	100000	M
966	PXUBDX	RVVKHJKXZN	5943152674 Dell Way	\N	TMXLKCC	SD	16715	US	1	RVVKHJKXZN@dell.com	5943152674	2	8813831590581686	2010/04	user966	password	73	20000	F
967	NDHLUC	HFKRPHQCBD	1493543520 Dell Way	\N	ZNOCPJE	DE	70170	US	1	HFKRPHQCBD@dell.com	1493543520	4	9327435762621464	2012/10	user967	password	24	40000	M
968	JURMBX	WTMEJPGNPT	1218104584 Dell Way	\N	BSJLXNC	WI	27266	US	1	WTMEJPGNPT@dell.com	1218104584	4	9547862268518656	2008/02	user968	password	78	60000	M
969	NZZKWS	XACMHPCARU	1320055919 Dell Way	\N	JCRXFQC	HI	46306	US	1	XACMHPCARU@dell.com	1320055919	2	5670913874637336	2012/11	user969	password	49	40000	M
970	KVRDSS	GFZWHZNCJQ	4100365668 Dell Way	\N	UGVKIBV	MA	47659	US	1	GFZWHZNCJQ@dell.com	4100365668	2	3274784554261714	2011/08	user970	password	22	20000	F
971	TIELPJ	LLRKZTUPOB	2722631615 Dell Way	\N	LZKNUTY	DC	11777	US	1	LLRKZTUPOB@dell.com	2722631615	5	7009729275945575	2009/02	user971	password	27	100000	F
972	HLARWL	IHKCBAQDMP	9687758315 Dell Way	\N	NZKHXOH	CO	51472	US	1	IHKCBAQDMP@dell.com	9687758315	2	6126145383343101	2008/05	user972	password	19	40000	M
973	BBRMJZ	XMBYDEKTRJ	7506118007 Dell Way	\N	DYHSGKD	HI	80712	US	1	XMBYDEKTRJ@dell.com	7506118007	2	2389714499935508	2011/09	user973	password	88	80000	M
974	QHDQEP	RDTWNMOXQM	6027735084 Dell Way	\N	FITQMZK	FL	36495	US	1	RDTWNMOXQM@dell.com	6027735084	5	9931524054612964	2010/09	user974	password	71	20000	M
975	WVEMMH	FJVSXSIKYQ	4686263738 Dell Way	\N	DOCDYHK	MT	29032	US	1	FJVSXSIKYQ@dell.com	4686263738	1	9264267607126386	2008/03	user975	password	83	20000	F
976	BNNJSW	FKTYSDWJHK	8748737910 Dell Way	\N	LKJTVWY	HI	92089	US	1	FKTYSDWJHK@dell.com	8748737910	2	2172908938489854	2011/05	user976	password	29	100000	M
977	RFQOKA	HITLFCSPOD	8977178685 Dell Way	\N	ZHYVGET	CA	60021	US	1	HITLFCSPOD@dell.com	8977178685	5	9599141888786108	2008/09	user977	password	80	80000	M
978	MGINOR	GZWJSMYVLF	5202256417 Dell Way	\N	UHMYBON	WA	47476	US	1	GZWJSMYVLF@dell.com	5202256417	5	2004814685788005	2009/09	user978	password	19	80000	M
979	JHNAON	XYGJXBVDWD	7062136987 Dell Way	\N	PVEDICO	SC	17913	US	1	XYGJXBVDWD@dell.com	7062136987	1	8109942341223360	2011/11	user979	password	73	20000	F
980	HBUUYT	BIQCDTZGIU	4719519383 Dell Way	\N	LMCNBWQ	OK	99543	US	1	BIQCDTZGIU@dell.com	4719519383	3	9136412558145822	2008/06	user980	password	26	60000	M
981	XGMQHU	HKYBJFJEQW	1336221660 Dell Way	\N	GEXDUQD	GA	15342	US	1	HKYBJFJEQW@dell.com	1336221660	2	5692355403210968	2008/10	user981	password	21	20000	F
982	NSJIAU	GBELLICHPG	4924859658 Dell Way	\N	FSBWWGX	VA	65264	US	1	GBELLICHPG@dell.com	4924859658	1	4924335135612637	2010/02	user982	password	55	20000	M
983	XIVROW	VAHEDPTJVL	7383508123 Dell Way	\N	KRIRPFH	AK	31478	US	1	VAHEDPTJVL@dell.com	7383508123	3	4143298769835383	2009/07	user983	password	31	20000	M
984	AUKXQL	EUOUOYPAIH	1849692488 Dell Way	\N	IAWNHWT	WY	43687	US	1	EUOUOYPAIH@dell.com	1849692488	2	8888072617352010	2009/04	user984	password	68	40000	F
985	CETNJO	BDCATCIAKJ	1045144829 Dell Way	\N	WXQTQPD	OR	83147	US	1	BDCATCIAKJ@dell.com	1045144829	1	2192783415783196	2011/04	user985	password	35	80000	F
986	ZIVNKZ	PKTRTTCCQZ	3358674748 Dell Way	\N	SKQINKD	NC	46217	US	1	PKTRTTCCQZ@dell.com	3358674748	2	7322294854093344	2010/01	user986	password	30	60000	F
987	AATZPD	THXNKZDKSO	5677641806 Dell Way	\N	AACKDPV	MD	86512	US	1	THXNKZDKSO@dell.com	5677641806	5	8949038285296411	2011/05	user987	password	35	80000	F
988	ZSADLI	AYSABCSQDS	1438817437 Dell Way	\N	SOWIJGE	UT	24176	US	1	AYSABCSQDS@dell.com	1438817437	3	5931080186273903	2009/04	user988	password	87	40000	M
989	YKKHLI	ZLKBDAFWST	6947140909 Dell Way	\N	SBCYFZC	IA	58523	US	1	ZLKBDAFWST@dell.com	6947140909	3	8288215321488679	2011/10	user989	password	74	60000	F
990	EVQMVC	XXFXCCQVUR	3177681274 Dell Way	\N	YTWXWDL	MT	70343	US	1	XXFXCCQVUR@dell.com	3177681274	1	5325818784069270	2008/09	user990	password	68	20000	M
991	IRILOF	RMITCDNUBG	9469169336 Dell Way	\N	RYCUKQL	NM	76227	US	1	RMITCDNUBG@dell.com	9469169336	4	4754047187976539	2011/11	user991	password	86	100000	M
992	GKCMBO	UURYILAPCZ	5125351169 Dell Way	\N	RXJHJAB	IL	69120	US	1	UURYILAPCZ@dell.com	5125351169	5	5446098457556218	2009/11	user992	password	18	80000	F
993	CDKQYE	HXNTXCVXUS	4841154515 Dell Way	\N	HCBHDJY	NE	34815	US	1	HXNTXCVXUS@dell.com	4841154515	5	2637531133368611	2010/08	user993	password	54	60000	M
994	XDTBLQ	PEORAMMSTO	6320973196 Dell Way	\N	UARDYHK	MA	32953	US	1	PEORAMMSTO@dell.com	6320973196	5	9042769424617292	2008/04	user994	password	67	100000	F
995	LBYBQC	QICCUVWJPW	5178968339 Dell Way	\N	BTVIEEO	PA	99651	US	1	QICCUVWJPW@dell.com	5178968339	5	3908413971308619	2008/10	user995	password	76	60000	M
996	SQNVHV	YKQUGZKCAD	4763036137 Dell Way	\N	XIHCXBC	MA	88902	US	1	YKQUGZKCAD@dell.com	4763036137	3	7209675724618138	2009/02	user996	password	58	100000	M
997	BUAXSK	NMQNXTNAQW	9231493393 Dell Way	\N	ITUJVDF	IA	70100	US	1	NMQNXTNAQW@dell.com	9231493393	3	7808348116930575	2010/06	user997	password	53	60000	F
998	MKYXYL	NLIGZIXVQQ	2613330785 Dell Way	\N	PZMTFSK	CT	28211	US	1	NLIGZIXVQQ@dell.com	2613330785	4	6658692321274430	2011/02	user998	password	79	20000	M
999	UBMFOY	NVXWSSNIIN	4352252650 Dell Way	\N	VCSONWT	OH	50931	US	1	NVXWSSNIIN@dell.com	4352252650	2	6256409952882678	2009/07	user999	password	27	100000	M
1000	QEDOSY	LOQECZNPUP	2748705411 Dell Way	\N	HICECUP	MN	24439	US	1	LOQECZNPUP@dell.com	2748705411	4	7063457543496043	2009/08	user1000	password	34	100000	M
1001	JMOHYD	YCFYQUSFCB	9699972236 Dell Way	\N	IGEDWQH	AZ	36810	US	1	YCFYQUSFCB@dell.com	9699972236	2	9586345199495556	2008/05	user1001	password	76	60000	M
1002	JVTMUW	SSMNLSQNBW	5981776752 Dell Way	\N	RETHMUP	MI	27457	US	1	SSMNLSQNBW@dell.com	5981776752	4	5757241853047163	2009/03	user1002	password	44	80000	F
1003	DFVZYN	MLYFBMGYDK	2782330861 Dell Way	\N	RLXMBIR	NH	95365	US	1	MLYFBMGYDK@dell.com	2782330861	5	2189441295340657	2010/08	user1003	password	29	80000	M
1004	ZRUMEG	LJHXQFBBXM	3907144196 Dell Way	\N	YJNGADE	HI	15950	US	1	LJHXQFBBXM@dell.com	3907144196	4	7562442842405290	2010/06	user1004	password	62	60000	F
1005	KYIQJR	YHHDIIAUHK	3074933290 Dell Way	\N	INLLSRN	AL	50355	US	1	YHHDIIAUHK@dell.com	3074933290	3	9206411646213384	2012/12	user1005	password	21	40000	M
1006	JWGBUO	JYWSZQZJZM	8445594237 Dell Way	\N	UKEMXFX	CT	74470	US	1	JYWSZQZJZM@dell.com	8445594237	5	7092336804140360	2012/03	user1006	password	59	40000	F
1007	VHWJQV	GIUWHEVUZG	5961774946 Dell Way	\N	YLDEJHW	FL	31952	US	1	GIUWHEVUZG@dell.com	5961774946	1	4995711990632117	2008/04	user1007	password	55	100000	M
1008	KIFFPO	ZLVEHPDOOO	6970031916 Dell Way	\N	SSXZPCF	DC	23434	US	1	ZLVEHPDOOO@dell.com	6970031916	2	5012698860373348	2008/03	user1008	password	19	60000	M
1009	GTDUTP	PXXFAMTPEM	2727619526 Dell Way	\N	NDBPJFT	AL	52081	US	1	PXXFAMTPEM@dell.com	2727619526	2	7253162647597492	2009/10	user1009	password	37	60000	M
1010	KGHAWF	YBFKVVPIIS	7721700813 Dell Way	\N	JXCPRCB	TX	37923	US	1	YBFKVVPIIS@dell.com	7721700813	1	1696741107851267	2008/07	user1010	password	62	60000	M
1011	XMPCKR	IVNDKVMDFK	7548234120 Dell Way	\N	GUBIVXQ	NE	99318	US	1	IVNDKVMDFK@dell.com	7548234120	3	5738639882765711	2009/01	user1011	password	39	40000	F
1012	XIXPQT	CUEXGICQOX	1985572882 Dell Way	\N	RXSPOHP	IL	90915	US	1	CUEXGICQOX@dell.com	1985572882	4	9367719109635800	2010/11	user1012	password	49	40000	F
1013	JXUCZP	HXVPALEXCB	7843144745 Dell Way	\N	QSQYHXV	MD	55562	US	1	HXVPALEXCB@dell.com	7843144745	5	4154324694070965	2008/02	user1013	password	55	60000	F
1014	IQAXYX	SNYDSVGUMZ	2272628490 Dell Way	\N	KKGHFQU	WY	50341	US	1	SNYDSVGUMZ@dell.com	2272628490	1	6079803165048361	2011/09	user1014	password	60	100000	F
1015	PWHNPV	LSNHZHTYRD	8747747924 Dell Way	\N	FZJWTJH	VT	58942	US	1	LSNHZHTYRD@dell.com	8747747924	3	3325681549031287	2010/07	user1015	password	62	20000	F
1016	XOZSAS	GHSNBQFEWF	7619117696 Dell Way	\N	OSZYZWM	TX	49399	US	1	GHSNBQFEWF@dell.com	7619117696	2	9788181624840946	2009/05	user1016	password	46	40000	M
1017	JYXCFE	UTFLZKHEZZ	4782960252 Dell Way	\N	DXZAKWL	CT	23790	US	1	UTFLZKHEZZ@dell.com	4782960252	3	5438951774500311	2012/09	user1017	password	46	20000	M
1018	HGWMBP	RNPCUTBUWZ	3542029617 Dell Way	\N	UWJQIMU	PA	97030	US	1	RNPCUTBUWZ@dell.com	3542029617	3	7178970302920789	2011/09	user1018	password	44	100000	M
1019	GKBWCO	LEJEGDBGYY	7809505829 Dell Way	\N	POGCJAB	NM	60762	US	1	LEJEGDBGYY@dell.com	7809505829	2	3654430662747473	2008/04	user1019	password	39	40000	M
1020	JFTXRY	GWFKXLIWBX	9913984142 Dell Way	\N	DDGDFXS	WV	27103	US	1	GWFKXLIWBX@dell.com	9913984142	1	4985513586550951	2009/06	user1020	password	25	80000	M
1021	WOJUUF	AFDLOZMLCQ	2893448398 Dell Way	\N	RGWPYVT	WA	94886	US	1	AFDLOZMLCQ@dell.com	2893448398	2	4719924091361463	2009/11	user1021	password	26	20000	F
1022	MZFSZK	VLYVXKYOCE	6602330409 Dell Way	\N	LRCGLAF	NM	30715	US	1	VLYVXKYOCE@dell.com	6602330409	5	1657904028892517	2011/02	user1022	password	51	40000	F
1023	RYCBTN	APLKNAMRLD	2004983606 Dell Way	\N	USOVXFB	MT	24218	US	1	APLKNAMRLD@dell.com	2004983606	2	3606255820952356	2010/06	user1023	password	47	40000	F
1024	NHEAHT	MRHMEYXITP	5762179812 Dell Way	\N	WONCPAG	OH	36305	US	1	MRHMEYXITP@dell.com	5762179812	2	7955763895995916	2012/06	user1024	password	30	60000	M
1025	ILBCYT	JKYIIGBXDQ	5622924763 Dell Way	\N	KFFLLXT	WV	26029	US	1	JKYIIGBXDQ@dell.com	5622924763	5	7093940006569029	2011/05	user1025	password	51	20000	M
1026	NDTHMD	GVLMWJQNUV	5188429974 Dell Way	\N	SGHPZGU	MS	23776	US	1	GVLMWJQNUV@dell.com	5188429974	1	5450602225959301	2012/03	user1026	password	39	60000	F
1027	ATVEAR	QNOADBUYTB	1915112249 Dell Way	\N	FJALDNP	NJ	73761	US	1	QNOADBUYTB@dell.com	1915112249	3	9346691127400846	2009/01	user1027	password	38	60000	M
1028	DPUUGH	IGKJBIDCOM	3640266315 Dell Way	\N	DAQRPGJ	OK	81871	US	1	IGKJBIDCOM@dell.com	3640266315	1	8240550987888128	2010/07	user1028	password	60	80000	F
1029	JMKQUR	BESKHVYUZY	3610059851 Dell Way	\N	LQORZGM	IL	43869	US	1	BESKHVYUZY@dell.com	3610059851	5	9271562251728028	2012/07	user1029	password	23	40000	F
1030	MWUDYZ	WIHRGBQFMG	3795332550 Dell Way	\N	TEGARNK	WI	43438	US	1	WIHRGBQFMG@dell.com	3795332550	5	9162303632590920	2009/01	user1030	password	84	100000	M
1031	SZWRVE	YNLADQNKJS	4985812648 Dell Way	\N	QKJEUIN	CO	23497	US	1	YNLADQNKJS@dell.com	4985812648	3	2861292597372085	2009/04	user1031	password	28	20000	F
1032	ATDESQ	QTUGGEQYVA	1013970847 Dell Way	\N	IZVQNXU	WI	45778	US	1	QTUGGEQYVA@dell.com	1013970847	2	7570775480940939	2008/05	user1032	password	21	20000	F
1033	EIVVYO	PFVUVUPWCO	7536994822 Dell Way	\N	RTCPOBZ	NC	42299	US	1	PFVUVUPWCO@dell.com	7536994822	4	7641889533959330	2011/11	user1033	password	81	100000	F
1034	STDHJI	DDEXSAAHST	5716598528 Dell Way	\N	JHHLHVU	AL	57455	US	1	DDEXSAAHST@dell.com	5716598528	4	4281846893485636	2009/09	user1034	password	57	20000	M
1035	RKWZNA	DKTEKAWEKE	2670227931 Dell Way	\N	LVMHQNV	DC	37920	US	1	DKTEKAWEKE@dell.com	2670227931	3	1490175964776426	2011/08	user1035	password	59	40000	F
1036	LJOLNY	ERJFONQTZM	1929133031 Dell Way	\N	FGCTCGB	ID	82552	US	1	ERJFONQTZM@dell.com	1929133031	5	5085991189815104	2011/05	user1036	password	53	20000	M
1037	AOGZTY	IZMWPFVCLC	7539554806 Dell Way	\N	FEFMGMH	KY	51914	US	1	IZMWPFVCLC@dell.com	7539554806	1	8565285266377033	2009/02	user1037	password	60	40000	M
1038	VGLTPK	GLALHDXKIC	4302617274 Dell Way	\N	PUIBBRN	SC	69800	US	1	GLALHDXKIC@dell.com	4302617274	1	8016238656826318	2012/04	user1038	password	51	80000	M
1039	XNCHTN	IFVLDFTFUO	6665937110 Dell Way	\N	NWPEKKW	PA	46270	US	1	IFVLDFTFUO@dell.com	6665937110	4	6976240073330701	2008/06	user1039	password	30	100000	F
1040	GGTUPZ	PACVTHQIVM	4450303022 Dell Way	\N	XAXIWRS	MS	42687	US	1	PACVTHQIVM@dell.com	4450303022	3	8585443479474635	2010/07	user1040	password	79	80000	M
1041	PPKPEK	RAEZQMVDKV	9110817742 Dell Way	\N	BSRSLEB	TN	77967	US	1	RAEZQMVDKV@dell.com	9110817742	2	3758594145067036	2011/03	user1041	password	27	40000	M
1042	NYYYQZ	CPPPKTAGUT	2465379859 Dell Way	\N	YMECOAW	MI	45900	US	1	CPPPKTAGUT@dell.com	2465379859	1	6186913523357362	2009/07	user1042	password	42	100000	F
1043	HTDGWT	WLDQMKKFIX	4481033761 Dell Way	\N	KKLKHXV	MI	18534	US	1	WLDQMKKFIX@dell.com	4481033761	4	6845150297041983	2011/07	user1043	password	28	20000	F
1044	HGDADO	ETAODFWBQH	2257814751 Dell Way	\N	MAOKVZM	HI	74224	US	1	ETAODFWBQH@dell.com	2257814751	5	3189612406771630	2009/12	user1044	password	55	60000	F
1045	QOJFSC	FHGLDHBLUC	9363254920 Dell Way	\N	ZEYZRER	SD	21943	US	1	FHGLDHBLUC@dell.com	9363254920	1	1874045714270323	2010/08	user1045	password	41	20000	F
1046	RGYTMG	ZYJHAUBCUG	5163478603 Dell Way	\N	BTXGLSJ	LA	84136	US	1	ZYJHAUBCUG@dell.com	5163478603	5	5349951481912285	2011/11	user1046	password	69	60000	F
1047	RFQXFO	HMOCORWVSQ	7819801773 Dell Way	\N	SYBLILH	RI	32316	US	1	HMOCORWVSQ@dell.com	7819801773	3	2156455924734473	2010/01	user1047	password	37	20000	F
1048	XBLLIY	ZKNRGIJXBI	7893828563 Dell Way	\N	YMQKTKQ	MT	96867	US	1	ZKNRGIJXBI@dell.com	7893828563	5	9849431917071344	2008/02	user1048	password	33	100000	F
1049	RJMPJX	DAELKBMSAZ	7332077331 Dell Way	\N	JKSTAGS	SC	31877	US	1	DAELKBMSAZ@dell.com	7332077331	5	4359712988603860	2012/10	user1049	password	57	60000	F
1050	AFNYIN	CTYDFRDEAN	8023449993 Dell Way	\N	XTOEMIK	FL	25422	US	1	CTYDFRDEAN@dell.com	8023449993	1	9367807685397566	2009/09	user1050	password	22	40000	M
1051	OHFCJZ	AMERQJSDHL	2149824737 Dell Way	\N	RLYAWDF	NM	30116	US	1	AMERQJSDHL@dell.com	2149824737	5	9266500910744072	2008/04	user1051	password	77	80000	M
1052	AWYZWL	EOBOGFVSXH	9188715596 Dell Way	\N	QXDTCTZ	IA	74857	US	1	EOBOGFVSXH@dell.com	9188715596	3	1321225353982299	2011/03	user1052	password	64	80000	F
1053	PTXAXM	CLTHHMEODC	2769928838 Dell Way	\N	RXFLWLE	SC	88335	US	1	CLTHHMEODC@dell.com	2769928838	3	1465097553562373	2012/04	user1053	password	24	60000	M
1054	ALXMOJ	GVQSAEVCWS	7096672888 Dell Way	\N	IHPTMKQ	NV	91221	US	1	GVQSAEVCWS@dell.com	7096672888	3	2476129075977951	2011/11	user1054	password	29	80000	F
1055	BGXLMS	BFTGBVDTEL	8373557185 Dell Way	\N	JXXTNOR	GA	14905	US	1	BFTGBVDTEL@dell.com	8373557185	5	9638337650336326	2012/09	user1055	password	40	20000	M
1056	FMMXOS	RUTNYNRJWO	8512323171 Dell Way	\N	GQCVHIW	CA	37160	US	1	RUTNYNRJWO@dell.com	8512323171	1	1382171307690441	2008/02	user1056	password	20	40000	M
1057	NGEFXZ	ZKXMCGIQNY	4839726566 Dell Way	\N	TIFCFIJ	AR	45020	US	1	ZKXMCGIQNY@dell.com	4839726566	1	5638782406225801	2010/07	user1057	password	27	100000	M
1058	HFSGED	DQFKZWXYQG	4298636822 Dell Way	\N	DSLMCMW	MT	71238	US	1	DQFKZWXYQG@dell.com	4298636822	5	2887403805740177	2010/12	user1058	password	18	80000	F
1059	SAJVEZ	BOZXMXNSBF	5972533554 Dell Way	\N	ENIRJVI	OK	81779	US	1	BOZXMXNSBF@dell.com	5972533554	2	7840044300537557	2010/12	user1059	password	86	40000	F
1060	HCEHET	GCFEPYFVCS	5805722965 Dell Way	\N	DTBZCUU	NV	10395	US	1	GCFEPYFVCS@dell.com	5805722965	2	9932447279337796	2010/06	user1060	password	18	80000	M
1061	EBTXHV	DMLBRHEJLX	3034055486 Dell Way	\N	LKAFERG	OK	90167	US	1	DMLBRHEJLX@dell.com	3034055486	1	4313967436086387	2009/12	user1061	password	87	60000	M
1062	SIHOLT	ZNLGRURPGC	5952352882 Dell Way	\N	PMHHSZE	WA	25792	US	1	ZNLGRURPGC@dell.com	5952352882	1	2075673870276659	2010/07	user1062	password	26	40000	M
1063	KTIETV	PZNKRCQUSC	4084192572 Dell Way	\N	BAUBESF	OR	89789	US	1	PZNKRCQUSC@dell.com	4084192572	2	5039046165999025	2010/06	user1063	password	42	100000	F
1064	RAYNQY	AAQDQKVTMW	6554355798 Dell Way	\N	ONAHTUE	CA	11693	US	1	AAQDQKVTMW@dell.com	6554355798	3	5312853781972081	2012/05	user1064	password	68	80000	F
1065	QDBPEB	GHSRDLDZAQ	3735181943 Dell Way	\N	AHKUMMV	CA	12297	US	1	GHSRDLDZAQ@dell.com	3735181943	1	4831315833609551	2008/08	user1065	password	80	80000	M
1066	XGYZMG	REKDHJDYKL	3452520430 Dell Way	\N	IFXVBZW	KY	11893	US	1	REKDHJDYKL@dell.com	3452520430	2	7039445545058698	2008/01	user1066	password	51	20000	F
1067	KZTQRX	BVFLZDVKMB	1104621934 Dell Way	\N	IHCIDLI	MD	81845	US	1	BVFLZDVKMB@dell.com	1104621934	3	8200684150215239	2010/07	user1067	password	22	100000	M
1068	VNGSOB	XZABVLNWUV	1301291868 Dell Way	\N	ZCYLLJG	MI	90209	US	1	XZABVLNWUV@dell.com	1301291868	5	5100413892883808	2008/10	user1068	password	19	100000	F
1069	GQWHOW	IPRUCOOYOQ	6154555881 Dell Way	\N	WZBFGND	ID	47622	US	1	IPRUCOOYOQ@dell.com	6154555881	2	2812644333112985	2010/04	user1069	password	55	100000	M
1070	JDLGMA	YGDNUBCLYC	6579857672 Dell Way	\N	MEIAHOK	TX	93723	US	1	YGDNUBCLYC@dell.com	6579857672	3	2728595762979239	2008/04	user1070	password	23	60000	F
1071	NTXOSE	SFYTHKSJWW	4495463040 Dell Way	\N	RWDGHAF	VT	50779	US	1	SFYTHKSJWW@dell.com	4495463040	1	7656690717674793	2010/07	user1071	password	30	100000	F
1072	CNAGFG	FZOPSYMOQJ	9298545869 Dell Way	\N	SXQSCOE	MO	65360	US	1	FZOPSYMOQJ@dell.com	9298545869	5	2592368227895349	2008/12	user1072	password	54	20000	F
1073	NLSUQS	IGKHSZXBRV	1674296055 Dell Way	\N	SKXHPKX	MT	41988	US	1	IGKHSZXBRV@dell.com	1674296055	4	3681686679832637	2010/10	user1073	password	74	20000	F
1074	MXXEGD	PNVOLXGHQR	3189027111 Dell Way	\N	EXHPUUY	UT	48243	US	1	PNVOLXGHQR@dell.com	3189027111	3	3074223116971552	2008/07	user1074	password	52	60000	F
1075	JSSMHG	IWRFCYVUDT	5661691844 Dell Way	\N	BTNWRKH	WA	87596	US	1	IWRFCYVUDT@dell.com	5661691844	5	4811223280150443	2012/06	user1075	password	82	40000	F
1076	PVLVDH	NJKMFEPYGJ	2616431703 Dell Way	\N	MCAXKYT	VT	91723	US	1	NJKMFEPYGJ@dell.com	2616431703	5	4247813613153994	2008/03	user1076	password	55	80000	F
1077	YMFGZP	QLUVBSBKFD	7029264537 Dell Way	\N	LCNKWLI	AR	39729	US	1	QLUVBSBKFD@dell.com	7029264537	1	6127589363139123	2008/10	user1077	password	64	20000	F
1078	WJFLAQ	FVRYWCDANG	8861457836 Dell Way	\N	NYDZGEH	VT	33615	US	1	FVRYWCDANG@dell.com	8861457836	1	1121573944110423	2010/03	user1078	password	34	40000	M
1079	LUPBZK	TYGVCGJIUH	9068512780 Dell Way	\N	LTNQBLW	WI	57652	US	1	TYGVCGJIUH@dell.com	9068512780	3	7721657834947110	2008/10	user1079	password	42	60000	M
1080	XPPIJN	OEPVOYPVKJ	1777369915 Dell Way	\N	JBLVYKI	SD	86234	US	1	OEPVOYPVKJ@dell.com	1777369915	5	6929799535311759	2010/07	user1080	password	36	40000	F
1081	WQMJFQ	ZAFYQBJAKK	4191335616 Dell Way	\N	LFIWOES	NM	19378	US	1	ZAFYQBJAKK@dell.com	4191335616	1	6465085734613240	2011/05	user1081	password	70	60000	F
1082	EVGVVG	BUWCDWMOIS	7831984396 Dell Way	\N	XEHBWXD	IA	98113	US	1	BUWCDWMOIS@dell.com	7831984396	5	4345082753803581	2010/04	user1082	password	47	80000	F
1083	QNZWOT	TQXQDLZVIE	4464956303 Dell Way	\N	DKBAOHA	IN	22397	US	1	TQXQDLZVIE@dell.com	4464956303	4	4995570587925613	2011/06	user1083	password	60	60000	M
1084	OHNHBE	ESHQRDZWGJ	8007496151 Dell Way	\N	XHXFHFI	OH	97888	US	1	ESHQRDZWGJ@dell.com	8007496151	3	4831424144562334	2009/11	user1084	password	46	100000	F
1085	XFGBKZ	JARMZNTJKB	8692997378 Dell Way	\N	GQJLYAL	OR	56169	US	1	JARMZNTJKB@dell.com	8692997378	1	4705464151687920	2009/01	user1085	password	62	20000	F
1086	WFPWOQ	NBQAVZLWGB	2621657904 Dell Way	\N	FSAGDTT	WY	85719	US	1	NBQAVZLWGB@dell.com	2621657904	2	8654748851899058	2011/05	user1086	password	23	80000	M
1087	RNEIBG	YBBYNYFOEX	1267535697 Dell Way	\N	PKAIEAE	LA	30790	US	1	YBBYNYFOEX@dell.com	1267535697	1	6459848755039275	2008/10	user1087	password	32	80000	F
1088	JCKPBM	RAZPFOUCDE	9588160296 Dell Way	\N	CMJDRSJ	OH	89727	US	1	RAZPFOUCDE@dell.com	9588160296	4	7472246749792249	2008/07	user1088	password	23	60000	M
1089	MDSYUS	YKYMEAQJDC	1590964599 Dell Way	\N	TGULPMJ	NC	33243	US	1	YKYMEAQJDC@dell.com	1590964599	4	8468374493997545	2008/03	user1089	password	54	80000	F
1090	FPDYNO	XATXQCATVH	1678090727 Dell Way	\N	NHWZQKG	OH	20665	US	1	XATXQCATVH@dell.com	1678090727	5	4027744297869504	2010/06	user1090	password	67	100000	F
1091	VTPJRP	COFFPYAWMI	6577740026 Dell Way	\N	TLYESRH	RI	55501	US	1	COFFPYAWMI@dell.com	6577740026	2	9873632273636760	2009/02	user1091	password	21	20000	M
1092	QMPFPD	KUTJVQVDJH	3087570212 Dell Way	\N	CNATVUG	MI	23168	US	1	KUTJVQVDJH@dell.com	3087570212	4	3809603872243315	2009/11	user1092	password	35	100000	F
1093	VCYZNS	TXNJTQSBTG	3635996766 Dell Way	\N	BMBVSNZ	WI	31707	US	1	TXNJTQSBTG@dell.com	3635996766	2	1825106011237949	2010/02	user1093	password	49	40000	F
1094	JJUBCR	PLLGEMZLNL	4159767650 Dell Way	\N	NIEAICG	NJ	41482	US	1	PLLGEMZLNL@dell.com	4159767650	1	5442240263335407	2011/07	user1094	password	72	20000	M
1095	OEZFUL	QAQDZBQKPZ	5749877961 Dell Way	\N	OPHRWXA	GA	17076	US	1	QAQDZBQKPZ@dell.com	5749877961	5	6516586997546256	2009/02	user1095	password	55	100000	F
1096	NBCZSC	PVBRLLGKAW	4007460901 Dell Way	\N	SSTQTYS	IL	95177	US	1	PVBRLLGKAW@dell.com	4007460901	3	1644099910277873	2012/05	user1096	password	46	40000	F
1097	MIDOYY	PPKBWVCTNV	5074477162 Dell Way	\N	MEOLXVJ	HI	45196	US	1	PPKBWVCTNV@dell.com	5074477162	1	7909690875094385	2012/06	user1097	password	32	40000	M
1098	IWRGMH	ROEMQXAMKE	1152955999 Dell Way	\N	AVCWFIG	NY	46068	US	1	ROEMQXAMKE@dell.com	1152955999	3	8535413994919510	2009/10	user1098	password	61	60000	M
1099	HUEPLS	TXJRYVBDWX	7847535831 Dell Way	\N	FSCNYUY	WV	35203	US	1	TXJRYVBDWX@dell.com	7847535831	1	1879019455984234	2009/09	user1099	password	75	80000	M
1100	YFZRZW	AQVWRYSPDL	8531088807 Dell Way	\N	RRKLPJT	KY	59347	US	1	AQVWRYSPDL@dell.com	8531088807	4	3378518778365105	2011/05	user1100	password	74	60000	M
1101	TGNQHD	LDVJWKMHCD	8616882573 Dell Way	\N	ROSAHBP	CT	78854	US	1	LDVJWKMHCD@dell.com	8616882573	4	1923066038638353	2011/04	user1101	password	66	40000	M
1102	EZVIKZ	EUWOHDRLUF	1806434001 Dell Way	\N	DVNFKQZ	ID	45539	US	1	EUWOHDRLUF@dell.com	1806434001	5	7481830873526634	2011/03	user1102	password	38	100000	F
1103	DGQDKK	ZZRCQCXWGT	2139707101 Dell Way	\N	JMEAMLK	ND	38486	US	1	ZZRCQCXWGT@dell.com	2139707101	2	6054006806109101	2010/03	user1103	password	75	60000	F
1104	KRXVQW	NTNQQJXJTJ	8640244437 Dell Way	\N	OTWZEKH	IL	75850	US	1	NTNQQJXJTJ@dell.com	8640244437	4	9726806710474194	2011/03	user1104	password	51	20000	M
1105	JXOGKH	TBXCYHWIVP	3705947264 Dell Way	\N	EUTPCBI	WI	76751	US	1	TBXCYHWIVP@dell.com	3705947264	3	9873030670918524	2011/08	user1105	password	83	20000	M
1106	LJYSCZ	QFXYBGTRKO	2772251028 Dell Way	\N	LARMIPF	NM	26632	US	1	QFXYBGTRKO@dell.com	2772251028	3	8347914446145297	2008/07	user1106	password	42	60000	M
1107	GGZGXE	DVFJPXUDIU	4802260372 Dell Way	\N	VUDKAUP	GA	27554	US	1	DVFJPXUDIU@dell.com	4802260372	2	7436484278645367	2011/10	user1107	password	60	20000	F
1108	OGZSKU	YUJVPNEKIY	3307841397 Dell Way	\N	OTYJJDO	RI	49711	US	1	YUJVPNEKIY@dell.com	3307841397	3	3406803347170353	2012/07	user1108	password	43	40000	M
1109	ICGCBB	LXQZBBHAPA	8313528400 Dell Way	\N	YYJCMDO	OR	70721	US	1	LXQZBBHAPA@dell.com	8313528400	3	3088776481337845	2008/12	user1109	password	22	60000	F
1110	HODIAA	ZZBAGBQHAP	7444030426 Dell Way	\N	RDBVRVM	MO	45642	US	1	ZZBAGBQHAP@dell.com	7444030426	4	4304677001666278	2011/02	user1110	password	50	20000	M
1111	OKSOKR	QLYSBGSQXV	3547383269 Dell Way	\N	SSMNFZX	VT	65054	US	1	QLYSBGSQXV@dell.com	3547383269	4	7506363140884788	2011/10	user1111	password	47	40000	F
1112	CWOUMA	TEBZXSXSKP	5715602657 Dell Way	\N	FYUEWSU	DC	47175	US	1	TEBZXSXSKP@dell.com	5715602657	5	2562900507356971	2012/02	user1112	password	43	20000	F
1113	YVMYOR	ZOOSLHDAMB	2380054440 Dell Way	\N	VRXOMBZ	AK	92736	US	1	ZOOSLHDAMB@dell.com	2380054440	5	1580543815158307	2010/12	user1113	password	22	60000	M
1114	OJIFJW	UBHBEIOGEF	2932890156 Dell Way	\N	ETSGSSD	VA	67205	US	1	UBHBEIOGEF@dell.com	2932890156	2	6367245740257204	2009/10	user1114	password	45	100000	F
1115	SBNPVO	XWTGKAKQEE	3353280163 Dell Way	\N	IKXAOUR	RI	24504	US	1	XWTGKAKQEE@dell.com	3353280163	1	9741720651742072	2011/11	user1115	password	27	40000	M
1116	QYTFVQ	ZBAAMREQZP	4945788398 Dell Way	\N	NAEHRYM	WI	11721	US	1	ZBAAMREQZP@dell.com	4945788398	3	9206015689298512	2010/12	user1116	password	80	40000	M
1117	PLRGLT	HLFYQWYGJY	3720263944 Dell Way	\N	KRQJDOK	NH	23023	US	1	HLFYQWYGJY@dell.com	3720263944	1	1641444447916001	2008/05	user1117	password	86	80000	M
1118	QAHJHS	OFJLDPUCAM	5500175806 Dell Way	\N	SKQHUGL	CA	46168	US	1	OFJLDPUCAM@dell.com	5500175806	2	8136989581864328	2010/01	user1118	password	64	20000	F
1119	XKHQZN	AKRPFUQSMA	8073455262 Dell Way	\N	JUUPFWZ	OH	19758	US	1	AKRPFUQSMA@dell.com	8073455262	1	1990842300467193	2010/03	user1119	password	26	40000	M
1120	KZPYAZ	QQFKGYXGHR	2381843876 Dell Way	\N	BWWYWPB	NV	74585	US	1	QQFKGYXGHR@dell.com	2381843876	1	9145619051996620	2009/05	user1120	password	54	80000	F
1121	CQKCGA	HRHFOONFPJ	3729436915 Dell Way	\N	COGRPXK	PA	96297	US	1	HRHFOONFPJ@dell.com	3729436915	1	4375221726484597	2012/09	user1121	password	75	100000	F
1122	FZQGHH	NNVCABSJEG	8552795463 Dell Way	\N	QWVNGPM	ND	65101	US	1	NNVCABSJEG@dell.com	8552795463	2	3961355756502599	2011/04	user1122	password	68	100000	F
1123	IBNPPA	LRANJKRQAN	1033085031 Dell Way	\N	MNUBZIR	TN	72946	US	1	LRANJKRQAN@dell.com	1033085031	3	9585959120653572	2011/04	user1123	password	31	100000	F
1124	SPYSAQ	TOADGQEUCR	5949581804 Dell Way	\N	OERXWNP	TX	97297	US	1	TOADGQEUCR@dell.com	5949581804	3	3284202670212835	2011/07	user1124	password	62	60000	F
1125	OEEEXT	FAZWFTZXHD	3843895026 Dell Way	\N	PEZCUWB	KY	45420	US	1	FAZWFTZXHD@dell.com	3843895026	1	9448858195450158	2012/07	user1125	password	23	60000	M
1126	GROZWP	YSUSRSZVHE	9991475042 Dell Way	\N	VJZRLHB	OR	44178	US	1	YSUSRSZVHE@dell.com	9991475042	4	9038349139969796	2008/02	user1126	password	59	40000	M
1127	DISSHL	NZCFZYMETW	7309120446 Dell Way	\N	DKHLMAV	MO	73538	US	1	NZCFZYMETW@dell.com	7309120446	3	8693804945796729	2009/11	user1127	password	67	40000	F
1128	JCNUQN	XWMVJQPFTA	2064007698 Dell Way	\N	NENOZZG	OH	59591	US	1	XWMVJQPFTA@dell.com	2064007698	5	5073235777206719	2011/05	user1128	password	68	20000	F
1129	FZCSWY	FSIVIOPIBU	8608305053 Dell Way	\N	WQUVXMK	AK	49014	US	1	FSIVIOPIBU@dell.com	8608305053	5	8023607753682882	2010/12	user1129	password	35	80000	M
1130	ILVHQN	QMWEBFGWBW	3905179642 Dell Way	\N	QXTCHTO	CT	59834	US	1	QMWEBFGWBW@dell.com	3905179642	4	5708472591824830	2010/05	user1130	password	51	100000	M
1131	HFNUVZ	RZBWFYXCOU	6965588090 Dell Way	\N	VRCPFFD	NC	88314	US	1	RZBWFYXCOU@dell.com	6965588090	1	3432121824473143	2008/12	user1131	password	27	40000	F
1132	QFAQWA	RSFPPIEKDV	8452882922 Dell Way	\N	MTBRWOO	NC	70217	US	1	RSFPPIEKDV@dell.com	8452882922	4	6974834097083659	2012/01	user1132	password	80	60000	F
1133	WFCWWU	CMKKQUOMHH	4912998121 Dell Way	\N	NZECNSU	LA	41737	US	1	CMKKQUOMHH@dell.com	4912998121	2	4618980550672859	2009/11	user1133	password	65	20000	F
1134	TBZODL	YOCTDPAKDZ	1206506038 Dell Way	\N	OFNGZWQ	MI	26416	US	1	YOCTDPAKDZ@dell.com	1206506038	4	1639569860417395	2011/11	user1134	password	29	60000	M
1135	DYBPXQ	SQTHRDLRSQ	3788035747 Dell Way	\N	EZQBPCG	NM	82847	US	1	SQTHRDLRSQ@dell.com	3788035747	2	7292294480372221	2010/09	user1135	password	63	60000	M
1136	SEOIXF	BEWFPNYGSY	5550192152 Dell Way	\N	XTOZAEU	KS	54319	US	1	BEWFPNYGSY@dell.com	5550192152	4	2898263089358806	2008/05	user1136	password	82	100000	M
1137	LELQFQ	NLGBKNTILN	7855668939 Dell Way	\N	WLOBGWO	OR	67898	US	1	NLGBKNTILN@dell.com	7855668939	5	1241648721974343	2011/09	user1137	password	61	20000	M
1138	BTCSGN	YIXMCFXQCI	7197860656 Dell Way	\N	EEOASHR	MO	24677	US	1	YIXMCFXQCI@dell.com	7197860656	1	8786037920508535	2009/03	user1138	password	70	40000	M
1139	UAFIZN	FLQLIGORKS	5841473169 Dell Way	\N	FKKNCXR	RI	10311	US	1	FLQLIGORKS@dell.com	5841473169	1	2868727202992886	2009/05	user1139	password	29	20000	F
1140	JJKXPW	NBFTPWDICO	8516329956 Dell Way	\N	TPQQGKQ	SD	51248	US	1	NBFTPWDICO@dell.com	8516329956	1	8634680937044323	2012/02	user1140	password	37	40000	M
1141	RGCOTE	TNTPRCSFVH	6263086754 Dell Way	\N	WLOHBJT	VA	48459	US	1	TNTPRCSFVH@dell.com	6263086754	5	5961313840933145	2012/03	user1141	password	21	60000	F
1142	ECGIVU	CLLEDRZKOK	3822017164 Dell Way	\N	ZVMIOJT	DC	34769	US	1	CLLEDRZKOK@dell.com	3822017164	1	5696496117860079	2009/07	user1142	password	19	60000	M
1143	HVLBXX	NCAFBLTMKP	2254077260 Dell Way	\N	YTEIMIQ	SD	39676	US	1	NCAFBLTMKP@dell.com	2254077260	1	8927095699124039	2008/09	user1143	password	55	60000	M
1144	ZNMWBO	WGPHACRQBL	3859359687 Dell Way	\N	UKYCATL	DC	92368	US	1	WGPHACRQBL@dell.com	3859359687	2	6560980184469373	2012/10	user1144	password	29	80000	F
1145	QQIENP	UUQWMGXXAH	2053448943 Dell Way	\N	WDHPPLM	VA	77117	US	1	UUQWMGXXAH@dell.com	2053448943	4	5488892461173237	2009/07	user1145	password	74	100000	F
1146	CCRSWM	ITZOQXPYTT	9397441464 Dell Way	\N	GIIRVFL	WA	94059	US	1	ITZOQXPYTT@dell.com	9397441464	2	5081121572293341	2011/02	user1146	password	63	100000	F
1147	HNBUVU	TKLQAKJTQS	6869461231 Dell Way	\N	BINGTMF	OH	71289	US	1	TKLQAKJTQS@dell.com	6869461231	3	8240450949873776	2009/03	user1147	password	18	60000	M
1148	CIPWCZ	ISZTCSJUUS	3420879194 Dell Way	\N	IBMUGEM	VA	62808	US	1	ISZTCSJUUS@dell.com	3420879194	1	8318733470514418	2009/09	user1148	password	58	40000	F
1149	DGEDPW	CIZVRUQKCR	5110487980 Dell Way	\N	WWXBJVQ	NJ	98820	US	1	CIZVRUQKCR@dell.com	5110487980	5	7515112812630833	2008/04	user1149	password	76	20000	F
1150	ZHBVKJ	VGBPWMSNJP	9794376144 Dell Way	\N	LKYGBOG	MT	49389	US	1	VGBPWMSNJP@dell.com	9794376144	3	7191073553171010	2011/09	user1150	password	31	80000	M
1151	GPJQKP	SALESZNHLY	9024771336 Dell Way	\N	FRZTYNF	VT	12531	US	1	SALESZNHLY@dell.com	9024771336	4	7353121419437230	2008/06	user1151	password	66	40000	F
1152	AYLPQL	BVDAJLLHRD	5714309179 Dell Way	\N	HLBUQZV	MT	72145	US	1	BVDAJLLHRD@dell.com	5714309179	3	2161582024302333	2008/12	user1152	password	29	20000	M
1153	PUNAVI	EWSQHZHKHS	3687853065 Dell Way	\N	MBJMWXE	MD	53692	US	1	EWSQHZHKHS@dell.com	3687853065	3	4628192714881152	2010/10	user1153	password	37	20000	M
1154	UBKDGH	VWOUDZBWLD	9994528830 Dell Way	\N	FYACCKP	MD	10508	US	1	VWOUDZBWLD@dell.com	9994528830	5	8149991699028761	2009/11	user1154	password	45	20000	M
1155	UEEBZB	QUEPWBBZHZ	3011226736 Dell Way	\N	AKCLZNL	WY	43740	US	1	QUEPWBBZHZ@dell.com	3011226736	2	3400200255680829	2011/04	user1155	password	33	60000	F
1156	KMMLCG	QSCRTCYTCI	1224733454 Dell Way	\N	WOIJZIT	FL	60321	US	1	QSCRTCYTCI@dell.com	1224733454	4	8747510473243893	2009/03	user1156	password	42	80000	M
1157	UCTBSL	EKFHJZKRVY	7697632609 Dell Way	\N	AFXIZCW	AK	89182	US	1	EKFHJZKRVY@dell.com	7697632609	2	1676562396809458	2008/11	user1157	password	72	100000	M
1158	NYRZCC	EJLETDARDG	6584422896 Dell Way	\N	PLFRIFO	CA	53173	US	1	EJLETDARDG@dell.com	6584422896	1	4366682645864785	2009/01	user1158	password	43	100000	M
1159	BVBDAL	OEFREXVKMH	7458728915 Dell Way	\N	QDPWRSI	IN	88143	US	1	OEFREXVKMH@dell.com	7458728915	4	9234037233982236	2008/07	user1159	password	83	20000	F
1160	ZGJKUO	PMTMHEYOUC	6894359905 Dell Way	\N	ERTWABT	OK	74652	US	1	PMTMHEYOUC@dell.com	6894359905	4	3184881488792598	2010/11	user1160	password	61	60000	F
1161	ZYYNNK	HASLZGFCLX	8785094713 Dell Way	\N	VHXXBPQ	OH	45867	US	1	HASLZGFCLX@dell.com	8785094713	2	3736344764474779	2010/10	user1161	password	50	60000	M
1162	KZFVGG	NRGUXIFUEN	9851954848 Dell Way	\N	RBOHRGR	NC	55600	US	1	NRGUXIFUEN@dell.com	9851954848	1	3405603331048042	2010/06	user1162	password	87	100000	F
1163	EQRKEI	QYGZEADRSE	3451378622 Dell Way	\N	GZWMRKA	NM	48574	US	1	QYGZEADRSE@dell.com	3451378622	1	8940888305194677	2009/11	user1163	password	40	40000	M
1164	ZVSIMR	OLVPONHTTH	3972897758 Dell Way	\N	PGYAGPL	MT	69892	US	1	OLVPONHTTH@dell.com	3972897758	4	6190089133102447	2011/02	user1164	password	27	80000	M
1165	WYKNMV	JCKWJDPQTV	4765847926 Dell Way	\N	PTCEFPV	NC	41370	US	1	JCKWJDPQTV@dell.com	4765847926	1	5366546459961683	2010/10	user1165	password	49	60000	M
1166	VYFRHH	BDRFTIYOXR	1922880199 Dell Way	\N	RCXGYKQ	KY	62742	US	1	BDRFTIYOXR@dell.com	1922880199	5	4308956537395716	2010/04	user1166	password	23	40000	F
1167	HBNPDR	GIKOHZMYQO	2955155529 Dell Way	\N	VXNGNWW	NJ	78001	US	1	GIKOHZMYQO@dell.com	2955155529	1	1574904051609337	2009/07	user1167	password	40	60000	M
1168	VESMKB	WZIVMHMBDJ	2994714902 Dell Way	\N	OKXKGNE	MN	70270	US	1	WZIVMHMBDJ@dell.com	2994714902	4	2825575937516987	2010/05	user1168	password	76	40000	M
1169	NVYPSX	XNKFALIKZT	6980532651 Dell Way	\N	HKZUOLM	RI	29576	US	1	XNKFALIKZT@dell.com	6980532651	2	6121812169905753	2010/08	user1169	password	24	100000	F
1170	AOEYMS	IRSUACTTJD	9838136673 Dell Way	\N	TERFQLK	IL	76295	US	1	IRSUACTTJD@dell.com	9838136673	4	4343630882445723	2008/09	user1170	password	78	20000	F
1171	ZATRJL	KDLMXFWAYA	3483590867 Dell Way	\N	SDQEOXX	NC	69911	US	1	KDLMXFWAYA@dell.com	3483590867	4	4535122119821608	2008/09	user1171	password	67	20000	M
1172	LUDXEG	JQEOMFNNXR	1997016527 Dell Way	\N	DCGBZUS	ID	46264	US	1	JQEOMFNNXR@dell.com	1997016527	2	2016878482419997	2011/06	user1172	password	80	40000	F
1173	ZDKGMB	KAOPOBNFEP	7888413958 Dell Way	\N	MGPGYWQ	AZ	30153	US	1	KAOPOBNFEP@dell.com	7888413958	5	7225091364700348	2011/02	user1173	password	86	80000	F
1174	JVSKGS	YVHAJNFYZL	3749976576 Dell Way	\N	NFKKWLP	NM	37935	US	1	YVHAJNFYZL@dell.com	3749976576	2	4662327529396862	2009/11	user1174	password	63	60000	M
1175	IZYBYU	IZDWECVPQB	2256824919 Dell Way	\N	ZAXKQOT	WI	84682	US	1	IZDWECVPQB@dell.com	2256824919	1	7296675550285727	2011/10	user1175	password	48	20000	M
1176	JDTEMS	IIWLDLBFKC	2927905115 Dell Way	\N	DVTROSN	OK	89821	US	1	IIWLDLBFKC@dell.com	2927905115	3	7058489073999227	2011/07	user1176	password	51	100000	M
1177	FEFXMN	TXRFZWPBAL	1618311417 Dell Way	\N	VRANFSK	ME	27087	US	1	TXRFZWPBAL@dell.com	1618311417	1	7818666306789965	2010/01	user1177	password	52	80000	F
1178	RQSFJP	WOPTERUQML	3637541169 Dell Way	\N	QZRIJCN	MI	21459	US	1	WOPTERUQML@dell.com	3637541169	5	2541675650980323	2011/09	user1178	password	45	60000	F
1179	CQSRNH	HHLYBBKNSK	6019114007 Dell Way	\N	EBUGPFK	UT	28572	US	1	HHLYBBKNSK@dell.com	6019114007	4	9154713706113400	2012/01	user1179	password	34	20000	M
1180	YSGFZN	QYOSJCLTGM	8855729380 Dell Way	\N	NNBTXYZ	MN	64224	US	1	QYOSJCLTGM@dell.com	8855729380	3	7143075913190842	2008/06	user1180	password	46	20000	F
1181	QFDDWB	SPKUBEBNRO	8704528287 Dell Way	\N	PLMOKYE	IL	40514	US	1	SPKUBEBNRO@dell.com	8704528287	2	7866826752666385	2009/06	user1181	password	83	100000	M
1182	AANCTD	MNERPSIDIU	6944321760 Dell Way	\N	QXFOCMX	WI	89413	US	1	MNERPSIDIU@dell.com	6944321760	1	3698032610584050	2010/01	user1182	password	87	60000	F
1183	MRVQEJ	VVYOECWZSU	8705574923 Dell Way	\N	EGXREVO	TN	12504	US	1	VVYOECWZSU@dell.com	8705574923	2	1949198826216161	2012/12	user1183	password	33	40000	M
1184	BXVKSR	IGWLDVDYAK	8042449530 Dell Way	\N	VROQGKR	CA	79232	US	1	IGWLDVDYAK@dell.com	8042449530	5	7694955027662218	2012/03	user1184	password	47	20000	F
1185	GLUXUA	TFEPICPSXH	2642825285 Dell Way	\N	HONRGQL	AL	56551	US	1	TFEPICPSXH@dell.com	2642825285	1	7248809443321080	2010/01	user1185	password	74	100000	F
1186	OSGPML	TCTWRMTZUI	3905649938 Dell Way	\N	MLOCWPQ	AZ	64660	US	1	TCTWRMTZUI@dell.com	3905649938	4	6844761443790049	2008/06	user1186	password	26	80000	F
1187	JFRUZT	OVLBPKVXXG	4094083344 Dell Way	\N	MADCQES	WV	84792	US	1	OVLBPKVXXG@dell.com	4094083344	1	3611740007996559	2010/09	user1187	password	52	100000	M
1188	DQXXET	JGITBGRHTR	7626801777 Dell Way	\N	LVIPNHL	UT	41053	US	1	JGITBGRHTR@dell.com	7626801777	2	1429835821501910	2009/03	user1188	password	89	40000	M
1189	XHZQQF	ZKGGBOZSZV	7577348619 Dell Way	\N	BPJIBGR	RI	63368	US	1	ZKGGBOZSZV@dell.com	7577348619	5	7892526195850224	2011/05	user1189	password	59	80000	M
1190	OGGUFQ	AMRPMKOHME	3478145970 Dell Way	\N	RUFXMZN	HI	99354	US	1	AMRPMKOHME@dell.com	3478145970	5	4141131117474288	2012/07	user1190	password	89	40000	M
1191	FEAWFM	OUYZJGLNXG	1805189284 Dell Way	\N	TVSTIYT	NJ	88089	US	1	OUYZJGLNXG@dell.com	1805189284	3	4642435890156776	2008/11	user1191	password	31	40000	F
1192	FEFRSZ	QRJWCWUIQP	3437467819 Dell Way	\N	BJYZCOW	GA	11672	US	1	QRJWCWUIQP@dell.com	3437467819	2	8791427756659687	2010/07	user1192	password	81	80000	M
1193	CJLBZC	KWFHQOXGPH	6970047615 Dell Way	\N	FPKUMPU	OR	88555	US	1	KWFHQOXGPH@dell.com	6970047615	2	4926081547047943	2010/11	user1193	password	29	80000	F
1194	PRFSCB	XKSLIZBPER	9252550791 Dell Way	\N	AZDPTXM	MI	18861	US	1	XKSLIZBPER@dell.com	9252550791	5	9730316875502468	2008/08	user1194	password	32	80000	F
1195	KJJMGU	ESCEUSJLSI	6108009036 Dell Way	\N	PHCMUNP	OH	54668	US	1	ESCEUSJLSI@dell.com	6108009036	4	1783093858975917	2011/06	user1195	password	44	20000	M
1196	TQBNVU	QZPIIBARQI	8771649470 Dell Way	\N	TDCHTVU	IN	63780	US	1	QZPIIBARQI@dell.com	8771649470	1	1385348526760935	2009/03	user1196	password	79	100000	M
1197	XNRSDR	HLAIMRZUKD	4328178906 Dell Way	\N	XSWSMEI	KY	32856	US	1	HLAIMRZUKD@dell.com	4328178906	3	5402132391463965	2009/07	user1197	password	44	20000	F
1198	BWFSDQ	SMDJMYUPVM	4499614181 Dell Way	\N	MOZQXIX	ID	89612	US	1	SMDJMYUPVM@dell.com	4499614181	3	4916798174381256	2011/08	user1198	password	54	80000	F
1199	SNQJFC	MPOKKEGXQU	5532655102 Dell Way	\N	WHSEEZB	ND	50160	US	1	MPOKKEGXQU@dell.com	5532655102	2	1610100308433175	2008/02	user1199	password	57	80000	M
1200	EBVHNK	WXVAESQZOX	2310552587 Dell Way	\N	RTCQVRC	KS	97751	US	1	WXVAESQZOX@dell.com	2310552587	2	1683165643364191	2011/01	user1200	password	67	100000	F
1201	MDPXZN	SZRLQQZOIT	4425416917 Dell Way	\N	RYPIAXH	DE	31500	US	1	SZRLQQZOIT@dell.com	4425416917	5	3389828681480140	2008/09	user1201	password	42	60000	M
1202	YMVLEV	DPMTPACJSA	4227949801 Dell Way	\N	YABWIFC	OK	16236	US	1	DPMTPACJSA@dell.com	4227949801	4	8036445614881814	2011/04	user1202	password	63	80000	M
1203	LBZHFP	TZFUBOMBNN	2614680824 Dell Way	\N	CJVIMOK	SD	39145	US	1	TZFUBOMBNN@dell.com	2614680824	3	6868555990513415	2012/02	user1203	password	50	40000	F
1204	LNKAHJ	FBLUNMIAPR	4530670042 Dell Way	\N	WYDKIZT	MT	54364	US	1	FBLUNMIAPR@dell.com	4530670042	2	6747335934545845	2012/07	user1204	password	80	40000	F
1205	HHKRNL	CIZOQZEIWD	6299281891 Dell Way	\N	MHLLAZY	MD	36739	US	1	CIZOQZEIWD@dell.com	6299281891	2	8887790327426047	2010/07	user1205	password	90	80000	M
1206	JJIVLR	UAHUFQQICX	9535755087 Dell Way	\N	UOXUNIB	CO	60957	US	1	UAHUFQQICX@dell.com	9535755087	3	1722118493169546	2012/04	user1206	password	82	40000	M
1207	FDCWXD	ERJUHRXFMM	1781899890 Dell Way	\N	DGALICA	IL	70368	US	1	ERJUHRXFMM@dell.com	1781899890	2	9515914124902340	2012/07	user1207	password	61	20000	M
1208	SBOVGG	EBOWYTJLWP	2660897348 Dell Way	\N	LIYOIFG	MD	50368	US	1	EBOWYTJLWP@dell.com	2660897348	2	9831524282693864	2011/07	user1208	password	64	60000	M
1209	FIWLMY	AJXTSIQIUY	9449899496 Dell Way	\N	HJGNPRY	RI	15315	US	1	AJXTSIQIUY@dell.com	9449899496	3	6709414306096733	2010/01	user1209	password	38	80000	F
1210	EGVCGF	ZAXIQGCPNL	3119827488 Dell Way	\N	WBBOZVP	WA	44372	US	1	ZAXIQGCPNL@dell.com	3119827488	3	4776421991176903	2010/04	user1210	password	74	80000	M
1211	PTVVTV	TBMZEBNPYO	3532412716 Dell Way	\N	RMOMCNW	KS	12273	US	1	TBMZEBNPYO@dell.com	3532412716	5	4037183351814747	2008/07	user1211	password	83	80000	F
1212	SMAOFB	AFFCTVBIMN	7813866502 Dell Way	\N	XZPKVYK	CO	78213	US	1	AFFCTVBIMN@dell.com	7813866502	1	3380625611636788	2011/10	user1212	password	57	40000	F
1213	OXOQYT	VBNRCVEPSD	2404508642 Dell Way	\N	FDYDOBX	IN	30124	US	1	VBNRCVEPSD@dell.com	2404508642	5	1458697895053774	2011/04	user1213	password	44	40000	F
1214	XWERSF	EJHANXTQCW	9397217994 Dell Way	\N	PGKRDSW	IL	70487	US	1	EJHANXTQCW@dell.com	9397217994	5	9969915798865260	2009/03	user1214	password	35	40000	F
1215	KWTQBD	YCQVWHYTXE	5874657648 Dell Way	\N	EOIWLPO	LA	62864	US	1	YCQVWHYTXE@dell.com	5874657648	4	8264061308465899	2011/11	user1215	password	82	20000	M
1216	QVVUTX	LPUTONQSRE	1440355503 Dell Way	\N	BNPRCZG	NJ	68059	US	1	LPUTONQSRE@dell.com	1440355503	3	5630872165318579	2012/08	user1216	password	37	60000	F
1217	CJFZUU	TNIHEBYIDM	1867803111 Dell Way	\N	YUOYAEP	AZ	62075	US	1	TNIHEBYIDM@dell.com	1867803111	5	2577398609835654	2009/07	user1217	password	62	60000	M
1218	ULTPFH	YMLAKUDXTX	4402754103 Dell Way	\N	LRYQGZF	LA	99145	US	1	YMLAKUDXTX@dell.com	4402754103	4	6125697651412339	2012/02	user1218	password	55	80000	M
1219	GJUOIG	ZIRUMONKAF	8795574468 Dell Way	\N	IQMHWVH	HI	60265	US	1	ZIRUMONKAF@dell.com	8795574468	2	7444811091758312	2009/12	user1219	password	40	80000	F
1220	CESJEA	BYNQMXQSFH	3614839308 Dell Way	\N	ENDAVJO	NY	62909	US	1	BYNQMXQSFH@dell.com	3614839308	1	6226642499677837	2010/09	user1220	password	87	80000	M
1221	QBBRDA	FTNCKFHSKU	4525907885 Dell Way	\N	VKQFZHV	ID	41234	US	1	FTNCKFHSKU@dell.com	4525907885	5	1399452143348753	2009/07	user1221	password	85	100000	M
1222	ZRTAWM	NZWTGPDBLN	4333791902 Dell Way	\N	RQNZLUI	TX	68545	US	1	NZWTGPDBLN@dell.com	4333791902	1	2922382128890604	2009/03	user1222	password	79	40000	M
1223	PHTBVS	YOZNRBYFTP	4440814058 Dell Way	\N	TSBNBXE	ME	19449	US	1	YOZNRBYFTP@dell.com	4440814058	4	3696110866498202	2009/01	user1223	password	31	100000	F
1224	YWDRVS	RIKSHQMXJF	3404217165 Dell Way	\N	YWGWBRZ	ME	45830	US	1	RIKSHQMXJF@dell.com	3404217165	4	4698965092189610	2010/06	user1224	password	71	40000	F
1225	WBDOSM	ZKUPXRYCQV	8326174978 Dell Way	\N	IMWALHK	OK	94923	US	1	ZKUPXRYCQV@dell.com	8326174978	1	4539953046478331	2010/07	user1225	password	69	60000	M
1226	WZHIYS	COPUNRKIAX	8537140931 Dell Way	\N	FAJNLCL	IA	32633	US	1	COPUNRKIAX@dell.com	8537140931	4	8245343768503518	2010/03	user1226	password	47	40000	F
1227	SSDLVR	APFSANTXTT	4637782856 Dell Way	\N	GGFJRLP	MT	29419	US	1	APFSANTXTT@dell.com	4637782856	1	4657123566139490	2012/06	user1227	password	60	60000	F
1228	SYAKZQ	PSQDLOWFVD	5252809721 Dell Way	\N	KEUWTIB	DE	45104	US	1	PSQDLOWFVD@dell.com	5252809721	5	8695965980645270	2008/06	user1228	password	21	80000	F
1229	BELRUD	IYPWVVSYFW	3747464519 Dell Way	\N	TCQBDUL	NJ	80161	US	1	IYPWVVSYFW@dell.com	3747464519	4	3491397725883871	2009/06	user1229	password	70	60000	M
1230	DCLHLJ	WHESADYWWA	4199139356 Dell Way	\N	MXEHJUC	NY	50346	US	1	WHESADYWWA@dell.com	4199139356	1	9072684219107032	2008/06	user1230	password	56	40000	M
1231	YNZIKG	NCHQADMAQK	3754688526 Dell Way	\N	EYUYAMK	MA	54005	US	1	NCHQADMAQK@dell.com	3754688526	3	9337467262055726	2012/09	user1231	password	51	80000	F
1232	LDPSQS	ZGSCTTTEYR	8509083495 Dell Way	\N	YXSKHCX	NJ	58026	US	1	ZGSCTTTEYR@dell.com	8509083495	3	2909470205195248	2009/03	user1232	password	47	80000	F
1233	AKZSKG	KMAEGECYDA	5249969525 Dell Way	\N	QOHSMXG	IN	43359	US	1	KMAEGECYDA@dell.com	5249969525	3	6544500386342407	2012/04	user1233	password	89	100000	M
1234	ZPDGZQ	GEWLGUOGLD	5315306331 Dell Way	\N	OEPMLXW	VA	55239	US	1	GEWLGUOGLD@dell.com	5315306331	4	8417836688924582	2010/08	user1234	password	59	60000	F
1235	RRGHYK	EJRZYYKBNP	9154594678 Dell Way	\N	RZAPWXC	KY	71888	US	1	EJRZYYKBNP@dell.com	9154594678	5	4175608948804438	2010/03	user1235	password	61	20000	M
1236	VMVGQF	XPDWAFJPXJ	5837820223 Dell Way	\N	PMFMOOE	MN	41921	US	1	XPDWAFJPXJ@dell.com	5837820223	5	6368336020503194	2008/02	user1236	password	55	100000	M
1237	JFEODU	SZUYIJVSYH	4697452217 Dell Way	\N	XLWLQIV	FL	32987	US	1	SZUYIJVSYH@dell.com	4697452217	2	4088275284506381	2012/04	user1237	password	83	40000	M
1238	BWRWOR	QNZAISZQPK	4859249548 Dell Way	\N	NBBVWGC	IL	60014	US	1	QNZAISZQPK@dell.com	4859249548	2	8657416421920062	2009/06	user1238	password	45	40000	F
1239	AGYRWL	RXUJWKZGXB	9794601207 Dell Way	\N	ITXOVFD	ID	46956	US	1	RXUJWKZGXB@dell.com	9794601207	3	9169237214140596	2009/12	user1239	password	37	40000	F
1240	EBCQTZ	KDVUDCSELM	6414816339 Dell Way	\N	CAIHDPS	CO	26124	US	1	KDVUDCSELM@dell.com	6414816339	3	2463881296571344	2012/11	user1240	password	46	20000	M
1241	NRRMBV	IWZLPDXCFX	3986013693 Dell Way	\N	KMBZFEE	SC	66463	US	1	IWZLPDXCFX@dell.com	3986013693	4	5314047230873257	2011/09	user1241	password	47	40000	F
1242	CSLYBH	XNXAKZGHJT	6508847273 Dell Way	\N	IJYNNTD	TX	45632	US	1	XNXAKZGHJT@dell.com	6508847273	3	1909392702858895	2008/10	user1242	password	52	20000	M
1243	XBOFYB	CZMBGUKZDT	2548106108 Dell Way	\N	YQHRTDB	LA	74745	US	1	CZMBGUKZDT@dell.com	2548106108	2	5686758194584400	2011/07	user1243	password	20	60000	M
1244	PTNRVN	EWTYHTBARR	7306813064 Dell Way	\N	IJLLLUE	NH	26131	US	1	EWTYHTBARR@dell.com	7306813064	2	7154351722914726	2011/10	user1244	password	35	40000	M
1245	TBIHFF	ADMTENLWVV	9497200876 Dell Way	\N	HHGCMVG	DE	17181	US	1	ADMTENLWVV@dell.com	9497200876	5	8824372060131282	2008/04	user1245	password	47	100000	F
1246	TFNYGQ	LAVYMSUHZB	3642156735 Dell Way	\N	NBOIISL	IL	66381	US	1	LAVYMSUHZB@dell.com	3642156735	3	9037816038355232	2011/05	user1246	password	32	60000	M
1247	SKWJVX	FTJXNQXPDZ	4380578584 Dell Way	\N	DMIWXPM	GA	14652	US	1	FTJXNQXPDZ@dell.com	4380578584	5	5196654607541859	2010/04	user1247	password	25	40000	M
1248	ZRNWWH	GUVWSLARON	1833503601 Dell Way	\N	ZLKOXQQ	IL	56706	US	1	GUVWSLARON@dell.com	1833503601	5	8647492110263557	2008/02	user1248	password	59	20000	M
1249	CBSKHM	FEFREWGSWR	1931503626 Dell Way	\N	CLPTBWG	DE	77181	US	1	FEFREWGSWR@dell.com	1931503626	2	9200079914648088	2011/07	user1249	password	72	80000	M
1250	LEXYKB	DBGAHYXZBI	1750090869 Dell Way	\N	OUKLBOE	DC	90768	US	1	DBGAHYXZBI@dell.com	1750090869	5	4847821745555848	2012/08	user1250	password	19	40000	M
1251	XFDYJF	FKMDHLFPAZ	8751305933 Dell Way	\N	ZLANPEL	OH	99287	US	1	FKMDHLFPAZ@dell.com	8751305933	3	6217229102738202	2012/10	user1251	password	42	80000	F
1252	MTJRYT	ECBQHQQGQC	1416272724 Dell Way	\N	HERMPJM	MN	90503	US	1	ECBQHQQGQC@dell.com	1416272724	2	7129039179999382	2009/02	user1252	password	68	100000	M
1253	BOUVTW	WJENALEDSI	7910781486 Dell Way	\N	VFYFRKC	OK	78230	US	1	WJENALEDSI@dell.com	7910781486	1	8917337235994638	2010/12	user1253	password	71	60000	M
1254	NJGKGQ	OTRZXUSGPX	3230637568 Dell Way	\N	FUOPWGJ	NM	42322	US	1	OTRZXUSGPX@dell.com	3230637568	1	3832069941796362	2012/08	user1254	password	78	60000	M
1255	BXFSMY	JLWDDDTBIN	5866005663 Dell Way	\N	PYKWHBF	ND	23619	US	1	JLWDDDTBIN@dell.com	5866005663	3	7950702651403845	2009/01	user1255	password	72	60000	M
1256	YDKXNW	UQAXKBGYQE	3839973242 Dell Way	\N	INMKTBO	ID	63032	US	1	UQAXKBGYQE@dell.com	3839973242	4	6716259240638465	2008/01	user1256	password	61	20000	F
1257	AYSWSJ	WQTXXROCAB	8727373118 Dell Way	\N	PLUQZBF	IL	72441	US	1	WQTXXROCAB@dell.com	8727373118	2	7893223624676467	2010/05	user1257	password	89	60000	F
1258	RIABFQ	VCONRQNSFY	1095465996 Dell Way	\N	MWYOBFG	WA	59932	US	1	VCONRQNSFY@dell.com	1095465996	2	9237475142814220	2012/11	user1258	password	32	80000	F
1259	FSJWNL	KACBOVGNIC	2198377942 Dell Way	\N	LWERCCF	CT	52762	US	1	KACBOVGNIC@dell.com	2198377942	1	3779399059712887	2009/10	user1259	password	52	60000	F
1260	VKAHVB	KWQFCENFPK	3382882887 Dell Way	\N	JHMMMQY	NJ	74869	US	1	KWQFCENFPK@dell.com	3382882887	5	5477795827202499	2011/07	user1260	password	90	60000	M
1261	AVTCFP	SLSWYYMIIT	7022552804 Dell Way	\N	VUGLTXE	AL	86764	US	1	SLSWYYMIIT@dell.com	7022552804	4	4301815981511027	2011/04	user1261	password	39	80000	F
1262	BUJRMU	JJTIWCQQXL	1055782324 Dell Way	\N	XJFUNGQ	GA	99818	US	1	JJTIWCQQXL@dell.com	1055782324	5	3764095297083259	2009/07	user1262	password	50	40000	F
1263	UAVPKF	ISCKJSIVPR	6197280227 Dell Way	\N	AKFHALH	AR	36577	US	1	ISCKJSIVPR@dell.com	6197280227	2	8687772041652352	2008/09	user1263	password	31	100000	M
1264	AKCGTU	IEDAMZQEAA	9641742521 Dell Way	\N	KHBVODC	CT	51380	US	1	IEDAMZQEAA@dell.com	9641742521	1	2337703160475939	2008/12	user1264	password	79	20000	F
1265	XKDSSH	WTUVJYVKIC	2942048177 Dell Way	\N	MDQPGTB	GA	91803	US	1	WTUVJYVKIC@dell.com	2942048177	2	8924281693063677	2008/07	user1265	password	37	100000	M
1266	KRRSOK	MJUKFFTHSW	5461207915 Dell Way	\N	YHDSJIP	NE	70323	US	1	MJUKFFTHSW@dell.com	5461207915	4	2767940097954124	2011/08	user1266	password	27	20000	F
1267	UWVEJF	ZUKENSWKQE	7401435011 Dell Way	\N	NIOVYDN	MN	80560	US	1	ZUKENSWKQE@dell.com	7401435011	2	4592524028848857	2012/05	user1267	password	68	80000	F
1268	NVQSUL	DZYVWJLBXU	9265348918 Dell Way	\N	PTTTGFN	WV	48695	US	1	DZYVWJLBXU@dell.com	9265348918	5	8434796594083310	2011/06	user1268	password	25	20000	F
1269	TWBEZA	DVXNHYKCND	3724170473 Dell Way	\N	VGJBUIM	OH	22659	US	1	DVXNHYKCND@dell.com	3724170473	2	6172279328107834	2010/06	user1269	password	78	20000	F
1270	WIIXMD	UZKSJMGMIM	9261141169 Dell Way	\N	WJGFWYI	DC	33296	US	1	UZKSJMGMIM@dell.com	9261141169	3	7334417558740825	2011/09	user1270	password	19	80000	F
1271	INNMIN	XBWJHJSUFC	9592704520 Dell Way	\N	AKYZTCG	NY	69138	US	1	XBWJHJSUFC@dell.com	9592704520	3	4403853712603450	2012/01	user1271	password	49	40000	M
1272	ZUXMRZ	IBGRTAXVBI	9144982580 Dell Way	\N	UBCWHUN	ID	28840	US	1	IBGRTAXVBI@dell.com	9144982580	2	3398281784728169	2009/07	user1272	password	80	40000	F
1273	UTZTCA	ZUUARQBAKD	4279385128 Dell Way	\N	CHLXURC	OH	92183	US	1	ZUUARQBAKD@dell.com	4279385128	1	5089569830801338	2009/05	user1273	password	74	100000	F
1274	TTFUTZ	PTRFVSPYVW	4733967915 Dell Way	\N	JSRBUJY	DE	48069	US	1	PTRFVSPYVW@dell.com	4733967915	2	7923961228691042	2008/05	user1274	password	82	100000	F
1275	CTWCIP	UOKMDJHASZ	3549415495 Dell Way	\N	SUUCTYN	DC	39115	US	1	UOKMDJHASZ@dell.com	3549415495	2	7353690022602678	2008/04	user1275	password	78	40000	F
1276	RJKHDY	SPCCXCUWVP	6676436399 Dell Way	\N	RXIPLMY	OK	82917	US	1	SPCCXCUWVP@dell.com	6676436399	5	1967399735003709	2010/02	user1276	password	29	20000	M
1277	OLQMEG	OGDRBAMQRK	3909650452 Dell Way	\N	YHVKFOF	TN	48468	US	1	OGDRBAMQRK@dell.com	3909650452	2	6149609230458737	2010/06	user1277	password	23	20000	M
1278	SMBYBH	CSIDFYVPWC	9854795916 Dell Way	\N	LHHZNDK	TN	50586	US	1	CSIDFYVPWC@dell.com	9854795916	2	9132754561491312	2008/04	user1278	password	76	80000	M
1279	WSWDVO	MYUKTJHWVP	7063157714 Dell Way	\N	EUCIFXU	FL	30315	US	1	MYUKTJHWVP@dell.com	7063157714	2	6006291761994362	2010/01	user1279	password	45	40000	M
1280	GMOVYN	PIHYQETFIO	9997454680 Dell Way	\N	HRTFLYL	CA	28469	US	1	PIHYQETFIO@dell.com	9997454680	3	3005283237434923	2009/11	user1280	password	88	80000	F
1281	OLHCAQ	JZGOTLWITN	5215373832 Dell Way	\N	CZYBKBG	ME	66028	US	1	JZGOTLWITN@dell.com	5215373832	4	5649693867191673	2010/06	user1281	password	81	100000	M
1282	DBWULW	AZQMWYFKAF	5813545196 Dell Way	\N	IBQKHBA	RI	85760	US	1	AZQMWYFKAF@dell.com	5813545196	2	3347836344037205	2010/03	user1282	password	26	60000	F
1283	AIRWIR	MVNKBXLGGM	1234087432 Dell Way	\N	WRUYROT	GA	79313	US	1	MVNKBXLGGM@dell.com	1234087432	4	9638900038320572	2008/03	user1283	password	33	20000	M
1284	XAWOMR	CXSAIZGVWX	9280055068 Dell Way	\N	QUPENUY	ND	47605	US	1	CXSAIZGVWX@dell.com	9280055068	4	6337727468460799	2008/11	user1284	password	25	20000	M
1285	YPJQRG	ISPHZLDXBX	3706324655 Dell Way	\N	MGLHFAS	DC	74423	US	1	ISPHZLDXBX@dell.com	3706324655	2	6088247857056559	2009/04	user1285	password	49	40000	M
1286	UZPBHH	RPGCTDEQQL	4518379884 Dell Way	\N	CXRCQUV	WA	17211	US	1	RPGCTDEQQL@dell.com	4518379884	2	4435934663284570	2012/09	user1286	password	38	60000	M
1287	WQYDHN	KKGOOXEAAC	9494677529 Dell Way	\N	RDTMYRO	KY	99574	US	1	KKGOOXEAAC@dell.com	9494677529	1	7050232279114426	2009/09	user1287	password	40	20000	F
1288	GGRUQC	AFQYJRYMIB	6036190723 Dell Way	\N	FVAXKJX	KS	54934	US	1	AFQYJRYMIB@dell.com	6036190723	3	3211065368261188	2012/08	user1288	password	64	20000	M
1289	IXNKXS	BWCSVPBWVW	9855493026 Dell Way	\N	XSGGPPT	DE	22892	US	1	BWCSVPBWVW@dell.com	9855493026	1	8052700300235302	2011/02	user1289	password	66	100000	F
1290	FIZXJV	ACQQDNMAKE	8173702204 Dell Way	\N	HQUWJZA	LA	10625	US	1	ACQQDNMAKE@dell.com	8173702204	5	2490007604938000	2010/11	user1290	password	33	80000	F
1291	EPPAPS	QGVESWOXDF	8624594008 Dell Way	\N	SZPRAZR	SD	95394	US	1	QGVESWOXDF@dell.com	8624594008	2	8766207921784372	2008/12	user1291	password	25	40000	M
1292	SGDKXJ	GBCCQAFVSF	2875206904 Dell Way	\N	LKFKBBI	VT	38011	US	1	GBCCQAFVSF@dell.com	2875206904	5	3146661083213985	2009/03	user1292	password	72	20000	F
1293	WLJGRK	ITAIZWBFHL	1121483289 Dell Way	\N	LSMMBKU	IA	44081	US	1	ITAIZWBFHL@dell.com	1121483289	3	6337985966354609	2011/07	user1293	password	22	80000	F
1294	KWRVEL	WNKSOPAZAS	8602902845 Dell Way	\N	MMTWGAG	IL	60217	US	1	WNKSOPAZAS@dell.com	8602902845	1	2232453940901905	2012/08	user1294	password	28	40000	M
1295	VDSGZF	QSTGSTHLFT	8943069238 Dell Way	\N	ECAEIHT	DE	40482	US	1	QSTGSTHLFT@dell.com	8943069238	1	9943323301617056	2008/05	user1295	password	54	100000	M
1296	FCNKTF	EZYXHJCBOE	7335925228 Dell Way	\N	BTNJMSS	MA	79261	US	1	EZYXHJCBOE@dell.com	7335925228	3	2415418481919914	2009/03	user1296	password	67	60000	F
1297	EVCKZB	IXJSZKHELA	3944714954 Dell Way	\N	SVNKNXE	IA	38148	US	1	IXJSZKHELA@dell.com	3944714954	3	6035146342124791	2008/11	user1297	password	83	20000	M
1298	ZPQBYO	KROUYSFZLB	3546901347 Dell Way	\N	NVPKAVS	KS	34251	US	1	KROUYSFZLB@dell.com	3546901347	2	2119147893507033	2008/07	user1298	password	76	20000	F
1299	LFBZPS	NJRGPQRQDN	5037819487 Dell Way	\N	GONBHWI	ND	27462	US	1	NJRGPQRQDN@dell.com	5037819487	4	7522090847603977	2009/11	user1299	password	80	80000	F
1300	XRRQFB	IMQYEHCRNR	9857565020 Dell Way	\N	FOYBXNG	KY	31688	US	1	IMQYEHCRNR@dell.com	9857565020	3	2186220163479447	2012/04	user1300	password	34	80000	M
1301	XKEYSQ	ORUWUMJLRY	3338335259 Dell Way	\N	KTVXAED	WY	78600	US	1	ORUWUMJLRY@dell.com	3338335259	5	1360991411842405	2010/08	user1301	password	18	40000	M
1302	EISVXK	PTFCCQUBAN	8802586487 Dell Way	\N	XXOBBOV	IN	43834	US	1	PTFCCQUBAN@dell.com	8802586487	4	9711808426305652	2012/02	user1302	password	88	20000	F
1303	RWJCLC	HOFYIGYWDW	3628411340 Dell Way	\N	KFXYBFI	VT	99872	US	1	HOFYIGYWDW@dell.com	3628411340	4	2389753106981516	2009/10	user1303	password	63	100000	M
1304	ZBDBIR	HGAOFWSCHX	4433421249 Dell Way	\N	AFYFOWF	TN	68334	US	1	HGAOFWSCHX@dell.com	4433421249	1	5182659075595439	2008/01	user1304	password	27	100000	F
1305	GBLYIS	YWXVPACMAI	4952097222 Dell Way	\N	LGWIMSZ	TX	83494	US	1	YWXVPACMAI@dell.com	4952097222	5	8790129563305528	2010/11	user1305	password	87	100000	M
1306	KUGCSC	ZOSAQEAZQH	3176754546 Dell Way	\N	VZTOYQJ	MA	53607	US	1	ZOSAQEAZQH@dell.com	3176754546	5	3956134161911905	2009/10	user1306	password	34	60000	M
1307	LRHORV	GRMLSLCZHB	2550676930 Dell Way	\N	TVAJFKV	MN	41712	US	1	GRMLSLCZHB@dell.com	2550676930	4	2262329332064837	2009/04	user1307	password	69	100000	M
1308	ZKPVRG	HDYSFXAHRW	2762372351 Dell Way	\N	HACSWOB	AL	29307	US	1	HDYSFXAHRW@dell.com	2762372351	3	5198405318893492	2012/04	user1308	password	46	100000	M
1309	ZSKFZN	DSTBTBTPJT	9197581332 Dell Way	\N	RBPFCQL	IN	17333	US	1	DSTBTBTPJT@dell.com	9197581332	2	4301616643089801	2009/02	user1309	password	23	40000	M
1310	MMTZQM	TRFUKUDEME	8932857666 Dell Way	\N	USHLEPN	AZ	83328	US	1	TRFUKUDEME@dell.com	8932857666	2	9106347920373084	2012/08	user1310	password	67	60000	F
1311	LKSYDK	DYVYBZLGUE	8937173194 Dell Way	\N	OFIESKZ	NH	78145	US	1	DYVYBZLGUE@dell.com	8937173194	3	4444056614302099	2010/12	user1311	password	52	20000	F
1312	EYNPCL	KANJMTDQIJ	5262057998 Dell Way	\N	YMBILRC	KY	29697	US	1	KANJMTDQIJ@dell.com	5262057998	5	2716780757997185	2012/12	user1312	password	59	20000	M
1313	CSYNCZ	AMLUQCCZAO	2031661179 Dell Way	\N	BJASLJY	WA	34977	US	1	AMLUQCCZAO@dell.com	2031661179	5	2767000909894705	2011/01	user1313	password	22	80000	M
1314	AHUZIH	LCXNFWOUXX	6885517601 Dell Way	\N	VQJEOHL	NV	25323	US	1	LCXNFWOUXX@dell.com	6885517601	2	2555764121469110	2011/02	user1314	password	82	80000	F
1315	RSSZDV	WRATGVREQH	2505916188 Dell Way	\N	NUWVGNZ	VT	87528	US	1	WRATGVREQH@dell.com	2505916188	4	9751511594746264	2008/05	user1315	password	45	80000	F
1316	CSFYPX	ZJDUAHKIVF	5841508566 Dell Way	\N	EQLSQJO	SC	99708	US	1	ZJDUAHKIVF@dell.com	5841508566	5	4053650195710361	2012/07	user1316	password	46	20000	F
1317	PYWMYG	PSGWCPSIUI	5366916873 Dell Way	\N	UMYDBTD	NH	63093	US	1	PSGWCPSIUI@dell.com	5366916873	3	2542737889569253	2012/07	user1317	password	51	60000	F
1318	JYKPOC	VLFLDNFLIS	9210674740 Dell Way	\N	KLUDPJT	CA	88231	US	1	VLFLDNFLIS@dell.com	9210674740	5	4533454385120422	2009/06	user1318	password	81	80000	F
1319	GHYJDJ	PPMDVYLNJX	9273167159 Dell Way	\N	HNMRGPN	DC	59796	US	1	PPMDVYLNJX@dell.com	9273167159	3	9879177015740424	2011/04	user1319	password	44	20000	M
1320	HLSRAH	EDCCPQLMXY	1920684836 Dell Way	\N	ZOFOCJD	AK	89154	US	1	EDCCPQLMXY@dell.com	1920684836	5	2187866851221770	2010/11	user1320	password	68	80000	F
1321	KLIRPL	TSBKDNHCMW	6913913180 Dell Way	\N	HBZQEZN	ID	82369	US	1	TSBKDNHCMW@dell.com	6913913180	4	6988276788033546	2009/07	user1321	password	87	80000	M
1322	GKNSEF	TOJHWMTTTV	2643519605 Dell Way	\N	SKZSYGN	NH	99047	US	1	TOJHWMTTTV@dell.com	2643519605	5	5463810286484659	2008/09	user1322	password	49	60000	F
1323	ZDGEXU	OEQAYKUTCF	5188697444 Dell Way	\N	SVDZITZ	MT	71186	US	1	OEQAYKUTCF@dell.com	5188697444	4	4135109424125403	2012/01	user1323	password	48	100000	F
1324	RBCLPG	CQEMLYPQQK	6082540585 Dell Way	\N	UQTNPHF	AZ	94566	US	1	CQEMLYPQQK@dell.com	6082540585	5	1017103663180023	2012/11	user1324	password	31	80000	M
1325	HCNNED	RRPPHGGSAX	7258226226 Dell Way	\N	MONTUOS	KY	58206	US	1	RRPPHGGSAX@dell.com	7258226226	2	4322087752632797	2012/12	user1325	password	36	20000	F
1326	TRGXJY	MZFSGYTDKI	2092510569 Dell Way	\N	QECFWLT	NC	78615	US	1	MZFSGYTDKI@dell.com	2092510569	3	7557767555117608	2009/08	user1326	password	75	20000	F
1327	ABQYNP	EGWCZANHRR	3829341439 Dell Way	\N	KWNVQBP	PA	55825	US	1	EGWCZANHRR@dell.com	3829341439	1	1906837567687034	2008/04	user1327	password	44	20000	F
1328	ZCVPGB	MJBMXJDOTA	8065087948 Dell Way	\N	COQEEJR	MN	54721	US	1	MJBMXJDOTA@dell.com	8065087948	3	7823366852942855	2008/09	user1328	password	22	20000	M
1329	XTBYFL	ASIJVXDVZR	1717341093 Dell Way	\N	LEVVWII	NM	89419	US	1	ASIJVXDVZR@dell.com	1717341093	4	6180118976626546	2008/12	user1329	password	43	20000	M
1330	KZXVZP	DJLAMGAESF	8093113671 Dell Way	\N	ANBIWRF	WA	52981	US	1	DJLAMGAESF@dell.com	8093113671	1	4712396144866944	2008/02	user1330	password	25	60000	F
1331	AJBQNL	BOXHPCAUCN	4707463629 Dell Way	\N	VKKNQIZ	ME	45105	US	1	BOXHPCAUCN@dell.com	4707463629	3	5352859428152442	2010/02	user1331	password	58	60000	F
1332	QDZBEN	YMDAMXDASO	6412977776 Dell Way	\N	KGESGPD	NV	25049	US	1	YMDAMXDASO@dell.com	6412977776	1	3481248850468546	2008/09	user1332	password	72	80000	M
1333	TVAHTN	KUZHXAALKH	7079394667 Dell Way	\N	QDNGGEK	UT	42794	US	1	KUZHXAALKH@dell.com	7079394667	1	1595258304849267	2010/10	user1333	password	84	20000	M
1334	YLJLVE	LDCLDNWKEA	5958797681 Dell Way	\N	YKHDUEM	MO	26761	US	1	LDCLDNWKEA@dell.com	5958797681	5	9867344647645952	2010/01	user1334	password	61	40000	M
1335	ZVIDHL	GSPUPZYPYI	3141837222 Dell Way	\N	XBDBNQG	CA	56668	US	1	GSPUPZYPYI@dell.com	3141837222	3	6260382941458375	2012/12	user1335	password	24	100000	M
1336	KZBWFT	LZJLXZKGWL	2004746331 Dell Way	\N	KYZAFBN	MI	64563	US	1	LZJLXZKGWL@dell.com	2004746331	2	5907702949363739	2008/02	user1336	password	41	80000	F
1337	JMGDYG	MKDLUKIFUH	4724720807 Dell Way	\N	FUMGIXW	MI	26391	US	1	MKDLUKIFUH@dell.com	4724720807	4	3451342798303813	2011/04	user1337	password	42	20000	M
1338	PFSVSC	ZEXJMDEUIZ	6514275704 Dell Way	\N	GPHELTI	UT	43392	US	1	ZEXJMDEUIZ@dell.com	6514275704	4	6665283321868629	2012/09	user1338	password	45	60000	M
1339	BJQEIU	BSHEWBNVIC	8832373726 Dell Way	\N	DMOWVLG	ME	12309	US	1	BSHEWBNVIC@dell.com	8832373726	2	7510391253046692	2009/11	user1339	password	65	40000	F
1340	HNPBOI	JTFKHBTJEF	2003300218 Dell Way	\N	YBAJHLK	DE	82748	US	1	JTFKHBTJEF@dell.com	2003300218	3	7414701682049782	2011/09	user1340	password	89	20000	F
1341	PCUXLO	CWWDPGIVEJ	8124809800 Dell Way	\N	VNRHXVC	AL	30813	US	1	CWWDPGIVEJ@dell.com	8124809800	4	9672298829536886	2011/10	user1341	password	32	40000	M
1342	AGJOJG	LNWRVRVFNJ	9091670918 Dell Way	\N	WUHSWIY	NM	20103	US	1	LNWRVRVFNJ@dell.com	9091670918	3	9397546728141608	2008/10	user1342	password	80	20000	F
1343	FRKMCY	ITUAPZNZWH	6558991686 Dell Way	\N	GPDONUR	ME	26947	US	1	ITUAPZNZWH@dell.com	6558991686	3	9682685574982316	2010/08	user1343	password	18	80000	F
1344	LEKJME	DNTDASAHZP	4058258419 Dell Way	\N	KNDEFNJ	TN	14416	US	1	DNTDASAHZP@dell.com	4058258419	2	6976357910316438	2009/01	user1344	password	87	80000	F
1345	JDRNHE	GKEZLMYAWM	4570847643 Dell Way	\N	DBSRLOT	RI	86316	US	1	GKEZLMYAWM@dell.com	4570847643	1	8660051390528680	2009/11	user1345	password	19	80000	F
1346	RFIWMS	BLENJFKWIL	8184273850 Dell Way	\N	OAXCTRY	DC	82004	US	1	BLENJFKWIL@dell.com	8184273850	3	7331086921505631	2012/03	user1346	password	72	60000	F
1347	BJXUKI	YYSDIOMTDN	8448897897 Dell Way	\N	QGHIELD	WV	93806	US	1	YYSDIOMTDN@dell.com	8448897897	4	2254407511558383	2010/04	user1347	password	58	80000	M
1348	LKCUJA	MNIBZCENTK	3478551696 Dell Way	\N	UCPFFOD	AL	43682	US	1	MNIBZCENTK@dell.com	3478551696	4	7156365328468383	2012/03	user1348	password	44	40000	M
1349	MBANNN	VPNYTBSEVU	4764685281 Dell Way	\N	UAZJEAT	MI	65869	US	1	VPNYTBSEVU@dell.com	4764685281	2	8665524790063501	2011/07	user1349	password	54	40000	M
1350	NTCBPR	POLQGQLBKM	5673762632 Dell Way	\N	AUQBNBR	WA	41157	US	1	POLQGQLBKM@dell.com	5673762632	4	8998528683558107	2008/12	user1350	password	52	60000	M
1351	PPJGEX	SUEJGFUSGO	6959301755 Dell Way	\N	JHBLYZU	MO	74239	US	1	SUEJGFUSGO@dell.com	6959301755	3	7249762130435557	2008/01	user1351	password	50	80000	M
1352	UZUSSP	WBVCVOIJXP	8554527194 Dell Way	\N	LIOLCAD	PA	57004	US	1	WBVCVOIJXP@dell.com	8554527194	5	5974528271704913	2009/08	user1352	password	30	20000	M
1353	ZUHOQI	JTEXBNURZD	3917846621 Dell Way	\N	FKFGOYU	MA	86211	US	1	JTEXBNURZD@dell.com	3917846621	4	5057603079359979	2010/09	user1353	password	20	60000	M
1354	IAERJX	VHYJCPIFVT	6961754556 Dell Way	\N	KCHJWRF	FL	40542	US	1	VHYJCPIFVT@dell.com	6961754556	4	1716048507485538	2011/02	user1354	password	61	20000	F
1355	TRNRNU	QWWGFCBYMD	3853088791 Dell Way	\N	FWAXBEG	OR	87492	US	1	QWWGFCBYMD@dell.com	3853088791	3	9951641016174108	2012/06	user1355	password	27	80000	F
1356	QIQLZN	IFSKHRXLXT	5247764251 Dell Way	\N	LUVQANM	KY	96408	US	1	IFSKHRXLXT@dell.com	5247764251	2	4688031364697963	2011/12	user1356	password	57	40000	F
1357	FSGSAL	LLSCIDZBOU	8040438342 Dell Way	\N	WEVKREJ	DC	47928	US	1	LLSCIDZBOU@dell.com	8040438342	4	4234214180614799	2009/12	user1357	password	64	60000	M
1358	XGSIRD	BUMFUNUOKZ	4027067484 Dell Way	\N	KVQOFUZ	WV	56181	US	1	BUMFUNUOKZ@dell.com	4027067484	2	5573698269203306	2012/10	user1358	password	32	100000	F
1359	XFTBGN	NMIBGXMFHH	6629715474 Dell Way	\N	VVMPVMD	DE	80155	US	1	NMIBGXMFHH@dell.com	6629715474	1	6500882022548468	2012/01	user1359	password	67	80000	F
1360	LUMZIY	HJEEVKMDFI	5342697510 Dell Way	\N	QVDCYHW	NE	48824	US	1	HJEEVKMDFI@dell.com	5342697510	2	4921725836582482	2008/02	user1360	password	65	60000	M
1361	DOGBVP	GALQMOWVER	2015451228 Dell Way	\N	YHQGDFR	NM	63169	US	1	GALQMOWVER@dell.com	2015451228	4	7494867281056941	2011/05	user1361	password	65	100000	M
1362	WYUMFV	XVIMSDRJCZ	5627466803 Dell Way	\N	AIDFATU	CT	59819	US	1	XVIMSDRJCZ@dell.com	5627466803	5	9524508580565454	2008/10	user1362	password	83	20000	M
1363	SNXNLT	VYLZQVBPVK	9605816897 Dell Way	\N	SAKLVNA	KS	47093	US	1	VYLZQVBPVK@dell.com	9605816897	3	2594092117156833	2012/07	user1363	password	83	60000	F
1364	UBMOXL	ZXBUZQQJIQ	9066067968 Dell Way	\N	UUMHUUS	PA	35044	US	1	ZXBUZQQJIQ@dell.com	9066067968	4	8236833056434990	2011/02	user1364	password	80	60000	F
1365	IDEUDB	VYALOKUFEO	5868942644 Dell Way	\N	RMJLFDT	CO	75536	US	1	VYALOKUFEO@dell.com	5868942644	5	9021825697273016	2009/06	user1365	password	27	80000	M
1366	HNTJIR	KUGUOLZDCL	3051080787 Dell Way	\N	MOQPITI	TX	67011	US	1	KUGUOLZDCL@dell.com	3051080787	2	1994980261661112	2009/12	user1366	password	71	80000	F
1367	MAVEKP	KEDVDGYPTN	7510486178 Dell Way	\N	GJVZSRP	WA	93623	US	1	KEDVDGYPTN@dell.com	7510486178	2	9161990530788900	2010/12	user1367	password	46	100000	M
1368	FCIUMN	XIQEHFYULH	2473709689 Dell Way	\N	QLZIBXG	RI	26337	US	1	XIQEHFYULH@dell.com	2473709689	2	2012745554558932	2010/02	user1368	password	21	80000	F
1369	JNSWLA	NQITOCEVTQ	1126800048 Dell Way	\N	VCRSILX	MS	69997	US	1	NQITOCEVTQ@dell.com	1126800048	1	8345548012759537	2008/10	user1369	password	21	60000	F
1370	TIUUVL	COZFTVZJQB	9794806174 Dell Way	\N	BJKMHXE	IL	96985	US	1	COZFTVZJQB@dell.com	9794806174	2	8018117238301785	2008/10	user1370	password	27	80000	F
1371	YPXJRM	JXFEXPVYQF	1080715317 Dell Way	\N	JDMGHTF	IL	18342	US	1	JXFEXPVYQF@dell.com	1080715317	2	8860083808191121	2008/02	user1371	password	88	20000	M
1372	WLJJUH	OYEEUDVZMY	2346587357 Dell Way	\N	LTGEZOH	WY	87019	US	1	OYEEUDVZMY@dell.com	2346587357	1	9568572731688620	2008/03	user1372	password	64	100000	M
1373	AIKHXI	LBDPXCBWNV	5274004469 Dell Way	\N	DSURZUN	DC	90101	US	1	LBDPXCBWNV@dell.com	5274004469	2	1692479752469808	2008/03	user1373	password	68	20000	M
1374	CKMLWO	OLLQNHEILX	8661164117 Dell Way	\N	CCXWQBU	CA	36975	US	1	OLLQNHEILX@dell.com	8661164117	1	5908196806907654	2010/04	user1374	password	27	80000	M
1375	PBOEPA	QGNYLWJJZL	2216535713 Dell Way	\N	GWBHQEP	MO	43022	US	1	QGNYLWJJZL@dell.com	2216535713	1	7086734587326647	2009/08	user1375	password	45	100000	M
1376	YBHYRO	MQAIZJHLPD	7602457851 Dell Way	\N	NXTRMGB	NJ	32236	US	1	MQAIZJHLPD@dell.com	7602457851	5	8999917539767922	2008/10	user1376	password	60	20000	M
1377	XAMLMD	LVCVCOKGBH	4334447849 Dell Way	\N	ATUGVKM	ND	35833	US	1	LVCVCOKGBH@dell.com	4334447849	4	1393442972563207	2012/09	user1377	password	80	100000	M
1378	JHGMTB	OOECZKEHKY	8297787731 Dell Way	\N	BRTMDIT	MS	99017	US	1	OOECZKEHKY@dell.com	8297787731	3	7488252760842443	2011/04	user1378	password	52	20000	M
1379	SMJUBX	YEXJIEUHGL	1778815655 Dell Way	\N	BSPJMCJ	IN	60104	US	1	YEXJIEUHGL@dell.com	1778815655	5	8774201998487116	2010/12	user1379	password	51	40000	F
1380	VBMSAQ	QJZUEHAPIT	7360986808 Dell Way	\N	FSGHCOV	DE	57430	US	1	QJZUEHAPIT@dell.com	7360986808	4	5564543236047030	2008/12	user1380	password	88	100000	F
1381	LSBCIK	CDOJEESXJL	7912929164 Dell Way	\N	ERNTNRG	GA	46023	US	1	CDOJEESXJL@dell.com	7912929164	2	4550532852299512	2011/05	user1381	password	49	20000	F
1382	MHKXKO	MUSRMQAYUS	9170269961 Dell Way	\N	LNFCUKN	ND	82076	US	1	MUSRMQAYUS@dell.com	9170269961	2	2545510166324675	2009/06	user1382	password	36	100000	M
1383	RSEFFY	XWLNXJIPUW	2618242622 Dell Way	\N	UXQFKFA	KS	54583	US	1	XWLNXJIPUW@dell.com	2618242622	4	9741127112414688	2010/07	user1383	password	72	20000	F
1384	XILWGH	HUEQCTLZOJ	3626446710 Dell Way	\N	QTTVTCI	WI	79476	US	1	HUEQCTLZOJ@dell.com	3626446710	2	3482689079362899	2008/06	user1384	password	54	100000	M
1385	YUBFCW	KSYEEYSNOM	4780867920 Dell Way	\N	HJGJSED	WY	61451	US	1	KSYEEYSNOM@dell.com	4780867920	1	1626261426601559	2012/12	user1385	password	83	100000	M
1386	ZCVVMO	UQSSIFGVNQ	8917470818 Dell Way	\N	BWIGAHV	MI	39055	US	1	UQSSIFGVNQ@dell.com	8917470818	2	3566584264859557	2011/03	user1386	password	20	80000	F
1387	WOULIK	DBTJHOWYQT	2404544400 Dell Way	\N	GWTORFW	ND	60649	US	1	DBTJHOWYQT@dell.com	2404544400	2	8077919493895025	2008/01	user1387	password	24	20000	M
1388	WNZHQA	BAIPXGGQMC	9632823699 Dell Way	\N	KATPXIE	AR	68049	US	1	BAIPXGGQMC@dell.com	9632823699	2	7435868883505464	2008/04	user1388	password	43	100000	M
1389	IFMIGN	QWKWCBJFMK	6746730907 Dell Way	\N	YCHHGJY	GA	65548	US	1	QWKWCBJFMK@dell.com	6746730907	2	9508628423791380	2012/03	user1389	password	74	40000	F
1390	GQQUHM	EEPGNUSYTU	2392044903 Dell Way	\N	FABPYGF	NH	56332	US	1	EEPGNUSYTU@dell.com	2392044903	3	7275963075459004	2012/11	user1390	password	24	20000	M
1391	SZUFEY	VKMPCKJXQK	4719202895 Dell Way	\N	YFIFLYS	NE	55678	US	1	VKMPCKJXQK@dell.com	4719202895	3	4446629548445344	2010/09	user1391	password	82	40000	M
1392	RLVPHG	CWJMGGCQFI	8196349042 Dell Way	\N	ZKTXCJK	MT	88234	US	1	CWJMGGCQFI@dell.com	8196349042	1	6235587800852955	2011/04	user1392	password	37	40000	M
1393	CZZIBW	ROCYRTDZSN	6042540488 Dell Way	\N	TQQCBEZ	TN	27426	US	1	ROCYRTDZSN@dell.com	6042540488	3	5014020682312548	2012/11	user1393	password	28	100000	M
1394	DGXZYM	CWDVZCNNWD	9605190115 Dell Way	\N	DZEIYAN	MT	59927	US	1	CWDVZCNNWD@dell.com	9605190115	2	4982770495582372	2008/04	user1394	password	40	40000	M
1395	FFLSHI	VCHYQVUUZU	9974834521 Dell Way	\N	ZHTZUGO	OR	65004	US	1	VCHYQVUUZU@dell.com	9974834521	5	8886435141321273	2009/01	user1395	password	46	60000	F
1396	WFOEBR	LZHHUCGOBN	1570461806 Dell Way	\N	IBHOPBE	NH	90201	US	1	LZHHUCGOBN@dell.com	1570461806	5	9697223504073920	2010/06	user1396	password	36	40000	M
1397	VMSMXR	UELWLAXYIZ	2177323259 Dell Way	\N	GXPHCEE	DC	19038	US	1	UELWLAXYIZ@dell.com	2177323259	4	5857259771786631	2009/11	user1397	password	32	20000	F
1398	XRHPLM	AIXBGVJFBG	6671544209 Dell Way	\N	UJJZNMC	NM	19528	US	1	AIXBGVJFBG@dell.com	6671544209	1	1157874885480850	2012/03	user1398	password	46	80000	M
1399	RIIEJR	CKXYTDAAXJ	1047269868 Dell Way	\N	JXWWZNZ	NJ	59315	US	1	CKXYTDAAXJ@dell.com	1047269868	3	7859217032324523	2009/03	user1399	password	65	20000	M
1400	ZGWQJH	OHARIBPRLM	4530137804 Dell Way	\N	OIMCICQ	KS	61340	US	1	OHARIBPRLM@dell.com	4530137804	4	7911168072372676	2008/10	user1400	password	38	20000	F
1401	ERLLGT	LXBNMSZZHI	9333714026 Dell Way	\N	MJQPZYE	MA	71475	US	1	LXBNMSZZHI@dell.com	9333714026	3	5456016231328249	2009/06	user1401	password	59	40000	F
1402	AUKTGH	UUUNTUVCGE	8643976723 Dell Way	\N	SWERAOJ	WA	10764	US	1	UUUNTUVCGE@dell.com	8643976723	1	5262129420880229	2010/07	user1402	password	63	60000	F
1403	AEOIZJ	DNDXJFENXB	8013578391 Dell Way	\N	SPBHYZH	RI	23329	US	1	DNDXJFENXB@dell.com	8013578391	2	7007883040234447	2010/08	user1403	password	89	60000	M
1404	OTVXWJ	AUSFZGDAZS	8989218832 Dell Way	\N	BGQBOKF	KY	66216	US	1	AUSFZGDAZS@dell.com	8989218832	4	3436741057783365	2012/03	user1404	password	25	60000	M
1405	YIUHIP	AOOGROGJQM	3926344354 Dell Way	\N	ASBLYKB	TN	25412	US	1	AOOGROGJQM@dell.com	3926344354	4	4123403283301741	2010/02	user1405	password	37	40000	F
1406	BRUQSI	FZZTFJKSKD	7307429976 Dell Way	\N	TVCEWXJ	FL	65036	US	1	FZZTFJKSKD@dell.com	7307429976	4	7538905163295568	2012/01	user1406	password	29	20000	M
1407	YRKGWJ	GQOQBGAEAV	5688558371 Dell Way	\N	HFSEOXU	ID	56775	US	1	GQOQBGAEAV@dell.com	5688558371	2	5743057983927429	2011/04	user1407	password	33	80000	M
1408	PWUZCK	OTLUTQVOXA	2797858391 Dell Way	\N	GCPDXWR	MD	18645	US	1	OTLUTQVOXA@dell.com	2797858391	1	4187052765395492	2010/09	user1408	password	38	20000	M
1409	BARMOK	XJDOESMFZO	2212988567 Dell Way	\N	VDLRUWU	AK	94267	US	1	XJDOESMFZO@dell.com	2212988567	3	6706759728025646	2010/06	user1409	password	32	60000	F
1410	WYAHWJ	KKODWUCLPG	3575631368 Dell Way	\N	WHBSBBQ	FL	53267	US	1	KKODWUCLPG@dell.com	3575631368	4	9435231412760914	2010/01	user1410	password	47	40000	F
1411	KQWUAG	IEDDHOSNKZ	1546096141 Dell Way	\N	PDBQUGD	AZ	86047	US	1	IEDDHOSNKZ@dell.com	1546096141	3	9256456922274084	2010/11	user1411	password	85	100000	M
1412	UROAAS	EDASWODVDG	9044966589 Dell Way	\N	XTBDXDZ	WI	71233	US	1	EDASWODVDG@dell.com	9044966589	3	6213479776866735	2012/04	user1412	password	24	60000	M
1413	QQAJUD	JMAXQWBXTV	4033509152 Dell Way	\N	YWSCVQT	OR	16338	US	1	JMAXQWBXTV@dell.com	4033509152	3	4365672010462731	2010/02	user1413	password	44	20000	M
1414	JLONVB	NSRJTPCONZ	4371374973 Dell Way	\N	HPVYJOA	OH	20214	US	1	NSRJTPCONZ@dell.com	4371374973	1	3345038741361350	2011/03	user1414	password	20	20000	M
1415	PPMQDF	IMZXPOLOVB	3787016445 Dell Way	\N	JTKYTDB	CT	33423	US	1	IMZXPOLOVB@dell.com	3787016445	5	5248140984214843	2009/12	user1415	password	27	100000	M
1416	PORUXE	TVTHGIDISW	6302666876 Dell Way	\N	TQQWRTD	WY	64418	US	1	TVTHGIDISW@dell.com	6302666876	2	5995947097893805	2011/04	user1416	password	26	40000	M
1417	UCTYWO	SEVAHDSEWJ	7175155958 Dell Way	\N	USANVAD	ME	42235	US	1	SEVAHDSEWJ@dell.com	7175155958	1	6585335145238788	2011/06	user1417	password	51	60000	M
1418	FOKTGO	PHWSAAOKUH	4888469575 Dell Way	\N	LIDLLOV	CT	73271	US	1	PHWSAAOKUH@dell.com	4888469575	5	2389973416924476	2012/07	user1418	password	69	20000	F
1419	DWISLQ	ODROSBJAMR	6149791193 Dell Way	\N	DYDSTHK	FL	28416	US	1	ODROSBJAMR@dell.com	6149791193	1	7575752051547170	2009/03	user1419	password	76	60000	F
1420	ECMURP	MFIOPJAHNZ	6512109745 Dell Way	\N	KFTRQYW	GA	10415	US	1	MFIOPJAHNZ@dell.com	6512109745	3	2591175696812570	2010/11	user1420	password	32	60000	M
1421	RJQHWW	PKMYLTMKDR	3319765941 Dell Way	\N	DVIBSNC	KS	12104	US	1	PKMYLTMKDR@dell.com	3319765941	4	9235126332379878	2010/04	user1421	password	84	20000	M
1422	OKOLAY	XZJQLUTDYP	9217006945 Dell Way	\N	LAHZCPZ	KY	40808	US	1	XZJQLUTDYP@dell.com	9217006945	5	6876458121929318	2012/12	user1422	password	42	40000	F
1423	WUJVRI	EHTZBWXRIY	5931255284 Dell Way	\N	YHAOHJX	GA	27188	US	1	EHTZBWXRIY@dell.com	5931255284	1	2186227153986692	2012/05	user1423	password	52	80000	F
1424	VPWDUE	XTFURWCPVJ	3925275577 Dell Way	\N	QJRAHWF	TN	88866	US	1	XTFURWCPVJ@dell.com	3925275577	4	3367788441944867	2011/06	user1424	password	50	80000	F
1425	HUVLRP	RLHONWKXMU	6071771327 Dell Way	\N	OMBLRWH	AK	63492	US	1	RLHONWKXMU@dell.com	6071771327	5	1664217571727931	2008/06	user1425	password	28	40000	F
1426	ZTXPLI	WAWSKUFFIS	8296069843 Dell Way	\N	GTKDBLT	NJ	31997	US	1	WAWSKUFFIS@dell.com	8296069843	4	7180355999153108	2012/12	user1426	password	83	100000	M
1427	UNEDJE	ZCPTIUCABW	8213414982 Dell Way	\N	LFXWYNC	PA	24908	US	1	ZCPTIUCABW@dell.com	8213414982	4	1915690399706363	2011/08	user1427	password	76	60000	F
1428	YQNDPP	TJYOLYPHKV	1205819493 Dell Way	\N	FGTTJNX	FL	29159	US	1	TJYOLYPHKV@dell.com	1205819493	5	8649892595130951	2012/05	user1428	password	18	80000	M
1429	NYPDRY	BFKAVSKQYR	9591792116 Dell Way	\N	JSBXQGC	NM	22874	US	1	BFKAVSKQYR@dell.com	9591792116	3	5716710804030300	2012/04	user1429	password	55	60000	F
1430	DQVCRB	MSWFCMEUWW	8074918156 Dell Way	\N	WUMDWCG	TN	61849	US	1	MSWFCMEUWW@dell.com	8074918156	4	8472047301474959	2009/04	user1430	password	18	60000	M
1431	WNOXAG	UFJHJEDFAY	2893214895 Dell Way	\N	SDUUKQJ	FL	47385	US	1	UFJHJEDFAY@dell.com	2893214895	3	7144456643145532	2009/12	user1431	password	59	20000	F
1432	DZLJTQ	TBAXEGYDYB	6766976481 Dell Way	\N	XTMODRY	KY	25306	US	1	TBAXEGYDYB@dell.com	6766976481	3	1854376861825585	2009/08	user1432	password	56	40000	M
1433	YSKPLL	QJQXHTVJQP	8110534665 Dell Way	\N	WESNDBS	SC	64667	US	1	QJQXHTVJQP@dell.com	8110534665	5	3195433311630040	2009/04	user1433	password	81	40000	F
1434	GXNRNW	HKEAGORVKW	4805186998 Dell Way	\N	NYAOQVE	MD	82437	US	1	HKEAGORVKW@dell.com	4805186998	4	2214874013792723	2009/01	user1434	password	31	60000	M
1435	RFKONV	TOBHGWRCKP	8838329257 Dell Way	\N	DZFYDQT	NE	42276	US	1	TOBHGWRCKP@dell.com	8838329257	5	4254740686155856	2008/05	user1435	password	36	80000	M
1436	RHDMAS	OIYKZBVPEU	2532189180 Dell Way	\N	VCYLVNV	OH	42756	US	1	OIYKZBVPEU@dell.com	2532189180	4	7909408518113197	2010/06	user1436	password	46	20000	M
1437	OOVGDD	ENDFJSJDNM	7291653071 Dell Way	\N	BZHOUAY	WV	77582	US	1	ENDFJSJDNM@dell.com	7291653071	2	3152532333973795	2008/06	user1437	password	19	80000	F
1438	VWEZBS	CHBVREJDGI	4843012025 Dell Way	\N	LUDLTCE	MI	53708	US	1	CHBVREJDGI@dell.com	4843012025	3	9638245072215796	2010/02	user1438	password	18	40000	F
1439	EHCWJK	XFBCOEIXQD	6128952164 Dell Way	\N	ABWDGHP	NY	84239	US	1	XFBCOEIXQD@dell.com	6128952164	1	9923380327410996	2010/06	user1439	password	20	80000	M
1440	DPCONH	PPVUXSKATM	1090902540 Dell Way	\N	XWTFMKA	AR	59493	US	1	PPVUXSKATM@dell.com	1090902540	4	9833408618345858	2008/05	user1440	password	68	40000	M
1441	UTNBJC	XDAPOBJBYG	7637500681 Dell Way	\N	UDSFEUT	DE	46826	US	1	XDAPOBJBYG@dell.com	7637500681	2	8072031785268337	2010/06	user1441	password	74	40000	F
1442	HGNJDR	KTGLDHKJBO	1608456072 Dell Way	\N	CHSWBWH	RI	19356	US	1	KTGLDHKJBO@dell.com	1608456072	2	5785048360005022	2012/05	user1442	password	69	20000	M
1443	GMVXWP	DISLSCNGEU	5326819834 Dell Way	\N	ZBVVIPY	MD	83131	US	1	DISLSCNGEU@dell.com	5326819834	2	2968970988877117	2008/05	user1443	password	82	60000	M
1444	SISHMB	ZXUCKAGFZI	7197167796 Dell Way	\N	BVQRUBM	ID	35863	US	1	ZXUCKAGFZI@dell.com	7197167796	3	6788757305126638	2010/11	user1444	password	53	40000	F
1445	FOSGOP	BQABXGBFHX	8568700577 Dell Way	\N	WYSXLZF	CO	49862	US	1	BQABXGBFHX@dell.com	8568700577	4	3974840109702200	2009/12	user1445	password	58	60000	M
1446	GVCWWS	XYQDZWLXSK	4359620121 Dell Way	\N	QQVPVYB	NV	66258	US	1	XYQDZWLXSK@dell.com	4359620121	5	6292694168165327	2012/07	user1446	password	26	20000	F
1447	FAFXYD	OCDKNBCXRT	9069681083 Dell Way	\N	TGORIFI	NY	28467	US	1	OCDKNBCXRT@dell.com	9069681083	4	7691617412492634	2008/10	user1447	password	25	40000	M
1448	HDTLRV	OBJQEHHXAO	6725090074 Dell Way	\N	MSWRAOX	VT	23574	US	1	OBJQEHHXAO@dell.com	6725090074	5	9392704066820444	2011/02	user1448	password	72	20000	F
1449	NMXIBZ	RREZZCZNPR	1100785868 Dell Way	\N	JGSYEPC	SC	57461	US	1	RREZZCZNPR@dell.com	1100785868	3	6836552610155196	2011/07	user1449	password	83	40000	F
1450	VPCVHU	ZGTCGHRXQY	4680127372 Dell Way	\N	QPCGRXT	NY	48513	US	1	ZGTCGHRXQY@dell.com	4680127372	3	9951468814164400	2009/09	user1450	password	21	20000	F
1451	DYPYYV	RACYSAPRQE	1816753029 Dell Way	\N	TWVRQNC	AL	95312	US	1	RACYSAPRQE@dell.com	1816753029	2	6834252921864391	2008/06	user1451	password	87	40000	F
1452	OFIJWI	LVBLLSCPMY	6099020350 Dell Way	\N	LEOZGPX	KY	91909	US	1	LVBLLSCPMY@dell.com	6099020350	3	4223364146426320	2010/10	user1452	password	71	20000	M
1453	BLWKXR	LJCELSRJEV	8001072483 Dell Way	\N	YDCNBLK	NM	91749	US	1	LJCELSRJEV@dell.com	8001072483	1	6986465048044921	2010/03	user1453	password	63	60000	M
1454	MZNDKX	GPIZGSECQI	2639474926 Dell Way	\N	EDJPOAN	KY	24673	US	1	GPIZGSECQI@dell.com	2639474926	5	4317845847457647	2012/06	user1454	password	18	40000	F
1455	OLULSK	TRRLVTCDYF	1665530902 Dell Way	\N	NOUOBCS	IA	96541	US	1	TRRLVTCDYF@dell.com	1665530902	1	4409882467705757	2008/05	user1455	password	73	80000	M
1456	OBMYVD	PHZJJDHPRW	8463129170 Dell Way	\N	JFXMXEL	WY	29020	US	1	PHZJJDHPRW@dell.com	8463129170	1	5952601690776647	2010/09	user1456	password	41	20000	M
1457	UCPYSX	YCHCKWTGGY	1655800619 Dell Way	\N	ETWIFWN	AL	95326	US	1	YCHCKWTGGY@dell.com	1655800619	4	6913891001604498	2009/10	user1457	password	49	20000	M
1458	BDOYCQ	FEACXHJWLC	3004150322 Dell Way	\N	TTHQGIO	KY	95205	US	1	FEACXHJWLC@dell.com	3004150322	4	7345245309639723	2011/12	user1458	password	58	80000	F
1459	DQDUWI	VZFCJCNMVG	7830991249 Dell Way	\N	ULNCAWB	HI	64546	US	1	VZFCJCNMVG@dell.com	7830991249	5	5844013913068921	2009/08	user1459	password	62	60000	F
1460	TFDBAD	HDMJQYFXSQ	5068103533 Dell Way	\N	LVRIWXX	NM	81108	US	1	HDMJQYFXSQ@dell.com	5068103533	5	4494196978863329	2008/05	user1460	password	64	100000	M
1461	UXRXFU	JOKIUIALTW	2476481220 Dell Way	\N	CBTZZJU	MI	40748	US	1	JOKIUIALTW@dell.com	2476481220	3	7710942967329175	2012/05	user1461	password	45	60000	F
1462	AMLUWA	FEUOFFIBHK	3565959490 Dell Way	\N	VHKFBVO	HI	40436	US	1	FEUOFFIBHK@dell.com	3565959490	1	7071861465927214	2011/08	user1462	password	84	80000	F
1463	JMYJSC	EGHJPJRZEZ	3050715440 Dell Way	\N	JKBFYHO	GA	38173	US	1	EGHJPJRZEZ@dell.com	3050715440	5	9330315738450736	2008/07	user1463	password	18	60000	F
1464	YWTBBA	JKPTCPXCZI	6804182731 Dell Way	\N	DFGKTLS	WY	39232	US	1	JKPTCPXCZI@dell.com	6804182731	1	8879916007164867	2011/08	user1464	password	84	80000	M
1465	RQORAZ	HTBXRDWZHC	8804585940 Dell Way	\N	FRVRKVZ	AR	95494	US	1	HTBXRDWZHC@dell.com	8804585940	4	6235794460866601	2011/04	user1465	password	24	60000	M
1466	QDZPKS	RHJVEICHNU	5181008569 Dell Way	\N	CFFYFGW	AZ	96637	US	1	RHJVEICHNU@dell.com	5181008569	5	3459120077081025	2010/04	user1466	password	34	20000	F
1467	FUVXLD	GHIOKPCESH	8883778216 Dell Way	\N	KQMQNOP	WV	45254	US	1	GHIOKPCESH@dell.com	8883778216	3	7054756386205555	2008/09	user1467	password	23	40000	M
1468	XFZALG	IAQXCVPKFG	5615879543 Dell Way	\N	XWTLLSV	KY	32690	US	1	IAQXCVPKFG@dell.com	5615879543	3	9744934512302280	2010/09	user1468	password	53	60000	M
1469	LMJSVJ	JTMEIXKOUG	3387441532 Dell Way	\N	IFSBBBH	NE	55798	US	1	JTMEIXKOUG@dell.com	3387441532	1	3315168454777449	2011/08	user1469	password	32	20000	F
1470	OXZYGS	LLAIWPCDYI	7133442902 Dell Way	\N	WZKXGZL	MT	24676	US	1	LLAIWPCDYI@dell.com	7133442902	2	8331755503080786	2012/06	user1470	password	88	60000	F
1471	YKQQWC	REZGHCFQYE	1026889241 Dell Way	\N	AWLAHYE	WV	30721	US	1	REZGHCFQYE@dell.com	1026889241	5	7344361961819232	2012/04	user1471	password	24	100000	M
1472	TNOVET	ULAXQRVUSS	2083323547 Dell Way	\N	FSZEXYK	VT	80229	US	1	ULAXQRVUSS@dell.com	2083323547	5	1723319024778902	2009/10	user1472	password	76	100000	F
1473	JULCPX	DMNVIINAOF	8100950201 Dell Way	\N	ZTDYEBS	IL	93510	US	1	DMNVIINAOF@dell.com	8100950201	3	7247816615272314	2010/06	user1473	password	89	100000	F
1474	LBVIFI	WAQFNQTTQN	6098775703 Dell Way	\N	XORYHZW	AZ	52154	US	1	WAQFNQTTQN@dell.com	6098775703	4	9208854924887420	2010/08	user1474	password	28	100000	M
1475	ZHWHEW	XJKODEFQBU	7046061607 Dell Way	\N	IZBHWDT	MI	80094	US	1	XJKODEFQBU@dell.com	7046061607	5	4398189897183329	2012/12	user1475	password	20	80000	F
1476	XBKUZT	EOWJTNKNVK	8857506448 Dell Way	\N	PDHSXSM	ND	72800	US	1	EOWJTNKNVK@dell.com	8857506448	2	6835198119748384	2012/02	user1476	password	83	100000	F
1477	HPFBUT	YDMLOAHYQK	3640938585 Dell Way	\N	FIIYVWQ	OH	31642	US	1	YDMLOAHYQK@dell.com	3640938585	4	4583673091139645	2008/06	user1477	password	63	60000	F
1478	VOUOMX	BYMCGKSRQA	5311936344 Dell Way	\N	ZPWVGOC	MT	24992	US	1	BYMCGKSRQA@dell.com	5311936344	4	6250051256734878	2008/03	user1478	password	61	100000	M
1479	JMGHNF	TPLEIDVICK	5514499196 Dell Way	\N	FYQTAEX	MS	90427	US	1	TPLEIDVICK@dell.com	5514499196	3	1921054042410105	2008/07	user1479	password	81	60000	M
1480	DUNIND	USLXNUZYZX	7869124668 Dell Way	\N	PSYTQLR	DC	11739	US	1	USLXNUZYZX@dell.com	7869124668	2	5740167618729175	2011/09	user1480	password	55	80000	F
1481	ABADVS	PTGJSFIQUB	6031216792 Dell Way	\N	PORAFVA	WY	14611	US	1	PTGJSFIQUB@dell.com	6031216792	4	7767839640378953	2008/05	user1481	password	34	20000	F
1482	FGGYVA	FFTKNKEOZT	8865614799 Dell Way	\N	GZZBAYD	NE	59998	US	1	FFTKNKEOZT@dell.com	8865614799	4	9171490709763020	2008/09	user1482	password	42	40000	M
1483	PHVPMA	IWOSBCSVJR	2747977535 Dell Way	\N	ULSSOHH	ME	93742	US	1	IWOSBCSVJR@dell.com	2747977535	3	7043887350242586	2010/11	user1483	password	66	20000	F
1484	MSPMBM	AUODNJMEDY	8066302465 Dell Way	\N	XWMEEXC	LA	47528	US	1	AUODNJMEDY@dell.com	8066302465	5	3376119756139815	2010/01	user1484	password	46	100000	M
1485	ZLUMMP	APCJCHNAFK	1739015081 Dell Way	\N	NJPKMYV	IL	84042	US	1	APCJCHNAFK@dell.com	1739015081	4	8445149518549443	2010/08	user1485	password	58	60000	F
1486	JYNYYD	BIGJWHOHUX	4938665055 Dell Way	\N	WEKUZRP	AZ	46557	US	1	BIGJWHOHUX@dell.com	4938665055	3	1467343392316252	2012/01	user1486	password	26	40000	M
1487	RIWUJF	ASBHGIBEEG	7682259616 Dell Way	\N	PZGHOIR	AK	88014	US	1	ASBHGIBEEG@dell.com	7682259616	1	8824400705285371	2012/05	user1487	password	76	60000	M
1488	RIAWIT	XQAGSFLZUK	3496994833 Dell Way	\N	FCZOUZK	MT	98222	US	1	XQAGSFLZUK@dell.com	3496994833	2	4054651640355587	2008/11	user1488	password	18	80000	F
1489	BPOUNF	VUXAFXVPCX	8656257468 Dell Way	\N	ORRNBFN	KY	62582	US	1	VUXAFXVPCX@dell.com	8656257468	3	5384238432161510	2012/02	user1489	password	69	100000	M
1490	GSHLNC	JNHGIXJGLA	2801404314 Dell Way	\N	YZCDMLS	KY	86936	US	1	JNHGIXJGLA@dell.com	2801404314	1	1127823445014655	2012/02	user1490	password	75	20000	M
1491	CPHEZV	MGEJQKURIU	1741062109 Dell Way	\N	UMGFEPB	MA	81799	US	1	MGEJQKURIU@dell.com	1741062109	2	9040664301253856	2012/06	user1491	password	67	100000	F
1492	ZDAUPH	ZYYJTPSNJE	1665321971 Dell Way	\N	UPJJQTE	OR	12130	US	1	ZYYJTPSNJE@dell.com	1665321971	4	5143726015463472	2011/07	user1492	password	55	80000	M
1493	OOHVNF	TWZJPMSUGI	4254205514 Dell Way	\N	DQZWVSX	VA	37042	US	1	TWZJPMSUGI@dell.com	4254205514	4	8710654234979303	2012/05	user1493	password	57	60000	M
1494	VGLAZI	ZIXMBRTJVJ	2695935107 Dell Way	\N	IRFAPCI	WI	78460	US	1	ZIXMBRTJVJ@dell.com	2695935107	5	2388467536773532	2011/03	user1494	password	24	60000	F
1495	NOLVOU	TBWKUGGEOY	4471241510 Dell Way	\N	JPNMYMG	CO	36304	US	1	TBWKUGGEOY@dell.com	4471241510	5	5719526297878475	2010/05	user1495	password	90	100000	M
1496	LVNGOO	CZJIFNXDWN	9545590986 Dell Way	\N	RJLDPOL	WV	45570	US	1	CZJIFNXDWN@dell.com	9545590986	3	8031667754054070	2012/06	user1496	password	72	40000	F
1497	HQVVTV	ECBSAFPNWY	7068572256 Dell Way	\N	YZNMKMX	LA	91896	US	1	ECBSAFPNWY@dell.com	7068572256	2	4075555386021733	2010/09	user1497	password	62	80000	F
1498	LNCGSF	HKFNZSJYRJ	2429196507 Dell Way	\N	LETXBDV	OR	49533	US	1	HKFNZSJYRJ@dell.com	2429196507	1	2282312049064785	2011/11	user1498	password	53	20000	F
1499	PLCUTM	AGMTQLKZWO	5088047748 Dell Way	\N	TTQWPJI	OR	57603	US	1	AGMTQLKZWO@dell.com	5088047748	3	4297322476748377	2012/09	user1499	password	71	60000	F
1500	VIYIJF	UCVGMUCBNW	9784539943 Dell Way	\N	SKLCSEP	FL	72441	US	1	UCVGMUCBNW@dell.com	9784539943	1	4582387604750693	2011/08	user1500	password	58	60000	M
1501	MVJRQL	NWXHYZVVRG	5866298103 Dell Way	\N	GTZLJDD	LA	34482	US	1	NWXHYZVVRG@dell.com	5866298103	1	9400544126052410	2008/07	user1501	password	86	60000	F
1502	HHASUX	QCVPXRHEXB	5506034438 Dell Way	\N	DJLHNUO	AR	86973	US	1	QCVPXRHEXB@dell.com	5506034438	1	4860350863542408	2010/09	user1502	password	78	80000	F
1503	WKUTBW	PRUGYZEACN	5857046842 Dell Way	\N	LKBGZCC	MO	32708	US	1	PRUGYZEACN@dell.com	5857046842	5	9971100031863900	2009/08	user1503	password	19	40000	F
1504	VYCROT	MUSLYSOMEZ	8887181289 Dell Way	\N	NLZQOLW	CA	41821	US	1	MUSLYSOMEZ@dell.com	8887181289	3	9802161088678988	2012/08	user1504	password	19	80000	M
1505	DKEWXY	OJXHXJMXXX	6807083322 Dell Way	\N	WOLIKNR	IN	98212	US	1	OJXHXJMXXX@dell.com	6807083322	1	6820120241027326	2011/11	user1505	password	37	80000	F
1506	LQEKFN	HNLRZJPWFD	5297704623 Dell Way	\N	INOWFVV	TX	12062	US	1	HNLRZJPWFD@dell.com	5297704623	3	9236915369983764	2011/04	user1506	password	32	20000	M
1507	JOEXWR	INRSCNXFWL	5840747187 Dell Way	\N	TSRPNNQ	AK	12727	US	1	INRSCNXFWL@dell.com	5840747187	4	4011484005022794	2011/12	user1507	password	39	20000	M
1508	MAJDJX	UBZIZFFLZX	9786895392 Dell Way	\N	CPLPFLQ	OR	28054	US	1	UBZIZFFLZX@dell.com	9786895392	3	2286350068636238	2009/08	user1508	password	65	80000	M
1509	AWZXRB	XAACFMCDOR	4000110344 Dell Way	\N	OEWZVPE	SC	17717	US	1	XAACFMCDOR@dell.com	4000110344	1	7177678634878249	2012/10	user1509	password	40	20000	M
1510	HXJIUK	JXQVATKRHO	9190112440 Dell Way	\N	NHKDMEF	SD	32587	US	1	JXQVATKRHO@dell.com	9190112440	4	1416061362251639	2009/10	user1510	password	70	60000	M
1511	CWNMFK	DBLWLCEAQL	9180231350 Dell Way	\N	KTXPZSW	VA	55742	US	1	DBLWLCEAQL@dell.com	9180231350	1	3749356835149229	2011/08	user1511	password	18	80000	F
1512	NFSYIT	JFFLJFCUQV	3197126854 Dell Way	\N	SGVLDSY	AL	84267	US	1	JFFLJFCUQV@dell.com	3197126854	4	5023776781745255	2009/05	user1512	password	85	80000	M
1513	PSZJCE	OOOUQJLMBS	3479027838 Dell Way	\N	HMVALWV	NY	56852	US	1	OOOUQJLMBS@dell.com	3479027838	5	9249104580841960	2008/09	user1513	password	57	100000	F
1514	NENRSB	FNSOYEQQLD	7842398433 Dell Way	\N	MMOIHGV	ND	25734	US	1	FNSOYEQQLD@dell.com	7842398433	4	8971408247947694	2009/07	user1514	password	41	100000	M
1515	WMMXSZ	QHYUYPGBBS	9392988322 Dell Way	\N	QJAWFPB	WY	41204	US	1	QHYUYPGBBS@dell.com	9392988322	2	9282136328518392	2009/02	user1515	password	66	20000	M
1516	DAHDQP	BLNRSOSLFC	3683167623 Dell Way	\N	LBIADHJ	AR	63127	US	1	BLNRSOSLFC@dell.com	3683167623	2	7099298406392337	2012/05	user1516	password	36	20000	F
1517	OFCDHN	QYGFRRKTDM	6897939808 Dell Way	\N	CDPKNRZ	TN	97743	US	1	QYGFRRKTDM@dell.com	6897939808	4	4446001886390150	2012/11	user1517	password	77	60000	F
1518	XOKKFJ	RKAIVULHWP	9469931628 Dell Way	\N	XGDPFYO	UT	76231	US	1	RKAIVULHWP@dell.com	9469931628	4	6606138257775456	2011/03	user1518	password	71	80000	M
1519	DBAMSK	NBGHNOECLK	5770316461 Dell Way	\N	FBQEPNX	NC	36268	US	1	NBGHNOECLK@dell.com	5770316461	2	5747712810989470	2009/12	user1519	password	42	60000	F
1520	IXTTKU	ZSHNWKZHQA	3002747372 Dell Way	\N	XUQKSES	HI	51621	US	1	ZSHNWKZHQA@dell.com	3002747372	3	4632097709458321	2010/11	user1520	password	48	100000	M
1521	DQFYQY	GEVQECGEZB	8657548080 Dell Way	\N	VKTZCZL	IN	51300	US	1	GEVQECGEZB@dell.com	8657548080	5	4239393639378250	2009/10	user1521	password	30	60000	F
1522	KJBIPF	EFKGMOGNKQ	1439541939 Dell Way	\N	GJSFVAR	NY	91055	US	1	EFKGMOGNKQ@dell.com	1439541939	5	6962165139615536	2009/05	user1522	password	23	80000	M
1523	DYHJDN	TJAIPNSGUC	6115799868 Dell Way	\N	ZAXASPX	RI	56323	US	1	TJAIPNSGUC@dell.com	6115799868	5	8789715467952193	2011/08	user1523	password	59	80000	M
1524	WDRKWA	KEQYXXTZWU	8492326813 Dell Way	\N	WWNLUHZ	KY	33785	US	1	KEQYXXTZWU@dell.com	8492326813	5	8747479476965965	2010/10	user1524	password	48	40000	M
1525	CRTCCY	TBVQVUNPRJ	5667296609 Dell Way	\N	CDEKCMR	WA	53780	US	1	TBVQVUNPRJ@dell.com	5667296609	2	3223625013139099	2012/08	user1525	password	27	20000	F
1526	XDKVWL	RNHMBWEKZH	8304477491 Dell Way	\N	PKKCBIO	ND	69719	US	1	RNHMBWEKZH@dell.com	8304477491	3	3516232206951827	2012/07	user1526	password	60	100000	M
1527	ZRMLJA	SVBPAMPHBZ	9641372984 Dell Way	\N	RDAASPR	MT	16807	US	1	SVBPAMPHBZ@dell.com	9641372984	3	6189737889450044	2010/04	user1527	password	32	60000	M
1528	SYJSRF	UHFHWMIVEM	1788365900 Dell Way	\N	WFFLXSN	TX	26388	US	1	UHFHWMIVEM@dell.com	1788365900	2	5460085167549551	2009/11	user1528	password	54	100000	M
1529	WSOBMV	GTRTCNYPJD	2505400022 Dell Way	\N	UUAMIWR	MD	34372	US	1	GTRTCNYPJD@dell.com	2505400022	4	2605331566184759	2011/08	user1529	password	21	60000	F
1530	POWKVP	CPSPNHYRBT	1363240272 Dell Way	\N	SOBPFMW	MD	23220	US	1	CPSPNHYRBT@dell.com	1363240272	1	8282167040742935	2008/07	user1530	password	30	80000	F
1531	ACZQEO	IUBQTTSMLG	9850193664 Dell Way	\N	OAMAXXE	WA	95087	US	1	IUBQTTSMLG@dell.com	9850193664	1	5669834063388408	2008/09	user1531	password	66	20000	M
1532	QVZEDT	FUMYMZKTOL	6219572112 Dell Way	\N	FOIDTGB	OK	34416	US	1	FUMYMZKTOL@dell.com	6219572112	5	9752744384109976	2009/01	user1532	password	73	100000	M
1533	TAAMGU	ZFHYPAMAGB	8661396442 Dell Way	\N	JJUPKNW	WY	45794	US	1	ZFHYPAMAGB@dell.com	8661396442	2	5092779492028058	2011/02	user1533	password	41	40000	F
1534	IVKDUP	KTFKGGQHPA	5033496554 Dell Way	\N	CFLPCKZ	WI	69441	US	1	KTFKGGQHPA@dell.com	5033496554	3	7861743011046202	2011/11	user1534	password	83	20000	M
1535	HFOWQH	CANIRVYRXE	9582005745 Dell Way	\N	CMGNMEE	WA	77160	US	1	CANIRVYRXE@dell.com	9582005745	4	6925498323980720	2012/10	user1535	password	47	20000	F
1536	ZAQGCR	ULJQJANNDA	4367195827 Dell Way	\N	URNZWLS	SD	24550	US	1	ULJQJANNDA@dell.com	4367195827	4	9706345583777876	2011/10	user1536	password	90	80000	M
1537	QAXIVI	RLSSZGWAAN	1932579917 Dell Way	\N	NAKZSFD	CA	89288	US	1	RLSSZGWAAN@dell.com	1932579917	5	7073118646629155	2008/08	user1537	password	52	80000	M
1538	JBLSTX	LLWRHWSVKS	9916390859 Dell Way	\N	FJLLNNI	NJ	47085	US	1	LLWRHWSVKS@dell.com	9916390859	4	1308363000862300	2010/06	user1538	password	66	100000	M
1539	DOGAZS	XRZUJVECBO	5708941081 Dell Way	\N	OMBBURM	SC	42942	US	1	XRZUJVECBO@dell.com	5708941081	2	8382614871487022	2008/02	user1539	password	42	40000	M
1540	PIQHFH	HARCEUESIQ	6373736539 Dell Way	\N	TKLKWFU	MD	52494	US	1	HARCEUESIQ@dell.com	6373736539	3	6097645982168615	2012/11	user1540	password	33	60000	F
1541	VVMDCM	UFQPJJXACH	7405002122 Dell Way	\N	LNERHOD	VA	24206	US	1	UFQPJJXACH@dell.com	7405002122	5	1603301218710839	2012/05	user1541	password	40	80000	F
1542	UXHGSN	XHXHEXJLJX	4646878248 Dell Way	\N	QBFEECI	VT	94278	US	1	XHXHEXJLJX@dell.com	4646878248	5	3678777924738824	2011/08	user1542	password	53	60000	F
1543	UTFHRM	EYRCIDMGTN	8016932787 Dell Way	\N	LXSOGQM	NV	50286	US	1	EYRCIDMGTN@dell.com	8016932787	2	1391055617947131	2009/11	user1543	password	57	20000	M
1544	TIIGNH	XPPACVTQHR	4997495936 Dell Way	\N	IVYYIPK	CA	98552	US	1	XPPACVTQHR@dell.com	4997495936	2	8796817383263261	2012/05	user1544	password	55	80000	M
1545	VZFDWV	SXXORNVIWR	7589101359 Dell Way	\N	HVZWFBW	NV	47437	US	1	SXXORNVIWR@dell.com	7589101359	4	8156680725980551	2009/05	user1545	password	54	20000	F
1546	SFFNYC	LMTYICVZJQ	3251173839 Dell Way	\N	ZGVBDML	TX	22395	US	1	LMTYICVZJQ@dell.com	3251173839	1	5607927208300680	2011/03	user1546	password	80	60000	F
1547	BYIEJU	XIDADCJTCQ	7714710113 Dell Way	\N	PDTCOPG	TN	72266	US	1	XIDADCJTCQ@dell.com	7714710113	3	8886620632838459	2010/01	user1547	password	37	80000	M
1548	OVJJTR	MTVPDPRTEU	7020470274 Dell Way	\N	NHJCNFU	ID	79806	US	1	MTVPDPRTEU@dell.com	7020470274	5	8085733841639013	2012/07	user1548	password	73	60000	F
1549	CWCUJV	PZZFQSKLGR	6388907738 Dell Way	\N	VIEADLV	SC	38800	US	1	PZZFQSKLGR@dell.com	6388907738	4	8616960722021759	2009/03	user1549	password	32	60000	F
1550	HGMDWL	CBCVLOBCJK	9254280125 Dell Way	\N	HKNTGIB	TN	15977	US	1	CBCVLOBCJK@dell.com	9254280125	1	3765599605627358	2008/08	user1550	password	49	60000	M
1551	XNTJQU	MMGAOIKYQV	2801731866 Dell Way	\N	MJBVLXX	LA	16801	US	1	MMGAOIKYQV@dell.com	2801731866	3	7479825146961958	2011/11	user1551	password	62	60000	F
1552	JXBDKO	JKCSVBJQNT	4581114054 Dell Way	\N	SJEPGOR	MN	14123	US	1	JKCSVBJQNT@dell.com	4581114054	1	9413607204798610	2008/08	user1552	password	44	40000	M
1553	LNYZXI	BQECZUQSNA	4891204359 Dell Way	\N	XDGLUSM	FL	81500	US	1	BQECZUQSNA@dell.com	4891204359	2	4785663504619152	2011/07	user1553	password	88	40000	F
1554	WEZFGP	JJOEZGSZEV	2501987469 Dell Way	\N	GPPYCUT	NC	10926	US	1	JJOEZGSZEV@dell.com	2501987469	2	6196068233810366	2008/07	user1554	password	66	20000	M
1555	QFZGPI	UUIBMHFHNV	3645594787 Dell Way	\N	XMXSGLS	MD	80933	US	1	UUIBMHFHNV@dell.com	3645594787	3	4019978200551123	2012/07	user1555	password	23	60000	M
1556	BVJJPD	RRPZWXNSUZ	2861272380 Dell Way	\N	QNGCFQW	MT	24241	US	1	RRPZWXNSUZ@dell.com	2861272380	3	7244775195606054	2009/01	user1556	password	51	40000	M
1557	VSMYJE	OJBMWTHWJU	6266646461 Dell Way	\N	CLATINX	NC	99050	US	1	OJBMWTHWJU@dell.com	6266646461	5	1448251361493021	2008/02	user1557	password	86	100000	M
1558	LVFPKO	QWLKDIUXKG	5279585618 Dell Way	\N	XDOLBCL	NJ	92699	US	1	QWLKDIUXKG@dell.com	5279585618	4	1518396265339106	2010/07	user1558	password	83	100000	F
1559	CLTRCP	DMTLGQWMOA	2296798571 Dell Way	\N	BABELRC	VT	40839	US	1	DMTLGQWMOA@dell.com	2296798571	2	8825178667437286	2008/02	user1559	password	33	20000	M
1560	YVROZD	HKKYHXMHYM	3052439237 Dell Way	\N	IDYAFVJ	LA	22434	US	1	HKKYHXMHYM@dell.com	3052439237	2	3561457737814635	2010/07	user1560	password	81	40000	F
1561	NYJRFT	BEBZQIYDRB	3947519941 Dell Way	\N	BRHXBQB	IL	12311	US	1	BEBZQIYDRB@dell.com	3947519941	4	6152186871040613	2008/02	user1561	password	87	80000	F
1562	IKHCLL	DLCLJGDKIV	9150455770 Dell Way	\N	RFWHHEI	NH	89198	US	1	DLCLJGDKIV@dell.com	9150455770	4	9956340217031540	2012/07	user1562	password	21	20000	M
1563	IGJUJU	WVDCZNLUFR	7425871997 Dell Way	\N	RNYVWNS	PA	38736	US	1	WVDCZNLUFR@dell.com	7425871997	4	8427472487092019	2011/10	user1563	password	70	20000	F
1564	BWKVTG	YWFMHASZSF	6176111421 Dell Way	\N	XNBLGVT	WV	49919	US	1	YWFMHASZSF@dell.com	6176111421	4	3091682097408920	2009/11	user1564	password	37	40000	M
1565	REMYDI	DQQEIPWONK	2183426990 Dell Way	\N	QYQLRQX	ID	42299	US	1	DQQEIPWONK@dell.com	2183426990	3	2790864758193493	2010/11	user1565	password	85	20000	F
1566	KAGSDX	JIGZEUMOLK	4601973732 Dell Way	\N	FWCVUJF	VT	91566	US	1	JIGZEUMOLK@dell.com	4601973732	2	8334549903869630	2009/05	user1566	password	84	80000	F
1567	ELOBUW	HTBCGPNQVK	8304834330 Dell Way	\N	TRECWCZ	ID	46951	US	1	HTBCGPNQVK@dell.com	8304834330	3	8262940166052432	2011/04	user1567	password	33	100000	M
1568	TYNQGH	RINHWEDGXU	7864907028 Dell Way	\N	LZROZYY	SD	57435	US	1	RINHWEDGXU@dell.com	7864907028	3	8447292947210372	2012/06	user1568	password	58	80000	F
1569	CJQJBZ	XIVBMCZGOZ	2820937342 Dell Way	\N	XCZWBUJ	SD	37414	US	1	XIVBMCZGOZ@dell.com	2820937342	4	7573723442386837	2011/07	user1569	password	26	100000	M
1570	TFZSDI	OFUREAFEYI	9483876617 Dell Way	\N	DUJXEEF	LA	97478	US	1	OFUREAFEYI@dell.com	9483876617	1	5554197272751481	2008/12	user1570	password	48	80000	F
1571	KNJSBO	MSTNYXMGBG	3464766416 Dell Way	\N	PYLUEVT	CO	94980	US	1	MSTNYXMGBG@dell.com	3464766416	1	9368213302455844	2011/12	user1571	password	28	20000	F
1572	MUOBHH	VVFSHMUOCT	7193166899 Dell Way	\N	AWXVQAT	VT	27612	US	1	VVFSHMUOCT@dell.com	7193166899	4	2435779910068959	2012/09	user1572	password	64	40000	F
1573	EKULFP	RYXDSMFLMC	7736933731 Dell Way	\N	JHSKBQP	OR	33123	US	1	RYXDSMFLMC@dell.com	7736933731	3	9598970336373896	2009/11	user1573	password	51	60000	F
1574	GANWRL	UVDGAPTDZA	7340036245 Dell Way	\N	VJCMYVT	OH	46273	US	1	UVDGAPTDZA@dell.com	7340036245	1	3802157636731863	2008/08	user1574	password	62	60000	M
1575	CGJOBE	RHFHAIGBEP	7106596881 Dell Way	\N	DROZKGJ	CO	40030	US	1	RHFHAIGBEP@dell.com	7106596881	2	9815769255161286	2009/09	user1575	password	65	60000	M
1576	ZYZEQH	JYHSEJWUMN	9292242607 Dell Way	\N	JLYPVBY	MS	38783	US	1	JYHSEJWUMN@dell.com	9292242607	4	9965151068288834	2010/03	user1576	password	86	60000	F
1577	XTUFDS	MVXVRRIFBU	5581953806 Dell Way	\N	DQPFPCN	MT	90822	US	1	MVXVRRIFBU@dell.com	5581953806	1	1801643006503582	2010/08	user1577	password	34	40000	F
1578	AONSBI	PXAHGFIAJZ	7597618806 Dell Way	\N	QOPTBCQ	NE	26167	US	1	PXAHGFIAJZ@dell.com	7597618806	1	8445994690991939	2012/05	user1578	password	33	100000	M
1579	SRABHX	BPEGYEQXVE	6506244688 Dell Way	\N	NOGPFUU	WI	84593	US	1	BPEGYEQXVE@dell.com	6506244688	5	2980250935070217	2012/11	user1579	password	30	60000	M
1580	EPWCQL	GXJLNHGRUV	7865253997 Dell Way	\N	XKASEZO	SC	89561	US	1	GXJLNHGRUV@dell.com	7865253997	4	7808538951911033	2012/03	user1580	password	40	20000	M
1581	EGKPMH	ZYUHFLBAJM	7238190837 Dell Way	\N	BCRBQMY	MA	19464	US	1	ZYUHFLBAJM@dell.com	7238190837	2	3519842778798193	2008/06	user1581	password	20	20000	M
1582	LUESTD	MAIYCJIPLK	2136035802 Dell Way	\N	GMATLKW	CT	75828	US	1	MAIYCJIPLK@dell.com	2136035802	1	2651563331950456	2008/04	user1582	password	81	60000	F
1583	BIVEUW	NTZWCOIMVU	8452741967 Dell Way	\N	NOGXKJQ	NC	53021	US	1	NTZWCOIMVU@dell.com	8452741967	4	7990997427143157	2011/04	user1583	password	80	80000	M
1584	RYLOLF	NIHCQTYLGN	3504861291 Dell Way	\N	REYAVMN	NV	27648	US	1	NIHCQTYLGN@dell.com	3504861291	2	5585211475379766	2008/02	user1584	password	27	100000	F
1585	OJMTXU	AALUYWBMOG	6319446541 Dell Way	\N	KPBXCSC	LA	14685	US	1	AALUYWBMOG@dell.com	6319446541	3	2385808294173330	2011/04	user1585	password	31	40000	M
1586	RBPMCQ	XWPUYBJELY	2072346749 Dell Way	\N	FIAXKJZ	AK	86977	US	1	XWPUYBJELY@dell.com	2072346749	4	2504264032002538	2009/01	user1586	password	80	100000	F
1587	MLDCJA	REYSNCELHN	8597641520 Dell Way	\N	LFYVEYR	IN	72639	US	1	REYSNCELHN@dell.com	8597641520	4	7502902123145760	2011/08	user1587	password	75	20000	F
1588	YGKZYP	XRCAVOIJAN	7102313565 Dell Way	\N	HVSGNAY	LA	66995	US	1	XRCAVOIJAN@dell.com	7102313565	1	3045008961576968	2010/03	user1588	password	38	60000	F
1589	SJKHHB	KHXYPGYDOU	7471589478 Dell Way	\N	VVHWURM	MN	74824	US	1	KHXYPGYDOU@dell.com	7471589478	5	9520538085605950	2012/05	user1589	password	49	80000	M
1590	WZAXJH	VIXCHARBWM	7407391753 Dell Way	\N	JSHBFTT	WA	70333	US	1	VIXCHARBWM@dell.com	7407391753	5	1184128246735781	2008/08	user1590	password	72	100000	M
1591	TXYBTH	YVOZNQVZAN	7313411834 Dell Way	\N	HBTAVRR	NC	62341	US	1	YVOZNQVZAN@dell.com	7313411834	4	2740751479752362	2010/09	user1591	password	75	40000	M
1592	THIAFE	PERFARGOYH	7444250933 Dell Way	\N	HZDYQRN	KY	42011	US	1	PERFARGOYH@dell.com	7444250933	4	1298473339993506	2010/01	user1592	password	63	40000	F
1593	YGNDVR	VBSMHGLPNK	8087477885 Dell Way	\N	SLBKZKT	OH	28818	US	1	VBSMHGLPNK@dell.com	8087477885	1	2976818440947682	2010/06	user1593	password	54	40000	M
1594	ANOSIP	KVXQHNDSFP	6387751781 Dell Way	\N	TQPEJHJ	DE	53236	US	1	KVXQHNDSFP@dell.com	6387751781	3	9257072866428644	2008/12	user1594	password	63	20000	F
1595	EUUTEP	RVXEZPKOIA	8600731115 Dell Way	\N	ENKLXPY	MS	24550	US	1	RVXEZPKOIA@dell.com	8600731115	3	2038561610970646	2010/09	user1595	password	60	80000	F
1596	JKRZBN	WFMLQBURFI	9303751689 Dell Way	\N	BRFQPSU	ME	37069	US	1	WFMLQBURFI@dell.com	9303751689	5	9982931218110026	2010/07	user1596	password	54	100000	M
1597	EVYRSE	EEVFZMKHNC	5640851738 Dell Way	\N	NERFZCN	VT	98908	US	1	EEVFZMKHNC@dell.com	5640851738	3	5519472887739540	2008/04	user1597	password	47	20000	F
1598	JWVOAA	JGZVRHJTUO	1011662798 Dell Way	\N	KAONNMM	AR	89375	US	1	JGZVRHJTUO@dell.com	1011662798	1	2448032182175666	2010/03	user1598	password	38	80000	F
1599	DIDDSK	DOBKXVFMFF	5972212221 Dell Way	\N	BTTNGUK	IA	84700	US	1	DOBKXVFMFF@dell.com	5972212221	4	1637395858764648	2012/06	user1599	password	31	100000	M
1600	ICLTFZ	UQXQVKWALP	5041328005 Dell Way	\N	UYVOIBJ	VA	74651	US	1	UQXQVKWALP@dell.com	5041328005	4	2246177597437054	2011/09	user1600	password	82	100000	M
1601	ISZINQ	FDLPZMBOGZ	3855184288 Dell Way	\N	KUILEFE	NM	92986	US	1	FDLPZMBOGZ@dell.com	3855184288	2	6448718555737287	2009/03	user1601	password	46	60000	M
1602	JVLABP	MROYSDFRNA	7566617558 Dell Way	\N	AZFFDVD	MN	18428	US	1	MROYSDFRNA@dell.com	7566617558	4	4013926604762673	2008/03	user1602	password	38	60000	F
1603	TNCIZU	XXMADENDEN	6280647147 Dell Way	\N	IJREMDG	HI	82410	US	1	XXMADENDEN@dell.com	6280647147	2	1067746887449175	2012/11	user1603	password	21	80000	F
1604	EYIYWG	KWJPKNTXVD	5659597752 Dell Way	\N	OAQSGWN	TN	27528	US	1	KWJPKNTXVD@dell.com	5659597752	4	1328067853581160	2010/04	user1604	password	46	80000	F
1605	SRDYBA	IRKVKIRNXR	3178951560 Dell Way	\N	EPYACUF	NJ	55114	US	1	IRKVKIRNXR@dell.com	3178951560	1	8495026875752957	2011/12	user1605	password	26	40000	M
1606	GHRGQI	RMSZEGWWKM	9356040960 Dell Way	\N	ULOPQFC	UT	45279	US	1	RMSZEGWWKM@dell.com	9356040960	3	3853375247679651	2008/11	user1606	password	83	40000	F
1607	OOUWFG	PELWBHGNCR	9917698868 Dell Way	\N	CRIHUER	OK	71906	US	1	PELWBHGNCR@dell.com	9917698868	4	5788428664207459	2012/01	user1607	password	67	60000	M
1608	LIUSYZ	DUALBONSQF	5014637586 Dell Way	\N	BXZFPSX	NE	50572	US	1	DUALBONSQF@dell.com	5014637586	3	5516937999054790	2008/12	user1608	password	25	60000	F
1609	XHEXLZ	YWAMJTDPUB	2920913795 Dell Way	\N	OZQGXFS	LA	72612	US	1	YWAMJTDPUB@dell.com	2920913795	3	6664665797725320	2009/01	user1609	password	83	40000	F
1610	CCUBBQ	BNAUQPOSEO	8839394316 Dell Way	\N	ILMODVG	LA	38337	US	1	BNAUQPOSEO@dell.com	8839394316	4	4392435884103179	2011/11	user1610	password	71	100000	F
1611	NXBEZP	FTGVIYZXGL	8999711361 Dell Way	\N	JVPFBYN	WA	65439	US	1	FTGVIYZXGL@dell.com	8999711361	4	5615332292858512	2011/07	user1611	password	56	20000	F
1612	PIKENE	KJNJJKQUTL	4822632638 Dell Way	\N	JYMHMKX	KY	19883	US	1	KJNJJKQUTL@dell.com	4822632638	5	6868143714033068	2012/02	user1612	password	25	60000	F
1613	NSZRDI	EMRPDMIOVH	3072728384 Dell Way	\N	BCTMACP	MI	16604	US	1	EMRPDMIOVH@dell.com	3072728384	3	2767136202193796	2009/12	user1613	password	65	100000	M
1614	QNUZSG	QHJCQYYYZB	1388844513 Dell Way	\N	RLBUANW	ID	93087	US	1	QHJCQYYYZB@dell.com	1388844513	3	8719219488091768	2011/06	user1614	password	54	40000	M
1615	HHSOYA	YBQWZPWAGI	4730925213 Dell Way	\N	CAJQWPO	VT	29024	US	1	YBQWZPWAGI@dell.com	4730925213	4	6871261861640961	2012/12	user1615	password	63	20000	F
1616	ITEIRF	ZNFOKGVSJV	5825024430 Dell Way	\N	BZSROQW	WI	31400	US	1	ZNFOKGVSJV@dell.com	5825024430	5	2467739742249250	2008/01	user1616	password	45	60000	M
1617	NVMTVA	YKKFFDOBEO	8303476512 Dell Way	\N	UWCKTBQ	ID	93135	US	1	YKKFFDOBEO@dell.com	8303476512	3	9965352041181178	2008/12	user1617	password	77	80000	M
1618	HMPILZ	SQFVEGASAW	8013039699 Dell Way	\N	VLPWCWU	VT	37970	US	1	SQFVEGASAW@dell.com	8013039699	1	3164005265105516	2010/10	user1618	password	18	100000	F
1619	PESPXJ	UTNBUGCRBN	7211084416 Dell Way	\N	GYQDSNL	MS	66784	US	1	UTNBUGCRBN@dell.com	7211084416	1	5069308826234192	2011/12	user1619	password	72	40000	F
1620	MWBVRV	JSPQUHRHNQ	5927176243 Dell Way	\N	YRIMDVC	SD	92018	US	1	JSPQUHRHNQ@dell.com	5927176243	3	8866008221171797	2009/10	user1620	password	20	80000	M
1621	CPIYYA	OOUVGCJWBA	8383588890 Dell Way	\N	FNDAPYY	DC	51315	US	1	OOUVGCJWBA@dell.com	8383588890	3	3322246339172125	2012/03	user1621	password	85	100000	M
1622	GWTHKH	CGOFPKGPQT	4675634697 Dell Way	\N	TRIRPMD	ME	93590	US	1	CGOFPKGPQT@dell.com	4675634697	2	2210472378879785	2009/03	user1622	password	85	60000	F
1623	RWNZZT	NEIYKYODRF	1328028651 Dell Way	\N	MJVZNGX	VT	57255	US	1	NEIYKYODRF@dell.com	1328028651	2	7730190029833467	2012/11	user1623	password	79	80000	M
1624	JPSDCW	LAHJPLBUXK	2291066976 Dell Way	\N	QXYWUWK	TN	19574	US	1	LAHJPLBUXK@dell.com	2291066976	4	9677648964803668	2012/05	user1624	password	69	40000	F
1625	KMCHXD	OHSAJNXTDU	6478266419 Dell Way	\N	RAPNKKQ	NC	28263	US	1	OHSAJNXTDU@dell.com	6478266419	3	6567479118239135	2009/11	user1625	password	63	80000	F
1626	SAHWPP	PPYCNSGIKG	2315644568 Dell Way	\N	XYQIPFN	FL	76661	US	1	PPYCNSGIKG@dell.com	2315644568	3	6710993666201831	2011/03	user1626	password	18	60000	F
1627	HJWWYL	VBZNHHXNFW	7831468138 Dell Way	\N	ENLJBQD	GA	22107	US	1	VBZNHHXNFW@dell.com	7831468138	5	4298710997682065	2011/06	user1627	password	63	20000	M
1628	MXUYTV	XGCEEQKBUX	6568862417 Dell Way	\N	MEZDIEG	AZ	21875	US	1	XGCEEQKBUX@dell.com	6568862417	5	6394333172123880	2009/11	user1628	password	49	80000	M
1629	FQOANU	CSZTCAOANT	8948477800 Dell Way	\N	ZQBDXDH	MT	96492	US	1	CSZTCAOANT@dell.com	8948477800	4	8575047187041492	2009/06	user1629	password	65	60000	F
1630	ENQZQJ	ZJMAYMORME	6839088940 Dell Way	\N	SQCVXPU	SD	40698	US	1	ZJMAYMORME@dell.com	6839088940	1	8245316451881082	2009/08	user1630	password	84	60000	F
1631	OMUXLE	JMDWAUJFNA	1154865568 Dell Way	\N	HJYWESF	SD	86116	US	1	JMDWAUJFNA@dell.com	1154865568	1	5281977696344257	2012/07	user1631	password	64	60000	F
1632	LJNQTZ	TQANAFAAMK	9896513218 Dell Way	\N	YJOROJN	NH	50222	US	1	TQANAFAAMK@dell.com	9896513218	3	1235319748055189	2011/12	user1632	password	23	20000	F
1633	PSDOLU	OZUUAUGKTQ	7879291682 Dell Way	\N	YKFHXUT	VT	37215	US	1	OZUUAUGKTQ@dell.com	7879291682	3	3593976119067520	2012/08	user1633	password	65	60000	F
1634	UZTOOS	IJTDQDWGBH	8409425516 Dell Way	\N	LJEGCCN	UT	66029	US	1	IJTDQDWGBH@dell.com	8409425516	4	2957122510764748	2010/02	user1634	password	55	40000	F
1635	GVSZEB	SIRVEXXLJH	6288273497 Dell Way	\N	QPJTDGJ	WI	96060	US	1	SIRVEXXLJH@dell.com	6288273497	3	1861610829830169	2008/09	user1635	password	34	40000	M
1636	YIRZAZ	RVEPTQYAHO	7098852476 Dell Way	\N	JBRQKQP	WY	14971	US	1	RVEPTQYAHO@dell.com	7098852476	1	7752809282857925	2012/06	user1636	password	37	100000	M
1637	YVTYNP	DCIUBIBPSC	7151438215 Dell Way	\N	GINWXNY	NH	65078	US	1	DCIUBIBPSC@dell.com	7151438215	3	1478113609831780	2012/05	user1637	password	76	100000	F
1638	OWSDZU	MTVUVLNYRV	6645477324 Dell Way	\N	LOTZMJO	DE	87811	US	1	MTVUVLNYRV@dell.com	6645477324	1	2971893812995404	2010/01	user1638	password	48	100000	M
1639	DDXYPQ	UKMFXKWTVL	9660371498 Dell Way	\N	NUYWJCT	AK	30991	US	1	UKMFXKWTVL@dell.com	9660371498	3	3427815625909716	2009/06	user1639	password	30	60000	M
1640	BLESFO	EKMOHGKSTF	3273380442 Dell Way	\N	QQPTJPZ	KY	13729	US	1	EKMOHGKSTF@dell.com	3273380442	4	5224217850714922	2010/03	user1640	password	20	60000	M
1641	FEWTIG	GXNMHGGNXW	2941991813 Dell Way	\N	CQGSQPT	UT	38929	US	1	GXNMHGGNXW@dell.com	2941991813	2	5905334018170834	2009/10	user1641	password	32	60000	M
1642	BFGHMD	VYLCFYZCBP	8238530974 Dell Way	\N	ITGYMCG	OK	46397	US	1	VYLCFYZCBP@dell.com	8238530974	5	2493482804857194	2008/05	user1642	password	24	20000	M
1643	IJCMFB	XHGWGIXWQR	8085221296 Dell Way	\N	CPDFWWQ	NV	84135	US	1	XHGWGIXWQR@dell.com	8085221296	4	3079137929715216	2012/09	user1643	password	80	40000	F
1644	YSHZQO	FMVNJREAUT	1933213430 Dell Way	\N	EAPBQGW	ME	92854	US	1	FMVNJREAUT@dell.com	1933213430	2	6680481459945441	2012/07	user1644	password	69	100000	F
1645	ZWVNCH	JQRAUSVOXV	1078120058 Dell Way	\N	EYLLVWJ	WA	24857	US	1	JQRAUSVOXV@dell.com	1078120058	5	7097951954230667	2011/10	user1645	password	83	80000	M
1646	SFTAPK	SPFLLUIGZH	4913153341 Dell Way	\N	SKDPUBT	SD	95807	US	1	SPFLLUIGZH@dell.com	4913153341	3	7680119168013335	2009/03	user1646	password	47	20000	F
1647	ECAOUQ	TGBOOINWBY	7910654777 Dell Way	\N	AQTBKOA	TN	15898	US	1	TGBOOINWBY@dell.com	7910654777	1	3518653541803360	2008/03	user1647	password	70	40000	F
1648	TYBJRH	LGWTTTURTL	3715689588 Dell Way	\N	KVVYWRA	NM	83445	US	1	LGWTTTURTL@dell.com	3715689588	5	1170655527617782	2008/03	user1648	password	39	80000	F
1649	JDUROA	OITIDLCOWY	8984373958 Dell Way	\N	KVUBVKW	DC	31090	US	1	OITIDLCOWY@dell.com	8984373958	1	4609790552407503	2008/12	user1649	password	53	60000	F
1650	HGQHUY	BCBMEQJCAE	9631732987 Dell Way	\N	XBAIYDO	SD	37337	US	1	BCBMEQJCAE@dell.com	9631732987	1	3049896357115358	2010/07	user1650	password	38	80000	M
1651	XAPVBS	XOWNYZNCXP	7997471244 Dell Way	\N	CFNGUJO	OR	42139	US	1	XOWNYZNCXP@dell.com	7997471244	1	9276848101988436	2008/11	user1651	password	70	100000	M
1652	HVZZSO	WGMWUPTKRZ	5933889733 Dell Way	\N	XYTHMMQ	ID	71700	US	1	WGMWUPTKRZ@dell.com	5933889733	2	6358912732917816	2009/04	user1652	password	55	60000	F
1653	NOVCLB	OIWEBGWBEU	6438526178 Dell Way	\N	VLHIBNA	NH	87303	US	1	OIWEBGWBEU@dell.com	6438526178	5	2358692497946322	2008/06	user1653	password	36	80000	M
1654	CSLDHT	ZLVGHWKBSV	8998611777 Dell Way	\N	IAWWAMT	NM	41370	US	1	ZLVGHWKBSV@dell.com	8998611777	4	8056122954003514	2008/05	user1654	password	75	40000	F
1655	FJKYJW	UPDRZFJUOK	3640971275 Dell Way	\N	RLLEECN	AZ	86254	US	1	UPDRZFJUOK@dell.com	3640971275	2	3274474344216287	2008/06	user1655	password	45	40000	M
1656	UGEQAT	USTABOOMGA	1782046942 Dell Way	\N	XKFZXHV	GA	53925	US	1	USTABOOMGA@dell.com	1782046942	2	9318122236058116	2010/07	user1656	password	71	40000	M
1657	XXWQRO	KRQYGCFHZP	2402409525 Dell Way	\N	MZMTVSG	VT	97611	US	1	KRQYGCFHZP@dell.com	2402409525	2	5855323103722185	2012/08	user1657	password	44	80000	M
1658	FLETVW	JUCMZJMOWL	3539465467 Dell Way	\N	BPGTVET	WV	58440	US	1	JUCMZJMOWL@dell.com	3539465467	5	2372235553804785	2011/08	user1658	password	65	100000	F
1659	VPXRZR	UMREYFAKHP	5728256523 Dell Way	\N	RBLVVKJ	CA	33475	US	1	UMREYFAKHP@dell.com	5728256523	4	9045680857729168	2008/08	user1659	password	87	20000	F
1660	VSFNMR	EQPKRASGRT	3158436948 Dell Way	\N	RNOCWRI	MD	45874	US	1	EQPKRASGRT@dell.com	3158436948	3	9845176068600268	2008/08	user1660	password	31	20000	F
1661	JOTBSK	RDBRVIJPAW	2845061553 Dell Way	\N	ECTVLDF	OH	74872	US	1	RDBRVIJPAW@dell.com	2845061553	5	3823981669265777	2009/11	user1661	password	61	80000	F
1662	JVEUMI	WEDENSFJWH	3457101136 Dell Way	\N	CSTGXLY	CT	38593	US	1	WEDENSFJWH@dell.com	3457101136	3	3099122251849621	2012/04	user1662	password	69	40000	F
1663	XAPFWT	IBHBGQXOTP	3672500935 Dell Way	\N	IZNTYQB	GA	24606	US	1	IBHBGQXOTP@dell.com	3672500935	1	4963823597412557	2012/04	user1663	password	57	100000	F
1664	DCFXKG	EMNUKCOAKN	8074195141 Dell Way	\N	NDMEFRI	MS	78868	US	1	EMNUKCOAKN@dell.com	8074195141	3	1800677972845733	2009/05	user1664	password	49	60000	F
1665	QJXXNJ	LITNWTXJHB	4418405019 Dell Way	\N	VLGNUTH	NH	31138	US	1	LITNWTXJHB@dell.com	4418405019	5	6548326989170164	2012/05	user1665	password	24	60000	M
1666	ZJGIUO	CIKVFUCGQO	1855132984 Dell Way	\N	NDJGLZM	SD	90563	US	1	CIKVFUCGQO@dell.com	1855132984	4	3454507264308631	2008/01	user1666	password	90	20000	F
1667	FNGTPO	ELUYOAOCNS	6759660261 Dell Way	\N	MUDMGYJ	KY	62100	US	1	ELUYOAOCNS@dell.com	6759660261	3	6932246187701822	2011/09	user1667	password	25	100000	F
1668	IQUXUF	RSTSHWGZJA	3792783156 Dell Way	\N	DVGBFPQ	TN	23353	US	1	RSTSHWGZJA@dell.com	3792783156	3	8587570567615331	2010/05	user1668	password	20	80000	M
1669	VQTAIM	UAURGTAGWW	2140133270 Dell Way	\N	NYBDPXH	VT	43500	US	1	UAURGTAGWW@dell.com	2140133270	2	7429872419685126	2008/02	user1669	password	68	100000	M
1670	LABYVC	TMIMMPJICI	4377116099 Dell Way	\N	KGYHNWR	NM	26986	US	1	TMIMMPJICI@dell.com	4377116099	5	3486034539993852	2008/10	user1670	password	19	60000	M
1671	CMREFD	MSQBCYEKJK	7079101707 Dell Way	\N	JQXFHOK	NY	43508	US	1	MSQBCYEKJK@dell.com	7079101707	4	2592115500941872	2011/04	user1671	password	18	80000	M
1672	RYYUKQ	KMSJQDSAMJ	1366360653 Dell Way	\N	YRRMCJW	PA	19146	US	1	KMSJQDSAMJ@dell.com	1366360653	3	4283123335801065	2008/03	user1672	password	25	80000	F
1673	ANORYA	KHQNAQZKPR	9164363686 Dell Way	\N	CBTLYNO	WV	98197	US	1	KHQNAQZKPR@dell.com	9164363686	1	2837398570030927	2008/10	user1673	password	43	20000	F
1674	XSEXCM	OQNFPYUHAW	7821753210 Dell Way	\N	BLUOZUO	VA	83557	US	1	OQNFPYUHAW@dell.com	7821753210	5	6118391104508192	2008/12	user1674	password	78	20000	M
1675	AYUNMK	BRAZMHZIIL	3889495663 Dell Way	\N	DXLYMIT	HI	31372	US	1	BRAZMHZIIL@dell.com	3889495663	2	2710353426635265	2008/05	user1675	password	80	20000	F
1676	QSTATL	BSYIRHRDLP	3794105008 Dell Way	\N	OJBWDGD	MI	64221	US	1	BSYIRHRDLP@dell.com	3794105008	3	9555591359734536	2008/10	user1676	password	34	100000	F
1677	ZVFLXX	KFPRWTCMHM	3960575045 Dell Way	\N	NEPUHAJ	NH	65558	US	1	KFPRWTCMHM@dell.com	3960575045	4	4521345795597881	2010/08	user1677	password	80	60000	F
1678	BAIZKN	PBKJEWQQKV	3100727268 Dell Way	\N	FECFOSV	UT	55053	US	1	PBKJEWQQKV@dell.com	3100727268	3	1808720404747873	2008/12	user1678	password	56	20000	M
1679	WEJJUL	UDPRTFBPKG	1129389674 Dell Way	\N	SQULMRY	OK	18111	US	1	UDPRTFBPKG@dell.com	1129389674	5	1691339947748929	2010/12	user1679	password	22	40000	F
1680	LTXXOB	MGVRIKCOCT	2648554035 Dell Way	\N	JNFALYC	MN	76581	US	1	MGVRIKCOCT@dell.com	2648554035	1	7476163801737130	2009/05	user1680	password	81	80000	F
1681	UPTVBZ	RTIBWXEPGS	2808648742 Dell Way	\N	VHDTJQM	ND	66612	US	1	RTIBWXEPGS@dell.com	2808648742	5	1210829381830990	2008/07	user1681	password	31	100000	F
1682	XSEXJX	GKUDOJKHER	7267714331 Dell Way	\N	LXBBKPR	NH	48404	US	1	GKUDOJKHER@dell.com	7267714331	4	9468647613190116	2012/07	user1682	password	21	100000	F
1683	FSODYZ	XCOGMVLEGJ	2745224411 Dell Way	\N	FHTVZJG	NV	13092	US	1	XCOGMVLEGJ@dell.com	2745224411	3	6032283913809807	2009/05	user1683	password	74	60000	F
1684	JOAIMD	WTQSEUYOAG	3392713828 Dell Way	\N	HVFRCWS	IL	48474	US	1	WTQSEUYOAG@dell.com	3392713828	3	8012740498874337	2008/12	user1684	password	80	40000	M
1685	WSZAPS	QHXLGLLNTG	8324152752 Dell Way	\N	SLIPDPA	MD	20823	US	1	QHXLGLLNTG@dell.com	8324152752	3	1662692652083933	2011/11	user1685	password	61	60000	M
1686	PODIFL	FQSRBFKHYV	4897363721 Dell Way	\N	QOZGPJJ	MD	83884	US	1	FQSRBFKHYV@dell.com	4897363721	1	6895413527730853	2008/08	user1686	password	33	80000	F
1687	JYJUDZ	NVASFIRBYF	9163409121 Dell Way	\N	BEULNFG	WV	33176	US	1	NVASFIRBYF@dell.com	9163409121	5	8789247162640096	2008/08	user1687	password	20	60000	M
1688	KGRJUM	JMSREUQJWU	5430779879 Dell Way	\N	EHIJNIQ	MI	38117	US	1	JMSREUQJWU@dell.com	5430779879	3	9348443041555584	2010/01	user1688	password	52	100000	F
1689	EHBRQO	JISEZCBTGI	6946391806 Dell Way	\N	CQWKGIT	PA	88131	US	1	JISEZCBTGI@dell.com	6946391806	2	9012516403570772	2008/03	user1689	password	30	40000	F
1690	GYCUIL	NNKPOEWXHN	8387232541 Dell Way	\N	TSTBLNY	CO	81685	US	1	NNKPOEWXHN@dell.com	8387232541	2	9865710050798954	2012/07	user1690	password	50	40000	F
1691	OAUANI	KDWPATWNNP	6171224826 Dell Way	\N	HPAUNDP	KS	41101	US	1	KDWPATWNNP@dell.com	6171224826	2	8790021755266935	2008/07	user1691	password	42	60000	M
1692	DPDLAG	IPHCMUPBBE	4532099697 Dell Way	\N	BWRELAN	AK	41246	US	1	IPHCMUPBBE@dell.com	4532099697	1	9188125074375422	2011/08	user1692	password	54	100000	F
1693	QHFXQU	ESGYIIANJW	5316115406 Dell Way	\N	FOHFCHO	MO	40745	US	1	ESGYIIANJW@dell.com	5316115406	2	9599751634523272	2012/01	user1693	password	29	80000	F
1694	JNADRS	KQBSQOCMTQ	4446267370 Dell Way	\N	UZTCOFL	AL	46757	US	1	KQBSQOCMTQ@dell.com	4446267370	1	5202714710962028	2010/08	user1694	password	78	100000	F
1695	VBUOLL	PEBEGOYXIY	7558717807 Dell Way	\N	QKMWVNG	GA	59487	US	1	PEBEGOYXIY@dell.com	7558717807	4	2596512890420854	2010/08	user1695	password	40	40000	M
1696	CYDNOI	PTODRMLPDW	4241180757 Dell Way	\N	CZRQGXE	WV	67980	US	1	PTODRMLPDW@dell.com	4241180757	3	3596337682567537	2011/12	user1696	password	89	80000	M
1697	CILKXE	ZAWMMMPIOP	8542199141 Dell Way	\N	AFVXKVO	PA	41297	US	1	ZAWMMMPIOP@dell.com	8542199141	3	3512079112231731	2012/03	user1697	password	29	100000	M
1698	PIKUIL	QVYDKHSAHX	3557639701 Dell Way	\N	VEHRTBA	NE	51941	US	1	QVYDKHSAHX@dell.com	3557639701	2	6982113935053349	2010/04	user1698	password	31	20000	M
1699	PWZBMU	AQFHIGOFCT	7344704622 Dell Way	\N	NTMOTBB	AL	51668	US	1	AQFHIGOFCT@dell.com	7344704622	3	8006333820521832	2012/07	user1699	password	49	60000	F
1700	LOWGOM	MVVSKBUDPN	9493570020 Dell Way	\N	QDGSEHE	VA	77575	US	1	MVVSKBUDPN@dell.com	9493570020	4	3507271068170667	2009/04	user1700	password	65	100000	M
1701	NBJANE	VFOXZSMMIQ	1503168006 Dell Way	\N	TBVAFSU	DC	54241	US	1	VFOXZSMMIQ@dell.com	1503168006	3	7836794284638018	2011/05	user1701	password	59	40000	F
1702	YGXDCD	SZCKLPTCJU	8713906547 Dell Way	\N	XJZPEDC	GA	71503	US	1	SZCKLPTCJU@dell.com	8713906547	5	1274996039923280	2010/02	user1702	password	49	40000	F
1703	IMNMFN	OPZEJBNDYX	1022994594 Dell Way	\N	DOBHQHZ	MS	27785	US	1	OPZEJBNDYX@dell.com	1022994594	5	4166567339561880	2010/04	user1703	password	73	80000	M
1704	HGZUVP	TZYUNCSLFG	3999435417 Dell Way	\N	NNXUMKZ	MO	40629	US	1	TZYUNCSLFG@dell.com	3999435417	5	6781022275332362	2008/09	user1704	password	50	40000	M
1705	LDTAWT	ZQHBJSGQGT	9391567732 Dell Way	\N	OAGYZSH	KS	68076	US	1	ZQHBJSGQGT@dell.com	9391567732	3	4025477877352387	2009/10	user1705	password	37	100000	M
1706	AVUUUL	BVVUCLAWAA	8378230503 Dell Way	\N	CYAVGJM	DE	80508	US	1	BVVUCLAWAA@dell.com	8378230503	3	6182866258546711	2008/05	user1706	password	55	20000	F
1707	IXYUYU	PTWBTTBUVA	5862889745 Dell Way	\N	VRGEELZ	WY	97794	US	1	PTWBTTBUVA@dell.com	5862889745	1	3917655015364289	2008/03	user1707	password	54	40000	F
1708	LDBGSU	DUOWWISWEJ	8572057106 Dell Way	\N	CIOOINN	TX	64431	US	1	DUOWWISWEJ@dell.com	8572057106	5	8165980740915985	2009/04	user1708	password	82	80000	F
1709	YADSDX	GATPSPTCSC	5997575940 Dell Way	\N	QGKEUGT	NJ	24138	US	1	GATPSPTCSC@dell.com	5997575940	5	4738836632110179	2010/10	user1709	password	76	40000	M
1710	YBYVIY	PXQERSXUJE	1233536644 Dell Way	\N	FNYLGOP	SD	58150	US	1	PXQERSXUJE@dell.com	1233536644	2	3586581319104880	2012/08	user1710	password	23	80000	M
1711	APAYEY	PJPIGKRLPE	8039231981 Dell Way	\N	JBLYQHM	NY	58488	US	1	PJPIGKRLPE@dell.com	8039231981	3	2424078861251473	2012/04	user1711	password	79	100000	M
1712	WVAULJ	KTQULBKQLL	1618509536 Dell Way	\N	CKCJXTX	NY	35027	US	1	KTQULBKQLL@dell.com	1618509536	3	5887026780750603	2012/05	user1712	password	46	80000	F
1713	KOQTZK	JUVKEMWQOG	3646913663 Dell Way	\N	SYDMWUT	VT	39434	US	1	JUVKEMWQOG@dell.com	3646913663	5	7479470441583545	2011/08	user1713	password	86	20000	F
1714	PVEZFY	VQDHMTWTLV	7511275309 Dell Way	\N	WYRRRPA	WV	48668	US	1	VQDHMTWTLV@dell.com	7511275309	4	1393117126077413	2011/09	user1714	password	34	40000	M
1715	KFUJBL	MJYGGRRBOQ	8161560745 Dell Way	\N	SFHIGHT	WI	93608	US	1	MJYGGRRBOQ@dell.com	8161560745	4	7044812121428550	2008/11	user1715	password	36	60000	F
1716	BUDNGN	LMTDEURUNX	9789622574 Dell Way	\N	CWDJPCH	MD	72827	US	1	LMTDEURUNX@dell.com	9789622574	3	6004075637087226	2009/11	user1716	password	64	40000	M
1717	UUXHGJ	AJOVAJJXMF	4383218355 Dell Way	\N	BWUDEFV	DC	66101	US	1	AJOVAJJXMF@dell.com	4383218355	2	5243310170713812	2008/09	user1717	password	24	80000	F
1718	ZBSJCB	YXBIGZULAR	5989086937 Dell Way	\N	GDVLYZC	KS	40712	US	1	YXBIGZULAR@dell.com	5989086937	2	1087305878289043	2011/02	user1718	password	52	80000	F
1719	EZIFYF	HGMGBYHSFK	8632188041 Dell Way	\N	NRJMTSV	IN	14004	US	1	HGMGBYHSFK@dell.com	8632188041	5	2694858087226748	2009/08	user1719	password	47	60000	M
1720	SSNYZT	LGVKNNPXBH	2913205252 Dell Way	\N	HOAZKIA	HI	37274	US	1	LGVKNNPXBH@dell.com	2913205252	3	9035947251133622	2011/01	user1720	password	52	40000	M
1721	ZHTTTZ	ODNCTKDASR	6418361389 Dell Way	\N	BRBKSIS	VT	87771	US	1	ODNCTKDASR@dell.com	6418361389	3	9195212794933468	2008/11	user1721	password	66	20000	F
1722	KVXKKB	XNUIQVAIXS	5484382414 Dell Way	\N	KHKSAIP	NJ	88809	US	1	XNUIQVAIXS@dell.com	5484382414	4	7839696166571230	2008/10	user1722	password	86	60000	M
1723	WZAXWN	SEEOFNLXXT	3582454476 Dell Way	\N	IQTQGJN	OR	14488	US	1	SEEOFNLXXT@dell.com	3582454476	5	8347508275881410	2009/06	user1723	password	48	20000	F
1724	LAHYSM	DHRQSPOMXF	5007979777 Dell Way	\N	FOLPBEQ	LA	15976	US	1	DHRQSPOMXF@dell.com	5007979777	3	5807741570752115	2012/09	user1724	password	88	40000	M
1725	GGKTKR	KAKZPXXUCL	1031252621 Dell Way	\N	GRNKIWM	PA	51742	US	1	KAKZPXXUCL@dell.com	1031252621	4	2256798654794693	2012/12	user1725	password	77	40000	F
1726	GZPYKP	IKFFHZITFA	7531955308 Dell Way	\N	GQIDCCP	CO	73997	US	1	IKFFHZITFA@dell.com	7531955308	1	6754595027305186	2010/04	user1726	password	78	80000	F
1727	KSSABC	FHKFPDLQJB	4442500811 Dell Way	\N	YMEABGT	SC	40339	US	1	FHKFPDLQJB@dell.com	4442500811	2	6845822643022985	2009/02	user1727	password	86	80000	M
1728	QQWTWD	DCTGNJPPIC	1133834413 Dell Way	\N	TIEACZJ	MN	38385	US	1	DCTGNJPPIC@dell.com	1133834413	4	4979033386334777	2012/04	user1728	password	37	80000	M
1729	DIVHLX	ASLKIBSKVB	3683856343 Dell Way	\N	OVDOFPW	HI	35011	US	1	ASLKIBSKVB@dell.com	3683856343	1	6252495189197362	2010/10	user1729	password	57	80000	F
1730	JAPHBH	TLPUDZQFOM	8116051332 Dell Way	\N	ICRYZXF	ID	18193	US	1	TLPUDZQFOM@dell.com	8116051332	5	8901556056924165	2009/07	user1730	password	18	80000	M
1731	PZPWTB	MOFMEKAQSD	2730012593 Dell Way	\N	IQDFWJI	NV	29733	US	1	MOFMEKAQSD@dell.com	2730012593	5	7945703617297114	2008/09	user1731	password	42	80000	M
1732	YQLZDZ	EPDOQUHUCY	3370275520 Dell Way	\N	XIUHQLM	TN	47271	US	1	EPDOQUHUCY@dell.com	3370275520	1	1868323464412242	2010/10	user1732	password	74	60000	F
1733	FMPERE	IFUDNOGLLO	2483598864 Dell Way	\N	FTFRFBB	MO	17181	US	1	IFUDNOGLLO@dell.com	2483598864	1	9034252204000952	2012/08	user1733	password	44	20000	F
1734	YIUDRZ	XUMMAYYPDR	8319608130 Dell Way	\N	UUXVWJX	AL	51415	US	1	XUMMAYYPDR@dell.com	8319608130	5	1587424309924245	2008/02	user1734	password	30	20000	F
1735	YGDYDX	LQYJONNGHI	1417240327 Dell Way	\N	DDFNBGZ	UT	29840	US	1	LQYJONNGHI@dell.com	1417240327	1	4126571969594807	2009/03	user1735	password	76	20000	F
1736	YCOVNE	TXTHLAOTDS	7859076099 Dell Way	\N	YRUFQRK	OH	74788	US	1	TXTHLAOTDS@dell.com	7859076099	5	8993729570414872	2010/01	user1736	password	39	60000	F
1737	VISACP	UJAUYUYQTP	7470090651 Dell Way	\N	LYGCJYV	CO	84903	US	1	UJAUYUYQTP@dell.com	7470090651	4	9085682338103652	2008/02	user1737	password	22	100000	F
1738	TWOJRY	KLWEJNXYYV	8646862503 Dell Way	\N	FBEDXHY	NJ	97620	US	1	KLWEJNXYYV@dell.com	8646862503	4	2246787871234119	2012/06	user1738	password	63	80000	F
1739	FAADLL	ZPVMNULJZN	9651250491 Dell Way	\N	OCKWBAV	VA	66983	US	1	ZPVMNULJZN@dell.com	9651250491	5	1974644721020013	2010/06	user1739	password	51	80000	M
1740	MXYYWO	TJBOVKNIZQ	5176162857 Dell Way	\N	SVRSQPJ	NH	45338	US	1	TJBOVKNIZQ@dell.com	5176162857	1	8887256098445506	2012/12	user1740	password	46	40000	M
1741	IITXCD	YQYJEGIUZE	3859403294 Dell Way	\N	MSVBBKL	MT	64535	US	1	YQYJEGIUZE@dell.com	3859403294	3	6242681162431837	2011/11	user1741	password	51	20000	F
1742	FYGJXX	IGBOPWOTIG	2572385967 Dell Way	\N	OJHZVVP	CT	33480	US	1	IGBOPWOTIG@dell.com	2572385967	5	1927482295781374	2011/11	user1742	password	38	100000	M
1743	OGSLOZ	MDOJRIRYXA	4689873979 Dell Way	\N	FXVBMZH	NV	82487	US	1	MDOJRIRYXA@dell.com	4689873979	2	7254693468101323	2011/03	user1743	password	56	40000	F
1744	GRYFEC	UNTDERAFXY	5612121910 Dell Way	\N	BYKAGBV	NY	43904	US	1	UNTDERAFXY@dell.com	5612121910	2	5934431723784656	2008/08	user1744	password	87	40000	F
1745	XMKZGX	TJCLKHJIII	7638437627 Dell Way	\N	TJPVEGE	NY	66341	US	1	TJCLKHJIII@dell.com	7638437627	4	2932179404422641	2011/12	user1745	password	51	80000	F
1746	WPSUJC	WUNEEVNMOW	2481824176 Dell Way	\N	BJAIOSY	IN	46984	US	1	WUNEEVNMOW@dell.com	2481824176	1	4555040074046701	2011/08	user1746	password	80	60000	F
1747	PHOREJ	EINAWZPSBY	3053550066 Dell Way	\N	SKNKIVV	MS	85378	US	1	EINAWZPSBY@dell.com	3053550066	1	4990347337909043	2008/08	user1747	password	65	80000	M
1748	FJCPNL	COHCDAECSO	7571704749 Dell Way	\N	PDXLZKH	GA	56323	US	1	COHCDAECSO@dell.com	7571704749	2	2348295933101326	2009/12	user1748	password	23	60000	F
1749	EEVQHK	YJNYOPRCFV	1286011423 Dell Way	\N	ZQVJYAW	NY	39259	US	1	YJNYOPRCFV@dell.com	1286011423	1	3628072422929108	2008/08	user1749	password	62	40000	M
1750	LYCVWM	IVAYMDDICU	8016613306 Dell Way	\N	DMSEJKM	MA	49694	US	1	IVAYMDDICU@dell.com	8016613306	3	1766313163097947	2009/10	user1750	password	84	100000	M
1751	ARQMAL	NYYQCGTWKF	5597582179 Dell Way	\N	POPZBZL	TN	52666	US	1	NYYQCGTWKF@dell.com	5597582179	2	3495739493053407	2010/01	user1751	password	19	60000	M
1752	QXTCKR	ABUHUQSAFG	4014163305 Dell Way	\N	PFIPQEB	DC	43844	US	1	ABUHUQSAFG@dell.com	4014163305	3	4884245259687305	2009/12	user1752	password	29	100000	M
1753	XCIPCJ	JKEZCFFJVL	6860617682 Dell Way	\N	RKCVLGF	SC	81883	US	1	JKEZCFFJVL@dell.com	6860617682	1	8063576661981643	2012/02	user1753	password	67	80000	F
1754	ZHIJQS	NQVSWENIWY	2834329393 Dell Way	\N	KSKQYEK	NH	38778	US	1	NQVSWENIWY@dell.com	2834329393	3	5125949997920543	2012/02	user1754	password	67	100000	F
1755	ZFBSSS	OLOTZWQXGI	3304861098 Dell Way	\N	HXHMHWU	MS	34377	US	1	OLOTZWQXGI@dell.com	3304861098	2	4419703832827509	2012/03	user1755	password	75	100000	F
1756	VRENFQ	CYQZONGXVD	7229230252 Dell Way	\N	EILBCYI	LA	39315	US	1	CYQZONGXVD@dell.com	7229230252	2	6162446701899171	2010/03	user1756	password	20	40000	M
1757	FWCWYA	MYPAEMWHRE	6137864021 Dell Way	\N	TSHRARZ	OH	96154	US	1	MYPAEMWHRE@dell.com	6137864021	1	2732223635073751	2011/06	user1757	password	24	100000	F
1758	ERHFDF	VEKHASYELR	3426482350 Dell Way	\N	MCRDCJC	NV	60386	US	1	VEKHASYELR@dell.com	3426482350	2	1480453690513968	2009/02	user1758	password	46	60000	M
1759	RTXXOB	HWCZVGKMTN	2261234072 Dell Way	\N	DWPNYHC	GA	59329	US	1	HWCZVGKMTN@dell.com	2261234072	3	6721258379518986	2010/02	user1759	password	47	40000	M
1760	IDKJLG	MLBTWOMJRI	5015472344 Dell Way	\N	ZFGGHLV	MI	11323	US	1	MLBTWOMJRI@dell.com	5015472344	5	1915565224364400	2012/03	user1760	password	86	20000	F
1761	INTPAE	QTAEFKWOJC	4369732682 Dell Way	\N	UQKGLVH	VT	83089	US	1	QTAEFKWOJC@dell.com	4369732682	4	1098197993822395	2009/11	user1761	password	42	80000	F
1762	CFLHWE	IBKSYYCAST	1646519916 Dell Way	\N	KZFGGCB	NM	87293	US	1	IBKSYYCAST@dell.com	1646519916	5	7819029565900565	2010/07	user1762	password	31	60000	M
1763	QURUCS	EVRDYRVRCV	6666751923 Dell Way	\N	XICAKSW	MO	68536	US	1	EVRDYRVRCV@dell.com	6666751923	5	3103008299134672	2012/05	user1763	password	20	60000	F
1764	SGHLLD	COCUKUXFRF	8977886599 Dell Way	\N	HRQAOCQ	FL	10234	US	1	COCUKUXFRF@dell.com	8977886599	1	4612495568580926	2012/06	user1764	password	61	80000	M
1765	XCDBER	DZCXWHOCPG	3228635463 Dell Way	\N	SPVVGAW	CT	12198	US	1	DZCXWHOCPG@dell.com	3228635463	1	5322027812711895	2012/09	user1765	password	31	80000	M
1766	IUZAXY	CVVJKXZQQO	9965130834 Dell Way	\N	MMUMIYN	NE	98192	US	1	CVVJKXZQQO@dell.com	9965130834	3	7071247902233154	2008/02	user1766	password	51	60000	M
1767	LNWJPR	FZBCYSTMFF	8863768350 Dell Way	\N	HROFFDF	GA	59609	US	1	FZBCYSTMFF@dell.com	8863768350	2	7433999798726291	2009/11	user1767	password	66	80000	F
1768	NDZFIY	HLXZEKFKRX	4103636873 Dell Way	\N	YXCCCHQ	WV	70632	US	1	HLXZEKFKRX@dell.com	4103636873	2	5972581620793790	2008/01	user1768	password	86	60000	F
1769	XTNWAY	TACDFMVCLT	7537001775 Dell Way	\N	FNVNDUE	MS	19904	US	1	TACDFMVCLT@dell.com	7537001775	3	2500728771556169	2011/01	user1769	password	43	60000	M
1770	WLVUFW	XJCKEFWYKJ	8585194201 Dell Way	\N	TXNOCAR	SD	57786	US	1	XJCKEFWYKJ@dell.com	8585194201	3	6243528292048723	2008/01	user1770	password	46	20000	M
1771	FWSCUC	EEHKAFVKYS	1538072661 Dell Way	\N	YNVYFQM	AR	20416	US	1	EEHKAFVKYS@dell.com	1538072661	2	2594862862490117	2010/04	user1771	password	68	80000	F
1772	KTYMYD	TIDZEOYWML	6673926664 Dell Way	\N	SKQIXRL	WI	93685	US	1	TIDZEOYWML@dell.com	6673926664	3	3100047739688307	2009/01	user1772	password	47	80000	M
1773	JFUMZD	QYHEWEQIWB	8411651950 Dell Way	\N	ZFZRRYP	IN	40100	US	1	QYHEWEQIWB@dell.com	8411651950	4	4702305209357292	2009/05	user1773	password	36	60000	M
1774	ABOERN	LVJQMSMORS	2884666774 Dell Way	\N	NIJMXRU	PA	35246	US	1	LVJQMSMORS@dell.com	2884666774	5	6597867154981942	2010/07	user1774	password	31	60000	M
1775	TRGGDC	PTPIGEZYSI	9085236437 Dell Way	\N	IEGZZZH	DE	96294	US	1	PTPIGEZYSI@dell.com	9085236437	4	5558628269471229	2008/02	user1775	password	25	100000	M
1776	JBXMRR	BZXGZWYHEC	9749205536 Dell Way	\N	NEBNMGM	LA	88182	US	1	BZXGZWYHEC@dell.com	9749205536	3	9977674381807448	2008/04	user1776	password	75	60000	F
1777	SXZJZY	HFXDEFIGSN	4866667000 Dell Way	\N	IFZORIL	NV	80596	US	1	HFXDEFIGSN@dell.com	4866667000	4	1392877386882901	2009/03	user1777	password	43	100000	F
1778	IHBHOH	ESLJBSCOAI	7391727497 Dell Way	\N	OPAWARR	MI	45174	US	1	ESLJBSCOAI@dell.com	7391727497	4	6028144988697023	2008/08	user1778	password	64	40000	M
1779	RRMZWE	KGGCIUDQIS	3298227706 Dell Way	\N	QFSHWES	NH	84561	US	1	KGGCIUDQIS@dell.com	3298227706	4	4825487066525966	2012/01	user1779	password	41	60000	M
1780	UOOZYU	FBDAEUIWKO	9919637866 Dell Way	\N	OSLTKAO	NY	72200	US	1	FBDAEUIWKO@dell.com	9919637866	3	7642488814890385	2009/02	user1780	password	50	20000	M
1781	ACQVHS	YHWSQSDEHW	1827167272 Dell Way	\N	QAHRPYJ	NH	57612	US	1	YHWSQSDEHW@dell.com	1827167272	5	7107358947396279	2010/01	user1781	password	45	60000	F
1782	AJJSIR	PAHHEMPADQ	5381439391 Dell Way	\N	IUFHDVV	HI	73876	US	1	PAHHEMPADQ@dell.com	5381439391	4	7418514102697373	2012/04	user1782	password	76	100000	M
1783	EPAVFB	DMFQCGTSPO	2430551765 Dell Way	\N	YWRTRXL	DC	72317	US	1	DMFQCGTSPO@dell.com	2430551765	1	1207282797433435	2012/11	user1783	password	71	20000	M
1784	TZSUDF	ATHHNZWCYS	4616678201 Dell Way	\N	TRKRCOJ	ID	59945	US	1	ATHHNZWCYS@dell.com	4616678201	2	5168872781097889	2008/05	user1784	password	89	100000	F
1785	SRLXSF	FZTFWVDPPU	5710972695 Dell Way	\N	ZHXNREB	AR	43980	US	1	FZTFWVDPPU@dell.com	5710972695	1	7567694020923228	2010/01	user1785	password	22	40000	M
1786	NDLSIL	MNHHRWWLVE	6352893608 Dell Way	\N	IIVMKWW	WA	14861	US	1	MNHHRWWLVE@dell.com	6352893608	3	2032233232166618	2011/08	user1786	password	80	20000	M
1787	HWCSJQ	AQHXNSTRBC	5699436250 Dell Way	\N	MOMJKKK	AK	86630	US	1	AQHXNSTRBC@dell.com	5699436250	4	5522292036097497	2009/10	user1787	password	38	80000	M
1788	JKBAKR	IIFBBWCDJQ	4477083961 Dell Way	\N	QSBADBW	NM	76191	US	1	IIFBBWCDJQ@dell.com	4477083961	1	5994525313377381	2011/09	user1788	password	36	20000	F
1789	HBNZJV	EKWBNALEQD	6377392947 Dell Way	\N	GRGHOXB	WA	93605	US	1	EKWBNALEQD@dell.com	6377392947	4	6553652699571103	2012/08	user1789	password	69	20000	M
1790	FDCBIN	YKAYVFPZLG	7309970883 Dell Way	\N	GTUEUTC	MA	40508	US	1	YKAYVFPZLG@dell.com	7309970883	2	9916028287727388	2010/05	user1790	password	69	80000	M
1791	URWIPH	INCNCCYJIS	2985172729 Dell Way	\N	EMMXOVF	ID	16058	US	1	INCNCCYJIS@dell.com	2985172729	4	5046528209000826	2012/04	user1791	password	89	80000	M
1792	VBOCKC	FXFHWOQOSD	4622504482 Dell Way	\N	BPRXVYY	AR	66916	US	1	FXFHWOQOSD@dell.com	4622504482	5	9358056288212540	2009/09	user1792	password	82	40000	M
1793	LIDNOB	SWYHMNZPPP	8347434058 Dell Way	\N	HMKGKLX	SD	49040	US	1	SWYHMNZPPP@dell.com	8347434058	1	2324940732214600	2011/06	user1793	password	84	20000	M
1794	BRIDKE	CRRQQHFFOR	6936547067 Dell Way	\N	QVCCSXN	NC	18698	US	1	CRRQQHFFOR@dell.com	6936547067	2	5655364715028555	2010/05	user1794	password	38	80000	F
1795	PTLTWC	KMTSRZHJPC	9474921652 Dell Way	\N	LRVIEJL	TN	63734	US	1	KMTSRZHJPC@dell.com	9474921652	3	9844597570598126	2009/01	user1795	password	20	100000	M
1796	MORPZD	IRVHYEXBPO	8390799971 Dell Way	\N	WYTGJOV	IN	97991	US	1	IRVHYEXBPO@dell.com	8390799971	3	1130540149752050	2012/04	user1796	password	77	40000	M
1797	MYWPGN	LOMPLOFALD	3694641984 Dell Way	\N	TRMHNUH	KY	36174	US	1	LOMPLOFALD@dell.com	3694641984	2	6422626713756472	2008/07	user1797	password	52	60000	F
1798	IFTWQH	JGTXLTJPMA	7687691978 Dell Way	\N	BUOWCXD	MA	18640	US	1	JGTXLTJPMA@dell.com	7687691978	3	6749254233669490	2009/02	user1798	password	26	60000	F
1799	WKYEUE	XRQRBFEBGZ	3347164127 Dell Way	\N	QDCNGMQ	AK	97714	US	1	XRQRBFEBGZ@dell.com	3347164127	2	1620005798526108	2009/10	user1799	password	44	40000	F
1800	HKYMHQ	CZRHETODJR	7639954127 Dell Way	\N	FXYSNYR	SC	23487	US	1	CZRHETODJR@dell.com	7639954127	1	9235062357503922	2008/05	user1800	password	24	40000	M
1801	BWCRYB	IFFCUJMLPJ	4303738630 Dell Way	\N	JHXHYRL	OH	86126	US	1	IFFCUJMLPJ@dell.com	4303738630	4	3102648212574422	2010/03	user1801	password	18	60000	F
1802	CEZDNF	JPZTBLILUQ	1991838108 Dell Way	\N	ICPAOHW	WA	18363	US	1	JPZTBLILUQ@dell.com	1991838108	2	3586441634688526	2008/11	user1802	password	42	40000	F
1803	IJOOSE	OMGZVRULAX	7380464130 Dell Way	\N	ABLIYJK	AR	78143	US	1	OMGZVRULAX@dell.com	7380464130	1	6756469581276179	2008/05	user1803	password	68	40000	M
1804	GYLKMX	RLSJFEKCFL	3948719035 Dell Way	\N	ONKYYLR	NV	64782	US	1	RLSJFEKCFL@dell.com	3948719035	4	9838645732030272	2008/02	user1804	password	69	40000	F
1805	ESNBJY	USEZCHEOWS	9697872384 Dell Way	\N	YUQJMHZ	SC	11388	US	1	USEZCHEOWS@dell.com	9697872384	5	1974308460019529	2011/02	user1805	password	27	100000	M
1806	QXDPSW	TRYBVMXNLR	6349297294 Dell Way	\N	EVDMUYM	PA	76701	US	1	TRYBVMXNLR@dell.com	6349297294	3	8437689980957658	2011/04	user1806	password	62	40000	F
1807	TYWPSN	OTJBQWMIBH	9500660272 Dell Way	\N	LNCJZWD	NH	36229	US	1	OTJBQWMIBH@dell.com	9500660272	2	6014117861166597	2010/09	user1807	password	70	40000	M
1808	PXIDMC	MNSJAAKIMX	1993597616 Dell Way	\N	KWXGZNO	WA	84479	US	1	MNSJAAKIMX@dell.com	1993597616	3	5616352609358728	2012/10	user1808	password	28	60000	M
1809	MODOBR	HKRIUZVSKR	5268314804 Dell Way	\N	QRRDFPY	KS	15732	US	1	HKRIUZVSKR@dell.com	5268314804	1	8598644210025669	2011/08	user1809	password	56	20000	F
1810	RREJYP	AHKACCKUSC	9379436507 Dell Way	\N	LWHAVPC	IN	79366	US	1	AHKACCKUSC@dell.com	9379436507	5	4239922436885536	2010/01	user1810	password	54	20000	M
1811	RNQHNX	ROATZUMBGJ	1856761115 Dell Way	\N	JGEZIMT	ID	46494	US	1	ROATZUMBGJ@dell.com	1856761115	4	4803616334218532	2011/11	user1811	password	25	40000	F
1812	TOXRGM	RALMNNSWWY	4289413602 Dell Way	\N	BVHNOOY	NV	37738	US	1	RALMNNSWWY@dell.com	4289413602	2	2716510282363742	2010/07	user1812	password	59	40000	F
1813	MWJZNJ	LAWYSTVRUR	1252616576 Dell Way	\N	YIFNGXV	NM	24447	US	1	LAWYSTVRUR@dell.com	1252616576	1	7498547498136760	2011/04	user1813	password	80	20000	F
1814	FBSPMS	MLKFGBZXAI	9188490604 Dell Way	\N	DOPAKFE	ME	39700	US	1	MLKFGBZXAI@dell.com	9188490604	1	6745333950500936	2011/02	user1814	password	77	100000	F
1815	NPRFBC	QHJSHGSPKH	4472707111 Dell Way	\N	EKRKPCT	MT	19923	US	1	QHJSHGSPKH@dell.com	4472707111	2	3018443340901285	2008/04	user1815	password	47	80000	M
1816	BYYEOF	NGMUZBEGGP	4073549751 Dell Way	\N	XRFAKSD	SD	10141	US	1	NGMUZBEGGP@dell.com	4073549751	5	3483733606990427	2011/09	user1816	password	28	100000	M
1817	BZEGML	SGKUKRBZOS	2718105731 Dell Way	\N	FPDXSYX	AR	94231	US	1	SGKUKRBZOS@dell.com	2718105731	4	6770112574566156	2009/08	user1817	password	37	40000	M
1818	LQAXJG	HERYFRNXWD	6118075027 Dell Way	\N	BUVZSWY	VA	68143	US	1	HERYFRNXWD@dell.com	6118075027	2	3082724835257977	2012/08	user1818	password	74	40000	F
1819	UEQBMU	TLAKZYHCZB	7034998467 Dell Way	\N	YZUUXRL	MO	89910	US	1	TLAKZYHCZB@dell.com	7034998467	2	5500640054699034	2010/08	user1819	password	73	40000	M
1820	KIHFBT	FMTDTVDVUC	7083467292 Dell Way	\N	QOAHAME	NY	81431	US	1	FMTDTVDVUC@dell.com	7083467292	1	4646926624700427	2010/05	user1820	password	33	100000	M
1821	NATGGF	ZKZVNVPQME	3733708421 Dell Way	\N	QTECYWX	NH	98811	US	1	ZKZVNVPQME@dell.com	3733708421	1	4276317720767111	2010/11	user1821	password	22	20000	M
1822	VGEBGO	ACBWRRIWIC	3256136307 Dell Way	\N	BKAXIQX	NJ	70079	US	1	ACBWRRIWIC@dell.com	3256136307	1	5914005704689771	2009/02	user1822	password	51	20000	F
1823	QEREFT	GBKYKHGNIR	4404221917 Dell Way	\N	NFZECPV	LA	75734	US	1	GBKYKHGNIR@dell.com	4404221917	4	8867033080663533	2012/10	user1823	password	38	60000	M
1824	YQDRXF	CVQJCDRTRX	9454863108 Dell Way	\N	TWAIRJB	AR	13020	US	1	CVQJCDRTRX@dell.com	9454863108	5	8337275019846857	2009/05	user1824	password	73	20000	F
1825	XVXCXT	SHVWZPOWIK	2002732063 Dell Way	\N	XRBGSDH	NY	12753	US	1	SHVWZPOWIK@dell.com	2002732063	5	4572891905903816	2012/01	user1825	password	48	80000	M
1826	IWUCOB	YLBNZYWKVN	1185047896 Dell Way	\N	LCGPJXQ	MS	82795	US	1	YLBNZYWKVN@dell.com	1185047896	2	8698471339885146	2010/02	user1826	password	71	80000	M
1827	NWNPUZ	QHYODIKRUM	5490112002 Dell Way	\N	XKWVAJQ	AR	74372	US	1	QHYODIKRUM@dell.com	5490112002	3	8432170371990652	2009/03	user1827	password	75	80000	F
1828	IIWHZE	GOHPYZKLXU	2771287591 Dell Way	\N	HSURJVJ	UT	38778	US	1	GOHPYZKLXU@dell.com	2771287591	1	6020345908589662	2012/11	user1828	password	65	40000	F
1829	NPERVS	ZKRYUCVOKO	1932073529 Dell Way	\N	JBYFLUO	NM	90743	US	1	ZKRYUCVOKO@dell.com	1932073529	4	7655432824511082	2011/11	user1829	password	85	40000	F
1830	CXIVXS	MVNPRCAGLC	6425541055 Dell Way	\N	ERNZGEW	KY	79868	US	1	MVNPRCAGLC@dell.com	6425541055	1	7190448992419989	2010/05	user1830	password	30	80000	F
1831	MLDFXZ	SNQUOWGQAY	7994004652 Dell Way	\N	DAEIWNC	MN	62611	US	1	SNQUOWGQAY@dell.com	7994004652	5	9288630648050458	2012/08	user1831	password	30	60000	F
1832	IQYHIM	XDAUJRVHVV	5269524388 Dell Way	\N	MDSZFEO	WY	24300	US	1	XDAUJRVHVV@dell.com	5269524388	5	7912772268056870	2011/05	user1832	password	76	100000	F
1833	TGJGEM	HYWYUETPQW	4552948910 Dell Way	\N	HPCMECQ	NM	13034	US	1	HYWYUETPQW@dell.com	4552948910	2	4792099071200937	2009/03	user1833	password	50	100000	F
1834	VFQINP	ELJJFZACHQ	7458151414 Dell Way	\N	ETUGJLH	RI	73871	US	1	ELJJFZACHQ@dell.com	7458151414	5	9588267199229450	2008/12	user1834	password	49	100000	F
1835	CHRRMC	BWHAWJHMOA	4228191095 Dell Way	\N	HVKSDEK	TN	23248	US	1	BWHAWJHMOA@dell.com	4228191095	1	1751709079835564	2011/12	user1835	password	35	100000	F
1836	XOUAPR	HPNRXAGYHB	7737154737 Dell Way	\N	IZENJAR	OR	12719	US	1	HPNRXAGYHB@dell.com	7737154737	3	1182102877181023	2012/05	user1836	password	41	100000	M
1837	CXOTFD	HXAHDYPFHO	5362127935 Dell Way	\N	KVYLMRM	HI	30431	US	1	HXAHDYPFHO@dell.com	5362127935	2	6762278001289815	2012/02	user1837	password	61	100000	M
1838	DRFHZC	IHFHWLPKWK	9336846837 Dell Way	\N	JHWBTCH	HI	39753	US	1	IHFHWLPKWK@dell.com	9336846837	1	4945062576327473	2010/12	user1838	password	49	80000	M
1839	QYPSHW	YOSKDDGNNN	3515155446 Dell Way	\N	KOHNWNV	SC	59560	US	1	YOSKDDGNNN@dell.com	3515155446	2	5490336080547422	2011/12	user1839	password	27	40000	M
1840	SBFPAT	IKWLRKZFUO	1382366941 Dell Way	\N	MIKZDFO	ME	56279	US	1	IKWLRKZFUO@dell.com	1382366941	1	5466421974357218	2008/06	user1840	password	49	100000	M
1841	QMPKUA	GGRRFWMUJU	4599530067 Dell Way	\N	EJYKXJX	WA	55583	US	1	GGRRFWMUJU@dell.com	4599530067	1	1043728074524551	2012/12	user1841	password	60	60000	F
1842	EWGEDN	WUTTGNCASL	8531411112 Dell Way	\N	ZCJIZHV	MD	45318	US	1	WUTTGNCASL@dell.com	8531411112	2	4476754389237613	2010/09	user1842	password	80	60000	M
1843	DURQQM	JKSWNTOYTR	4398243239 Dell Way	\N	IBRPXBZ	OR	34969	US	1	JKSWNTOYTR@dell.com	4398243239	1	9733190393075348	2009/09	user1843	password	56	40000	M
1844	FZDRJO	KFBEUAXMIZ	4848097669 Dell Way	\N	DXWEXPL	IL	75341	US	1	KFBEUAXMIZ@dell.com	4848097669	3	5086676904931665	2012/11	user1844	password	87	20000	M
1845	CVFQFL	RJFRHSAGVX	8766705802 Dell Way	\N	CAVRLCK	VA	65381	US	1	RJFRHSAGVX@dell.com	8766705802	5	5372169681824744	2012/12	user1845	password	42	100000	M
1846	OOAZGK	FYRXYXSWAS	8909892655 Dell Way	\N	RSEUCBK	WV	92037	US	1	FYRXYXSWAS@dell.com	8909892655	4	9057908273302020	2009/09	user1846	password	68	80000	F
1847	STNCYM	UVKROHSHYK	4081722932 Dell Way	\N	LTNNDML	AK	35449	US	1	UVKROHSHYK@dell.com	4081722932	2	9971739214845004	2008/12	user1847	password	38	80000	M
1848	VVRHPM	SHAZAIYKUS	7333409949 Dell Way	\N	YIVLTVS	CO	16034	US	1	SHAZAIYKUS@dell.com	7333409949	1	1529224146157503	2012/11	user1848	password	75	80000	M
1849	LCIYUQ	ZUQHTBBLZJ	2995036964 Dell Way	\N	GKDCCFE	SD	41821	US	1	ZUQHTBBLZJ@dell.com	2995036964	4	3071438430808484	2008/08	user1849	password	86	60000	M
1850	GJLXIG	NPZORKOARY	9529661829 Dell Way	\N	DTBJYWS	DC	68904	US	1	NPZORKOARY@dell.com	9529661829	1	3155947791878134	2012/08	user1850	password	84	20000	M
1851	JBIPOX	PDPZRPRQTL	4814523625 Dell Way	\N	RDJNVNE	SC	70041	US	1	PDPZRPRQTL@dell.com	4814523625	4	3412228211294860	2009/11	user1851	password	35	80000	M
1852	OHMMWP	BWHRNXLYOO	7900181178 Dell Way	\N	ICKVHFM	OH	89097	US	1	BWHRNXLYOO@dell.com	7900181178	1	7506126850843430	2008/09	user1852	password	63	60000	F
1853	CAXRCT	ZTHWFGLTON	9713301289 Dell Way	\N	EKUJXNG	NV	58475	US	1	ZTHWFGLTON@dell.com	9713301289	4	3343560923822224	2010/03	user1853	password	37	80000	F
1854	EJIXIC	FFILQCZDGK	3339138024 Dell Way	\N	YPHLWYZ	TN	65183	US	1	FFILQCZDGK@dell.com	3339138024	3	8536110388580711	2010/02	user1854	password	24	80000	F
1855	LPUOUZ	WGPYGTEQSU	3822939731 Dell Way	\N	XERWEMM	ME	91404	US	1	WGPYGTEQSU@dell.com	3822939731	5	9939122643787416	2010/08	user1855	password	50	100000	F
1856	FJBFGH	UENOJEGECL	2880504405 Dell Way	\N	VYPIKAF	OR	98234	US	1	UENOJEGECL@dell.com	2880504405	1	6708752940408886	2011/12	user1856	password	83	100000	F
1857	YCPGWU	ULDYSIADDZ	4232187239 Dell Way	\N	SLKTRDS	UT	35458	US	1	ULDYSIADDZ@dell.com	4232187239	3	3368968446273357	2009/05	user1857	password	63	40000	F
1858	GMJAGU	EFNMGQPFJB	3917121980 Dell Way	\N	QCSUVOB	FL	17843	US	1	EFNMGQPFJB@dell.com	3917121980	3	5367123885080219	2012/08	user1858	password	88	20000	F
1859	IFJDJO	QVVHLBQMRT	3973667418 Dell Way	\N	EMOTNTV	TX	26873	US	1	QVVHLBQMRT@dell.com	3973667418	5	8537361580412836	2009/12	user1859	password	87	80000	F
1860	ITOXKK	SRVTHILANX	4163771166 Dell Way	\N	PHLIDHN	MN	17195	US	1	SRVTHILANX@dell.com	4163771166	4	1597860797774046	2009/05	user1860	password	36	80000	F
1861	VNNFFE	BZMKLMYIBF	2706667983 Dell Way	\N	TKIBXUD	ID	59393	US	1	BZMKLMYIBF@dell.com	2706667983	3	9314685517456384	2010/03	user1861	password	21	40000	M
1862	OMXTOX	FYIRWQTCKD	7212968391 Dell Way	\N	KLBFOHT	PA	87198	US	1	FYIRWQTCKD@dell.com	7212968391	2	1309246998280286	2011/06	user1862	password	70	40000	M
1863	QBNNGL	VYIMSKWVVI	1730462464 Dell Way	\N	XBXEVRB	MT	87747	US	1	VYIMSKWVVI@dell.com	1730462464	2	4040144774597138	2012/07	user1863	password	39	60000	M
1864	UYWGTV	PGNACJWLGY	2593450591 Dell Way	\N	ILTZNGV	NE	57514	US	1	PGNACJWLGY@dell.com	2593450591	2	1873763361480087	2010/10	user1864	password	70	40000	M
1865	PONLDT	ZEWIAHPYPB	6377502612 Dell Way	\N	SPOZLDN	NH	56962	US	1	ZEWIAHPYPB@dell.com	6377502612	1	4011997019406408	2009/05	user1865	password	24	100000	M
1866	PJBJIF	GQGNGEDIXS	8802321833 Dell Way	\N	WWEAJTN	WI	85251	US	1	GQGNGEDIXS@dell.com	8802321833	2	2723965381737798	2012/03	user1866	password	24	60000	M
1867	DYWIEN	OSUTWCQPYN	5708049045 Dell Way	\N	TZWMMVI	LA	19509	US	1	OSUTWCQPYN@dell.com	5708049045	2	3702651856467128	2011/11	user1867	password	79	80000	M
1868	SCAFQT	ZKPBBEAOXZ	6939362343 Dell Way	\N	LKMGTWJ	ID	26053	US	1	ZKPBBEAOXZ@dell.com	6939362343	5	1671168897766620	2010/08	user1868	password	84	40000	M
1869	YKIRKT	GMULMJIMUT	1784121970 Dell Way	\N	ZAMVKTA	AR	64732	US	1	GMULMJIMUT@dell.com	1784121970	3	2996785990893841	2008/10	user1869	password	84	100000	F
1870	GQPAXB	UIOERBYKAZ	5215761952 Dell Way	\N	XWJQWKG	WV	97039	US	1	UIOERBYKAZ@dell.com	5215761952	5	7580194447655231	2009/12	user1870	password	84	80000	M
1871	NQLPLT	DPLFOWGNTC	9821858854 Dell Way	\N	WKZHQZG	CO	94794	US	1	DPLFOWGNTC@dell.com	9821858854	3	8752234052866698	2012/02	user1871	password	47	60000	M
1872	VZGPDV	AIKWPXQSUA	5181008217 Dell Way	\N	SBQRHTP	IL	31666	US	1	AIKWPXQSUA@dell.com	5181008217	1	4341078743804246	2012/08	user1872	password	29	80000	M
1873	JHSFIB	PFQNVIHVAI	8633757980 Dell Way	\N	MRQGHYM	PA	19327	US	1	PFQNVIHVAI@dell.com	8633757980	4	7237127769272775	2012/04	user1873	password	37	40000	M
1874	ZPYBFD	RTYAAUBJHS	7511450612 Dell Way	\N	ANAYZUA	TN	46151	US	1	RTYAAUBJHS@dell.com	7511450612	5	7554178746882827	2012/03	user1874	password	43	100000	M
1875	HABLSU	KSVETELMEZ	4670127213 Dell Way	\N	NCYHDUR	UT	66814	US	1	KSVETELMEZ@dell.com	4670127213	5	8654978499282152	2011/11	user1875	password	67	20000	M
1876	TMONWG	IBANNMSMZV	7463057786 Dell Way	\N	LHYGYVW	LA	70184	US	1	IBANNMSMZV@dell.com	7463057786	1	5549169333651662	2009/03	user1876	password	44	20000	M
1877	XRNEZP	FNCRFPRAAY	9623559420 Dell Way	\N	ZGXUDGL	TN	44300	US	1	FNCRFPRAAY@dell.com	9623559420	2	5958157601766289	2009/05	user1877	password	32	40000	F
1878	TKAIPN	KHTZZUAYTG	1255131457 Dell Way	\N	VNKCZGM	WA	52830	US	1	KHTZZUAYTG@dell.com	1255131457	2	8620915970299394	2009/06	user1878	password	81	100000	M
1879	XHNLRV	ERUYSSSYOF	9208183852 Dell Way	\N	JQFPDDB	DC	47023	US	1	ERUYSSSYOF@dell.com	9208183852	2	9164507767185570	2011/05	user1879	password	77	80000	M
1880	ICIDHA	YGSRYQFEAW	8573388056 Dell Way	\N	JPZNRDY	NE	56115	US	1	YGSRYQFEAW@dell.com	8573388056	2	8758232310414315	2011/01	user1880	password	53	100000	F
1881	VDLVCR	NTPEYTEUDT	3387683589 Dell Way	\N	TRLXPZK	MI	42141	US	1	NTPEYTEUDT@dell.com	3387683589	1	4550568534061313	2011/02	user1881	password	57	60000	F
1882	ZJIQWB	GAZAFUDZNU	2235992298 Dell Way	\N	KLKKVVT	CA	92908	US	1	GAZAFUDZNU@dell.com	2235992298	5	1084390975069254	2011/05	user1882	password	35	80000	M
1883	OHRPNS	ONXIRWWMGH	6506376397 Dell Way	\N	WQDRKFP	MT	16417	US	1	ONXIRWWMGH@dell.com	6506376397	2	5378881595563144	2012/11	user1883	password	38	60000	F
1884	YZQROE	OXVLUHSCEJ	1013992518 Dell Way	\N	FVTLLHN	AR	52693	US	1	OXVLUHSCEJ@dell.com	1013992518	5	3917049163021147	2009/04	user1884	password	51	40000	F
1885	CXWHLU	DXOLPRPYXL	7951459658 Dell Way	\N	SIWZVXL	TX	83761	US	1	DXOLPRPYXL@dell.com	7951459658	1	2123605628497898	2009/05	user1885	password	49	40000	F
1886	HQSBTP	QEFITEFFWN	9253875476 Dell Way	\N	BWJZHFU	AZ	40749	US	1	QEFITEFFWN@dell.com	9253875476	2	7277066138107330	2009/08	user1886	password	86	80000	F
1887	QSAGJF	MRZQWENKFJ	1158768253 Dell Way	\N	TERZZTI	VA	13903	US	1	MRZQWENKFJ@dell.com	1158768253	2	7144436514005066	2012/11	user1887	password	87	80000	M
1888	ZWYEIQ	DZMHMWNWQS	9904284143 Dell Way	\N	NQRGYPH	WI	84466	US	1	DZMHMWNWQS@dell.com	9904284143	5	7344103476498277	2012/07	user1888	password	39	100000	F
1889	GBSWFR	IMDFAZWSNM	5573506457 Dell Way	\N	KUKZCJU	AZ	34234	US	1	IMDFAZWSNM@dell.com	5573506457	1	8098448614589871	2012/11	user1889	password	30	20000	M
1890	WXENGR	RLRRHJETTZ	6219231158 Dell Way	\N	ETBNODU	AR	23384	US	1	RLRRHJETTZ@dell.com	6219231158	5	1567448193673044	2011/11	user1890	password	21	80000	M
1891	FDAXVM	OMUYRNSQSL	1508544872 Dell Way	\N	SFZVAAZ	NH	89998	US	1	OMUYRNSQSL@dell.com	1508544872	2	8057874524500222	2008/12	user1891	password	60	40000	F
1892	PFXCTK	WRCKKTCVLI	5620231678 Dell Way	\N	UHIVHYS	KY	35238	US	1	WRCKKTCVLI@dell.com	5620231678	3	3121599624399096	2008/10	user1892	password	42	80000	M
1893	GUSRQK	TAUMCQYLLF	3073168568 Dell Way	\N	UGNSZWZ	MS	35920	US	1	TAUMCQYLLF@dell.com	3073168568	3	1414332774933427	2010/04	user1893	password	18	100000	F
1894	SMSDFS	YRVOQGZVBG	5728790962 Dell Way	\N	ITGETTM	WV	40939	US	1	YRVOQGZVBG@dell.com	5728790962	3	6719986073672772	2010/05	user1894	password	69	40000	M
1895	KKACIS	YWJFWEGCNZ	1624361249 Dell Way	\N	ISTCFSL	OR	33523	US	1	YWJFWEGCNZ@dell.com	1624361249	2	6561112027615309	2011/07	user1895	password	50	20000	M
1896	MGGFFD	OKZTQCHQLZ	9595543001 Dell Way	\N	JNFBZYI	AL	26482	US	1	OKZTQCHQLZ@dell.com	9595543001	5	7324871296063066	2009/12	user1896	password	63	100000	F
1897	WCLAQV	ZKMCRCORLC	6951718354 Dell Way	\N	WNBUWCY	SD	90385	US	1	ZKMCRCORLC@dell.com	6951718354	2	8792273721192033	2009/02	user1897	password	25	20000	F
1898	ODVKDF	WGWYUNJWJX	7774791184 Dell Way	\N	XDTZCOX	RI	79930	US	1	WGWYUNJWJX@dell.com	7774791184	1	8787370467092843	2012/03	user1898	password	20	60000	F
1899	WUMBQT	YPNLZKVWHZ	8483087181 Dell Way	\N	QHBEEVZ	WA	89720	US	1	YPNLZKVWHZ@dell.com	8483087181	4	1749198301695287	2012/03	user1899	password	49	80000	M
1900	YUQRSF	EEFOZBWYRE	8547718708 Dell Way	\N	AWIWVHT	NY	15625	US	1	EEFOZBWYRE@dell.com	8547718708	3	3360842966474593	2009/04	user1900	password	36	20000	F
1901	XWUDBZ	IQYJNXBRYY	6433100815 Dell Way	\N	AVTHPLI	ME	97577	US	1	IQYJNXBRYY@dell.com	6433100815	4	3200944408774376	2012/11	user1901	password	40	80000	M
1902	CXUBFK	APXYQPXOPS	9932233930 Dell Way	\N	IWHUFST	SD	46577	US	1	APXYQPXOPS@dell.com	9932233930	4	3596694885753095	2009/06	user1902	password	20	60000	F
1903	VMNGND	EMTTJIJCRF	8400045160 Dell Way	\N	KLLDFGN	GA	93606	US	1	EMTTJIJCRF@dell.com	8400045160	3	4310493195895106	2012/11	user1903	password	68	80000	F
1904	FYXJCJ	CWTLFWDKGP	4554618527 Dell Way	\N	WKUCYAA	PA	55774	US	1	CWTLFWDKGP@dell.com	4554618527	4	4801787796895951	2008/04	user1904	password	77	40000	F
1905	SRHCUD	WGISJTZZPJ	7479875844 Dell Way	\N	USHUSBH	CT	68335	US	1	WGISJTZZPJ@dell.com	7479875844	2	9352414408233018	2010/07	user1905	password	27	40000	F
1906	LJZOGF	XZPRYOGIJZ	3270531094 Dell Way	\N	QDSRLVI	DE	12090	US	1	XZPRYOGIJZ@dell.com	3270531094	4	5953853695653380	2009/12	user1906	password	72	100000	F
1907	SKPYHO	NZNCGVLFMP	3589229179 Dell Way	\N	XDASMET	OK	88657	US	1	NZNCGVLFMP@dell.com	3589229179	1	8559487944003195	2008/12	user1907	password	31	80000	F
1908	URQIFP	VHVRSBDHYH	2861866757 Dell Way	\N	IQTMKLJ	NY	60021	US	1	VHVRSBDHYH@dell.com	2861866757	4	5261198451276869	2009/06	user1908	password	75	20000	F
1909	KMIZIP	VAIWDQUKYL	6726314766 Dell Way	\N	DLVPUNE	AK	30696	US	1	VAIWDQUKYL@dell.com	6726314766	2	7187896790914238	2010/07	user1909	password	77	100000	F
1910	DUKTQK	CMOSHYQSCC	1064923502 Dell Way	\N	OSXCWXI	MT	36455	US	1	CMOSHYQSCC@dell.com	1064923502	5	8740964039228857	2012/09	user1910	password	85	100000	M
1911	ITESVR	GNYFERIGGA	2772102123 Dell Way	\N	DIXBQKI	NV	41146	US	1	GNYFERIGGA@dell.com	2772102123	3	1851508008781820	2008/06	user1911	password	65	60000	F
1912	VDAMKN	KQSCYZIYDQ	7466685906 Dell Way	\N	WEHHNYQ	OH	46015	US	1	KQSCYZIYDQ@dell.com	7466685906	5	8690463759936393	2009/04	user1912	password	21	20000	F
1913	BRVPCL	HEJHMIKDEO	6114213626 Dell Way	\N	KMBICUS	SD	63709	US	1	HEJHMIKDEO@dell.com	6114213626	1	8686066165100784	2011/05	user1913	password	37	80000	F
1914	CGDNOH	XVUFFXKUHW	1853937553 Dell Way	\N	WPZQIUG	VA	95850	US	1	XVUFFXKUHW@dell.com	1853937553	3	3908808012958616	2009/02	user1914	password	44	60000	F
1915	NYYUWU	PBAMMUUIRK	4240826425 Dell Way	\N	HISCOPA	NV	20401	US	1	PBAMMUUIRK@dell.com	4240826425	1	3516476635821164	2011/06	user1915	password	68	40000	F
1916	QAGLQI	LDUGYDXILG	1549257146 Dell Way	\N	BNUROLU	VT	51118	US	1	LDUGYDXILG@dell.com	1549257146	4	9185144997667522	2011/11	user1916	password	41	60000	M
1917	PVOXHR	SOPVLYGSZU	3750006809 Dell Way	\N	MQJYLGK	MO	91929	US	1	SOPVLYGSZU@dell.com	3750006809	2	8055094528011978	2011/08	user1917	password	68	40000	F
1918	GDUXVI	NQULXMKSZB	1084927907 Dell Way	\N	BXMIHZF	NJ	28535	US	1	NQULXMKSZB@dell.com	1084927907	2	8662577377632261	2011/06	user1918	password	42	100000	M
1919	DVKLJA	FUYRFQRGSO	7759066855 Dell Way	\N	SAWSGMX	IA	74595	US	1	FUYRFQRGSO@dell.com	7759066855	5	2513237798120826	2008/11	user1919	password	71	40000	M
1920	DQCEWW	COBTFILTAM	9964807921 Dell Way	\N	QSSCQYV	MA	91916	US	1	COBTFILTAM@dell.com	9964807921	3	8203305368311704	2011/09	user1920	password	57	100000	F
1921	QAEMDS	OWXWIRXUHQ	2500943851 Dell Way	\N	MKGLGQJ	IA	20010	US	1	OWXWIRXUHQ@dell.com	2500943851	5	8116413237527014	2011/10	user1921	password	26	40000	M
1922	HVYZJV	XFEPDYWTLH	5980216092 Dell Way	\N	AXOQGUT	MI	77176	US	1	XFEPDYWTLH@dell.com	5980216092	1	6174268219619990	2011/06	user1922	password	48	100000	F
1923	JYQFWW	JLZIITTQTR	3332588786 Dell Way	\N	EKYYEJR	OK	54571	US	1	JLZIITTQTR@dell.com	3332588786	2	9597062745131552	2011/05	user1923	password	34	20000	F
1924	WGDTQP	SYXMSOFJSQ	1814745392 Dell Way	\N	HQUQIND	NE	92325	US	1	SYXMSOFJSQ@dell.com	1814745392	2	3284635603893548	2009/04	user1924	password	57	20000	M
1925	RXFHQE	FCWTIFLZMC	5227349803 Dell Way	\N	UDKHGZF	LA	32355	US	1	FCWTIFLZMC@dell.com	5227349803	4	6081123067531735	2008/11	user1925	password	28	80000	M
1926	JZLNEO	JXXPJWCLQF	6829366884 Dell Way	\N	WYMVDVC	NJ	56813	US	1	JXXPJWCLQF@dell.com	6829366884	4	4477297645527870	2011/05	user1926	password	30	20000	F
1927	PRNEBL	BQUXSGNXCM	2357001327 Dell Way	\N	KXQGZGT	NV	89496	US	1	BQUXSGNXCM@dell.com	2357001327	3	2997082701884210	2009/08	user1927	password	57	100000	F
1928	BCIMDY	HAQNOOPBZN	1244765897 Dell Way	\N	RFNXZEU	CT	64122	US	1	HAQNOOPBZN@dell.com	1244765897	3	2782938038464635	2010/05	user1928	password	52	80000	F
1929	UCPSKQ	JXFYNGXAYD	5354817864 Dell Way	\N	NWDRRGH	NY	74937	US	1	JXFYNGXAYD@dell.com	5354817864	2	2015519884880632	2012/11	user1929	password	61	80000	F
1930	FLKVVH	BUUISVGVIC	1533865293 Dell Way	\N	ZATFILY	SC	72901	US	1	BUUISVGVIC@dell.com	1533865293	4	6283953129779548	2011/06	user1930	password	61	100000	M
1931	ZRTHTN	CBFXHBGKAG	8771134297 Dell Way	\N	DGOPEJH	IA	20243	US	1	CBFXHBGKAG@dell.com	8771134297	5	6293016016483307	2010/09	user1931	password	55	60000	F
1932	GSEUVF	ASNBYXCFAI	8768708369 Dell Way	\N	UPNEXTH	PA	70110	US	1	ASNBYXCFAI@dell.com	8768708369	2	4746225506067276	2009/08	user1932	password	80	80000	F
1933	ALEGLX	TNVRPBSYVI	3678722159 Dell Way	\N	LAFFHZW	DC	25683	US	1	TNVRPBSYVI@dell.com	3678722159	3	8372685358859599	2008/02	user1933	password	31	20000	M
1934	JLBGFO	CWEDOCZXNZ	1562787386 Dell Way	\N	CTGBQKG	WA	93194	US	1	CWEDOCZXNZ@dell.com	1562787386	1	1809378979261964	2009/04	user1934	password	68	80000	M
1935	TWWHYT	MBIOBFCAIV	7337609395 Dell Way	\N	HJLRQJP	OH	50450	US	1	MBIOBFCAIV@dell.com	7337609395	5	7318869966547937	2009/07	user1935	password	46	20000	F
1936	GLIAXK	ILLONMWJTG	3988217333 Dell Way	\N	ULWEBOQ	RI	54962	US	1	ILLONMWJTG@dell.com	3988217333	1	1418397985398769	2011/04	user1936	password	50	100000	M
1937	UAQFIC	QXQDTZXAUI	9862247243 Dell Way	\N	WZKLPEY	WA	41102	US	1	QXQDTZXAUI@dell.com	9862247243	4	6848403715994210	2010/08	user1937	password	46	40000	M
1938	AKZDBW	TEQSBQNKNM	9845400535 Dell Way	\N	VYBZWZI	UT	67036	US	1	TEQSBQNKNM@dell.com	9845400535	2	3368590548168868	2009/07	user1938	password	83	60000	M
1939	WOZTHE	JAGAOQNALL	9718096324 Dell Way	\N	CLIBTFS	PA	55980	US	1	JAGAOQNALL@dell.com	9718096324	1	1290017521008849	2012/07	user1939	password	88	80000	F
1940	YMJDWK	JWYAJYLVBX	9332999825 Dell Way	\N	ECRJVKX	SC	58380	US	1	JWYAJYLVBX@dell.com	9332999825	4	1703875280916690	2012/05	user1940	password	29	100000	M
1941	OZTYIP	XJZWUVXRZA	4357598175 Dell Way	\N	JJVTGQH	FL	34657	US	1	XJZWUVXRZA@dell.com	4357598175	1	7024203083477915	2010/12	user1941	password	58	20000	M
1942	HAGXYP	XUKSRCSSLC	1920064319 Dell Way	\N	OFJEMOL	UT	66835	US	1	XUKSRCSSLC@dell.com	1920064319	3	6120614429470152	2011/06	user1942	password	53	100000	M
1943	TWLJTG	TMYWEQIGEN	4087576803 Dell Way	\N	PIADTXU	UT	36368	US	1	TMYWEQIGEN@dell.com	4087576803	3	8015281464438886	2012/06	user1943	password	39	60000	F
1944	TYCZSO	XOSOWZSKOB	4213936252 Dell Way	\N	KSVHMRP	TN	27868	US	1	XOSOWZSKOB@dell.com	4213936252	4	7045657976996154	2011/03	user1944	password	18	40000	F
1945	CJWQHK	JVHIORWPBP	9578265229 Dell Way	\N	KJBCYXH	IL	59362	US	1	JVHIORWPBP@dell.com	9578265229	5	7988276057876647	2012/05	user1945	password	86	20000	M
1946	URAFAV	MJKEGZFVKP	2079472397 Dell Way	\N	XMNUTUI	OH	76573	US	1	MJKEGZFVKP@dell.com	2079472397	4	1718140320386737	2008/09	user1946	password	76	100000	F
1947	UBLQNU	ARAAXVKMTW	6587696717 Dell Way	\N	ANQUWIO	WY	99749	US	1	ARAAXVKMTW@dell.com	6587696717	1	7342701850458980	2010/11	user1947	password	24	40000	M
1948	NWMHXE	IYCDIPXFPL	8901255972 Dell Way	\N	VJIEYIE	NC	42673	US	1	IYCDIPXFPL@dell.com	8901255972	5	3356400012969971	2012/03	user1948	password	33	60000	F
1949	RUZWCX	YGGNDLCOHM	8219626186 Dell Way	\N	WMKEQYO	MT	92900	US	1	YGGNDLCOHM@dell.com	8219626186	3	2028293054550886	2008/12	user1949	password	31	80000	M
1950	EOWBMC	IAFTCUBPRN	9971602254 Dell Way	\N	AVEYJSW	FL	27555	US	1	IAFTCUBPRN@dell.com	9971602254	1	2597936443518847	2008/11	user1950	password	86	40000	F
1951	UKYXSY	DMBXOQOCQK	4005731136 Dell Way	\N	GPUYMYE	MS	23037	US	1	DMBXOQOCQK@dell.com	4005731136	4	1252069355454295	2009/01	user1951	password	51	20000	F
1952	KZDICQ	JZEAOGRZNH	8908577011 Dell Way	\N	TMTSQGW	WV	93530	US	1	JZEAOGRZNH@dell.com	8908577011	2	9446055337321014	2009/04	user1952	password	44	80000	F
1953	MBJDLJ	HLYOCXCJRO	3424074707 Dell Way	\N	DJFKFEI	CA	48370	US	1	HLYOCXCJRO@dell.com	3424074707	3	7731560726650060	2011/02	user1953	password	20	20000	F
1954	KGQUOB	SDEQFOHUSQ	4055510806 Dell Way	\N	ZCWELYP	OH	43895	US	1	SDEQFOHUSQ@dell.com	4055510806	2	5834044519346208	2009/06	user1954	password	72	80000	M
1955	KOHMHK	QXPEFKXVJZ	6003695521 Dell Way	\N	SOKQDDA	MO	50160	US	1	QXPEFKXVJZ@dell.com	6003695521	5	9113539760932328	2009/08	user1955	password	62	80000	F
1956	XEMHUK	XZPHWLRWDF	7721124536 Dell Way	\N	HUJKVVV	LA	72365	US	1	XZPHWLRWDF@dell.com	7721124536	4	3991394762415439	2009/05	user1956	password	57	40000	M
1957	BNILLH	BSENKBRQIM	8626207134 Dell Way	\N	ZSHVORN	KS	39997	US	1	BSENKBRQIM@dell.com	8626207134	4	7332945294212551	2009/12	user1957	password	34	60000	F
1958	OWWWYP	BMZCDQKQPD	6408190725 Dell Way	\N	XLSOYAX	SC	71622	US	1	BMZCDQKQPD@dell.com	6408190725	1	6432080050464720	2012/08	user1958	password	21	40000	F
1959	YGLNHX	NJBDTRTXPE	8989281399 Dell Way	\N	PDDPBXH	NM	17487	US	1	NJBDTRTXPE@dell.com	8989281399	3	7171827706042678	2012/11	user1959	password	30	100000	F
1960	PKJNYT	OCMFVKUAZY	8359551017 Dell Way	\N	DPZBWQD	PA	19451	US	1	OCMFVKUAZY@dell.com	8359551017	4	9634047113358976	2012/07	user1960	password	21	60000	M
1961	LCXEQZ	RWVBRWAQZP	3844914240 Dell Way	\N	QAMGEFJ	WY	91381	US	1	RWVBRWAQZP@dell.com	3844914240	5	5192061584442854	2009/07	user1961	password	49	80000	M
1962	IYHIPE	DQVZRMZHCA	3892377571 Dell Way	\N	TIEYSEW	AK	22539	US	1	DQVZRMZHCA@dell.com	3892377571	2	7293465784285218	2011/03	user1962	password	43	20000	F
1963	QKTVNK	RNBDMIFNBO	7208046831 Dell Way	\N	RAGWWHZ	GA	70330	US	1	RNBDMIFNBO@dell.com	7208046831	5	8661839451640845	2008/01	user1963	password	89	80000	F
1964	SMYCDM	EHZNMMOBEP	2226224024 Dell Way	\N	IAMPARH	OH	66829	US	1	EHZNMMOBEP@dell.com	2226224024	4	6975823664572091	2008/06	user1964	password	24	100000	M
1965	BYBNDI	NQVZFXDUGE	3327948992 Dell Way	\N	HVEZDWP	ID	64571	US	1	NQVZFXDUGE@dell.com	3327948992	2	1222979512065649	2009/03	user1965	password	86	60000	F
1966	ZYHILY	ELDBPYHTFD	4798647835 Dell Way	\N	XEHUUOK	AR	94018	US	1	ELDBPYHTFD@dell.com	4798647835	2	2464573528617620	2009/10	user1966	password	43	40000	M
1967	QREPWP	SYERGXWKVB	3773336986 Dell Way	\N	RQWFAXD	MI	35015	US	1	SYERGXWKVB@dell.com	3773336986	5	1618710496928542	2011/02	user1967	password	75	40000	M
1968	YWSOPQ	SGWQDGLFYC	3472419839 Dell Way	\N	BDCYHOF	NH	41129	US	1	SGWQDGLFYC@dell.com	3472419839	2	5530137862078846	2008/07	user1968	password	43	20000	F
1969	BOASHH	PXKWJPULQY	9410399622 Dell Way	\N	OOFCTVL	AL	16495	US	1	PXKWJPULQY@dell.com	9410399622	1	6602750137448311	2009/02	user1969	password	21	40000	M
1970	BBZIQW	TMGIHRZFFN	9641997910 Dell Way	\N	LHHGTII	NY	48727	US	1	TMGIHRZFFN@dell.com	9641997910	5	6026833145413548	2008/04	user1970	password	36	20000	F
1971	FLZCEM	INUAMAFZLN	6327357482 Dell Way	\N	HSGPBYA	AK	89656	US	1	INUAMAFZLN@dell.com	6327357482	1	2678861300460994	2012/02	user1971	password	57	20000	M
1972	OESBNF	VNSVTRHHZZ	6040772506 Dell Way	\N	OOBMPBJ	GA	17556	US	1	VNSVTRHHZZ@dell.com	6040772506	1	2756252849940210	2008/02	user1972	password	71	80000	F
1973	LRVRNI	JICBQKBPYP	9993576222 Dell Way	\N	RLFSVKU	LA	51547	US	1	JICBQKBPYP@dell.com	9993576222	3	6203404611907900	2011/02	user1973	password	81	20000	M
1974	RWIAGQ	CIHNJXLZOX	6958187411 Dell Way	\N	FGSQBBC	AZ	57987	US	1	CIHNJXLZOX@dell.com	6958187411	5	6845341685228050	2010/01	user1974	password	50	40000	M
1975	TFDKIM	RWVOHVDEAJ	2089222202 Dell Way	\N	WQLYSNM	MA	39808	US	1	RWVOHVDEAJ@dell.com	2089222202	5	3994101333431900	2010/02	user1975	password	33	40000	F
1976	JTSVLO	QAWMDAMNXD	2282827758 Dell Way	\N	YWWMIGV	MI	26124	US	1	QAWMDAMNXD@dell.com	2282827758	1	3841817705426365	2009/05	user1976	password	67	80000	F
1977	KNNYEN	UQQVCDTGCP	8716833663 Dell Way	\N	CPYJKJO	NC	44914	US	1	UQQVCDTGCP@dell.com	8716833663	5	7640445499680937	2010/08	user1977	password	78	100000	F
1978	JWGXRW	ONZRGGUWIJ	3645306269 Dell Way	\N	USUEGHO	CO	27649	US	1	ONZRGGUWIJ@dell.com	3645306269	4	8064505313988776	2008/07	user1978	password	82	60000	F
1979	DKDAYQ	AQXGKUPUOH	8655592804 Dell Way	\N	OTNWHQB	NE	35253	US	1	AQXGKUPUOH@dell.com	8655592804	4	8663367279805244	2011/03	user1979	password	39	100000	M
1980	KXNBXD	YDOTTIHAXA	3991759844 Dell Way	\N	OUIFVXM	NY	66952	US	1	YDOTTIHAXA@dell.com	3991759844	3	8557328015565873	2011/04	user1980	password	49	20000	F
1981	YCCCBG	QUZZCAWDPQ	8742393493 Dell Way	\N	MUMKGEA	NH	62109	US	1	QUZZCAWDPQ@dell.com	8742393493	2	8894813830032946	2009/04	user1981	password	23	40000	F
1982	EILLYG	KXJLUMALZU	5591504474 Dell Way	\N	XJBBJQQ	HI	88635	US	1	KXJLUMALZU@dell.com	5591504474	3	2329176644328981	2010/10	user1982	password	56	80000	F
1983	ZEBGPY	PBTCBEBWBK	6360224911 Dell Way	\N	YDTOTZL	ID	57037	US	1	PBTCBEBWBK@dell.com	6360224911	5	3578992017079145	2008/08	user1983	password	45	20000	M
1984	KIKJYL	DANHBKJLIM	1161001197 Dell Way	\N	FXGFINT	WA	41980	US	1	DANHBKJLIM@dell.com	1161001197	1	9668178453575820	2009/02	user1984	password	73	100000	M
1985	EELQHL	EPMOYYWLDT	5613840745 Dell Way	\N	RICFBAO	CA	17558	US	1	EPMOYYWLDT@dell.com	5613840745	3	3246479810215533	2009/04	user1985	password	73	60000	F
1986	EBUQFJ	CUIAQUEKMN	8532040811 Dell Way	\N	MRPNFRP	OK	25107	US	1	CUIAQUEKMN@dell.com	8532040811	5	5134834245312959	2010/06	user1986	password	85	80000	M
1987	SKTCMN	KNDESNRFAI	1919330840 Dell Way	\N	UNNMCGQ	WA	31861	US	1	KNDESNRFAI@dell.com	1919330840	3	7127261902205647	2008/04	user1987	password	31	80000	M
1988	XVELFS	OKKCBQCJKP	1701046447 Dell Way	\N	XXRENQK	NM	23080	US	1	OKKCBQCJKP@dell.com	1701046447	4	4989642998203635	2009/05	user1988	password	27	20000	F
1989	IPLBEW	LGYCJHMYFJ	8670420672 Dell Way	\N	QJXGTOK	TX	28389	US	1	LGYCJHMYFJ@dell.com	8670420672	1	6469966185744852	2012/04	user1989	password	78	40000	M
1990	HJCDVI	BXSJKQOUHY	1311065204 Dell Way	\N	ROSFYOL	SD	69714	US	1	BXSJKQOUHY@dell.com	1311065204	4	9647018841933460	2012/02	user1990	password	81	20000	F
1991	YGHHIF	ZRPQGJXFBL	1748777161 Dell Way	\N	XHKLSFD	PA	11727	US	1	ZRPQGJXFBL@dell.com	1748777161	4	2190949237439781	2012/09	user1991	password	62	100000	F
1992	XFIDEZ	SVGCSLEEIL	9789651831 Dell Way	\N	PUEVYXV	AK	55721	US	1	SVGCSLEEIL@dell.com	9789651831	5	3225498246960342	2010/11	user1992	password	36	60000	F
1993	OQGOIB	ULUGPZPBPJ	8716708714 Dell Way	\N	FKHCGIP	HI	34955	US	1	ULUGPZPBPJ@dell.com	8716708714	5	2283586219884455	2008/04	user1993	password	33	80000	M
1994	LFGNAS	IGHHVJWFOH	3346857279 Dell Way	\N	NQNVGTD	CT	62228	US	1	IGHHVJWFOH@dell.com	3346857279	2	9035089639946820	2010/11	user1994	password	77	100000	F
1995	CLDUTK	CBFLYLZFZQ	9850484684 Dell Way	\N	TUXNYAC	FL	31578	US	1	CBFLYLZFZQ@dell.com	9850484684	4	2177874725777656	2012/07	user1995	password	35	100000	F
1996	JRUTUV	ZFTLFYKVSF	2151832005 Dell Way	\N	TFDTHIZ	IL	96398	US	1	ZFTLFYKVSF@dell.com	2151832005	1	5802690279670060	2009/12	user1996	password	58	80000	M
1997	INLDNQ	WYWVIRNNLT	5094032875 Dell Way	\N	QEAYEIX	KS	46007	US	1	WYWVIRNNLT@dell.com	5094032875	4	4388719951733947	2008/06	user1997	password	20	40000	M
1998	MMLCIK	ZESRSGCLXH	6134014263 Dell Way	\N	MWLUUUF	IA	51581	US	1	ZESRSGCLXH@dell.com	6134014263	2	9089313634205610	2011/07	user1998	password	80	20000	F
1999	IEJSDO	LUGRXSPEEL	7847039937 Dell Way	\N	QZGKEMW	PA	74890	US	1	LUGRXSPEEL@dell.com	7847039937	2	3619288523681462	2011/06	user1999	password	41	100000	M
2000	SQTGBO	NSLFIPKTGK	5315461073 Dell Way	\N	ZQOMMIE	ID	70561	US	1	NSLFIPKTGK@dell.com	5315461073	5	1858160700183361	2012/10	user2000	password	69	60000	F
2001	LTMAHF	LNNBYHHIGY	1001614924 Dell Way	\N	XTLGXRX	MD	60295	US	1	LNNBYHHIGY@dell.com	1001614924	2	4158183055929840	2011/09	user2001	password	74	20000	F
2002	GETLQH	YSFFAOMYLF	9851483333 Dell Way	\N	JRDBPOQ	NE	77389	US	1	YSFFAOMYLF@dell.com	9851483333	2	5116052483208478	2011/06	user2002	password	85	100000	M
2003	RLGYKZ	EQZSDYDIIV	3151701771 Dell Way	\N	MKKAAAU	AK	36293	US	1	EQZSDYDIIV@dell.com	3151701771	4	7678518895059825	2008/10	user2003	password	44	100000	F
2004	QVPPZF	PRINVRWQEG	1957436137 Dell Way	\N	BFGBZHJ	GA	13543	US	1	PRINVRWQEG@dell.com	1957436137	2	8172424693591894	2010/03	user2004	password	90	20000	F
2005	PSAUHR	DVNUREYXFD	3679758372 Dell Way	\N	EHDLRIN	RI	74594	US	1	DVNUREYXFD@dell.com	3679758372	2	9564203178510072	2009/05	user2005	password	90	100000	F
2006	ARJRUF	FPWJOUPSZW	8429218860 Dell Way	\N	VLOEYIW	IA	60115	US	1	FPWJOUPSZW@dell.com	8429218860	3	9178337249439212	2012/05	user2006	password	89	100000	F
2007	INWOSL	KBAFQSFNNQ	8697318006 Dell Way	\N	CRPKOVY	MA	42304	US	1	KBAFQSFNNQ@dell.com	8697318006	1	7863791481126101	2012/01	user2007	password	78	20000	M
2008	SSGDDI	EJZWONJFPB	7572954113 Dell Way	\N	UZPPYZZ	SC	23993	US	1	EJZWONJFPB@dell.com	7572954113	4	2582316854968667	2010/10	user2008	password	70	40000	M
2009	ZKQHOZ	HKOUUTKVNJ	7450501121 Dell Way	\N	KDIKCCO	TN	74104	US	1	HKOUUTKVNJ@dell.com	7450501121	2	5490392784122378	2010/08	user2009	password	18	60000	F
2010	QSQQZB	EUWXFRLOCO	2766203728 Dell Way	\N	XMRZAMS	PA	90156	US	1	EUWXFRLOCO@dell.com	2766203728	1	5915822331327946	2008/08	user2010	password	63	100000	F
2011	GMHIQC	EOHWZWYOTL	2539241336 Dell Way	\N	GSMTLGQ	NJ	47266	US	1	EOHWZWYOTL@dell.com	2539241336	5	1015946541447192	2011/08	user2011	password	39	20000	F
2012	PJTRNI	YJIVIXOUDH	9289990314 Dell Way	\N	HWSNMIX	NV	24854	US	1	YJIVIXOUDH@dell.com	9289990314	3	8394049836788327	2009/06	user2012	password	86	100000	M
2013	SMJALT	JGCGVXJCEG	2453639310 Dell Way	\N	VRSEPJI	MT	84334	US	1	JGCGVXJCEG@dell.com	2453639310	4	3842256556730717	2008/07	user2013	password	30	100000	F
2014	OWMIFS	KLOIVQMBMD	3777797747 Dell Way	\N	URTEZGZ	DE	99327	US	1	KLOIVQMBMD@dell.com	3777797747	2	5791423275135458	2010/01	user2014	password	58	20000	M
2015	AIDTTP	HBKYOMKSGB	3102981925 Dell Way	\N	LLBSKFS	OR	53938	US	1	HBKYOMKSGB@dell.com	3102981925	2	6106239750515670	2011/03	user2015	password	54	100000	M
2016	QOIFVK	QTYCEQJGCU	6308167546 Dell Way	\N	IUFNNYA	OR	24204	US	1	QTYCEQJGCU@dell.com	6308167546	3	4515475022606552	2008/05	user2016	password	88	80000	M
2017	HYSROM	QRQHAXJVFE	5891513932 Dell Way	\N	BTRZTLD	KY	96553	US	1	QRQHAXJVFE@dell.com	5891513932	3	3699052893556655	2010/02	user2017	password	31	80000	F
2018	XMQJCH	AKIYUDDYFW	4061934772 Dell Way	\N	QEQCIZB	VA	47917	US	1	AKIYUDDYFW@dell.com	4061934772	2	6151254401076586	2010/03	user2018	password	65	60000	M
2019	HVUPVE	XUYBXXGUOL	4473785808 Dell Way	\N	KQUKRRV	AK	17561	US	1	XUYBXXGUOL@dell.com	4473785808	3	3461698543280363	2008/12	user2019	password	86	40000	M
2020	SXQXVK	WXHUEBIQMY	5246924694 Dell Way	\N	LWQCRQF	AZ	27118	US	1	WXHUEBIQMY@dell.com	5246924694	1	2460466111078858	2010/06	user2020	password	87	20000	F
2021	OBFZXC	HSGJAWVZHS	6548998593 Dell Way	\N	PKKGQML	CA	62984	US	1	HSGJAWVZHS@dell.com	6548998593	3	1284131865948438	2010/08	user2021	password	46	20000	M
2022	PCQRJI	YSJVOIDHYO	7867786229 Dell Way	\N	RFEDRGT	IL	78612	US	1	YSJVOIDHYO@dell.com	7867786229	5	4757833042182028	2008/12	user2022	password	27	80000	F
2023	TKMCJF	LETUHASVRY	4974506504 Dell Way	\N	AVPGOWA	KS	74436	US	1	LETUHASVRY@dell.com	4974506504	3	7245957861188800	2010/03	user2023	password	74	40000	M
2024	GLZLWE	ERMFJHXHIT	2631063606 Dell Way	\N	XOHUPQM	AR	20663	US	1	ERMFJHXHIT@dell.com	2631063606	4	4071009234525263	2012/12	user2024	password	89	40000	F
2025	ZQGDVX	PBHXYPFRNU	1758442111 Dell Way	\N	ZHKQTLT	WA	14293	US	1	PBHXYPFRNU@dell.com	1758442111	5	1002331485040485	2008/02	user2025	password	46	20000	M
2026	REOPUP	WROMXGZSGG	6246096947 Dell Way	\N	CWANPYP	NY	86589	US	1	WROMXGZSGG@dell.com	6246096947	4	9589671541005374	2012/10	user2026	password	68	80000	M
2027	GFTWCL	LOIROBXUDT	6023272881 Dell Way	\N	URJTGBP	TX	81282	US	1	LOIROBXUDT@dell.com	6023272881	5	6206536409445108	2009/06	user2027	password	57	60000	M
2028	HKTSVH	BNVCKQGELY	9604316775 Dell Way	\N	OEFPUBJ	KY	90076	US	1	BNVCKQGELY@dell.com	9604316775	3	4039556976873428	2010/02	user2028	password	90	80000	M
2029	SNJAOW	WRHMYMXXAC	4769342434 Dell Way	\N	DPWEZFC	WA	84073	US	1	WRHMYMXXAC@dell.com	4769342434	3	9491173680406064	2010/03	user2029	password	51	20000	M
2030	VEHRAZ	ZMYLKVLNZA	4379993447 Dell Way	\N	KEZPGXL	NV	40584	US	1	ZMYLKVLNZA@dell.com	4379993447	1	5944634239189327	2012/03	user2030	password	37	80000	F
2031	OIJOIW	MTHIEUHFEL	1033532914 Dell Way	\N	FURCFIL	NE	46016	US	1	MTHIEUHFEL@dell.com	1033532914	3	6410407918971033	2009/01	user2031	password	87	100000	F
2032	IJTFWM	MEQGLWKXBE	9211910388 Dell Way	\N	OEKXQZI	NJ	45324	US	1	MEQGLWKXBE@dell.com	9211910388	5	5240053151734174	2012/09	user2032	password	83	20000	F
2033	QKYCWD	TCPPNMRSBV	9446774554 Dell Way	\N	CZLBHCM	FL	98189	US	1	TCPPNMRSBV@dell.com	9446774554	1	7381411147303880	2012/04	user2033	password	77	60000	M
2034	TONXIQ	MXEYPWAKZZ	6792369708 Dell Way	\N	WBGYNLY	MI	56460	US	1	MXEYPWAKZZ@dell.com	6792369708	2	8003557834774257	2010/09	user2034	password	49	40000	F
2035	YCPPPN	TOCPONONKP	5864880610 Dell Way	\N	UJDGHOT	WA	86577	US	1	TOCPONONKP@dell.com	5864880610	2	6292670853901655	2012/08	user2035	password	82	100000	M
2036	MNHAGV	DVKQKYBASK	2354923772 Dell Way	\N	DZSSSQO	ID	11781	US	1	DVKQKYBASK@dell.com	2354923772	2	6653702318668366	2008/03	user2036	password	43	60000	M
2037	QNXMRT	XIEVJENUIN	7755026459 Dell Way	\N	MAGCPND	PA	76946	US	1	XIEVJENUIN@dell.com	7755026459	4	9202988334465772	2008/04	user2037	password	60	80000	M
2038	MGMGDU	KYEPMYXZKY	4416174561 Dell Way	\N	FNOSQHM	MA	15743	US	1	KYEPMYXZKY@dell.com	4416174561	3	4275233236607164	2012/03	user2038	password	32	60000	F
2039	SSQMDO	RSBPQBAOHO	8339948411 Dell Way	\N	CZEKMPL	TX	16039	US	1	RSBPQBAOHO@dell.com	8339948411	5	3751022926997393	2008/04	user2039	password	75	80000	M
2040	KFCZWU	AMLCNZJBCJ	2883413948 Dell Way	\N	GMVVYRX	PA	52349	US	1	AMLCNZJBCJ@dell.com	2883413948	4	7652665945701302	2012/06	user2040	password	70	60000	M
2041	VJOQKB	BMOAWQDFXP	9069821719 Dell Way	\N	ATORQHE	TX	15166	US	1	BMOAWQDFXP@dell.com	9069821719	5	5754981140606106	2011/04	user2041	password	33	60000	M
2042	TBBVCO	KDKAGPYWQR	3752348156 Dell Way	\N	LIISMEU	MA	10830	US	1	KDKAGPYWQR@dell.com	3752348156	5	3370335706509650	2010/06	user2042	password	83	40000	F
2043	YCOMMS	XNZNLWDCHM	8611884498 Dell Way	\N	KZYOUIP	AZ	38723	US	1	XNZNLWDCHM@dell.com	8611884498	3	7643300426192582	2011/11	user2043	password	33	80000	M
2044	UFLMCY	LPJHTMOGXO	6144443614 Dell Way	\N	ELINBKV	VA	99236	US	1	LPJHTMOGXO@dell.com	6144443614	4	8712582881562413	2011/04	user2044	password	77	60000	M
2045	GAQEMF	OTZAIFXWKJ	5017788548 Dell Way	\N	FYKPTHP	KS	93630	US	1	OTZAIFXWKJ@dell.com	5017788548	1	3306576316710562	2009/08	user2045	password	74	60000	M
2046	KRDQFX	QGFVECGNHE	4724678302 Dell Way	\N	YWYFMGE	VT	43803	US	1	QGFVECGNHE@dell.com	4724678302	1	1311352679040283	2008/09	user2046	password	70	60000	F
2047	WFPTVV	ZRZBYNJCLF	7486007496 Dell Way	\N	BRSIVPR	IA	80764	US	1	ZRZBYNJCLF@dell.com	7486007496	3	5146604340057820	2010/01	user2047	password	77	40000	F
2048	KBBFBT	FDRSMTDSVU	3278071639 Dell Way	\N	KDQAUWU	MT	36036	US	1	FDRSMTDSVU@dell.com	3278071639	5	3730466820765287	2008/04	user2048	password	56	60000	F
2049	PRKIWN	ZPZTSRONBR	6527948126 Dell Way	\N	EBMAWAI	CO	98055	US	1	ZPZTSRONBR@dell.com	6527948126	1	3220415884163231	2008/08	user2049	password	60	80000	F
2050	ZBFMBU	LUNDJBEAFG	7783719679 Dell Way	\N	NFDNNGN	DC	47853	US	1	LUNDJBEAFG@dell.com	7783719679	2	1563733522780239	2009/01	user2050	password	45	40000	F
2051	PUDJGX	WJGYOHDVVJ	6946032570 Dell Way	\N	YIXEWBP	NH	40932	US	1	WJGYOHDVVJ@dell.com	6946032570	5	4372961923480034	2008/04	user2051	password	51	80000	F
2052	PZHNWQ	UVFCYAXHZG	9728788733 Dell Way	\N	FDCGTRP	MD	66318	US	1	UVFCYAXHZG@dell.com	9728788733	3	8890985521487893	2010/01	user2052	password	84	20000	F
2053	FNYWIU	BKSCHABNGF	8116601335 Dell Way	\N	PMYHCJX	AR	82628	US	1	BKSCHABNGF@dell.com	8116601335	3	8958119725342841	2011/07	user2053	password	88	100000	F
2054	XTJSVT	KYBLZORFEE	2888109008 Dell Way	\N	ELGNJHI	DE	79698	US	1	KYBLZORFEE@dell.com	2888109008	5	3541916386689991	2008/10	user2054	password	41	20000	M
2055	RUJLFI	MRIBINGMRR	1803922896 Dell Way	\N	TFBANFU	OR	18420	US	1	MRIBINGMRR@dell.com	1803922896	5	8877430777065457	2010/12	user2055	password	48	20000	M
2056	UOZDBQ	LCZYIMQAFV	3563926539 Dell Way	\N	CGIIBBK	DC	97682	US	1	LCZYIMQAFV@dell.com	3563926539	3	9718998586293312	2011/09	user2056	password	72	60000	F
2057	TQHKBK	JATVQTBMWH	8424557340 Dell Way	\N	VEJWPNW	UT	16305	US	1	JATVQTBMWH@dell.com	8424557340	3	7657244304660708	2010/02	user2057	password	88	40000	M
2058	GSVQBV	JXMDZYAHTE	9693500690 Dell Way	\N	QQTEMQF	KS	30117	US	1	JXMDZYAHTE@dell.com	9693500690	5	3894494811072946	2012/03	user2058	password	22	20000	M
2059	WVZSEX	EIXCIEWNVM	5198529371 Dell Way	\N	HZZXFHD	DE	26838	US	1	EIXCIEWNVM@dell.com	5198529371	1	4592693527694792	2010/04	user2059	password	41	40000	F
2060	ICHGGP	DJYHFLDSSC	6231047508 Dell Way	\N	SQIZUME	ID	64136	US	1	DJYHFLDSSC@dell.com	6231047508	4	8962243923451752	2012/03	user2060	password	89	40000	F
2061	GLNWPW	UWCGAVZDNQ	4832257381 Dell Way	\N	LNKYSRO	ID	50948	US	1	UWCGAVZDNQ@dell.com	4832257381	1	6659333327319474	2010/05	user2061	password	82	80000	M
2062	KNLHIH	JPIEOLSEXF	4214837479 Dell Way	\N	PVXHJES	SC	42221	US	1	JPIEOLSEXF@dell.com	4214837479	2	7770819670986385	2009/11	user2062	password	61	80000	F
2063	AXTIHI	QMXCFCZKRU	6504244267 Dell Way	\N	IZENRZW	AR	24917	US	1	QMXCFCZKRU@dell.com	6504244267	2	1304714819416403	2009/12	user2063	password	49	40000	M
2064	EODNFQ	KHVNHGFCOE	4794452856 Dell Way	\N	GBWFXXK	NC	27106	US	1	KHVNHGFCOE@dell.com	4794452856	4	2152393970638513	2012/12	user2064	password	89	20000	M
2065	DOTUZB	PMIWRKKVRM	9106047827 Dell Way	\N	RXKPHYU	OH	69950	US	1	PMIWRKKVRM@dell.com	9106047827	3	6775198428425939	2012/08	user2065	password	31	20000	F
2066	YUDZKQ	IGITRDKDVH	7983153369 Dell Way	\N	OKPMEHD	CA	86570	US	1	IGITRDKDVH@dell.com	7983153369	5	5118564828764647	2012/01	user2066	password	63	100000	M
2067	UWFKEM	SXEWIIRQWC	8217993237 Dell Way	\N	FIHMMJI	IA	41575	US	1	SXEWIIRQWC@dell.com	8217993237	2	4166867717634887	2010/02	user2067	password	29	20000	M
2068	JPDWIB	BEKJWAFYFO	3892924574 Dell Way	\N	GSAQBHZ	TX	52521	US	1	BEKJWAFYFO@dell.com	3892924574	2	6039718318264932	2010/06	user2068	password	55	100000	F
2069	RTKSUO	DDKDJJJYPB	3318518990 Dell Way	\N	YFDFEZS	MT	33973	US	1	DDKDJJJYPB@dell.com	3318518990	5	7755707195959986	2011/11	user2069	password	78	60000	M
2070	FEJUHM	EKWOTUDVTJ	9472424549 Dell Way	\N	YYOYRBE	VT	15730	US	1	EKWOTUDVTJ@dell.com	9472424549	4	9245199955068530	2011/02	user2070	password	54	100000	F
2071	WUPJZZ	FNTZRPSANR	6711973506 Dell Way	\N	PLIRQGS	NE	93349	US	1	FNTZRPSANR@dell.com	6711973506	2	1483717058785259	2008/05	user2071	password	43	100000	F
2072	YICXOP	RNGGGHUXWF	5136255610 Dell Way	\N	GNWMGLK	UT	81894	US	1	RNGGGHUXWF@dell.com	5136255610	1	2367371774278581	2012/12	user2072	password	38	80000	F
2073	JRWZIK	FPRNJOJPVW	8609443797 Dell Way	\N	LHDXSZS	DE	98919	US	1	FPRNJOJPVW@dell.com	8609443797	5	9857732561882586	2008/09	user2073	password	41	60000	F
2074	FMRQSH	HFQWOFRLRY	5737364366 Dell Way	\N	OOROGVO	CO	81133	US	1	HFQWOFRLRY@dell.com	5737364366	2	5457522329408676	2012/09	user2074	password	80	20000	F
2075	ORXVYD	MUSRMDJLSY	2796780931 Dell Way	\N	CHFXVHS	KY	58623	US	1	MUSRMDJLSY@dell.com	2796780931	1	3503997432067990	2008/03	user2075	password	53	80000	M
2076	KLWNXR	FPDJYPCWRJ	2712543320 Dell Way	\N	BPEJHNX	MO	75231	US	1	FPDJYPCWRJ@dell.com	2712543320	3	9747169584501536	2011/02	user2076	password	83	20000	M
2077	TQMLVB	PFZEIWWRYL	1974091519 Dell Way	\N	WHSKFFD	MD	78120	US	1	PFZEIWWRYL@dell.com	1974091519	1	9164044302422554	2008/03	user2077	password	53	80000	M
2078	YFQAVW	AZEWVWUGTC	8791326390 Dell Way	\N	ZEIFHSY	MD	83079	US	1	AZEWVWUGTC@dell.com	8791326390	3	9892693333327772	2009/03	user2078	password	75	40000	F
2079	KIFHIF	LEAIZHBCHF	9339908470 Dell Way	\N	KMNDLXY	KS	37526	US	1	LEAIZHBCHF@dell.com	9339908470	4	5307331025600434	2011/12	user2079	password	81	20000	F
2080	BKQHWU	HEUPGWXLHK	6756172086 Dell Way	\N	YKVWIEE	ID	84580	US	1	HEUPGWXLHK@dell.com	6756172086	5	8284638247918338	2010/02	user2080	password	26	60000	M
2081	TWJOEO	ITUFRFMBEX	7240374528 Dell Way	\N	XAGBENW	TN	53218	US	1	ITUFRFMBEX@dell.com	7240374528	2	6279928617645056	2012/12	user2081	password	25	60000	M
2082	MBYAKS	UPJZCLEZIE	8039097699 Dell Way	\N	FJJSGFF	WI	57843	US	1	UPJZCLEZIE@dell.com	8039097699	4	5062865900341422	2012/04	user2082	password	34	40000	F
2083	EJUWDJ	GDMRHLAMRJ	1282173652 Dell Way	\N	WKQBPPP	LA	42999	US	1	GDMRHLAMRJ@dell.com	1282173652	2	6965171891730279	2009/08	user2083	password	20	60000	M
2084	VIBFOF	RGMDGZUQVF	9202885903 Dell Way	\N	HWUWLDG	MO	45112	US	1	RGMDGZUQVF@dell.com	9202885903	4	9838822305202484	2012/02	user2084	password	85	80000	F
2085	ZYAFQH	RTNQODLTKI	1335289571 Dell Way	\N	NHTROGB	MN	98011	US	1	RTNQODLTKI@dell.com	1335289571	3	2289435011334717	2012/02	user2085	password	63	100000	F
2086	QESXVM	LMAPYTZHHH	4611613117 Dell Way	\N	AYWHAIG	AR	74718	US	1	LMAPYTZHHH@dell.com	4611613117	1	8903087887447328	2008/12	user2086	password	89	80000	F
2087	SPYEAL	EPKYPRGXSE	7019915216 Dell Way	\N	TZEBFFU	NM	30754	US	1	EPKYPRGXSE@dell.com	7019915216	4	2751379154622555	2011/04	user2087	password	40	40000	M
2088	HNYSSO	CRDTXBLCVK	9270440421 Dell Way	\N	GWQMRHS	KY	93775	US	1	CRDTXBLCVK@dell.com	9270440421	5	3236467924434692	2009/05	user2088	password	29	60000	M
2089	CFPQIG	UBDVNFQYMN	1354822297 Dell Way	\N	PZFWSOU	NM	58276	US	1	UBDVNFQYMN@dell.com	1354822297	5	8972057040780784	2008/05	user2089	password	73	40000	M
2090	JXXPRZ	TNMZDKMRZM	8535124571 Dell Way	\N	WWEKQVY	NY	70933	US	1	TNMZDKMRZM@dell.com	8535124571	5	1430925259366631	2010/02	user2090	password	64	100000	F
2091	NOTNHG	ZGKKTCKFZG	9254297316 Dell Way	\N	JKWEIOW	DE	49476	US	1	ZGKKTCKFZG@dell.com	9254297316	4	6380947989411653	2010/09	user2091	password	66	20000	F
2092	LPOSPV	CZOFJTEPDO	1795566072 Dell Way	\N	MIXBFBM	CT	86089	US	1	CZOFJTEPDO@dell.com	1795566072	4	6045553061645479	2011/10	user2092	password	77	20000	F
2093	JWYEZX	TFHNJXQYJZ	3918834198 Dell Way	\N	VLEXYHT	AK	97917	US	1	TFHNJXQYJZ@dell.com	3918834198	4	7657158184796572	2008/12	user2093	password	25	60000	M
2094	ASVYLA	GYKDPINOEY	7825726991 Dell Way	\N	TCWBWXA	FL	70019	US	1	GYKDPINOEY@dell.com	7825726991	2	6575632488820702	2012/11	user2094	password	50	100000	M
2095	GWZHCX	RFMZTAESUG	7850614060 Dell Way	\N	PVDMVID	NH	67136	US	1	RFMZTAESUG@dell.com	7850614060	3	5236332776956260	2009/05	user2095	password	90	60000	F
2096	ZTHWKM	IKGJPYDVNY	4479034623 Dell Way	\N	ZZUHDJX	VA	83336	US	1	IKGJPYDVNY@dell.com	4479034623	1	2367737112101167	2009/07	user2096	password	42	40000	F
2097	PFSCOD	IXSHBOUZNU	2043634112 Dell Way	\N	UUXDSVZ	CO	92561	US	1	IXSHBOUZNU@dell.com	2043634112	3	5390576399862767	2010/11	user2097	password	76	20000	F
2098	NEPQNN	IUOXPOKJIF	5627691245 Dell Way	\N	HMXCLAA	ND	55976	US	1	IUOXPOKJIF@dell.com	5627691245	1	4130138549022377	2009/01	user2098	password	46	100000	F
2099	ZMTMVN	BSCPDMXIUK	2207252303 Dell Way	\N	GXVHXKU	ME	47146	US	1	BSCPDMXIUK@dell.com	2207252303	4	5352115907240659	2010/07	user2099	password	70	60000	F
2100	LAWZBP	CQSPOBJYHG	1806696158 Dell Way	\N	UPEFJPP	MS	39467	US	1	CQSPOBJYHG@dell.com	1806696158	1	9143328717909754	2012/07	user2100	password	88	40000	M
2101	VGPLJF	EYTFHSNOMC	5662995335 Dell Way	\N	SSLHHYP	MA	97829	US	1	EYTFHSNOMC@dell.com	5662995335	1	5634936298709363	2010/06	user2101	password	21	40000	M
2102	QTBVXA	PDHIQVUSOM	6558267905 Dell Way	\N	EVUDLEC	WI	44422	US	1	PDHIQVUSOM@dell.com	6558267905	3	8606091648340226	2011/10	user2102	password	58	40000	M
2103	QDLQTO	YBFUWYIJCD	6185717589 Dell Way	\N	EGPJIOT	WI	98512	US	1	YBFUWYIJCD@dell.com	6185717589	4	7704905360937119	2008/12	user2103	password	37	80000	F
2104	SKVHIX	MCTLLCNPHU	4938037732 Dell Way	\N	EQCSJBS	WA	73287	US	1	MCTLLCNPHU@dell.com	4938037732	1	6748920596204699	2011/11	user2104	password	70	60000	F
2105	OSPLES	FQDIDSPYWF	5112329367 Dell Way	\N	BPOCHNV	OK	61485	US	1	FQDIDSPYWF@dell.com	5112329367	3	4703714659903199	2008/11	user2105	password	65	80000	M
2106	GESYJI	BRMUGKQMMF	5718436269 Dell Way	\N	BPNOKFC	TX	67180	US	1	BRMUGKQMMF@dell.com	5718436269	1	5237147715874017	2008/10	user2106	password	18	60000	M
2107	TJHBKZ	OEGZVSLBTA	9055187767 Dell Way	\N	OHLUKHL	WA	37789	US	1	OEGZVSLBTA@dell.com	9055187767	1	1655633279122412	2012/07	user2107	password	18	80000	M
2108	ISHHHM	NGIGSKZTYH	8392975335 Dell Way	\N	ETRLEQT	AZ	75187	US	1	NGIGSKZTYH@dell.com	8392975335	5	3228776593692601	2012/08	user2108	password	26	20000	F
2109	KLOXZV	FFOPFHOMLH	7994911868 Dell Way	\N	EXMUQNN	MN	54835	US	1	FFOPFHOMLH@dell.com	7994911868	2	1864544785115868	2012/06	user2109	password	47	40000	M
2110	ZFWVKB	JAHQOUCWZZ	5070052162 Dell Way	\N	IUPWHBJ	CA	41319	US	1	JAHQOUCWZZ@dell.com	5070052162	5	8048071159515531	2012/04	user2110	password	66	100000	F
2111	NQXPZX	WQMQSIPRRK	5235562333 Dell Way	\N	HNSIWUR	KS	78199	US	1	WQMQSIPRRK@dell.com	5235562333	1	1448326773475855	2008/01	user2111	password	57	80000	M
2112	LFQJCG	WSYEIQVTXJ	1102366762 Dell Way	\N	LGGFYOZ	MD	77241	US	1	WSYEIQVTXJ@dell.com	1102366762	3	7760139156598599	2010/03	user2112	password	46	20000	F
2113	AJMGFF	FKOWGHTQSA	9399885501 Dell Way	\N	WXYLWJE	VA	90279	US	1	FKOWGHTQSA@dell.com	9399885501	3	1632787668611854	2009/06	user2113	password	52	40000	M
2114	YPBEVM	SRTZKJSLGQ	7197349247 Dell Way	\N	JRMSWJQ	SC	84240	US	1	SRTZKJSLGQ@dell.com	7197349247	1	3511892229318619	2008/06	user2114	password	26	20000	F
2115	EGWRZN	KZYURJAHTR	3426459857 Dell Way	\N	ULNEBIZ	RI	48561	US	1	KZYURJAHTR@dell.com	3426459857	5	8848280504345895	2009/01	user2115	password	84	60000	F
2116	TFHHQG	FKXOKFHCZT	3290820861 Dell Way	\N	QDVYDPJ	ME	57615	US	1	FKXOKFHCZT@dell.com	3290820861	4	6028977349400521	2008/05	user2116	password	80	100000	M
2117	DFFJLQ	HZBMHEMBUQ	6436293121 Dell Way	\N	XTTNDEB	MA	97555	US	1	HZBMHEMBUQ@dell.com	6436293121	3	4025791561696678	2010/06	user2117	password	85	60000	M
2118	EYDUFD	VSLAEMUUKN	1327699611 Dell Way	\N	OXRSZAS	ND	62415	US	1	VSLAEMUUKN@dell.com	1327699611	1	1555575152393430	2012/08	user2118	password	73	20000	M
2119	WXUZTM	KTRXOLIBZF	4707764011 Dell Way	\N	TSETLTJ	MN	80450	US	1	KTRXOLIBZF@dell.com	4707764011	3	4524069813545793	2008/07	user2119	password	87	20000	F
2120	SAFFLZ	WJNIRPIXIA	1060452875 Dell Way	\N	BCLVLXP	TX	40891	US	1	WJNIRPIXIA@dell.com	1060452875	1	8996006929315628	2012/01	user2120	password	43	80000	F
2121	OXNNTW	ACOQKLYKNA	1271351584 Dell Way	\N	WIMUYID	WI	40293	US	1	ACOQKLYKNA@dell.com	1271351584	5	4526037117466331	2009/08	user2121	password	52	100000	F
2122	ALGXMI	LCSWBDJCAR	6494307743 Dell Way	\N	OVQWZPF	AK	54563	US	1	LCSWBDJCAR@dell.com	6494307743	2	1793921400327235	2008/04	user2122	password	60	20000	M
2123	VZGEKJ	XGLBPNCHCX	1869186553 Dell Way	\N	YYWNEWA	SC	32880	US	1	XGLBPNCHCX@dell.com	1869186553	5	6036596935242415	2011/12	user2123	password	41	60000	M
2124	ORJYPQ	JQGWSNYQLX	2765233837 Dell Way	\N	NZCJZWQ	AZ	78101	US	1	JQGWSNYQLX@dell.com	2765233837	4	7547484233975411	2010/04	user2124	password	67	20000	M
2125	BANRJE	XGWKFNWDAV	6195946008 Dell Way	\N	FKVCAXW	HI	67605	US	1	XGWKFNWDAV@dell.com	6195946008	4	9103897626046092	2009/10	user2125	password	79	40000	M
2126	JYFOWM	LHRYDVYZAI	3163291269 Dell Way	\N	VDJSZPI	NC	39704	US	1	LHRYDVYZAI@dell.com	3163291269	5	2400808761827647	2008/02	user2126	password	18	60000	F
2127	FAXSLE	KJIFIIGQDJ	1847484691 Dell Way	\N	AVIPEWY	MD	70377	US	1	KJIFIIGQDJ@dell.com	1847484691	3	7939646636135877	2008/12	user2127	password	78	40000	M
2128	TAKXLU	GQCOWTSGTN	8833578897 Dell Way	\N	OJRLICC	MD	62775	US	1	GQCOWTSGTN@dell.com	8833578897	3	5897083363030106	2011/10	user2128	password	55	60000	M
2129	XJHSPY	UEVOWBHKQR	3792285259 Dell Way	\N	CBZEDKT	AK	91771	US	1	UEVOWBHKQR@dell.com	3792285259	4	7628069594502450	2012/02	user2129	password	61	80000	M
2130	XLDVFI	QTFSBPITRJ	8166695189 Dell Way	\N	TWNDQNB	WA	32772	US	1	QTFSBPITRJ@dell.com	8166695189	4	4692847606260330	2009/06	user2130	password	85	40000	M
2131	BDEJTX	PMZEUTWEMS	9083104722 Dell Way	\N	SQIGSHM	MS	13443	US	1	PMZEUTWEMS@dell.com	9083104722	5	5830439332872630	2012/03	user2131	password	52	100000	F
2132	QHBOWN	NAIHWNTPFK	8115983342 Dell Way	\N	YLCFYPG	TN	54008	US	1	NAIHWNTPFK@dell.com	8115983342	4	6969596216455103	2009/07	user2132	password	87	100000	M
2133	ALROZS	WGPKAEPKDB	3511941757 Dell Way	\N	NIZDPVQ	MA	54906	US	1	WGPKAEPKDB@dell.com	3511941757	4	1510453867260366	2009/07	user2133	password	83	40000	M
2134	PUYHRE	XBFBRQFTEO	2194941005 Dell Way	\N	THDPXNB	FL	25555	US	1	XBFBRQFTEO@dell.com	2194941005	3	7358539930079133	2008/08	user2134	password	67	80000	F
2135	PXCUUE	AWWQBPUPIC	2332497839 Dell Way	\N	TXZGZEL	CT	61571	US	1	AWWQBPUPIC@dell.com	2332497839	1	3041588637977838	2012/10	user2135	password	66	60000	M
2136	UGLYGH	VXIKSYTURR	7567262378 Dell Way	\N	TYRYKUN	NC	95519	US	1	VXIKSYTURR@dell.com	7567262378	2	7328997698612512	2009/10	user2136	password	43	20000	F
2137	UDHBYF	KJXJCRAULZ	9160498216 Dell Way	\N	LKKGXYF	NJ	37145	US	1	KJXJCRAULZ@dell.com	9160498216	1	1970366740133613	2009/03	user2137	password	29	20000	F
2138	MCGRMQ	PVTHWNTWZD	6379779510 Dell Way	\N	GFAELQM	KY	69106	US	1	PVTHWNTWZD@dell.com	6379779510	3	8663151236250997	2011/08	user2138	password	30	40000	M
2139	LXFBMB	UTYIMUHPBN	7806737651 Dell Way	\N	PGYGTGX	KS	87106	US	1	UTYIMUHPBN@dell.com	7806737651	1	5326165660750121	2012/04	user2139	password	32	40000	F
2140	KLRMGK	KOXFVMGICN	8802296541 Dell Way	\N	GIGNGOK	AK	69121	US	1	KOXFVMGICN@dell.com	8802296541	5	9678851709235460	2008/04	user2140	password	29	60000	M
2141	VYZGJN	DOJQVRSIYB	7658500974 Dell Way	\N	OMIDWIU	OR	32898	US	1	DOJQVRSIYB@dell.com	7658500974	4	6102730075828732	2012/04	user2141	password	41	80000	F
2142	HZOVDD	ETYWLGVNUH	9728703769 Dell Way	\N	VXEDRXK	ME	73130	US	1	ETYWLGVNUH@dell.com	9728703769	2	9787185511086136	2009/01	user2142	password	32	60000	F
2143	TLEWPX	UMJBIXVQST	4335835544 Dell Way	\N	UWKSHVK	IA	24300	US	1	UMJBIXVQST@dell.com	4335835544	3	2977365540340543	2010/02	user2143	password	37	40000	M
2144	LFEIAQ	SBYPXOIQJE	3278448841 Dell Way	\N	BBLWLRA	TN	29688	US	1	SBYPXOIQJE@dell.com	3278448841	2	4045510240364820	2010/09	user2144	password	82	100000	M
2145	BHYRZA	QPXFXNPCOQ	7973988999 Dell Way	\N	NLCFMXL	OK	37944	US	1	QPXFXNPCOQ@dell.com	7973988999	2	1288554627448320	2011/03	user2145	password	88	80000	F
2146	XJMYAB	VGYJVAXMOJ	8405151914 Dell Way	\N	OUVMFOU	WY	81074	US	1	VGYJVAXMOJ@dell.com	8405151914	4	9839533358812332	2011/05	user2146	password	51	80000	M
2147	YQTZLZ	YUUZSGOBVI	2839110594 Dell Way	\N	XIOLCOF	WA	27410	US	1	YUUZSGOBVI@dell.com	2839110594	4	5844339411705733	2011/05	user2147	password	37	80000	F
2148	APMZOH	UOABCBXLYF	3384971284 Dell Way	\N	ZKHNPFS	SD	93925	US	1	UOABCBXLYF@dell.com	3384971284	3	4107712482102215	2010/02	user2148	password	46	60000	M
2149	WNGEIU	EJXGGIFLIP	3323953280 Dell Way	\N	TWFZPAX	TX	54012	US	1	EJXGGIFLIP@dell.com	3323953280	2	6166069880127907	2011/11	user2149	password	37	60000	F
2150	NRTHWC	ECJNHVVXPR	2391828013 Dell Way	\N	COGCMCP	OR	53337	US	1	ECJNHVVXPR@dell.com	2391828013	2	4463589876890183	2010/11	user2150	password	77	100000	M
2151	OFLQKO	AXWVTTLLVZ	7167579229 Dell Way	\N	SYMVNFH	NV	63212	US	1	AXWVTTLLVZ@dell.com	7167579229	1	5423035818617791	2010/12	user2151	password	23	20000	F
2152	NRPCSN	YOHSZSNZLM	7661710706 Dell Way	\N	LGZROQG	HI	73553	US	1	YOHSZSNZLM@dell.com	7661710706	4	7305026276968420	2012/10	user2152	password	84	40000	F
2153	NLDBKS	ICRAQQMCCS	1920209385 Dell Way	\N	BTGSAMK	OR	28944	US	1	ICRAQQMCCS@dell.com	1920209385	3	9751036902423948	2008/11	user2153	password	48	60000	F
2154	OOTHWW	YXMPJPSCQL	1073286390 Dell Way	\N	IILVTFA	TX	78173	US	1	YXMPJPSCQL@dell.com	1073286390	5	7060670594219119	2010/05	user2154	password	20	20000	M
2155	UHVQFT	DVDSNFJZOR	1415257491 Dell Way	\N	KJLPKHJ	ME	22085	US	1	DVDSNFJZOR@dell.com	1415257491	5	5632754665333778	2008/11	user2155	password	51	100000	F
2156	HMIAQE	DIRJRRXJCG	7467805003 Dell Way	\N	USRBBCF	CO	93242	US	1	DIRJRRXJCG@dell.com	7467805003	1	7924514849204571	2008/01	user2156	password	82	60000	M
2157	GMEKQM	CZETWNVDIN	6223903012 Dell Way	\N	UJPXPRV	IN	89390	US	1	CZETWNVDIN@dell.com	6223903012	3	9423609019722790	2010/12	user2157	password	53	80000	F
2158	RCBEEB	IYXVTBEGWO	4231639850 Dell Way	\N	WTDOOLL	CT	92400	US	1	IYXVTBEGWO@dell.com	4231639850	4	8745919110253454	2012/04	user2158	password	39	60000	F
2159	JRPKZN	IVHJZOFNKY	8840599592 Dell Way	\N	RYNCJQA	OK	31740	US	1	IVHJZOFNKY@dell.com	8840599592	3	5888993946369738	2008/01	user2159	password	87	60000	M
2160	NXTBGP	IPOWVCHUUF	7339941241 Dell Way	\N	HWOXWHE	PA	86934	US	1	IPOWVCHUUF@dell.com	7339941241	5	9398387487512084	2011/06	user2160	password	67	20000	F
2161	LGPAPE	OMZRTTLYAI	6395695223 Dell Way	\N	NYFVDYR	SD	87402	US	1	OMZRTTLYAI@dell.com	6395695223	3	3626547800842673	2009/08	user2161	password	64	80000	M
2162	FSMKHY	JZRDKQETED	1404982196 Dell Way	\N	YZGXQBT	IA	58248	US	1	JZRDKQETED@dell.com	1404982196	3	2737470396328717	2011/03	user2162	password	24	100000	M
2163	PHFNRE	FVPWAJADHA	2555984699 Dell Way	\N	JEQLYXZ	WY	46823	US	1	FVPWAJADHA@dell.com	2555984699	4	6735124704428018	2009/08	user2163	password	59	100000	M
2164	UJPZPK	PLKYMOFMXK	1530425918 Dell Way	\N	DJJAIJK	MT	12320	US	1	PLKYMOFMXK@dell.com	1530425918	4	6484168578870595	2011/08	user2164	password	54	60000	F
2165	BKPMZB	XXOLDAJOES	9065776939 Dell Way	\N	XEBGPPH	NV	43055	US	1	XXOLDAJOES@dell.com	9065776939	2	1022304902318865	2009/09	user2165	password	19	60000	F
2166	QYBSVZ	GHCHQQLJOQ	4341393312 Dell Way	\N	KVFACWJ	AK	23623	US	1	GHCHQQLJOQ@dell.com	4341393312	2	8705006043426693	2009/11	user2166	password	87	20000	M
2167	ASRZYY	CGPTRYHHJC	4471980690 Dell Way	\N	NJFJSFN	CO	64949	US	1	CGPTRYHHJC@dell.com	4471980690	3	5290460349991918	2009/07	user2167	password	39	40000	F
2168	YJEXLK	MECKLKUOXD	1759765945 Dell Way	\N	UHWZVZP	GA	50367	US	1	MECKLKUOXD@dell.com	1759765945	3	9548091861419380	2009/11	user2168	password	29	40000	F
2169	IGRTTW	VEIGYWDBRL	3681905707 Dell Way	\N	YRGXGLJ	KY	99990	US	1	VEIGYWDBRL@dell.com	3681905707	4	9097653317730876	2010/01	user2169	password	28	80000	F
2170	VOBRKF	ZQDWUFNFDE	8517743413 Dell Way	\N	MBLYKUY	OH	57542	US	1	ZQDWUFNFDE@dell.com	8517743413	1	6392019519582391	2012/12	user2170	password	84	100000	F
2171	ZMXEMN	IIHNWNRBZS	4871309615 Dell Way	\N	NYDHWVV	OK	98109	US	1	IIHNWNRBZS@dell.com	4871309615	4	9388659915886820	2009/06	user2171	password	49	40000	M
2172	IMMVUV	DIRRATRTGP	6303873975 Dell Way	\N	WOMRJER	SD	87099	US	1	DIRRATRTGP@dell.com	6303873975	1	4201462199911475	2008/06	user2172	password	43	40000	M
2173	VETQHC	HYCBQVHFRV	1479737494 Dell Way	\N	RJFVAAS	NH	25504	US	1	HYCBQVHFRV@dell.com	1479737494	4	6754922675900162	2009/12	user2173	password	61	40000	F
2174	IVKLDJ	NEZIMFZIWI	4156863518 Dell Way	\N	NSIOKYS	MO	59392	US	1	NEZIMFZIWI@dell.com	4156863518	5	5468382392544300	2012/01	user2174	password	62	40000	M
2175	ASBKFG	KOSQNANWOF	2681160343 Dell Way	\N	FCQDUDR	DC	99739	US	1	KOSQNANWOF@dell.com	2681160343	1	1706821058876812	2011/05	user2175	password	90	100000	F
2176	BGIHRW	AHJAUGOALQ	8909316274 Dell Way	\N	RPLUHPU	MN	71397	US	1	AHJAUGOALQ@dell.com	8909316274	2	1535450336989015	2012/02	user2176	password	28	100000	F
2177	LFAHFH	RGCXUDJLUY	3193968402 Dell Way	\N	XPFNKRE	IL	95946	US	1	RGCXUDJLUY@dell.com	3193968402	1	1465287189930677	2009/01	user2177	password	46	100000	F
2178	KEMSVS	UTNXDZSBXI	1024748009 Dell Way	\N	HKSZPAY	TN	24839	US	1	UTNXDZSBXI@dell.com	1024748009	2	3146041396539658	2009/01	user2178	password	55	100000	F
2179	ANBTIV	HGYGYAEHIO	4838834916 Dell Way	\N	AIEAHZE	IL	30176	US	1	HGYGYAEHIO@dell.com	4838834916	4	3722009945660830	2012/06	user2179	password	57	100000	F
2180	PSILZO	KGNLKUUZVD	7004127054 Dell Way	\N	DVKDASJ	MI	44829	US	1	KGNLKUUZVD@dell.com	7004127054	2	8954383768606932	2009/05	user2180	password	83	100000	F
2181	FGAURG	HDQCXQXAUT	4585723019 Dell Way	\N	LXTDHFN	WI	64586	US	1	HDQCXQXAUT@dell.com	4585723019	1	9632417197804900	2009/12	user2181	password	18	60000	F
2182	AHXGOA	XRYOOYIHKG	8520494668 Dell Way	\N	BNNHALW	MI	64479	US	1	XRYOOYIHKG@dell.com	8520494668	4	6176080294884742	2012/03	user2182	password	77	100000	M
2183	SDCTBT	SPHRXPBDRO	3692389766 Dell Way	\N	RYPDVAS	NM	78530	US	1	SPHRXPBDRO@dell.com	3692389766	3	9930432445835324	2008/05	user2183	password	54	100000	F
2184	PPNIHD	QYBGAFXPWV	9825864293 Dell Way	\N	EZQFSHZ	AK	78860	US	1	QYBGAFXPWV@dell.com	9825864293	1	2023249541874975	2010/12	user2184	password	61	20000	M
2185	DKWGAV	HGVMEKJZPJ	7991032832 Dell Way	\N	QVBXVBR	SC	26006	US	1	HGVMEKJZPJ@dell.com	7991032832	2	2222403137944638	2009/05	user2185	password	68	60000	M
2186	OTUJBB	FOFQXEFGUB	7109323451 Dell Way	\N	HSWJJRO	DC	97412	US	1	FOFQXEFGUB@dell.com	7109323451	3	3945126397069544	2009/01	user2186	password	23	100000	M
2187	WHUXNI	CDGHJMCKUU	3607846668 Dell Way	\N	HEDZSHZ	MA	81541	US	1	CDGHJMCKUU@dell.com	3607846668	4	8168309476692230	2009/09	user2187	password	57	40000	M
2188	IDMRGQ	XNZJPKEKSI	4756847133 Dell Way	\N	OSAVRKQ	WI	25421	US	1	XNZJPKEKSI@dell.com	4756847133	2	8680382794700564	2012/07	user2188	password	79	40000	M
2189	IYYYVL	YFBJKLBTZU	2956740819 Dell Way	\N	UVLFLKJ	TX	75371	US	1	YFBJKLBTZU@dell.com	2956740819	5	3577197950333357	2008/02	user2189	password	89	40000	F
2190	XIXJHD	LQNXSHWMBS	3823888680 Dell Way	\N	XGDHPAA	SD	84401	US	1	LQNXSHWMBS@dell.com	3823888680	5	9414401599671692	2009/04	user2190	password	90	40000	M
2191	XPWAAN	OXFVURWMOC	4597465144 Dell Way	\N	QWSQXNM	GA	45880	US	1	OXFVURWMOC@dell.com	4597465144	3	6919762524776161	2009/09	user2191	password	36	40000	F
2192	DHHQWF	WRZNOMCQCY	9372436901 Dell Way	\N	JSWWFBH	NH	61311	US	1	WRZNOMCQCY@dell.com	9372436901	5	3576550594996661	2008/04	user2192	password	60	40000	M
2193	WZLCVC	BIQNKHPJQI	2188914543 Dell Way	\N	FNOHUDV	OK	21082	US	1	BIQNKHPJQI@dell.com	2188914543	5	4542049364652485	2011/03	user2193	password	88	60000	F
2194	KRAMTI	DGTLWCBFIP	4751979799 Dell Way	\N	TPJXLCA	ND	98073	US	1	DGTLWCBFIP@dell.com	4751979799	2	2817473713308573	2009/11	user2194	password	46	80000	M
2195	KHHSLO	MWLOYQWNKL	2140700180 Dell Way	\N	WIXYILY	PA	76146	US	1	MWLOYQWNKL@dell.com	2140700180	1	6470670206937940	2010/12	user2195	password	29	100000	F
2196	LQQZCM	LRKBNXMZUU	7174078506 Dell Way	\N	XSDIQXC	RI	13015	US	1	LRKBNXMZUU@dell.com	7174078506	2	9573163483291864	2012/03	user2196	password	29	40000	M
2197	UHYGSP	RUDOHDICAB	2014561020 Dell Way	\N	GJSDLME	CT	79865	US	1	RUDOHDICAB@dell.com	2014561020	5	9846640294883400	2009/04	user2197	password	78	20000	M
2198	UHHJYB	NNJRWLRXRA	8830556835 Dell Way	\N	QVMCZPX	CA	61776	US	1	NNJRWLRXRA@dell.com	8830556835	2	8558105210773648	2011/05	user2198	password	46	60000	M
2199	RWQTJD	CAZOSXGTOB	3125726555 Dell Way	\N	FQAVOCK	MD	49282	US	1	CAZOSXGTOB@dell.com	3125726555	1	8390964952763171	2011/07	user2199	password	54	40000	F
2200	DBUGEV	GSNEYHSZMJ	4134411555 Dell Way	\N	ZIXCSIN	WI	48387	US	1	GSNEYHSZMJ@dell.com	4134411555	3	1050799500662833	2012/11	user2200	password	49	100000	M
2201	GGCCNU	QRTXKTKUTS	4967964349 Dell Way	\N	RVKAJJL	OK	95376	US	1	QRTXKTKUTS@dell.com	4967964349	3	8528840286191554	2012/07	user2201	password	74	20000	M
2202	WFHRVZ	LSJECDXUVT	4375761437 Dell Way	\N	FWCPHVO	OR	42539	US	1	LSJECDXUVT@dell.com	4375761437	4	9004337359219790	2008/09	user2202	password	66	20000	M
2203	YSTXDL	HHOLFJHZPD	2124062215 Dell Way	\N	BEKWSDG	CA	76427	US	1	HHOLFJHZPD@dell.com	2124062215	2	5179389957338572	2011/04	user2203	password	46	80000	M
2204	DQCPXK	DIQMPPBTRG	5284789942 Dell Way	\N	DNYHTBA	VA	34640	US	1	DIQMPPBTRG@dell.com	5284789942	4	5795507537666709	2012/05	user2204	password	54	100000	F
2205	PPYZSH	QFXFHQWOTK	4058054202 Dell Way	\N	MAENBBU	MT	74773	US	1	QFXFHQWOTK@dell.com	4058054202	2	2062493558041751	2012/05	user2205	password	28	60000	M
2206	CKSJBX	GGFWCTQNGQ	5922464084 Dell Way	\N	RUSSPFL	WA	64001	US	1	GGFWCTQNGQ@dell.com	5922464084	4	9874774521682412	2011/03	user2206	password	87	80000	M
2207	QDQOJX	UGANWNTNEN	9962286615 Dell Way	\N	FXDKIBA	UT	81896	US	1	UGANWNTNEN@dell.com	9962286615	3	9836670490447432	2012/05	user2207	password	60	80000	F
2208	GEVDYB	DMYRFLWTQT	7378430743 Dell Way	\N	XABYBYS	AR	54901	US	1	DMYRFLWTQT@dell.com	7378430743	5	8522282465361060	2009/08	user2208	password	40	60000	M
2209	DRSFVE	DMKOIEFBBG	4711132384 Dell Way	\N	DZHCSIO	ME	38221	US	1	DMKOIEFBBG@dell.com	4711132384	4	9214544242247940	2011/03	user2209	password	67	100000	M
2210	KCSPFF	ZUNEAPFGTF	1610652055 Dell Way	\N	NVXVKIE	SD	15420	US	1	ZUNEAPFGTF@dell.com	1610652055	3	3777786901220679	2011/05	user2210	password	34	20000	F
2211	YSSDSN	RWNGCTAHHV	9317494180 Dell Way	\N	FCFOGAQ	KY	59565	US	1	RWNGCTAHHV@dell.com	9317494180	1	9426204727496952	2008/03	user2211	password	47	20000	M
2212	CFRPXO	CEQWEYDZDG	7486323753 Dell Way	\N	FSNGIWU	IA	94308	US	1	CEQWEYDZDG@dell.com	7486323753	2	2554947736673057	2008/06	user2212	password	27	40000	M
2213	VVPJYT	ZUXYYXBECT	6881801421 Dell Way	\N	SICOCIM	TN	73379	US	1	ZUXYYXBECT@dell.com	6881801421	5	2555839403532445	2011/03	user2213	password	81	80000	F
2214	LYYEYT	CWRZYWBSOK	9941241165 Dell Way	\N	UCNDPJV	IA	38029	US	1	CWRZYWBSOK@dell.com	9941241165	1	5464325957931578	2012/08	user2214	password	55	40000	M
2215	MMOFPK	XOJUQCIBWL	7558744327 Dell Way	\N	OZBXVHG	SD	38433	US	1	XOJUQCIBWL@dell.com	7558744327	4	9536809723358602	2009/12	user2215	password	57	80000	F
2216	CXBNVQ	WPHYYIVKXV	9927211008 Dell Way	\N	LVQSBLB	RI	18958	US	1	WPHYYIVKXV@dell.com	9927211008	1	1668888387270271	2010/09	user2216	password	58	80000	M
2217	PDMGZC	NYAWTLTPWP	8396844828 Dell Way	\N	FPQQQKT	NM	49819	US	1	NYAWTLTPWP@dell.com	8396844828	1	2487280590459704	2009/10	user2217	password	76	100000	M
2218	HGXJTV	KQPVJESZKH	6686006668 Dell Way	\N	PBYAUPM	NJ	77638	US	1	KQPVJESZKH@dell.com	6686006668	5	5828699664678425	2010/12	user2218	password	50	80000	F
2219	ICZEMP	UHZZZYJHNL	1795729686 Dell Way	\N	FOFUAVO	NV	84989	US	1	UHZZZYJHNL@dell.com	1795729686	1	8263088764622808	2010/10	user2219	password	18	100000	M
2220	ZBJOVQ	NUQMEXAPCO	3603455087 Dell Way	\N	UXPQMGM	ND	41140	US	1	NUQMEXAPCO@dell.com	3603455087	1	2474562728777528	2009/12	user2220	password	22	40000	M
2221	KVVBJP	RVTOVJRKEP	7672250002 Dell Way	\N	ZUBGHQP	NE	73528	US	1	RVTOVJRKEP@dell.com	7672250002	5	6908038815483452	2012/02	user2221	password	65	40000	M
2222	LHJBYF	VNAEFLIVKD	8867883160 Dell Way	\N	XQKNFZF	WV	88171	US	1	VNAEFLIVKD@dell.com	8867883160	4	1202425497118383	2010/12	user2222	password	19	100000	F
2223	JBFPWT	PBZBJULNRC	8233237706 Dell Way	\N	XFIXKHU	IL	15072	US	1	PBZBJULNRC@dell.com	8233237706	5	1347369276918470	2012/10	user2223	password	39	40000	M
2224	NUSGKT	GLDAXQSAOX	7444909746 Dell Way	\N	ILIQGPR	AR	45998	US	1	GLDAXQSAOX@dell.com	7444909746	5	2709264219272882	2008/01	user2224	password	19	60000	M
2225	SUGMAR	PBPFTPTQXF	2295539936 Dell Way	\N	YNLOFNY	WA	42655	US	1	PBPFTPTQXF@dell.com	2295539936	5	4830905769951642	2008/06	user2225	password	37	100000	F
2226	NJHEZI	TFCJZTGESU	9457880937 Dell Way	\N	QGZDFYN	LA	87628	US	1	TFCJZTGESU@dell.com	9457880937	3	3981384729035199	2009/06	user2226	password	61	80000	M
2227	WXUFRZ	IAYBHDUCUB	2754948973 Dell Way	\N	CYGALQW	MD	23468	US	1	IAYBHDUCUB@dell.com	2754948973	4	6210253687109799	2011/04	user2227	password	46	80000	F
2228	EXXEFY	CHGGBIBCKZ	7307487891 Dell Way	\N	JKLZGVD	MI	49471	US	1	CHGGBIBCKZ@dell.com	7307487891	2	7881944830995054	2008/11	user2228	password	18	40000	M
2229	XKAWNH	CTJKULUUUF	3328574148 Dell Way	\N	FULBXXM	NH	22554	US	1	CTJKULUUUF@dell.com	3328574148	4	1455195969436317	2009/12	user2229	password	80	20000	F
2230	WBWEDQ	NOLZJGUOLO	1784246257 Dell Way	\N	ZNLXABA	ID	75325	US	1	NOLZJGUOLO@dell.com	1784246257	3	7001475666183979	2012/09	user2230	password	19	100000	M
2231	XZWNNL	ZMUFGIRVIE	7256940937 Dell Way	\N	GFEHGLA	LA	96563	US	1	ZMUFGIRVIE@dell.com	7256940937	2	6965845021419228	2011/02	user2231	password	47	80000	F
2232	HDQSDC	NIJWZEEELK	4674133104 Dell Way	\N	ITRUUAT	MO	40218	US	1	NIJWZEEELK@dell.com	4674133104	1	5062193353194744	2012/10	user2232	password	58	20000	M
2233	EVBHIK	RFKWJOHUXB	3772580859 Dell Way	\N	MRVNLIW	TN	55699	US	1	RFKWJOHUXB@dell.com	3772580859	4	3781935243401676	2012/10	user2233	password	36	20000	M
2234	IIYSZD	CWNRDIOFUG	2632975598 Dell Way	\N	BIRJENW	MO	24515	US	1	CWNRDIOFUG@dell.com	2632975598	2	9265219694934786	2010/05	user2234	password	54	80000	M
2235	LMSOOO	CFSKUYFAZN	3506126829 Dell Way	\N	RIRFFEJ	MD	56394	US	1	CFSKUYFAZN@dell.com	3506126829	5	9150209250394256	2011/07	user2235	password	63	40000	F
2236	IUPXWV	QHPOMQNZIW	3333267980 Dell Way	\N	RNCVWMJ	DC	37855	US	1	QHPOMQNZIW@dell.com	3333267980	5	9008980765938760	2012/02	user2236	password	86	40000	M
2237	ODVJTC	ZIPPVOXSGK	5306460988 Dell Way	\N	UBHHLLP	NY	42720	US	1	ZIPPVOXSGK@dell.com	5306460988	3	5688098879996688	2010/10	user2237	password	52	100000	M
2238	HISKHA	ZWWOUOUEJW	8010592916 Dell Way	\N	MQHXGZG	OK	58653	US	1	ZWWOUOUEJW@dell.com	8010592916	1	4059944481123239	2009/01	user2238	password	38	60000	F
2239	ZZRZYO	VNIKHMTEZK	3679993191 Dell Way	\N	LWQKCJY	VA	53526	US	1	VNIKHMTEZK@dell.com	3679993191	1	6018400699365885	2010/09	user2239	password	87	60000	M
2240	QNQEJD	MTLZNPYYBU	9952900585 Dell Way	\N	PMXYLUL	OK	95003	US	1	MTLZNPYYBU@dell.com	9952900585	2	6803841499611736	2012/11	user2240	password	40	60000	F
2241	YSSBFM	NEADCZEXOQ	2682268120 Dell Way	\N	UNBPYUO	WI	16792	US	1	NEADCZEXOQ@dell.com	2682268120	5	9243278734851628	2010/06	user2241	password	38	60000	F
2242	ANJNAN	NDQNINBYIP	8008568557 Dell Way	\N	AXOUMNW	NV	45399	US	1	NDQNINBYIP@dell.com	8008568557	1	8604778614826501	2008/08	user2242	password	19	20000	F
2243	JPDXDH	OQPBSNKHOI	6155977511 Dell Way	\N	VIUIFLS	WV	61653	US	1	OQPBSNKHOI@dell.com	6155977511	1	2431560346856713	2010/02	user2243	password	36	100000	M
2244	JWVRLL	GMDUXKIFGR	2179941376 Dell Way	\N	ZPWKHVZ	UT	87670	US	1	GMDUXKIFGR@dell.com	2179941376	3	9765243427827956	2009/06	user2244	password	66	80000	F
2245	MLTXRG	ALDLUIRLHG	9648586848 Dell Way	\N	HRODRLZ	SC	91857	US	1	ALDLUIRLHG@dell.com	9648586848	1	4106018914375454	2011/12	user2245	password	66	20000	F
2246	KABQBN	TMHBESJKAA	7104628270 Dell Way	\N	ZDSLDMI	CO	69189	US	1	TMHBESJKAA@dell.com	7104628270	4	6442928127478809	2009/10	user2246	password	89	80000	M
2247	AJWNDJ	VENONYPOXS	1078504163 Dell Way	\N	GIWTRZK	KY	72276	US	1	VENONYPOXS@dell.com	1078504163	4	5703326166141779	2012/06	user2247	password	44	20000	M
2248	GOXPJC	CXQBMFYFMH	3416507659 Dell Way	\N	CFYBQHT	NM	98750	US	1	CXQBMFYFMH@dell.com	3416507659	4	4697770264465362	2011/08	user2248	password	33	100000	F
2249	DMOFPM	WQZCOEOWHU	5588746404 Dell Way	\N	VIKCCAC	KY	68966	US	1	WQZCOEOWHU@dell.com	5588746404	5	3644536303821951	2011/11	user2249	password	53	100000	F
2250	ABXNYN	MACROYYITH	7500463249 Dell Way	\N	TWJUZSL	MO	72016	US	1	MACROYYITH@dell.com	7500463249	2	5867473829071969	2009/01	user2250	password	80	40000	F
2251	TTBHFB	JXQIVZCDSY	4803952230 Dell Way	\N	MMYFXKW	NM	65062	US	1	JXQIVZCDSY@dell.com	4803952230	5	6892565725836904	2009/02	user2251	password	74	20000	M
2252	VIBXSY	NAUNCXFBKS	7018531334 Dell Way	\N	ZPQKMHA	VA	21096	US	1	NAUNCXFBKS@dell.com	7018531334	1	2870094538666308	2010/03	user2252	password	20	40000	M
2253	CDGBRH	VEJTKLDDLS	4266321727 Dell Way	\N	TVFAVCE	MT	33630	US	1	VEJTKLDDLS@dell.com	4266321727	5	5359990332275629	2010/03	user2253	password	20	60000	F
2254	HOAOJF	YDQJGTUZMQ	1214089137 Dell Way	\N	ENMHRZO	AR	95490	US	1	YDQJGTUZMQ@dell.com	1214089137	3	2455213675275445	2008/12	user2254	password	56	40000	F
2255	OXWUVA	KFGDAGQRLE	3215860579 Dell Way	\N	DSWDGXC	IL	40603	US	1	KFGDAGQRLE@dell.com	3215860579	2	3591225605923682	2011/09	user2255	password	75	40000	M
2256	RCLRNQ	YQREHIQLLJ	8378950806 Dell Way	\N	HPQERYN	VT	35689	US	1	YQREHIQLLJ@dell.com	8378950806	4	9814826471265406	2011/01	user2256	password	59	40000	F
2257	AXQQVH	IAOQRACBIR	8980836598 Dell Way	\N	RNIQBGX	UT	95044	US	1	IAOQRACBIR@dell.com	8980836598	3	9658051773440094	2010/09	user2257	password	24	60000	M
2258	SDMALN	PBEPDGYUYL	3781526390 Dell Way	\N	DONKLKJ	KY	87371	US	1	PBEPDGYUYL@dell.com	3781526390	5	6316324291285128	2009/04	user2258	password	35	20000	F
2259	SDVGSW	LIARGVPSYD	1693641790 Dell Way	\N	GJPQSYM	AL	76922	US	1	LIARGVPSYD@dell.com	1693641790	3	1121571136172860	2009/07	user2259	password	47	20000	M
2260	FHJCSS	CKZXZRWDYG	4851267445 Dell Way	\N	SOYRBZK	CT	45484	US	1	CKZXZRWDYG@dell.com	4851267445	3	9367128872778268	2012/06	user2260	password	61	20000	M
2261	ZDMRGW	QEVIBZGHSV	6041129667 Dell Way	\N	GJWGUZQ	GA	48042	US	1	QEVIBZGHSV@dell.com	6041129667	1	9074567180126906	2008/02	user2261	password	65	20000	F
2262	DUMZKQ	VTSUAAMVGW	9934615149 Dell Way	\N	RMQRDWC	NY	92155	US	1	VTSUAAMVGW@dell.com	9934615149	5	1043519930914044	2011/12	user2262	password	35	80000	M
2263	STEJOX	BJYBWTISLV	2433150276 Dell Way	\N	JCYGFQE	GA	52753	US	1	BJYBWTISLV@dell.com	2433150276	5	4922000662423670	2009/08	user2263	password	31	20000	F
2264	JMXHOH	FQDYYWKTFN	3378261546 Dell Way	\N	SMSJQXV	RI	77700	US	1	FQDYYWKTFN@dell.com	3378261546	1	4256784730590880	2010/04	user2264	password	70	100000	M
2265	QCIXHY	BGWXQQDDJP	8974701485 Dell Way	\N	WSFUOZN	SD	23491	US	1	BGWXQQDDJP@dell.com	8974701485	2	4954925612080842	2011/01	user2265	password	33	40000	F
2266	NELMFS	ICJZFNJUJC	5967924807 Dell Way	\N	ZDQZRLC	ND	73347	US	1	ICJZFNJUJC@dell.com	5967924807	1	7981216253247113	2011/05	user2266	password	86	40000	M
2267	KTTCCV	LCBZLVINVM	1772079103 Dell Way	\N	EUDPXSI	MN	87863	US	1	LCBZLVINVM@dell.com	1772079103	2	3353384212590754	2008/07	user2267	password	77	60000	F
2268	ONJKZM	LYXHHLDUQX	7819806660 Dell Way	\N	YFVQNHM	NJ	53927	US	1	LYXHHLDUQX@dell.com	7819806660	4	9967610817402602	2010/01	user2268	password	37	20000	M
2269	QNOCZM	AHULKOCIMH	8988660442 Dell Way	\N	DCVKPMX	LA	19770	US	1	AHULKOCIMH@dell.com	8988660442	5	2506691594608128	2008/01	user2269	password	72	80000	M
2270	HWPUWW	OIGDKPPSSS	3729823434 Dell Way	\N	OCHAARD	VA	62875	US	1	OIGDKPPSSS@dell.com	3729823434	1	6811138562392444	2008/10	user2270	password	35	40000	M
2271	VDORSW	YVHNKAFDPI	3823356287 Dell Way	\N	KPICTGR	AR	34937	US	1	YVHNKAFDPI@dell.com	3823356287	1	1843197175767272	2010/06	user2271	password	74	40000	M
2272	IAHFZC	NMNNSQCBBS	9984424906 Dell Way	\N	KDLQUMX	CT	63120	US	1	NMNNSQCBBS@dell.com	9984424906	4	1216063880361616	2011/01	user2272	password	61	20000	F
2273	WIBYVN	MIGCLHEDRH	7423267760 Dell Way	\N	PHCCFFR	GA	90043	US	1	MIGCLHEDRH@dell.com	7423267760	5	9304894067347052	2009/01	user2273	password	90	20000	F
2274	ADFOPO	URZCWDUDTC	3520240483 Dell Way	\N	GVHMNNJ	IA	53665	US	1	URZCWDUDTC@dell.com	3520240483	3	6099428896792234	2009/09	user2274	password	87	40000	M
2275	EWKSRC	RUYVOCOQIK	5290964768 Dell Way	\N	XUXLEDX	MI	72383	US	1	RUYVOCOQIK@dell.com	5290964768	4	4574045482091606	2010/01	user2275	password	33	60000	M
2276	QHPSZJ	RUXTJOCTLW	9178912650 Dell Way	\N	RXBVUMN	ID	27814	US	1	RUXTJOCTLW@dell.com	9178912650	4	2999463292304426	2008/04	user2276	password	26	80000	M
2277	SMPBDK	ZWTNYNZVEW	8019312623 Dell Way	\N	WZRJNYO	ME	67163	US	1	ZWTNYNZVEW@dell.com	8019312623	3	9424248051829636	2012/04	user2277	password	57	80000	M
2278	DRWNQT	GERUDNYZKY	2319015665 Dell Way	\N	QTLOIWF	CA	45985	US	1	GERUDNYZKY@dell.com	2319015665	5	7187633498571814	2011/08	user2278	password	50	100000	F
2279	IIYBPC	TJFGIFRGWK	6852714625 Dell Way	\N	SLTOQVZ	SC	84679	US	1	TJFGIFRGWK@dell.com	6852714625	3	4926244939677417	2008/04	user2279	password	70	60000	M
2280	QLESFN	YMWDDCAOUL	4518845980 Dell Way	\N	HJCDIWY	WY	40046	US	1	YMWDDCAOUL@dell.com	4518845980	1	6454697765409947	2008/06	user2280	password	32	80000	M
2281	JMDXKP	TOTWPHRAPA	9128085233 Dell Way	\N	CSJZRIH	AZ	46855	US	1	TOTWPHRAPA@dell.com	9128085233	1	8948497032281012	2008/11	user2281	password	77	60000	F
2282	YJVODK	HZZPQZERCX	6918228141 Dell Way	\N	ABOJJQU	ID	80906	US	1	HZZPQZERCX@dell.com	6918228141	2	7339995597954840	2010/10	user2282	password	25	60000	F
2283	XZIIHH	HWYHBPJYQL	6501500020 Dell Way	\N	MAUDUBX	MI	46981	US	1	HWYHBPJYQL@dell.com	6501500020	5	3121103847399354	2011/04	user2283	password	49	80000	F
2284	TYPBFL	ANMPXKGIXG	8383840146 Dell Way	\N	DBAEYLP	ND	43062	US	1	ANMPXKGIXG@dell.com	8383840146	2	7268051078543068	2009/11	user2284	password	18	20000	M
2285	PBBABO	NRLYYUWEXX	7607624846 Dell Way	\N	FBVRQKA	MO	69839	US	1	NRLYYUWEXX@dell.com	7607624846	4	6032538878731430	2011/09	user2285	password	46	40000	M
2286	LJWAWO	LUMFQRDOWF	1071863344 Dell Way	\N	KOWUPIL	KS	14263	US	1	LUMFQRDOWF@dell.com	1071863344	1	8052649803459645	2009/05	user2286	password	60	100000	M
2287	LWPAHJ	NNAERPBWZP	8655417191 Dell Way	\N	STEAFMB	GA	60070	US	1	NNAERPBWZP@dell.com	8655417191	4	9413413561880588	2010/06	user2287	password	66	100000	F
2288	GXPQKD	RPUGQQFFJZ	4547700133 Dell Way	\N	KJEXLJL	IL	98954	US	1	RPUGQQFFJZ@dell.com	4547700133	4	4947978024370969	2008/08	user2288	password	71	40000	M
2289	IYYMPO	HWEYBKHBUR	1228382989 Dell Way	\N	FSCPEKP	ND	20228	US	1	HWEYBKHBUR@dell.com	1228382989	4	7655264712870122	2011/11	user2289	password	38	20000	M
2290	GPLUWI	YVKICLDTQV	1828653572 Dell Way	\N	WGZGVOJ	TX	24484	US	1	YVKICLDTQV@dell.com	1828653572	4	1678362087812274	2009/09	user2290	password	85	80000	F
2291	JJFSIA	CRCNUWEQSK	4706743401 Dell Way	\N	QYGEHCI	MA	75860	US	1	CRCNUWEQSK@dell.com	4706743401	4	5166415357962251	2009/05	user2291	password	75	80000	M
2292	ZKBZNS	CANYEDQPUP	2330397820 Dell Way	\N	VYXYHHR	OH	14413	US	1	CANYEDQPUP@dell.com	2330397820	1	4757166337221861	2012/10	user2292	password	30	100000	F
2293	GXRYZS	MXWQOMKEII	8294996406 Dell Way	\N	BHQIZIK	CO	42387	US	1	MXWQOMKEII@dell.com	8294996406	1	2054025258403271	2012/12	user2293	password	39	40000	M
2294	ZEVRQT	OHIARMJAOQ	4992847508 Dell Way	\N	QXPZHSI	CA	76894	US	1	OHIARMJAOQ@dell.com	4992847508	1	7278790697921068	2011/04	user2294	password	58	80000	F
2295	JJCDYJ	LYAYIAMYRJ	7091110590 Dell Way	\N	NQQGZTZ	ME	82089	US	1	LYAYIAMYRJ@dell.com	7091110590	1	1665290409233421	2009/11	user2295	password	55	80000	F
2296	PTEYED	ZDLAPJRZXI	3074545577 Dell Way	\N	QDHJDSE	SD	87083	US	1	ZDLAPJRZXI@dell.com	3074545577	1	7438100598752499	2011/08	user2296	password	87	40000	F
2297	DHOGGS	RHHBYHZHXD	8733464197 Dell Way	\N	PGHHKCD	NM	20953	US	1	RHHBYHZHXD@dell.com	8733464197	2	7855390580371023	2012/09	user2297	password	28	100000	F
2298	SEHKWO	SYNZYVWCKD	3939497580 Dell Way	\N	JROLVEO	NY	60639	US	1	SYNZYVWCKD@dell.com	3939497580	3	3594326629303396	2010/06	user2298	password	40	20000	M
2299	POMEHL	RGJMDLXHUO	8570410033 Dell Way	\N	VGKZUBO	CT	60998	US	1	RGJMDLXHUO@dell.com	8570410033	3	9954883966129274	2008/10	user2299	password	62	80000	F
2300	CXQNPX	WCAIZHDOCJ	6153859257 Dell Way	\N	YCEAQHP	MS	90901	US	1	WCAIZHDOCJ@dell.com	6153859257	4	7027363228611649	2008/05	user2300	password	19	40000	F
2301	QUXNRZ	OZZWCNYMLB	5518593424 Dell Way	\N	QMSYBFV	NJ	85780	US	1	OZZWCNYMLB@dell.com	5518593424	4	3073430771473795	2010/01	user2301	password	56	20000	M
2302	KRNKGM	JCPWABICSU	1661070460 Dell Way	\N	UQVAMLV	WV	31416	US	1	JCPWABICSU@dell.com	1661070460	3	3677743937354535	2011/08	user2302	password	28	20000	F
2303	QKODUQ	TRRUZTNUOD	6396848162 Dell Way	\N	QOPBKOH	MO	13682	US	1	TRRUZTNUOD@dell.com	6396848162	1	7107939352281392	2011/02	user2303	password	90	40000	M
2304	ONHEHZ	WCYQPTESJT	6272924104 Dell Way	\N	HLEWSQX	KS	75903	US	1	WCYQPTESJT@dell.com	6272924104	1	8510236128233374	2010/06	user2304	password	43	20000	M
2305	RIGQEJ	PUYIZQSSYD	1949121243 Dell Way	\N	XVWOSEH	IN	32364	US	1	PUYIZQSSYD@dell.com	1949121243	5	7381884368602187	2010/01	user2305	password	69	20000	F
2306	ZTNIIH	GRHXJZVMXQ	5261022791 Dell Way	\N	ILJNSRT	SC	61728	US	1	GRHXJZVMXQ@dell.com	5261022791	2	6392022893298418	2008/05	user2306	password	86	20000	F
2307	LMMTSD	APNALZXCII	4023761380 Dell Way	\N	MWAEPVT	CA	18530	US	1	APNALZXCII@dell.com	4023761380	2	5329821323044598	2009/05	user2307	password	63	80000	M
2308	CMPGMF	TMRTKTBSGY	2427641052 Dell Way	\N	TKNPDQR	MO	89960	US	1	TMRTKTBSGY@dell.com	2427641052	4	3715088962111622	2011/06	user2308	password	31	100000	M
2309	UCLAWX	RPILRBRPUB	9473735009 Dell Way	\N	DJFTBSQ	HI	50647	US	1	RPILRBRPUB@dell.com	9473735009	5	9349247968290002	2008/11	user2309	password	81	100000	M
2310	HXVFOK	NABPRRJTUT	1430571337 Dell Way	\N	ZNVREAD	CO	12444	US	1	NABPRRJTUT@dell.com	1430571337	2	8983030427247287	2012/02	user2310	password	80	40000	F
2311	RLQBZQ	DOIUYBOSBC	5177511489 Dell Way	\N	NSHOVKP	UT	67481	US	1	DOIUYBOSBC@dell.com	5177511489	5	8154391280375422	2009/01	user2311	password	81	100000	F
2312	NBLEEZ	MYXONPPQDI	7711376902 Dell Way	\N	XRDIGAY	OK	84994	US	1	MYXONPPQDI@dell.com	7711376902	1	8645936693064869	2011/01	user2312	password	39	20000	F
2313	SHFSTE	QISGYJJGGA	2045300401 Dell Way	\N	KOHLNAG	ID	14106	US	1	QISGYJJGGA@dell.com	2045300401	5	1497908471617847	2010/01	user2313	password	25	20000	F
2314	IVBNMJ	FSIOBOVCZK	5520927311 Dell Way	\N	KKYKRFL	RI	16978	US	1	FSIOBOVCZK@dell.com	5520927311	1	1731607867870479	2011/05	user2314	password	44	100000	F
2315	KLQURI	DFKRBMQLXA	7569274474 Dell Way	\N	JHSOTMQ	IA	70561	US	1	DFKRBMQLXA@dell.com	7569274474	5	1083794347010552	2008/10	user2315	password	31	60000	F
2316	VIWELC	PDECTPZUZG	6943428115 Dell Way	\N	NOZZFGQ	WA	17660	US	1	PDECTPZUZG@dell.com	6943428115	1	8793704424053431	2012/07	user2316	password	24	80000	M
2317	ZWIBLL	FOFVNAVUNJ	9721749887 Dell Way	\N	UMOADMC	SC	56476	US	1	FOFVNAVUNJ@dell.com	9721749887	4	1577493196353316	2008/05	user2317	password	86	20000	F
2318	GCRRIF	XESXZNKIHW	9720252074 Dell Way	\N	XHAKKUX	MA	50608	US	1	XESXZNKIHW@dell.com	9720252074	3	8067365005612374	2012/06	user2318	password	90	20000	M
2319	RWXWTB	PQACBJJXGR	9821186868 Dell Way	\N	YRCTOMF	NC	91146	US	1	PQACBJJXGR@dell.com	9821186868	3	4255513874813914	2012/08	user2319	password	85	80000	F
2320	VMFWCV	XEWHOUOGTF	1741398186 Dell Way	\N	JMTVRHS	NV	75870	US	1	XEWHOUOGTF@dell.com	1741398186	4	3959768982604146	2008/04	user2320	password	74	100000	M
2321	ZSVUPA	RWPMKWFQFS	7683289279 Dell Way	\N	KAJRTAK	TN	69142	US	1	RWPMKWFQFS@dell.com	7683289279	5	9226468471810224	2010/08	user2321	password	66	60000	F
2322	NHYNZV	DMGZRWFJGF	4202852900 Dell Way	\N	TYZUJUL	CO	66153	US	1	DMGZRWFJGF@dell.com	4202852900	4	3520192643627524	2008/02	user2322	password	64	60000	F
2323	PBKKFW	RENOJXUPRT	3336774406 Dell Way	\N	OLCJXFZ	IA	84547	US	1	RENOJXUPRT@dell.com	3336774406	2	9454031627625228	2012/10	user2323	password	43	60000	M
2324	TXBPOG	CCQAXGRRVD	7665645129 Dell Way	\N	TEAZDHU	MD	59451	US	1	CCQAXGRRVD@dell.com	7665645129	2	4158373103011400	2008/10	user2324	password	34	100000	M
2325	HKFONI	EOGLFXGJRK	6220002766 Dell Way	\N	KQORLYF	DE	32611	US	1	EOGLFXGJRK@dell.com	6220002766	2	1215473220217973	2011/02	user2325	password	68	20000	F
2326	XQAGVO	MGUJMDAXOR	7177894598 Dell Way	\N	LFCKLHR	AL	58276	US	1	MGUJMDAXOR@dell.com	7177894598	5	6580594189930708	2009/12	user2326	password	25	40000	M
2327	CNJRAQ	LKDPKBDCMJ	6572081109 Dell Way	\N	EXVMOWZ	IA	72695	US	1	LKDPKBDCMJ@dell.com	6572081109	4	6584930680692197	2011/12	user2327	password	31	100000	F
2328	ONMFYW	INHJRJWAOT	1329804114 Dell Way	\N	WAISAPK	NM	29919	US	1	INHJRJWAOT@dell.com	1329804114	2	2277767452411353	2009/03	user2328	password	61	80000	M
2329	BZRXHE	FRWONXDHTD	6323922088 Dell Way	\N	QMDFXUL	WA	23466	US	1	FRWONXDHTD@dell.com	6323922088	1	4192158660385758	2008/12	user2329	password	22	40000	M
2330	SEEXJW	TYKRBRKEIX	6689885745 Dell Way	\N	IOUDASH	NH	87647	US	1	TYKRBRKEIX@dell.com	6689885745	4	8030502128880472	2011/01	user2330	password	66	60000	F
2331	WIPSCN	CTOUETDCCR	3112731868 Dell Way	\N	WFRPNHL	DC	16656	US	1	CTOUETDCCR@dell.com	3112731868	5	2004218279849738	2012/04	user2331	password	41	80000	M
2332	XMRKPL	ZKPTNSVFOB	4323324535 Dell Way	\N	XEPEPSG	TX	59450	US	1	ZKPTNSVFOB@dell.com	4323324535	4	8197819714434446	2011/07	user2332	password	45	60000	M
2333	BAPMZZ	CTNUPSJRPN	3756697165 Dell Way	\N	GUDYBZN	MD	74574	US	1	CTNUPSJRPN@dell.com	3756697165	1	3096340432297438	2011/09	user2333	password	34	80000	M
2334	VFSUHL	HBBALSPYYK	9760052984 Dell Way	\N	BXLAKVT	OK	95087	US	1	HBBALSPYYK@dell.com	9760052984	2	6763682255055756	2009/02	user2334	password	43	20000	F
2335	BVQNDS	ODDGTBEDCC	9965364458 Dell Way	\N	ODMKWFJ	TX	64783	US	1	ODDGTBEDCC@dell.com	9965364458	1	7583535956218839	2009/01	user2335	password	22	40000	M
2336	RXAJLE	MRXOWBQYPU	1074360175 Dell Way	\N	LARRJNH	MA	60668	US	1	MRXOWBQYPU@dell.com	1074360175	4	6765565081965179	2008/02	user2336	password	57	80000	F
2337	PCLTPD	RDZSUYIOKI	9489933720 Dell Way	\N	FBSTICH	LA	81843	US	1	RDZSUYIOKI@dell.com	9489933720	3	9177246684208512	2010/02	user2337	password	84	20000	F
2338	JVWMMZ	METKMIVUOW	3745441870 Dell Way	\N	NHFPPPK	NC	99874	US	1	METKMIVUOW@dell.com	3745441870	1	2400829787831753	2009/02	user2338	password	48	60000	M
2339	GBJGNN	AYAITVXQIE	6176314514 Dell Way	\N	VYUKIIK	NM	41893	US	1	AYAITVXQIE@dell.com	6176314514	5	5044691000599414	2012/06	user2339	password	43	40000	F
2340	SNZGNX	GVQCSGKXCI	8334890380 Dell Way	\N	RNRAYHJ	MT	23875	US	1	GVQCSGKXCI@dell.com	8334890380	3	6217472601216287	2008/10	user2340	password	22	100000	F
2341	BDUZKP	QMIWXGZGYN	9709921513 Dell Way	\N	YYMGHZK	CT	56041	US	1	QMIWXGZGYN@dell.com	9709921513	2	3563059821259230	2008/03	user2341	password	58	20000	F
2342	IATYQG	HNENNKLBJK	3806535638 Dell Way	\N	NPSNZVA	WI	20220	US	1	HNENNKLBJK@dell.com	3806535638	5	3659075875766575	2012/01	user2342	password	63	40000	F
2343	JESQLG	UZUFLVOVJD	8015797806 Dell Way	\N	OWDJXBM	GA	12828	US	1	UZUFLVOVJD@dell.com	8015797806	1	1617899526841938	2010/04	user2343	password	28	80000	F
2344	WKXDFX	XKITZECDSY	4664972711 Dell Way	\N	GCWHOBI	KY	22255	US	1	XKITZECDSY@dell.com	4664972711	4	4814879554323852	2010/07	user2344	password	81	60000	M
2345	UNDRLO	ZENEGQXFXZ	7229607785 Dell Way	\N	BFODNXG	WA	69440	US	1	ZENEGQXFXZ@dell.com	7229607785	3	2835820534266531	2010/11	user2345	password	29	40000	F
2346	HAWWAB	KEIABNXAPD	4134972765 Dell Way	\N	PTQMAPD	OH	16806	US	1	KEIABNXAPD@dell.com	4134972765	2	9778389286249876	2010/08	user2346	password	47	100000	M
2347	HRQIBU	QCWEAXUDMN	4819083191 Dell Way	\N	UZNJCFL	MN	53856	US	1	QCWEAXUDMN@dell.com	4819083191	5	1886308057233691	2012/10	user2347	password	70	20000	F
2348	JLNDBP	AGQXAUJNOJ	8763293542 Dell Way	\N	BYLHJXT	SC	88410	US	1	AGQXAUJNOJ@dell.com	8763293542	4	6788871118798853	2010/09	user2348	password	24	100000	F
2349	PCGFCN	VZNQJBESCC	6452683958 Dell Way	\N	EKMCDHZ	AK	92431	US	1	VZNQJBESCC@dell.com	6452683958	3	6963685633614660	2011/07	user2349	password	79	40000	M
2350	CNRPJR	DZBEDUHGZR	6233151512 Dell Way	\N	SBVAAVX	NM	48598	US	1	DZBEDUHGZR@dell.com	6233151512	2	9585602931678296	2010/08	user2350	password	58	60000	F
2351	GDMYGL	ZLPUSWTKOV	4903793643 Dell Way	\N	FOWBMMM	AZ	82308	US	1	ZLPUSWTKOV@dell.com	4903793643	3	4842649633530528	2012/01	user2351	password	58	40000	F
2352	BELNEW	CZPYSZNOFC	1907774052 Dell Way	\N	KGPWTRR	DE	24381	US	1	CZPYSZNOFC@dell.com	1907774052	1	2722695422824472	2011/05	user2352	password	44	80000	M
2353	UFTRIS	GHLGVZLXJR	5657072578 Dell Way	\N	NGKEYPI	AL	77286	US	1	GHLGVZLXJR@dell.com	5657072578	4	2328998717479408	2012/05	user2353	password	70	80000	M
2354	MIYFOG	QUBQFZAXMG	8413012354 Dell Way	\N	IQEYZFR	MS	91689	US	1	QUBQFZAXMG@dell.com	8413012354	2	3768321565818042	2010/01	user2354	password	85	20000	F
2355	WFYDWS	EMYEMWRTFH	4415609159 Dell Way	\N	YDHEVUB	NM	23876	US	1	EMYEMWRTFH@dell.com	4415609159	1	2734347077086568	2009/03	user2355	password	58	20000	F
2356	MIHFMT	DRGAIAFQZJ	1359277710 Dell Way	\N	XDESFVW	NE	99969	US	1	DRGAIAFQZJ@dell.com	1359277710	5	2886109170503914	2010/01	user2356	password	64	20000	F
2357	YGXSKO	YLWZRMYAKB	2986738431 Dell Way	\N	FCGAYVA	WY	75845	US	1	YLWZRMYAKB@dell.com	2986738431	3	8250026746187360	2012/08	user2357	password	31	80000	M
2358	BMIQLT	MKKZILKKQN	1526094175 Dell Way	\N	RQMNQLG	UT	13153	US	1	MKKZILKKQN@dell.com	1526094175	4	7159841362386943	2009/07	user2358	password	61	40000	M
2359	XYLRLV	CLENWPDJGU	1019811809 Dell Way	\N	VULHBHI	CO	12509	US	1	CLENWPDJGU@dell.com	1019811809	2	5873199452646077	2010/09	user2359	password	56	60000	M
2360	YFCUHN	ZUJOYTVSPP	1187292834 Dell Way	\N	DWQLETM	FL	18905	US	1	ZUJOYTVSPP@dell.com	1187292834	4	7950984362978489	2010/04	user2360	password	47	60000	M
2361	MHUAHP	JVNDRGSHKO	5957226049 Dell Way	\N	YWTRIYU	LA	74509	US	1	JVNDRGSHKO@dell.com	5957226049	5	1191120283678174	2012/06	user2361	password	56	60000	M
2362	ILAXUW	LYNSQUDFSZ	6843035379 Dell Way	\N	ZKIXERQ	OR	64601	US	1	LYNSQUDFSZ@dell.com	6843035379	4	1342832731083035	2008/02	user2362	password	74	60000	M
2363	UKIQVH	DOXYRDRQDB	3654881730 Dell Way	\N	ZAFQRYG	IN	66336	US	1	DOXYRDRQDB@dell.com	3654881730	3	7521790846716613	2008/12	user2363	password	36	100000	F
2364	PMFWQT	UPKXGBAHAB	8363403654 Dell Way	\N	NRSMXAC	GA	56385	US	1	UPKXGBAHAB@dell.com	8363403654	2	5389887017663568	2008/02	user2364	password	80	80000	M
2365	BMHVGW	FECHFKHHXY	1315130096 Dell Way	\N	ZJWAMBO	IL	41285	US	1	FECHFKHHXY@dell.com	1315130096	2	5375343258958310	2012/12	user2365	password	26	100000	F
2366	KUTGZY	JGDTOKRMKB	3192394540 Dell Way	\N	ILNKZUT	AL	23390	US	1	JGDTOKRMKB@dell.com	3192394540	5	2329980745445937	2009/11	user2366	password	64	80000	M
2367	KAQIKX	MDMXVYIWHU	5021864085 Dell Way	\N	JSUDMVH	OK	76207	US	1	MDMXVYIWHU@dell.com	5021864085	1	6567006865050644	2008/11	user2367	password	37	60000	M
2368	YVGVHK	IFFGNBOHKH	3142048412 Dell Way	\N	BOTWWLQ	IN	56288	US	1	IFFGNBOHKH@dell.com	3142048412	2	4139555671717972	2010/11	user2368	password	33	60000	M
2369	LHZWPF	BWSCKAMRCB	7539728370 Dell Way	\N	KZXWPFJ	TN	62669	US	1	BWSCKAMRCB@dell.com	7539728370	2	5132300140336156	2012/10	user2369	password	29	40000	F
2370	DGRJHN	CJYCWQFYBE	1638315705 Dell Way	\N	VXUAHQP	AK	99322	US	1	CJYCWQFYBE@dell.com	1638315705	5	8043176815379412	2009/05	user2370	password	80	40000	M
2371	NTWAVG	YXDPDBQIWN	5730174277 Dell Way	\N	CXVTNVT	NE	78445	US	1	YXDPDBQIWN@dell.com	5730174277	5	1851638774853199	2009/03	user2371	password	66	100000	M
2372	NXSTWQ	XMUYCCVPFS	1820946663 Dell Way	\N	KYFGRUZ	HI	65447	US	1	XMUYCCVPFS@dell.com	1820946663	3	8232710517942906	2011/06	user2372	password	70	40000	F
2373	LBHCYT	WWVYRLDKWC	8577776418 Dell Way	\N	QCUKCAA	FL	63831	US	1	WWVYRLDKWC@dell.com	8577776418	5	1752292891964316	2010/03	user2373	password	53	20000	F
2374	UCFNZC	JYUUCEREUT	6870248510 Dell Way	\N	ZFWZGBO	CA	98953	US	1	JYUUCEREUT@dell.com	6870248510	4	2972541780211031	2008/09	user2374	password	54	100000	M
2375	SLTVUS	PPUUGZPAYU	2144180887 Dell Way	\N	WXBXMDX	CT	82018	US	1	PPUUGZPAYU@dell.com	2144180887	2	5274642210919410	2011/03	user2375	password	37	40000	M
2376	AEKTUA	NPGMEHKYEI	4822914828 Dell Way	\N	ACUDZXY	CT	24546	US	1	NPGMEHKYEI@dell.com	4822914828	4	4055492940358818	2011/02	user2376	password	87	80000	F
2377	JLCJZR	QLWYWVCEVE	4139366873 Dell Way	\N	YZEWXHA	KY	13161	US	1	QLWYWVCEVE@dell.com	4139366873	1	2285613316111266	2009/10	user2377	password	49	80000	F
2378	NBEFSQ	BQMWSRSXPR	5839761513 Dell Way	\N	BLPJLYK	SD	96121	US	1	BQMWSRSXPR@dell.com	5839761513	1	7371840036474169	2012/10	user2378	password	84	60000	M
2379	CSOSUE	FRXWJULAWX	2763381570 Dell Way	\N	PGJNQEM	DE	35438	US	1	FRXWJULAWX@dell.com	2763381570	1	1641546811908483	2008/08	user2379	password	84	20000	F
2380	LXEQCV	NYEIKFFHVL	2719614759 Dell Way	\N	RJBVVGD	AL	44155	US	1	NYEIKFFHVL@dell.com	2719614759	1	1293510247487574	2008/05	user2380	password	47	60000	F
2381	OEJKSH	PASVGAQRRZ	4510531124 Dell Way	\N	TNVZQWJ	TN	99852	US	1	PASVGAQRRZ@dell.com	4510531124	5	4022622779011726	2012/06	user2381	password	60	40000	M
2382	YUJFJK	YFRYVIQVBD	8408549343 Dell Way	\N	QBTMKPM	SC	57172	US	1	YFRYVIQVBD@dell.com	8408549343	3	1121190660633146	2010/12	user2382	password	68	40000	M
2383	BODMMI	DKEMAZOEPP	1610359175 Dell Way	\N	YCANPUB	ME	46458	US	1	DKEMAZOEPP@dell.com	1610359175	5	4425339229404926	2011/02	user2383	password	28	100000	M
2384	HIEQLP	UYQUMVKCTM	7142333846 Dell Way	\N	CHCXIMH	MD	38240	US	1	UYQUMVKCTM@dell.com	7142333846	1	5133430402260274	2012/12	user2384	password	29	20000	F
2385	ITTYNR	PHEKSGDEIK	5858322324 Dell Way	\N	HGTTODC	HI	36021	US	1	PHEKSGDEIK@dell.com	5858322324	1	3410123775247484	2011/02	user2385	password	58	20000	M
2386	IZKAOS	EYKLCPTMWA	9306661056 Dell Way	\N	FQOJSUR	ID	83877	US	1	EYKLCPTMWA@dell.com	9306661056	5	9789817596320064	2010/12	user2386	password	81	80000	M
2387	HUNAZM	KKOAEBWEHN	3590383606 Dell Way	\N	SQGMHMI	HI	50227	US	1	KKOAEBWEHN@dell.com	3590383606	4	4952791122719646	2008/07	user2387	password	47	60000	F
2388	YLHKWR	ZWVATZIHSZ	9018806393 Dell Way	\N	NFGANML	SD	27968	US	1	ZWVATZIHSZ@dell.com	9018806393	5	7364106775261462	2009/05	user2388	password	18	40000	M
2389	HRRYQO	URIUZPNYCS	6523144671 Dell Way	\N	FCGSOAX	MN	99788	US	1	URIUZPNYCS@dell.com	6523144671	4	4540515212342143	2011/12	user2389	password	34	100000	M
2390	XWHMRZ	ULZKZYMRDP	4060330057 Dell Way	\N	XWEYTPY	LA	42937	US	1	ULZKZYMRDP@dell.com	4060330057	5	4259069473948330	2010/11	user2390	password	19	60000	M
2391	IZLHTX	HDWFQOIGME	7682885908 Dell Way	\N	KKYAJIJ	OH	37583	US	1	HDWFQOIGME@dell.com	7682885908	2	2961956169921905	2011/10	user2391	password	18	20000	M
2392	LKMJRQ	GWHUFNHKXR	2627608565 Dell Way	\N	IYBRITZ	AR	11971	US	1	GWHUFNHKXR@dell.com	2627608565	5	8009840972255916	2008/11	user2392	password	54	80000	F
2393	ZAZQGV	XBBKILIAUG	6714191332 Dell Way	\N	CLOVKPW	NH	48514	US	1	XBBKILIAUG@dell.com	6714191332	4	3999883903656155	2008/06	user2393	password	64	20000	F
2394	PTSLQU	MADYJETPGF	5820845519 Dell Way	\N	ECQUYFF	NE	11356	US	1	MADYJETPGF@dell.com	5820845519	4	5036760194692761	2008/11	user2394	password	83	80000	M
2395	QFFKSG	ORPTKFZQJC	9538841911 Dell Way	\N	GDBMJQN	VA	40897	US	1	ORPTKFZQJC@dell.com	9538841911	1	2670174501370638	2012/10	user2395	password	74	60000	F
2396	ZXTGLK	VFVBFMKHSO	5285772632 Dell Way	\N	IFXYSUH	NV	85870	US	1	VFVBFMKHSO@dell.com	5285772632	3	6997155951801688	2009/12	user2396	password	69	40000	M
2397	LLIWHN	SISETAXIIC	5656043992 Dell Way	\N	FHVAOMW	AR	98151	US	1	SISETAXIIC@dell.com	5656043992	2	9642456882167608	2009/07	user2397	password	78	80000	M
2398	EOGSHP	KLJLJRTLWB	7180964236 Dell Way	\N	HXPTTRS	IA	95659	US	1	KLJLJRTLWB@dell.com	7180964236	3	5220194453373552	2010/02	user2398	password	50	80000	M
2399	SKZIVL	RGUIAGFBNC	7660127004 Dell Way	\N	RGVIZBH	NY	59079	US	1	RGUIAGFBNC@dell.com	7660127004	1	7308771939948202	2008/11	user2399	password	48	100000	F
2400	KFCVWI	PEIVJJJLAP	6331782767 Dell Way	\N	HJPIQGX	LA	51028	US	1	PEIVJJJLAP@dell.com	6331782767	3	4059743256773800	2008/06	user2400	password	62	40000	M
2401	SFMAVR	IRBSANTQUC	3384920934 Dell Way	\N	FDSMABY	NJ	63898	US	1	IRBSANTQUC@dell.com	3384920934	4	1282203047536313	2012/01	user2401	password	66	60000	F
2402	EPBVYS	XQTKJJFLOI	8559519518 Dell Way	\N	DAJFYZV	HI	65153	US	1	XQTKJJFLOI@dell.com	8559519518	1	6738320267293603	2010/09	user2402	password	82	80000	F
2403	YNERKV	KUEUAQIIUJ	9495543967 Dell Way	\N	SZISUNH	NM	66908	US	1	KUEUAQIIUJ@dell.com	9495543967	1	3704050997272134	2012/10	user2403	password	58	80000	F
2404	TLSOWN	TQNJZWEIOE	2170916036 Dell Way	\N	RHZFOPV	MT	78538	US	1	TQNJZWEIOE@dell.com	2170916036	2	6208917041774840	2011/02	user2404	password	83	60000	M
2405	QZMDSD	RCCOGLDKCK	3855230154 Dell Way	\N	JHZZDMT	ID	85028	US	1	RCCOGLDKCK@dell.com	3855230154	5	9654641872737558	2009/05	user2405	password	58	100000	F
2406	AZBDQD	GEKRHUUSEC	9446431169 Dell Way	\N	RDGDWNZ	FL	51583	US	1	GEKRHUUSEC@dell.com	9446431169	3	8534795502666385	2010/03	user2406	password	31	60000	F
2407	GQWKWB	UOJOJBSMSW	5726277472 Dell Way	\N	SWTFVYR	RI	40212	US	1	UOJOJBSMSW@dell.com	5726277472	2	6207960561849177	2011/10	user2407	password	76	100000	F
2408	RJHSDW	CSGDLSWHLS	8897269379 Dell Way	\N	AQOZIIH	UT	61516	US	1	CSGDLSWHLS@dell.com	8897269379	3	4049954526592046	2011/07	user2408	password	72	40000	M
2409	BBAXDS	DHEWDLHWMX	6540991302 Dell Way	\N	KLGSTDH	NJ	72772	US	1	DHEWDLHWMX@dell.com	6540991302	2	3087557899300009	2009/08	user2409	password	26	60000	M
2410	DIWWLD	AHHMODYMNK	8214907405 Dell Way	\N	TGDWNUO	CT	16721	US	1	AHHMODYMNK@dell.com	8214907405	3	7482478656340391	2012/11	user2410	password	49	20000	F
2411	HXRLXZ	TJNXIALSUR	4977625897 Dell Way	\N	WQEQFIS	AL	84295	US	1	TJNXIALSUR@dell.com	4977625897	5	7583710530307145	2012/12	user2411	password	87	20000	M
2412	QQVPJF	DGOERGYJDP	4801276023 Dell Way	\N	OUUWNVR	WI	79192	US	1	DGOERGYJDP@dell.com	4801276023	5	7881791546940804	2009/12	user2412	password	66	100000	M
2413	MPZSSF	GWXNUGRJUL	5916145805 Dell Way	\N	EQYAIXU	RI	76198	US	1	GWXNUGRJUL@dell.com	5916145805	1	7581313134171069	2009/02	user2413	password	43	80000	M
2414	IKKNRH	LEBRVLMHQD	6510650841 Dell Way	\N	GRMDLGW	WY	44123	US	1	LEBRVLMHQD@dell.com	6510650841	2	5594214410521091	2012/11	user2414	password	34	40000	F
2415	QVAXGE	ZYALKHCNNT	2252480784 Dell Way	\N	AREGOEQ	FL	43539	US	1	ZYALKHCNNT@dell.com	2252480784	1	3587795923929662	2009/05	user2415	password	63	20000	F
2416	QYLVXK	VJUDMIRFJJ	3256028461 Dell Way	\N	KPXPFCZ	LA	30618	US	1	VJUDMIRFJJ@dell.com	3256028461	4	6701883266679943	2012/09	user2416	password	79	60000	M
2417	IIOSDY	NHLVYREHBU	2615213050 Dell Way	\N	FRAIQJO	UT	19435	US	1	NHLVYREHBU@dell.com	2615213050	4	8506318606901915	2008/04	user2417	password	53	40000	M
2418	BASAOZ	LJYCOGEJLW	7182051884 Dell Way	\N	JUMTIJW	MS	20108	US	1	LJYCOGEJLW@dell.com	7182051884	3	4315477188676596	2008/11	user2418	password	86	40000	M
2419	QGLQSV	OVKVZTGVCB	2387409744 Dell Way	\N	IWJRSWU	MD	44929	US	1	OVKVZTGVCB@dell.com	2387409744	3	3241131782997399	2008/10	user2419	password	28	80000	F
2420	PJUKYP	UTONAKQBSN	9377478151 Dell Way	\N	LKFHEQR	KY	28057	US	1	UTONAKQBSN@dell.com	9377478151	3	1136729208752512	2008/03	user2420	password	24	80000	M
2421	WBNLVG	AJHLAJENUO	6306132881 Dell Way	\N	TCTJTCO	OH	56299	US	1	AJHLAJENUO@dell.com	6306132881	4	7178222683258355	2011/06	user2421	password	35	60000	F
2422	TZIZZS	HKTQOGLDAN	2404644676 Dell Way	\N	WJHYYZM	NC	79142	US	1	HKTQOGLDAN@dell.com	2404644676	2	2821099100168794	2009/10	user2422	password	68	20000	M
2423	ADSTKD	MBSTNWTASD	3635213117 Dell Way	\N	IRCIDQC	IN	86499	US	1	MBSTNWTASD@dell.com	3635213117	4	6459016469772906	2012/10	user2423	password	42	20000	M
2424	BTJFGL	YZYUSZNVIF	1040390568 Dell Way	\N	XQJOSRK	AK	41845	US	1	YZYUSZNVIF@dell.com	1040390568	1	2642265672329813	2009/01	user2424	password	28	60000	M
2425	NQAYOZ	XJSXWOFBLV	6498342963 Dell Way	\N	KAOBKPL	MD	62585	US	1	XJSXWOFBLV@dell.com	6498342963	4	6472275324631483	2011/03	user2425	password	46	40000	M
2426	KFJKDS	CAPQFRCBCD	4427731768 Dell Way	\N	PENEPYU	GA	72277	US	1	CAPQFRCBCD@dell.com	4427731768	5	8745434946380556	2011/03	user2426	password	65	20000	F
2427	APOTSO	IJUZLVCPLG	6321565792 Dell Way	\N	CQVBKAS	SC	97467	US	1	IJUZLVCPLG@dell.com	6321565792	3	2668963077478111	2009/09	user2427	password	63	40000	F
2428	EABTIK	NIWJKLVQNL	6897447019 Dell Way	\N	MOWMHQM	VA	27780	US	1	NIWJKLVQNL@dell.com	6897447019	1	9506914173718544	2009/05	user2428	password	38	60000	F
2429	IFTSTC	OCMZYDNJQC	1014344717 Dell Way	\N	FDKWPHB	IA	47939	US	1	OCMZYDNJQC@dell.com	1014344717	3	8454691560938955	2009/12	user2429	password	35	80000	F
2430	ZIXBXA	OXYSKIINNL	4832866506 Dell Way	\N	XKAELGP	MN	80353	US	1	OXYSKIINNL@dell.com	4832866506	4	7753220100887121	2011/05	user2430	password	85	80000	M
2431	VSOWHM	UAWDIJQTGB	6326458267 Dell Way	\N	ULMBBYV	MN	71956	US	1	UAWDIJQTGB@dell.com	6326458267	1	1363481436390429	2010/10	user2431	password	70	40000	M
2432	HFVTAV	QDDAUXHVSS	9940611969 Dell Way	\N	ITTGPFY	GA	42170	US	1	QDDAUXHVSS@dell.com	9940611969	4	2336056108120829	2011/01	user2432	password	66	20000	F
2433	MTHHKK	LKEJRZBKHV	8851420931 Dell Way	\N	DOKJNQS	MT	39634	US	1	LKEJRZBKHV@dell.com	8851420931	2	4507004614919424	2010/03	user2433	password	65	20000	F
2434	YIKITU	MCMMEWUZAI	7677148370 Dell Way	\N	KJWACJJ	WV	64572	US	1	MCMMEWUZAI@dell.com	7677148370	3	8596307565923781	2009/07	user2434	password	79	40000	M
2435	GQPBDS	NPXKKWKTHT	4906132257 Dell Way	\N	PHWZRVP	MD	39962	US	1	NPXKKWKTHT@dell.com	4906132257	4	8772364475764335	2009/02	user2435	password	70	60000	M
2436	IPXBDN	YNXVXQCRGK	5905404296 Dell Way	\N	NGBJVLR	ID	31953	US	1	YNXVXQCRGK@dell.com	5905404296	3	4266035832930356	2009/01	user2436	password	27	60000	M
2437	AQUOPH	MKFDNWJXJQ	1150442031 Dell Way	\N	YTLKKSQ	WI	33407	US	1	MKFDNWJXJQ@dell.com	1150442031	2	4085253030061722	2008/10	user2437	password	19	20000	F
2438	UTBCFL	HIYESWOIVH	1676982925 Dell Way	\N	TFRMWQT	VA	88178	US	1	HIYESWOIVH@dell.com	1676982925	1	7096736004110426	2008/03	user2438	password	27	100000	M
2439	EZEPHM	OLEKZMGGGM	2320721671 Dell Way	\N	YSIPLGM	MT	35361	US	1	OLEKZMGGGM@dell.com	2320721671	4	5547427817247808	2009/07	user2439	password	51	60000	M
2440	QBUCQG	HBFTHMATLT	2028729085 Dell Way	\N	CBEINSP	NV	40107	US	1	HBFTHMATLT@dell.com	2028729085	5	8611399404704572	2010/05	user2440	password	43	40000	F
2441	DHBJPC	PIJCJDNCFO	2601111864 Dell Way	\N	HOCZETI	ID	71002	US	1	PIJCJDNCFO@dell.com	2601111864	5	1490382809191942	2010/01	user2441	password	53	80000	F
2442	OBYQRH	ATQEHSJWAY	4845697909 Dell Way	\N	YACSIJJ	MT	27393	US	1	ATQEHSJWAY@dell.com	4845697909	1	3152568770106882	2012/09	user2442	password	60	60000	M
2443	NCKUDE	KHLDRIDPGD	5236112764 Dell Way	\N	RYMAIZG	PA	12601	US	1	KHLDRIDPGD@dell.com	5236112764	4	7635823424905539	2008/02	user2443	password	54	60000	F
2444	XJKBUS	NXKVBZCFRB	4849998240 Dell Way	\N	RSJRYDR	ME	83322	US	1	NXKVBZCFRB@dell.com	4849998240	3	9560443915892392	2012/01	user2444	password	32	100000	F
2445	PXEHLC	RGDRJIJKAC	7265058986 Dell Way	\N	URBYJMT	SC	96032	US	1	RGDRJIJKAC@dell.com	7265058986	4	1116271120496094	2012/07	user2445	password	49	60000	F
2446	PUWSLD	WDMEMXFORW	1403137758 Dell Way	\N	PPFBJAA	AR	75574	US	1	WDMEMXFORW@dell.com	1403137758	5	3445062665734440	2010/06	user2446	password	70	20000	F
2447	PUQSQU	EVGCAVTWKJ	2075516022 Dell Way	\N	CMSDNTW	NE	72299	US	1	EVGCAVTWKJ@dell.com	2075516022	1	2068955997005105	2012/02	user2447	password	41	60000	M
2448	ZDOTIJ	ZKJUEGFNJS	8029109672 Dell Way	\N	FMGZIVR	MI	87588	US	1	ZKJUEGFNJS@dell.com	8029109672	2	9878138774540276	2008/09	user2448	password	83	20000	M
2449	LVEUUO	EPSKVGTOLF	5243147687 Dell Way	\N	UKNQCZM	UT	30874	US	1	EPSKVGTOLF@dell.com	5243147687	5	9323688582517208	2009/01	user2449	password	73	100000	M
2450	XPRMTH	FECLXRWDMH	8017340361 Dell Way	\N	RCJQOGW	AR	28991	US	1	FECLXRWDMH@dell.com	8017340361	3	3239730446133762	2010/03	user2450	password	25	60000	M
2451	TXOACT	DOQUKUGSLJ	8210522476 Dell Way	\N	CBYIXZO	OH	44962	US	1	DOQUKUGSLJ@dell.com	8210522476	2	6447809446137399	2012/09	user2451	password	48	80000	M
2452	ZRSSVG	JQREXJPGMR	2287942688 Dell Way	\N	EVPDJHN	DE	57179	US	1	JQREXJPGMR@dell.com	2287942688	1	2828547598794102	2010/09	user2452	password	76	60000	F
2453	NHGTRW	LVTVLAHCEC	7397630821 Dell Way	\N	SIMZWRN	AK	75738	US	1	LVTVLAHCEC@dell.com	7397630821	3	5200463989749551	2010/02	user2453	password	83	20000	F
2454	DUCAFX	UAIUILZLDI	7977240762 Dell Way	\N	XDFPQFI	KY	81834	US	1	UAIUILZLDI@dell.com	7977240762	5	9397542147431524	2011/11	user2454	password	43	100000	M
2455	LVXJQY	SLGDLSHTQK	9193471521 Dell Way	\N	YFAENJZ	IL	30382	US	1	SLGDLSHTQK@dell.com	9193471521	5	1953673404641449	2009/10	user2455	password	74	80000	M
2456	RBGPTR	WWCOEWEOVJ	3669050776 Dell Way	\N	PAWZZDE	VA	18971	US	1	WWCOEWEOVJ@dell.com	3669050776	1	8784915214870126	2008/11	user2456	password	52	80000	M
2457	SIQKEN	MTRJXGFGVF	3264159909 Dell Way	\N	DUEHZCK	IL	31373	US	1	MTRJXGFGVF@dell.com	3264159909	2	1858664888422936	2011/02	user2457	password	18	60000	F
2458	QVQEIJ	WRGCWNYBRT	7042870654 Dell Way	\N	GYTIIBO	NH	46109	US	1	WRGCWNYBRT@dell.com	7042870654	2	5528425112366677	2011/09	user2458	password	86	40000	M
2459	ONXYJO	EMLSLNKEUI	8946809017 Dell Way	\N	YCRZRHJ	LA	63562	US	1	EMLSLNKEUI@dell.com	8946809017	1	4089909650851041	2012/05	user2459	password	84	40000	M
2460	UIGJNS	VFDIQICYHF	8789934206 Dell Way	\N	QGXYQHN	MT	37768	US	1	VFDIQICYHF@dell.com	8789934206	2	7014866997022182	2011/09	user2460	password	56	60000	F
2461	TYOMTU	QCKZEJGKAN	6065875346 Dell Way	\N	IYDPLRX	KS	10839	US	1	QCKZEJGKAN@dell.com	6065875346	1	7685835550539196	2008/09	user2461	password	75	100000	M
2462	IIJDYL	NYQWEBXRJV	3120044513 Dell Way	\N	VYHMVPM	MD	72378	US	1	NYQWEBXRJV@dell.com	3120044513	3	4309128982480615	2008/05	user2462	password	89	40000	M
2463	JMQVAO	LXTMUKVPFU	5818681907 Dell Way	\N	WSPMFAE	MI	54569	US	1	LXTMUKVPFU@dell.com	5818681907	3	8569386472925545	2010/11	user2463	password	55	100000	F
2464	ERJSDG	LPBWLQCFNU	2570614272 Dell Way	\N	VAZVELI	OH	90695	US	1	LPBWLQCFNU@dell.com	2570614272	2	7600026449654252	2011/02	user2464	password	22	100000	M
2465	KOXRAN	SWZJYFXTAX	8190284123 Dell Way	\N	TWBEFTB	MA	98819	US	1	SWZJYFXTAX@dell.com	8190284123	1	1801790569908917	2012/12	user2465	password	81	40000	F
2466	UZNIRJ	HBINYBOVUK	7437059775 Dell Way	\N	WZQQBAQ	TN	16889	US	1	HBINYBOVUK@dell.com	7437059775	4	1009783017914742	2010/12	user2466	password	53	40000	M
2467	ZSQJAR	SNPTBLOMHO	2441523802 Dell Way	\N	CYPCOKE	IL	21466	US	1	SNPTBLOMHO@dell.com	2441523802	5	2083177852910012	2011/04	user2467	password	23	80000	M
2468	SAZKSM	ZMNKBZSPCR	8529035685 Dell Way	\N	EEFPINS	MO	44765	US	1	ZMNKBZSPCR@dell.com	8529035685	1	6812733445782215	2012/10	user2468	password	62	80000	M
2469	PANBAZ	PKAPDPRUTW	6166996516 Dell Way	\N	AJEOBQY	VT	80305	US	1	PKAPDPRUTW@dell.com	6166996516	5	6040690434630961	2008/06	user2469	password	43	80000	F
2470	WWLVLW	WBALTVFPWP	7825292540 Dell Way	\N	TKRKIOF	VA	45191	US	1	WBALTVFPWP@dell.com	7825292540	1	8540208816528321	2008/11	user2470	password	39	100000	M
2471	TVEQRG	RDZMJPIYJS	4460958365 Dell Way	\N	PTBEZYO	OR	12804	US	1	RDZMJPIYJS@dell.com	4460958365	5	9010542058851572	2011/10	user2471	password	61	60000	M
2472	TBHZSK	ZFTOORXGHR	2663028878 Dell Way	\N	ILQGZJH	LA	29520	US	1	ZFTOORXGHR@dell.com	2663028878	1	1253188800532370	2011/06	user2472	password	65	60000	M
2473	YOHINM	CCAUAHBRPM	9664978263 Dell Way	\N	IWLSEUY	KY	85451	US	1	CCAUAHBRPM@dell.com	9664978263	1	3794049276970327	2011/09	user2473	password	80	60000	F
2474	DWTPZV	QTVXUNNGWJ	6877979894 Dell Way	\N	SONNNWI	MN	99611	US	1	QTVXUNNGWJ@dell.com	6877979894	1	7013293785043061	2010/08	user2474	password	82	80000	M
2475	QGMLWF	HTAUGHQQZF	7179260698 Dell Way	\N	DMSAVEA	MO	33620	US	1	HTAUGHQQZF@dell.com	7179260698	5	8975089743267746	2010/08	user2475	password	46	20000	M
2476	WQSCXL	CRSJIIJNMV	6235583358 Dell Way	\N	GNRLNDS	HI	21139	US	1	CRSJIIJNMV@dell.com	6235583358	4	7638991029933096	2012/12	user2476	password	60	100000	M
2477	HYNTBF	LLNUUBHQIU	3628443682 Dell Way	\N	HTILLOO	AL	40727	US	1	LLNUUBHQIU@dell.com	3628443682	1	3895672141574323	2012/11	user2477	password	86	20000	M
2478	LXVRIG	FDBHKRPFZJ	7811986600 Dell Way	\N	OKVCYWL	IA	86968	US	1	FDBHKRPFZJ@dell.com	7811986600	1	7366101684980095	2011/04	user2478	password	54	20000	F
2479	IVNPAQ	QHBIXHHGVS	5374266645 Dell Way	\N	BXRYJXU	CO	12261	US	1	QHBIXHHGVS@dell.com	5374266645	5	3757760254666209	2012/12	user2479	password	53	40000	M
2480	AXUROC	SXZAFGVXIT	8186111599 Dell Way	\N	OGCMBFM	MT	10455	US	1	SXZAFGVXIT@dell.com	8186111599	3	9618922966532410	2009/10	user2480	password	71	40000	M
2481	NYIQRF	QRLWMIFGXM	5543675876 Dell Way	\N	IJNOWBO	NV	61040	US	1	QRLWMIFGXM@dell.com	5543675876	5	4584509525448084	2009/03	user2481	password	28	80000	F
2482	MJVSZN	DWAMCGKOPT	2114668872 Dell Way	\N	CDQERHS	FL	31495	US	1	DWAMCGKOPT@dell.com	2114668872	3	5226194856688380	2009/03	user2482	password	64	80000	M
2483	MLOZPK	ABNGLCWFEZ	8529497486 Dell Way	\N	VIRDBWJ	FL	35317	US	1	ABNGLCWFEZ@dell.com	8529497486	3	5122868789359927	2010/03	user2483	password	18	100000	M
2484	OYGYYH	MFTOBYSBUB	3942568085 Dell Way	\N	SXDPHIW	CT	81829	US	1	MFTOBYSBUB@dell.com	3942568085	3	1076396412216126	2009/07	user2484	password	66	100000	M
2485	XVMFIR	YWTXPURRNP	9414400128 Dell Way	\N	UDXDZAY	KS	64960	US	1	YWTXPURRNP@dell.com	9414400128	4	2525343164801597	2010/07	user2485	password	67	60000	F
2486	DSRVQN	OODJGUXVOA	5751445737 Dell Way	\N	TSATQIJ	ND	98072	US	1	OODJGUXVOA@dell.com	5751445737	1	5601154622156174	2009/08	user2486	password	82	40000	F
2487	OEACTO	FDUABQOBKG	9153319091 Dell Way	\N	CDXKMLK	AL	64770	US	1	FDUABQOBKG@dell.com	9153319091	2	3427054197061807	2011/08	user2487	password	64	40000	M
2488	QMNFSR	ASSRHUBNWF	7821259600 Dell Way	\N	LHRWRSM	NE	94815	US	1	ASSRHUBNWF@dell.com	7821259600	2	5744612428825349	2009/09	user2488	password	39	20000	F
2489	VGXMHP	EYWYAKVFWC	1731553863 Dell Way	\N	XSTPFIO	WV	73949	US	1	EYWYAKVFWC@dell.com	1731553863	2	5016750659793616	2009/05	user2489	password	65	20000	M
2490	ORYEVX	BUXMPDISAB	9628362104 Dell Way	\N	MQGUEGN	ID	64784	US	1	BUXMPDISAB@dell.com	9628362104	4	1164362155832350	2011/11	user2490	password	68	20000	M
2491	QJJNKD	LWTOFLPGXF	4467060244 Dell Way	\N	NSKTGRJ	FL	39002	US	1	LWTOFLPGXF@dell.com	4467060244	5	2422901036217809	2008/12	user2491	password	66	80000	F
2492	AGTERQ	XGVJVBHBPA	6707361054 Dell Way	\N	MIGDSLM	CA	32073	US	1	XGVJVBHBPA@dell.com	6707361054	1	3058478931430727	2009/11	user2492	password	59	40000	F
2493	HMUXJB	TTXUBYJBLS	2896761517 Dell Way	\N	HPLTBNZ	OH	71193	US	1	TTXUBYJBLS@dell.com	2896761517	5	5932101516984404	2011/04	user2493	password	65	20000	M
2494	LZDMSW	JNXIXZTQGI	8072272907 Dell Way	\N	BAKOZBG	GA	15575	US	1	JNXIXZTQGI@dell.com	8072272907	5	4185205121524632	2010/01	user2494	password	25	100000	F
2495	GJTDTH	BBEAVUHEVH	1291035105 Dell Way	\N	OKHQQMR	ME	49856	US	1	BBEAVUHEVH@dell.com	1291035105	5	5398764773271978	2008/09	user2495	password	56	40000	F
2496	HNWOOY	TOTOVXJDLU	8195311978 Dell Way	\N	KBKWTVI	RI	71059	US	1	TOTOVXJDLU@dell.com	8195311978	5	4793949719984085	2009/04	user2496	password	57	80000	M
2497	KEJIXX	CMTAVWMPHO	9404066164 Dell Way	\N	ADHVLBN	IA	99408	US	1	CMTAVWMPHO@dell.com	9404066164	3	3692462152801454	2010/03	user2497	password	25	100000	F
2498	MFHJIT	DIPAUFHIFK	9895918459 Dell Way	\N	QBWSOCR	MS	71125	US	1	DIPAUFHIFK@dell.com	9895918459	5	8776684043463320	2008/11	user2498	password	34	60000	F
2499	NYJGBS	WBMBIVGTLI	3284691984 Dell Way	\N	PDWSVJK	TN	39188	US	1	WBMBIVGTLI@dell.com	3284691984	5	2472200406715274	2010/06	user2499	password	33	100000	F
2500	PGMHCO	UEXPKQBSGF	4970243397 Dell Way	\N	PZBYJXH	NJ	83309	US	1	UEXPKQBSGF@dell.com	4970243397	1	3738990927115083	2011/01	user2500	password	71	40000	F
2501	FNLUHP	SXAIZTPEIO	3271449239 Dell Way	\N	GHXDONY	AK	65433	US	1	SXAIZTPEIO@dell.com	3271449239	4	7285752312745900	2012/11	user2501	password	20	40000	F
2502	MATBSQ	CBQVQVEFBL	9724215696 Dell Way	\N	DEARDAH	MA	72072	US	1	CBQVQVEFBL@dell.com	9724215696	2	6384807600174100	2008/08	user2502	password	20	60000	M
2503	UOHKQJ	BMZWQFXCIC	4900442822 Dell Way	\N	DZGDGQV	HI	10241	US	1	BMZWQFXCIC@dell.com	4900442822	2	6352992888074369	2010/09	user2503	password	32	40000	F
2504	MRYWSK	WOBBLEKOHK	1059032905 Dell Way	\N	ULQKGWK	OH	20653	US	1	WOBBLEKOHK@dell.com	1059032905	1	8551734134554864	2009/05	user2504	password	26	80000	F
2505	BOTMKH	NLTRWHZGCK	7556130695 Dell Way	\N	XMRUXJX	VT	56611	US	1	NLTRWHZGCK@dell.com	7556130695	1	9263340505771340	2012/10	user2505	password	89	100000	F
2506	SJTAWF	TOBBNIDYFQ	4422113143 Dell Way	\N	PZNYWLM	NH	57928	US	1	TOBBNIDYFQ@dell.com	4422113143	3	4061439502518624	2009/05	user2506	password	69	20000	M
2507	MCPRWD	TYRBBQHRFG	5542712493 Dell Way	\N	FDDQPSE	WY	24545	US	1	TYRBBQHRFG@dell.com	5542712493	2	5515717790927738	2009/06	user2507	password	32	80000	M
2508	UJKYCI	QEJGMBLSGP	3039603581 Dell Way	\N	VXFOBFS	ND	58445	US	1	QEJGMBLSGP@dell.com	3039603581	4	9664362919051200	2010/06	user2508	password	53	40000	M
2509	WDXETB	OANPLGWACU	9328155805 Dell Way	\N	GRVLKKZ	NJ	24621	US	1	OANPLGWACU@dell.com	9328155805	1	6379559539724142	2010/04	user2509	password	45	40000	F
2510	HMEJAE	WQPDNQGHWX	3370179224 Dell Way	\N	CHHNGXR	FL	95926	US	1	WQPDNQGHWX@dell.com	3370179224	3	2899354832246899	2011/11	user2510	password	62	100000	F
2511	UGJYDA	OHNFNUCLXJ	8312408549 Dell Way	\N	TKQQBVP	KY	47829	US	1	OHNFNUCLXJ@dell.com	8312408549	5	3704076348338276	2010/11	user2511	password	65	40000	F
2512	AEIASP	NYDIAPGJIQ	6092943428 Dell Way	\N	AZSVOBG	MA	12837	US	1	NYDIAPGJIQ@dell.com	6092943428	5	9394993453752250	2009/01	user2512	password	25	40000	F
2513	KGXAUV	ECVUJFCZGB	7454965130 Dell Way	\N	SCQTJAU	WA	85434	US	1	ECVUJFCZGB@dell.com	7454965130	1	8727637102361769	2012/05	user2513	password	20	40000	M
2514	YHKULN	QGWWIWCKOE	7849689398 Dell Way	\N	AIOBCMX	SD	64721	US	1	QGWWIWCKOE@dell.com	7849689398	4	9776349851861596	2012/11	user2514	password	61	80000	F
2515	ZNPNDV	JZEGCOUHPC	8909444312 Dell Way	\N	VRFHOAX	KS	68808	US	1	JZEGCOUHPC@dell.com	8909444312	1	5742422757204623	2010/11	user2515	password	67	60000	F
2516	HZODJO	HPQWKXMNTD	9240382728 Dell Way	\N	SASTYAK	SD	24901	US	1	HPQWKXMNTD@dell.com	9240382728	2	1398902617394924	2010/10	user2516	password	50	100000	M
2517	AACOHS	EECCQPVTIW	7300292940 Dell Way	\N	LBVMLQR	LA	93847	US	1	EECCQPVTIW@dell.com	7300292940	5	7212942579761148	2008/11	user2517	password	49	20000	M
2518	NSDGXH	IZXYVRHSDI	8167145351 Dell Way	\N	NQUEHEC	WV	20461	US	1	IZXYVRHSDI@dell.com	8167145351	1	9563855970744044	2009/04	user2518	password	75	80000	M
2519	YAWFJW	DHRVPKYYYO	9505813784 Dell Way	\N	SCWWFVZ	AK	95771	US	1	DHRVPKYYYO@dell.com	9505813784	2	3070456226821989	2011/12	user2519	password	33	80000	M
2520	BXIXAQ	PWFZUEXJWA	3077010996 Dell Way	\N	FTGBTGA	OH	52282	US	1	PWFZUEXJWA@dell.com	3077010996	3	5180223290342838	2010/02	user2520	password	51	60000	M
2521	UKALAW	RARVYASZGL	4306725635 Dell Way	\N	FHFLHXX	NC	38558	US	1	RARVYASZGL@dell.com	4306725635	5	4649921055417508	2012/06	user2521	password	45	80000	M
2522	KCXGTY	XPWYIVETAM	6266836835 Dell Way	\N	ZMUWJIE	OR	35517	US	1	XPWYIVETAM@dell.com	6266836835	3	7806249108165503	2012/03	user2522	password	65	40000	F
2523	OPBNNQ	JLYFQSGCSS	3290744460 Dell Way	\N	XOBFTVM	KS	43730	US	1	JLYFQSGCSS@dell.com	3290744460	2	6162313329055906	2012/08	user2523	password	80	60000	F
2524	XZTOJF	NOVGVYYNVN	4250837338 Dell Way	\N	PBGKOOU	SD	86659	US	1	NOVGVYYNVN@dell.com	4250837338	4	5475427310913801	2009/03	user2524	password	72	20000	F
2525	MRNSFC	NLXLKLHXBJ	1411513220 Dell Way	\N	DLXSGSO	NH	47276	US	1	NLXLKLHXBJ@dell.com	1411513220	5	6417032950092108	2011/12	user2525	password	74	40000	M
2526	HZWKNH	IZSTGPUPTG	3049323856 Dell Way	\N	NLNFZCQ	AL	94734	US	1	IZSTGPUPTG@dell.com	3049323856	5	9070413205306978	2012/02	user2526	password	57	40000	F
2527	KSPSAO	KUVAPLTVYE	3719137500 Dell Way	\N	JEDMUEK	AK	98932	US	1	KUVAPLTVYE@dell.com	3719137500	1	1847266308963298	2012/04	user2527	password	31	40000	F
2528	UYAJIU	EIJQCFOGOS	6856141909 Dell Way	\N	KANOLNO	OR	57438	US	1	EIJQCFOGOS@dell.com	6856141909	3	8513472917489708	2012/10	user2528	password	79	80000	M
2529	WZCQDL	AUNFITUBEU	4938565842 Dell Way	\N	OSGBHYP	WA	58048	US	1	AUNFITUBEU@dell.com	4938565842	4	4086471674963832	2009/05	user2529	password	24	20000	F
2530	EUNPUH	DAQWURAPGT	7139934870 Dell Way	\N	VIBUXZI	KY	76646	US	1	DAQWURAPGT@dell.com	7139934870	4	2189904244616627	2011/10	user2530	password	54	100000	M
2531	AOIHRJ	YOEPPUVIQD	3065813846 Dell Way	\N	KLBJUKC	MN	12194	US	1	YOEPPUVIQD@dell.com	3065813846	2	8056328696198762	2011/03	user2531	password	41	80000	M
2532	RBKAZY	FONZKWPOGA	8169602112 Dell Way	\N	PQUZSGA	WI	53373	US	1	FONZKWPOGA@dell.com	8169602112	4	6881202681455762	2008/06	user2532	password	45	80000	F
2533	UVLSAA	GZKDPYKQOB	8497753793 Dell Way	\N	LNTSOSE	KY	45331	US	1	GZKDPYKQOB@dell.com	8497753793	3	8333961636759342	2009/03	user2533	password	38	100000	F
2534	SSCTZB	DDRCOHQPTE	3544259849 Dell Way	\N	JLSBQBM	MN	56612	US	1	DDRCOHQPTE@dell.com	3544259849	4	7896157994866372	2010/08	user2534	password	78	40000	F
2535	XAJZEN	QHBYYRRCAD	2532351412 Dell Way	\N	VCTXOFK	TX	87584	US	1	QHBYYRRCAD@dell.com	2532351412	3	5667964605614543	2008/09	user2535	password	83	100000	M
2536	GXYUNF	VMENEHNHCQ	6552047971 Dell Way	\N	BZFGKBC	ND	51935	US	1	VMENEHNHCQ@dell.com	6552047971	3	2612914078868925	2010/06	user2536	password	85	80000	F
2537	WOWCKJ	GXNNLVQBWP	9539532609 Dell Way	\N	GCZHEOU	SD	20587	US	1	GXNNLVQBWP@dell.com	9539532609	2	6278737452812493	2012/02	user2537	password	86	80000	M
2538	VVBEBY	SPKNFLKUSM	1515584333 Dell Way	\N	UARJUMM	OR	82552	US	1	SPKNFLKUSM@dell.com	1515584333	4	9197741569019856	2012/05	user2538	password	59	100000	F
2539	QAFPSU	ZGALQUDDPD	9896870710 Dell Way	\N	UYXHLQC	MO	31556	US	1	ZGALQUDDPD@dell.com	9896870710	3	6191639877390117	2010/04	user2539	password	71	20000	F
2540	YUATTH	TEXOHAELVD	8287960222 Dell Way	\N	JCOZEAG	DC	55985	US	1	TEXOHAELVD@dell.com	8287960222	4	8307490974664689	2010/11	user2540	password	26	60000	M
2541	DGLKAP	IPXITJDXSF	8118020542 Dell Way	\N	LSJMYNZ	PA	30820	US	1	IPXITJDXSF@dell.com	8118020542	2	2147205568384379	2012/10	user2541	password	76	20000	F
2542	GMCVUR	TCLCGIVMUN	7666557479 Dell Way	\N	WGMJFFP	AK	56954	US	1	TCLCGIVMUN@dell.com	7666557479	5	3865421685390174	2010/12	user2542	password	45	80000	F
2543	MPFDJI	PMPYIBSWXY	4529327332 Dell Way	\N	IHEOXEB	NV	18438	US	1	PMPYIBSWXY@dell.com	4529327332	1	1585467646829784	2011/12	user2543	password	54	40000	M
2544	SKYAZL	QXTRQPPOXX	1528944471 Dell Way	\N	SMUXOLZ	WA	68234	US	1	QXTRQPPOXX@dell.com	1528944471	4	6529334053397179	2010/12	user2544	password	32	40000	F
2545	DIIOYF	IPVXFKVCDH	6477323728 Dell Way	\N	XAVJAUZ	CA	53735	US	1	IPVXFKVCDH@dell.com	6477323728	4	4861951731611043	2012/11	user2545	password	73	100000	F
2546	BNDHVT	DTYOPBRXYS	4843817245 Dell Way	\N	THSNHUZ	VA	50350	US	1	DTYOPBRXYS@dell.com	4843817245	4	4242212586570531	2008/08	user2546	password	60	40000	F
2547	TOAMRT	LFJMXGLPZT	9394061386 Dell Way	\N	IMADMXO	VT	64824	US	1	LFJMXGLPZT@dell.com	9394061386	1	3284319300204515	2010/05	user2547	password	48	40000	M
2548	LTPFEU	ORSUDHUWPH	6772552269 Dell Way	\N	WSTUHRK	IA	79848	US	1	ORSUDHUWPH@dell.com	6772552269	4	2169351507909596	2008/12	user2548	password	20	60000	M
2549	PSXKGP	DBSKWOADKT	5182484790 Dell Way	\N	WFBOPHI	HI	12727	US	1	DBSKWOADKT@dell.com	5182484790	2	1226227289997041	2010/10	user2549	password	73	20000	F
2550	RNTGQV	YBRMBUXURC	2662088793 Dell Way	\N	WFSDOYE	AL	29085	US	1	YBRMBUXURC@dell.com	2662088793	3	9979277668055148	2012/08	user2550	password	53	80000	F
2551	FWUBUW	SHXMFSDIOJ	2431005087 Dell Way	\N	ARXYWYE	AL	51377	US	1	SHXMFSDIOJ@dell.com	2431005087	5	1772900379262864	2011/07	user2551	password	35	100000	F
2552	AXFXPN	UCSNFBBPBT	1043222042 Dell Way	\N	NAPLEQX	KY	64845	US	1	UCSNFBBPBT@dell.com	1043222042	5	2632538419216871	2009/11	user2552	password	61	40000	M
2553	VEJIYM	BMSCNHEHVF	3873976968 Dell Way	\N	XGKNETD	FL	75134	US	1	BMSCNHEHVF@dell.com	3873976968	3	6249874121975154	2012/09	user2553	password	43	80000	M
2554	TBWFCI	XFWEJDZPAG	1128285116 Dell Way	\N	ZOLSSQL	AK	17507	US	1	XFWEJDZPAG@dell.com	1128285116	5	8226737167220563	2009/08	user2554	password	68	20000	M
2555	OHVWFA	SKKVKAWQZK	6764051503 Dell Way	\N	CRCTCDV	CT	15074	US	1	SKKVKAWQZK@dell.com	6764051503	3	7500708264764399	2009/08	user2555	password	50	100000	M
2556	HSCILM	TGWTDNSOQK	6122650016 Dell Way	\N	RJNUFQW	TX	21461	US	1	TGWTDNSOQK@dell.com	6122650016	1	7495295705273748	2008/01	user2556	password	62	40000	M
2557	SPFEJM	BCPOUEEEVO	2612237990 Dell Way	\N	SQUIMQL	AL	83377	US	1	BCPOUEEEVO@dell.com	2612237990	1	8844239861238749	2011/05	user2557	password	65	60000	M
2558	WRIISK	YHEDMJYACP	2117411456 Dell Way	\N	VKBLWCG	AR	22774	US	1	YHEDMJYACP@dell.com	2117411456	5	5427881547715515	2011/05	user2558	password	51	80000	F
2559	TZTEYB	JBNSAOVPJF	4388134517 Dell Way	\N	RUCTBDW	DE	97220	US	1	JBNSAOVPJF@dell.com	4388134517	5	3788950372487307	2012/08	user2559	password	42	60000	M
2560	CTNDCP	QVQEQGOWXI	4063874512 Dell Way	\N	YQJBNOA	VA	55036	US	1	QVQEQGOWXI@dell.com	4063874512	4	1818573059514165	2011/04	user2560	password	66	80000	F
2561	FXEUNZ	KSPQHMNPKE	2231678078 Dell Way	\N	ZLROMOB	TN	36580	US	1	KSPQHMNPKE@dell.com	2231678078	3	6481249237433077	2012/04	user2561	password	67	20000	F
2562	VURVFK	LWRXKHHOHT	7595922791 Dell Way	\N	GVGVWBD	AK	61175	US	1	LWRXKHHOHT@dell.com	7595922791	5	8500956238247455	2010/10	user2562	password	90	40000	M
2563	RBVCMS	TJCBQRIKYE	1919310866 Dell Way	\N	QTBSWBG	NJ	87898	US	1	TJCBQRIKYE@dell.com	1919310866	1	7166224630083889	2008/03	user2563	password	39	80000	F
2564	DWTVQD	XRUPAENEVG	8365714343 Dell Way	\N	FNDGUTD	VA	78726	US	1	XRUPAENEVG@dell.com	8365714343	5	1090451602358371	2008/09	user2564	password	40	40000	M
2565	BBFFZX	ZPXECCZJHM	1335914869 Dell Way	\N	NOHGSEA	MT	23252	US	1	ZPXECCZJHM@dell.com	1335914869	4	9017858198843896	2009/11	user2565	password	53	60000	M
2566	SPZPPO	MTRPSAXFOM	7347552001 Dell Way	\N	MUERVSV	UT	40242	US	1	MTRPSAXFOM@dell.com	7347552001	2	3061926123220473	2008/08	user2566	password	32	100000	F
2567	EMUSZO	JOGKLMYXZT	4109265615 Dell Way	\N	CQPUMLD	DE	69146	US	1	JOGKLMYXZT@dell.com	4109265615	2	3454530377406627	2010/04	user2567	password	53	80000	M
2568	HKSVUH	CFTPDROXTF	8585542385 Dell Way	\N	MNRXRWO	WY	29299	US	1	CFTPDROXTF@dell.com	8585542385	3	5215077582281083	2009/03	user2568	password	33	80000	M
2569	YMLFOR	ZEUQTRKYDY	2602016343 Dell Way	\N	QBPMQPS	MN	22243	US	1	ZEUQTRKYDY@dell.com	2602016343	5	4441139510832727	2009/06	user2569	password	21	40000	M
2570	NOMENQ	YEJQOIUNZV	2874532245 Dell Way	\N	CMLREYV	KY	75846	US	1	YEJQOIUNZV@dell.com	2874532245	4	2469333582092076	2009/01	user2570	password	22	80000	M
2571	NYCEXH	ONVWHIVDLH	4732373736 Dell Way	\N	PDMNYVG	DE	60555	US	1	ONVWHIVDLH@dell.com	4732373736	3	6555210824124516	2010/03	user2571	password	33	20000	F
2572	IEZPSN	LPVUKYFSOI	2782845510 Dell Way	\N	FBHAILP	OK	87956	US	1	LPVUKYFSOI@dell.com	2782845510	2	1429159242659807	2010/03	user2572	password	29	80000	F
2573	EJCRUS	MODLUVZDBA	8002133527 Dell Way	\N	KBIWQBS	TN	34163	US	1	MODLUVZDBA@dell.com	8002133527	2	5330021575093270	2012/12	user2573	password	81	20000	F
2574	ZTDRGS	VRMRRPSRAT	8600290172 Dell Way	\N	AWKCPGJ	MA	53535	US	1	VRMRRPSRAT@dell.com	8600290172	2	5295293502043933	2011/05	user2574	password	77	80000	F
2575	YKLQFC	DWTSOLTIMP	9067003522 Dell Way	\N	SOFYYPK	RI	94235	US	1	DWTSOLTIMP@dell.com	9067003522	3	4154664617963135	2011/03	user2575	password	56	80000	M
2576	YHUBKR	VDFGWNTMFI	6471938560 Dell Way	\N	SEGIOAG	MO	56920	US	1	VDFGWNTMFI@dell.com	6471938560	1	7512718689627946	2008/11	user2576	password	41	20000	F
2577	DDOUZS	ZFONZBSHTW	8189597339 Dell Way	\N	NCLOIYB	WI	20299	US	1	ZFONZBSHTW@dell.com	8189597339	1	9626664337236436	2008/03	user2577	password	25	40000	F
2578	RAHJZN	XMMZFTTCHV	6007339374 Dell Way	\N	OVEMXCP	OK	27135	US	1	XMMZFTTCHV@dell.com	6007339374	5	4237319893669337	2011/01	user2578	password	67	40000	F
2579	YRBLPO	YOURHWZDLV	9438200965 Dell Way	\N	HXTKNLP	AZ	35174	US	1	YOURHWZDLV@dell.com	9438200965	4	4123889157082886	2011/01	user2579	password	48	60000	M
2580	MAIBYW	VQESPHDKPB	2957539539 Dell Way	\N	DZOPOQW	MO	42121	US	1	VQESPHDKPB@dell.com	2957539539	1	4603660313412547	2011/08	user2580	password	26	20000	M
2581	LEPHAG	MSVUVGJXKJ	8599753911 Dell Way	\N	LZXCWKL	AZ	53823	US	1	MSVUVGJXKJ@dell.com	8599753911	4	2291172902565449	2012/10	user2581	password	77	40000	F
2582	KSAQES	MZOSJMCSXC	6665538328 Dell Way	\N	PAYZLZM	IN	72659	US	1	MZOSJMCSXC@dell.com	6665538328	2	5759904406499118	2010/08	user2582	password	57	100000	F
2583	ONNHZN	WSWIVOGXEG	1316835143 Dell Way	\N	VESVRZN	IN	32786	US	1	WSWIVOGXEG@dell.com	1316835143	4	9097216633148492	2010/08	user2583	password	35	20000	F
2584	TKCHGU	DPPSVMXBIC	9224554380 Dell Way	\N	TDTTQBA	NV	80621	US	1	DPPSVMXBIC@dell.com	9224554380	2	4434881963301450	2008/05	user2584	password	53	100000	M
2585	OFBJIQ	ZBLLYNTAHW	9891627804 Dell Way	\N	UBNVBEP	WV	46254	US	1	ZBLLYNTAHW@dell.com	9891627804	1	7914858184289188	2010/01	user2585	password	57	20000	F
2586	PKPFJQ	RVPEPQLMKM	3976272057 Dell Way	\N	ZFOEVNO	SD	66577	US	1	RVPEPQLMKM@dell.com	3976272057	2	7077800652012230	2012/04	user2586	password	85	60000	M
2587	NRDDIY	TNOJYATLAY	8179731835 Dell Way	\N	ZEUMTPD	CA	87504	US	1	TNOJYATLAY@dell.com	8179731835	5	2699066142085939	2011/06	user2587	password	85	40000	F
2588	BJLACY	OLXPFJQDJV	6016855156 Dell Way	\N	YVONZQJ	PA	64215	US	1	OLXPFJQDJV@dell.com	6016855156	3	1245894114021211	2010/09	user2588	password	27	60000	F
2589	PNFNCQ	LRWVIAEDYA	9591356953 Dell Way	\N	RLZIVTY	LA	29940	US	1	LRWVIAEDYA@dell.com	9591356953	5	9398373862728476	2008/05	user2589	password	19	80000	M
2590	FFAWQS	SLASQDRQVC	5458262690 Dell Way	\N	PDXIBHO	AK	21304	US	1	SLASQDRQVC@dell.com	5458262690	1	5612910673022271	2010/10	user2590	password	49	80000	M
2591	LPPDIB	EASHSICUYF	6488124883 Dell Way	\N	SHHZVHC	KS	46815	US	1	EASHSICUYF@dell.com	6488124883	5	2589957781136036	2008/07	user2591	password	28	60000	F
2592	TQMVUN	NCFWEAUKSB	6418303659 Dell Way	\N	SRXATFL	MA	14894	US	1	NCFWEAUKSB@dell.com	6418303659	3	6619069447275252	2011/12	user2592	password	75	60000	M
2593	GIJUWM	ZSRZMBROUJ	3898900100 Dell Way	\N	LUDQFNS	TN	94202	US	1	ZSRZMBROUJ@dell.com	3898900100	3	8701464173849673	2008/01	user2593	password	48	40000	F
2594	UEGGDZ	XDMZVAUELP	6635074724 Dell Way	\N	ICVVUQU	CO	29403	US	1	XDMZVAUELP@dell.com	6635074724	2	3617990359663963	2008/08	user2594	password	68	100000	M
2595	ZCXYAA	KAWKUBWKJY	4136023994 Dell Way	\N	FFTVZWB	NJ	16720	US	1	KAWKUBWKJY@dell.com	4136023994	4	7041051794309170	2008/07	user2595	password	48	20000	M
2596	IYQJJR	FUMHQWRPBW	9483310105 Dell Way	\N	IXWFYMH	IN	21156	US	1	FUMHQWRPBW@dell.com	9483310105	2	6650942635722459	2009/05	user2596	password	35	80000	F
2597	WBROHL	AOBWFRYCAV	2364306503 Dell Way	\N	YFUKMCN	ME	50050	US	1	AOBWFRYCAV@dell.com	2364306503	4	8240718563087285	2009/06	user2597	password	25	40000	M
2598	TVUEVJ	GSOXQQYLOD	6229462259 Dell Way	\N	GZPIMAU	NM	82213	US	1	GSOXQQYLOD@dell.com	6229462259	1	3485670966561884	2011/04	user2598	password	76	60000	F
2599	PQYYXQ	NVHDTSSWYR	6141359685 Dell Way	\N	MHEMBVH	NV	87338	US	1	NVHDTSSWYR@dell.com	6141359685	2	2516640377230942	2009/10	user2599	password	39	100000	F
2600	GXIXKD	EOXWGTVYGD	9664644873 Dell Way	\N	CTFYAWU	NH	27056	US	1	EOXWGTVYGD@dell.com	9664644873	5	9830722515936942	2009/12	user2600	password	48	60000	M
2601	TKGXOU	UKBOGAUKDN	6540368770 Dell Way	\N	PBOLWDQ	SD	20209	US	1	UKBOGAUKDN@dell.com	6540368770	1	1436642601620405	2008/07	user2601	password	83	80000	M
2602	DRMYMX	AAEAUODIEF	2655239848 Dell Way	\N	WPBAGWD	TX	93106	US	1	AAEAUODIEF@dell.com	2655239848	5	5367479214910418	2008/08	user2602	password	49	40000	F
2603	XEUVFV	AGQOKYTPVI	9224371663 Dell Way	\N	QWPNZLL	DE	39167	US	1	AGQOKYTPVI@dell.com	9224371663	2	9892640246544034	2009/06	user2603	password	41	40000	M
2604	DCXYCD	ORNNKDITUE	1739913923 Dell Way	\N	IHEUSIC	NJ	62077	US	1	ORNNKDITUE@dell.com	1739913923	5	1499140330590307	2010/03	user2604	password	70	60000	F
2605	PMLTAD	HONKWHEBPL	2701139548 Dell Way	\N	FJEOMUD	ND	77290	US	1	HONKWHEBPL@dell.com	2701139548	5	9840463217813524	2012/07	user2605	password	41	60000	M
2606	TGAWNO	KYKRCMHORR	3035029576 Dell Way	\N	SGEMJSG	NE	72140	US	1	KYKRCMHORR@dell.com	3035029576	3	2714223787188530	2010/01	user2606	password	29	40000	F
2607	EEUSPT	DGVPOKHGCN	1096710407 Dell Way	\N	KPXDWMV	AZ	96090	US	1	DGVPOKHGCN@dell.com	1096710407	4	9637704435270280	2008/12	user2607	password	34	40000	F
2608	AARTDY	PTMZATCODS	8541865172 Dell Way	\N	LHOXCQW	CO	33715	US	1	PTMZATCODS@dell.com	8541865172	2	2651205101981759	2008/08	user2608	password	38	20000	M
2609	YWUWLO	JLODOCHGOO	9282459995 Dell Way	\N	VMQMJTT	FL	13742	US	1	JLODOCHGOO@dell.com	9282459995	2	6922399563714863	2008/05	user2609	password	40	20000	F
2610	DAQRKC	FNQIUXWJTJ	5129297792 Dell Way	\N	ZFSTYXU	UT	22737	US	1	FNQIUXWJTJ@dell.com	5129297792	1	5361917491070926	2011/03	user2610	password	67	100000	F
2611	IOQKUE	BCZYZIRIIX	5894240066 Dell Way	\N	ACVXXSB	KY	79327	US	1	BCZYZIRIIX@dell.com	5894240066	1	9813529891427608	2009/01	user2611	password	33	60000	M
2612	WYIBAL	AZKJQTROTT	8643625626 Dell Way	\N	KRQCTZW	IL	20460	US	1	AZKJQTROTT@dell.com	8643625626	3	2082891380414366	2008/01	user2612	password	67	100000	F
2613	ZZALZZ	VIQOAEIUOZ	7035253080 Dell Way	\N	LRTLNAO	MA	56939	US	1	VIQOAEIUOZ@dell.com	7035253080	3	6130113087128848	2009/05	user2613	password	59	40000	F
2614	PTJOPS	EESJMMYMYP	3947742921 Dell Way	\N	FJDGXNT	NE	96816	US	1	EESJMMYMYP@dell.com	3947742921	5	4137578871101141	2012/04	user2614	password	69	60000	F
2615	BBQTGU	MPHYNTXCZG	1519324376 Dell Way	\N	GFETZTS	IN	70565	US	1	MPHYNTXCZG@dell.com	1519324376	2	9498497464694084	2011/09	user2615	password	89	100000	M
2616	QOZKAO	SZBLWELDKQ	6821333295 Dell Way	\N	HDQAWXS	VT	20871	US	1	SZBLWELDKQ@dell.com	6821333295	4	8285822895821185	2011/07	user2616	password	57	40000	F
2617	NRCBJC	DVZIHCSXJW	4533184290 Dell Way	\N	OKTMDRP	PA	40857	US	1	DVZIHCSXJW@dell.com	4533184290	2	8629940803162754	2012/08	user2617	password	85	60000	F
2618	ANSDRN	CZUFSSPPGA	2521719014 Dell Way	\N	ISDZIXI	OH	35075	US	1	CZUFSSPPGA@dell.com	2521719014	4	9337984429672360	2008/02	user2618	password	36	20000	M
2619	YGHMJG	HPYZENGEWZ	4596663029 Dell Way	\N	IVHFDZM	KS	67296	US	1	HPYZENGEWZ@dell.com	4596663029	3	7538742386735976	2011/07	user2619	password	42	60000	M
2620	PBEWJT	UIYIPDEPLA	3259699500 Dell Way	\N	XQDXCMN	MS	88593	US	1	UIYIPDEPLA@dell.com	3259699500	1	4701671814080328	2010/10	user2620	password	33	20000	M
2621	KBEEWN	CEDGJSRJPI	3254094769 Dell Way	\N	NMKZAYV	ID	17736	US	1	CEDGJSRJPI@dell.com	3254094769	5	8542405373882503	2010/01	user2621	password	66	100000	F
2622	VAYJCD	MJMEAVUIIH	6431671143 Dell Way	\N	THIRDPT	MA	50415	US	1	MJMEAVUIIH@dell.com	6431671143	5	5521751269232482	2009/09	user2622	password	61	20000	M
2623	OLVRXE	DCFZXNIFHP	1505986405 Dell Way	\N	NZTCSDO	KS	98970	US	1	DCFZXNIFHP@dell.com	1505986405	3	7270700656808913	2011/09	user2623	password	48	40000	F
2624	GWBLAE	QABEIGLYUK	5550943380 Dell Way	\N	RWDVLMV	MO	16969	US	1	QABEIGLYUK@dell.com	5550943380	1	7937779952771962	2012/05	user2624	password	84	20000	F
2625	YPGDGH	EKPLWOFHFC	7814760909 Dell Way	\N	LBNXWAZ	LA	24246	US	1	EKPLWOFHFC@dell.com	7814760909	2	5622566654812545	2011/06	user2625	password	72	80000	F
2626	ATHHXS	XJPLOWRQHS	8722412959 Dell Way	\N	EFOEEXI	WI	27795	US	1	XJPLOWRQHS@dell.com	8722412959	4	6884315774776042	2011/03	user2626	password	70	80000	M
2627	AYXTVG	IGVFYMMQQS	9662554913 Dell Way	\N	FVWCEVI	AL	49819	US	1	IGVFYMMQQS@dell.com	9662554913	4	7120108132250608	2011/04	user2627	password	66	80000	F
2628	OLAVUH	QZFCLWTDBP	9890290903 Dell Way	\N	ADTWMUI	ME	48797	US	1	QZFCLWTDBP@dell.com	9890290903	1	7304178250487895	2011/10	user2628	password	83	40000	F
2629	XAAFQA	KTMGMQHBRL	7636875010 Dell Way	\N	VNXPVIA	SD	50286	US	1	KTMGMQHBRL@dell.com	7636875010	3	3327606105245650	2011/09	user2629	password	55	60000	M
2630	OTIODB	AKORSQIELV	2169720030 Dell Way	\N	CBRLCMW	SD	96083	US	1	AKORSQIELV@dell.com	2169720030	3	6649882765021176	2011/12	user2630	password	40	40000	M
2631	QUXSVH	HMAXUEJQGK	4372548691 Dell Way	\N	HRMUOHT	NY	78307	US	1	HMAXUEJQGK@dell.com	4372548691	2	7812341167591513	2011/07	user2631	password	54	40000	F
2632	JBDRIP	RGJWPACZHU	3572754393 Dell Way	\N	MCIUVAN	HI	40169	US	1	RGJWPACZHU@dell.com	3572754393	5	8815230811014772	2011/03	user2632	password	30	20000	F
2633	HVQWNW	GKLGMLOHXR	8449810150 Dell Way	\N	PRNQFSY	MS	67244	US	1	GKLGMLOHXR@dell.com	8449810150	2	8910529898479582	2008/06	user2633	password	30	40000	F
2634	VEVRLF	DSSPHZMYPE	7288696707 Dell Way	\N	LFJEEWV	AK	22549	US	1	DSSPHZMYPE@dell.com	7288696707	1	6199853241443635	2012/04	user2634	password	80	80000	F
2635	RJYWNQ	PCXOOWETIK	7286388868 Dell Way	\N	CNPZIPD	AK	65452	US	1	PCXOOWETIK@dell.com	7286388868	5	9371104002930224	2010/07	user2635	password	48	40000	M
2636	JDLZSN	XHCULWCWZP	6250994015 Dell Way	\N	LYXABYQ	PA	84699	US	1	XHCULWCWZP@dell.com	6250994015	2	4675357176922262	2008/07	user2636	password	43	40000	M
2637	UJKIHR	LBCHEZGTKF	8564340592 Dell Way	\N	RLGPCAL	NY	41158	US	1	LBCHEZGTKF@dell.com	8564340592	4	9165217752102764	2008/01	user2637	password	60	100000	F
2638	ZISQTT	TAXSHRCMIO	1092200431 Dell Way	\N	TYQTJIC	GA	10430	US	1	TAXSHRCMIO@dell.com	1092200431	2	1496808355208486	2010/05	user2638	password	52	60000	M
2639	EFLYYM	VRUNUGVIZT	4161890761 Dell Way	\N	ZTDHWIH	TX	75083	US	1	VRUNUGVIZT@dell.com	4161890761	3	1964800469111651	2012/01	user2639	password	77	100000	F
2640	GXETTV	NGPUCYUWXN	2162780058 Dell Way	\N	ZFJHMFA	TX	70874	US	1	NGPUCYUWXN@dell.com	2162780058	4	7310498318634928	2012/08	user2640	password	85	40000	M
2641	CYIYMP	OHRMBNKOMP	5736325429 Dell Way	\N	YUCDVYV	WI	65031	US	1	OHRMBNKOMP@dell.com	5736325429	5	3444466590881348	2010/02	user2641	password	79	60000	F
2642	ENNUBU	LOWZYKMOIG	5357180772 Dell Way	\N	RMBPIAF	TX	90334	US	1	LOWZYKMOIG@dell.com	5357180772	2	9784505481366068	2009/11	user2642	password	19	60000	F
2643	OHLJTZ	FSYQENZKEM	4313175048 Dell Way	\N	MUUMZQK	MO	93309	US	1	FSYQENZKEM@dell.com	4313175048	5	8094859730917961	2009/04	user2643	password	29	100000	M
2644	PHIPMB	ODFBCQGODA	7094250409 Dell Way	\N	IQAZAMX	MA	36709	US	1	ODFBCQGODA@dell.com	7094250409	4	6588177586905659	2012/09	user2644	password	34	60000	M
2645	PAMQOP	VQSMWGPXPF	3856898354 Dell Way	\N	XOGKLQS	CT	45120	US	1	VQSMWGPXPF@dell.com	3856898354	5	1840076509397477	2010/05	user2645	password	24	20000	F
2646	OTZEPQ	XBMERKTXHI	3194361576 Dell Way	\N	DSUTKXD	OK	89193	US	1	XBMERKTXHI@dell.com	3194361576	2	3498966374900192	2009/05	user2646	password	68	100000	F
2647	RCTHZV	UENFYKNGOF	1958758030 Dell Way	\N	AHPYLIV	OH	64050	US	1	UENFYKNGOF@dell.com	1958758030	1	9986332401633264	2012/12	user2647	password	29	60000	F
2648	XUASPE	GUCQHJEMKM	1272945302 Dell Way	\N	CJYLEQA	IL	68474	US	1	GUCQHJEMKM@dell.com	1272945302	1	6239213963039220	2008/07	user2648	password	62	20000	F
2649	QVYVBT	YRAHWNSIPB	2027277251 Dell Way	\N	GAGWBNN	CO	64286	US	1	YRAHWNSIPB@dell.com	2027277251	2	2590034127701074	2011/05	user2649	password	57	40000	F
2650	MFFFDX	GLTTDCJEIK	7454197561 Dell Way	\N	KFLYTOO	UT	85633	US	1	GLTTDCJEIK@dell.com	7454197561	3	2864903781097382	2009/12	user2650	password	46	80000	F
2651	PZHNFS	HYWJHBSRMY	7703515951 Dell Way	\N	DKRSYON	NY	24429	US	1	HYWJHBSRMY@dell.com	7703515951	5	2139093239791691	2008/09	user2651	password	38	80000	M
2652	PGVHNU	EXCFPTSNXD	1494601626 Dell Way	\N	FPBTDTY	UT	70826	US	1	EXCFPTSNXD@dell.com	1494601626	1	4140372777357698	2009/10	user2652	password	90	100000	F
2653	VFOPKL	RQALIOJLTY	3623488598 Dell Way	\N	NNCGLZY	MS	97647	US	1	RQALIOJLTY@dell.com	3623488598	5	7565199474338443	2009/10	user2653	password	72	20000	M
2654	HSJSKA	TWIHFUBEHO	9215754186 Dell Way	\N	GOAFNNE	SC	42093	US	1	TWIHFUBEHO@dell.com	9215754186	1	2083316900301724	2011/03	user2654	password	25	100000	M
2655	MRIMKE	VSKPTOXIUL	3823709596 Dell Way	\N	IAZVFTF	CO	85169	US	1	VSKPTOXIUL@dell.com	3823709596	4	1151309240143746	2010/09	user2655	password	85	100000	F
2656	GKUKGN	UWGJTOEFXE	8056910743 Dell Way	\N	ETJYYMT	IA	32078	US	1	UWGJTOEFXE@dell.com	8056910743	4	9625659074634316	2011/07	user2656	password	42	100000	M
2657	DIGQDC	XMVMRAKVFD	8962563860 Dell Way	\N	FDBRXHY	OH	97751	US	1	XMVMRAKVFD@dell.com	8962563860	2	6024755590129644	2009/04	user2657	password	58	40000	M
2658	UAVWYI	SLZTVUYYAC	8704077521 Dell Way	\N	ARAIPSH	MS	19003	US	1	SLZTVUYYAC@dell.com	8704077521	4	4864368544425816	2010/02	user2658	password	25	40000	F
2659	XCBFUM	FOHANGAPHS	8695239533 Dell Way	\N	QPHIXUL	PA	57652	US	1	FOHANGAPHS@dell.com	8695239533	1	6602437622379512	2012/05	user2659	password	71	100000	F
2660	UCGGHU	OHHVHXCZNR	3342260060 Dell Way	\N	HWPCHIQ	DC	53919	US	1	OHHVHXCZNR@dell.com	3342260060	1	8667734226211906	2012/12	user2660	password	40	80000	F
2661	OBJIQQ	QLYOOYCGGY	5432840126 Dell Way	\N	VJGDZKQ	ID	53371	US	1	QLYOOYCGGY@dell.com	5432840126	2	5032574821263552	2011/01	user2661	password	55	40000	F
2662	WRSNIE	MXSKZZRYUA	5616392607 Dell Way	\N	FYAPPHB	AZ	57033	US	1	MXSKZZRYUA@dell.com	5616392607	5	6053693188820035	2008/03	user2662	password	65	100000	M
2663	JKGOWD	GHDFYCAYHY	3891348667 Dell Way	\N	ZWNGYPT	MI	51716	US	1	GHDFYCAYHY@dell.com	3891348667	3	7045992259867490	2012/05	user2663	password	59	40000	M
2664	UXQYEX	BKVDKULJTH	6548830703 Dell Way	\N	WZFMTRY	AZ	21044	US	1	BKVDKULJTH@dell.com	6548830703	1	5263108594808728	2008/05	user2664	password	34	100000	F
2665	VXLTZV	ODGIOPCVMC	3862154821 Dell Way	\N	BZVSXXV	MT	94700	US	1	ODGIOPCVMC@dell.com	3862154821	4	4022869018372148	2010/09	user2665	password	63	40000	M
2666	CDPXRT	EAHUDDGFFF	2843895316 Dell Way	\N	AXDYTRW	CA	43133	US	1	EAHUDDGFFF@dell.com	2843895316	4	1595889713615179	2012/01	user2666	password	68	100000	F
2667	HVVAAV	IUYLAEQGEO	5260037968 Dell Way	\N	JDIBZKK	FL	12099	US	1	IUYLAEQGEO@dell.com	5260037968	1	1288232561200857	2008/12	user2667	password	29	60000	M
2668	ZMUUUO	TFPXWVCKFF	2733741685 Dell Way	\N	TGFDRKE	CT	48847	US	1	TFPXWVCKFF@dell.com	2733741685	2	4291246108245105	2009/09	user2668	password	27	40000	F
2669	XDZLXF	AVBWXMBDFI	6150765916 Dell Way	\N	JJZUNCF	OK	46418	US	1	AVBWXMBDFI@dell.com	6150765916	1	2278578732628375	2011/05	user2669	password	43	80000	M
2670	IBKNCF	PYDCAHHJQR	9969063598 Dell Way	\N	ILELQXW	GA	96352	US	1	PYDCAHHJQR@dell.com	9969063598	5	4111795022152364	2009/07	user2670	password	80	80000	M
2671	GFRMVQ	PXRXFAOWJZ	3301396392 Dell Way	\N	BUPYRVX	NV	74679	US	1	PXRXFAOWJZ@dell.com	3301396392	5	3162506375461817	2008/09	user2671	password	78	40000	M
2672	NWSDLP	UJUVXREWTZ	3158848538 Dell Way	\N	MRQHPHZ	TX	34736	US	1	UJUVXREWTZ@dell.com	3158848538	5	9526157032698394	2008/05	user2672	password	78	60000	F
2673	NSRDNA	YIXPMUJMGA	6359051989 Dell Way	\N	CNQJNMQ	RI	49136	US	1	YIXPMUJMGA@dell.com	6359051989	5	7983584610279650	2010/05	user2673	password	88	100000	F
2674	QCQQAY	OQLIZYOAAC	3895637553 Dell Way	\N	QKQCBKO	NM	32734	US	1	OQLIZYOAAC@dell.com	3895637553	1	6942721374798567	2009/01	user2674	password	74	100000	F
2675	KODJCU	VKUTZUTCLD	1654389597 Dell Way	\N	TNFECVK	MD	90497	US	1	VKUTZUTCLD@dell.com	1654389597	4	9258131504990160	2012/08	user2675	password	20	40000	F
2676	EQGYLR	SERNYUYCNM	9346634792 Dell Way	\N	HRODCZA	DE	69247	US	1	SERNYUYCNM@dell.com	9346634792	1	3434199128299952	2012/04	user2676	password	49	20000	M
2677	RCIJUM	AILVGNISUA	2546583008 Dell Way	\N	HXCGYGX	TX	34127	US	1	AILVGNISUA@dell.com	2546583008	5	5814842203631998	2011/12	user2677	password	48	40000	F
2678	TRVFSD	RNKEVDZVKX	9866252313 Dell Way	\N	YQVEORL	OK	55551	US	1	RNKEVDZVKX@dell.com	9866252313	2	5065668234601617	2010/08	user2678	password	53	20000	F
2679	IJZMAM	WFIZEDKCBA	6123397074 Dell Way	\N	XGPPSID	OH	67024	US	1	WFIZEDKCBA@dell.com	6123397074	1	3293377497233450	2008/03	user2679	password	57	40000	M
2680	NVQZRV	IRALBCNCAU	8962617228 Dell Way	\N	RQMZTEQ	KS	34987	US	1	IRALBCNCAU@dell.com	8962617228	2	5595002447720618	2010/09	user2680	password	26	100000	M
2681	TYGOGX	PSZRGCSAUI	5469850914 Dell Way	\N	NUCSKKZ	IL	80358	US	1	PSZRGCSAUI@dell.com	5469850914	4	5645247104112059	2011/08	user2681	password	23	40000	M
2682	IXVGMO	GEUIWVCFJW	1051102615 Dell Way	\N	HBHSBOM	NC	34782	US	1	GEUIWVCFJW@dell.com	1051102615	1	9311471183318646	2008/06	user2682	password	55	60000	F
2683	IRWXXB	RFXNIDWEKX	3095370604 Dell Way	\N	MDYAQMI	NJ	67015	US	1	RFXNIDWEKX@dell.com	3095370604	4	2103247368708253	2011/02	user2683	password	55	20000	M
2684	KZRLRW	JEFMAKXYWB	2148342037 Dell Way	\N	WXRJFHA	MI	10278	US	1	JEFMAKXYWB@dell.com	2148342037	1	2075475839432329	2011/04	user2684	password	83	20000	F
2685	ONXLWC	QJCAHBXIYU	4826323986 Dell Way	\N	AHZHHKH	ME	63351	US	1	QJCAHBXIYU@dell.com	4826323986	1	8720291743054987	2009/02	user2685	password	25	100000	M
2686	AINCYW	FZEGWMEQNM	5501224767 Dell Way	\N	QVUBCFQ	NC	36131	US	1	FZEGWMEQNM@dell.com	5501224767	5	4764413674362004	2011/09	user2686	password	21	80000	F
2687	OSALYZ	PEWCJNPVDK	5939752505 Dell Way	\N	QFNVVBD	KY	91936	US	1	PEWCJNPVDK@dell.com	5939752505	5	6802039926871658	2010/07	user2687	password	68	20000	F
2688	SOFSEK	OGUBVQFFGK	4115376299 Dell Way	\N	TCGUFPS	RI	59579	US	1	OGUBVQFFGK@dell.com	4115376299	2	2064405256416648	2008/07	user2688	password	47	80000	F
2689	QLGBZM	VBILHNSSHU	3295056597 Dell Way	\N	ZBAPTUD	CO	23788	US	1	VBILHNSSHU@dell.com	3295056597	1	7032178435008974	2011/11	user2689	password	73	40000	F
2690	AIIMEK	UPSIHKPCKR	7382610421 Dell Way	\N	CZLXDOB	MA	72598	US	1	UPSIHKPCKR@dell.com	7382610421	1	6343818589113653	2010/05	user2690	password	85	60000	M
2691	GYVRTL	JBTURVEIXE	6400605631 Dell Way	\N	TVHIWRA	ND	74080	US	1	JBTURVEIXE@dell.com	6400605631	1	1422600897960364	2010/06	user2691	password	70	80000	F
2692	OMFZVG	SQYNVHLZBG	7470937856 Dell Way	\N	HJDYJRR	WV	72728	US	1	SQYNVHLZBG@dell.com	7470937856	3	2722893348895013	2010/04	user2692	password	64	100000	M
2693	VZPCRG	BFBIRBJYIT	6617372631 Dell Way	\N	BHCTZBL	NY	61306	US	1	BFBIRBJYIT@dell.com	6617372631	1	8782593591138721	2009/02	user2693	password	63	20000	F
2694	FFTLGZ	NOROYPWRRE	3661374478 Dell Way	\N	UKDWVVL	MN	94219	US	1	NOROYPWRRE@dell.com	3661374478	4	1386809274554252	2012/10	user2694	password	26	20000	F
2695	WPHWDV	NRUDOMVSGF	6919000718 Dell Way	\N	WDBRONP	TX	32871	US	1	NRUDOMVSGF@dell.com	6919000718	4	1731058325152844	2011/12	user2695	password	25	80000	M
2696	JNRFBI	AEXMZPTFMW	2164570541 Dell Way	\N	HELUUHB	ME	15587	US	1	AEXMZPTFMW@dell.com	2164570541	2	9891957347746940	2009/11	user2696	password	56	80000	F
2697	EVLNWQ	KIPACVMZCQ	7768352453 Dell Way	\N	KXKSYVT	AZ	14560	US	1	KIPACVMZCQ@dell.com	7768352453	2	9239812168292702	2009/12	user2697	password	40	60000	M
2698	TZQJJZ	ZKBUWBXNLU	7795658242 Dell Way	\N	YESUYUV	NY	17088	US	1	ZKBUWBXNLU@dell.com	7795658242	5	9993578544352204	2008/05	user2698	password	73	80000	F
2699	JETIDD	KYALVOXPNB	2462933718 Dell Way	\N	IHZCDRE	VA	66038	US	1	KYALVOXPNB@dell.com	2462933718	5	1322844373062253	2012/09	user2699	password	48	40000	M
2700	EQAIBY	JNUYKJLMRS	8329195682 Dell Way	\N	MTWEYTU	CA	71204	US	1	JNUYKJLMRS@dell.com	8329195682	1	4798640367109329	2009/04	user2700	password	41	60000	M
2701	JTAIDO	CBZMMLEFYY	9042044838 Dell Way	\N	BCWUWYM	OH	97314	US	1	CBZMMLEFYY@dell.com	9042044838	5	3643934244289994	2009/05	user2701	password	37	60000	F
2702	HXGVZH	VLUHPZFNBI	6467698780 Dell Way	\N	KVFIIXI	GA	83692	US	1	VLUHPZFNBI@dell.com	6467698780	3	2563269922975451	2012/12	user2702	password	39	20000	M
2703	NAWVVI	QCXPILRQWM	7314019422 Dell Way	\N	VFUSNAN	CO	48144	US	1	QCXPILRQWM@dell.com	7314019422	5	4714061100967229	2012/02	user2703	password	39	60000	F
2704	DJALZC	JPKVGBRTWW	4480109836 Dell Way	\N	OPJOCMZ	SD	53784	US	1	JPKVGBRTWW@dell.com	4480109836	5	6848863643594087	2011/04	user2704	password	78	100000	M
2705	VHRYQG	JMNLEGHBUW	1597101937 Dell Way	\N	LIZYIUK	OH	63876	US	1	JMNLEGHBUW@dell.com	1597101937	2	9319591110106560	2012/03	user2705	password	62	80000	F
2706	HSDNBP	AMUHUVBRGK	9826141621 Dell Way	\N	RFSLPKB	NY	81516	US	1	AMUHUVBRGK@dell.com	9826141621	3	9895260341465474	2010/04	user2706	password	51	100000	F
2707	PKCELO	ZSJUUBBESG	1913681563 Dell Way	\N	XEWIFOC	GA	20465	US	1	ZSJUUBBESG@dell.com	1913681563	4	4885346968658269	2010/08	user2707	password	50	20000	F
2708	NIMCHE	MCYNEDFKAJ	4408721859 Dell Way	\N	HJPVMUY	ND	62461	US	1	MCYNEDFKAJ@dell.com	4408721859	1	3125752907712012	2012/04	user2708	password	38	40000	M
2709	TLXYXZ	XLDAQOBAWK	3062675058 Dell Way	\N	QRWKQLZ	AK	59642	US	1	XLDAQOBAWK@dell.com	3062675058	5	8308290046639741	2010/03	user2709	password	47	40000	M
2710	HFNHCY	LDPZEQWPGO	3271468325 Dell Way	\N	LQEXQFL	UT	13938	US	1	LDPZEQWPGO@dell.com	3271468325	2	3019617599435150	2011/08	user2710	password	79	100000	M
2711	JFZIQC	YQHOMXUAJL	7301295382 Dell Way	\N	FGBLRYM	WA	38575	US	1	YQHOMXUAJL@dell.com	7301295382	3	9736889486201108	2010/07	user2711	password	79	100000	M
2712	VGJXFA	FTMCONLZTS	3451130434 Dell Way	\N	BEJZRIH	LA	90610	US	1	FTMCONLZTS@dell.com	3451130434	5	4768058268353343	2008/11	user2712	password	29	100000	F
2713	NVHNBB	AEPOQOHIQM	4075591859 Dell Way	\N	SPDAXNX	DE	47802	US	1	AEPOQOHIQM@dell.com	4075591859	2	3299269405193627	2010/03	user2713	password	43	20000	F
2714	QODSOH	HCYWKGMWZC	2967108949 Dell Way	\N	AAZOYEZ	IL	49703	US	1	HCYWKGMWZC@dell.com	2967108949	4	6841887381393463	2010/10	user2714	password	69	40000	F
2715	VYXCFZ	BCKIOHHQHH	8933183580 Dell Way	\N	QWGUVNG	AL	35475	US	1	BCKIOHHQHH@dell.com	8933183580	4	1638753697741776	2010/10	user2715	password	47	60000	M
2716	HNZHOB	RWQYEHGMXC	6245956986 Dell Way	\N	SSXFYYN	TN	57890	US	1	RWQYEHGMXC@dell.com	6245956986	3	4224872105289251	2012/10	user2716	password	26	40000	F
2717	COXDFU	UEYBKLZMDS	2868456316 Dell Way	\N	KJQIWMW	MN	89885	US	1	UEYBKLZMDS@dell.com	2868456316	3	7323267184197903	2009/09	user2717	password	20	60000	F
2718	YOMSJQ	RKBCKNGDXP	8594292656 Dell Way	\N	UGMGCYD	IL	47053	US	1	RKBCKNGDXP@dell.com	8594292656	4	2226732994429767	2012/01	user2718	password	48	100000	M
2719	XNXOFI	PHTDNXADRG	2284827722 Dell Way	\N	QXJPBQA	VA	32400	US	1	PHTDNXADRG@dell.com	2284827722	4	3379547066055238	2010/08	user2719	password	79	60000	F
2720	TAICPQ	WSETTHKAYI	5765296757 Dell Way	\N	JNKAOHG	NY	15926	US	1	WSETTHKAYI@dell.com	5765296757	2	6996966612990946	2009/09	user2720	password	76	20000	M
2721	DGHTCA	YWUGHUEPES	1012641842 Dell Way	\N	ZFGGMYI	WY	24682	US	1	YWUGHUEPES@dell.com	1012641842	2	8722433193586768	2012/06	user2721	password	58	100000	M
2722	WSVXQR	RWZMBORTOW	9543944248 Dell Way	\N	AVIYDIC	DC	70482	US	1	RWZMBORTOW@dell.com	9543944248	5	2481338776648044	2010/11	user2722	password	83	40000	M
2723	SGGKYD	JKEYBYMXYI	4451770362 Dell Way	\N	GWLOYPF	VT	61291	US	1	JKEYBYMXYI@dell.com	4451770362	3	5206050754524768	2009/10	user2723	password	23	20000	F
2724	ILZLVK	QTLOGJNOPJ	7033605470 Dell Way	\N	AEIQJFF	PA	68161	US	1	QTLOGJNOPJ@dell.com	7033605470	1	4933794134296477	2011/01	user2724	password	53	20000	F
2725	MNHWEB	ISHSFWIPWM	3115975472 Dell Way	\N	XMWDSQU	MA	69149	US	1	ISHSFWIPWM@dell.com	3115975472	1	7333860057406128	2011/03	user2725	password	30	40000	M
2726	LBWNKP	UCVQLKNXIA	7639904410 Dell Way	\N	TMSJHCA	MT	28025	US	1	UCVQLKNXIA@dell.com	7639904410	2	4515614958480001	2012/06	user2726	password	25	40000	M
2727	ZWYORB	KHMVVJEVDQ	2756722198 Dell Way	\N	NNYPOMU	IL	74717	US	1	KHMVVJEVDQ@dell.com	2756722198	2	2581315246876329	2009/07	user2727	password	69	40000	F
2728	QWDRGL	EBGOFBRWPE	2519152701 Dell Way	\N	UETHZAZ	FL	29994	US	1	EBGOFBRWPE@dell.com	2519152701	3	8189470144454391	2012/10	user2728	password	36	60000	M
2729	JFWUJX	BXDCPARUVW	6056033466 Dell Way	\N	NCWOBAT	IA	56135	US	1	BXDCPARUVW@dell.com	6056033466	1	3460001974832267	2012/08	user2729	password	82	20000	M
2730	TZFRBD	UDTUVNPRAR	4079375735 Dell Way	\N	NPTOIAB	VT	21872	US	1	UDTUVNPRAR@dell.com	4079375735	4	7974128398578615	2009/11	user2730	password	63	100000	M
2731	WQYAKC	TFXGVPHNCW	2697506353 Dell Way	\N	HRFHTCK	AZ	84740	US	1	TFXGVPHNCW@dell.com	2697506353	2	7651140229776502	2012/04	user2731	password	65	80000	M
2732	PRIRKN	PRJEZWHVDY	7597134990 Dell Way	\N	BKREVTZ	AK	15745	US	1	PRJEZWHVDY@dell.com	7597134990	5	4020160389598459	2009/07	user2732	password	34	100000	F
2733	OQPCFH	LKGHRCKPDV	5088021722 Dell Way	\N	HHQBHRD	AL	54038	US	1	LKGHRCKPDV@dell.com	5088021722	3	9964595343917608	2011/05	user2733	password	31	40000	F
2734	UIGBTQ	IAHKLXOGFV	1498654942 Dell Way	\N	XGDOKEB	TN	61261	US	1	IAHKLXOGFV@dell.com	1498654942	3	9475089172832668	2009/10	user2734	password	87	20000	F
2735	FCVVKW	DUHBIOGEMN	9980440946 Dell Way	\N	IAXMCTB	DC	35818	US	1	DUHBIOGEMN@dell.com	9980440946	2	1453528662212193	2012/05	user2735	password	27	20000	M
2736	YZXUDS	CEBQLGCZOD	9837964840 Dell Way	\N	XBGQCKY	CO	80915	US	1	CEBQLGCZOD@dell.com	9837964840	1	2809820926748216	2008/03	user2736	password	69	20000	F
2737	PWIIYM	KPYQSXFWUG	5550735722 Dell Way	\N	DKJNJMH	KY	58648	US	1	KPYQSXFWUG@dell.com	5550735722	3	7821171523537488	2009/07	user2737	password	88	100000	F
2738	HDIUNY	SEQPJNJQQU	7924974169 Dell Way	\N	ZEDMLMA	WV	93802	US	1	SEQPJNJQQU@dell.com	7924974169	1	4965350444894284	2011/12	user2738	password	77	20000	F
2739	DURBMW	SBFGLWWGVA	3108482637 Dell Way	\N	JIMWILU	CA	67075	US	1	SBFGLWWGVA@dell.com	3108482637	5	6686999609228224	2008/11	user2739	password	74	20000	M
2740	MGCIZE	OFPKCVGDFO	4264781539 Dell Way	\N	QCWCWZT	CO	82398	US	1	OFPKCVGDFO@dell.com	4264781539	1	6772285750601441	2008/05	user2740	password	37	80000	M
2741	JXPNMV	DWYZCBFQSH	9506783688 Dell Way	\N	NUEMNHH	VA	49368	US	1	DWYZCBFQSH@dell.com	9506783688	1	8064162079244853	2009/08	user2741	password	46	60000	M
2742	ZCAUGW	SFZULPNSDH	4409469122 Dell Way	\N	WQVEYTP	UT	79625	US	1	SFZULPNSDH@dell.com	4409469122	1	4753564641810954	2011/08	user2742	password	89	80000	M
2743	AOZXHF	WCQMPIPXFF	6932871310 Dell Way	\N	TJEMZAG	KY	20969	US	1	WCQMPIPXFF@dell.com	6932871310	1	7950817634351552	2011/11	user2743	password	55	80000	F
2744	NNSSKV	IWKRLHWRAG	7872147262 Dell Way	\N	VMFWTOZ	MD	71642	US	1	IWKRLHWRAG@dell.com	7872147262	1	6031784825958312	2009/09	user2744	password	90	80000	F
2745	SMPNVM	XMXFJPGQLS	6888210011 Dell Way	\N	VHLKHWC	AR	89894	US	1	XMXFJPGQLS@dell.com	6888210011	2	6146870975848288	2011/02	user2745	password	75	40000	M
2746	KXKWUX	UAGJGWVZSC	7717024943 Dell Way	\N	LDKHGLE	VA	79061	US	1	UAGJGWVZSC@dell.com	7717024943	3	8935274571646006	2010/11	user2746	password	53	100000	M
2747	XVPUPP	BZWYUVRXGV	4415515144 Dell Way	\N	HOBSSYM	MN	51698	US	1	BZWYUVRXGV@dell.com	4415515144	1	4239457962103188	2012/12	user2747	password	28	80000	M
2748	SOJIQJ	EOEAGCGBJV	8608199240 Dell Way	\N	CCNAPAM	WY	10612	US	1	EOEAGCGBJV@dell.com	8608199240	5	9616239307448268	2012/08	user2748	password	71	80000	F
2749	CBUMGJ	RGPTNQDITG	8455667717 Dell Way	\N	WTVWGVW	CA	70763	US	1	RGPTNQDITG@dell.com	8455667717	1	3567260034848005	2010/10	user2749	password	51	80000	M
2750	GDCPUI	FOVVREPXAJ	5780108481 Dell Way	\N	TXPOURG	NH	79068	US	1	FOVVREPXAJ@dell.com	5780108481	1	6091656165197492	2012/10	user2750	password	48	40000	M
2751	MVTVAI	RWZWMXWVQU	4821080536 Dell Way	\N	KFOCLEW	WV	37807	US	1	RWZWMXWVQU@dell.com	4821080536	5	2127610057592392	2012/03	user2751	password	24	40000	F
2752	WEBEVY	DRKAOFRJPW	5513252065 Dell Way	\N	XSHBOHJ	WY	32520	US	1	DRKAOFRJPW@dell.com	5513252065	5	5007104204036296	2010/03	user2752	password	52	60000	F
2753	NPEMTW	WTLBKURHSK	6080006539 Dell Way	\N	PUYWEYD	NV	79109	US	1	WTLBKURHSK@dell.com	6080006539	2	9411023105960340	2008/09	user2753	password	37	60000	F
2754	LAAIXT	UZEPRLHBBC	6854683672 Dell Way	\N	AXGYAXS	NH	24055	US	1	UZEPRLHBBC@dell.com	6854683672	4	8554058947600425	2012/03	user2754	password	26	40000	F
2755	DSDXMC	BBUNIVOLVM	6122923115 Dell Way	\N	RUNONCS	DC	75752	US	1	BBUNIVOLVM@dell.com	6122923115	1	9372189660556616	2011/06	user2755	password	30	100000	F
2756	HRPKTR	FHAAWLWICQ	6338255079 Dell Way	\N	VRDYKHR	WV	44288	US	1	FHAAWLWICQ@dell.com	6338255079	4	8460295764263720	2011/06	user2756	password	89	20000	F
2757	PMXGRE	GSAROJUFFL	9020038675 Dell Way	\N	JDWRUVB	MA	52141	US	1	GSAROJUFFL@dell.com	9020038675	1	9313636891078204	2012/03	user2757	password	23	60000	M
2758	ZSJEZB	FQQOLWTWGW	9431452817 Dell Way	\N	SXROZBA	UT	27865	US	1	FQQOLWTWGW@dell.com	9431452817	4	4645098959095776	2008/03	user2758	password	24	100000	M
2759	LDWNIN	EXYAQVGNOE	8680714831 Dell Way	\N	FCEGCAL	AR	79041	US	1	EXYAQVGNOE@dell.com	8680714831	1	9629548189695924	2012/01	user2759	password	80	60000	F
2760	SYMGCK	EDAAKOOPTR	5525279484 Dell Way	\N	TZTULVO	IN	87700	US	1	EDAAKOOPTR@dell.com	5525279484	2	9047956242691726	2009/08	user2760	password	22	20000	M
2761	OISYNV	ZNGNBVHSOH	1464972814 Dell Way	\N	MISHWAE	MA	34020	US	1	ZNGNBVHSOH@dell.com	1464972814	4	9270069103688004	2008/10	user2761	password	54	80000	F
2762	FQRAPE	GDFBKYQRLZ	6549468516 Dell Way	\N	KSWLWGS	WA	98537	US	1	GDFBKYQRLZ@dell.com	6549468516	1	8323884715791792	2008/09	user2762	password	88	40000	F
2763	QJYUPC	ARMYIEKHPD	2666519450 Dell Way	\N	DAAKSYJ	KY	98529	US	1	ARMYIEKHPD@dell.com	2666519450	3	7354465067852289	2008/10	user2763	password	21	80000	F
2764	ZOTCOL	ONTTXBIAFJ	6947053221 Dell Way	\N	APBZYKY	DC	87756	US	1	ONTTXBIAFJ@dell.com	6947053221	2	6801296628080309	2011/01	user2764	password	74	80000	M
2765	NUEYJS	SCQTLRZUSO	8028376629 Dell Way	\N	WRNHQQD	IL	95352	US	1	SCQTLRZUSO@dell.com	8028376629	5	1127396206837147	2010/09	user2765	password	64	20000	F
2766	VAWNTY	ENKVMENABF	2325226647 Dell Way	\N	NIVELCD	IA	19872	US	1	ENKVMENABF@dell.com	2325226647	4	8364095161203296	2011/11	user2766	password	40	80000	M
2767	EDRCHE	NDQRQRTVFB	7362487999 Dell Way	\N	RKNUNTX	NV	58848	US	1	NDQRQRTVFB@dell.com	7362487999	3	4783288060687483	2008/01	user2767	password	42	20000	F
2768	ZHMEUP	VMGMFCRHTB	5444592355 Dell Way	\N	UNPNKGB	CT	73627	US	1	VMGMFCRHTB@dell.com	5444592355	1	7795824007131160	2012/04	user2768	password	86	100000	M
2769	KALAVX	GIDIAKCCFQ	4563418033 Dell Way	\N	RSBYUEQ	IN	39226	US	1	GIDIAKCCFQ@dell.com	4563418033	1	6921011725906283	2009/12	user2769	password	39	80000	M
2770	STUQZC	UICFLEKBWD	3265832731 Dell Way	\N	CUYGLGP	SD	42616	US	1	UICFLEKBWD@dell.com	3265832731	1	3866883413866162	2010/11	user2770	password	38	40000	M
2771	BXQDSZ	GXKLHLHLOB	3545126047 Dell Way	\N	JVMPKIZ	NV	52370	US	1	GXKLHLHLOB@dell.com	3545126047	2	4318130672909320	2010/06	user2771	password	19	80000	F
2772	RUBQAZ	BLGNTRBUBW	5079427032 Dell Way	\N	HRHPQYC	VT	23835	US	1	BLGNTRBUBW@dell.com	5079427032	3	6597864208742977	2010/02	user2772	password	90	20000	M
2773	BUWAVI	HIBZKWBHES	3544676463 Dell Way	\N	OUINWGR	KS	73127	US	1	HIBZKWBHES@dell.com	3544676463	4	8085952458437533	2009/12	user2773	password	65	40000	M
2774	NJOWRX	YRHVSOZKCU	5057973831 Dell Way	\N	SQQZHZR	ND	79764	US	1	YRHVSOZKCU@dell.com	5057973831	5	7354741561692209	2008/03	user2774	password	48	80000	M
2775	ZMGWLX	DGPSGZUASL	2164484501 Dell Way	\N	RRSQJHL	SC	21076	US	1	DGPSGZUASL@dell.com	2164484501	5	3846920218318701	2010/07	user2775	password	82	60000	F
2776	DJLAMR	QEYQZYJLPA	8694945517 Dell Way	\N	DGKKREO	SD	18044	US	1	QEYQZYJLPA@dell.com	8694945517	2	6517195762600750	2011/11	user2776	password	63	100000	F
2777	BXTTNX	REXQNIGOMN	8432534720 Dell Way	\N	YXFDLAF	IL	44285	US	1	REXQNIGOMN@dell.com	8432534720	1	3293347225990146	2010/11	user2777	password	53	60000	M
2778	FHJDZN	BQAKWOXKMU	3172236310 Dell Way	\N	PPGPVNZ	NV	60652	US	1	BQAKWOXKMU@dell.com	3172236310	1	5266651181038469	2011/08	user2778	password	39	100000	M
2779	QCXDEN	DOJSMUFGJU	1507038723 Dell Way	\N	MZQAYHP	FL	43886	US	1	DOJSMUFGJU@dell.com	1507038723	5	1036359866149723	2009/11	user2779	password	85	100000	M
2780	VDDIHS	SZEMELVZYU	3331128859 Dell Way	\N	PYTWNYG	NH	88470	US	1	SZEMELVZYU@dell.com	3331128859	5	7739668445196003	2008/12	user2780	password	70	100000	F
2781	WIIOBH	TNMEJLDEBB	5554206689 Dell Way	\N	YYPXFFT	MN	21904	US	1	TNMEJLDEBB@dell.com	5554206689	4	1473146959207952	2009/08	user2781	password	25	20000	M
2782	KRASKN	FPXRSCTUAR	8101752853 Dell Way	\N	KXWPRIT	DE	97553	US	1	FPXRSCTUAR@dell.com	8101752853	2	6447122507262976	2012/06	user2782	password	59	40000	F
2783	OAOCGE	ZXXBRSCIDZ	2184242046 Dell Way	\N	FSQOMVN	IA	29205	US	1	ZXXBRSCIDZ@dell.com	2184242046	1	7317595477215946	2011/06	user2783	password	80	40000	F
2784	LJTPJR	NLIGNQJNWC	9135839600 Dell Way	\N	ELOZYUF	CA	93876	US	1	NLIGNQJNWC@dell.com	9135839600	4	4418071515858174	2011/01	user2784	password	81	20000	F
2785	PUTGIE	OOSFXFCAKN	6846949195 Dell Way	\N	OJMIPOH	MO	39632	US	1	OOSFXFCAKN@dell.com	6846949195	2	4321794398594648	2010/06	user2785	password	73	20000	F
2786	NJOSYD	KEBQGBAUPK	5540618539 Dell Way	\N	GYZUFMD	TX	74091	US	1	KEBQGBAUPK@dell.com	5540618539	2	2370290692429989	2009/06	user2786	password	46	80000	M
2787	ZMVCXZ	ENGFNAVXHT	3052680674 Dell Way	\N	XCZJFVB	OR	27727	US	1	ENGFNAVXHT@dell.com	3052680674	1	7183251971844584	2011/10	user2787	password	58	60000	F
2788	JSEIWR	PCFQXDXQAZ	3917929091 Dell Way	\N	QKFLMYQ	OH	96437	US	1	PCFQXDXQAZ@dell.com	3917929091	2	7762458337005229	2012/11	user2788	password	20	40000	M
2789	FOMWEO	BULFRCFRSP	6188603076 Dell Way	\N	XDBWUTV	CO	16469	US	1	BULFRCFRSP@dell.com	6188603076	5	9838105095084758	2011/03	user2789	password	61	80000	M
2790	BRZPTT	BYLDDCWTAA	6657232860 Dell Way	\N	VWUOSXQ	IL	91042	US	1	BYLDDCWTAA@dell.com	6657232860	5	2117151529528200	2009/09	user2790	password	85	40000	F
2791	XXCQYA	BCEEYYEYTB	7269521503 Dell Way	\N	TIURZBO	NH	96253	US	1	BCEEYYEYTB@dell.com	7269521503	5	6817979046143592	2011/02	user2791	password	18	60000	M
2792	CDYDFA	HJZFOYYQSH	1766216670 Dell Way	\N	KJGMYVL	NM	68446	US	1	HJZFOYYQSH@dell.com	1766216670	2	7712552074808628	2008/10	user2792	password	71	20000	M
2793	RHCSPM	RUAPTQHBBR	5610626449 Dell Way	\N	HOPDZGT	AZ	55067	US	1	RUAPTQHBBR@dell.com	5610626449	1	3381068058777601	2009/04	user2793	password	30	100000	M
2794	GPFSHA	TWUKEVLVCZ	5152927274 Dell Way	\N	LFZSZAF	MS	26389	US	1	TWUKEVLVCZ@dell.com	5152927274	4	5610421826131642	2011/08	user2794	password	28	100000	F
2795	JPOJJK	DTPZELBEXH	8839942451 Dell Way	\N	DPHEUUJ	IA	56382	US	1	DTPZELBEXH@dell.com	8839942451	5	2559880210086703	2008/10	user2795	password	50	40000	F
2796	ZTSKXM	ZWRLYVIFZY	9656519599 Dell Way	\N	NDSHNZU	MA	86024	US	1	ZWRLYVIFZY@dell.com	9656519599	2	6479232518002391	2010/10	user2796	password	89	40000	F
2797	SUKEUG	VFEROKQMXU	6565032189 Dell Way	\N	FEHEZRA	WA	16938	US	1	VFEROKQMXU@dell.com	6565032189	2	8525661122519524	2011/09	user2797	password	42	40000	F
2798	SMGZIM	EZAOPNMKSR	3635942300 Dell Way	\N	SWQJXOL	MS	91982	US	1	EZAOPNMKSR@dell.com	3635942300	1	6638892384245992	2011/05	user2798	password	26	40000	M
2799	KIFWME	XBUKNEDEWA	9408599218 Dell Way	\N	VGXKSKI	AK	54882	US	1	XBUKNEDEWA@dell.com	9408599218	4	9222151988651604	2008/12	user2799	password	77	60000	F
2800	AIUFFV	ZQIETNBUII	5242384691 Dell Way	\N	RTBBBBO	WV	72419	US	1	ZQIETNBUII@dell.com	5242384691	1	7098648687358946	2009/06	user2800	password	89	40000	M
2801	TNAONQ	XSKKTETCWM	6020456055 Dell Way	\N	DXNEMNW	WI	58517	US	1	XSKKTETCWM@dell.com	6020456055	2	1118636468425393	2010/07	user2801	password	76	40000	F
2802	VWOLTG	WEABYCXKGV	1031178177 Dell Way	\N	YKILHGZ	TX	53358	US	1	WEABYCXKGV@dell.com	1031178177	2	1163553385995328	2012/09	user2802	password	23	80000	M
2803	QBHXYM	XAKAYUGTTR	8433245175 Dell Way	\N	BFYIEVV	FL	28505	US	1	XAKAYUGTTR@dell.com	8433245175	5	8999965023249389	2012/08	user2803	password	49	60000	M
2804	SKQEIQ	PIOKOIDFKI	1757016044 Dell Way	\N	ESNZNSF	LA	74264	US	1	PIOKOIDFKI@dell.com	1757016044	2	3934313721023500	2010/10	user2804	password	18	40000	F
2805	QLNHAV	VKKENQOWVH	2367052763 Dell Way	\N	KUVCZEV	CA	49528	US	1	VKKENQOWVH@dell.com	2367052763	3	2994218739680946	2008/10	user2805	password	48	80000	F
2806	YBHUXR	FBFVQCQXML	6296436130 Dell Way	\N	TPLYKNJ	ND	19308	US	1	FBFVQCQXML@dell.com	6296436130	4	9398243285249920	2008/07	user2806	password	32	100000	M
2807	MTMDYO	JTFLKCXVWN	8302395959 Dell Way	\N	GUXUDMW	OR	29174	US	1	JTFLKCXVWN@dell.com	8302395959	4	7649329307023437	2008/09	user2807	password	42	60000	F
2808	VPJKYC	PKNSHIOUPJ	2434123210 Dell Way	\N	SJNFGGK	AZ	10008	US	1	PKNSHIOUPJ@dell.com	2434123210	1	7279856964014471	2010/07	user2808	password	27	40000	F
2809	MSCPIM	CAULPPAYIK	4574766975 Dell Way	\N	LORSYSS	CT	81076	US	1	CAULPPAYIK@dell.com	4574766975	4	3937390005216003	2010/12	user2809	password	52	20000	M
2810	PPZBSZ	WDPMENVPZJ	1698051425 Dell Way	\N	GRIYJLT	RI	15146	US	1	WDPMENVPZJ@dell.com	1698051425	2	9950102253817024	2010/04	user2810	password	65	20000	M
2811	QFPQCT	FOXSKMSTTJ	6234380169 Dell Way	\N	CSTNLNP	MT	83979	US	1	FOXSKMSTTJ@dell.com	6234380169	1	2131781382951885	2009/03	user2811	password	20	100000	F
2812	QMMKRB	IKMVDFONIG	7564899427 Dell Way	\N	GVSULFP	AK	37143	US	1	IKMVDFONIG@dell.com	7564899427	2	5561277328059078	2011/02	user2812	password	84	60000	M
2813	KUHMCR	YXVELIMSOI	4867472719 Dell Way	\N	KJTQYUX	NY	12188	US	1	YXVELIMSOI@dell.com	4867472719	3	2194902499206364	2009/11	user2813	password	70	80000	M
2814	ZGTRER	NJCVVVJEFS	8880774511 Dell Way	\N	YVRSTJT	FL	83029	US	1	NJCVVVJEFS@dell.com	8880774511	3	6941206127870829	2010/04	user2814	password	40	60000	M
2815	BHSSUB	VPXQZCVSAR	3096510647 Dell Way	\N	KTLTMPO	LA	22812	US	1	VPXQZCVSAR@dell.com	3096510647	5	4864414955023676	2010/07	user2815	password	87	60000	M
2816	RHQSCF	QSFSOXSGIM	8623481951 Dell Way	\N	RBYHQIK	UT	35464	US	1	QSFSOXSGIM@dell.com	8623481951	3	8561181867960841	2011/12	user2816	password	67	60000	F
2817	IEJOUC	TMRRFXZSPB	1952663397 Dell Way	\N	RWSZHPG	CO	10057	US	1	TMRRFXZSPB@dell.com	1952663397	5	9992311967536808	2011/05	user2817	password	38	20000	M
2818	RQIUKV	LBBJATYCKU	4436718731 Dell Way	\N	UKBJREJ	RI	18738	US	1	LBBJATYCKU@dell.com	4436718731	3	5208373099099845	2011/08	user2818	password	18	40000	F
2819	ICREOT	FXUZWWKRRU	5191919272 Dell Way	\N	SBMXLGZ	TN	82105	US	1	FXUZWWKRRU@dell.com	5191919272	3	5162518829107285	2010/10	user2819	password	73	100000	M
2820	LZMFFK	ZFGWPXOKQP	4433063501 Dell Way	\N	WOBDNWX	AK	42470	US	1	ZFGWPXOKQP@dell.com	4433063501	3	2609562633559108	2008/04	user2820	password	25	80000	F
2821	PUMZUS	GRHEFSUVPI	3547025772 Dell Way	\N	WSWTQWC	AK	41699	US	1	GRHEFSUVPI@dell.com	3547025772	1	6810223677661271	2009/10	user2821	password	85	100000	M
2822	LYJDEA	LJGDDBTMYL	3048484098 Dell Way	\N	JRBFUCP	AZ	31537	US	1	LJGDDBTMYL@dell.com	3048484098	3	9977076018694788	2008/06	user2822	password	59	60000	F
2823	YSOYDX	FHBHANFMXX	8768981418 Dell Way	\N	ODRQSTW	WA	28690	US	1	FHBHANFMXX@dell.com	8768981418	1	6657594866119326	2010/08	user2823	password	90	40000	F
2824	OINLNU	NUVBZHYXVB	2469411198 Dell Way	\N	OLTIIRN	FL	77654	US	1	NUVBZHYXVB@dell.com	2469411198	4	4721246361732483	2008/12	user2824	password	75	80000	F
2825	HEUCRO	XSOEQLARAL	3411418024 Dell Way	\N	LJUCXYW	AR	60077	US	1	XSOEQLARAL@dell.com	3411418024	2	5631812090985477	2008/12	user2825	password	75	40000	F
2826	OKTDIM	RMDDMVEYGN	7595338266 Dell Way	\N	SJKRFMF	MO	70791	US	1	RMDDMVEYGN@dell.com	7595338266	3	6389246052596719	2010/11	user2826	password	68	20000	F
2827	LFPYXC	BAOXFNDSFM	8795877696 Dell Way	\N	DXSPCEG	TN	73209	US	1	BAOXFNDSFM@dell.com	8795877696	2	6092244809493423	2010/06	user2827	password	79	20000	M
2828	LYNNAO	CXTPBLVOPS	7346607331 Dell Way	\N	GEVLLRD	IN	12435	US	1	CXTPBLVOPS@dell.com	7346607331	5	5108854138292372	2010/11	user2828	password	24	100000	M
2829	PNWDQU	XGWJBKYURD	8103461068 Dell Way	\N	QDOHGWI	WV	76846	US	1	XGWJBKYURD@dell.com	8103461068	3	6647270473651589	2012/07	user2829	password	52	60000	F
2830	JQQDNW	AWYLVTCYJG	7632653162 Dell Way	\N	MRMJALC	SD	97481	US	1	AWYLVTCYJG@dell.com	7632653162	4	5352763291914016	2009/03	user2830	password	55	60000	M
2831	ESIBSF	ADATGYDMLV	9128354326 Dell Way	\N	ZVWLYRK	NV	41326	US	1	ADATGYDMLV@dell.com	9128354326	5	5662215906661004	2010/06	user2831	password	41	60000	F
2832	QQWWQZ	WKGVNTHJTC	7560309966 Dell Way	\N	FFAWQRF	MT	59662	US	1	WKGVNTHJTC@dell.com	7560309966	5	9801668459083886	2008/07	user2832	password	25	80000	F
2833	YOUYLE	FHSZOBTRHY	9112816742 Dell Way	\N	RDOJJCY	AZ	12444	US	1	FHSZOBTRHY@dell.com	9112816742	1	6009525910951198	2008/10	user2833	password	70	100000	F
2834	NXVSDD	LDRNWJUUBX	1165032758 Dell Way	\N	JKGLIIM	IA	52284	US	1	LDRNWJUUBX@dell.com	1165032758	2	3705718421842903	2011/03	user2834	password	68	40000	F
2835	NZHRKK	JXGSRBTPKE	9799795816 Dell Way	\N	WVNFHTR	KS	10573	US	1	JXGSRBTPKE@dell.com	9799795816	1	3043560225050896	2011/04	user2835	password	44	40000	F
2836	QWSBFP	IXHJRXTVTP	3946944318 Dell Way	\N	IYXCQFC	NJ	33959	US	1	IXHJRXTVTP@dell.com	3946944318	2	6236359158065171	2011/06	user2836	password	81	40000	F
2837	OKOESM	LBDIVZCLIB	4528232782 Dell Way	\N	IKSONIV	TN	63788	US	1	LBDIVZCLIB@dell.com	4528232782	3	1817063445225358	2009/11	user2837	password	50	100000	F
2838	AZZMLB	QUXPWIXYRH	6654028001 Dell Way	\N	QFUYAQN	ME	24547	US	1	QUXPWIXYRH@dell.com	6654028001	4	1344827183987945	2008/07	user2838	password	41	20000	M
2839	IOYJET	HUQQROIZEN	6414642012 Dell Way	\N	TDOKRZO	IL	71051	US	1	HUQQROIZEN@dell.com	6414642012	2	2734501341823488	2012/06	user2839	password	69	40000	F
2840	QPEKXY	ANQOWPTKJW	8337059940 Dell Way	\N	YTOYIVQ	WA	27496	US	1	ANQOWPTKJW@dell.com	8337059940	5	6758459084667266	2010/01	user2840	password	65	20000	M
2841	VOPUOD	LDZAXJJTID	9706812870 Dell Way	\N	HGMDXKI	OH	31175	US	1	LDZAXJJTID@dell.com	9706812870	2	3807301107794046	2011/05	user2841	password	18	60000	M
2842	PGNSRQ	SSNBCHKFPQ	6558806224 Dell Way	\N	RTNBBGH	AL	50333	US	1	SSNBCHKFPQ@dell.com	6558806224	4	8482909191865475	2011/02	user2842	password	74	40000	F
2843	HYBYQT	MSVTCAJTSC	8008013914 Dell Way	\N	GUEMCFY	OK	86263	US	1	MSVTCAJTSC@dell.com	8008013914	2	9544412968680264	2010/07	user2843	password	40	100000	F
2844	JUCCGV	XAXYJQRMXL	6929331284 Dell Way	\N	RKNWIGS	CT	61995	US	1	XAXYJQRMXL@dell.com	6929331284	4	2062915599439293	2012/07	user2844	password	61	40000	F
2845	SKNNHO	KGYAXKYJBI	8514631045 Dell Way	\N	XYRDQUS	IN	50954	US	1	KGYAXKYJBI@dell.com	8514631045	2	9699963409919292	2010/08	user2845	password	36	20000	M
2846	UQHIAO	GBLRZUTIRR	2624218081 Dell Way	\N	ZVITOQF	MA	91167	US	1	GBLRZUTIRR@dell.com	2624218081	5	5386032100766897	2010/12	user2846	password	52	40000	M
2847	TNPHUR	TLROEZGWYB	2688656832 Dell Way	\N	ESQUYZS	CO	82407	US	1	TLROEZGWYB@dell.com	2688656832	3	7632733763195575	2011/09	user2847	password	40	60000	F
2848	XTBOMM	GARFHNEJRW	5538904410 Dell Way	\N	ZMUZEXT	LA	49563	US	1	GARFHNEJRW@dell.com	5538904410	1	2698537763673812	2012/06	user2848	password	52	80000	F
2849	NHRANS	RSZFXIWTHJ	1759215602 Dell Way	\N	OGOLAXX	NC	94228	US	1	RSZFXIWTHJ@dell.com	1759215602	2	4512436083983630	2010/01	user2849	password	60	20000	F
2850	GCWYUO	YZLHWFOFTV	9991424047 Dell Way	\N	TFWRDKP	GA	75783	US	1	YZLHWFOFTV@dell.com	9991424047	4	8027388888876886	2010/11	user2850	password	26	100000	M
2851	YUSNSS	ZZPFOUYJOE	2254706988 Dell Way	\N	GGHQWMJ	TX	32952	US	1	ZZPFOUYJOE@dell.com	2254706988	3	1826454793568700	2009/03	user2851	password	20	40000	F
2852	TTTMSS	BXGWWQLBWR	2828815354 Dell Way	\N	JNNWWJC	AK	82242	US	1	BXGWWQLBWR@dell.com	2828815354	2	1460188528522849	2009/06	user2852	password	23	100000	F
2853	UMYNNV	UJSKUUHMDU	2991563155 Dell Way	\N	ZZRJCRE	IN	93124	US	1	UJSKUUHMDU@dell.com	2991563155	3	4495912674814463	2009/07	user2853	password	61	20000	M
2854	NQNJKW	CVRWDDZYDZ	6193370744 Dell Way	\N	PNCGRKE	VA	94744	US	1	CVRWDDZYDZ@dell.com	6193370744	1	5262786331586540	2008/04	user2854	password	52	80000	M
2855	ZBIWDD	NZGRZFUZUH	9051282282 Dell Way	\N	CBZMGWK	SD	14430	US	1	NZGRZFUZUH@dell.com	9051282282	5	4034651757217944	2009/09	user2855	password	35	40000	M
2856	OEWSSW	YJWDEVYMXZ	7323626717 Dell Way	\N	LKGIVBJ	OK	13930	US	1	YJWDEVYMXZ@dell.com	7323626717	1	7481423513032497	2012/05	user2856	password	50	60000	M
2857	IFIEES	AIWWGJTGVE	3817767917 Dell Way	\N	MDZOMRP	GA	77225	US	1	AIWWGJTGVE@dell.com	3817767917	1	2401154825463891	2011/08	user2857	password	73	20000	M
2858	BGATGJ	QCPAWWVAJZ	6053092181 Dell Way	\N	ZXMRNRK	SD	83318	US	1	QCPAWWVAJZ@dell.com	6053092181	3	5260993023402989	2009/08	user2858	password	42	40000	M
2859	JEDSUF	IVCFQCOPCM	1216934856 Dell Way	\N	BTZTDVO	OK	45541	US	1	IVCFQCOPCM@dell.com	1216934856	1	1394684789236635	2009/05	user2859	password	85	80000	M
2860	BLJHUE	JZVMOLOBNH	3696927096 Dell Way	\N	BGLWUDG	SD	24410	US	1	JZVMOLOBNH@dell.com	3696927096	1	6129409719724209	2009/11	user2860	password	27	40000	F
2861	NOERXD	NKSYYUMFVS	5577171859 Dell Way	\N	QRNUYIY	HI	56810	US	1	NKSYYUMFVS@dell.com	5577171859	3	4923520502634347	2011/09	user2861	password	76	20000	F
2862	YVFCJP	VHNPUTKMKC	3611941454 Dell Way	\N	ZEAICGW	NJ	75238	US	1	VHNPUTKMKC@dell.com	3611941454	2	5166953555773944	2008/05	user2862	password	73	20000	F
2863	ZEPPZW	DPQWADGCDK	6399682037 Dell Way	\N	DMNKIDD	NJ	44767	US	1	DPQWADGCDK@dell.com	6399682037	4	8082637181039900	2009/10	user2863	password	19	40000	M
2864	PXYMAN	DXOGDRKOUW	4415975788 Dell Way	\N	BFFFJVP	WI	56759	US	1	DXOGDRKOUW@dell.com	4415975788	2	3553760556504130	2009/08	user2864	password	33	100000	M
2865	DMPRPN	FWQWHFRDHX	9637609531 Dell Way	\N	IMGECFR	MN	57408	US	1	FWQWHFRDHX@dell.com	9637609531	5	2615905789658427	2008/11	user2865	password	72	40000	F
2866	JZYWFV	NCCSUGARPN	8648044502 Dell Way	\N	YTPDKBR	LA	92201	US	1	NCCSUGARPN@dell.com	8648044502	3	7931494430638851	2011/11	user2866	password	25	100000	M
2867	AVBWJE	YCYECPTPNM	9358388500 Dell Way	\N	FRXGJGE	GA	83245	US	1	YCYECPTPNM@dell.com	9358388500	5	7130258369725198	2008/10	user2867	password	57	20000	M
2868	PXYUWB	SADITTWGYN	9092011961 Dell Way	\N	DEWKICF	ID	89761	US	1	SADITTWGYN@dell.com	9092011961	2	6904365668538958	2010/05	user2868	password	37	20000	F
2869	FVDGND	KVXERDCFHH	7504855077 Dell Way	\N	CSQEXXB	SD	29099	US	1	KVXERDCFHH@dell.com	7504855077	2	6260465427767486	2012/04	user2869	password	81	40000	F
2870	AMREWM	BBEFDKNLNF	7915235935 Dell Way	\N	BRCZTXE	MO	25115	US	1	BBEFDKNLNF@dell.com	7915235935	3	5241847809404135	2011/08	user2870	password	61	80000	F
2871	GUATWB	YCFIPQVURN	4990776914 Dell Way	\N	XRHUVTZ	NJ	27843	US	1	YCFIPQVURN@dell.com	4990776914	2	8718789064791054	2008/11	user2871	password	90	40000	M
2872	ABOBZQ	GIFWEAOSXF	7987227129 Dell Way	\N	ZSBSRRX	CO	94454	US	1	GIFWEAOSXF@dell.com	7987227129	1	8545234882272781	2011/06	user2872	password	57	80000	M
2873	CVNTBV	ZYAZNSWTSO	3413926586 Dell Way	\N	UKGMIJL	CO	56413	US	1	ZYAZNSWTSO@dell.com	3413926586	5	9751247556414456	2012/08	user2873	password	53	100000	F
2874	ZRNVQM	WQZPNSHCNS	2555993978 Dell Way	\N	IABRLEF	OK	13869	US	1	WQZPNSHCNS@dell.com	2555993978	3	7212343256920577	2011/06	user2874	password	29	80000	F
2875	RMTEIJ	EXWWEYKXHL	8425240344 Dell Way	\N	YZXCEPD	KY	22062	US	1	EXWWEYKXHL@dell.com	8425240344	5	6169777862261981	2012/08	user2875	password	67	80000	F
2876	KVLUAJ	RXNPHKXTJW	9426887555 Dell Way	\N	QLAFPJJ	MD	41170	US	1	RXNPHKXTJW@dell.com	9426887555	2	9859288268256932	2011/01	user2876	password	25	20000	M
2877	OVXXMU	LCCWZVFWLQ	5994223032 Dell Way	\N	WRFFBQO	WV	11896	US	1	LCCWZVFWLQ@dell.com	5994223032	3	1732745845336467	2011/08	user2877	password	89	20000	F
2878	XCYRNB	UJBPOXBFTT	2634269873 Dell Way	\N	LZUCOTC	CO	41733	US	1	UJBPOXBFTT@dell.com	2634269873	4	9812720572575928	2008/12	user2878	password	49	20000	F
2879	JTOKNY	MDMJFSDYEC	8527149794 Dell Way	\N	TGRNIUW	MT	60180	US	1	MDMJFSDYEC@dell.com	8527149794	4	5704079975839705	2009/10	user2879	password	60	80000	M
2880	DBBBNE	OWKHAJLDCR	6951777191 Dell Way	\N	UPAPMOD	IN	31295	US	1	OWKHAJLDCR@dell.com	6951777191	3	9887577589601280	2009/03	user2880	password	53	40000	F
2881	NLUSAR	DIRMTUPLPF	3279708893 Dell Way	\N	MERAIZG	WY	58861	US	1	DIRMTUPLPF@dell.com	3279708893	2	7809691140893848	2011/08	user2881	password	20	40000	F
2882	VZCNCK	FPEAEQPKCU	3931110262 Dell Way	\N	BDCAKCO	NV	37794	US	1	FPEAEQPKCU@dell.com	3931110262	2	9159755911212416	2009/08	user2882	password	88	20000	M
2883	BSTLXJ	PXOFNYIIZL	7589868538 Dell Way	\N	LAVNPMV	VT	89559	US	1	PXOFNYIIZL@dell.com	7589868538	2	5933581358753145	2011/06	user2883	password	32	80000	F
2884	ZEBIUZ	XZNVIVVTGW	5821428070 Dell Way	\N	PULCPJZ	KS	66515	US	1	XZNVIVVTGW@dell.com	5821428070	1	1823286543134600	2011/10	user2884	password	36	80000	M
2885	IBSIYR	VTARPUXLKR	9535783853 Dell Way	\N	WMHFMQW	AK	67368	US	1	VTARPUXLKR@dell.com	9535783853	4	4510499587748200	2009/06	user2885	password	40	60000	M
2886	AWLSSF	SJUMHGWZCJ	9045402419 Dell Way	\N	GIVWFVN	DC	63700	US	1	SJUMHGWZCJ@dell.com	9045402419	2	1519545424263924	2009/11	user2886	password	59	40000	M
2887	AXLFQU	ACBGZAJIHS	7024495896 Dell Way	\N	EDXARBP	NC	46648	US	1	ACBGZAJIHS@dell.com	7024495896	4	3695223637856543	2009/12	user2887	password	21	40000	M
2888	MLNHMQ	JTPKCYRVCV	5283964949 Dell Way	\N	SDMUTBE	MD	81522	US	1	JTPKCYRVCV@dell.com	5283964949	4	7904614568222315	2010/11	user2888	password	65	20000	F
2889	EIVURO	KBRITMLPEP	7149477956 Dell Way	\N	CYIDDSX	NH	42759	US	1	KBRITMLPEP@dell.com	7149477956	1	3233874827623367	2009/02	user2889	password	61	60000	F
2890	KIDZSF	QBZCNOHCQG	7805526340 Dell Way	\N	KUJDRZN	LA	19320	US	1	QBZCNOHCQG@dell.com	7805526340	4	3295399970840663	2009/03	user2890	password	70	80000	M
2891	WTGBJI	BMWPTYGAJA	7299168055 Dell Way	\N	JNSIACL	RI	81458	US	1	BMWPTYGAJA@dell.com	7299168055	1	1163651039358228	2010/11	user2891	password	58	40000	M
2892	VJADKM	ZAGYGGIHQV	9159651313 Dell Way	\N	AZWCKQX	CT	79167	US	1	ZAGYGGIHQV@dell.com	9159651313	3	7002580195665360	2010/10	user2892	password	40	40000	F
2893	ILOVKO	CJVJRDZNDZ	4963729288 Dell Way	\N	JGKADNU	AL	15307	US	1	CJVJRDZNDZ@dell.com	4963729288	3	8888488187920303	2011/10	user2893	password	21	20000	F
2894	PXPEAZ	AJQDJEHINN	2630120705 Dell Way	\N	SNQGHRH	PA	23704	US	1	AJQDJEHINN@dell.com	2630120705	3	9334271866828204	2009/07	user2894	password	27	100000	F
2895	TAMSAV	JDFNLNBYGP	3720775534 Dell Way	\N	ONXFVQJ	WY	22345	US	1	JDFNLNBYGP@dell.com	3720775534	2	7410059071611614	2010/01	user2895	password	32	20000	F
2896	RWBNGF	SUQGVONKDA	8173643543 Dell Way	\N	HJVYTVC	AL	14423	US	1	SUQGVONKDA@dell.com	8173643543	3	1870578996837139	2012/08	user2896	password	28	80000	M
2897	FFTLXN	BEJQSTTSBD	5906017315 Dell Way	\N	OAWKCXL	VA	41802	US	1	BEJQSTTSBD@dell.com	5906017315	5	9834001265000552	2011/07	user2897	password	53	100000	M
2898	GIRTKW	CAOWUHYXWY	9835782067 Dell Way	\N	TGBQSYA	IA	86037	US	1	CAOWUHYXWY@dell.com	9835782067	5	4645085703115910	2010/11	user2898	password	29	80000	F
2899	VMORPP	GLJNKGJJAQ	6589498868 Dell Way	\N	KRIJROF	NM	54491	US	1	GLJNKGJJAQ@dell.com	6589498868	1	4018307154998183	2011/10	user2899	password	54	80000	F
2900	BHXQOJ	ABTGLCHBNY	7824892065 Dell Way	\N	JXPYCGK	OR	43750	US	1	ABTGLCHBNY@dell.com	7824892065	3	2832651307340711	2009/02	user2900	password	55	40000	F
2901	KZZTZA	NGMPNNDMXA	9261170519 Dell Way	\N	CVDIGXS	WY	46147	US	1	NGMPNNDMXA@dell.com	9261170519	2	5770119654014707	2010/08	user2901	password	87	100000	M
2902	YONYBU	KRHYVUVWWQ	8498305595 Dell Way	\N	AFWXXWH	TN	21112	US	1	KRHYVUVWWQ@dell.com	8498305595	2	7410043820738793	2011/01	user2902	password	38	80000	M
2903	VRSPCK	XAGRVCNMCS	1368503156 Dell Way	\N	IAQFILI	DC	72561	US	1	XAGRVCNMCS@dell.com	1368503156	5	7921534449793399	2009/08	user2903	password	48	20000	F
2904	DSKOPL	UHHWUTZNCA	1349181000 Dell Way	\N	DHIOQMH	NY	47663	US	1	UHHWUTZNCA@dell.com	1349181000	5	1696145665831864	2010/02	user2904	password	47	60000	M
2905	VDLGXS	OUNHUAKUES	1817346703 Dell Way	\N	DTIPAZA	AR	97677	US	1	OUNHUAKUES@dell.com	1817346703	3	1767407395411282	2010/02	user2905	password	84	40000	F
2906	JPDCDY	PLSQVNUNQN	9124922033 Dell Way	\N	WGNVGOV	KY	14960	US	1	PLSQVNUNQN@dell.com	9124922033	5	2283948410302400	2012/02	user2906	password	44	20000	M
2907	NGXLWI	EMERGSIUOO	1396913591 Dell Way	\N	HKUWFDX	CT	97015	US	1	EMERGSIUOO@dell.com	1396913591	5	2134173976257443	2010/02	user2907	password	82	100000	F
2908	UJFCNR	HFYZOSOCZY	2041321578 Dell Way	\N	XVEATHZ	SC	29435	US	1	HFYZOSOCZY@dell.com	2041321578	1	3960535545367748	2012/02	user2908	password	68	80000	F
2909	XWAPDG	NDUGRWGPTC	6356505186 Dell Way	\N	UUVBTPG	VA	83229	US	1	NDUGRWGPTC@dell.com	6356505186	5	9393447244074196	2009/08	user2909	password	48	20000	M
2910	LURRIU	LOMHUCBXWV	1654888165 Dell Way	\N	SXPIEMD	RI	42762	US	1	LOMHUCBXWV@dell.com	1654888165	1	1056121816392987	2010/04	user2910	password	55	100000	F
2911	EPJZAY	LITOJQKFII	7100394641 Dell Way	\N	VRNHVHR	VA	40600	US	1	LITOJQKFII@dell.com	7100394641	2	6404824858997018	2008/04	user2911	password	65	40000	M
2912	AJXZVF	SJPIUVRDQJ	8538564354 Dell Way	\N	QYEXQBG	IN	48602	US	1	SJPIUVRDQJ@dell.com	8538564354	3	7488978751003743	2010/11	user2912	password	61	60000	F
2913	MMCSFL	IOGDGJUPZS	9744958748 Dell Way	\N	TXJVDQG	WV	22584	US	1	IOGDGJUPZS@dell.com	9744958748	3	1173549836501479	2010/12	user2913	password	37	20000	F
2914	JUQUCE	BGKLAAKTUH	9014110050 Dell Way	\N	CPLTWKW	SD	85624	US	1	BGKLAAKTUH@dell.com	9014110050	2	8260302016511560	2008/06	user2914	password	36	60000	F
2915	XIICJO	NUPNFIHNKX	9889378236 Dell Way	\N	YDTIAOE	VA	96548	US	1	NUPNFIHNKX@dell.com	9889378236	1	4738523027393967	2009/07	user2915	password	65	20000	M
2916	ZGGOTB	DGGLOUVMTZ	2469981058 Dell Way	\N	FCZUGXT	IA	95252	US	1	DGGLOUVMTZ@dell.com	2469981058	3	5600004805251956	2012/08	user2916	password	46	80000	M
2917	QIQRLX	YXLTTYMSDO	1488288267 Dell Way	\N	SYVPRCO	TN	62011	US	1	YXLTTYMSDO@dell.com	1488288267	4	2972388433292508	2010/06	user2917	password	25	20000	M
2918	STFPSC	BMVZYODNGB	3079160284 Dell Way	\N	JWSLKOA	MN	28766	US	1	BMVZYODNGB@dell.com	3079160284	5	6797103882767261	2009/12	user2918	password	47	20000	M
2919	QRLTSY	OSWDVKKXTG	1306646076 Dell Way	\N	QEQEFCK	ME	99303	US	1	OSWDVKKXTG@dell.com	1306646076	4	9712433645036072	2010/10	user2919	password	69	20000	F
2920	EUECJX	ZMTJWQDDGH	8379127744 Dell Way	\N	TLMWVXW	TX	70018	US	1	ZMTJWQDDGH@dell.com	8379127744	2	5188465383369476	2010/05	user2920	password	85	80000	F
2921	CUOZUA	SDXJGAPOUA	1868563279 Dell Way	\N	BRWZNSQ	KS	10113	US	1	SDXJGAPOUA@dell.com	1868563279	5	4320926393847913	2008/07	user2921	password	57	20000	F
2922	CCDCVH	AENBUCWVDN	7659344910 Dell Way	\N	RCBJTJJ	TN	30928	US	1	AENBUCWVDN@dell.com	7659344910	5	8155276870355011	2009/12	user2922	password	29	40000	F
2923	HMXOMC	COWELRIYJL	4498699418 Dell Way	\N	ZSEJCZP	TN	86321	US	1	COWELRIYJL@dell.com	4498699418	1	8319266710430384	2010/06	user2923	password	82	100000	M
2924	UKLWMZ	TRKLAJULJN	3360550220 Dell Way	\N	PSQPIML	OH	61893	US	1	TRKLAJULJN@dell.com	3360550220	2	1422308817971497	2008/01	user2924	password	89	100000	F
2925	KVZKOQ	VAQFVCOIRH	1474363600 Dell Way	\N	ZHPLTIA	WY	60409	US	1	VAQFVCOIRH@dell.com	1474363600	1	6775266124866903	2008/01	user2925	password	26	60000	M
2926	CWMSSM	JXHLMQDTPK	8871810342 Dell Way	\N	JBDRBDG	CO	36022	US	1	JXHLMQDTPK@dell.com	8871810342	1	4333651275373995	2012/08	user2926	password	37	20000	F
2927	TUEFEB	NQNETHUERV	2161855550 Dell Way	\N	IIWMOYT	MI	18697	US	1	NQNETHUERV@dell.com	2161855550	3	7203760590404273	2009/07	user2927	password	29	20000	F
2928	IJMJWC	XBWFVAWQIE	3224630933 Dell Way	\N	NVTLOEO	OH	65410	US	1	XBWFVAWQIE@dell.com	3224630933	1	2062280167359858	2009/03	user2928	password	48	80000	M
2929	XCMZAN	VFIWBZFGMA	9464599225 Dell Way	\N	AYPFNHV	PA	44119	US	1	VFIWBZFGMA@dell.com	9464599225	1	6525376764126123	2009/11	user2929	password	33	40000	M
2930	RGYFBE	OXGNCNADNY	9734786642 Dell Way	\N	STLZOFJ	MS	41061	US	1	OXGNCNADNY@dell.com	9734786642	5	2821709684096277	2008/02	user2930	password	28	100000	F
2931	CBKGPI	NDLADOOCGH	3502927151 Dell Way	\N	NFVSPIB	ND	26407	US	1	NDLADOOCGH@dell.com	3502927151	4	3609221116174012	2010/08	user2931	password	64	60000	M
2932	BUGJHJ	UINJWPPDDV	7897482205 Dell Way	\N	ZWKHYZM	GA	72943	US	1	UINJWPPDDV@dell.com	7897482205	4	3605785042978823	2009/02	user2932	password	86	60000	M
2933	EUGOPP	BYLROPUKOQ	7786952047 Dell Way	\N	UWOTITM	CA	45919	US	1	BYLROPUKOQ@dell.com	7786952047	3	6064617964439095	2011/12	user2933	password	56	100000	M
2934	ULIJNH	VEWLZGZPAV	8965351639 Dell Way	\N	EUEYGGI	AK	78134	US	1	VEWLZGZPAV@dell.com	8965351639	4	7216716439463199	2010/08	user2934	password	49	40000	F
2935	TPOBKT	XVSDVHERLZ	5865595184 Dell Way	\N	VJGCSGW	NE	97148	US	1	XVSDVHERLZ@dell.com	5865595184	5	6030043309554458	2012/03	user2935	password	61	80000	M
2936	DUFXSA	PWWWBNIAJS	1424887875 Dell Way	\N	GLKNHZM	TN	97847	US	1	PWWWBNIAJS@dell.com	1424887875	5	2523825197946280	2011/07	user2936	password	87	80000	F
2937	DRBEGX	BDYOMZYEGJ	7370460044 Dell Way	\N	PTROGNO	IL	39528	US	1	BDYOMZYEGJ@dell.com	7370460044	5	8870289165060968	2011/09	user2937	password	34	80000	F
2938	HZREAV	DPHDNLJWAC	3499177686 Dell Way	\N	OPJBDQK	TX	62413	US	1	DPHDNLJWAC@dell.com	3499177686	3	3784085440449417	2010/04	user2938	password	70	80000	F
2939	JZHFCW	MGJYPGZSUO	6419875236 Dell Way	\N	BWSSGOH	NC	13364	US	1	MGJYPGZSUO@dell.com	6419875236	1	3947725440841168	2009/10	user2939	password	60	80000	M
2940	WXXSJD	BHSHGKCVMY	4860115839 Dell Way	\N	NFFBMTC	CA	81344	US	1	BHSHGKCVMY@dell.com	4860115839	3	6468900087289513	2008/02	user2940	password	46	100000	F
2941	HPJKQR	DYYOATAYHF	3715078266 Dell Way	\N	DJSXLUS	UT	28854	US	1	DYYOATAYHF@dell.com	3715078266	5	3862837590742856	2011/10	user2941	password	41	100000	F
2942	SJZJMX	HBXBBWJHAS	4064054438 Dell Way	\N	AXDVPAA	VT	93119	US	1	HBXBBWJHAS@dell.com	4064054438	3	7244649483822287	2011/07	user2942	password	21	40000	M
2943	ASLYAM	WCOSLWTDWQ	9299674610 Dell Way	\N	HRGHSEF	AR	77700	US	1	WCOSLWTDWQ@dell.com	9299674610	4	3857818310149014	2012/01	user2943	password	36	100000	M
2944	SYUEUW	TNIPGLLXSD	4401767746 Dell Way	\N	DAVIGWB	FL	61403	US	1	TNIPGLLXSD@dell.com	4401767746	1	6659491041209549	2011/02	user2944	password	47	40000	F
2945	FNXCGK	KVRWHPOKTP	3767648599 Dell Way	\N	GBWCCAR	MO	26224	US	1	KVRWHPOKTP@dell.com	3767648599	1	3904864394571632	2011/06	user2945	password	47	100000	M
2946	HAFSKA	KHIZWSSLYT	8611514827 Dell Way	\N	HBWITJN	AR	52139	US	1	KHIZWSSLYT@dell.com	8611514827	4	9256519468035550	2009/09	user2946	password	81	60000	M
2947	BHDCRK	KRGDJRCDZE	7742943770 Dell Way	\N	AIXJWYV	OH	75082	US	1	KRGDJRCDZE@dell.com	7742943770	5	4704257396515459	2011/07	user2947	password	26	80000	M
2948	GUMQFD	WJNOLROPRW	6439077204 Dell Way	\N	NATMWLF	NJ	46357	US	1	WJNOLROPRW@dell.com	6439077204	2	9274295447859914	2011/12	user2948	password	69	100000	M
2949	EOZILI	VZUMNJDKXE	9254264291 Dell Way	\N	DJBPORZ	DE	91799	US	1	VZUMNJDKXE@dell.com	9254264291	5	8646220982074738	2011/10	user2949	password	61	100000	F
2950	ODVXYV	RLJBPTYTXH	3215161709 Dell Way	\N	VNWMNAK	ME	91077	US	1	RLJBPTYTXH@dell.com	3215161709	1	7565462171565742	2012/11	user2950	password	27	60000	M
2951	ZHYUYJ	EZYYYSVGNJ	7689150203 Dell Way	\N	CAWCKHA	NV	40917	US	1	EZYYYSVGNJ@dell.com	7689150203	3	2866153346840292	2012/11	user2951	password	32	100000	F
2952	DQDMUD	KSBCOHQYJQ	6653768883 Dell Way	\N	UMBCNSK	IA	26761	US	1	KSBCOHQYJQ@dell.com	6653768883	1	1751695735845714	2012/12	user2952	password	37	100000	M
2953	KKLOVE	PYTXPRHFLU	3026653788 Dell Way	\N	GNHYYOD	NE	70730	US	1	PYTXPRHFLU@dell.com	3026653788	2	6872332046274096	2010/05	user2953	password	38	100000	M
2954	SLPWBN	PYCGGISAPF	2696636429 Dell Way	\N	IOEWRTN	VT	22081	US	1	PYCGGISAPF@dell.com	2696636429	3	5214507482945919	2010/04	user2954	password	34	20000	M
2955	UBVIQU	LXATPBJVJX	4054389777 Dell Way	\N	ZGOTUMW	WV	89276	US	1	LXATPBJVJX@dell.com	4054389777	3	2756369241047650	2010/08	user2955	password	88	40000	M
2956	USHPDE	QXURGPBDPH	3380139440 Dell Way	\N	SIBEFAB	ND	50986	US	1	QXURGPBDPH@dell.com	3380139440	1	1517556272912770	2009/06	user2956	password	69	20000	F
2957	ZPIEFF	YXMOZQEGIM	8756854203 Dell Way	\N	INSJPGU	TX	42936	US	1	YXMOZQEGIM@dell.com	8756854203	1	8583550552371890	2010/02	user2957	password	19	60000	M
2958	ISYORW	BFVRJBAWKN	1421093018 Dell Way	\N	PTCVOZF	MD	15029	US	1	BFVRJBAWKN@dell.com	1421093018	5	2469663363881409	2008/07	user2958	password	82	60000	F
2959	VZXRAD	MRMORJYFYR	5659349861 Dell Way	\N	IUFHZQJ	AR	64241	US	1	MRMORJYFYR@dell.com	5659349861	1	2082311327569186	2009/07	user2959	password	43	40000	F
2960	GXNJJF	WYXGWCFOLZ	2276602703 Dell Way	\N	USZKCBA	NH	24125	US	1	WYXGWCFOLZ@dell.com	2276602703	5	7103193543851376	2010/03	user2960	password	30	80000	F
2961	RDMXZK	UGHWLVILQA	3852909628 Dell Way	\N	LBDMBSQ	GA	74491	US	1	UGHWLVILQA@dell.com	3852909628	4	9371380568016320	2010/06	user2961	password	20	20000	M
2962	NBOXWU	FSGAARQBDR	6076882143 Dell Way	\N	FPTXGYQ	ND	68226	US	1	FSGAARQBDR@dell.com	6076882143	1	1843343284912407	2010/03	user2962	password	66	20000	F
2963	FADAFW	GGXYXZBOER	1103142440 Dell Way	\N	ICXHTMX	IN	57962	US	1	GGXYXZBOER@dell.com	1103142440	5	7850683395750821	2011/12	user2963	password	22	100000	F
2964	FXGBEM	ZDJYFYDXGG	6323627745 Dell Way	\N	VNZHLGV	MN	23970	US	1	ZDJYFYDXGG@dell.com	6323627745	1	2391215409617871	2011/01	user2964	password	30	100000	M
2965	KXDXXH	GVMFZKLFFZ	7811738655 Dell Way	\N	ENLLIXP	WA	13588	US	1	GVMFZKLFFZ@dell.com	7811738655	3	1653770430479198	2012/05	user2965	password	19	40000	F
2966	EFFLMB	YRBIDGNDLA	6204793245 Dell Way	\N	OXJMMHN	IA	87483	US	1	YRBIDGNDLA@dell.com	6204793245	1	3497222302015871	2011/07	user2966	password	62	80000	M
2967	VFGXEX	YMBEAEQBSN	8814778544 Dell Way	\N	LFASSHP	IL	51250	US	1	YMBEAEQBSN@dell.com	8814778544	5	9864480040036144	2010/08	user2967	password	72	40000	M
2968	ZEBXCO	YHOCYQVMCA	2849542011 Dell Way	\N	MVSTKAF	IL	89608	US	1	YHOCYQVMCA@dell.com	2849542011	4	5849132674280555	2012/01	user2968	password	48	100000	F
2969	LVIZTQ	OWPFRBHSOD	8791885253 Dell Way	\N	LHNLNUI	OR	59329	US	1	OWPFRBHSOD@dell.com	8791885253	4	6375971938483418	2009/08	user2969	password	78	80000	F
2970	ESEVHA	KNSMVLAYWH	4606444295 Dell Way	\N	LIVGQOU	MT	30381	US	1	KNSMVLAYWH@dell.com	4606444295	4	8435046223923565	2009/07	user2970	password	35	60000	F
2971	KGOLQB	ECXPCVMKHV	8586692060 Dell Way	\N	GNLUIZA	OR	78900	US	1	ECXPCVMKHV@dell.com	8586692060	5	3649853317998350	2008/05	user2971	password	58	60000	M
2972	CYGEDJ	CTMXFXEBDS	5766541926 Dell Way	\N	MXBMYVG	RI	80630	US	1	CTMXFXEBDS@dell.com	5766541926	5	2503427513875067	2008/05	user2972	password	75	20000	F
2973	BJLKME	XJKUOLXHYV	2033735210 Dell Way	\N	JLUEROY	FL	47419	US	1	XJKUOLXHYV@dell.com	2033735210	2	8082164328545333	2012/06	user2973	password	26	100000	M
2974	OJITGR	EAGQYNPUWA	3687001141 Dell Way	\N	OBRCZWN	CO	23847	US	1	EAGQYNPUWA@dell.com	3687001141	1	6627957709599287	2010/12	user2974	password	53	100000	F
2975	UTOMXP	SONGDHDEWE	5663919981 Dell Way	\N	WYETLHX	PA	35372	US	1	SONGDHDEWE@dell.com	5663919981	1	3050636286381632	2012/02	user2975	password	56	80000	M
2976	CHURAJ	EHMMKRIPNH	5982457987 Dell Way	\N	THTBEMI	NY	69018	US	1	EHMMKRIPNH@dell.com	5982457987	4	8190078012645245	2008/06	user2976	password	67	20000	M
2977	MVUVAB	IMMZVBNCVU	8044938058 Dell Way	\N	VWYIEQZ	OR	37759	US	1	IMMZVBNCVU@dell.com	8044938058	5	8076526949647815	2010/12	user2977	password	58	100000	M
2978	ITVJBH	VBDXOFSIBO	1117460349 Dell Way	\N	HKTXJNF	DE	40259	US	1	VBDXOFSIBO@dell.com	1117460349	4	3918541447725147	2010/07	user2978	password	27	100000	F
2979	YGJGCK	JZZPSHRHPB	2927398614 Dell Way	\N	BNLOTPX	PA	31474	US	1	JZZPSHRHPB@dell.com	2927398614	2	8133033118210734	2009/03	user2979	password	24	40000	F
2980	LOOWXO	VNGDFNSGOG	4295176173 Dell Way	\N	SDZIASO	HI	13529	US	1	VNGDFNSGOG@dell.com	4295176173	3	3158440192695707	2010/11	user2980	password	69	100000	F
2981	GUIVPW	BSBPLIERAH	6847900772 Dell Way	\N	QJIJYOK	IN	21643	US	1	BSBPLIERAH@dell.com	6847900772	4	1011728466022759	2009/09	user2981	password	48	80000	F
2982	TLBPMU	QCFZGXAONJ	6059377904 Dell Way	\N	WXILIQO	WV	46169	US	1	QCFZGXAONJ@dell.com	6059377904	2	1788140560965985	2012/12	user2982	password	57	80000	F
2983	PIWJZY	PYFMYUZHQX	7629543656 Dell Way	\N	QCFGQEQ	GA	53800	US	1	PYFMYUZHQX@dell.com	7629543656	1	4733042716979981	2009/11	user2983	password	74	100000	F
2984	QGEOVC	UHAOHIFFYH	5427566786 Dell Way	\N	KFYPWDC	NE	38857	US	1	UHAOHIFFYH@dell.com	5427566786	5	3025626024231315	2009/09	user2984	password	50	100000	F
2985	QLVTGD	UULCZQBGBG	8874216183 Dell Way	\N	FRCITRQ	HI	60149	US	1	UULCZQBGBG@dell.com	8874216183	3	3748341132886708	2009/05	user2985	password	40	100000	M
2986	DSBHMV	SPVJQCLXHC	6031432098 Dell Way	\N	APVSGBG	CT	59718	US	1	SPVJQCLXHC@dell.com	6031432098	3	9365831949282438	2012/05	user2986	password	73	20000	F
2987	VHORAD	MKUOVRVYRL	3943039386 Dell Way	\N	UJSVQVK	FL	35634	US	1	MKUOVRVYRL@dell.com	3943039386	1	7188665302470327	2008/01	user2987	password	75	100000	F
2988	JPJMBU	HQQYMOQYJA	5005576329 Dell Way	\N	QFRMPWT	WA	92300	US	1	HQQYMOQYJA@dell.com	5005576329	1	9850846434477718	2009/12	user2988	password	43	60000	M
2989	SBONIF	DHSSXQBYGG	4140250212 Dell Way	\N	PTVLMTJ	WI	80022	US	1	DHSSXQBYGG@dell.com	4140250212	1	7327174274250866	2011/09	user2989	password	33	60000	M
2990	UYDZBK	RTIIUHPBWI	2337934920 Dell Way	\N	XIVRSUL	AR	95038	US	1	RTIIUHPBWI@dell.com	2337934920	4	7212788139004261	2009/02	user2990	password	54	20000	F
2991	QDDBVX	KDSRTTOBQX	3773695807 Dell Way	\N	XIPRTQQ	VT	43186	US	1	KDSRTTOBQX@dell.com	3773695807	2	5723369190935046	2012/05	user2991	password	62	60000	M
2992	TNJQXN	IPGBDISAFA	2307622986 Dell Way	\N	QXUGNSQ	TN	97293	US	1	IPGBDISAFA@dell.com	2307622986	4	4407747613731772	2011/01	user2992	password	85	60000	M
2993	HCMVLB	BMFKFGQGWN	1742127432 Dell Way	\N	ACBTTXS	UT	56862	US	1	BMFKFGQGWN@dell.com	1742127432	4	6382161504589022	2008/02	user2993	password	30	40000	F
2994	RDRSFE	YPJEGPAUQD	8534867712 Dell Way	\N	VJWSCTG	DE	44601	US	1	YPJEGPAUQD@dell.com	8534867712	1	5518057385459543	2008/06	user2994	password	71	80000	M
2995	KKUOIJ	YMQNNKERFO	2598409371 Dell Way	\N	NYQHEUR	AL	96395	US	1	YMQNNKERFO@dell.com	2598409371	1	4863026903476566	2012/09	user2995	password	19	40000	F
2996	UWKEUX	UIKFMCKBQJ	8701351583 Dell Way	\N	RXOMPOL	PA	64290	US	1	UIKFMCKBQJ@dell.com	8701351583	4	3784350995905697	2012/12	user2996	password	47	80000	M
2997	VWQSRY	DWLFHMWQDT	6968437464 Dell Way	\N	EQITBCJ	VA	79233	US	1	DWLFHMWQDT@dell.com	6968437464	4	7721655693370850	2008/06	user2997	password	60	100000	F
2998	FQYDUU	PABBWSFPXV	6025515506 Dell Way	\N	YQWBZUV	NV	59496	US	1	PABBWSFPXV@dell.com	6025515506	4	9949863914400340	2008/08	user2998	password	39	40000	F
2999	GMABCA	CDWVJMSELI	4430656587 Dell Way	\N	BMIVHZK	TN	74062	US	1	CDWVJMSELI@dell.com	4430656587	5	3985692017246038	2011/05	user2999	password	60	100000	M
3000	PYXQBB	MXKZPPKYRW	3773100055 Dell Way	\N	HMEGWAZ	ID	99311	US	1	MXKZPPKYRW@dell.com	3773100055	5	3954634865745902	2012/11	user3000	password	29	60000	M
3001	CCXDPU	OPKDZIUWPH	4352676523 Dell Way	\N	BWEBWLB	DC	43518	US	1	OPKDZIUWPH@dell.com	4352676523	1	3012072252109647	2010/07	user3001	password	20	80000	M
3002	YTFSIU	CLULGRAOSX	7913123490 Dell Way	\N	TUTEVXO	FL	95573	US	1	CLULGRAOSX@dell.com	7913123490	4	5245386016089469	2012/05	user3002	password	24	80000	F
3003	ILKDNW	XYDPZRIXKC	9876472900 Dell Way	\N	QPXODCN	VA	82995	US	1	XYDPZRIXKC@dell.com	9876472900	4	2375477741006762	2008/06	user3003	password	36	40000	M
3004	RNKNLJ	QAJIIGSKXI	4220202450 Dell Way	\N	HMLKZIF	WY	13647	US	1	QAJIIGSKXI@dell.com	4220202450	1	5240566568449140	2011/06	user3004	password	42	40000	M
3005	TUKCLK	MTTTMDRULD	1722842195 Dell Way	\N	FWDOBCP	MD	25215	US	1	MTTTMDRULD@dell.com	1722842195	1	6609140663873405	2010/04	user3005	password	60	20000	F
3006	ZHMKTG	DMSHDMSHSO	3835275005 Dell Way	\N	KHQNXAR	WY	15169	US	1	DMSHDMSHSO@dell.com	3835275005	3	4084762671962381	2012/07	user3006	password	48	100000	M
3007	XHPDKC	WRGJKOBZZJ	1385397003 Dell Way	\N	PMHQEGS	MS	69498	US	1	WRGJKOBZZJ@dell.com	1385397003	2	3112515724264085	2010/04	user3007	password	24	40000	M
3008	SNYVJQ	CSAQUAPEQC	6231890572 Dell Way	\N	LGGRYTJ	AK	23496	US	1	CSAQUAPEQC@dell.com	6231890572	3	4885283894836903	2011/10	user3008	password	90	40000	F
3009	YFRPHK	QXEQNIGPUN	2663468953 Dell Way	\N	WLMPUMT	MA	93641	US	1	QXEQNIGPUN@dell.com	2663468953	1	7757231436669827	2008/06	user3009	password	23	20000	M
3010	USXEIV	JYISFYMSUY	3890225999 Dell Way	\N	EJTQDDO	KS	27996	US	1	JYISFYMSUY@dell.com	3890225999	3	6757657464593650	2010/08	user3010	password	38	20000	F
3011	FIQASP	JKUHXMBVQL	6058935034 Dell Way	\N	PHPSWXX	FL	45388	US	1	JKUHXMBVQL@dell.com	6058935034	3	1052279086783528	2012/10	user3011	password	41	20000	F
3012	YBUNKF	HSCUUYLFNS	1927016178 Dell Way	\N	UGPSETC	OK	40381	US	1	HSCUUYLFNS@dell.com	1927016178	3	1796680974308401	2010/08	user3012	password	31	40000	M
3013	ZXBEFU	HZOFLTSDOY	9118449846 Dell Way	\N	SHCMJVV	MO	44840	US	1	HZOFLTSDOY@dell.com	9118449846	5	9804694376420232	2008/04	user3013	password	63	20000	F
3014	RGKMNJ	ASUULYIKRQ	7282226180 Dell Way	\N	NDZIYLS	TX	42174	US	1	ASUULYIKRQ@dell.com	7282226180	5	6648235695902259	2009/12	user3014	password	76	20000	F
3015	EMTOMM	JGXIPIZFVC	6918199031 Dell Way	\N	FDBRWXA	NE	87124	US	1	JGXIPIZFVC@dell.com	6918199031	5	8693324813619257	2010/11	user3015	password	24	80000	F
3016	WFWIPD	GXTOWZKZEO	7118683942 Dell Way	\N	BWKZWZV	NC	89706	US	1	GXTOWZKZEO@dell.com	7118683942	5	8163304675836117	2011/08	user3016	password	31	80000	M
3017	BYLFFI	YUFXEFCSGY	8396819200 Dell Way	\N	DFVDAJA	OK	41857	US	1	YUFXEFCSGY@dell.com	8396819200	3	1002819282468408	2008/02	user3017	password	80	20000	F
3018	HGHQFC	WDGBFZHDDN	7022630613 Dell Way	\N	YHNIIGR	CT	76870	US	1	WDGBFZHDDN@dell.com	7022630613	1	8728645508177579	2010/03	user3018	password	86	100000	F
3019	FMRHIU	OKAORDSECZ	6191382104 Dell Way	\N	SKHZCLS	PA	61068	US	1	OKAORDSECZ@dell.com	6191382104	2	7954138950910420	2010/02	user3019	password	35	80000	M
3020	YBYSPI	SEAWWFZWXJ	9451474392 Dell Way	\N	EXMPPFE	FL	55126	US	1	SEAWWFZWXJ@dell.com	9451474392	4	6602466376498342	2008/06	user3020	password	34	20000	F
3021	EVCMOG	NKDSJAQTEN	5981182488 Dell Way	\N	FUDLYIY	VA	11017	US	1	NKDSJAQTEN@dell.com	5981182488	1	5012030562851578	2011/03	user3021	password	85	100000	F
3022	ALOHYY	LRILHCQVHK	7341222159 Dell Way	\N	YSJGRGG	GA	39749	US	1	LRILHCQVHK@dell.com	7341222159	5	5597389488015324	2011/12	user3022	password	55	80000	F
3023	BXIAIA	JUHLKCTVBL	3596309624 Dell Way	\N	EHCLOIU	ID	37893	US	1	JUHLKCTVBL@dell.com	3596309624	5	3211985311470926	2012/07	user3023	password	63	100000	F
3024	ZXUZGO	HSZKLULXZT	9113793837 Dell Way	\N	ALHIFOR	MS	48339	US	1	HSZKLULXZT@dell.com	9113793837	2	9543647030368448	2010/03	user3024	password	46	60000	F
3025	EMJTUB	SENNQLNJLY	6072517036 Dell Way	\N	QUEELRP	LA	98948	US	1	SENNQLNJLY@dell.com	6072517036	5	2579900138545781	2012/05	user3025	password	37	20000	M
3026	QWRSPV	FCMQPVCOMX	6197356213 Dell Way	\N	TRJKHSK	TN	63801	US	1	FCMQPVCOMX@dell.com	6197356213	4	9911259885877372	2012/11	user3026	password	81	60000	M
3027	NEJJKM	VBCRDQDBKU	7384139636 Dell Way	\N	KUBDFXS	RI	70840	US	1	VBCRDQDBKU@dell.com	7384139636	4	6314534591510893	2010/02	user3027	password	45	20000	F
3028	TMRFIS	HZWYDYIXIC	2116466409 Dell Way	\N	ZMIWECN	VA	74718	US	1	HZWYDYIXIC@dell.com	2116466409	3	8371693331282587	2010/08	user3028	password	25	40000	F
3029	ULLMSL	JQOIZMRCLD	1247740500 Dell Way	\N	KHIMVFF	WI	71772	US	1	JQOIZMRCLD@dell.com	1247740500	3	3551928322762251	2008/09	user3029	password	45	100000	F
3030	UKVGUM	UCLGTNSWXA	4285959843 Dell Way	\N	EKVKPUC	NM	31973	US	1	UCLGTNSWXA@dell.com	4285959843	4	9337034898344428	2011/08	user3030	password	21	60000	F
3031	WUVJPX	UVRHOOFOSQ	4213462654 Dell Way	\N	KDGEFWL	ND	67236	US	1	UVRHOOFOSQ@dell.com	4213462654	2	3652453438844532	2009/11	user3031	password	43	40000	M
3032	EQFCKB	TSQHYEAOOD	6391565928 Dell Way	\N	UTJREXH	NC	30604	US	1	TSQHYEAOOD@dell.com	6391565928	5	1794501696247607	2012/03	user3032	password	71	20000	M
3033	YFGAZY	QHXVHLKLGD	1318104054 Dell Way	\N	UXISFXY	SD	84839	US	1	QHXVHLKLGD@dell.com	1318104054	4	1408882283139973	2011/11	user3033	password	82	80000	F
3034	DTCBKJ	ZFRKPDRTXP	8873067304 Dell Way	\N	CQUZPQV	NJ	44645	US	1	ZFRKPDRTXP@dell.com	8873067304	2	3490643304307014	2011/02	user3034	password	46	100000	M
3035	MYGVXM	NICQZWOOZE	6883186837 Dell Way	\N	JZUZUKJ	NY	80285	US	1	NICQZWOOZE@dell.com	6883186837	3	9037102415692062	2008/04	user3035	password	73	60000	F
3036	AJEMWM	PNMLBBKGLK	1897075915 Dell Way	\N	AKELUWF	MI	36020	US	1	PNMLBBKGLK@dell.com	1897075915	3	6283775106538088	2012/01	user3036	password	78	100000	F
3037	ZJGMYT	YKVZVCKFDV	2139165252 Dell Way	\N	KOQGTBO	TX	60855	US	1	YKVZVCKFDV@dell.com	2139165252	4	6162128554191441	2012/07	user3037	password	87	100000	M
3038	FKXZJH	UJCXTHAPRP	5020747620 Dell Way	\N	GYIIMFW	NH	91999	US	1	UJCXTHAPRP@dell.com	5020747620	3	5435040786862374	2009/06	user3038	password	49	60000	M
3039	IOGPJP	RHJZHZQWFP	8362261112 Dell Way	\N	FNBKJQI	TN	27211	US	1	RHJZHZQWFP@dell.com	8362261112	2	7140740140806884	2009/10	user3039	password	60	60000	F
3040	VETLWA	UVITMFZBKM	6689435956 Dell Way	\N	DVWTERY	WV	91673	US	1	UVITMFZBKM@dell.com	6689435956	2	7521704584360123	2009/10	user3040	password	25	20000	M
3041	WMVWHR	FBDKAFVMIQ	6945584767 Dell Way	\N	ICUABUY	NY	99909	US	1	FBDKAFVMIQ@dell.com	6945584767	5	8171512943692506	2011/12	user3041	password	73	80000	F
3042	PNSGST	KCTQYGZOPB	9488095908 Dell Way	\N	JPDDOUD	GA	72466	US	1	KCTQYGZOPB@dell.com	9488095908	5	6718019021209330	2011/08	user3042	password	22	40000	F
3043	TOVMZY	GPWMOKBQUR	9064600397 Dell Way	\N	TYFOCLG	AL	47218	US	1	GPWMOKBQUR@dell.com	9064600397	4	1120978711638599	2012/01	user3043	password	26	80000	M
3044	YFPWLE	SYTDAKYSEW	8135226222 Dell Way	\N	YTZJZZU	VA	76317	US	1	SYTDAKYSEW@dell.com	8135226222	5	8040240689180792	2012/07	user3044	password	46	100000	M
3045	ZSFDKD	XOEIMWMJUF	8398963388 Dell Way	\N	IDFHYDB	OK	97021	US	1	XOEIMWMJUF@dell.com	8398963388	4	5687663301825524	2009/06	user3045	password	38	20000	F
3046	MIPQGD	UOQRAZLGHP	1723479710 Dell Way	\N	MPNPQGO	MI	89396	US	1	UOQRAZLGHP@dell.com	1723479710	4	4283851534593850	2009/10	user3046	password	58	100000	F
3047	EMKHHY	YYYXJFEYRT	9787908768 Dell Way	\N	MHJSVVP	VT	52723	US	1	YYYXJFEYRT@dell.com	9787908768	2	3751426373142749	2010/02	user3047	password	51	80000	M
3048	WZWUXU	TVEYZDQTPX	7514221745 Dell Way	\N	DITYYQK	WA	92882	US	1	TVEYZDQTPX@dell.com	7514221745	3	1317982114851474	2008/02	user3048	password	63	20000	F
3049	MVBHOW	LMVODPEASN	4286383992 Dell Way	\N	TQLKBJI	SC	84751	US	1	LMVODPEASN@dell.com	4286383992	5	9704711452126504	2012/01	user3049	password	24	60000	M
3050	DTJZFW	VUAKYADMUU	1885240039 Dell Way	\N	XFWHNQD	VA	66198	US	1	VUAKYADMUU@dell.com	1885240039	5	6757544535212219	2008/05	user3050	password	52	40000	F
3051	WIJSDD	SOCTROOLMT	2933657117 Dell Way	\N	HUGYXDO	AK	12986	US	1	SOCTROOLMT@dell.com	2933657117	1	4585339937359095	2011/07	user3051	password	56	60000	M
3052	WGZAZN	CTFRHRDAZX	8863083829 Dell Way	\N	HXVLMVM	OK	12270	US	1	CTFRHRDAZX@dell.com	8863083829	2	5922299065627158	2010/12	user3052	password	45	40000	F
3053	JHEWKY	CBFTEGSCOQ	3794617184 Dell Way	\N	XZDTMVT	KY	30420	US	1	CBFTEGSCOQ@dell.com	3794617184	4	2399858564138412	2011/01	user3053	password	43	20000	F
3054	NXSMZT	STYYLBMBYM	4692798790 Dell Way	\N	FRYALHG	RI	13135	US	1	STYYLBMBYM@dell.com	4692798790	3	1569322051946073	2011/06	user3054	password	46	40000	F
3055	CTKWLD	VKOWXQVKVN	7654441517 Dell Way	\N	JWZQDTR	NC	26968	US	1	VKOWXQVKVN@dell.com	7654441517	2	7140288578346372	2008/07	user3055	password	24	40000	F
3056	MCUQYF	EUCVQNRDWN	7335483590 Dell Way	\N	CNRVEEA	VT	53110	US	1	EUCVQNRDWN@dell.com	7335483590	1	1534584037959575	2011/04	user3056	password	47	40000	F
3057	FXIKCD	NXTAPWWDZK	5655242146 Dell Way	\N	UUOZVML	MT	56951	US	1	NXTAPWWDZK@dell.com	5655242146	2	8179894947446884	2012/08	user3057	password	31	20000	F
3058	MNPPAN	JBCFYFEIAZ	7124170928 Dell Way	\N	WZVJLIW	WV	68889	US	1	JBCFYFEIAZ@dell.com	7124170928	5	3280320830643177	2012/01	user3058	password	72	40000	M
3059	IZOVIP	YONESWESTE	7857618733 Dell Way	\N	NCQWZPN	NV	53403	US	1	YONESWESTE@dell.com	7857618733	3	5341507959179580	2010/11	user3059	password	90	100000	M
3060	OREDQS	RULNYDGDRI	3822219726 Dell Way	\N	TNIJAZV	SC	55092	US	1	RULNYDGDRI@dell.com	3822219726	2	4425867842510343	2009/02	user3060	password	35	100000	M
3061	KZLDQF	OEESKIJTBX	9517781784 Dell Way	\N	CKYBGTO	ND	13585	US	1	OEESKIJTBX@dell.com	9517781784	5	2717229705303907	2008/09	user3061	password	19	60000	M
3062	MSJSHN	XZYFJSGHUR	2637654535 Dell Way	\N	FVYYKMZ	LA	42561	US	1	XZYFJSGHUR@dell.com	2637654535	3	1740260020364076	2009/02	user3062	password	75	80000	M
3063	DJCRHC	PMMHTTBLZX	3613981630 Dell Way	\N	JXIWXRF	CA	28885	US	1	PMMHTTBLZX@dell.com	3613981630	2	4002430983819068	2008/12	user3063	password	30	40000	F
3064	HWQJMC	WTWPVHOTQM	3408587594 Dell Way	\N	BMKSRMY	WV	79486	US	1	WTWPVHOTQM@dell.com	3408587594	1	7741466857958586	2010/04	user3064	password	26	80000	F
3065	TCPWYJ	SNEZCXPOZB	9637231054 Dell Way	\N	ZRTLQSF	VA	80182	US	1	SNEZCXPOZB@dell.com	9637231054	2	1422672282438725	2008/01	user3065	password	31	100000	F
3066	URCEJQ	JISHYHGAGY	3862621719 Dell Way	\N	TSOMXLH	UT	80117	US	1	JISHYHGAGY@dell.com	3862621719	5	8428777867928148	2010/09	user3066	password	88	40000	F
3067	BMURVC	KCBRIBYGUQ	8835001914 Dell Way	\N	VHOGOKB	VA	41079	US	1	KCBRIBYGUQ@dell.com	8835001914	2	1857847254723310	2012/09	user3067	password	55	100000	F
3068	HOZKYC	LQLMORHFNP	6267076394 Dell Way	\N	TUDDVBM	OH	49160	US	1	LQLMORHFNP@dell.com	6267076394	3	2235843058675527	2008/05	user3068	password	40	40000	M
3069	IUXKFN	VRBNZHAOAU	3831520172 Dell Way	\N	SDPTQHE	HI	83818	US	1	VRBNZHAOAU@dell.com	3831520172	2	3049275702331215	2011/09	user3069	password	31	100000	F
3070	CIRPEJ	RRIYSWYNOC	5182515141 Dell Way	\N	DITKMZG	SD	35811	US	1	RRIYSWYNOC@dell.com	5182515141	3	9861169033218176	2011/05	user3070	password	51	80000	M
3071	DIXMAP	UZHRXUGAXO	1040357053 Dell Way	\N	TIBTOWA	AR	35868	US	1	UZHRXUGAXO@dell.com	1040357053	4	6918907897546888	2010/06	user3071	password	45	60000	M
3072	GBUVWT	DNRYUSWIME	2666219433 Dell Way	\N	KFTGFUN	HI	54052	US	1	DNRYUSWIME@dell.com	2666219433	4	9264157380908728	2010/04	user3072	password	68	100000	F
3073	MQEFTS	XSNPOVBSFG	7209031017 Dell Way	\N	MMMHZRU	FL	43146	US	1	XSNPOVBSFG@dell.com	7209031017	4	6671593654435129	2009/07	user3073	password	87	100000	F
3074	DCZWZR	KPFGQYLXKY	1530418948 Dell Way	\N	JRYBLCL	DC	86565	US	1	KPFGQYLXKY@dell.com	1530418948	3	4601282346528024	2008/05	user3074	password	61	20000	F
3075	OBLFLA	KRRIDOTBYL	4116402512 Dell Way	\N	ZZXCLBY	MO	61385	US	1	KRRIDOTBYL@dell.com	4116402512	3	9554743572138252	2012/08	user3075	password	47	60000	M
3076	WSDWDU	OLXCFZBQYA	1719738405 Dell Way	\N	NBLOZYD	KY	49612	US	1	OLXCFZBQYA@dell.com	1719738405	2	1928579600062221	2010/10	user3076	password	77	40000	F
3077	YFPTTB	RWGQXWPYKQ	8998232228 Dell Way	\N	KYQIBYU	DC	31730	US	1	RWGQXWPYKQ@dell.com	8998232228	4	1157248413655906	2011/12	user3077	password	54	80000	F
3078	CJZEAV	KRTHGRRWCP	7333004688 Dell Way	\N	MLRLFVR	CO	53900	US	1	KRTHGRRWCP@dell.com	7333004688	5	5282151117920876	2009/06	user3078	password	67	40000	M
3079	QMWMWN	FDTXVQALCL	9314318888 Dell Way	\N	DORYGUL	WI	61948	US	1	FDTXVQALCL@dell.com	9314318888	1	1232387724798172	2011/06	user3079	password	80	40000	M
3080	STUGZY	AWUQWFTIIH	4192697055 Dell Way	\N	ZHNTSMI	NV	64929	US	1	AWUQWFTIIH@dell.com	4192697055	2	1600724575575441	2009/07	user3080	password	90	100000	F
3081	UEFTEC	NUZSNHBUHI	5190696612 Dell Way	\N	IABUJSK	OK	96397	US	1	NUZSNHBUHI@dell.com	5190696612	5	5271004104521126	2010/11	user3081	password	71	40000	F
3082	YZEBNZ	AFNIGHQPQR	7891823607 Dell Way	\N	QKAIVTH	IL	71084	US	1	AFNIGHQPQR@dell.com	7891823607	4	5818621176294983	2010/12	user3082	password	58	60000	M
3083	TMMSNS	FWZNMOEDEP	2165025440 Dell Way	\N	ENKXURP	NE	47677	US	1	FWZNMOEDEP@dell.com	2165025440	1	4652434712741524	2011/07	user3083	password	46	60000	F
3084	WENOKJ	OXWCCAHREU	6036762310 Dell Way	\N	BCPTRED	SD	31025	US	1	OXWCCAHREU@dell.com	6036762310	3	7678140938282014	2012/12	user3084	password	72	100000	F
3085	GKMQYK	NAMNIDRCFU	8628737953 Dell Way	\N	SYLWCGC	NV	78983	US	1	NAMNIDRCFU@dell.com	8628737953	3	7298372198361904	2010/05	user3085	password	76	100000	M
3086	HNSRAT	EOBIFENAWL	2783235051 Dell Way	\N	MTOTWEM	OH	80363	US	1	EOBIFENAWL@dell.com	2783235051	2	2675877489615232	2012/02	user3086	password	89	40000	M
3087	SYRLDF	NLLSYLOKXI	1840893686 Dell Way	\N	YQEDDWX	KY	24561	US	1	NLLSYLOKXI@dell.com	1840893686	2	3784400231204927	2008/08	user3087	password	88	80000	M
3088	QGRWTD	HLBTAMRIKH	8689703881 Dell Way	\N	NNLJLUO	MT	20414	US	1	HLBTAMRIKH@dell.com	8689703881	3	7490881204139442	2012/05	user3088	password	38	60000	M
3089	ZIJCPV	DJVPAEAHRN	4303056322 Dell Way	\N	TBZNPMQ	MN	18269	US	1	DJVPAEAHRN@dell.com	4303056322	2	5159161239862442	2011/09	user3089	password	22	80000	F
3090	KSRFVA	BLAFMIXABZ	1185793508 Dell Way	\N	ZPPMGBO	NJ	41107	US	1	BLAFMIXABZ@dell.com	1185793508	2	1788655063137412	2008/11	user3090	password	28	60000	M
3091	UTKUUW	VAIDYIFXHU	1049395414 Dell Way	\N	NUBOIQX	KY	91949	US	1	VAIDYIFXHU@dell.com	1049395414	3	8037474531214685	2008/12	user3091	password	43	100000	M
3092	TTLQOM	YSKHXIPSWJ	1832254119 Dell Way	\N	TKSKIBI	KY	54189	US	1	YSKHXIPSWJ@dell.com	1832254119	3	4877135507296771	2010/06	user3092	password	25	40000	F
3093	OVTBUL	MBJURBQBUB	7504728728 Dell Way	\N	TFKUNTH	NH	30848	US	1	MBJURBQBUB@dell.com	7504728728	1	6952507309615613	2012/03	user3093	password	79	40000	F
3094	PLWAXY	JSPKIQFKKK	5030789735 Dell Way	\N	VEYOMNU	GA	62064	US	1	JSPKIQFKKK@dell.com	5030789735	1	8410572604741902	2009/06	user3094	password	83	100000	M
3095	TXTRGL	HRUXXFIIAM	2687695248 Dell Way	\N	GOZUJEJ	SC	29451	US	1	HRUXXFIIAM@dell.com	2687695248	1	6711675358004869	2008/12	user3095	password	53	100000	M
3096	GNCRUU	MSRRAZSNGG	5696403124 Dell Way	\N	MAPRKKX	NE	55357	US	1	MSRRAZSNGG@dell.com	5696403124	4	5106950599700213	2008/06	user3096	password	39	40000	M
3097	KYUEKM	VCMVUZBBMC	1446137328 Dell Way	\N	RDMCABP	NC	75972	US	1	VCMVUZBBMC@dell.com	1446137328	3	3013289933092892	2009/10	user3097	password	33	80000	M
3098	ZXEMTG	YOBXQCKTUN	3264689570 Dell Way	\N	FWOHMCA	MT	68517	US	1	YOBXQCKTUN@dell.com	3264689570	5	5087689484935254	2010/08	user3098	password	32	60000	F
3099	JYGPWU	RULUEEOSKL	5028214190 Dell Way	\N	GRXISKZ	WV	35108	US	1	RULUEEOSKL@dell.com	5028214190	3	8889363484922797	2011/11	user3099	password	45	100000	M
3100	PPRKHM	VBQAPJKBPB	5725476464 Dell Way	\N	YYUJYTQ	MA	25850	US	1	VBQAPJKBPB@dell.com	5725476464	1	1632988092489540	2012/01	user3100	password	82	60000	M
3101	OXXBTY	STOBDQQFOP	9911644615 Dell Way	\N	ZYNTPXX	CO	93705	US	1	STOBDQQFOP@dell.com	9911644615	1	9554602819029244	2012/07	user3101	password	60	60000	F
3102	MNFLFY	AGCQXIFMID	8249451596 Dell Way	\N	ABTYZWW	WV	88477	US	1	AGCQXIFMID@dell.com	8249451596	5	4569184472784400	2009/04	user3102	password	79	100000	M
3103	AHAZIH	BYEKERSHST	2516616681 Dell Way	\N	BQSXMSU	IL	58602	US	1	BYEKERSHST@dell.com	2516616681	4	8590144189074636	2008/07	user3103	password	65	20000	M
3104	RAEYCC	DMHVEONYQD	7594824196 Dell Way	\N	RNQJHYX	MN	63574	US	1	DMHVEONYQD@dell.com	7594824196	3	2215172723866999	2009/06	user3104	password	89	20000	M
3105	DAPGEC	NZGCNESRVG	9601250038 Dell Way	\N	HENFBZV	SD	51294	US	1	NZGCNESRVG@dell.com	9601250038	1	9625430324114860	2012/04	user3105	password	52	20000	F
3106	BILEWK	KZYPSPKYXP	9097028195 Dell Way	\N	MDRMYMY	VT	70569	US	1	KZYPSPKYXP@dell.com	9097028195	5	9367635345086456	2009/12	user3106	password	33	60000	F
3107	QPDBAD	APVPAUNPHQ	4335879943 Dell Way	\N	HTPTSML	NH	40601	US	1	APVPAUNPHQ@dell.com	4335879943	5	3409706146921963	2010/06	user3107	password	57	40000	F
3108	RHAVHQ	RXQLKGTAON	7571518067 Dell Way	\N	QIFDTVM	CT	80993	US	1	RXQLKGTAON@dell.com	7571518067	4	2928172284737229	2009/12	user3108	password	35	100000	F
3109	HUMXLJ	OXUUQVJDLR	2429579292 Dell Way	\N	IOKEANY	PA	31388	US	1	OXUUQVJDLR@dell.com	2429579292	1	2402757843490690	2010/12	user3109	password	44	80000	M
3110	WPFFDC	ZYTVHWGYFV	3745500002 Dell Way	\N	JJVXIPD	MO	65310	US	1	ZYTVHWGYFV@dell.com	3745500002	5	6388939811382443	2011/07	user3110	password	44	60000	F
3111	OTHRTG	LONIUMNPWX	3248202408 Dell Way	\N	LUGAYSQ	HI	65548	US	1	LONIUMNPWX@dell.com	3248202408	5	2655051636975258	2011/05	user3111	password	42	20000	F
3112	QWWWHK	KPFXDVUBHO	8492406667 Dell Way	\N	HIMAZSQ	GA	66109	US	1	KPFXDVUBHO@dell.com	8492406667	5	1287697485648095	2008/01	user3112	password	30	100000	M
3113	BREMCU	SAXNUZUIHC	2889208106 Dell Way	\N	VIBOYHE	SC	20459	US	1	SAXNUZUIHC@dell.com	2889208106	5	2181004381738603	2009/10	user3113	password	19	60000	F
3114	FXOZPO	XDIWYREAMM	6815569022 Dell Way	\N	CBLKGFN	MI	26635	US	1	XDIWYREAMM@dell.com	6815569022	5	9592806297354400	2011/04	user3114	password	47	100000	F
3115	YVUMTX	VPVMUWZGZB	1255532598 Dell Way	\N	RJHXWSB	MT	59133	US	1	VPVMUWZGZB@dell.com	1255532598	1	8258104939479382	2010/01	user3115	password	89	40000	M
3116	TWPQSF	LFZIFFHGXQ	6432867614 Dell Way	\N	NUNGWAU	VA	29375	US	1	LFZIFFHGXQ@dell.com	6432867614	2	3295199815183878	2010/09	user3116	password	27	40000	M
3117	TZHYKN	YTSEAZBQMW	6823547303 Dell Way	\N	DTSEOPK	DC	92500	US	1	YTSEAZBQMW@dell.com	6823547303	4	6605012635234744	2011/01	user3117	password	33	60000	F
3118	NMLAKE	TPESQUFMYY	4069844363 Dell Way	\N	FDMUNQS	DE	41960	US	1	TPESQUFMYY@dell.com	4069844363	5	4643983646295965	2010/06	user3118	password	48	20000	M
3119	WCIAVX	ENOZSBYRGB	5820527392 Dell Way	\N	DBPUUTD	CO	72365	US	1	ENOZSBYRGB@dell.com	5820527392	4	2303364678286016	2012/09	user3119	password	22	100000	M
3120	KVRHAE	VAXXYODASE	2739443957 Dell Way	\N	PMZJQBB	DE	76755	US	1	VAXXYODASE@dell.com	2739443957	1	5290937343146652	2009/12	user3120	password	40	80000	M
3121	YYTDUT	BRSQUTIZIV	3179766051 Dell Way	\N	YSLATPT	WA	74756	US	1	BRSQUTIZIV@dell.com	3179766051	1	6753986274823547	2010/10	user3121	password	46	60000	M
3122	DQNXSF	QIZJRZSMYK	9109373934 Dell Way	\N	YYDOSCG	WI	34275	US	1	QIZJRZSMYK@dell.com	9109373934	3	1918359981384128	2009/01	user3122	password	81	60000	M
3123	KJJPZR	PJIOBVMMTL	1545601555 Dell Way	\N	PHEROCY	MN	65527	US	1	PJIOBVMMTL@dell.com	1545601555	4	6635353431571276	2012/03	user3123	password	38	40000	M
3124	QYNINW	RCYMPKGAAO	5812823648 Dell Way	\N	ESCHROX	OR	38171	US	1	RCYMPKGAAO@dell.com	5812823648	4	5479322947096080	2012/12	user3124	password	20	60000	M
3125	OULLLN	KYCUEDVSHN	2751371715 Dell Way	\N	VPFJNYS	AL	62240	US	1	KYCUEDVSHN@dell.com	2751371715	5	6111619503237308	2009/04	user3125	password	53	80000	F
3126	YFOLPM	OKRRFKZTFO	1197755121 Dell Way	\N	YPCWHCL	MO	97570	US	1	OKRRFKZTFO@dell.com	1197755121	4	3655437798704952	2010/07	user3126	password	47	60000	M
3127	ZWJMLT	DCZNCTTRRJ	2097297030 Dell Way	\N	TOQWADV	AR	86734	US	1	DCZNCTTRRJ@dell.com	2097297030	3	4240098557434976	2010/12	user3127	password	24	60000	M
3128	LZHFCK	EQMYKDQTWE	7592500753 Dell Way	\N	KTFNOGJ	NY	80972	US	1	EQMYKDQTWE@dell.com	7592500753	2	7901130500249565	2012/09	user3128	password	63	40000	M
3129	XMUHRK	UPVYFOVKYO	4628235483 Dell Way	\N	PMCWVUQ	ND	11210	US	1	UPVYFOVKYO@dell.com	4628235483	2	7507951109204442	2008/09	user3129	password	46	100000	F
3130	EGVPAK	KZQZUAXIQJ	9910226434 Dell Way	\N	LMFGDUG	NC	25509	US	1	KZQZUAXIQJ@dell.com	9910226434	3	8574687368702144	2009/06	user3130	password	90	60000	M
3131	UEUFOT	WNNXLWNVIA	8345334643 Dell Way	\N	APDUWRZ	TN	31719	US	1	WNNXLWNVIA@dell.com	8345334643	2	7649474942591042	2012/10	user3131	password	53	80000	M
3132	GVNARB	OOMKCHTDII	9374179993 Dell Way	\N	GDEYCAE	WA	30982	US	1	OOMKCHTDII@dell.com	9374179993	4	1151202148757874	2010/05	user3132	password	87	80000	F
3133	MRVNGK	ZRMHKPQTWT	2487380217 Dell Way	\N	XVWXAUD	WI	56780	US	1	ZRMHKPQTWT@dell.com	2487380217	2	8693302915897221	2008/01	user3133	password	18	60000	M
3134	VCYGCP	SKAIATFUQA	8330248529 Dell Way	\N	QOALSZY	UT	38772	US	1	SKAIATFUQA@dell.com	8330248529	1	4149381646886468	2012/08	user3134	password	22	80000	M
3135	AXUQQE	QZEKEYBEPQ	8459772289 Dell Way	\N	FBIEAFM	SD	29795	US	1	QZEKEYBEPQ@dell.com	8459772289	4	8305372909642757	2012/04	user3135	password	54	100000	F
3136	HOWLFV	QPZPREEHJG	8704019782 Dell Way	\N	PNGVZBB	SD	74884	US	1	QPZPREEHJG@dell.com	8704019782	4	1406825192272663	2009/08	user3136	password	38	80000	F
3137	EBKZRA	ZHRDMYMSOA	8087265789 Dell Way	\N	YJAAKVT	ID	59175	US	1	ZHRDMYMSOA@dell.com	8087265789	4	2677021879237145	2008/04	user3137	password	45	40000	F
3138	UFAUFH	LITKVLYWKH	4701580572 Dell Way	\N	WLSREZF	WI	64577	US	1	LITKVLYWKH@dell.com	4701580572	1	8737295581959189	2011/03	user3138	password	31	60000	F
3139	FJRMVZ	GFVRDRCLNN	6423424859 Dell Way	\N	DFRDLQT	TX	69953	US	1	GFVRDRCLNN@dell.com	6423424859	4	9237659804522992	2011/03	user3139	password	45	100000	M
3140	AMKASP	WJTOMEBZIH	9063130022 Dell Way	\N	RMSIFOZ	SD	27150	US	1	WJTOMEBZIH@dell.com	9063130022	4	4634983443655074	2009/08	user3140	password	89	40000	F
3141	JITZFD	TTPXVPGCGS	9570639059 Dell Way	\N	UOYJOTO	MI	42974	US	1	TTPXVPGCGS@dell.com	9570639059	4	9559845632407816	2012/01	user3141	password	90	40000	F
3142	THPWAI	LYDAFGHYBW	9568023427 Dell Way	\N	WKKQYWA	VT	62303	US	1	LYDAFGHYBW@dell.com	9568023427	5	6514295812696219	2012/02	user3142	password	90	80000	F
3143	OOMXAL	BBQHIPIFLS	7057431508 Dell Way	\N	QCRMCPB	AR	47672	US	1	BBQHIPIFLS@dell.com	7057431508	5	6176266025286168	2011/09	user3143	password	20	40000	F
3144	NDGZEH	QLQFUVRNLT	7826034376 Dell Way	\N	EYWTZXE	NY	90541	US	1	QLQFUVRNLT@dell.com	7826034376	2	6205118115991355	2011/07	user3144	password	77	40000	M
3145	BIWJYI	ZECVWPHQUF	8721438588 Dell Way	\N	MOFKSWH	MO	29140	US	1	ZECVWPHQUF@dell.com	8721438588	2	7950074402615429	2011/08	user3145	password	51	80000	M
3146	ICXQBB	SXXHEOCKAQ	5248929813 Dell Way	\N	PKJMRVS	NC	20601	US	1	SXXHEOCKAQ@dell.com	5248929813	2	7565577745437623	2012/12	user3146	password	66	40000	F
3147	OWCPPA	NXEBZOCPEN	6687932644 Dell Way	\N	YRFUJTX	TN	97235	US	1	NXEBZOCPEN@dell.com	6687932644	4	9305403586477042	2009/01	user3147	password	88	100000	M
3148	BLLBZI	GAIVDXZQWQ	5309977163 Dell Way	\N	VQAPOVO	DE	64050	US	1	GAIVDXZQWQ@dell.com	5309977163	3	6479933961760253	2010/04	user3148	password	53	60000	M
3149	YPSHVT	PQWNQNJHJA	3960939620 Dell Way	\N	HYODMSS	WV	26170	US	1	PQWNQNJHJA@dell.com	3960939620	3	5288570008706302	2012/12	user3149	password	33	80000	F
3150	XBIQQZ	NEPANWJNDI	4936348272 Dell Way	\N	BGUUZUY	KS	26781	US	1	NEPANWJNDI@dell.com	4936348272	1	1940046584233641	2011/11	user3150	password	61	60000	M
3151	YFPXTT	MUHIDUMMWT	4075157513 Dell Way	\N	HQTBPBG	AR	27440	US	1	MUHIDUMMWT@dell.com	4075157513	4	1778848684858530	2012/04	user3151	password	20	100000	F
3152	QTFJGZ	QODLBPHVWY	9223240072 Dell Way	\N	OYOQEPV	MT	35355	US	1	QODLBPHVWY@dell.com	9223240072	3	5841755887027830	2012/04	user3152	password	18	60000	F
3153	FYHFPW	JAYYIUVHIU	3207571853 Dell Way	\N	VZYLULS	OK	91096	US	1	JAYYIUVHIU@dell.com	3207571853	4	2985087196808308	2009/03	user3153	password	39	60000	F
3154	PSTMBU	LADFWKOQGN	2130188544 Dell Way	\N	ORIAJBX	NJ	73435	US	1	LADFWKOQGN@dell.com	2130188544	5	9381150401197376	2010/05	user3154	password	25	20000	F
3155	WMCQXD	TDZERPKEDB	2670628000 Dell Way	\N	NDLOBBG	DE	95301	US	1	TDZERPKEDB@dell.com	2670628000	3	3787437899969518	2009/08	user3155	password	44	20000	F
3156	MUAPND	OSUDCZHEML	9650219178 Dell Way	\N	QBMSHRQ	MO	32526	US	1	OSUDCZHEML@dell.com	9650219178	4	8748993290588261	2009/11	user3156	password	88	100000	M
3157	ZKFDZX	YDAYKEKWVM	1880451038 Dell Way	\N	INTZEGG	DC	10791	US	1	YDAYKEKWVM@dell.com	1880451038	3	9174547216854990	2008/04	user3157	password	60	20000	M
3158	UFRRDU	RBFWMBSYJG	8915517260 Dell Way	\N	SJKZPOZ	OH	11867	US	1	RBFWMBSYJG@dell.com	8915517260	4	3718015252146870	2010/10	user3158	password	90	40000	F
3159	RXELPF	QMSSFRCLKL	7403414921 Dell Way	\N	VJBKITK	GA	57600	US	1	QMSSFRCLKL@dell.com	7403414921	4	4188299498055130	2011/11	user3159	password	45	40000	M
3160	NVLTMY	MEDEGOOSKY	4694523949 Dell Way	\N	TUGNFMB	VT	22882	US	1	MEDEGOOSKY@dell.com	4694523949	4	1486718714702874	2011/12	user3160	password	82	40000	M
3161	ICGHPK	KTRZIJJGDE	2550177461 Dell Way	\N	NRJZTHD	DC	91181	US	1	KTRZIJJGDE@dell.com	2550177461	5	8935637591872365	2008/03	user3161	password	67	40000	F
3162	YRXJBR	ABZKLFOPSF	1346511330 Dell Way	\N	ZSYGVCE	WY	12401	US	1	ABZKLFOPSF@dell.com	1346511330	1	3487513878848404	2011/06	user3162	password	62	80000	F
3163	NZEEAG	EKRJYGCEFU	5910725752 Dell Way	\N	DMPGQPH	NY	66827	US	1	EKRJYGCEFU@dell.com	5910725752	2	1621745739132166	2008/01	user3163	password	30	80000	F
3164	JWAPBL	GLKNNOTISF	2880163488 Dell Way	\N	XYWNFOD	RI	93963	US	1	GLKNNOTISF@dell.com	2880163488	5	9638401792850346	2009/08	user3164	password	88	80000	M
3165	ZIOKOZ	UCMJVVCBTB	4068953966 Dell Way	\N	XGHLJBJ	NH	97848	US	1	UCMJVVCBTB@dell.com	4068953966	5	6387097246944905	2009/09	user3165	password	25	40000	F
3166	QSPQNS	DWNYZORAMX	9051096849 Dell Way	\N	HXHIHXH	NM	87509	US	1	DWNYZORAMX@dell.com	9051096849	5	6167603692971171	2012/03	user3166	password	62	80000	M
3167	FGMXJI	LIHZZIMXPJ	5613762115 Dell Way	\N	EXRCFHY	CO	32519	US	1	LIHZZIMXPJ@dell.com	5613762115	1	5455609403084964	2008/09	user3167	password	50	40000	F
3168	XHKGSS	OSRWEPMOUJ	3389573766 Dell Way	\N	FWONURU	IN	79199	US	1	OSRWEPMOUJ@dell.com	3389573766	3	5570492803119123	2011/10	user3168	password	55	80000	F
3169	XXUPLM	HIRXUFREKN	7141789726 Dell Way	\N	TYIKSQE	WV	15478	US	1	HIRXUFREKN@dell.com	7141789726	4	8614756620954723	2008/04	user3169	password	84	20000	F
3170	RSREAZ	VXTAOYLCRJ	9466672342 Dell Way	\N	KBCAGBC	VT	78067	US	1	VXTAOYLCRJ@dell.com	9466672342	1	1708187694661319	2012/03	user3170	password	39	60000	M
3171	YRXYNV	SNJQYLHIWI	3925424448 Dell Way	\N	LXOMZMG	WA	64331	US	1	SNJQYLHIWI@dell.com	3925424448	4	8318610759451986	2011/04	user3171	password	71	60000	M
3172	QMMLEA	VUZHCHEKTB	9101887138 Dell Way	\N	ZFBMMZC	SC	80108	US	1	VUZHCHEKTB@dell.com	9101887138	3	1771012862678617	2011/12	user3172	password	23	40000	F
3173	OTQPOL	OWNWAYPCYV	1094442616 Dell Way	\N	DLHDNBY	ME	52951	US	1	OWNWAYPCYV@dell.com	1094442616	1	4999613196589053	2008/04	user3173	password	83	80000	F
3174	OGQZUM	NQNMFPLATW	3745669694 Dell Way	\N	IXJJVUW	TN	85116	US	1	NQNMFPLATW@dell.com	3745669694	5	2379031362012028	2009/07	user3174	password	33	80000	M
3175	VTPIHG	VTLKEMEBUB	2742235675 Dell Way	\N	KEXFBSB	LA	67104	US	1	VTLKEMEBUB@dell.com	2742235675	3	2873673338908702	2009/04	user3175	password	19	40000	F
3176	PNIVJC	HUHUYIPATU	5108276989 Dell Way	\N	XYVPZFG	DE	78888	US	1	HUHUYIPATU@dell.com	5108276989	3	1714664663653820	2010/10	user3176	password	28	20000	F
3177	MYROFM	VAKEQLXKIV	3831358775 Dell Way	\N	GYUMEZG	NM	59521	US	1	VAKEQLXKIV@dell.com	3831358775	1	4124519379809499	2010/03	user3177	password	67	100000	F
3178	JMJVIJ	GMARJKZFRY	9035186614 Dell Way	\N	AECZKTO	OK	87218	US	1	GMARJKZFRY@dell.com	9035186614	1	1487919942010194	2010/02	user3178	password	30	100000	M
3179	NUXXAK	XRUIRAAPAE	4291593722 Dell Way	\N	SAOLOHI	MN	49381	US	1	XRUIRAAPAE@dell.com	4291593722	1	5758832356892527	2010/12	user3179	password	26	20000	M
3180	AZTLWL	GEDGFTGJLG	2634712274 Dell Way	\N	YXVFFHQ	NE	37014	US	1	GEDGFTGJLG@dell.com	2634712274	1	3392806302290410	2009/03	user3180	password	18	40000	F
3181	TTAFAF	JGKCMUNTSK	4771029870 Dell Way	\N	PYQWPED	RI	37019	US	1	JGKCMUNTSK@dell.com	4771029870	1	5333108650986105	2010/05	user3181	password	64	20000	F
3182	QKEWTK	HVXBJQUUFT	4252594696 Dell Way	\N	KCIPFDW	NV	27727	US	1	HVXBJQUUFT@dell.com	4252594696	1	6390030506532640	2012/04	user3182	password	74	80000	M
3183	YNLJUH	GVQXQLCJVE	6787004485 Dell Way	\N	SKKWHBB	NM	23097	US	1	GVQXQLCJVE@dell.com	6787004485	4	4736741810105741	2010/04	user3183	password	25	40000	M
3184	OSOVYK	MVBXYLSDED	2647381667 Dell Way	\N	OAKQBAT	OH	70156	US	1	MVBXYLSDED@dell.com	2647381667	1	9481275604106488	2009/06	user3184	password	70	100000	F
3185	HRCRDX	SBWEUZIXOI	9495796174 Dell Way	\N	HEJIYBA	CT	23896	US	1	SBWEUZIXOI@dell.com	9495796174	3	6474469400942326	2011/03	user3185	password	73	100000	M
3186	WQAUJB	QNWQVTEDBJ	3857398473 Dell Way	\N	NJHOJKS	KS	82382	US	1	QNWQVTEDBJ@dell.com	3857398473	5	1280879674945026	2008/12	user3186	password	84	100000	M
3187	YSXAIK	WZGQEJRNWA	1237969188 Dell Way	\N	ULKEDTZ	MN	74866	US	1	WZGQEJRNWA@dell.com	1237969188	3	6845570620149375	2012/06	user3187	password	32	100000	F
3188	CXNNUN	TKRDBEACYL	6434609738 Dell Way	\N	MDPGDBY	DE	64645	US	1	TKRDBEACYL@dell.com	6434609738	1	1725833646021783	2012/12	user3188	password	37	100000	M
3189	ULRHFB	YJDDJFCVSF	2692456093 Dell Way	\N	LYJNXNC	MS	68103	US	1	YJDDJFCVSF@dell.com	2692456093	2	6780952248722315	2010/03	user3189	password	57	40000	M
3190	FNWHMF	KQPPSKIYVG	2053095449 Dell Way	\N	HIDVLQM	NM	94338	US	1	KQPPSKIYVG@dell.com	2053095449	1	2388541817199439	2011/04	user3190	password	77	100000	M
3191	REJWPZ	MERWNPSTXB	6581350736 Dell Way	\N	XSNNFEM	KS	32086	US	1	MERWNPSTXB@dell.com	6581350736	5	6178519747219980	2010/11	user3191	password	50	20000	F
3192	UZPULU	LIHBBBZCYS	6420550411 Dell Way	\N	QMXUYFA	ND	27961	US	1	LIHBBBZCYS@dell.com	6420550411	5	1573643099050969	2008/02	user3192	password	25	100000	F
3193	SQONCW	VDXWCAVURH	2635644924 Dell Way	\N	SLGXMUD	AZ	81912	US	1	VDXWCAVURH@dell.com	2635644924	1	9107541067525744	2009/12	user3193	password	90	100000	M
3194	ONRKIU	IEXJASAHKM	1460022256 Dell Way	\N	OIYJLAD	NM	21024	US	1	IEXJASAHKM@dell.com	1460022256	5	1714552124030888	2008/11	user3194	password	66	60000	F
3195	IZTDIY	BSYTTGEFUN	4172218326 Dell Way	\N	DDZDHQH	KY	59666	US	1	BSYTTGEFUN@dell.com	4172218326	2	5183898189105094	2008/12	user3195	password	82	40000	M
3196	QLHONA	MHTTMYNZCR	6689138310 Dell Way	\N	ZGZQNIE	TX	73446	US	1	MHTTMYNZCR@dell.com	6689138310	5	7104276519268752	2010/03	user3196	password	65	20000	M
3197	YREYEL	SXXQLXSCXY	7889978918 Dell Way	\N	BNLJRIC	IN	26574	US	1	SXXQLXSCXY@dell.com	7889978918	5	4476615304127336	2010/12	user3197	password	21	40000	M
3198	FIURAS	OQDMJFJIHW	6922861779 Dell Way	\N	URNCTVH	NC	66660	US	1	OQDMJFJIHW@dell.com	6922861779	5	6195508989039809	2011/04	user3198	password	33	100000	M
3199	APQSDH	VPRBYZJUTA	4107350061 Dell Way	\N	IVUDCIT	RI	33711	US	1	VPRBYZJUTA@dell.com	4107350061	3	6142556009814144	2010/05	user3199	password	32	60000	M
3200	VGDDCT	UDSUMNNNVJ	5177844292 Dell Way	\N	IZMQTGX	AZ	76637	US	1	UDSUMNNNVJ@dell.com	5177844292	4	2274290312081575	2011/03	user3200	password	27	60000	F
3201	GQNZLR	RGEEURADZZ	8077787483 Dell Way	\N	QQSXNUQ	WV	47049	US	1	RGEEURADZZ@dell.com	8077787483	4	6361834500916303	2012/02	user3201	password	20	20000	M
3202	OEGGVM	KAGCBKCABS	5624557545 Dell Way	\N	SYFNPEX	MA	85068	US	1	KAGCBKCABS@dell.com	5624557545	2	9880966049153360	2010/06	user3202	password	75	20000	M
3203	BJLNTM	UWNFYOGQGF	8652845296 Dell Way	\N	VUVARFW	GA	57539	US	1	UWNFYOGQGF@dell.com	8652845296	4	9948587019462140	2011/11	user3203	password	62	80000	F
3204	BFZOAW	CGUQNKXSGR	3811486175 Dell Way	\N	OGJUDOI	WV	39503	US	1	CGUQNKXSGR@dell.com	3811486175	4	2841188958846032	2012/04	user3204	password	50	20000	M
3205	LOOHQU	BHHLEARWOY	3960153686 Dell Way	\N	FJCURBD	WY	71615	US	1	BHHLEARWOY@dell.com	3960153686	5	9891893540509046	2011/11	user3205	password	55	40000	F
3206	BMDVOK	CAPCSMRQRA	5297084559 Dell Way	\N	TMSUPSM	WI	65181	US	1	CAPCSMRQRA@dell.com	5297084559	4	5767153964843602	2012/12	user3206	password	18	20000	F
3207	DWYOZZ	EBRQTIIUBV	3991909541 Dell Way	\N	MWKEJJU	TN	16667	US	1	EBRQTIIUBV@dell.com	3991909541	5	9929211395327004	2009/11	user3207	password	47	60000	M
3208	JBSIFU	ZVNHEHJZUF	8383438121 Dell Way	\N	KZOTUKV	CT	28311	US	1	ZVNHEHJZUF@dell.com	8383438121	3	1536260380875319	2009/12	user3208	password	75	60000	M
3209	MXFGXA	UFECOEWUOW	9931446421 Dell Way	\N	IHRSDUY	WI	31768	US	1	UFECOEWUOW@dell.com	9931446421	1	2698213208001107	2011/10	user3209	password	30	40000	M
3210	JNOKHU	PJITGDHCLP	9743257255 Dell Way	\N	TETODSU	CO	88546	US	1	PJITGDHCLP@dell.com	9743257255	5	6704143966548145	2008/02	user3210	password	40	60000	M
3211	WYYRNH	AHODPQOFKT	2343989202 Dell Way	\N	YYWQTZN	OK	89010	US	1	AHODPQOFKT@dell.com	2343989202	5	1209055519662797	2010/05	user3211	password	67	40000	F
3212	QAVXAD	MDSDSXNLWM	3006661528 Dell Way	\N	INGIAYF	DE	82477	US	1	MDSDSXNLWM@dell.com	3006661528	4	2700310230255127	2012/12	user3212	password	54	60000	M
3213	ILZMXC	EAUCOGYBOL	2993058981 Dell Way	\N	HXMFCQA	IN	33831	US	1	EAUCOGYBOL@dell.com	2993058981	2	3057967706583440	2011/09	user3213	password	32	20000	F
3214	ENBGSC	AUQGTSVFZS	8199443783 Dell Way	\N	RFUHGCO	MN	37222	US	1	AUQGTSVFZS@dell.com	8199443783	1	1259765887167304	2012/03	user3214	password	32	20000	M
3215	GKMJKG	ZRARMFREWW	4559676465 Dell Way	\N	ZECBTOJ	NC	78106	US	1	ZRARMFREWW@dell.com	4559676465	3	1027281720191240	2010/09	user3215	password	74	100000	F
3216	GFMNEE	NWQSOVPLUT	8865402930 Dell Way	\N	OWNCGBW	NM	62864	US	1	NWQSOVPLUT@dell.com	8865402930	2	3483995348680764	2011/01	user3216	password	44	100000	F
3217	WKLAYI	RQXNGIIZWE	4762879865 Dell Way	\N	NZKOVBD	OK	34402	US	1	RQXNGIIZWE@dell.com	4762879865	2	4051164148375392	2011/04	user3217	password	62	80000	M
3218	BRPKIG	HVMPEMLIAL	4780311537 Dell Way	\N	TOGVSZC	CO	40753	US	1	HVMPEMLIAL@dell.com	4780311537	5	6430470222141594	2008/07	user3218	password	38	20000	F
3219	WMNDTJ	QJNDVWDGPR	4856932828 Dell Way	\N	NKJMNMV	WA	45046	US	1	QJNDVWDGPR@dell.com	4856932828	5	9244576735422016	2011/01	user3219	password	25	60000	M
3220	QSHZJQ	MMLIQRYIFJ	5443010468 Dell Way	\N	RRWENUP	WA	77773	US	1	MMLIQRYIFJ@dell.com	5443010468	4	8038058410398663	2010/03	user3220	password	39	40000	M
3221	OEIFRV	QALIZTNJLF	6342388338 Dell Way	\N	GQSBFQV	OH	36235	US	1	QALIZTNJLF@dell.com	6342388338	2	5669146588072181	2012/06	user3221	password	52	60000	M
3222	UQJPHK	AQKUDTFJAV	5884863398 Dell Way	\N	CBATXSA	MO	99911	US	1	AQKUDTFJAV@dell.com	5884863398	2	5490430427249521	2008/10	user3222	password	31	100000	F
3223	OKSZLI	JFMDKWDGYF	5208790111 Dell Way	\N	GRCZRPZ	HI	95083	US	1	JFMDKWDGYF@dell.com	5208790111	2	7758929945528508	2011/01	user3223	password	32	40000	F
3224	XFXGOC	TSNPVTNBAF	4975045846 Dell Way	\N	EZXTYDR	MD	43664	US	1	TSNPVTNBAF@dell.com	4975045846	1	4854010821320117	2011/04	user3224	password	82	60000	F
3225	UVBWOT	KEPDSQDXUD	7524239364 Dell Way	\N	UOBXGMH	NY	59093	US	1	KEPDSQDXUD@dell.com	7524239364	2	8552517209667713	2011/11	user3225	password	42	40000	M
3226	JHGDRK	SVCJYAECVS	1069031007 Dell Way	\N	DTZQAQE	PA	97210	US	1	SVCJYAECVS@dell.com	1069031007	2	8578933364246041	2009/10	user3226	password	56	80000	F
3227	UWSEON	HYMICODVSW	3284213939 Dell Way	\N	UIXLMRK	MS	14530	US	1	HYMICODVSW@dell.com	3284213939	5	8337786395568401	2011/07	user3227	password	80	60000	F
3228	OTZCBY	OJADNWVKRE	8674459270 Dell Way	\N	ICQZNEA	PA	10055	US	1	OJADNWVKRE@dell.com	8674459270	3	6084691021591426	2011/02	user3228	password	89	40000	M
3229	ZJXXXG	YAUUWELAMO	4474038895 Dell Way	\N	RMBVNVV	LA	42895	US	1	YAUUWELAMO@dell.com	4474038895	1	5204174624755979	2009/05	user3229	password	40	40000	M
3230	FGPMEQ	GZMLKMXZEK	7116898940 Dell Way	\N	AZXWUGF	FL	40205	US	1	GZMLKMXZEK@dell.com	7116898940	3	7067855825647712	2012/11	user3230	password	44	40000	F
3231	ZRIPYH	CJSOHRTSSS	8929837440 Dell Way	\N	PONWTSF	MI	32520	US	1	CJSOHRTSSS@dell.com	8929837440	3	2324738191906363	2009/08	user3231	password	38	40000	F
3232	PUHXWR	PLYHERZXGN	5501511340 Dell Way	\N	KDHCISJ	HI	24770	US	1	PLYHERZXGN@dell.com	5501511340	3	8238576865289361	2011/09	user3232	password	27	40000	F
3233	KHJBWV	ADARDXYQHC	6676205482 Dell Way	\N	YKLRTQV	ID	20923	US	1	ADARDXYQHC@dell.com	6676205482	1	8199273735750467	2011/06	user3233	password	38	20000	M
3234	QFPLFT	LXWJVNRYLB	9315472200 Dell Way	\N	JCVAYCD	ND	21639	US	1	LXWJVNRYLB@dell.com	9315472200	2	6092174531426281	2009/06	user3234	password	38	100000	M
3235	WHXPTV	MCRZTPKVYN	4787508009 Dell Way	\N	QYLSBAW	WY	38906	US	1	MCRZTPKVYN@dell.com	4787508009	1	8188988629262895	2011/01	user3235	password	53	60000	F
3236	KECFQF	XQYMAULOKJ	1974813595 Dell Way	\N	ZDLZALI	ME	68383	US	1	XQYMAULOKJ@dell.com	1974813595	1	7229293346870691	2010/09	user3236	password	20	20000	M
3237	DGNIDD	HPEBBSMLRQ	7042133826 Dell Way	\N	WRQIZBZ	CA	24745	US	1	HPEBBSMLRQ@dell.com	7042133826	4	8722970523871482	2011/09	user3237	password	71	100000	M
3238	GDBJLR	OMSGYDYPAQ	3354633786 Dell Way	\N	FJPGISK	AK	45687	US	1	OMSGYDYPAQ@dell.com	3354633786	4	1851694518700242	2012/07	user3238	password	19	40000	M
3239	CQDTEP	MKOPJDQZJZ	7886574223 Dell Way	\N	OPIHZIR	ID	14465	US	1	MKOPJDQZJZ@dell.com	7886574223	2	6334675734862686	2011/06	user3239	password	39	100000	F
3240	KQHACR	PSATIZCIOS	6707188445 Dell Way	\N	RVSZNYB	IL	27742	US	1	PSATIZCIOS@dell.com	6707188445	1	7166885895188899	2012/12	user3240	password	75	40000	M
3241	BJQTZI	UTRUVZJOQF	1618858684 Dell Way	\N	GQSERZJ	IN	15640	US	1	UTRUVZJOQF@dell.com	1618858684	2	1011186701711267	2012/07	user3241	password	58	100000	M
3242	FRYNMR	FGNEPBVUHL	6092082439 Dell Way	\N	NMDNWLO	WA	70988	US	1	FGNEPBVUHL@dell.com	6092082439	4	3273010868113488	2008/09	user3242	password	32	40000	F
3243	DWWUBC	HFSJBNQNAD	1188836743 Dell Way	\N	QNZCCXT	NM	72740	US	1	HFSJBNQNAD@dell.com	1188836743	4	4764576626941562	2009/02	user3243	password	77	40000	M
3244	RDZULF	NUGALUAOLO	5943337776 Dell Way	\N	NNQLHHD	IN	13607	US	1	NUGALUAOLO@dell.com	5943337776	3	2178645144216716	2009/11	user3244	password	23	20000	F
3245	BWLHJG	OJRIKGTYTH	9971747278 Dell Way	\N	OFOVIWW	UT	45234	US	1	OJRIKGTYTH@dell.com	9971747278	2	3429647025652230	2008/04	user3245	password	39	20000	F
3246	TKNZYW	RHGXAFRHTW	4400960966 Dell Way	\N	WOFSLCC	MI	39985	US	1	RHGXAFRHTW@dell.com	4400960966	3	6701423129532487	2011/08	user3246	password	75	60000	F
3247	HKZECH	KAHPSPJPLY	8607358971 Dell Way	\N	UEJWHVF	NV	38882	US	1	KAHPSPJPLY@dell.com	8607358971	2	9632276419550180	2011/09	user3247	password	18	100000	F
3248	ABGHMH	OCZELOQKJU	8761626381 Dell Way	\N	TFCPLTX	IL	15062	US	1	OCZELOQKJU@dell.com	8761626381	5	8153463453985751	2012/10	user3248	password	87	100000	M
3249	FDKMSM	LXYANIJICP	9843223001 Dell Way	\N	KSADPIE	MN	30725	US	1	LXYANIJICP@dell.com	9843223001	2	1543752490542829	2012/03	user3249	password	88	20000	F
3250	JPBVBY	UBMDLUGAEY	6877268693 Dell Way	\N	BIOJNAP	MO	40342	US	1	UBMDLUGAEY@dell.com	6877268693	3	5789787802379579	2011/07	user3250	password	81	100000	F
3251	XVFWPH	ITSDATHYUQ	4449635680 Dell Way	\N	NDDNTQW	MA	13356	US	1	ITSDATHYUQ@dell.com	4449635680	1	6311793734319509	2009/12	user3251	password	72	20000	M
3252	ZBKGJE	ZMESUDMLQQ	8228666572 Dell Way	\N	ODJEZUF	MA	79838	US	1	ZMESUDMLQQ@dell.com	8228666572	4	7770006282720716	2010/10	user3252	password	57	60000	M
3253	YUFCUS	HMNKZYAQME	3814258405 Dell Way	\N	AREUXNO	OH	24432	US	1	HMNKZYAQME@dell.com	3814258405	2	9645206779241564	2012/10	user3253	password	76	100000	M
3254	AXISFV	GPVEPLRUMI	6334048709 Dell Way	\N	YGFMVXQ	CT	23999	US	1	GPVEPLRUMI@dell.com	6334048709	5	9346121677663178	2009/10	user3254	password	53	60000	M
3255	VDXRJM	MNCYFXKOVR	7883513696 Dell Way	\N	UHMRYPV	MT	62026	US	1	MNCYFXKOVR@dell.com	7883513696	5	4326981606427580	2009/04	user3255	password	23	20000	F
3256	ZTVMFJ	OEOMOCHFWP	3028183531 Dell Way	\N	RONHKAW	DE	95626	US	1	OEOMOCHFWP@dell.com	3028183531	3	3466639369260520	2009/06	user3256	password	71	40000	F
3257	OTMXIQ	LUEOCKLRCZ	5012045549 Dell Way	\N	EJKFFOE	MI	96127	US	1	LUEOCKLRCZ@dell.com	5012045549	4	5112668503541500	2008/01	user3257	password	69	80000	M
3258	EQDUBX	ZQZKBRMBWV	4674398144 Dell Way	\N	LBBZGNY	NY	32479	US	1	ZQZKBRMBWV@dell.com	4674398144	5	3531455243472010	2008/07	user3258	password	22	40000	F
3259	ECHCBX	CLZTYBPUNR	8740554725 Dell Way	\N	VMXILPP	TX	51068	US	1	CLZTYBPUNR@dell.com	8740554725	5	1299829422961920	2012/03	user3259	password	34	20000	F
3260	MFKKHW	KBULQOYIJL	3904962332 Dell Way	\N	GSWVHTH	DC	73151	US	1	KBULQOYIJL@dell.com	3904962332	1	9539455429185184	2010/03	user3260	password	38	20000	F
3261	RLRNVT	IHKWFSGRYY	9308502581 Dell Way	\N	NUGHCKZ	MD	52942	US	1	IHKWFSGRYY@dell.com	9308502581	5	6986317970789970	2009/12	user3261	password	22	100000	F
3262	TKHMSO	XOUPVLOUZJ	6174837459 Dell Way	\N	AGLLGVX	DC	79708	US	1	XOUPVLOUZJ@dell.com	6174837459	2	7954856672324241	2011/03	user3262	password	34	40000	M
3263	NWICTX	XJTIXNIGOP	1564732704 Dell Way	\N	RZVNXZH	MO	39322	US	1	XJTIXNIGOP@dell.com	1564732704	1	5994944169651718	2009/06	user3263	password	31	100000	F
3264	NXDLUM	EDKSLRGAJG	7236066306 Dell Way	\N	VWDVEPD	HI	73355	US	1	EDKSLRGAJG@dell.com	7236066306	3	2731925712898373	2012/04	user3264	password	58	40000	F
3265	RVAEAD	OSPGYPPELM	8200805796 Dell Way	\N	HGQXKWP	CA	45850	US	1	OSPGYPPELM@dell.com	8200805796	5	7507619919255377	2009/05	user3265	password	87	20000	F
3266	YEFCTX	RZWHPATBIA	7464289742 Dell Way	\N	SGKPVMZ	NM	52304	US	1	RZWHPATBIA@dell.com	7464289742	5	8551715442910791	2011/01	user3266	password	20	80000	F
3267	GSZDKZ	AROAKQJKIP	6581755749 Dell Way	\N	VYLIYBU	NV	16416	US	1	AROAKQJKIP@dell.com	6581755749	2	1890514364466071	2011/12	user3267	password	41	100000	M
3268	HBBGBS	VCDLLNUAIS	7428707351 Dell Way	\N	MRQOLHP	AR	65729	US	1	VCDLLNUAIS@dell.com	7428707351	4	6031915239989758	2008/08	user3268	password	33	40000	M
3269	GOTZKV	CVHQPIZIUQ	4951778224 Dell Way	\N	YIBGYDW	NV	85433	US	1	CVHQPIZIUQ@dell.com	4951778224	4	5180653181392700	2011/01	user3269	password	29	100000	M
3270	XWZTZU	APKIOSDFRL	7123613322 Dell Way	\N	GXKJUBF	IA	78868	US	1	APKIOSDFRL@dell.com	7123613322	5	8026039167772979	2012/10	user3270	password	45	80000	M
3271	JMQDMG	NVVGYAXKGV	4976601108 Dell Way	\N	VQPXWVR	NC	76248	US	1	NVVGYAXKGV@dell.com	4976601108	2	5815645453985781	2012/02	user3271	password	33	20000	M
3272	WHBCVX	YBWYYGFTCW	5397780540 Dell Way	\N	JZSFQGY	CA	67022	US	1	YBWYYGFTCW@dell.com	5397780540	5	7659529353957624	2011/01	user3272	password	41	60000	F
3273	JRFHPG	DOFJTZMPJL	9576992965 Dell Way	\N	IPCPNEF	AL	17272	US	1	DOFJTZMPJL@dell.com	9576992965	4	2279605947434902	2009/04	user3273	password	55	80000	M
3274	SXOZAC	FKWEWMOIUD	8470343503 Dell Way	\N	LJRPORR	MT	46193	US	1	FKWEWMOIUD@dell.com	8470343503	4	7198326828889549	2009/06	user3274	password	65	20000	F
3275	FAKIFV	EKRQZALCLU	5691355505 Dell Way	\N	TBJLTXV	NE	72443	US	1	EKRQZALCLU@dell.com	5691355505	5	2240753718186170	2008/12	user3275	password	54	40000	M
3276	XSFSXQ	KOPKZRWUKY	8798535996 Dell Way	\N	DWRARGS	GA	24456	US	1	KOPKZRWUKY@dell.com	8798535996	2	2069884611293673	2009/10	user3276	password	25	40000	F
3277	HZJXJY	MUXERRPPVL	8129509353 Dell Way	\N	GVDNOIR	MI	72449	US	1	MUXERRPPVL@dell.com	8129509353	5	5128731033764780	2012/01	user3277	password	86	20000	F
3278	ICKGPF	DUWVJLQUSM	4447227513 Dell Way	\N	XFBFXMY	OH	36635	US	1	DUWVJLQUSM@dell.com	4447227513	3	4277268639300019	2009/10	user3278	password	47	80000	M
3279	UXNZAH	WWQHMLAYJG	2425950494 Dell Way	\N	APDMNVU	VA	45610	US	1	WWQHMLAYJG@dell.com	2425950494	2	2534730908926576	2010/11	user3279	password	22	40000	M
3280	OJTVFQ	MNCXNBGTBV	3388069915 Dell Way	\N	WOJSJGC	MT	50008	US	1	MNCXNBGTBV@dell.com	3388069915	1	3641887320671231	2009/06	user3280	password	20	100000	M
3281	USAKFO	NDBPKVQGSF	6001783341 Dell Way	\N	PKPVMCG	PA	27413	US	1	NDBPKVQGSF@dell.com	6001783341	1	6757654321379960	2010/12	user3281	password	50	40000	M
3282	MUXAIA	BXKXOQPUFZ	3740979114 Dell Way	\N	JBMMHGR	TX	40508	US	1	BXKXOQPUFZ@dell.com	3740979114	3	3794561084359884	2011/10	user3282	password	18	40000	M
3283	XGYYIV	IFJZUDFUMG	2703634053 Dell Way	\N	HZOOQKW	WA	85653	US	1	IFJZUDFUMG@dell.com	2703634053	4	6943157137371600	2008/12	user3283	password	37	20000	F
3284	FAMAJR	JIMNOGAUOZ	2969061601 Dell Way	\N	ICQSZOO	DE	32964	US	1	JIMNOGAUOZ@dell.com	2969061601	2	2551851696334779	2010/06	user3284	password	41	80000	F
3285	USWMCE	YPSFQNTQVV	3147021329 Dell Way	\N	GOVVCZB	KS	39353	US	1	YPSFQNTQVV@dell.com	3147021329	5	8050242420285941	2010/07	user3285	password	37	40000	F
3286	DVHITX	BYOOSEJOKY	4879904100 Dell Way	\N	JGAIHJQ	NC	24753	US	1	BYOOSEJOKY@dell.com	4879904100	1	7017728109378368	2011/06	user3286	password	82	100000	F
3287	EDACEZ	QSRVCFGAOM	3153564670 Dell Way	\N	BXUKOIO	WV	47148	US	1	QSRVCFGAOM@dell.com	3153564670	4	8850226006936283	2008/06	user3287	password	29	40000	M
3288	EKUEBN	WWQBDRQPSN	9733852529 Dell Way	\N	JDCRSBC	WI	75066	US	1	WWQBDRQPSN@dell.com	9733852529	1	2959360931534320	2008/05	user3288	password	79	40000	M
3289	QMVEIS	VKVMALFOUJ	6753652138 Dell Way	\N	QMBSPZK	ND	15239	US	1	VKVMALFOUJ@dell.com	6753652138	4	4825853330548853	2010/12	user3289	password	32	20000	F
3290	AIUSDE	OQFZWUUFLH	7574741114 Dell Way	\N	GDWGOLH	FL	19658	US	1	OQFZWUUFLH@dell.com	7574741114	4	1855951603502035	2012/10	user3290	password	58	100000	F
3291	IRHNGX	TFTNAYZHFC	8193028886 Dell Way	\N	ELRPTWS	MS	57812	US	1	TFTNAYZHFC@dell.com	8193028886	3	4137205251958221	2009/05	user3291	password	53	80000	F
3292	TFHRZN	LMNKLVPOAB	9400067065 Dell Way	\N	FPVBIIP	CO	76471	US	1	LMNKLVPOAB@dell.com	9400067065	3	1992472618352621	2010/02	user3292	password	29	20000	F
3293	LWJZHV	NRHJHVJJBZ	4050685030 Dell Way	\N	ECHMRJF	NJ	86495	US	1	NRHJHVJJBZ@dell.com	4050685030	1	1147347034886479	2010/03	user3293	password	47	100000	F
3294	TYJPLB	XUITDRUCWW	6705149162 Dell Way	\N	JJOTOEQ	VT	29678	US	1	XUITDRUCWW@dell.com	6705149162	3	4933234227355570	2008/05	user3294	password	55	80000	F
3295	WKTYHN	GARYVUUSEE	1863138431 Dell Way	\N	GYTLOQR	FL	15687	US	1	GARYVUUSEE@dell.com	1863138431	2	4910198791883886	2011/01	user3295	password	71	60000	F
3296	MKSZRT	RQOLLGPPNN	5181996637 Dell Way	\N	IYBZPGA	OH	50755	US	1	RQOLLGPPNN@dell.com	5181996637	2	5231450791936368	2008/10	user3296	password	82	80000	F
3297	PQWIHN	XTYDINQVWP	1461433023 Dell Way	\N	XVEDWWP	KS	26423	US	1	XTYDINQVWP@dell.com	1461433023	3	9758808996994048	2012/03	user3297	password	30	60000	M
3298	BWDOTW	NXFBNAXDXS	3981896565 Dell Way	\N	HBOEQWJ	NY	45239	US	1	NXFBNAXDXS@dell.com	3981896565	4	6107672615908087	2010/02	user3298	password	46	60000	F
3299	NDUKQS	PRGQPJOHRP	7332751362 Dell Way	\N	WVFTEXD	MT	57790	US	1	PRGQPJOHRP@dell.com	7332751362	1	7205425546504558	2008/08	user3299	password	70	80000	M
3300	NAJFQB	MGQVUYMKVI	7698055233 Dell Way	\N	PONNSAB	MD	14687	US	1	MGQVUYMKVI@dell.com	7698055233	3	6839847540482879	2010/02	user3300	password	45	100000	F
3301	TFUVRA	MNVKZFGHVU	5727866471 Dell Way	\N	UJMVKWW	DC	44387	US	1	MNVKZFGHVU@dell.com	5727866471	4	5591214003507048	2012/08	user3301	password	66	80000	M
3302	LMNMYA	IJANPIJKCS	7027511014 Dell Way	\N	XYCUVGE	KY	88821	US	1	IJANPIJKCS@dell.com	7027511014	2	5369513096287847	2009/11	user3302	password	40	80000	F
3303	VHJWPS	WDIEMTHEQF	9128662122 Dell Way	\N	HKAOPJK	IA	64670	US	1	WDIEMTHEQF@dell.com	9128662122	3	5627574372570962	2009/05	user3303	password	84	20000	M
3304	GXGZTJ	IXWCEASKID	9221457397 Dell Way	\N	LWSUHZK	DE	60520	US	1	IXWCEASKID@dell.com	9221457397	2	9500161255709828	2012/06	user3304	password	62	20000	F
3305	WBBGKZ	CMEDFOLIZH	5908895086 Dell Way	\N	BUOBESP	CO	20522	US	1	CMEDFOLIZH@dell.com	5908895086	5	5934943254571409	2008/12	user3305	password	81	20000	F
3306	YHLXJY	BMDQYMQFOK	2450847303 Dell Way	\N	TPPMESP	OR	65999	US	1	BMDQYMQFOK@dell.com	2450847303	5	6573285245802254	2008/11	user3306	password	67	100000	F
3307	DWOCYB	FPZSFEGQYV	2691694203 Dell Way	\N	GLAYBTO	HI	68335	US	1	FPZSFEGQYV@dell.com	2691694203	2	6047866056207568	2012/03	user3307	password	72	20000	F
3308	HCAIHQ	IAVMGMLCSX	1657664448 Dell Way	\N	CRYWGEN	ME	49289	US	1	IAVMGMLCSX@dell.com	1657664448	2	6874256615061314	2012/04	user3308	password	72	20000	F
3309	ULSKTS	GGYSSALPDC	8609276867 Dell Way	\N	OZJTNUF	NE	16200	US	1	GGYSSALPDC@dell.com	8609276867	3	4379959417041391	2010/07	user3309	password	74	40000	M
3310	MTTEAZ	DSSDEIHGXH	8509348484 Dell Way	\N	QQUKVKL	OH	80891	US	1	DSSDEIHGXH@dell.com	8509348484	2	3724849876947701	2011/08	user3310	password	37	20000	F
3311	AGKAJD	SNHAVOYCEO	4378460120 Dell Way	\N	XOKHACB	TX	44107	US	1	SNHAVOYCEO@dell.com	4378460120	3	1161042863503098	2011/07	user3311	password	48	80000	M
3312	VQDYJR	FKMUIPYXMM	8298210996 Dell Way	\N	IUNKVJU	HI	83163	US	1	FKMUIPYXMM@dell.com	8298210996	5	4101278977468610	2009/07	user3312	password	27	20000	F
3313	HZNYFY	LZGAYDNKLH	4984683727 Dell Way	\N	YWDHRJC	MN	29101	US	1	LZGAYDNKLH@dell.com	4984683727	4	7561385251581670	2010/09	user3313	password	83	100000	M
3314	LUYJGY	PGWTUHFBFB	5346373327 Dell Way	\N	FMSOPET	AR	89959	US	1	PGWTUHFBFB@dell.com	5346373327	4	6742115907371045	2009/06	user3314	password	45	100000	F
3315	IEMHUT	DNOLSQQUVD	3035057924 Dell Way	\N	NJTSCUP	NH	45518	US	1	DNOLSQQUVD@dell.com	3035057924	5	8648708328604699	2011/10	user3315	password	25	100000	M
3316	PFTJJG	XVZNMUJPHS	4494159394 Dell Way	\N	JZUDOKN	SC	42960	US	1	XVZNMUJPHS@dell.com	4494159394	3	2355448114685714	2010/05	user3316	password	25	20000	M
3317	VMYCKT	CXFWGVEZFE	7170663790 Dell Way	\N	UISEWNN	ID	94762	US	1	CXFWGVEZFE@dell.com	7170663790	4	3653386135119945	2011/11	user3317	password	81	80000	F
3318	VTSPVQ	VSXRXWWBQF	5886349560 Dell Way	\N	UVBHJIG	AL	19331	US	1	VSXRXWWBQF@dell.com	5886349560	5	9657765669748188	2010/06	user3318	password	38	40000	F
3319	AVBQRU	NIRKESBJMW	8708076782 Dell Way	\N	LUFUBGX	NE	17199	US	1	NIRKESBJMW@dell.com	8708076782	1	5915096454322339	2008/03	user3319	password	73	20000	F
3320	VUTPIB	HSGZUPMQBG	7714683995 Dell Way	\N	WVHDTXF	NH	90165	US	1	HSGZUPMQBG@dell.com	7714683995	4	2216778101399541	2010/11	user3320	password	33	40000	M
3321	YYZAFS	GEMWQDXXAT	2212278146 Dell Way	\N	FDMCICZ	AZ	84204	US	1	GEMWQDXXAT@dell.com	2212278146	3	7372733245603741	2009/11	user3321	password	45	40000	M
3322	JIABOF	OLVRITSCZV	2699433990 Dell Way	\N	OCDRCFM	HI	81857	US	1	OLVRITSCZV@dell.com	2699433990	3	7302338946610690	2010/11	user3322	password	56	100000	F
3323	OZUTNF	PFNIXPISEK	6199047656 Dell Way	\N	WVMCISW	MS	35356	US	1	PFNIXPISEK@dell.com	6199047656	1	2447080144658685	2008/12	user3323	password	44	80000	M
3324	DKLIZR	WIOLQGQBDM	7173001000 Dell Way	\N	NFUGBHN	NV	41736	US	1	WIOLQGQBDM@dell.com	7173001000	4	3931359980255365	2008/05	user3324	password	37	20000	M
3325	SNTJJC	YVSEMTHYHM	7204093909 Dell Way	\N	SNOABFJ	OR	98264	US	1	YVSEMTHYHM@dell.com	7204093909	4	4447130907792598	2012/12	user3325	password	30	80000	F
3326	YBWAZR	SEDMLBUYUH	2088150333 Dell Way	\N	NUJTECT	TX	90881	US	1	SEDMLBUYUH@dell.com	2088150333	5	8850899052806199	2009/06	user3326	password	44	40000	M
3327	FGNWZR	ALDCFCWNQR	7954607210 Dell Way	\N	XKWADSX	IA	57547	US	1	ALDCFCWNQR@dell.com	7954607210	3	1174301781225949	2008/10	user3327	password	59	40000	F
3328	CFZTGL	XIRAFEQXCA	1137343761 Dell Way	\N	TCEMZKZ	PA	95657	US	1	XIRAFEQXCA@dell.com	1137343761	5	7499695776961745	2010/03	user3328	password	71	80000	F
3329	SLRDIZ	UJFZZCCAWE	3455946747 Dell Way	\N	EIDPIXO	KS	82132	US	1	UJFZZCCAWE@dell.com	3455946747	5	1231628475245088	2008/07	user3329	password	51	80000	F
3330	DWJDRS	IRSLTSHXXP	8273278719 Dell Way	\N	BNYZBGU	KY	25284	US	1	IRSLTSHXXP@dell.com	8273278719	2	7712931171525270	2009/01	user3330	password	73	60000	M
3331	COPVXH	NIAGQYDFAR	3975801627 Dell Way	\N	EZTKUBP	NE	47748	US	1	NIAGQYDFAR@dell.com	3975801627	5	5378029734361917	2008/04	user3331	password	48	20000	M
3332	AZSHNA	ITQHXWHOAH	3469926236 Dell Way	\N	HLBJAQU	LA	53892	US	1	ITQHXWHOAH@dell.com	3469926236	3	7798780040349812	2011/08	user3332	password	59	80000	M
3333	HADHJW	YQUVYIVFQH	2191546468 Dell Way	\N	GAIXURJ	AZ	20196	US	1	YQUVYIVFQH@dell.com	2191546468	4	7724442043341697	2011/06	user3333	password	45	100000	M
3334	NHXKFN	EALNWRDEXD	1020474432 Dell Way	\N	MVYDEZG	KS	78309	US	1	EALNWRDEXD@dell.com	1020474432	1	3194997490383685	2009/12	user3334	password	73	100000	F
3335	QHMEMN	QZKHDOFHAA	3115424479 Dell Way	\N	GEFGLNZ	ME	60521	US	1	QZKHDOFHAA@dell.com	3115424479	5	6038115886971355	2012/09	user3335	password	78	80000	F
3336	IVNWLN	GTQUZYVAEA	8962283846 Dell Way	\N	FKLTKWI	NM	70453	US	1	GTQUZYVAEA@dell.com	8962283846	4	4478453715331853	2011/04	user3336	password	47	20000	F
3337	XXOKDI	BYHAUHFUNP	2144735325 Dell Way	\N	FHABPQT	MS	35401	US	1	BYHAUHFUNP@dell.com	2144735325	2	6059881967026741	2010/04	user3337	password	66	60000	F
3338	FWHNYF	VYZDDTQTZY	3271650812 Dell Way	\N	TBNKUAR	VT	32035	US	1	VYZDDTQTZY@dell.com	3271650812	3	5491776451934129	2012/11	user3338	password	64	20000	M
3339	XRRDMQ	DQUXGNWEHY	5554925576 Dell Way	\N	SSSTKQA	NM	16559	US	1	DQUXGNWEHY@dell.com	5554925576	3	9713323560077698	2008/09	user3339	password	71	20000	F
3340	KFWBIM	VGTJDYRBRJ	4768223936 Dell Way	\N	TLUJLKL	WI	98559	US	1	VGTJDYRBRJ@dell.com	4768223936	1	7169634308665992	2008/03	user3340	password	22	60000	F
3341	YQTLMZ	EWCDNDVXXG	7898030650 Dell Way	\N	RGSCSRC	CT	80342	US	1	EWCDNDVXXG@dell.com	7898030650	2	9623613353818656	2012/11	user3341	password	43	80000	F
3342	CFYBKU	DNHHJFEQXL	7846682026 Dell Way	\N	IZEABHU	TN	61633	US	1	DNHHJFEQXL@dell.com	7846682026	4	4786517985165119	2008/06	user3342	password	83	20000	M
3343	VGAPJN	XRXDVNAGWA	7349003809 Dell Way	\N	KXBSRXH	MI	59567	US	1	XRXDVNAGWA@dell.com	7349003809	3	9748754116240890	2010/09	user3343	password	61	60000	M
3344	PBJDZA	ACVOCCKCNH	6347327366 Dell Way	\N	EGZBNLQ	HI	99473	US	1	ACVOCCKCNH@dell.com	6347327366	5	7611392918042839	2008/03	user3344	password	69	80000	F
3345	BXGBYJ	XMMAXPOFTU	4169035474 Dell Way	\N	EVHQLNQ	AR	40704	US	1	XMMAXPOFTU@dell.com	4169035474	2	6310409178026021	2008/01	user3345	password	82	20000	M
3346	DFWMCI	YDGORLHLQD	2686718844 Dell Way	\N	TGPGWQP	HI	87527	US	1	YDGORLHLQD@dell.com	2686718844	2	8840606855228544	2008/05	user3346	password	75	40000	M
3347	QSSZQV	GENRMYIQRO	6087693000 Dell Way	\N	FYLVOQS	OR	94044	US	1	GENRMYIQRO@dell.com	6087693000	4	4061123240739107	2009/01	user3347	password	86	20000	M
3348	RAJMGO	AYAYGQQUWP	2451486955 Dell Way	\N	GRDXJWV	WI	69519	US	1	AYAYGQQUWP@dell.com	2451486955	2	6980538154020906	2008/04	user3348	password	44	80000	F
3349	SGOGHM	HGTYWOUMUM	8169218833 Dell Way	\N	PRWMMUD	NV	18954	US	1	HGTYWOUMUM@dell.com	8169218833	4	4699876188300550	2008/07	user3349	password	71	100000	M
3350	HDBUKH	NJECDQWPGN	7935540073 Dell Way	\N	MSAGWRJ	NV	48601	US	1	NJECDQWPGN@dell.com	7935540073	5	9543367091566324	2010/09	user3350	password	71	80000	M
3351	UPFCDO	GFSXBIDPUW	7027636688 Dell Way	\N	QASHKJS	DE	24290	US	1	GFSXBIDPUW@dell.com	7027636688	4	8546146892011166	2010/06	user3351	password	65	20000	F
3352	WGELNJ	DKLLNBGKRH	4976686281 Dell Way	\N	CYRLRVP	KY	55265	US	1	DKLLNBGKRH@dell.com	4976686281	4	9701853357255460	2008/12	user3352	password	19	100000	F
3353	FKSPND	AZRCFBTMDS	5071693871 Dell Way	\N	DPKZFTM	NM	54772	US	1	AZRCFBTMDS@dell.com	5071693871	4	4985734726302326	2010/09	user3353	password	65	80000	F
3354	KGPNHO	EJUGDGJVKZ	9244403787 Dell Way	\N	GKEZWUM	KS	57225	US	1	EJUGDGJVKZ@dell.com	9244403787	5	2807389449793845	2010/06	user3354	password	37	100000	M
3355	WMAKRK	FXNLHJWGPG	9409721421 Dell Way	\N	KODFALT	WI	32802	US	1	FXNLHJWGPG@dell.com	9409721421	3	7532963127363474	2008/06	user3355	password	51	20000	M
3356	MMQWRN	JDUTZAIGLW	8130622046 Dell Way	\N	JQXVJWB	IN	44865	US	1	JDUTZAIGLW@dell.com	8130622046	3	8839517337735743	2009/07	user3356	password	78	80000	F
3357	LPRYYU	SRUTAAEWJV	9253980874 Dell Way	\N	UFERGMB	AR	98957	US	1	SRUTAAEWJV@dell.com	9253980874	2	5854860900435597	2011/01	user3357	password	58	20000	M
3358	GDOBWG	VQGWUDFQXK	8311760242 Dell Way	\N	UORHQTH	NC	12621	US	1	VQGWUDFQXK@dell.com	8311760242	2	1391003218479454	2009/06	user3358	password	64	80000	M
3359	ERNKMD	RIYUOOSZIH	5257617383 Dell Way	\N	RQXKXLL	OK	75381	US	1	RIYUOOSZIH@dell.com	5257617383	1	2863057130482048	2008/09	user3359	password	78	40000	F
3360	ISVMJE	KETYWTHDKX	4707157903 Dell Way	\N	BUVMFNF	OH	65778	US	1	KETYWTHDKX@dell.com	4707157903	5	3852168094366789	2009/02	user3360	password	66	60000	M
3361	NBFRLJ	LKFERJOPKJ	8943911221 Dell Way	\N	KWPYCHO	MS	19533	US	1	LKFERJOPKJ@dell.com	8943911221	4	2912768421228975	2010/04	user3361	password	20	20000	F
3362	GTVPEF	VIWEXMOGWL	5239414513 Dell Way	\N	WVNDKAG	ID	78484	US	1	VIWEXMOGWL@dell.com	5239414513	5	1738751776516437	2010/11	user3362	password	50	80000	M
3363	GIVLDE	IIBUXIRIFM	7535276151 Dell Way	\N	WJXWPEQ	CA	98313	US	1	IIBUXIRIFM@dell.com	7535276151	3	8823989577125759	2008/04	user3363	password	55	60000	M
3364	IXUMGD	OAAXSICFFM	1897697860 Dell Way	\N	CCCGSEF	MN	77519	US	1	OAAXSICFFM@dell.com	1897697860	4	1697267868556082	2011/01	user3364	password	71	100000	M
3365	OLFRAG	RYYZBDFNGH	6243077345 Dell Way	\N	PMATSLN	SD	17908	US	1	RYYZBDFNGH@dell.com	6243077345	3	2398876930121332	2009/05	user3365	password	26	100000	M
3366	INVOET	MEUQJIWRXJ	4299722525 Dell Way	\N	RRCDEXF	PA	39918	US	1	MEUQJIWRXJ@dell.com	4299722525	1	7304126462899149	2010/12	user3366	password	55	100000	F
3367	IJQCWU	WNEFKVCTMT	8083562748 Dell Way	\N	WPXTVRC	FL	76011	US	1	WNEFKVCTMT@dell.com	8083562748	4	6907077348325402	2009/06	user3367	password	24	80000	M
3368	SSSNPG	RUQNXKZQGP	6675672376 Dell Way	\N	OZLGCQZ	UT	37543	US	1	RUQNXKZQGP@dell.com	6675672376	1	8201139124110342	2011/10	user3368	password	66	60000	M
3369	KYCQPX	GCUQCLXSAW	8852666951 Dell Way	\N	DGYTGVB	TX	98670	US	1	GCUQCLXSAW@dell.com	8852666951	3	7993750199209899	2010/01	user3369	password	38	100000	M
3370	KOOHVR	CLUNIMOFQU	7883069745 Dell Way	\N	EKAAMXZ	LA	53554	US	1	CLUNIMOFQU@dell.com	7883069745	5	5561036495026202	2008/10	user3370	password	52	60000	F
3371	BSESVQ	NIZAXFRRKB	6482860348 Dell Way	\N	SKOQJXC	DC	81168	US	1	NIZAXFRRKB@dell.com	6482860348	1	6453994263894857	2008/08	user3371	password	89	20000	F
3372	EWEUJN	UJKABCKCVU	9640913622 Dell Way	\N	RLEONIJ	DC	56511	US	1	UJKABCKCVU@dell.com	9640913622	2	2367155898362398	2012/05	user3372	password	55	20000	F
3373	SXOFSY	QSZSCCNXTZ	1474381471 Dell Way	\N	BINJRQX	NM	88514	US	1	QSZSCCNXTZ@dell.com	1474381471	3	2943500183057040	2010/09	user3373	password	47	40000	M
3374	ZMGXCZ	XVBZIYTIAB	5955915945 Dell Way	\N	VKTMHJI	KY	96003	US	1	XVBZIYTIAB@dell.com	5955915945	5	6632267952430994	2012/03	user3374	password	32	100000	M
3375	MVTLSP	MSYLLGLNBW	3140348596 Dell Way	\N	HNERWNP	MD	48875	US	1	MSYLLGLNBW@dell.com	3140348596	2	6567319669295103	2010/04	user3375	password	38	100000	F
3376	BIVQVO	OGZUSNWPUJ	3660654049 Dell Way	\N	TLFGBQR	IN	97968	US	1	OGZUSNWPUJ@dell.com	3660654049	4	3330516838468611	2010/08	user3376	password	44	80000	M
3377	FGUTVB	TQTGMIBWCN	9285322792 Dell Way	\N	BIPRAXR	IN	67661	US	1	TQTGMIBWCN@dell.com	9285322792	5	3522541487589479	2009/07	user3377	password	36	60000	M
3378	AGPCZF	VGSEHOGVQP	3193979809 Dell Way	\N	LHPIZXZ	VA	79161	US	1	VGSEHOGVQP@dell.com	3193979809	1	3501721703447402	2010/08	user3378	password	21	60000	M
3379	QPWWLC	PQKDXGTMRB	1193192788 Dell Way	\N	CZAZYXT	GA	17583	US	1	PQKDXGTMRB@dell.com	1193192788	4	7752269408665598	2008/03	user3379	password	65	80000	M
3380	NPGQFX	BIUHCHZDJZ	9245336064 Dell Way	\N	EIYCCDE	CO	84804	US	1	BIUHCHZDJZ@dell.com	9245336064	1	1423105123918503	2010/11	user3380	password	80	20000	M
3381	DSSAUA	UBDBBHLALU	9716167200 Dell Way	\N	YNWCRYX	NH	21528	US	1	UBDBBHLALU@dell.com	9716167200	1	1278741044923663	2012/04	user3381	password	57	100000	M
3382	GYTHTV	KVWRGXCAVQ	9911209317 Dell Way	\N	WYIVWYY	SD	19416	US	1	KVWRGXCAVQ@dell.com	9911209317	4	4257491874042899	2010/08	user3382	password	42	80000	M
3383	CBIXLD	TDKRGKMWHL	6352561002 Dell Way	\N	FDHDCCG	AZ	77524	US	1	TDKRGKMWHL@dell.com	6352561002	4	4155701195355505	2012/05	user3383	password	84	20000	F
3384	FXWJRA	TIGEVCLGHP	7686210242 Dell Way	\N	OLRQRTK	ID	42268	US	1	TIGEVCLGHP@dell.com	7686210242	1	7672454227693380	2011/03	user3384	password	30	100000	F
3385	BFVBYD	HDZKOGSEUD	7149507854 Dell Way	\N	VLUPVBY	NE	31064	US	1	HDZKOGSEUD@dell.com	7149507854	2	4939415474422276	2012/02	user3385	password	58	100000	F
3386	JZHNHK	NRZTKDONYZ	1298560243 Dell Way	\N	IOVJMKP	DE	64790	US	1	NRZTKDONYZ@dell.com	1298560243	1	7295896850526334	2010/12	user3386	password	18	100000	M
3387	HMFRZX	QTHTHVSHDG	8096072244 Dell Way	\N	CMTMCXC	CT	94391	US	1	QTHTHVSHDG@dell.com	8096072244	4	8946241592057050	2011/09	user3387	password	77	20000	F
3388	ATDXJW	FDEAWLECOQ	6267577045 Dell Way	\N	WATTCWS	VA	60957	US	1	FDEAWLECOQ@dell.com	6267577045	4	3150348286610097	2009/10	user3388	password	46	60000	M
3389	NIXKOA	OPWATZOKVO	8055961996 Dell Way	\N	DPRZHPO	VA	34570	US	1	OPWATZOKVO@dell.com	8055961996	2	1393900746013969	2008/09	user3389	password	58	80000	F
3390	LCPMRE	IRYIGIEVLT	4481895220 Dell Way	\N	MKBBZZI	PA	32398	US	1	IRYIGIEVLT@dell.com	4481895220	5	9589107644278556	2012/08	user3390	password	18	40000	M
3391	PWKUFC	SOIASDMMQX	7441517456 Dell Way	\N	ORWNAQT	ME	59333	US	1	SOIASDMMQX@dell.com	7441517456	2	2557917176745832	2011/10	user3391	password	83	40000	M
3392	HCVJVJ	RWCVJOLGCC	5250515765 Dell Way	\N	DQDTJOH	CA	92808	US	1	RWCVJOLGCC@dell.com	5250515765	5	7072248479351402	2009/02	user3392	password	39	80000	F
3393	DACMSY	ONHDYOGBRW	4295102592 Dell Way	\N	FLGUTIR	GA	22586	US	1	ONHDYOGBRW@dell.com	4295102592	3	3464386959094554	2011/03	user3393	password	56	80000	F
3394	PHAOWN	WZMKFOCCUO	1467656267 Dell Way	\N	IOHQGMU	NH	17422	US	1	WZMKFOCCUO@dell.com	1467656267	2	3965369548182935	2010/01	user3394	password	62	20000	F
3395	PSEDPE	QZKFCMZRUN	8680131102 Dell Way	\N	YLTLFJN	ID	65827	US	1	QZKFCMZRUN@dell.com	8680131102	5	7019856773316861	2010/01	user3395	password	90	20000	M
3396	EFIJWI	TBKGABAOAL	9614286873 Dell Way	\N	ILRRZXH	TN	76877	US	1	TBKGABAOAL@dell.com	9614286873	2	7713957175146789	2012/05	user3396	password	52	20000	M
3397	UNMCGN	NNOPNDPZLB	1429293214 Dell Way	\N	QCAOKWH	KY	24537	US	1	NNOPNDPZLB@dell.com	1429293214	2	5837917826138437	2010/06	user3397	password	28	40000	M
3398	PKFDXS	SNGVCGHEXJ	7755918880 Dell Way	\N	ELUBTDF	SC	48528	US	1	SNGVCGHEXJ@dell.com	7755918880	2	8902108847629280	2012/08	user3398	password	78	60000	F
3399	BQYUJL	BEOHLSFVXQ	1323773481 Dell Way	\N	PYKSEFE	VT	58170	US	1	BEOHLSFVXQ@dell.com	1323773481	5	2522293199785054	2012/04	user3399	password	33	100000	M
3400	ESHQTM	EBYXGUUXKT	3065419101 Dell Way	\N	ICXNHVB	IN	67490	US	1	EBYXGUUXKT@dell.com	3065419101	1	9504908308852464	2010/02	user3400	password	82	60000	M
3401	EFPRKQ	PHXJCVTVDW	2535138152 Dell Way	\N	TQDPSLF	WI	67576	US	1	PHXJCVTVDW@dell.com	2535138152	2	7697215056978167	2008/12	user3401	password	58	40000	F
3402	DXPUNX	RXZMRVQOPH	5846069134 Dell Way	\N	SEZEKYU	NE	38706	US	1	RXZMRVQOPH@dell.com	5846069134	4	3688159223180264	2008/11	user3402	password	54	40000	M
3403	CAHZSF	ZFWVVKKDCO	7054230451 Dell Way	\N	DGZBAOJ	NE	25594	US	1	ZFWVVKKDCO@dell.com	7054230451	4	1432633160147816	2008/11	user3403	password	78	40000	M
3404	DHQIGW	ECSOMVRBYX	8192389070 Dell Way	\N	AZYPJNT	AR	26873	US	1	ECSOMVRBYX@dell.com	8192389070	2	1919212714303285	2011/06	user3404	password	21	80000	M
3405	RCAOHC	GVOCNQAKRA	2344536134 Dell Way	\N	JGJWZKB	SC	66389	US	1	GVOCNQAKRA@dell.com	2344536134	3	1996931903995573	2008/03	user3405	password	81	100000	F
3406	WLOZSK	OUXEUIWURC	3882037810 Dell Way	\N	ENCPOXF	OK	38280	US	1	OUXEUIWURC@dell.com	3882037810	5	5555993007496000	2008/10	user3406	password	75	20000	F
3407	IBXTPR	QUMYQGPSLC	5602382566 Dell Way	\N	UARRFKA	NC	35962	US	1	QUMYQGPSLC@dell.com	5602382566	4	1659800363238901	2009/10	user3407	password	39	80000	M
3408	FJLXAF	JYVQONBRIB	1859742864 Dell Way	\N	JAHTAVA	NC	60018	US	1	JYVQONBRIB@dell.com	1859742864	5	4160253482405096	2009/06	user3408	password	31	80000	M
3409	PMWUWV	QMJDNBMPKN	6550194062 Dell Way	\N	WDNSEBG	IA	91811	US	1	QMJDNBMPKN@dell.com	6550194062	4	4493640600703657	2012/03	user3409	password	35	60000	M
3410	CFPYVB	IZPJMFUZCX	8833787141 Dell Way	\N	NUBOBIM	NY	97664	US	1	IZPJMFUZCX@dell.com	8833787141	3	2975050559267402	2008/11	user3410	password	88	40000	F
3411	OEZQMY	GWKLQKNOXI	2436828867 Dell Way	\N	QMJZYBY	TN	58576	US	1	GWKLQKNOXI@dell.com	2436828867	5	4929354449734092	2008/02	user3411	password	58	80000	F
3412	NHVMOR	XZIHNXEVNR	3175272143 Dell Way	\N	FMPGLLU	NH	43373	US	1	XZIHNXEVNR@dell.com	3175272143	4	5813820516690612	2011/05	user3412	password	81	40000	M
3413	RUFJRF	RYSODNCUTP	7725681311 Dell Way	\N	KAAVVPF	AR	38314	US	1	RYSODNCUTP@dell.com	7725681311	5	7268923119176180	2011/02	user3413	password	45	40000	M
3414	PQQVIP	NXSBZNUPYV	2966628598 Dell Way	\N	PUQFZRN	OR	57594	US	1	NXSBZNUPYV@dell.com	2966628598	2	7259220735169948	2011/08	user3414	password	65	40000	F
3415	HAQWON	PPNDKCBFSV	7564168123 Dell Way	\N	VXVNLOA	NV	92628	US	1	PPNDKCBFSV@dell.com	7564168123	2	6025673567783088	2009/06	user3415	password	79	80000	F
3416	MNAZCQ	NFAQGFJCBG	9667457165 Dell Way	\N	XOSMPJK	KS	66746	US	1	NFAQGFJCBG@dell.com	9667457165	4	1884232765063643	2012/05	user3416	password	60	40000	M
3417	PHYGUD	GLKMUMOBKC	8650797484 Dell Way	\N	TXSDHAT	ID	75586	US	1	GLKMUMOBKC@dell.com	8650797484	1	1673817474395036	2010/05	user3417	password	85	20000	M
3418	WHKZNW	KAQWORHRLE	2853716945 Dell Way	\N	JOMKHSD	DC	81780	US	1	KAQWORHRLE@dell.com	2853716945	3	2324712061323225	2008/08	user3418	password	74	100000	M
3419	FZLBJM	RGAINSTSCI	8496458634 Dell Way	\N	EMPXPTR	SD	40331	US	1	RGAINSTSCI@dell.com	8496458634	5	9666334506124260	2011/12	user3419	password	81	80000	M
3420	IVHUNN	UWANQSPYXB	6520115376 Dell Way	\N	OURIMMQ	IN	49726	US	1	UWANQSPYXB@dell.com	6520115376	5	4343640831764788	2010/09	user3420	password	38	80000	M
3421	OOBBJY	CXOVMNTOBN	5783164355 Dell Way	\N	FJZSAHE	NV	26155	US	1	CXOVMNTOBN@dell.com	5783164355	1	8934129649773241	2012/12	user3421	password	49	40000	F
3422	MLWLOT	ZKFNDUOQZY	9614396332 Dell Way	\N	QSZXWQB	MD	79056	US	1	ZKFNDUOQZY@dell.com	9614396332	2	7203948269598187	2009/08	user3422	password	31	100000	F
3423	BHPUHZ	AUCUJTUIJN	4760934727 Dell Way	\N	IGKYIUS	IL	10710	US	1	AUCUJTUIJN@dell.com	4760934727	4	6334504756610841	2010/07	user3423	password	63	80000	M
3424	FLEEMZ	HHIACRJPZQ	4363906153 Dell Way	\N	ZYZURHU	CO	95644	US	1	HHIACRJPZQ@dell.com	4363906153	4	5594434992875904	2012/05	user3424	password	45	20000	M
3425	NJHNQO	VRQNBGNRFL	4610342710 Dell Way	\N	RZDYUGX	DC	94526	US	1	VRQNBGNRFL@dell.com	4610342710	1	3559185148216784	2011/04	user3425	password	23	40000	M
3426	JVIXQZ	OEAURSADJZ	7514186582 Dell Way	\N	GITNFXL	NJ	14629	US	1	OEAURSADJZ@dell.com	7514186582	2	4430099789984524	2012/09	user3426	password	23	20000	M
3427	KBEKPI	LKADKDNKJW	5516268268 Dell Way	\N	EWBBIRD	AR	16151	US	1	LKADKDNKJW@dell.com	5516268268	5	7962347813881934	2010/12	user3427	password	39	100000	F
3428	MJRUUB	UYLYMWIIAF	9140325842 Dell Way	\N	KBNBFOD	OH	46747	US	1	UYLYMWIIAF@dell.com	9140325842	2	4673665080219507	2008/04	user3428	password	52	80000	M
3429	DMLFHJ	RFWNNENSOP	6404694063 Dell Way	\N	FQUUTMF	NV	78181	US	1	RFWNNENSOP@dell.com	6404694063	5	1109707646071910	2008/07	user3429	password	64	40000	M
3430	BKGLBM	HPZMCSARXQ	7505684738 Dell Way	\N	MSKYXBS	MS	92301	US	1	HPZMCSARXQ@dell.com	7505684738	3	4912238850723952	2009/10	user3430	password	49	60000	F
3431	SXGEFV	DRXWSPTJBM	2557463837 Dell Way	\N	TAJVTWT	MN	48382	US	1	DRXWSPTJBM@dell.com	2557463837	5	2785889055114239	2010/04	user3431	password	45	40000	F
3432	QLJLPA	JLSZFCASWB	5972685028 Dell Way	\N	BRUYKGJ	NE	16254	US	1	JLSZFCASWB@dell.com	5972685028	1	3979432290419936	2012/06	user3432	password	53	60000	M
3433	VAOWJA	PIGRJYNLAF	8961496945 Dell Way	\N	GYPMHEO	TN	43772	US	1	PIGRJYNLAF@dell.com	8961496945	4	8660613288171590	2009/04	user3433	password	75	40000	F
3434	IBSIQB	OILNVWNBDL	1593444381 Dell Way	\N	QPSVEOF	AR	39950	US	1	OILNVWNBDL@dell.com	1593444381	3	6917926397640259	2012/08	user3434	password	90	20000	M
3435	SNITCR	FPNCDOFOFU	8669979562 Dell Way	\N	HAYWGZF	IN	46323	US	1	FPNCDOFOFU@dell.com	8669979562	1	1186271956190466	2012/05	user3435	password	69	60000	M
3436	AHZSMO	FOSTUGYOOZ	9446121520 Dell Way	\N	NLFNQNX	MO	72869	US	1	FOSTUGYOOZ@dell.com	9446121520	2	1418475233018398	2011/11	user3436	password	84	80000	F
3437	WJRLPG	EIALGOZGCK	7609136572 Dell Way	\N	LPBZNNR	MN	85150	US	1	EIALGOZGCK@dell.com	7609136572	1	7263726423028857	2011/10	user3437	password	80	60000	F
3438	NZTTEB	TPIIPOKAAA	1862356865 Dell Way	\N	BAOORAK	ME	19718	US	1	TPIIPOKAAA@dell.com	1862356865	1	9022729203570636	2012/08	user3438	password	21	60000	M
3439	UFTWZJ	EHYSSYTSZT	3413864840 Dell Way	\N	GOLGYWJ	AR	94693	US	1	EHYSSYTSZT@dell.com	3413864840	5	5970205984078348	2009/06	user3439	password	29	20000	M
3440	XYQHDY	FWQDPJCIQR	2271937067 Dell Way	\N	UXPQHQP	NC	66823	US	1	FWQDPJCIQR@dell.com	2271937067	5	1843288563657552	2009/12	user3440	password	74	40000	M
3441	KMBJRX	AVNJYVZPQX	5944141865 Dell Way	\N	EHEVWSL	AK	61587	US	1	AVNJYVZPQX@dell.com	5944141865	2	5877127103507519	2009/07	user3441	password	51	80000	F
3442	NCSKCN	XMMTMBKJGR	4247113493 Dell Way	\N	NBNGNNV	AZ	86092	US	1	XMMTMBKJGR@dell.com	4247113493	2	4364315634127706	2012/02	user3442	password	46	40000	F
3443	CTJQRV	CLHDVRKMFL	7957243519 Dell Way	\N	ALZOGAK	NJ	48387	US	1	CLHDVRKMFL@dell.com	7957243519	3	6054215813055635	2008/10	user3443	password	76	40000	M
3444	DXFZAQ	HELYOYDZYP	9907072743 Dell Way	\N	ZNVAXML	NY	92045	US	1	HELYOYDZYP@dell.com	9907072743	5	7290944432374091	2011/02	user3444	password	35	100000	F
3445	LXACFE	ODSMGSLVRY	7818795396 Dell Way	\N	RRWDDOB	CO	46438	US	1	ODSMGSLVRY@dell.com	7818795396	5	5718755481299013	2012/11	user3445	password	58	60000	M
3446	OOYTCC	MPJFAFXZWP	4108677406 Dell Way	\N	WASKCVV	TX	74148	US	1	MPJFAFXZWP@dell.com	4108677406	5	6004875773563982	2012/04	user3446	password	41	60000	M
3447	HFXJSN	SYNYVNVKJV	2764287457 Dell Way	\N	CUYYQUQ	WV	66009	US	1	SYNYVNVKJV@dell.com	2764287457	5	9248811909928920	2010/04	user3447	password	72	80000	M
3448	REHEXF	SVAFQLPLOK	7329916594 Dell Way	\N	KMAECAU	IN	87433	US	1	SVAFQLPLOK@dell.com	7329916594	5	2706987086683512	2010/08	user3448	password	72	20000	M
3449	AHRFAM	FGCRWOFGYR	4157618212 Dell Way	\N	HCTHXBE	NH	89852	US	1	FGCRWOFGYR@dell.com	4157618212	1	5495894707273692	2008/03	user3449	password	38	20000	F
3450	YIMKOS	MFOBKVZBDC	3654921846 Dell Way	\N	VLZXPOU	WI	63995	US	1	MFOBKVZBDC@dell.com	3654921846	1	7930629657115788	2010/03	user3450	password	35	60000	F
3451	SXBLKH	ALRWLTZNPL	4596989667 Dell Way	\N	MNBAHZQ	NH	14062	US	1	ALRWLTZNPL@dell.com	4596989667	1	2916492270305753	2011/09	user3451	password	69	40000	M
3452	UVZBVL	TRWMRJCDVP	4742345791 Dell Way	\N	EWXENNF	VT	70744	US	1	TRWMRJCDVP@dell.com	4742345791	3	4115198628045619	2008/11	user3452	password	85	100000	M
3453	XYOJRG	FEXPHALXFH	3923975024 Dell Way	\N	UJUHOSZ	WV	32554	US	1	FEXPHALXFH@dell.com	3923975024	1	2443906261585653	2009/01	user3453	password	82	20000	M
3454	LNQRSV	OHCPTZVAUE	9570604961 Dell Way	\N	VCTOBSU	MD	83761	US	1	OHCPTZVAUE@dell.com	9570604961	4	8420464989729226	2012/10	user3454	password	74	40000	F
3455	KXBGMJ	ICCIXDDCYF	2677030441 Dell Way	\N	VMHOHRJ	IA	39085	US	1	ICCIXDDCYF@dell.com	2677030441	1	2212461048271507	2012/04	user3455	password	51	40000	F
3456	NQTWZV	YHTBKWAQRN	1404406154 Dell Way	\N	XFVPPBX	RI	21621	US	1	YHTBKWAQRN@dell.com	1404406154	4	5148934794124216	2010/02	user3456	password	69	20000	M
3457	LWSHVZ	BXKXYBPLYV	9263401027 Dell Way	\N	HOKILFL	MS	94317	US	1	BXKXYBPLYV@dell.com	9263401027	5	1513319660909473	2011/01	user3457	password	76	20000	M
3458	MJSMLQ	XJOYZAXUHL	4667745868 Dell Way	\N	FPXKBKJ	WY	44820	US	1	XJOYZAXUHL@dell.com	4667745868	4	4590534772723913	2009/09	user3458	password	39	80000	F
3459	AFNQCW	EBVFYQMKVC	5221307171 Dell Way	\N	HGERPDB	AK	77936	US	1	EBVFYQMKVC@dell.com	5221307171	2	5046053625643254	2011/12	user3459	password	56	80000	F
3460	AKFXOH	TTGJGQFIYM	8455914220 Dell Way	\N	MQCQSCJ	DE	38918	US	1	TTGJGQFIYM@dell.com	8455914220	5	3201299734413624	2009/09	user3460	password	44	40000	F
3461	PHQWAK	CKRTPZSCMI	8474270743 Dell Way	\N	ECAGMEP	IN	18212	US	1	CKRTPZSCMI@dell.com	8474270743	4	7969245780725033	2008/01	user3461	password	80	80000	F
3462	NRJXUT	PNJPFLBOPE	6323598291 Dell Way	\N	OWQSLYV	IL	63875	US	1	PNJPFLBOPE@dell.com	6323598291	3	6767007062677295	2010/04	user3462	password	88	100000	M
3463	IWSCLF	LALXCZNGOJ	1437851515 Dell Way	\N	WHVVCDK	NY	65396	US	1	LALXCZNGOJ@dell.com	1437851515	1	8983951267320664	2008/01	user3463	password	77	40000	M
3464	NLKTWK	FUMEHTTRPA	2176307594 Dell Way	\N	MKCQVUG	UT	91391	US	1	FUMEHTTRPA@dell.com	2176307594	5	9753602858632804	2012/03	user3464	password	84	60000	M
3465	HFOSKI	FPQYIHNIUY	1816597591 Dell Way	\N	LKTFQQD	RI	55718	US	1	FPQYIHNIUY@dell.com	1816597591	4	7704377221409232	2012/03	user3465	password	48	40000	F
3466	ZZUIFK	YDSFRBZPMK	3112192178 Dell Way	\N	JSAZVVM	VT	58680	US	1	YDSFRBZPMK@dell.com	3112192178	5	7566354546695948	2011/03	user3466	password	27	80000	F
3467	XYKIWN	ABEBBUOLDG	6129438796 Dell Way	\N	MDBHPYV	TX	86980	US	1	ABEBBUOLDG@dell.com	6129438796	3	1415432384237647	2011/02	user3467	password	35	80000	F
3468	QYYDYA	IABCONGUAJ	7365674450 Dell Way	\N	WHZUDVR	OK	37959	US	1	IABCONGUAJ@dell.com	7365674450	3	4940535015892238	2012/01	user3468	password	54	60000	M
3469	LSXLAX	NCMBIGBRCJ	2917905308 Dell Way	\N	QXMMPFU	IL	66080	US	1	NCMBIGBRCJ@dell.com	2917905308	2	6834866146091372	2011/10	user3469	password	61	20000	F
3470	MPMKDP	WEXDGPGPGD	6184958591 Dell Way	\N	CSSHNAY	OK	31621	US	1	WEXDGPGPGD@dell.com	6184958591	3	1242745703551918	2008/08	user3470	password	55	80000	F
3471	ZBIPXN	NATCGJJKLC	4815932509 Dell Way	\N	DTPERIK	IA	76897	US	1	NATCGJJKLC@dell.com	4815932509	3	4003806973807514	2012/02	user3471	password	57	100000	F
3472	WNBKAC	EDJNNUZPYS	6314729219 Dell Way	\N	FCKNMQG	VT	16513	US	1	EDJNNUZPYS@dell.com	6314729219	5	2472951077390462	2008/10	user3472	password	40	20000	F
3473	JKHMPL	WCYRBOPUTR	1523074050 Dell Way	\N	EGEVNCX	CO	93087	US	1	WCYRBOPUTR@dell.com	1523074050	2	7261114471126348	2009/03	user3473	password	89	80000	M
3474	HGFSCI	RTKFJEYAJF	9137233720 Dell Way	\N	FESHBVF	CT	15277	US	1	RTKFJEYAJF@dell.com	9137233720	3	3676487469114363	2012/04	user3474	password	87	20000	M
3475	EXQNOK	XTTCSULXZQ	8317843216 Dell Way	\N	QHSLMWN	MD	41916	US	1	XTTCSULXZQ@dell.com	8317843216	2	6581346008926631	2011/06	user3475	password	27	100000	F
3476	TLXEJQ	XLJSXGSOXZ	1647599065 Dell Way	\N	GJMCWWL	NY	24380	US	1	XLJSXGSOXZ@dell.com	1647599065	3	6515156973619015	2009/05	user3476	password	87	100000	M
3477	WDENAQ	WTODLCALIK	6106808927 Dell Way	\N	XLGUWYY	WI	44940	US	1	WTODLCALIK@dell.com	6106808927	1	7948572529014201	2010/02	user3477	password	62	40000	F
3478	UXHLTA	ZWMBXXKHVV	6970599505 Dell Way	\N	OQSNPQX	DC	82522	US	1	ZWMBXXKHVV@dell.com	6970599505	4	9385800387710334	2009/01	user3478	password	31	20000	M
3479	MMSNMP	ZNMXXUTSJJ	8221679287 Dell Way	\N	KWYBTCW	ME	80191	US	1	ZNMXXUTSJJ@dell.com	8221679287	4	8518823149148376	2012/09	user3479	password	74	60000	F
3480	MZSBYF	OWDIPWRZGO	6707728768 Dell Way	\N	XIHAFSU	AK	45294	US	1	OWDIPWRZGO@dell.com	6707728768	5	2188890851568430	2010/06	user3480	password	44	100000	F
3481	BYJHMF	KVVGNUNBSW	6304671086 Dell Way	\N	JSBBNBL	DC	13827	US	1	KVVGNUNBSW@dell.com	6304671086	3	5409770568367094	2012/06	user3481	password	83	20000	F
3482	GHWMSR	HYEBMFTIOM	9628747738 Dell Way	\N	JQZLCDM	NY	72063	US	1	HYEBMFTIOM@dell.com	9628747738	4	2161668429151177	2012/08	user3482	password	54	20000	M
3483	JPQAXP	EZBKTKYGTP	2573258649 Dell Way	\N	FERJRJB	NJ	99807	US	1	EZBKTKYGTP@dell.com	2573258649	3	6821390975266696	2011/08	user3483	password	61	20000	F
3484	GADVFC	XPWHOCBDIG	8431903873 Dell Way	\N	VRXESNE	VA	11084	US	1	XPWHOCBDIG@dell.com	8431903873	3	6562814874108881	2010/08	user3484	password	78	80000	M
3485	YMVBJK	YRZATCJZXA	1582777261 Dell Way	\N	XCTLHRL	CO	30906	US	1	YRZATCJZXA@dell.com	1582777261	3	8480523341801018	2012/03	user3485	password	51	100000	M
3486	HYASWS	RXLUHLSHIV	8087394137 Dell Way	\N	BUCSFFY	IL	74642	US	1	RXLUHLSHIV@dell.com	8087394137	1	9011232027783992	2009/01	user3486	password	57	60000	M
3487	PGWHYT	TTAELINGKH	2343326273 Dell Way	\N	IDNOCVG	UT	10843	US	1	TTAELINGKH@dell.com	2343326273	1	1534953424241393	2011/09	user3487	password	21	40000	M
3488	XOWRHQ	SMBBAILIRP	7695869434 Dell Way	\N	WFRRMOR	NJ	71237	US	1	SMBBAILIRP@dell.com	7695869434	2	4167632687836886	2011/07	user3488	password	38	80000	F
3489	EJLUBY	WCYEOHVDDB	4739097686 Dell Way	\N	VVNJMDB	IA	48596	US	1	WCYEOHVDDB@dell.com	4739097686	1	1054478975944221	2011/09	user3489	password	28	100000	F
3490	PRDNNG	MSUTNYXPUS	6799969437 Dell Way	\N	CEFFFLQ	NM	52976	US	1	MSUTNYXPUS@dell.com	6799969437	2	2731462344527244	2011/03	user3490	password	37	40000	M
3491	KXKQKC	LEQJCFEUHI	2128159826 Dell Way	\N	AMOLDFY	RI	58419	US	1	LEQJCFEUHI@dell.com	2128159826	3	7793980252463371	2009/12	user3491	password	64	80000	M
3492	AKHDVL	TFNYKIGSIT	7725715422 Dell Way	\N	GUWLSQZ	TN	30082	US	1	TFNYKIGSIT@dell.com	7725715422	2	2615816048812121	2009/01	user3492	password	21	60000	F
3493	INGUHM	IGWQMPZFVT	2192359400 Dell Way	\N	CHMSHHY	AL	58015	US	1	IGWQMPZFVT@dell.com	2192359400	3	5901988322846592	2008/10	user3493	password	88	60000	F
3494	GHRSPX	PGJEFOAYQI	8114430267 Dell Way	\N	KJPSIQG	MN	14958	US	1	PGJEFOAYQI@dell.com	8114430267	4	8990637356415392	2011/02	user3494	password	36	100000	F
3495	XSBUHH	EMNTMLKUWU	9799868030 Dell Way	\N	KPCAVOC	NJ	29565	US	1	EMNTMLKUWU@dell.com	9799868030	2	4437255517113954	2009/05	user3495	password	79	20000	F
3496	XYJFDV	SWIEGDBANQ	3755485871 Dell Way	\N	DOLSQBY	NJ	49011	US	1	SWIEGDBANQ@dell.com	3755485871	5	8148963306564838	2008/01	user3496	password	81	20000	M
3497	GHCBAZ	KEGNGHBWKP	6348731696 Dell Way	\N	HDGJBWU	LA	76106	US	1	KEGNGHBWKP@dell.com	6348731696	3	7730091932229698	2010/07	user3497	password	70	80000	M
3498	VTVUEA	BRGISCTIKW	9408710530 Dell Way	\N	PUXLPGE	DE	78337	US	1	BRGISCTIKW@dell.com	9408710530	4	3876061187125743	2011/04	user3498	password	29	60000	F
3499	ZHGAIY	GQRJJZUFOO	5222157478 Dell Way	\N	DADKFID	CT	95716	US	1	GQRJJZUFOO@dell.com	5222157478	4	3466456471942365	2011/04	user3499	password	44	80000	M
3500	PQWNXN	EGWEBCTQGT	3840981325 Dell Way	\N	TQYCUCB	IA	89427	US	1	EGWEBCTQGT@dell.com	3840981325	5	2374984507914632	2011/06	user3500	password	69	40000	F
3501	OUABZH	YEIBXYHQSY	7524999003 Dell Way	\N	PVSRWYO	DE	84746	US	1	YEIBXYHQSY@dell.com	7524999003	5	3876360312104225	2010/02	user3501	password	49	100000	M
3502	LBXTAB	BCZAKPTIFO	2195590611 Dell Way	\N	AXLZMPV	GA	50275	US	1	BCZAKPTIFO@dell.com	2195590611	4	6124979116953910	2010/08	user3502	password	54	20000	M
3503	KTSMVU	LWFBPNHENE	2925919799 Dell Way	\N	PNRFIWQ	MN	54317	US	1	LWFBPNHENE@dell.com	2925919799	1	2043655829969793	2011/01	user3503	password	77	20000	M
3504	NPQIBM	NDBBKGPPVC	7718077479 Dell Way	\N	HALDRXQ	VA	92891	US	1	NDBBKGPPVC@dell.com	7718077479	4	9784505527466536	2010/09	user3504	password	75	20000	F
3505	KLKXZN	ZAYFPOBRVC	8991903321 Dell Way	\N	CZTZPRX	KY	34165	US	1	ZAYFPOBRVC@dell.com	8991903321	5	9958638006821276	2011/12	user3505	password	42	20000	F
3506	SZKGYK	FDZUERPHUP	9690782606 Dell Way	\N	BTESROZ	ND	50255	US	1	FDZUERPHUP@dell.com	9690782606	2	5016736280638725	2009/04	user3506	password	81	20000	F
3507	HHFRNJ	RHOIXVCMWW	1893659459 Dell Way	\N	ROOFNCQ	MS	40520	US	1	RHOIXVCMWW@dell.com	1893659459	4	6921871751081199	2012/10	user3507	password	87	40000	F
3508	EYPOPX	CXUXAGUXYJ	5820677278 Dell Way	\N	LDXOUKW	VA	26953	US	1	CXUXAGUXYJ@dell.com	5820677278	5	1096590210683643	2010/02	user3508	password	26	80000	F
3509	SFQQHN	KFORZLPIXS	8374710015 Dell Way	\N	FLMQHJV	TN	31135	US	1	KFORZLPIXS@dell.com	8374710015	2	4070223481394351	2012/12	user3509	password	45	80000	F
3510	ZHMNRR	CIROXALQGW	1719712966 Dell Way	\N	DWENRAT	MS	40301	US	1	CIROXALQGW@dell.com	1719712966	3	3880895940121263	2010/02	user3510	password	54	60000	F
3511	ZZBQBK	IPIIBZPXCL	7674700728 Dell Way	\N	BPCCIPK	ME	13371	US	1	IPIIBZPXCL@dell.com	7674700728	5	2222806546371430	2009/04	user3511	password	55	40000	F
3512	PWIZEY	INZHCWKNYZ	4871503987 Dell Way	\N	QBIGLTH	GA	64228	US	1	INZHCWKNYZ@dell.com	4871503987	3	9180111807305368	2012/08	user3512	password	31	60000	M
3513	NNSLWF	LEIHOWGNMH	1945183295 Dell Way	\N	WTTPBYF	MO	46410	US	1	LEIHOWGNMH@dell.com	1945183295	3	1552802230231464	2009/12	user3513	password	60	100000	M
3514	HGJMRN	VZCRGQEOMX	7536530959 Dell Way	\N	HBYGHLR	MA	87940	US	1	VZCRGQEOMX@dell.com	7536530959	4	8503477477002890	2009/06	user3514	password	42	60000	M
3515	SCKGXJ	IOQYSELQLN	7473965014 Dell Way	\N	PSUAKEX	CO	85118	US	1	IOQYSELQLN@dell.com	7473965014	3	3708983101882041	2008/01	user3515	password	19	80000	F
3516	KAZUJO	KIGOTXAHMT	4394164634 Dell Way	\N	BMDGJGB	CO	70752	US	1	KIGOTXAHMT@dell.com	4394164634	1	7149033237714321	2009/12	user3516	password	74	100000	M
3517	UPHIAP	PPJMQQZJSL	2197718089 Dell Way	\N	NZVUBYL	ME	18569	US	1	PPJMQQZJSL@dell.com	2197718089	5	1199598909821361	2012/08	user3517	password	88	80000	F
3518	GAGWQV	GCLXBVQNIP	4835631264 Dell Way	\N	JCQIOBK	OH	88051	US	1	GCLXBVQNIP@dell.com	4835631264	4	5417769841849804	2009/04	user3518	password	70	80000	F
3519	YNYUUB	FSCAIQJXAM	9639985859 Dell Way	\N	OIBPSTM	DC	42011	US	1	FSCAIQJXAM@dell.com	9639985859	3	6881685361731798	2011/03	user3519	password	88	80000	M
3520	XKNYQF	BQOSAMSNAB	3882976487 Dell Way	\N	OQUICYR	AR	53648	US	1	BQOSAMSNAB@dell.com	3882976487	4	7232837571762503	2009/05	user3520	password	49	20000	M
3521	ZDJFFA	TXBFQOFRDV	6182081921 Dell Way	\N	MLYKCZW	ME	72383	US	1	TXBFQOFRDV@dell.com	6182081921	4	1355993400327861	2008/11	user3521	password	75	100000	F
3522	DEGEYE	FDUUJMXFYI	8757868108 Dell Way	\N	EILDFVV	SC	60123	US	1	FDUUJMXFYI@dell.com	8757868108	5	5167714205104858	2011/10	user3522	password	55	80000	M
3523	TZXXEB	SYLEVRCEVL	5101633832 Dell Way	\N	PZRLULZ	NV	33788	US	1	SYLEVRCEVL@dell.com	5101633832	2	1507501765154302	2012/02	user3523	password	20	80000	F
3524	YQGAJE	MNAEQFZCUY	5845616893 Dell Way	\N	TFTFFKM	NY	71977	US	1	MNAEQFZCUY@dell.com	5845616893	4	8071800809353591	2010/05	user3524	password	80	60000	F
3525	COJHAW	IENNEQHDJN	7590073911 Dell Way	\N	WPTGCKY	NJ	13588	US	1	IENNEQHDJN@dell.com	7590073911	1	4612284964881838	2010/09	user3525	password	47	80000	F
3526	TYHQHM	EUQUCTEPQU	2660559494 Dell Way	\N	IXWTVMU	NE	69671	US	1	EUQUCTEPQU@dell.com	2660559494	1	4439581139013171	2010/10	user3526	password	65	40000	M
3527	YZBKEW	BYYVDOLXXJ	3314674626 Dell Way	\N	TQEFKTW	NH	91843	US	1	BYYVDOLXXJ@dell.com	3314674626	1	7639508092775942	2012/07	user3527	password	56	100000	M
3528	PGRLIQ	KDTYPQVYKL	5882844961 Dell Way	\N	DPWXMLU	OR	67825	US	1	KDTYPQVYKL@dell.com	5882844961	4	2591773971915245	2008/06	user3528	password	69	80000	M
3529	JCBAMF	TLVKGUUSXK	8462585813 Dell Way	\N	OVWAPPQ	DC	30469	US	1	TLVKGUUSXK@dell.com	8462585813	2	7427904495503754	2010/11	user3529	password	52	100000	M
3530	OYMTSX	PCEJXWHHKC	7123256643 Dell Way	\N	DKSTBWZ	VT	17218	US	1	PCEJXWHHKC@dell.com	7123256643	3	9710062584839762	2008/05	user3530	password	88	80000	F
3531	LLZJAB	NKZKRGUTKF	4132075736 Dell Way	\N	LDHHCFJ	RI	67229	US	1	NKZKRGUTKF@dell.com	4132075736	5	9830950633622708	2009/08	user3531	password	36	80000	F
3532	FDCHRM	GBDMWXXCJA	2956677142 Dell Way	\N	KQDPAXG	MA	84642	US	1	GBDMWXXCJA@dell.com	2956677142	4	4991337244864553	2010/06	user3532	password	54	80000	M
3533	PZGCFI	GSFDPHMQRD	9299713472 Dell Way	\N	THEQNNM	OR	29563	US	1	GSFDPHMQRD@dell.com	9299713472	2	7010507925413550	2010/11	user3533	password	36	20000	M
3534	NCCVJV	AMKIZAACUH	7123837199 Dell Way	\N	GLVUXOA	TN	79531	US	1	AMKIZAACUH@dell.com	7123837199	2	7061985258013011	2012/04	user3534	password	58	60000	F
3535	QHTLIG	WQFXQIRYPC	7839463308 Dell Way	\N	TKAIKWC	CA	19774	US	1	WQFXQIRYPC@dell.com	7839463308	1	4565748617518693	2009/06	user3535	password	76	100000	M
3536	OKBUGR	AEIIVGYYAI	3796721255 Dell Way	\N	YISUKUX	DE	83207	US	1	AEIIVGYYAI@dell.com	3796721255	3	3470446094404906	2008/06	user3536	password	19	80000	M
3537	BLCTMG	CVCJTAJCZS	7210145517 Dell Way	\N	UUDPSHK	AK	79775	US	1	CVCJTAJCZS@dell.com	7210145517	1	2884905575308949	2011/10	user3537	password	21	80000	F
3538	DOSKQO	MZHMJJMBEG	5102153531 Dell Way	\N	EUZMFZG	VA	18948	US	1	MZHMJJMBEG@dell.com	5102153531	4	8933214593213052	2010/05	user3538	password	26	80000	M
3539	VAOJNO	RAYBMZGTEB	7072957001 Dell Way	\N	SQGSXDU	KY	76317	US	1	RAYBMZGTEB@dell.com	7072957001	5	2101880481466651	2011/06	user3539	password	22	80000	M
3540	QAAFSA	DUNDAGHBZY	3702500387 Dell Way	\N	HRVLMEE	CT	13604	US	1	DUNDAGHBZY@dell.com	3702500387	5	5758063468150795	2009/07	user3540	password	21	100000	M
3541	BEHCIB	PLCWTEVRMN	3604424425 Dell Way	\N	NXZSCCT	MA	14110	US	1	PLCWTEVRMN@dell.com	3604424425	4	6560221542604268	2009/09	user3541	password	33	60000	M
3542	NNFPDR	RZKVVCHJPF	1922041577 Dell Way	\N	IIHLCRM	MA	46178	US	1	RZKVVCHJPF@dell.com	1922041577	4	2135569374542683	2009/02	user3542	password	20	100000	M
3543	GKTXBT	HXPKFYAKHI	8866086223 Dell Way	\N	RSLIFVT	IN	58425	US	1	HXPKFYAKHI@dell.com	8866086223	4	7023196986876429	2012/06	user3543	password	40	20000	M
3544	BBXVJV	KTAJTLQCCJ	6029618904 Dell Way	\N	NLOJFVX	AZ	50992	US	1	KTAJTLQCCJ@dell.com	6029618904	5	9010132234077902	2012/02	user3544	password	71	100000	F
3545	QUPMFJ	MOCXFFAOTM	3577935872 Dell Way	\N	CCRYZTK	ND	76068	US	1	MOCXFFAOTM@dell.com	3577935872	3	8887162962928415	2008/05	user3545	password	24	80000	F
3546	RDIAPX	DNCJNQCATF	1417834134 Dell Way	\N	RRFLCTE	LA	25183	US	1	DNCJNQCATF@dell.com	1417834134	2	5793525322340429	2008/01	user3546	password	66	100000	F
3547	ZVTXYG	ZHUQKVJPMB	3302179208 Dell Way	\N	UYDOCMS	DC	88644	US	1	ZHUQKVJPMB@dell.com	3302179208	2	9162953804247082	2012/02	user3547	password	22	100000	M
3548	VVWCUE	WLPSUFFWAD	3275009465 Dell Way	\N	ZOGMHJI	NC	70011	US	1	WLPSUFFWAD@dell.com	3275009465	3	7803979104384781	2009/05	user3548	password	66	20000	F
3549	OFZSCK	HUFMZBMCBB	2257347158 Dell Way	\N	INISWWJ	CO	39045	US	1	HUFMZBMCBB@dell.com	2257347158	3	7341056181117893	2012/07	user3549	password	83	40000	M
3550	XBVIJP	NWOPJRQKAD	6687058479 Dell Way	\N	TSZPCCY	IA	57208	US	1	NWOPJRQKAD@dell.com	6687058479	1	1573403858579695	2010/05	user3550	password	76	60000	F
3551	QTVFHS	UWBMMMMQFF	3889664073 Dell Way	\N	QVITTOG	MA	66379	US	1	UWBMMMMQFF@dell.com	3889664073	5	1316802269779145	2008/05	user3551	password	55	80000	F
3552	JZJBTF	DGSPSIVYYQ	5280284581 Dell Way	\N	GSKVYUL	ID	72350	US	1	DGSPSIVYYQ@dell.com	5280284581	2	1302583699580282	2012/02	user3552	password	26	40000	F
3553	MKWRND	JDVSZTRPAJ	5618349120 Dell Way	\N	AVIUHPM	PA	99295	US	1	JDVSZTRPAJ@dell.com	5618349120	4	2212532809935510	2011/01	user3553	password	36	20000	F
3554	DUAGED	CWCWOSWYTS	9755271276 Dell Way	\N	GNZVASV	MT	50298	US	1	CWCWOSWYTS@dell.com	9755271276	1	5693025884218514	2009/03	user3554	password	90	40000	F
3555	APEERB	HNPAKNTCUG	7875046872 Dell Way	\N	CQGULUG	MI	92207	US	1	HNPAKNTCUG@dell.com	7875046872	4	2358326862566173	2011/12	user3555	password	29	80000	M
3556	IYHJFV	ZFFNYIHFKX	3687063368 Dell Way	\N	MFJGLUD	GA	49686	US	1	ZFFNYIHFKX@dell.com	3687063368	5	4961810997687280	2010/09	user3556	password	20	80000	M
3557	IEXDEC	IRBRYGBVSH	8800240908 Dell Way	\N	FYSZCYL	MD	90687	US	1	IRBRYGBVSH@dell.com	8800240908	5	6765537551604212	2012/08	user3557	password	41	40000	M
3558	FIZHRQ	JIPPKLIRQH	8746234219 Dell Way	\N	KPJIAUF	VA	66692	US	1	JIPPKLIRQH@dell.com	8746234219	4	3566567819565535	2008/01	user3558	password	26	40000	F
3559	CSATBI	IRTTZKJGVZ	3879624057 Dell Way	\N	QDAKJXA	HI	75002	US	1	IRTTZKJGVZ@dell.com	3879624057	3	7575702594127507	2010/10	user3559	password	22	60000	F
3560	BHNKQE	DKEOULJTBN	2483563463 Dell Way	\N	UMXSNCL	TN	56070	US	1	DKEOULJTBN@dell.com	2483563463	2	3705732398666441	2009/10	user3560	password	75	40000	F
3561	ISSNWD	RKXCUREILQ	2216698314 Dell Way	\N	FEEIPZV	RI	32723	US	1	RKXCUREILQ@dell.com	2216698314	5	1518714484293013	2012/04	user3561	password	29	40000	F
3562	WTWAKH	XNBOSKAJPF	8451581149 Dell Way	\N	NYUNTOU	VT	60577	US	1	XNBOSKAJPF@dell.com	8451581149	5	8752665419131518	2012/01	user3562	password	81	100000	M
3563	SWFZUT	BJMMJVBOJA	4222006064 Dell Way	\N	JWUYQRM	MO	54946	US	1	BJMMJVBOJA@dell.com	4222006064	3	5991019565612078	2009/04	user3563	password	43	100000	F
3564	OYZIAI	UMSPOHZORV	1544371401 Dell Way	\N	IPMACZN	MI	47945	US	1	UMSPOHZORV@dell.com	1544371401	4	7736387064214797	2010/08	user3564	password	87	100000	M
3565	YHOGBA	ZRPGQDXLMN	1721018301 Dell Way	\N	YMPXZBI	AL	74362	US	1	ZRPGQDXLMN@dell.com	1721018301	3	3991889286320657	2008/06	user3565	password	83	100000	M
3566	LFTMFK	BLBFJNRXLD	6215296198 Dell Way	\N	MJDNREG	RI	64508	US	1	BLBFJNRXLD@dell.com	6215296198	5	1230948225129395	2010/10	user3566	password	71	100000	M
3567	MKEXMQ	YSALJXXNKG	4933726312 Dell Way	\N	QYYUESK	PA	57000	US	1	YSALJXXNKG@dell.com	4933726312	2	3548874284140766	2008/02	user3567	password	37	80000	M
3568	LOBCNU	DZDAWRLDIJ	6498073825 Dell Way	\N	CDOUOII	WV	58534	US	1	DZDAWRLDIJ@dell.com	6498073825	1	7255635279696435	2012/10	user3568	password	37	40000	F
3569	ILXCOW	GPTYAWGKYK	5406451489 Dell Way	\N	YTYGCXU	OH	16141	US	1	GPTYAWGKYK@dell.com	5406451489	3	8844554245471955	2011/11	user3569	password	35	20000	F
3570	DFXZMM	SKMPRXNCVH	9041775372 Dell Way	\N	ACJYXBA	MA	67012	US	1	SKMPRXNCVH@dell.com	9041775372	1	5829842914361507	2008/03	user3570	password	81	40000	F
3571	TGYFZI	SOAQCDLKDO	9930630879 Dell Way	\N	TCLVDVL	AL	96701	US	1	SOAQCDLKDO@dell.com	9930630879	1	2800486043095589	2012/06	user3571	password	65	80000	M
3572	OVRXOF	YFIBQSFFMI	6788222401 Dell Way	\N	RHLMTML	PA	67207	US	1	YFIBQSFFMI@dell.com	6788222401	4	1542728775180876	2009/03	user3572	password	72	100000	F
3573	KUQQSV	ZUMRASEIJM	9663869292 Dell Way	\N	UVFGHZX	WA	62464	US	1	ZUMRASEIJM@dell.com	9663869292	2	8302873413544149	2011/01	user3573	password	82	20000	M
3574	NTOJSJ	WKJOOSXAMT	6366414100 Dell Way	\N	GTAFQYU	NJ	24662	US	1	WKJOOSXAMT@dell.com	6366414100	2	3119903089478612	2010/06	user3574	password	24	20000	F
3575	QJWAGG	JUUBSVNMBH	8561305987 Dell Way	\N	MGYLAOP	NJ	88162	US	1	JUUBSVNMBH@dell.com	8561305987	1	3665169578045607	2012/02	user3575	password	51	60000	F
3576	IOTPYN	KZGFNSGVEM	5123246004 Dell Way	\N	TQNHGDE	AZ	33208	US	1	KZGFNSGVEM@dell.com	5123246004	1	4379212233237922	2012/07	user3576	password	81	40000	F
3577	PWBDGB	JLPBSKGFDX	5594730895 Dell Way	\N	SLDWPFD	AR	29067	US	1	JLPBSKGFDX@dell.com	5594730895	5	8046501979231835	2009/03	user3577	password	85	100000	F
3578	ADIBMU	QOMBVSESLQ	1505742785 Dell Way	\N	WHFBLGH	WI	31173	US	1	QOMBVSESLQ@dell.com	1505742785	2	5225408365949989	2012/04	user3578	password	58	100000	F
3579	XBXRSM	ETHWYAHOWP	7504590636 Dell Way	\N	TXAAFZG	IA	37807	US	1	ETHWYAHOWP@dell.com	7504590636	2	6595370864961297	2009/03	user3579	password	21	20000	F
3580	ZWZLAS	TXQTFFPUYN	7714837027 Dell Way	\N	VZSVFZD	WI	27932	US	1	TXQTFFPUYN@dell.com	7714837027	2	4750231787562370	2011/05	user3580	password	67	80000	F
3581	RFHJYE	ARJFHEEUAE	1892639084 Dell Way	\N	NVKMYIR	OH	61427	US	1	ARJFHEEUAE@dell.com	1892639084	3	9747789996210488	2011/04	user3581	password	34	60000	F
3582	NVKRVB	BBJGGDHKRC	7162381820 Dell Way	\N	UDBDVTS	WA	33620	US	1	BBJGGDHKRC@dell.com	7162381820	4	5725094555411488	2012/02	user3582	password	90	60000	M
3583	KCVMEW	VKDZROQUIU	4592991244 Dell Way	\N	WMQPFOW	UT	35102	US	1	VKDZROQUIU@dell.com	4592991244	4	4926635494455695	2009/03	user3583	password	47	80000	F
3584	FGMCBW	FAOTRJCLFP	4183373084 Dell Way	\N	CVUQSRX	CA	50404	US	1	FAOTRJCLFP@dell.com	4183373084	3	6833791615441442	2011/04	user3584	password	86	100000	F
3585	KBOHHO	WBGFERLTTG	3655170579 Dell Way	\N	NKYFIAQ	NY	56377	US	1	WBGFERLTTG@dell.com	3655170579	3	7962883086409421	2009/05	user3585	password	37	80000	F
3586	VYUKUW	QAAILUCRIM	9508095586 Dell Way	\N	QNVREME	MI	93166	US	1	QAAILUCRIM@dell.com	9508095586	4	4050516633782536	2009/05	user3586	password	78	20000	F
3587	QLBMBC	MKNGMFOZVB	5812891873 Dell Way	\N	UMFHQRF	NH	42973	US	1	MKNGMFOZVB@dell.com	5812891873	5	7326547236647458	2009/11	user3587	password	89	100000	F
3588	BLJDYT	QEGVTFRVZD	8198808644 Dell Way	\N	BGUSLKC	WY	28942	US	1	QEGVTFRVZD@dell.com	8198808644	2	1573316917289048	2011/04	user3588	password	43	100000	M
3589	SYSMPX	SLQXCMXGNE	7416766459 Dell Way	\N	BGQLJPQ	DC	96491	US	1	SLQXCMXGNE@dell.com	7416766459	5	3641231755260378	2008/09	user3589	password	23	80000	M
3590	UGHRYS	HWUUTBHYCO	4622162094 Dell Way	\N	ONXDEAC	VA	96311	US	1	HWUUTBHYCO@dell.com	4622162094	5	7318267588503659	2010/09	user3590	password	46	40000	M
3591	RXYJFV	EZPFHNHVBV	4701977916 Dell Way	\N	SFZTHWS	OH	83439	US	1	EZPFHNHVBV@dell.com	4701977916	1	5955370338167996	2012/06	user3591	password	57	60000	F
3592	MVOHZO	WFVJMRLHJQ	5533763701 Dell Way	\N	HDYDVQY	IA	83006	US	1	WFVJMRLHJQ@dell.com	5533763701	1	3133869636803865	2008/07	user3592	password	60	60000	F
3593	DVIRSN	NCAENHNDOR	7750231973 Dell Way	\N	BSMSRSN	DE	79071	US	1	NCAENHNDOR@dell.com	7750231973	2	3449281047098339	2009/09	user3593	password	62	60000	M
3594	YDGLQJ	LVWTJAIACA	3324354769 Dell Way	\N	MURFHVZ	AR	14318	US	1	LVWTJAIACA@dell.com	3324354769	2	8019614803604782	2012/10	user3594	password	42	80000	M
3595	PGPYSL	VLUVTUXUHR	2250825580 Dell Way	\N	MMZIMAJ	OR	44850	US	1	VLUVTUXUHR@dell.com	2250825580	4	2918936382979154	2010/05	user3595	password	30	20000	M
3596	UAIFVU	ZROUOIBGUO	8679583756 Dell Way	\N	GCAGMUQ	NJ	44478	US	1	ZROUOIBGUO@dell.com	8679583756	1	8028369823005051	2008/02	user3596	password	48	100000	F
3597	TAAOAS	CVHLWNGLUJ	4665261907 Dell Way	\N	MAVGRLQ	MT	57549	US	1	CVHLWNGLUJ@dell.com	4665261907	3	7251246267929674	2012/05	user3597	password	82	60000	F
3598	XDLQGG	XRDLXOFGAG	7688172861 Dell Way	\N	CGXNWKB	IL	96390	US	1	XRDLXOFGAG@dell.com	7688172861	1	3936687890905887	2011/09	user3598	password	71	60000	M
3599	EECKCT	NNRCTXCZZJ	6167297170 Dell Way	\N	WNGHONG	IN	67418	US	1	NNRCTXCZZJ@dell.com	6167297170	5	4128570806235075	2009/06	user3599	password	32	60000	M
3600	HWTAKH	RNAPPAPYWC	7128102699 Dell Way	\N	EERSKZI	WY	90778	US	1	RNAPPAPYWC@dell.com	7128102699	2	4461913525592536	2012/10	user3600	password	21	20000	M
3601	UEBCWO	DLEDBCADHE	1437762402 Dell Way	\N	UZPTIOR	WY	87454	US	1	DLEDBCADHE@dell.com	1437762402	5	6597455209586770	2008/01	user3601	password	37	100000	F
3602	IABXDN	BGOEGSLKNK	1382538246 Dell Way	\N	ZHTOYSK	AK	63174	US	1	BGOEGSLKNK@dell.com	1382538246	1	6516092867590488	2009/01	user3602	password	77	80000	F
3603	XNDKPJ	ZTQSFAGQAN	3566181711 Dell Way	\N	JPMCAMR	AR	63364	US	1	ZTQSFAGQAN@dell.com	3566181711	2	6450492484960706	2008/12	user3603	password	63	100000	M
3604	TKDDKX	TDCUJSUXBK	1673483707 Dell Way	\N	KEKWVLM	CO	80891	US	1	TDCUJSUXBK@dell.com	1673483707	2	8050918630324305	2011/03	user3604	password	41	60000	M
3605	LPAIIE	LCNDXLFHVJ	7191002244 Dell Way	\N	RSFDEIX	IA	57885	US	1	LCNDXLFHVJ@dell.com	7191002244	5	7673754227347673	2008/05	user3605	password	44	60000	M
3606	KUHOFK	CJHNOPIYHA	7536416027 Dell Way	\N	DKFLHLZ	WY	42738	US	1	CJHNOPIYHA@dell.com	7536416027	5	7691764644812793	2008/06	user3606	password	69	60000	F
3607	ZBLJDU	RQJHZHOAKY	7658792844 Dell Way	\N	FWGQWGZ	NE	32598	US	1	RQJHZHOAKY@dell.com	7658792844	4	7279268558602781	2010/02	user3607	password	85	60000	F
3608	JUIDMZ	MTYUIZFHEC	7657997820 Dell Way	\N	NUYUUNB	NC	27876	US	1	MTYUIZFHEC@dell.com	7657997820	5	4247236284427345	2011/05	user3608	password	59	20000	F
3609	XERWRL	VLTURAZTOT	7786334422 Dell Way	\N	RJOFKCK	CT	16948	US	1	VLTURAZTOT@dell.com	7786334422	4	5299171833787114	2009/10	user3609	password	67	40000	F
3610	JCRUYD	NSUOSNCMFL	7159222518 Dell Way	\N	AKWDUZF	NC	79919	US	1	NSUOSNCMFL@dell.com	7159222518	5	6437817203346640	2009/01	user3610	password	62	80000	F
3611	HNCLBV	FPNTSZYEAI	4441853045 Dell Way	\N	ADDAJRU	AR	57752	US	1	FPNTSZYEAI@dell.com	4441853045	3	6488516955170781	2012/02	user3611	password	75	40000	M
3612	XSRSYG	GRZGQDGYEK	9073335845 Dell Way	\N	CETTYUH	KS	28702	US	1	GRZGQDGYEK@dell.com	9073335845	2	3958373219706118	2011/08	user3612	password	87	60000	F
3613	QHGXNX	WTNAAMELPJ	5801325156 Dell Way	\N	EIHZQQF	MT	95244	US	1	WTNAAMELPJ@dell.com	5801325156	2	5967418150510640	2010/10	user3613	password	81	20000	F
3614	CAPAWI	OWJBBUQKZY	8453205424 Dell Way	\N	SZPIECH	OK	36663	US	1	OWJBBUQKZY@dell.com	8453205424	2	1566819953266531	2011/04	user3614	password	26	80000	F
3615	SVFAJB	KKDFAOEZGE	1124479761 Dell Way	\N	OOJRWBY	NY	35722	US	1	KKDFAOEZGE@dell.com	1124479761	2	6487635891418905	2008/03	user3615	password	86	100000	M
3616	DWJFGT	ILUXQUDUIS	2116674607 Dell Way	\N	DZOFYGN	WI	65794	US	1	ILUXQUDUIS@dell.com	2116674607	1	8131506115663797	2008/11	user3616	password	75	20000	M
3617	DKAXTL	RQCLTXUMBT	7289080209 Dell Way	\N	BHSHUQX	VT	74764	US	1	RQCLTXUMBT@dell.com	7289080209	5	6523733885958791	2010/03	user3617	password	44	80000	M
3618	JNIVFY	YQSVLEWFFD	8873921362 Dell Way	\N	XNYOKWG	CO	84405	US	1	YQSVLEWFFD@dell.com	8873921362	3	9955338747240604	2009/03	user3618	password	59	80000	M
3619	WLXVJO	NEASBFYFCL	8261563149 Dell Way	\N	DQWZXZV	RI	61045	US	1	NEASBFYFCL@dell.com	8261563149	1	7994978428818286	2009/08	user3619	password	54	40000	F
3620	KBLZPP	ZHREFWHRZY	8512597159 Dell Way	\N	NZVMUPB	NH	65755	US	1	ZHREFWHRZY@dell.com	8512597159	5	3185172688681632	2009/03	user3620	password	40	80000	F
3621	TTWJSE	AXJWFBWDOW	4948618405 Dell Way	\N	ZBROCGF	WI	31525	US	1	AXJWFBWDOW@dell.com	4948618405	2	5123007589485496	2011/01	user3621	password	71	60000	M
3622	PVMTVK	DSQEPTTMTU	1867455141 Dell Way	\N	DIXKNVQ	WI	20257	US	1	DSQEPTTMTU@dell.com	1867455141	4	2264262035489082	2012/03	user3622	password	84	60000	F
3623	KFVVIO	LNEFHQYBUG	1463753724 Dell Way	\N	YEUUVSX	VT	47734	US	1	LNEFHQYBUG@dell.com	1463753724	4	6339288627263159	2012/03	user3623	password	61	40000	F
3624	LETAPH	EVOVUPQAOU	5949093533 Dell Way	\N	VJPNGNY	KS	35157	US	1	EVOVUPQAOU@dell.com	5949093533	2	5235325121320784	2008/08	user3624	password	81	60000	M
3625	PPKWUG	KQAAGBOAWY	9311144087 Dell Way	\N	QKFEJNL	VT	81185	US	1	KQAAGBOAWY@dell.com	9311144087	1	4811111499089748	2011/08	user3625	password	34	40000	F
3626	QHAXRQ	XSWZHXVFOG	2196270388 Dell Way	\N	KSPXENS	CO	61947	US	1	XSWZHXVFOG@dell.com	2196270388	5	2986616697162390	2009/04	user3626	password	51	20000	M
3627	MXGDVY	AUFXQLLWVE	8073774672 Dell Way	\N	MTJZLLO	NE	40918	US	1	AUFXQLLWVE@dell.com	8073774672	5	6641795506700874	2009/12	user3627	password	31	80000	M
3628	KWRJWL	PTBAFYVKKO	2678472204 Dell Way	\N	TKAFYQO	PA	60792	US	1	PTBAFYVKKO@dell.com	2678472204	5	5702758070081473	2009/09	user3628	password	45	80000	M
3629	BDLNSF	PTLNOVYDPI	8805683140 Dell Way	\N	EVHUJBI	ND	13017	US	1	PTLNOVYDPI@dell.com	8805683140	5	7824161075986923	2009/09	user3629	password	42	40000	M
3630	UVPZKI	LYXGWAWFFR	4067831391 Dell Way	\N	NZBOIQP	FL	59065	US	1	LYXGWAWFFR@dell.com	4067831391	3	3361622856464237	2011/09	user3630	password	27	60000	M
3631	SLZBWY	YDVZAAERND	2515592664 Dell Way	\N	TCMJRQX	AK	17883	US	1	YDVZAAERND@dell.com	2515592664	4	8494585396721960	2009/02	user3631	password	47	20000	M
3632	KCMIAQ	DAQEEISICU	4344999467 Dell Way	\N	ULLLJLO	MT	23452	US	1	DAQEEISICU@dell.com	4344999467	5	3742265422362834	2011/11	user3632	password	84	20000	M
3633	KMZBPZ	STEBLNDGHO	6363544086 Dell Way	\N	RTYDHLH	NV	33895	US	1	STEBLNDGHO@dell.com	6363544086	3	1999289004132151	2010/08	user3633	password	21	100000	F
3634	AZRZRL	ESXRVDZKVS	2450480410 Dell Way	\N	IYAUGRB	TN	20482	US	1	ESXRVDZKVS@dell.com	2450480410	2	7437418739311398	2009/04	user3634	password	75	40000	F
3635	MFXXJQ	UAMYZWTSFS	2924016189 Dell Way	\N	SAYJBUM	HI	23013	US	1	UAMYZWTSFS@dell.com	2924016189	3	4782709143590182	2008/08	user3635	password	66	60000	M
3636	PJEFEE	RDEOWWUOOU	8852969286 Dell Way	\N	NYWHLBL	NV	54703	US	1	RDEOWWUOOU@dell.com	8852969286	4	2135742599144578	2010/02	user3636	password	87	20000	M
3637	DISIAV	MPRIKGXFUW	7791325976 Dell Way	\N	BCHDNYQ	MD	64561	US	1	MPRIKGXFUW@dell.com	7791325976	5	7649215937592090	2011/01	user3637	password	36	100000	F
3638	YELUQB	LZLSXQMTSO	3839451351 Dell Way	\N	AVCZLNO	GA	50969	US	1	LZLSXQMTSO@dell.com	3839451351	5	5734396665822715	2010/10	user3638	password	86	60000	M
3639	JHOLTN	WMKNZEFNEA	2160332156 Dell Way	\N	QDMDSSP	AR	65240	US	1	WMKNZEFNEA@dell.com	2160332156	4	4301989600062370	2008/02	user3639	password	38	60000	F
3640	VWEJTR	UGQYMDCMUG	6977149581 Dell Way	\N	ZYZROAH	NY	67410	US	1	UGQYMDCMUG@dell.com	6977149581	4	7925921294838191	2012/03	user3640	password	32	80000	F
3641	JDVAXC	RVOVYBPFAO	6792565991 Dell Way	\N	FSCGATW	NY	54345	US	1	RVOVYBPFAO@dell.com	6792565991	4	7143772294279189	2012/05	user3641	password	72	40000	M
3642	OGLQXG	FSFGILHWRZ	8922183790 Dell Way	\N	YXASTRF	MD	36332	US	1	FSFGILHWRZ@dell.com	8922183790	2	7094640360679478	2011/06	user3642	password	31	40000	M
3643	PWQWBJ	CHSOOOFONC	2852834138 Dell Way	\N	OFWGKHN	IN	57486	US	1	CHSOOOFONC@dell.com	2852834138	5	9983876612968744	2009/02	user3643	password	71	20000	M
3644	JXBTAI	LOXAUMNWAT	5950754801 Dell Way	\N	THEAULO	AK	45273	US	1	LOXAUMNWAT@dell.com	5950754801	3	5747139153536410	2009/05	user3644	password	55	80000	F
3645	OKIXVW	VVQHJNICGP	6698795578 Dell Way	\N	GHKSVKC	MD	81957	US	1	VVQHJNICGP@dell.com	6698795578	4	2901792524382472	2008/04	user3645	password	55	80000	M
3646	VQNSLJ	ITSWBVDRBK	5164562240 Dell Way	\N	BUGLWRG	MT	39447	US	1	ITSWBVDRBK@dell.com	5164562240	4	6813637161627412	2012/05	user3646	password	43	100000	F
3647	XNLGVE	ZSGUVXVGYQ	2341136065 Dell Way	\N	NKNERAN	CT	71855	US	1	ZSGUVXVGYQ@dell.com	2341136065	1	1637919886969030	2010/11	user3647	password	23	40000	F
3648	NQGSQZ	YKUWGBVWOF	2325865360 Dell Way	\N	JTWKGAB	MD	19948	US	1	YKUWGBVWOF@dell.com	2325865360	5	1178839550819247	2009/04	user3648	password	49	80000	M
3649	RLOQKZ	LGFNCBCHLV	3950333784 Dell Way	\N	EVCFXMI	AR	44863	US	1	LGFNCBCHLV@dell.com	3950333784	2	7153734940569849	2011/01	user3649	password	63	60000	F
3650	ECXDOE	JBGLDOWZTS	6459968691 Dell Way	\N	BYPNGRX	NE	95336	US	1	JBGLDOWZTS@dell.com	6459968691	2	9784053038805724	2009/10	user3650	password	51	60000	M
3651	JOLNYN	TJQHGQBYRZ	2370742992 Dell Way	\N	OFFFDUE	OR	21688	US	1	TJQHGQBYRZ@dell.com	2370742992	5	9210450730286540	2011/05	user3651	password	76	100000	M
3652	GMXTGG	KONAPLROAW	6776903818 Dell Way	\N	UGAPKTS	ND	73134	US	1	KONAPLROAW@dell.com	6776903818	1	1826194099616259	2010/02	user3652	password	22	80000	M
3653	YKWFVK	SVAEMPEJKL	8973395857 Dell Way	\N	JZVCSKU	LA	62772	US	1	SVAEMPEJKL@dell.com	8973395857	5	7591544726397843	2012/06	user3653	password	44	100000	M
3654	FDSQWN	RAAGFJQQSQ	2866461088 Dell Way	\N	MVIXPSM	MS	55751	US	1	RAAGFJQQSQ@dell.com	2866461088	3	9899084748234600	2010/05	user3654	password	83	80000	F
3655	PLHDCI	DJOMZEFQRA	2497874440 Dell Way	\N	ZOQRADE	IA	60470	US	1	DJOMZEFQRA@dell.com	2497874440	5	9071150125470012	2008/08	user3655	password	43	80000	F
3656	RUEZXN	OKNTQDKQCZ	8692975367 Dell Way	\N	HTAKYGY	CA	15024	US	1	OKNTQDKQCZ@dell.com	8692975367	1	6983000011183322	2009/10	user3656	password	70	100000	M
3657	WWNKKX	XDNAOECNLV	5395476401 Dell Way	\N	NVTTUWV	NV	10352	US	1	XDNAOECNLV@dell.com	5395476401	5	8315796263050289	2009/09	user3657	password	47	20000	M
3658	XMAVJE	JJSNMFYHTU	7604996071 Dell Way	\N	BNPXIGX	TN	18635	US	1	JJSNMFYHTU@dell.com	7604996071	1	8437342890538276	2008/02	user3658	password	48	20000	M
3659	LWZPFJ	HTVNRDHMEU	3041090170 Dell Way	\N	BCDHAZK	PA	11479	US	1	HTVNRDHMEU@dell.com	3041090170	5	2289524328894913	2011/12	user3659	password	72	20000	M
3660	SRABZT	XMLAUYEPAH	8719053413 Dell Way	\N	SIHSSBS	WA	95163	US	1	XMLAUYEPAH@dell.com	8719053413	3	8995802381541581	2011/09	user3660	password	69	40000	F
3661	TKINHV	YHPXMEXTXF	9586287599 Dell Way	\N	BPXDHWB	DC	50209	US	1	YHPXMEXTXF@dell.com	9586287599	4	2057304602582007	2011/02	user3661	password	51	40000	F
3662	UXUPWB	ETOIQHFWJU	2905703063 Dell Way	\N	UMCQOGC	MT	11275	US	1	ETOIQHFWJU@dell.com	2905703063	1	1910200056154281	2011/07	user3662	password	60	60000	F
3663	JAHLFB	ZNSHTPQOJD	1080169471 Dell Way	\N	QARXCFX	KS	43198	US	1	ZNSHTPQOJD@dell.com	1080169471	5	9344896159600468	2010/06	user3663	password	45	100000	F
3664	RJQTIE	LQXAGMKKCK	6315888767 Dell Way	\N	CZNHXVR	VT	85340	US	1	LQXAGMKKCK@dell.com	6315888767	3	3453384487424046	2012/06	user3664	password	71	80000	M
3665	KKEOWU	MXBYHMBSOB	2819664881 Dell Way	\N	GWYCNWY	CO	43201	US	1	MXBYHMBSOB@dell.com	2819664881	1	8477563331369311	2012/09	user3665	password	66	40000	F
3666	WXARJX	SIFFJYTKEP	4821412682 Dell Way	\N	JHDFFGP	MD	38924	US	1	SIFFJYTKEP@dell.com	4821412682	2	1543705313000828	2008/08	user3666	password	32	100000	M
3667	FPYDIG	INPGHALXKS	6921441931 Dell Way	\N	AQYHFIP	NM	70337	US	1	INPGHALXKS@dell.com	6921441931	4	4002557818777859	2012/09	user3667	password	82	20000	F
3668	VFQBNE	RULSGJCZKS	2998085781 Dell Way	\N	XRXFGOX	WA	35978	US	1	RULSGJCZKS@dell.com	2998085781	4	9736591270659120	2008/11	user3668	password	37	100000	F
3669	XZPBQJ	NIQWLPGDMY	8827921368 Dell Way	\N	BRFPPDX	SC	92168	US	1	NIQWLPGDMY@dell.com	8827921368	5	7974862670060248	2008/10	user3669	password	78	20000	M
3670	KCLUPT	KLEASIMRJE	7020461712 Dell Way	\N	WZTZWOX	PA	51184	US	1	KLEASIMRJE@dell.com	7020461712	5	3533795399591327	2010/11	user3670	password	23	100000	M
3671	NSPGDB	LDTUPKDUHD	8276826615 Dell Way	\N	NGABDTN	SD	68074	US	1	LDTUPKDUHD@dell.com	8276826615	2	5988480439875275	2012/03	user3671	password	57	40000	M
3672	DQCECF	YWVJAPQDCW	2034149574 Dell Way	\N	EEAXSWO	MT	25042	US	1	YWVJAPQDCW@dell.com	2034149574	2	4631333715748042	2011/10	user3672	password	43	80000	F
3673	LYNQWK	LFLAWODSSI	2571890437 Dell Way	\N	TQAPFOU	KS	94109	US	1	LFLAWODSSI@dell.com	2571890437	5	7437748676165939	2010/10	user3673	password	28	100000	M
3674	RPPCBV	NCRCFKVODL	7887541985 Dell Way	\N	OTRDNZB	OH	96024	US	1	NCRCFKVODL@dell.com	7887541985	2	7437775431200863	2012/03	user3674	password	48	60000	M
3675	ARVVFX	MHDWCRAOGT	8927028857 Dell Way	\N	FJHFKZE	DE	26409	US	1	MHDWCRAOGT@dell.com	8927028857	1	4212395856156945	2009/09	user3675	password	27	40000	F
3676	YDOVPW	YMZPMNWFTF	1024404434 Dell Way	\N	NZQMDUQ	AL	88970	US	1	YMZPMNWFTF@dell.com	1024404434	2	6015656694769860	2008/08	user3676	password	85	20000	M
3677	MXJJVW	ILIWHOQMBP	4068402999 Dell Way	\N	CNTXETU	DE	18013	US	1	ILIWHOQMBP@dell.com	4068402999	2	7549585283733905	2009/05	user3677	password	54	80000	F
3678	WCBSKM	BGUPXHQMKE	8231831294 Dell Way	\N	FHIZCMB	ME	80583	US	1	BGUPXHQMKE@dell.com	8231831294	4	2223759836982935	2009/06	user3678	password	45	20000	M
3679	LXYYYF	SNCZEPKIVS	1765354063 Dell Way	\N	RUUEWFY	OH	90901	US	1	SNCZEPKIVS@dell.com	1765354063	5	4054105421062559	2010/02	user3679	password	82	100000	F
3680	VVZBON	EOSTYBPQSK	8796113324 Dell Way	\N	KWHQVYN	VT	95289	US	1	EOSTYBPQSK@dell.com	8796113324	2	1966124482918530	2011/04	user3680	password	29	60000	F
3681	DQQRUE	JOCKDTCNEZ	8419665892 Dell Way	\N	VUVUISS	FL	18701	US	1	JOCKDTCNEZ@dell.com	8419665892	5	4223500004503876	2012/07	user3681	password	50	20000	F
3682	BUYGDN	JOQCREHQZB	6849290923 Dell Way	\N	MTKFMPH	IN	55869	US	1	JOQCREHQZB@dell.com	6849290923	2	1173168480861932	2008/05	user3682	password	29	20000	F
3683	CKJPUX	GXOLEFLGRE	7636444867 Dell Way	\N	QWRFEZS	SD	32576	US	1	GXOLEFLGRE@dell.com	7636444867	5	6986630121245981	2012/02	user3683	password	81	20000	M
3684	FPHDWE	SHJXSPPXGM	5112784089 Dell Way	\N	OLROEMU	VA	46402	US	1	SHJXSPPXGM@dell.com	5112784089	4	5452087704557926	2009/10	user3684	password	18	60000	F
3685	HRGMKO	WIHLXFRKUD	5115434824 Dell Way	\N	BIHOCEZ	ND	97750	US	1	WIHLXFRKUD@dell.com	5115434824	5	7950264118611813	2010/06	user3685	password	31	80000	F
3686	LGNACV	HOTNGEHJGP	6366896818 Dell Way	\N	RUSWTHV	HI	26001	US	1	HOTNGEHJGP@dell.com	6366896818	4	6665087822359056	2011/06	user3686	password	74	40000	M
3687	HGVDOK	XBRCIBIYSD	7663394572 Dell Way	\N	QOXYKDC	WY	84984	US	1	XBRCIBIYSD@dell.com	7663394572	4	3615548308938742	2010/12	user3687	password	18	100000	F
3688	VZTGWU	XZDYIBRMSF	6823120430 Dell Way	\N	JRQNTPJ	MS	42221	US	1	XZDYIBRMSF@dell.com	6823120430	1	4038846585433930	2011/11	user3688	password	58	60000	M
3689	HTRCQR	GPZIHLANVS	4726341305 Dell Way	\N	DILSSZB	KY	98721	US	1	GPZIHLANVS@dell.com	4726341305	1	8376676003914327	2012/06	user3689	password	63	40000	F
3690	HJXYQN	YYUJZHERKN	9186281038 Dell Way	\N	DCFCEOC	NH	61458	US	1	YYUJZHERKN@dell.com	9186281038	3	1635200919117778	2010/11	user3690	password	40	100000	F
3691	FUWSSU	MCUTHLEVPG	3239903528 Dell Way	\N	ASLPUBE	OH	66300	US	1	MCUTHLEVPG@dell.com	3239903528	2	5214574420824647	2010/01	user3691	password	68	80000	M
3692	OMOJZR	DSYPXTEDUW	7799807753 Dell Way	\N	PKRROJH	SD	62132	US	1	DSYPXTEDUW@dell.com	7799807753	2	6711631998419762	2010/02	user3692	password	52	100000	M
3693	BIPSMI	QBFJFJECZO	3914839756 Dell Way	\N	TQDCYYR	NY	37852	US	1	QBFJFJECZO@dell.com	3914839756	1	5142399214673788	2012/02	user3693	password	25	100000	F
3694	SOYBEZ	GOFQTIPHCG	1990838360 Dell Way	\N	KEEIWWQ	GA	99154	US	1	GOFQTIPHCG@dell.com	1990838360	1	2088535787537694	2009/11	user3694	password	61	100000	F
3695	OYPOFE	TVXCLFESPJ	8659333153 Dell Way	\N	WYGTPLS	OH	49403	US	1	TVXCLFESPJ@dell.com	8659333153	5	3611253216397017	2010/10	user3695	password	68	100000	M
3696	HNZLHV	JJHOOZDXWC	3603756161 Dell Way	\N	DPROIJZ	DE	36323	US	1	JJHOOZDXWC@dell.com	3603756161	4	1986819942481815	2012/08	user3696	password	81	40000	F
3697	WSLRBU	YPJXTGTWJJ	3833789405 Dell Way	\N	NYRXYWF	HI	53898	US	1	YPJXTGTWJJ@dell.com	3833789405	2	1892524608876556	2008/06	user3697	password	35	20000	F
3698	RSGMQW	VOQBIMLRZJ	8416919553 Dell Way	\N	JXIGCOS	ME	77656	US	1	VOQBIMLRZJ@dell.com	8416919553	4	3015037002507597	2008/08	user3698	password	47	80000	F
3699	RFANAO	DCWPOOPYYN	7992398520 Dell Way	\N	GEQUXBO	OK	70384	US	1	DCWPOOPYYN@dell.com	7992398520	4	3947414434514940	2008/07	user3699	password	68	100000	M
3700	SJTGNW	DDKRSIQGPU	9231588561 Dell Way	\N	WKSXYKP	OR	28533	US	1	DDKRSIQGPU@dell.com	9231588561	5	7479276094585658	2011/10	user3700	password	50	40000	F
3701	EOQBRU	LJMUZTKUPU	8591661590 Dell Way	\N	MNTXCMD	AK	44694	US	1	LJMUZTKUPU@dell.com	8591661590	4	2346653608139604	2009/11	user3701	password	38	60000	F
3702	YNDSZN	FTMYDHNYUB	7068281018 Dell Way	\N	RSDDVEN	NY	80017	US	1	FTMYDHNYUB@dell.com	7068281018	5	7234653925988824	2012/06	user3702	password	29	100000	M
3703	HPXUUR	HSUPGTJHKC	1694527166 Dell Way	\N	LOXPBPJ	OR	58935	US	1	HSUPGTJHKC@dell.com	1694527166	4	9754573784768582	2009/08	user3703	password	84	60000	F
3704	VIZMPS	HEZAOHKQSZ	6856718966 Dell Way	\N	OIADSTR	SC	52009	US	1	HEZAOHKQSZ@dell.com	6856718966	1	1519674974959343	2010/07	user3704	password	35	40000	M
3705	FWLYEQ	XEEEPVXOJF	8943060047 Dell Way	\N	PNYJESV	TN	75585	US	1	XEEEPVXOJF@dell.com	8943060047	3	3387408717069775	2008/10	user3705	password	26	40000	M
3706	OHVEEA	JJPFGEOMTB	1913087144 Dell Way	\N	KDGCYCV	TN	53997	US	1	JJPFGEOMTB@dell.com	1913087144	5	3516910600475967	2009/04	user3706	password	86	80000	M
3707	UZUUID	JOKOCWIEGL	3658562274 Dell Way	\N	LJJNFFA	IN	23401	US	1	JOKOCWIEGL@dell.com	3658562274	3	5066929593682289	2009/04	user3707	password	20	20000	F
3708	VUPYED	JSGFBLMMWV	6755407581 Dell Way	\N	VKABKIE	OK	87294	US	1	JSGFBLMMWV@dell.com	6755407581	5	2359699759632349	2011/12	user3708	password	47	60000	M
3709	ALXDUQ	KARVMESIZC	7391320782 Dell Way	\N	JANSFFO	TX	25135	US	1	KARVMESIZC@dell.com	7391320782	3	2157387397252023	2008/01	user3709	password	82	20000	F
3710	UHHLRI	DNUHFDHHMI	3935580733 Dell Way	\N	VEOATKF	MI	95447	US	1	DNUHFDHHMI@dell.com	3935580733	3	9907724700868132	2009/09	user3710	password	53	20000	M
3711	ULQCPD	XWIAEQMMLR	4373580486 Dell Way	\N	AMKLRWK	AK	48781	US	1	XWIAEQMMLR@dell.com	4373580486	2	2126192225143313	2012/03	user3711	password	24	80000	M
3712	TTGWQD	FQHWDUIVUU	6894529995 Dell Way	\N	GGMCQMN	WY	72563	US	1	FQHWDUIVUU@dell.com	6894529995	5	9184791105333716	2011/07	user3712	password	60	60000	F
3713	VJWYPN	GLRATMVOSB	2118778192 Dell Way	\N	AVSNJSF	AK	59698	US	1	GLRATMVOSB@dell.com	2118778192	4	1482284914236515	2011/03	user3713	password	39	60000	M
3714	EMESTQ	JTJWPYPQZK	6801630814 Dell Way	\N	IMTBSUP	TN	58458	US	1	JTJWPYPQZK@dell.com	6801630814	3	8034356350079180	2012/01	user3714	password	46	20000	M
3715	OUHEEA	OAQNPHMAQZ	8885554144 Dell Way	\N	URROGNC	VA	13560	US	1	OAQNPHMAQZ@dell.com	8885554144	5	1887359596323222	2009/12	user3715	password	64	100000	M
3716	XAXYPX	OCNVONLOHD	8765462783 Dell Way	\N	FWJSYGT	TN	17807	US	1	OCNVONLOHD@dell.com	8765462783	1	1207754530943930	2010/12	user3716	password	73	60000	M
3717	RJNOYP	CUEPGSXJYU	1934829922 Dell Way	\N	TQTZKOC	IL	69616	US	1	CUEPGSXJYU@dell.com	1934829922	4	6220413614064456	2012/03	user3717	password	55	60000	M
3718	ACNQEI	UUPNSYLMSC	1371330179 Dell Way	\N	FRNUUUL	UT	60674	US	1	UUPNSYLMSC@dell.com	1371330179	4	7941458669491113	2010/04	user3718	password	44	60000	F
3719	XFNFAI	VNAUYNMBTE	6891532019 Dell Way	\N	ONYIZVW	AR	59268	US	1	VNAUYNMBTE@dell.com	6891532019	3	8227879888843746	2008/03	user3719	password	28	100000	F
3720	RDJZYX	ZSWNEXGJLU	5021360082 Dell Way	\N	HTUCQVQ	IL	47195	US	1	ZSWNEXGJLU@dell.com	5021360082	2	6252349905669690	2010/03	user3720	password	88	40000	F
3721	IGHGGA	CTFZZOKTVE	4236980950 Dell Way	\N	OYUJPCU	AL	43956	US	1	CTFZZOKTVE@dell.com	4236980950	4	6263210685458035	2009/11	user3721	password	85	80000	F
3722	FXJFZC	LZBZJVVNJT	4306783579 Dell Way	\N	ITJKNJU	UT	10198	US	1	LZBZJVVNJT@dell.com	4306783579	1	8976423982996494	2009/11	user3722	password	18	60000	M
3723	JTTLES	NDCIZQSTZL	4278832283 Dell Way	\N	CJZMEVM	MT	12344	US	1	NDCIZQSTZL@dell.com	4278832283	5	8908131764736027	2009/04	user3723	password	64	80000	F
3724	JEGCSJ	FBJVTCVFFE	9241544674 Dell Way	\N	ERIAEWA	MT	70498	US	1	FBJVTCVFFE@dell.com	9241544674	5	9985579434316606	2010/08	user3724	password	22	100000	M
3725	HAMRGO	BCHEXNJBRB	9382080633 Dell Way	\N	KSFGSTY	NM	67448	US	1	BCHEXNJBRB@dell.com	9382080633	1	3404554273001850	2012/02	user3725	password	23	40000	F
3726	OZKCAM	KEJXNLPOVH	4870627198 Dell Way	\N	UCANBRE	WV	87568	US	1	KEJXNLPOVH@dell.com	4870627198	5	9906632040161640	2010/04	user3726	password	29	20000	F
3727	OEFAPJ	KNXWCMSKGU	9394019493 Dell Way	\N	KUVCYVY	MA	79542	US	1	KNXWCMSKGU@dell.com	9394019493	5	1212096289731562	2008/12	user3727	password	35	80000	F
3728	LRTVCG	TYJFQTMKEH	8778460902 Dell Way	\N	GGFBFPV	CT	54753	US	1	TYJFQTMKEH@dell.com	8778460902	2	5127151212655008	2008/11	user3728	password	62	60000	M
3729	JKPPDN	ZJDSWOWDVD	9531277030 Dell Way	\N	JXIZTLM	NH	69438	US	1	ZJDSWOWDVD@dell.com	9531277030	4	5579540983773768	2010/04	user3729	password	20	100000	M
3730	QNVEMF	IECXBFSFPQ	2349355430 Dell Way	\N	NPJZCZQ	AL	71485	US	1	IECXBFSFPQ@dell.com	2349355430	3	9595784978475424	2008/06	user3730	password	64	100000	F
3731	LZMRHR	TETZXYPOME	5699150859 Dell Way	\N	XLGWCHO	IA	90704	US	1	TETZXYPOME@dell.com	5699150859	3	4557236036285758	2008/03	user3731	password	47	80000	F
3732	XHNOAS	HAQGPESTCE	6679370224 Dell Way	\N	AZHINNG	AR	96923	US	1	HAQGPESTCE@dell.com	6679370224	2	2903640872333199	2008/10	user3732	password	49	100000	F
3733	ZMDRUD	HASMTMOYNN	9464430476 Dell Way	\N	FWBTCCS	OR	38805	US	1	HASMTMOYNN@dell.com	9464430476	4	2285696720238775	2009/09	user3733	password	36	40000	F
3734	KAYNIZ	GUTTJRHXXD	5649026504 Dell Way	\N	YRGBKZJ	KY	76140	US	1	GUTTJRHXXD@dell.com	5649026504	4	4826297596562654	2011/01	user3734	password	61	20000	F
3735	ORKNYF	HROYYLWCKO	4975976866 Dell Way	\N	ILYHVHA	KS	11046	US	1	HROYYLWCKO@dell.com	4975976866	1	1658270611427724	2008/03	user3735	password	28	60000	M
3736	ODWTKN	IJMTFODTWP	1701495998 Dell Way	\N	SDKZESA	NH	83624	US	1	IJMTFODTWP@dell.com	1701495998	4	1581391179468482	2009/03	user3736	password	90	80000	F
3737	VNTJVC	VPHKSBGITK	3764484200 Dell Way	\N	STOLTEG	TN	82610	US	1	VPHKSBGITK@dell.com	3764484200	1	1321500498335808	2009/11	user3737	password	46	20000	F
3738	DNFFIU	NTNPZVIKOC	9599815010 Dell Way	\N	YZWCFSX	MT	80057	US	1	NTNPZVIKOC@dell.com	9599815010	5	6640920544974507	2009/12	user3738	password	18	60000	F
3739	FRUAFO	OUNKDXYFWX	2812038162 Dell Way	\N	CZDUXQO	TX	52277	US	1	OUNKDXYFWX@dell.com	2812038162	1	4810675795190036	2009/08	user3739	password	82	60000	F
3740	RLNGAH	TKKRJQOHSN	9539631222 Dell Way	\N	KNKBCHN	IN	52201	US	1	TKKRJQOHSN@dell.com	9539631222	3	2134878005832433	2012/12	user3740	password	51	60000	F
3741	ZTJHNU	SFDITKBGUP	5962915480 Dell Way	\N	RWRYJZL	KS	53502	US	1	SFDITKBGUP@dell.com	5962915480	1	4664841216057539	2008/09	user3741	password	74	100000	F
3742	DHYXZD	AIWLKDFZVB	5858133677 Dell Way	\N	RULQFTD	PA	93058	US	1	AIWLKDFZVB@dell.com	5858133677	4	6400963173713536	2009/10	user3742	password	20	60000	F
3743	ZJACKJ	ZVTDBTYDKS	8739568121 Dell Way	\N	OBXIEQG	OR	45944	US	1	ZVTDBTYDKS@dell.com	8739568121	1	2399199989624321	2012/07	user3743	password	32	100000	M
3744	FZHPYD	IBEBAHMSWN	8124902827 Dell Way	\N	PFSGMLQ	KS	54587	US	1	IBEBAHMSWN@dell.com	8124902827	2	9963471582159400	2012/01	user3744	password	81	40000	F
3745	DUAGDC	LFCTSUPFJV	9102869707 Dell Way	\N	YQHKGPX	AR	84210	US	1	LFCTSUPFJV@dell.com	9102869707	1	9138149736914784	2011/03	user3745	password	87	100000	F
3746	ZEEBQK	DJCXZIHUGX	4786444086 Dell Way	\N	CRERPFN	MO	32669	US	1	DJCXZIHUGX@dell.com	4786444086	2	5484735678415746	2009/03	user3746	password	57	40000	F
3747	SKZCNJ	ELJNTDURGL	8357439741 Dell Way	\N	WYABLNI	TX	78482	US	1	ELJNTDURGL@dell.com	8357439741	2	9391637691762300	2009/08	user3747	password	39	20000	M
3748	HENQJZ	ZWSDQKJCGH	3923774718 Dell Way	\N	DITQQPK	MN	85450	US	1	ZWSDQKJCGH@dell.com	3923774718	5	4816893847193569	2011/11	user3748	password	47	100000	F
3749	YOLXOI	QRZABBHJFP	9689353961 Dell Way	\N	CVGSFSO	NC	55772	US	1	QRZABBHJFP@dell.com	9689353961	1	4616169427987188	2009/01	user3749	password	53	40000	M
3750	YFEGVW	GVXIDHNSJI	6090733346 Dell Way	\N	ZCORQCE	NH	33651	US	1	GVXIDHNSJI@dell.com	6090733346	5	3928814794402570	2008/04	user3750	password	86	100000	F
3751	CGHYMD	WVGDIZNRYP	9285320219 Dell Way	\N	FPGITVP	KS	82079	US	1	WVGDIZNRYP@dell.com	9285320219	2	1591942444909364	2012/05	user3751	password	56	100000	M
3752	UXCYTX	EXGDLXCBDR	9837006491 Dell Way	\N	HMLCBTX	WY	19825	US	1	EXGDLXCBDR@dell.com	9837006491	5	5118700401857496	2010/10	user3752	password	22	40000	M
3753	DGMBKJ	IOVGQWJIDW	1379494789 Dell Way	\N	TGYMEYP	DC	80980	US	1	IOVGQWJIDW@dell.com	1379494789	4	6395195280201734	2008/12	user3753	password	40	40000	F
3754	UIPEQE	ZWUVGCYCVF	4298816458 Dell Way	\N	BIJZXNT	WA	24165	US	1	ZWUVGCYCVF@dell.com	4298816458	1	2055910222698003	2011/04	user3754	password	40	60000	M
3755	XQGBPC	WLJZKMVPND	7571138957 Dell Way	\N	YMALGYP	NJ	99492	US	1	WLJZKMVPND@dell.com	7571138957	2	3555868420749903	2008/10	user3755	password	83	100000	F
3756	DAAGXL	PWVBRKPVJB	1630639722 Dell Way	\N	VVIULYU	DC	33023	US	1	PWVBRKPVJB@dell.com	1630639722	1	1204707922879606	2012/02	user3756	password	48	20000	F
3757	LJCWZZ	RARCQMLSIG	3349733244 Dell Way	\N	ACRZXVG	WV	12969	US	1	RARCQMLSIG@dell.com	3349733244	5	2686813547275960	2011/01	user3757	password	45	20000	F
3758	MZILRJ	CTAPFSXLSA	2713677743 Dell Way	\N	DSXZYWA	GA	80822	US	1	CTAPFSXLSA@dell.com	2713677743	5	8350251031573863	2010/01	user3758	password	32	20000	M
3759	OMQYPJ	YEOQBAJBDB	4861894483 Dell Way	\N	ZDAVDFP	KS	20642	US	1	YEOQBAJBDB@dell.com	4861894483	5	2079532487783581	2011/11	user3759	password	24	20000	F
3760	SCZCAD	RRERAGVCFZ	6058518055 Dell Way	\N	CBCIRKL	CA	35802	US	1	RRERAGVCFZ@dell.com	6058518055	4	2812188814394176	2011/11	user3760	password	60	40000	M
3761	OMARDR	WVSDRUJQWK	6492470527 Dell Way	\N	SFBDQDK	GA	87373	US	1	WVSDRUJQWK@dell.com	6492470527	5	7758095803670586	2008/03	user3761	password	72	80000	M
3762	TLWLHR	DLJXUZUESZ	9805408455 Dell Way	\N	FVQJFVF	TN	70569	US	1	DLJXUZUESZ@dell.com	9805408455	1	9166226673405618	2011/10	user3762	password	63	60000	F
3763	MXNDBY	MZTMTXESDZ	7596916197 Dell Way	\N	IMFDSBV	OH	17134	US	1	MZTMTXESDZ@dell.com	7596916197	3	8797599821351469	2009/11	user3763	password	24	100000	M
3764	PZWOMV	HYPFCIICQV	3645487742 Dell Way	\N	HUOJQGL	LA	70149	US	1	HYPFCIICQV@dell.com	3645487742	4	6153174980077893	2009/07	user3764	password	47	100000	F
3765	HOZDWX	SBAAJCRFKM	3079895938 Dell Way	\N	TTCZELR	MO	23029	US	1	SBAAJCRFKM@dell.com	3079895938	5	7037370030768216	2011/11	user3765	password	30	100000	F
3766	DAGATI	BUSELXPXQI	3135019466 Dell Way	\N	ZQNKHAO	MT	88899	US	1	BUSELXPXQI@dell.com	3135019466	1	7599836750421674	2010/01	user3766	password	28	60000	F
3767	KOWTQQ	LUBIJYYSYP	8746128377 Dell Way	\N	GJWGYKD	DE	58301	US	1	LUBIJYYSYP@dell.com	8746128377	3	6361253463197500	2008/02	user3767	password	68	60000	M
3768	NDHEPC	FXMEWECLKL	8530963732 Dell Way	\N	IRJSUOG	NV	19963	US	1	FXMEWECLKL@dell.com	8530963732	4	2916358633432537	2010/01	user3768	password	82	20000	F
3769	FFVHLS	TPOYSAJEIA	4696520053 Dell Way	\N	OAUCHLF	CO	20771	US	1	TPOYSAJEIA@dell.com	4696520053	4	2822275751736015	2009/09	user3769	password	50	60000	M
3770	GUJZOZ	OMROVVXVJY	4788841398 Dell Way	\N	QLFCQIF	AZ	97676	US	1	OMROVVXVJY@dell.com	4788841398	2	7165256951935590	2012/11	user3770	password	63	20000	M
3771	ZCEYQR	QFMLCIVAYH	3083293337 Dell Way	\N	GBYOHZO	OH	41865	US	1	QFMLCIVAYH@dell.com	3083293337	3	2909739167895168	2012/09	user3771	password	80	100000	M
3772	AUKSKP	EWRMRSLYYM	4844435066 Dell Way	\N	WNUWBMF	IL	11682	US	1	EWRMRSLYYM@dell.com	4844435066	1	7175391791854054	2009/12	user3772	password	50	40000	M
3773	VAEKEB	BRSUDRSQNG	6148592438 Dell Way	\N	KKHWPPX	AL	76161	US	1	BRSUDRSQNG@dell.com	6148592438	2	7440623719245196	2008/08	user3773	password	53	100000	M
3774	RGVSIN	LCRCVHQBRA	4518948927 Dell Way	\N	JOQYLQR	AK	97206	US	1	LCRCVHQBRA@dell.com	4518948927	1	6449004701338709	2012/11	user3774	password	36	60000	F
3775	CGKQRN	HTIOJJGKSV	3118172188 Dell Way	\N	ARGRIHQ	OR	36532	US	1	HTIOJJGKSV@dell.com	3118172188	4	2390000075567513	2010/02	user3775	password	36	60000	F
3776	RFCENW	MCGWJQPEQG	2285449818 Dell Way	\N	LHPSYIZ	DE	93631	US	1	MCGWJQPEQG@dell.com	2285449818	4	1736961724702268	2009/04	user3776	password	53	20000	F
3777	PGZLTC	RPLHFPYMAF	4529921492 Dell Way	\N	BSDJSII	TN	96922	US	1	RPLHFPYMAF@dell.com	4529921492	2	2945012198761105	2012/04	user3777	password	68	60000	M
3778	RXHTOX	EWCUUOUAQN	6858630048 Dell Way	\N	EAFMIBL	OK	35255	US	1	EWCUUOUAQN@dell.com	6858630048	3	6233911265153438	2009/01	user3778	password	26	20000	M
3779	KUNHZJ	KTDZODPBHP	2508725936 Dell Way	\N	GUXHFPP	TX	27958	US	1	KTDZODPBHP@dell.com	2508725936	2	3247912306804210	2009/03	user3779	password	32	80000	F
3780	SZZBKT	FJHJYJRNQL	5497820646 Dell Way	\N	LYQBNNG	NY	74204	US	1	FJHJYJRNQL@dell.com	5497820646	5	9514365882612766	2011/09	user3780	password	88	40000	M
3781	ZLBSQK	AZJJRXACIY	9124387582 Dell Way	\N	TKLGQDY	CT	19793	US	1	AZJJRXACIY@dell.com	9124387582	5	8007875206414611	2012/03	user3781	password	50	100000	M
3782	NOIXOI	HYZEYBNXUX	4242676973 Dell Way	\N	IBNMARP	VT	54842	US	1	HYZEYBNXUX@dell.com	4242676973	4	7476448891218752	2012/08	user3782	password	46	40000	F
3783	SFSAMR	ARPBENWCVY	5485541862 Dell Way	\N	PIYHXVU	IA	65122	US	1	ARPBENWCVY@dell.com	5485541862	1	2972744676750153	2012/05	user3783	password	45	80000	M
3784	CQCTQT	JSYWPASNQA	2110056311 Dell Way	\N	LXXHREX	FL	30291	US	1	JSYWPASNQA@dell.com	2110056311	1	6283144766464830	2010/09	user3784	password	30	60000	F
3785	GIYASR	YOGYHUPHGM	2675319795 Dell Way	\N	FNEJLJP	ND	49837	US	1	YOGYHUPHGM@dell.com	2675319795	1	2057798468507826	2009/08	user3785	password	48	80000	M
3786	JPRAOG	HNNCCUIPAW	7332418135 Dell Way	\N	UJHDZVP	DE	90429	US	1	HNNCCUIPAW@dell.com	7332418135	3	5767023332882673	2008/02	user3786	password	54	60000	M
3787	ENHKVU	XXXSFMSBHC	6576756124 Dell Way	\N	JKCFAGC	OK	79964	US	1	XXXSFMSBHC@dell.com	6576756124	5	9157278828322888	2008/04	user3787	password	65	40000	M
3788	YSSTPP	QIVDBXLEGV	2703876088 Dell Way	\N	GLVNOOH	DE	44494	US	1	QIVDBXLEGV@dell.com	2703876088	2	7443726519588382	2012/07	user3788	password	60	80000	F
3789	HNWWEF	SIGPTKWPRH	1726793059 Dell Way	\N	LEVZLZJ	NV	34647	US	1	SIGPTKWPRH@dell.com	1726793059	3	8570888556074352	2011/04	user3789	password	25	100000	M
3790	ZVZENH	LCBWYQNGBS	2847036446 Dell Way	\N	CBECKVJ	MS	37780	US	1	LCBWYQNGBS@dell.com	2847036446	1	6149862502235920	2009/02	user3790	password	44	40000	M
3791	IMKQXN	RUMHHTJAVK	9051363750 Dell Way	\N	EYUAHHI	MS	50479	US	1	RUMHHTJAVK@dell.com	9051363750	5	5860430859494955	2009/02	user3791	password	50	60000	M
3792	WFMJWG	WDOPMOLXTJ	9892823860 Dell Way	\N	SURZCDL	WY	95918	US	1	WDOPMOLXTJ@dell.com	9892823860	2	1413319880608469	2010/10	user3792	password	62	40000	F
3793	CRWIOA	WDNLPKFYDZ	7887742828 Dell Way	\N	PDBTOBS	ND	37685	US	1	WDNLPKFYDZ@dell.com	7887742828	5	2206602345220744	2009/04	user3793	password	29	60000	M
3794	AUMBQQ	PCFAHEDGUG	8499235911 Dell Way	\N	IOUKHJS	AR	40168	US	1	PCFAHEDGUG@dell.com	8499235911	3	6475221043918282	2012/11	user3794	password	58	20000	M
3795	BCHRRJ	XRQBUXWAGL	2143239440 Dell Way	\N	VQSEITN	DE	24866	US	1	XRQBUXWAGL@dell.com	2143239440	1	1272459462285041	2011/03	user3795	password	66	80000	F
3796	YKYIHQ	YJLWGLCRHS	3890901606 Dell Way	\N	JMBDZFH	CO	42887	US	1	YJLWGLCRHS@dell.com	3890901606	4	5914615500718356	2012/07	user3796	password	77	100000	M
3797	TGFKFP	VBVHEMOXWA	1602396626 Dell Way	\N	YZAEHDN	NH	94178	US	1	VBVHEMOXWA@dell.com	1602396626	3	5100141145754606	2012/07	user3797	password	45	80000	M
3798	PBZEWA	ZDEMSBISAI	3493912611 Dell Way	\N	TEPXSFV	PA	80874	US	1	ZDEMSBISAI@dell.com	3493912611	4	3793867896776646	2011/04	user3798	password	23	40000	F
3799	BKFBJJ	GVBIEUJMNN	4344550150 Dell Way	\N	BKFHFZB	MS	66441	US	1	GVBIEUJMNN@dell.com	4344550150	1	9337342120241376	2010/05	user3799	password	37	60000	M
3800	MODVVZ	WDDQNPEARO	8024942957 Dell Way	\N	GYUFAHW	MA	51394	US	1	WDDQNPEARO@dell.com	8024942957	5	8597943529020996	2008/04	user3800	password	63	60000	M
3801	TJSSGW	WWJMBJEPQD	1199535127 Dell Way	\N	KWDSSNE	MS	43326	US	1	WWJMBJEPQD@dell.com	1199535127	3	7299562847707421	2011/01	user3801	password	60	40000	F
3802	HDRDZO	NMPXQFNTQJ	5285995662 Dell Way	\N	WICKNOU	NC	20866	US	1	NMPXQFNTQJ@dell.com	5285995662	1	2795270156580955	2008/07	user3802	password	64	40000	M
3803	INRWAD	MXURKNHUKQ	7894669909 Dell Way	\N	WUDLORO	AR	87476	US	1	MXURKNHUKQ@dell.com	7894669909	1	4923826253507286	2010/06	user3803	password	28	80000	M
3804	VPZZBW	TSHGABQQYL	7929491289 Dell Way	\N	UJAMYBI	OK	25223	US	1	TSHGABQQYL@dell.com	7929491289	1	6721341838128865	2012/11	user3804	password	62	80000	F
3805	PSMLMF	TTGVKWTVRD	7480130759 Dell Way	\N	WDCXMUC	IA	92887	US	1	TTGVKWTVRD@dell.com	7480130759	1	7902997900266201	2009/11	user3805	password	32	100000	M
3806	SJCXCV	DXFARBSUXV	4273066082 Dell Way	\N	WVIRXOP	NM	75236	US	1	DXFARBSUXV@dell.com	4273066082	5	6558581417892129	2010/11	user3806	password	34	40000	F
3807	IEJDIH	JJYLBTJXPF	2286994046 Dell Way	\N	GHDUXTN	IA	75708	US	1	JJYLBTJXPF@dell.com	2286994046	5	6479819800239057	2009/02	user3807	password	80	80000	F
3808	FVPMFZ	LRAEAYUFEB	4955021635 Dell Way	\N	IZYCMFV	NM	12312	US	1	LRAEAYUFEB@dell.com	4955021635	1	1995074105449021	2009/09	user3808	password	45	60000	M
3809	ZZTYKK	ZPLXJQBLZA	7563111483 Dell Way	\N	KCNPXEQ	LA	24850	US	1	ZPLXJQBLZA@dell.com	7563111483	4	8783574768342079	2008/02	user3809	password	47	20000	F
3810	EAOOZE	ZWNQYYQZIS	7139394099 Dell Way	\N	MYQQOZV	ID	66433	US	1	ZWNQYYQZIS@dell.com	7139394099	2	8050076995044947	2008/06	user3810	password	86	40000	F
3811	NVMRVI	ELHDCGLUTJ	8263225670 Dell Way	\N	KKYKFFA	VT	62295	US	1	ELHDCGLUTJ@dell.com	8263225670	5	1388299421872943	2011/03	user3811	password	56	40000	F
3812	ZXWIBI	PFKWQFQAQA	8066886222 Dell Way	\N	YAGEBET	TX	23754	US	1	PFKWQFQAQA@dell.com	8066886222	3	4535952908918262	2009/11	user3812	password	50	40000	M
3813	IQVRGA	BCRHTSXTRY	7521635462 Dell Way	\N	AVZEOVI	LA	49112	US	1	BCRHTSXTRY@dell.com	7521635462	4	3476337801199406	2008/12	user3813	password	19	60000	M
3814	VDVWFY	NNRFKLXILS	8856956905 Dell Way	\N	IQHEYQP	NY	37545	US	1	NNRFKLXILS@dell.com	8856956905	5	3376172520220280	2012/05	user3814	password	79	80000	M
3815	RPSPCF	GIQRGZCYHT	5154243024 Dell Way	\N	GMRXBJF	WA	29772	US	1	GIQRGZCYHT@dell.com	5154243024	5	6133418666664512	2009/07	user3815	password	23	100000	F
3816	UOGAVP	RMVQPUYIAK	2614528890 Dell Way	\N	AYMKDKP	NE	31139	US	1	RMVQPUYIAK@dell.com	2614528890	5	8123961137142033	2009/11	user3816	password	86	20000	F
3817	EBFUTS	PJIJIQKSRI	6554304107 Dell Way	\N	EBMPRBV	TN	94223	US	1	PJIJIQKSRI@dell.com	6554304107	1	8171126110479236	2010/02	user3817	password	33	80000	F
3818	LNYECI	MMQCXIUGNV	5376709320 Dell Way	\N	SDMTYIR	ND	48690	US	1	MMQCXIUGNV@dell.com	5376709320	1	6173377290368081	2011/11	user3818	password	75	20000	F
3819	TILBUY	SXVARCONUR	4038964937 Dell Way	\N	ZOQIGET	OR	36205	US	1	SXVARCONUR@dell.com	4038964937	3	2187759923283010	2008/08	user3819	password	52	100000	M
3820	YYRWQP	SRGUGTPXTD	2236278033 Dell Way	\N	NCKSWCA	FL	58799	US	1	SRGUGTPXTD@dell.com	2236278033	2	2137396449223160	2011/03	user3820	password	19	60000	F
3821	SKUHCL	OXRHNPBQCD	8333284240 Dell Way	\N	AVADVFR	WV	56339	US	1	OXRHNPBQCD@dell.com	8333284240	3	7409793926868588	2012/02	user3821	password	80	60000	M
3822	QVQBJO	TRBITSLXTG	3860272686 Dell Way	\N	XXCCPBP	MD	67571	US	1	TRBITSLXTG@dell.com	3860272686	2	7895929135382176	2008/10	user3822	password	39	80000	M
3823	YWANPR	OXLHIIBOFY	2027805982 Dell Way	\N	QINSYXJ	IA	24395	US	1	OXLHIIBOFY@dell.com	2027805982	3	9531065433286132	2010/03	user3823	password	59	40000	F
3824	PWQHLN	SSVATKGSBP	3264368602 Dell Way	\N	FTNDCTH	HI	24019	US	1	SSVATKGSBP@dell.com	3264368602	4	4178188848309219	2012/01	user3824	password	47	60000	M
3825	ARIOJB	JKVURNVGTP	1200899890 Dell Way	\N	TWSNEYR	MI	61608	US	1	JKVURNVGTP@dell.com	1200899890	2	6168310002423823	2010/08	user3825	password	50	60000	F
3826	TZSUJD	PDVCZCWOVS	4228412939 Dell Way	\N	HJXFAIU	AR	63950	US	1	PDVCZCWOVS@dell.com	4228412939	3	3360276437830180	2012/12	user3826	password	61	60000	M
3827	IJGLYK	HBJJXYFQFO	7741314743 Dell Way	\N	OLPXFQM	NE	18827	US	1	HBJJXYFQFO@dell.com	7741314743	2	1135300823487341	2009/12	user3827	password	85	80000	F
3828	EDGPKI	ZTFYYWEMKP	8239841547 Dell Way	\N	BHVRUKU	NC	80464	US	1	ZTFYYWEMKP@dell.com	8239841547	5	7512483015656472	2011/07	user3828	password	19	100000	M
3829	GNBOMU	UKTQOFBEHJ	8968721508 Dell Way	\N	ZZDJURE	NE	59063	US	1	UKTQOFBEHJ@dell.com	8968721508	2	1835871233139187	2012/03	user3829	password	73	20000	M
3830	VSFQNQ	JEEPFJXPIW	1199343584 Dell Way	\N	SSRJWGY	PA	57962	US	1	JEEPFJXPIW@dell.com	1199343584	4	7721352490596474	2011/10	user3830	password	52	80000	M
3831	RGBHQG	MFMVDBEATX	2562488214 Dell Way	\N	RDTXCNL	CO	26557	US	1	MFMVDBEATX@dell.com	2562488214	5	1030861061066389	2011/07	user3831	password	58	40000	M
3832	QQJWCP	IYTJDTDAKH	5439832800 Dell Way	\N	UHJHSMM	VA	42309	US	1	IYTJDTDAKH@dell.com	5439832800	3	8753645552787931	2008/11	user3832	password	62	80000	F
3833	ZNPPVO	IFRBIRMQMU	7078918508 Dell Way	\N	ZUNLGKV	PA	95674	US	1	IFRBIRMQMU@dell.com	7078918508	5	8336299240589143	2009/06	user3833	password	39	40000	M
3834	XWULFA	CHIUTYGOYA	3017948640 Dell Way	\N	BKHLFBK	UT	87889	US	1	CHIUTYGOYA@dell.com	3017948640	1	3962075129151344	2010/06	user3834	password	40	60000	F
3835	CVNCYU	LSOKZCIADS	6209893784 Dell Way	\N	IPYJAVG	IA	98776	US	1	LSOKZCIADS@dell.com	6209893784	4	4894158192910254	2012/03	user3835	password	72	100000	F
3836	HCYCOR	QYRTHRXAAM	2799047205 Dell Way	\N	ZKNUQTT	GA	56373	US	1	QYRTHRXAAM@dell.com	2799047205	1	7172074712347240	2012/02	user3836	password	68	40000	F
3837	QHTIYS	ZRAQOBQBAA	5821994100 Dell Way	\N	PURIOWW	PA	98042	US	1	ZRAQOBQBAA@dell.com	5821994100	4	1635739494115114	2009/12	user3837	password	37	100000	F
3838	AEETEW	UULVLNVMCP	1731866696 Dell Way	\N	DKEAGYA	SD	67114	US	1	UULVLNVMCP@dell.com	1731866696	1	6131998633965850	2009/11	user3838	password	77	40000	F
3839	ZDGWXB	HSMUOZWEDH	5131512279 Dell Way	\N	IEOGEJX	ID	46579	US	1	HSMUOZWEDH@dell.com	5131512279	4	3810344933066517	2009/12	user3839	password	47	40000	F
3840	QDBRKT	EFIECMHJUM	1287550265 Dell Way	\N	YBQIYXS	MD	55307	US	1	EFIECMHJUM@dell.com	1287550265	4	5495256043970585	2010/12	user3840	password	64	20000	F
3841	RULLYQ	TDSFLCAXBB	4789105235 Dell Way	\N	NJAKCKX	CO	17336	US	1	TDSFLCAXBB@dell.com	4789105235	3	1099947464652359	2008/08	user3841	password	22	80000	F
3842	NEJEYM	XDXZEUBGIK	7827633216 Dell Way	\N	GTMRQPT	AZ	23252	US	1	XDXZEUBGIK@dell.com	7827633216	1	7955907926429064	2012/11	user3842	password	30	40000	F
3843	NMYZJC	XJHRKNAVUT	8540927250 Dell Way	\N	ILKXELB	WI	63041	US	1	XJHRKNAVUT@dell.com	8540927250	4	5047607374843210	2008/01	user3843	password	53	60000	M
3844	LNYOLI	VDTIDODWXO	7690252239 Dell Way	\N	GVTSWRH	OK	49366	US	1	VDTIDODWXO@dell.com	7690252239	4	5680517733562738	2009/03	user3844	password	24	80000	M
3845	AFFJBI	CKLRNHOBOJ	4936329861 Dell Way	\N	UGGMOYX	IL	71079	US	1	CKLRNHOBOJ@dell.com	4936329861	3	9323264210950584	2010/03	user3845	password	69	60000	F
3846	XXLFAW	RSJZGLNQFU	5093397778 Dell Way	\N	XSIWQPN	AZ	20285	US	1	RSJZGLNQFU@dell.com	5093397778	3	3686233589891344	2008/02	user3846	password	69	20000	F
3847	EHCAYU	JYBULSAFPT	5858958423 Dell Way	\N	NLJDZLG	ME	11036	US	1	JYBULSAFPT@dell.com	5858958423	3	2449346791487187	2009/08	user3847	password	34	60000	M
3848	IKWCUU	EPGWQLLJZX	3833092269 Dell Way	\N	SCWDIHD	VA	86744	US	1	EPGWQLLJZX@dell.com	3833092269	1	5368743084371090	2010/07	user3848	password	47	100000	M
3849	GZTBDI	HAYTLISIAV	8203243317 Dell Way	\N	EEEMIBI	NM	26996	US	1	HAYTLISIAV@dell.com	8203243317	1	7510987809859217	2008/01	user3849	password	67	60000	F
3850	KNETVE	SOPAHYBCDF	3328366494 Dell Way	\N	HPOJXFN	OK	44260	US	1	SOPAHYBCDF@dell.com	3328366494	5	4898503916338086	2012/05	user3850	password	51	40000	M
3851	QCSUUH	KVOJWRMCZC	6870121750 Dell Way	\N	QIAVWSF	CO	66158	US	1	KVOJWRMCZC@dell.com	6870121750	1	1015541104599833	2008/05	user3851	password	83	80000	F
3852	QNHXYD	MHZEUCDXSM	3060817545 Dell Way	\N	XOIPULF	MI	54422	US	1	MHZEUCDXSM@dell.com	3060817545	3	9023610845673830	2008/04	user3852	password	46	80000	M
3853	RRUVEC	UIXXMUQYRE	1955353783 Dell Way	\N	HHZSMKF	OR	97013	US	1	UIXXMUQYRE@dell.com	1955353783	5	3351577652618289	2010/08	user3853	password	24	20000	F
3854	WZLYUU	WRGQHFHMMO	1868711705 Dell Way	\N	LFBWKUV	MT	69083	US	1	WRGQHFHMMO@dell.com	1868711705	1	3484278095420450	2008/03	user3854	password	59	20000	F
3855	AAZUWR	AMYFULSJXX	2383111957 Dell Way	\N	LTIFPVW	OH	85119	US	1	AMYFULSJXX@dell.com	2383111957	5	1244162274524569	2011/12	user3855	password	33	80000	M
3856	ENVVOI	UUDFMMCJXW	4315337386 Dell Way	\N	RDLNADI	DE	11913	US	1	UUDFMMCJXW@dell.com	4315337386	5	9640342639293524	2010/08	user3856	password	85	80000	F
3857	TPRCKL	FQXRTHPPZS	2723101521 Dell Way	\N	BMSFVWG	FL	78131	US	1	FQXRTHPPZS@dell.com	2723101521	4	4270055462606251	2008/07	user3857	password	53	100000	F
3858	DYNODE	MVXTKNSDPE	8739131700 Dell Way	\N	WUZTAEM	GA	94203	US	1	MVXTKNSDPE@dell.com	8739131700	2	5143367487937212	2009/03	user3858	password	61	60000	F
3859	DBHHND	FHOSARHFOC	7935246920 Dell Way	\N	FHCJUII	NM	67116	US	1	FHOSARHFOC@dell.com	7935246920	5	8421126284170897	2009/06	user3859	password	88	60000	M
3860	GUBJZI	XSIPAOECTL	9558992275 Dell Way	\N	ECFMKWD	FL	86106	US	1	XSIPAOECTL@dell.com	9558992275	3	3776987284421921	2012/01	user3860	password	78	20000	M
3861	WOVFMO	OBOCFQVRVY	9139893784 Dell Way	\N	XHJTLOP	MA	19087	US	1	OBOCFQVRVY@dell.com	9139893784	2	2391294589266181	2011/06	user3861	password	18	60000	F
3862	VUMKIO	YLTOGLKEIS	3958705562 Dell Way	\N	NBDBRNE	NE	82259	US	1	YLTOGLKEIS@dell.com	3958705562	2	3384136078413576	2009/11	user3862	password	37	20000	M
3863	TOAHNM	BCSMMXUEKW	8784679813 Dell Way	\N	HMNURCP	WY	45311	US	1	BCSMMXUEKW@dell.com	8784679813	2	3576841032132506	2008/06	user3863	password	89	100000	F
3864	ADOMEQ	ERDBLHMIPZ	6550551889 Dell Way	\N	VJQYZQI	TN	94998	US	1	ERDBLHMIPZ@dell.com	6550551889	5	4936267826706171	2010/11	user3864	password	54	80000	M
3865	BCESHV	VIHDVPSULC	4945918414 Dell Way	\N	LKBBSXA	KY	88324	US	1	VIHDVPSULC@dell.com	4945918414	5	7434996763244272	2012/07	user3865	password	69	100000	M
3866	XSXSOG	ARCQJWCLIM	9838742375 Dell Way	\N	NJFKJOG	SD	55398	US	1	ARCQJWCLIM@dell.com	9838742375	4	1488256307784468	2011/09	user3866	password	68	60000	F
3867	PHZWIQ	YZAVBMDOZM	9229892873 Dell Way	\N	UJWJQRW	NJ	47042	US	1	YZAVBMDOZM@dell.com	9229892873	2	2337299747858196	2011/11	user3867	password	61	40000	F
3868	PBNGZM	GVOSYDSLXB	5690995565 Dell Way	\N	HHSYDIJ	AR	65084	US	1	GVOSYDSLXB@dell.com	5690995565	4	5409914938267321	2008/11	user3868	password	66	80000	M
3869	EYXRES	FXRIPCGRJN	7870956625 Dell Way	\N	JIRRSSH	IA	41710	US	1	FXRIPCGRJN@dell.com	7870956625	2	2896357187069952	2010/01	user3869	password	27	80000	M
3870	BHEUNB	LWRNCIXQRG	6008283101 Dell Way	\N	HIZZQFI	MA	61298	US	1	LWRNCIXQRG@dell.com	6008283101	5	6558923772536219	2011/06	user3870	password	61	80000	M
3871	TNFVYB	MMEVKUNRCV	1501567692 Dell Way	\N	QCMWLVL	WY	69137	US	1	MMEVKUNRCV@dell.com	1501567692	4	1795680036768317	2011/06	user3871	password	76	60000	M
3872	AFXCSJ	GNUBBMDXCG	9414527227 Dell Way	\N	JZREKRW	MO	40937	US	1	GNUBBMDXCG@dell.com	9414527227	1	7844154106918723	2011/07	user3872	password	68	80000	M
3873	PVMZCA	TDBFHYINHI	9816825882 Dell Way	\N	FMTWIFF	ID	40982	US	1	TDBFHYINHI@dell.com	9816825882	5	8874320554547013	2011/09	user3873	password	64	40000	M
3874	CFRDZV	EFDCORKWWW	1335629893 Dell Way	\N	PTEVYLE	WA	49075	US	1	EFDCORKWWW@dell.com	1335629893	4	2632054536137730	2011/11	user3874	password	73	80000	F
3875	LXBGBH	JEVAORXLHQ	7132090917 Dell Way	\N	QCPBGNN	IL	23335	US	1	JEVAORXLHQ@dell.com	7132090917	5	1143937113229185	2010/09	user3875	password	25	100000	M
3876	EDSLNW	GOLYLWFCNH	4558216044 Dell Way	\N	SOOGBVJ	PA	81212	US	1	GOLYLWFCNH@dell.com	4558216044	2	5736767914611847	2010/02	user3876	password	29	80000	F
3877	WDTTKI	EIUBNXOVPD	5526092713 Dell Way	\N	JVFEEYZ	NE	24447	US	1	EIUBNXOVPD@dell.com	5526092713	1	3240953646600246	2011/10	user3877	password	53	60000	M
3878	GGHPLP	JMCGBXVEGQ	7867081223 Dell Way	\N	KLVJLKN	WA	55532	US	1	JMCGBXVEGQ@dell.com	7867081223	3	3424506534356624	2009/02	user3878	password	29	60000	F
3879	LCUALG	DSIBONIEXT	2928067728 Dell Way	\N	AGFLTDY	MT	74674	US	1	DSIBONIEXT@dell.com	2928067728	4	8455179094336928	2009/04	user3879	password	31	100000	F
3880	ZVVGYN	OZBBHGYBHF	9335703575 Dell Way	\N	GSZJRMC	UT	34842	US	1	OZBBHGYBHF@dell.com	9335703575	2	6013328751083464	2008/01	user3880	password	85	20000	M
3881	TIVHWV	IYCPXEWCLP	4656005390 Dell Way	\N	BUGOXDW	TN	43416	US	1	IYCPXEWCLP@dell.com	4656005390	5	4783524401020259	2009/01	user3881	password	39	20000	F
3882	CJFXRE	AHBFEEQTGL	9364175542 Dell Way	\N	AVIDREN	AZ	18423	US	1	AHBFEEQTGL@dell.com	9364175542	2	2044662018772214	2009/06	user3882	password	51	40000	M
3883	RGNVHU	XMZBCSHNTC	3055220261 Dell Way	\N	WWTAKVC	KS	29503	US	1	XMZBCSHNTC@dell.com	3055220261	3	7151741870678962	2011/11	user3883	password	54	40000	F
3884	AFKUDX	UEANMOGPKD	1573792778 Dell Way	\N	ILNEOVJ	RI	43221	US	1	UEANMOGPKD@dell.com	1573792778	3	3182244261261076	2010/11	user3884	password	45	60000	F
3885	UJERDJ	SQVGXKRATC	9656744058 Dell Way	\N	NXQJHLS	KY	89960	US	1	SQVGXKRATC@dell.com	9656744058	5	7510400024708361	2009/06	user3885	password	74	20000	M
3886	YVZHNQ	CUNNLNGOBE	3081984126 Dell Way	\N	FKLQCUN	AZ	72862	US	1	CUNNLNGOBE@dell.com	3081984126	3	2566186460666358	2008/07	user3886	password	19	100000	F
3887	AGWQJQ	DWBRCPSHUC	4349931948 Dell Way	\N	SLFMYHF	DE	73499	US	1	DWBRCPSHUC@dell.com	4349931948	1	3122138467617333	2009/02	user3887	password	60	40000	F
3888	LASBEO	DVRTOYORRZ	2143565219 Dell Way	\N	XEXEJBX	OR	31717	US	1	DVRTOYORRZ@dell.com	2143565219	1	4234396017622203	2011/07	user3888	password	70	20000	M
3889	KFSZIO	RBDPQUGPRL	2557542790 Dell Way	\N	NWUOTNV	VA	66778	US	1	RBDPQUGPRL@dell.com	2557542790	3	2316948109772056	2012/09	user3889	password	68	40000	M
3890	KHGZYI	COZXVOOGBL	3889314384 Dell Way	\N	AQFOLCE	NJ	71019	US	1	COZXVOOGBL@dell.com	3889314384	3	4677848752122373	2008/10	user3890	password	42	60000	F
3891	PKBYMP	XKLMZRNKSE	8041192181 Dell Way	\N	PGPSLFJ	PA	75174	US	1	XKLMZRNKSE@dell.com	8041192181	4	5818929525557906	2008/03	user3891	password	64	80000	M
3892	RRCHPM	SBLKPVDTLJ	8388216648 Dell Way	\N	IDVONOH	IN	40599	US	1	SBLKPVDTLJ@dell.com	8388216648	3	5750889476854355	2010/02	user3892	password	26	20000	M
3893	FLLREM	COBYRVKBEN	3999888052 Dell Way	\N	XSBMAJU	SD	80704	US	1	COBYRVKBEN@dell.com	3999888052	2	9497561658732594	2010/06	user3893	password	75	80000	M
3894	FHASKP	UIHPTJTGGL	4724832378 Dell Way	\N	ISLRNHM	TN	60516	US	1	UIHPTJTGGL@dell.com	4724832378	2	9840621518436820	2008/12	user3894	password	79	60000	F
3895	WCQLWZ	SMSBFZHRHZ	9525458065 Dell Way	\N	DZNKLIZ	TX	66960	US	1	SMSBFZHRHZ@dell.com	9525458065	1	6033161960076541	2011/06	user3895	password	75	80000	M
3896	KBLJUX	CVDBCUICXI	2302199576 Dell Way	\N	PITYHQP	HI	71330	US	1	CVDBCUICXI@dell.com	2302199576	1	2328063397668302	2012/08	user3896	password	70	40000	M
3897	ESMCVI	GWLAFNYNDG	7674136102 Dell Way	\N	HCOXRTP	TN	80509	US	1	GWLAFNYNDG@dell.com	7674136102	4	4907079500146210	2010/02	user3897	password	29	80000	M
3898	QTQYZN	KASXYGBFNE	7505019991 Dell Way	\N	TLVNARH	RI	47594	US	1	KASXYGBFNE@dell.com	7505019991	2	5686051172669977	2012/11	user3898	password	43	60000	M
3899	ZMPNWP	FUOLWTZAMK	5096899474 Dell Way	\N	WZLNHFY	AK	51420	US	1	FUOLWTZAMK@dell.com	5096899474	5	4076869857031852	2012/05	user3899	password	88	100000	M
3900	PITEOO	TZKMZLZKHZ	8867371810 Dell Way	\N	WUGBTGN	FL	22352	US	1	TZKMZLZKHZ@dell.com	8867371810	5	5846758961211891	2012/10	user3900	password	48	60000	F
3901	EPRSJR	DWQOVAWUXQ	9919963314 Dell Way	\N	BYJIMOL	LA	60907	US	1	DWQOVAWUXQ@dell.com	9919963314	2	4349549180828035	2010/08	user3901	password	54	60000	F
3902	EIPVLL	LAHMWCJNDI	4610979546 Dell Way	\N	XMVMXEA	VT	45817	US	1	LAHMWCJNDI@dell.com	4610979546	2	1274799601640552	2012/11	user3902	password	38	20000	F
3903	WWRIIS	QVPSFCWNZI	9765912471 Dell Way	\N	JLFOMDY	VA	50817	US	1	QVPSFCWNZI@dell.com	9765912471	4	4275997054297477	2009/11	user3903	password	61	20000	M
3904	HMBZCW	OUBRQPRYYD	2235175092 Dell Way	\N	EMPILMU	MD	35366	US	1	OUBRQPRYYD@dell.com	2235175092	4	2090895712375641	2011/10	user3904	password	78	20000	F
3905	WAISPD	UGTJYSIBXU	6079900566 Dell Way	\N	RFGEZQL	CT	36729	US	1	UGTJYSIBXU@dell.com	6079900566	5	1758017782121896	2009/11	user3905	password	42	40000	M
3906	RZMUUT	OERHMSEHJK	5766936772 Dell Way	\N	NOKDZNL	ND	45477	US	1	OERHMSEHJK@dell.com	5766936772	5	3471259134821594	2012/03	user3906	password	30	60000	F
3907	QIAJWE	BDQTIXDSKR	3794931954 Dell Way	\N	CORQAFA	NC	25026	US	1	BDQTIXDSKR@dell.com	3794931954	2	4455628866795451	2010/12	user3907	password	61	20000	F
3908	PMDTNH	KHPHLISCLG	5982789182 Dell Way	\N	UBGACUE	ME	27344	US	1	KHPHLISCLG@dell.com	5982789182	5	2120127909816801	2008/01	user3908	password	45	80000	F
3909	NNAUXI	JFTSXWDDQF	5697300621 Dell Way	\N	KRHFVSK	MA	65032	US	1	JFTSXWDDQF@dell.com	5697300621	3	6566320353653283	2012/04	user3909	password	26	60000	M
3910	DFSMPX	FHUCKYTPJK	8658636923 Dell Way	\N	XOFQYPG	MO	22712	US	1	FHUCKYTPJK@dell.com	8658636923	2	4873242171946913	2012/10	user3910	password	35	20000	M
3911	YPOVVV	QXGPRVYBTM	5250624265 Dell Way	\N	HJLXPXB	MI	36509	US	1	QXGPRVYBTM@dell.com	5250624265	3	1742478102445602	2011/07	user3911	password	22	80000	F
3912	QMYMDV	SSNOQOHDWQ	8720527643 Dell Way	\N	OTGMURU	ID	18733	US	1	SSNOQOHDWQ@dell.com	8720527643	5	6637314918451012	2012/08	user3912	password	72	60000	F
3913	RAGNSY	AHPPOSLFHF	8667088362 Dell Way	\N	LTADNHF	MD	33074	US	1	AHPPOSLFHF@dell.com	8667088362	2	8977919084019960	2010/11	user3913	password	18	40000	M
3914	GUQFVX	VKLNVQVBCP	5251392001 Dell Way	\N	BFDILNP	IN	85329	US	1	VKLNVQVBCP@dell.com	5251392001	5	7394404987338931	2010/03	user3914	password	62	80000	M
3915	FZUCUE	OIAFDBISDO	9151012584 Dell Way	\N	VLZJBHF	MT	27490	US	1	OIAFDBISDO@dell.com	9151012584	5	4295600796118379	2010/09	user3915	password	42	80000	M
3916	CWMHKV	IQYKYRNMNZ	3993155863 Dell Way	\N	MWAUBNZ	WV	57807	US	1	IQYKYRNMNZ@dell.com	3993155863	3	3468356473371387	2011/03	user3916	password	89	80000	F
3917	MBMHJC	GTBYHOLGAI	6459763414 Dell Way	\N	GUKUTJI	CA	87517	US	1	GTBYHOLGAI@dell.com	6459763414	4	1731459583621472	2010/07	user3917	password	28	20000	M
3918	QJYTPS	UOZIZGIIND	1235141326 Dell Way	\N	SIXCQZY	IA	75173	US	1	UOZIZGIIND@dell.com	1235141326	5	3206071505788714	2008/11	user3918	password	78	100000	F
3919	UOXMIL	MRLSATGDLO	9783703614 Dell Way	\N	ANEAMLT	MS	35539	US	1	MRLSATGDLO@dell.com	9783703614	4	2756439091637730	2012/06	user3919	password	52	60000	F
3920	JBJUOA	FHAYNEKBFY	2618133234 Dell Way	\N	GFKSYXZ	VT	63350	US	1	FHAYNEKBFY@dell.com	2618133234	4	1662986022885888	2011/04	user3920	password	25	20000	F
3921	LVYMAF	NZTRKUXIBC	4010929118 Dell Way	\N	TTBRTZG	WA	72009	US	1	NZTRKUXIBC@dell.com	4010929118	3	9920398482121528	2010/08	user3921	password	44	100000	F
3922	HJLNWL	GOVBLECNXW	3010003518 Dell Way	\N	OPPOWNG	FL	18896	US	1	GOVBLECNXW@dell.com	3010003518	4	7184025240130723	2010/06	user3922	password	24	100000	M
3923	NKSYQG	URRYUFWQUL	5972771542 Dell Way	\N	GIHTOMW	SC	17753	US	1	URRYUFWQUL@dell.com	5972771542	2	6245280688162894	2011/04	user3923	password	49	20000	M
3924	DCHKWZ	CVTIRKCDQL	6038683509 Dell Way	\N	KKAXHVZ	TN	27895	US	1	CVTIRKCDQL@dell.com	6038683509	3	5210477627348155	2012/08	user3924	password	27	20000	M
3925	LOQLRL	FZDPCGGORR	1484125936 Dell Way	\N	OOYKOUP	CO	34076	US	1	FZDPCGGORR@dell.com	1484125936	1	9125505112111568	2008/03	user3925	password	65	80000	M
3926	HBMSGL	VWOCCCUURI	7310178083 Dell Way	\N	TBWNQZU	OH	15882	US	1	VWOCCCUURI@dell.com	7310178083	5	3805715532507747	2009/07	user3926	password	26	80000	M
3927	PIVBER	PHUSBOJJHL	6385828633 Dell Way	\N	GVCFQUH	KS	70003	US	1	PHUSBOJJHL@dell.com	6385828633	4	2616267879493534	2011/04	user3927	password	72	40000	M
3928	OJUFZC	ZRDOBNWMTR	2708426833 Dell Way	\N	OZHIHQA	UT	36687	US	1	ZRDOBNWMTR@dell.com	2708426833	3	6267403208650649	2012/11	user3928	password	33	60000	F
3929	ASGCSX	FHYTDLMUZM	6448576231 Dell Way	\N	CITSJQA	NC	29435	US	1	FHYTDLMUZM@dell.com	6448576231	3	2076589383650571	2012/12	user3929	password	46	100000	M
3930	QXKNDR	MWUXJPXWSG	6247343721 Dell Way	\N	QKPGLDM	AR	66116	US	1	MWUXJPXWSG@dell.com	6247343721	5	6341363885905594	2012/09	user3930	password	38	60000	M
3931	RDTJPQ	ENATLWMRMX	6852442104 Dell Way	\N	HTILFJB	SC	31859	US	1	ENATLWMRMX@dell.com	6852442104	4	9374677413608880	2012/05	user3931	password	57	80000	F
3932	HZBXDP	YXAUKSHHZB	2448541554 Dell Way	\N	PKGZMBF	CT	82016	US	1	YXAUKSHHZB@dell.com	2448541554	1	2381606999319047	2011/09	user3932	password	63	100000	M
3933	SXVHVS	HQCAYKZZZK	2964486549 Dell Way	\N	FZWGFZB	MA	14290	US	1	HQCAYKZZZK@dell.com	2964486549	1	7490390045568348	2012/01	user3933	password	45	60000	M
3934	EVUXDL	ADJKDIKNOK	2402163629 Dell Way	\N	KVPKXZL	CO	14705	US	1	ADJKDIKNOK@dell.com	2402163629	5	1985716196708381	2010/06	user3934	password	23	80000	F
3935	WQMHRQ	QCTZMGNXRJ	6786870174 Dell Way	\N	NBGMMJN	NM	37583	US	1	QCTZMGNXRJ@dell.com	6786870174	1	8243013540748508	2011/11	user3935	password	28	60000	M
3936	PWFGNH	ZMUGARXJEY	1873841241 Dell Way	\N	QRKZFBH	TN	30313	US	1	ZMUGARXJEY@dell.com	1873841241	3	2076092617586255	2009/02	user3936	password	65	100000	M
3937	WCMDBZ	YHAQEKUDAM	9511385877 Dell Way	\N	OARPHNV	MA	15704	US	1	YHAQEKUDAM@dell.com	9511385877	4	2729341408703476	2010/06	user3937	password	31	60000	M
3938	RPPROX	RECBZFBLTB	8780201978 Dell Way	\N	CJJPETR	CT	44282	US	1	RECBZFBLTB@dell.com	8780201978	4	8734644876327366	2008/03	user3938	password	48	80000	M
3939	AJIYBM	ACLGEXAFZJ	6194836735 Dell Way	\N	PPOIGRS	CT	47544	US	1	ACLGEXAFZJ@dell.com	6194836735	1	6443541800137610	2012/11	user3939	password	46	20000	F
3940	SZIFZL	RGPOGUOPKD	8800349026 Dell Way	\N	ESKVLNG	AK	73972	US	1	RGPOGUOPKD@dell.com	8800349026	1	6520341394469143	2009/01	user3940	password	83	100000	F
3941	GFARWG	GLMBZCLCGD	4215291355 Dell Way	\N	NCPAJPT	HI	66643	US	1	GLMBZCLCGD@dell.com	4215291355	3	7077963428571821	2009/06	user3941	password	68	60000	M
3942	SDOYJZ	LKYNVBUZOX	5567446739 Dell Way	\N	POGFIMV	NY	97682	US	1	LKYNVBUZOX@dell.com	5567446739	5	5081102918367833	2008/06	user3942	password	27	100000	M
3943	RVYRHJ	PUFQPFEMUT	6813858121 Dell Way	\N	TZCFVTF	KS	71562	US	1	PUFQPFEMUT@dell.com	6813858121	3	1927504822146147	2011/06	user3943	password	66	60000	F
3944	PDNZTI	EKYJOKDIDD	9544915346 Dell Way	\N	KJYEOHW	GA	83286	US	1	EKYJOKDIDD@dell.com	9544915346	5	3107011936139315	2011/06	user3944	password	53	40000	M
3945	AEIJIS	HSHSWQWZAG	3561198674 Dell Way	\N	YEUGAAB	WY	99189	US	1	HSHSWQWZAG@dell.com	3561198674	3	5036553668789566	2011/10	user3945	password	20	100000	M
3946	JEICMB	JEXZAXAHVF	5543376034 Dell Way	\N	BBGBDFB	MD	84159	US	1	JEXZAXAHVF@dell.com	5543376034	1	6778321823105217	2010/12	user3946	password	64	100000	F
3947	ZZPAJU	XJVUJCQOES	5425064842 Dell Way	\N	UFVAHFW	SC	47025	US	1	XJVUJCQOES@dell.com	5425064842	2	4563014633487910	2008/03	user3947	password	57	20000	F
3948	EDPYBY	UWHWNWAFRG	1721164360 Dell Way	\N	BSOHOIR	AL	69616	US	1	UWHWNWAFRG@dell.com	1721164360	1	9140912458300592	2011/04	user3948	password	28	80000	F
3949	TTMRNJ	ZKWWLBNSDF	2335328877 Dell Way	\N	GKTPBUG	DC	96662	US	1	ZKWWLBNSDF@dell.com	2335328877	4	3187112851999700	2009/07	user3949	password	66	20000	F
3950	DSVMSG	JORLBKOHQY	1481289940 Dell Way	\N	BFAWMEV	NJ	94204	US	1	JORLBKOHQY@dell.com	1481289940	5	5568946434184909	2011/12	user3950	password	78	100000	M
3951	RJIXSX	PDYZRGQPHV	2739051131 Dell Way	\N	PDHTZXR	AK	83572	US	1	PDYZRGQPHV@dell.com	2739051131	4	7707740531302989	2008/08	user3951	password	45	80000	M
3952	SPQPEU	OELVUADQQH	4749761839 Dell Way	\N	YJGWBGR	IA	98205	US	1	OELVUADQQH@dell.com	4749761839	2	6131422990001739	2011/12	user3952	password	55	60000	M
3953	EDTYRX	JNSKQIAXGK	9363693210 Dell Way	\N	DDLJUSJ	GA	97939	US	1	JNSKQIAXGK@dell.com	9363693210	1	9376999037340284	2010/07	user3953	password	52	60000	M
3954	FNICXV	UHLDHJKRMN	7770844074 Dell Way	\N	DWHVFNV	DC	55671	US	1	UHLDHJKRMN@dell.com	7770844074	3	1263193171937018	2009/03	user3954	password	67	60000	M
3955	AOPVJW	HMEQWWDKZZ	7524695146 Dell Way	\N	RVFERJS	ME	96403	US	1	HMEQWWDKZZ@dell.com	7524695146	4	2354442655108869	2009/01	user3955	password	81	40000	M
3956	MGZINM	NEIJHTJHKF	9947707741 Dell Way	\N	NPWWHHV	AL	94236	US	1	NEIJHTJHKF@dell.com	9947707741	3	1163578200619667	2012/10	user3956	password	65	40000	F
3957	QRPCET	LOBEYJPDXF	3405585339 Dell Way	\N	AUNIPNG	NJ	96096	US	1	LOBEYJPDXF@dell.com	3405585339	3	8025759601965547	2012/10	user3957	password	79	60000	F
3958	LQQFCF	GHDQWHNCHH	8748818024 Dell Way	\N	PQXDWNC	CT	98856	US	1	GHDQWHNCHH@dell.com	8748818024	1	8024109473451973	2011/08	user3958	password	35	20000	F
3959	XIJCPQ	GFNNTPVBFL	3110797463 Dell Way	\N	YIHMKLL	ID	53602	US	1	GFNNTPVBFL@dell.com	3110797463	5	1770653077866882	2010/02	user3959	password	42	40000	F
3960	SLAIRF	WFZMAARLYZ	7855891369 Dell Way	\N	TKJEWQR	CO	64826	US	1	WFZMAARLYZ@dell.com	7855891369	3	7322326265275479	2008/12	user3960	password	26	80000	F
3961	DDCIZH	ILIIDUHCOS	4985552826 Dell Way	\N	MTODKRT	DE	33791	US	1	ILIIDUHCOS@dell.com	4985552826	2	2937120272312313	2010/01	user3961	password	63	80000	F
3962	SAFAIR	JRUDYWRQJK	4129490485 Dell Way	\N	ENVWGZD	NY	32759	US	1	JRUDYWRQJK@dell.com	4129490485	2	3914923411794007	2012/12	user3962	password	56	80000	M
3963	TSHKCY	EFWBXMLHRY	7001037024 Dell Way	\N	COECRWI	AL	18980	US	1	EFWBXMLHRY@dell.com	7001037024	1	1236067434772849	2008/09	user3963	password	89	100000	F
3964	GINFNS	COPPAXGYAV	1753405556 Dell Way	\N	CCNYLOB	CO	59175	US	1	COPPAXGYAV@dell.com	1753405556	2	3245562985073775	2008/03	user3964	password	67	40000	M
3965	EOCXQR	NFRLMPLHRO	2329030849 Dell Way	\N	VQZJSCX	SC	48336	US	1	NFRLMPLHRO@dell.com	2329030849	5	7059463742654771	2012/03	user3965	password	36	20000	M
3966	IXJZLO	QWBFIJXWEO	1584793180 Dell Way	\N	WNGZKBK	ND	90997	US	1	QWBFIJXWEO@dell.com	1584793180	2	1714894893579185	2009/05	user3966	password	76	80000	F
3967	EQTTHQ	UNYDLUIZQV	3560434755 Dell Way	\N	GPGHAVF	AZ	30078	US	1	UNYDLUIZQV@dell.com	3560434755	2	6656460773665459	2008/01	user3967	password	87	40000	M
3968	SZYJTM	HXXCFXSBDI	1101082537 Dell Way	\N	ILJEQKJ	WA	82729	US	1	HXXCFXSBDI@dell.com	1101082537	1	8607843411620707	2012/04	user3968	password	56	80000	F
3969	MAAYIY	WKETDGXMOI	8997237539 Dell Way	\N	VSZGCXB	CT	95353	US	1	WKETDGXMOI@dell.com	8997237539	1	2997524805366993	2010/10	user3969	password	52	100000	M
3970	MWCLSM	PLPVICKRXD	7647346831 Dell Way	\N	QDFOEIN	AZ	48253	US	1	PLPVICKRXD@dell.com	7647346831	3	2697829140815884	2009/05	user3970	password	89	80000	F
3971	CDXOTJ	EORGYIEBZH	3251692804 Dell Way	\N	HOLQBNB	SD	98747	US	1	EORGYIEBZH@dell.com	3251692804	1	4140140741132200	2009/09	user3971	password	58	40000	M
3972	MXPVCE	NIDVNEVUMJ	1916735396 Dell Way	\N	GDLTEGT	MI	34949	US	1	NIDVNEVUMJ@dell.com	1916735396	4	1085617444477975	2011/12	user3972	password	82	20000	M
3973	MYYQLH	UHUYCPLMVO	5329841825 Dell Way	\N	YPTFJEM	MN	85648	US	1	UHUYCPLMVO@dell.com	5329841825	1	8321973344311119	2009/03	user3973	password	67	100000	F
3974	PNQXHY	RGBGROCGMS	8435382648 Dell Way	\N	ZRBEDNA	NM	66066	US	1	RGBGROCGMS@dell.com	8435382648	5	8807246574666352	2010/11	user3974	password	22	20000	F
3975	SAQQRW	SYNGBUSTUK	8302481861 Dell Way	\N	VYOIYEY	RI	25837	US	1	SYNGBUSTUK@dell.com	8302481861	2	1165427458006888	2012/05	user3975	password	44	60000	F
3976	ZFCVXB	JECDXWXHRW	2977326564 Dell Way	\N	VAVAYPF	PA	90159	US	1	JECDXWXHRW@dell.com	2977326564	4	3577137512620539	2010/03	user3976	password	68	60000	F
3977	UKJVTN	YXKVVSNSON	3751463224 Dell Way	\N	NPMDUGA	AK	89353	US	1	YXKVVSNSON@dell.com	3751463224	3	1915555078070610	2012/02	user3977	password	58	80000	M
3978	XQILOF	WKBPXTDLHS	2361917665 Dell Way	\N	YKNEKNB	OR	17768	US	1	WKBPXTDLHS@dell.com	2361917665	4	3094276011455804	2011/07	user3978	password	74	80000	F
3979	CBSHYC	JNACRLJKKU	7398481467 Dell Way	\N	XOFKPYM	PA	69468	US	1	JNACRLJKKU@dell.com	7398481467	3	2470612798817456	2010/01	user3979	password	38	60000	F
3980	ZWCBGP	CIHOSRYNOM	5388236453 Dell Way	\N	SYCRLVI	CT	36857	US	1	CIHOSRYNOM@dell.com	5388236453	4	4323944184929133	2011/03	user3980	password	55	80000	F
3981	PVHFXQ	MMJDKXSXPQ	5510487793 Dell Way	\N	ZHBVPFD	CA	83591	US	1	MMJDKXSXPQ@dell.com	5510487793	5	1086725058499723	2008/08	user3981	password	23	80000	F
3982	JUJAHV	KKGHCDXTDE	8561814890 Dell Way	\N	VYUACWV	NH	75899	US	1	KKGHCDXTDE@dell.com	8561814890	4	4120746831875295	2012/03	user3982	password	75	40000	F
3983	DIHZSS	FZVJXOMBKL	8218060112 Dell Way	\N	WKNSGDL	AZ	75474	US	1	FZVJXOMBKL@dell.com	8218060112	5	9380707392469048	2010/04	user3983	password	86	80000	M
3984	FSIYYI	TIFIUHSGDD	6008292518 Dell Way	\N	UWJXILQ	CO	47720	US	1	TIFIUHSGDD@dell.com	6008292518	4	7350312316790224	2010/06	user3984	password	40	80000	F
3985	QQDYKL	DSFLLMOOGL	5113464369 Dell Way	\N	XDTITWT	KS	60723	US	1	DSFLLMOOGL@dell.com	5113464369	5	1118735877797007	2011/07	user3985	password	31	40000	F
3986	IIOTMH	ZXSLMHRXEV	1642961916 Dell Way	\N	QNOMGXB	OK	73046	US	1	ZXSLMHRXEV@dell.com	1642961916	3	3050904880277812	2009/11	user3986	password	47	60000	F
3987	ZIRGHP	ZSBGKYKFPY	6443940996 Dell Way	\N	UCERDXJ	HI	44495	US	1	ZSBGKYKFPY@dell.com	6443940996	3	3315857028122991	2008/01	user3987	password	51	100000	F
3988	DFRSFK	ULUTWAJUUL	5553174215 Dell Way	\N	ZMPWWVG	MN	37675	US	1	ULUTWAJUUL@dell.com	5553174215	3	4266576407011598	2012/06	user3988	password	71	20000	M
3989	KVWUQH	PKDPTYJEXW	3524017016 Dell Way	\N	UTSPAEX	MS	65097	US	1	PKDPTYJEXW@dell.com	3524017016	3	1384598811622709	2008/08	user3989	password	68	60000	F
3990	OFBVUL	ZJEXTJUPDO	2002137929 Dell Way	\N	HTOLRBB	WV	58638	US	1	ZJEXTJUPDO@dell.com	2002137929	5	2130907196551561	2012/05	user3990	password	58	40000	M
3991	PFJBET	GCMPXCTLKN	7524303661 Dell Way	\N	ZVFBXEP	AL	22339	US	1	GCMPXCTLKN@dell.com	7524303661	5	5748595362529159	2009/03	user3991	password	26	100000	F
3992	MYOFER	STOUNZEAZA	1505684664 Dell Way	\N	GBYKQZN	LA	82030	US	1	STOUNZEAZA@dell.com	1505684664	4	9944212969392540	2008/07	user3992	password	46	80000	F
3993	YXQQPK	EKXEOYDPEE	3706253011 Dell Way	\N	OOVNCFH	DC	85703	US	1	EKXEOYDPEE@dell.com	3706253011	2	4300771973561496	2011/12	user3993	password	78	80000	M
3994	LGMVLW	TPKRTAWYOK	2559722986 Dell Way	\N	TBNZJQU	NY	97312	US	1	TPKRTAWYOK@dell.com	2559722986	2	9573255160357804	2012/01	user3994	password	77	60000	F
3995	HHSDAI	OSBOOZDZTF	1391888066 Dell Way	\N	MSPDNGC	OK	65856	US	1	OSBOOZDZTF@dell.com	1391888066	4	6648969376459718	2012/02	user3995	password	83	20000	F
3996	PHMYVE	ZKSZOSTTEM	8616498011 Dell Way	\N	IHAPJSF	ME	47751	US	1	ZKSZOSTTEM@dell.com	8616498011	2	6162071033380926	2011/06	user3996	password	18	40000	M
3997	MHOQHY	JGNBAGGMPN	2661281247 Dell Way	\N	MFXEKIP	ID	65045	US	1	JGNBAGGMPN@dell.com	2661281247	1	1401614619884640	2008/05	user3997	password	73	80000	M
3998	HIYGSF	UTFBARQNDW	4689418339 Dell Way	\N	LIHTYOJ	DC	60470	US	1	UTFBARQNDW@dell.com	4689418339	2	9451622739899904	2008/01	user3998	password	62	60000	F
3999	OTATNU	YOUQFITBTC	4334441056 Dell Way	\N	IMBWWFL	ID	57995	US	1	YOUQFITBTC@dell.com	4334441056	3	5868833776097745	2012/11	user3999	password	81	60000	M
4000	XGERFS	MVXUPZNSHA	1381709385 Dell Way	\N	TEXZPEN	WV	63684	US	1	MVXUPZNSHA@dell.com	1381709385	5	5574204024858773	2012/06	user4000	password	29	100000	M
4001	IMYAYU	YTJXGCFHWJ	4942974925 Dell Way	\N	EVYIIYY	LA	87912	US	1	YTJXGCFHWJ@dell.com	4942974925	2	3971776042133570	2010/01	user4001	password	22	100000	M
4002	AYNUXG	EUNGAVCJZY	5040560050 Dell Way	\N	IIGGGQD	OH	90741	US	1	EUNGAVCJZY@dell.com	5040560050	2	9817596916574986	2010/03	user4002	password	57	60000	F
4003	BIBIMV	WTVRWFRUOA	5729589405 Dell Way	\N	AUHQXZO	LA	33711	US	1	WTVRWFRUOA@dell.com	5729589405	5	5232005795463920	2008/05	user4003	password	63	20000	M
4004	RMFNIY	JAUOSOCSPX	7303573148 Dell Way	\N	ZGVZUEF	IN	14045	US	1	JAUOSOCSPX@dell.com	7303573148	2	4999455294106156	2009/07	user4004	password	29	100000	F
4005	JMJHVJ	CKCQNVGKVM	8778221431 Dell Way	\N	FUGJAOK	OK	95824	US	1	CKCQNVGKVM@dell.com	8778221431	1	5341226214077324	2008/01	user4005	password	53	40000	M
4006	VRJFTT	IKGDQQYDWT	4485628708 Dell Way	\N	JFTYQMX	MS	55781	US	1	IKGDQQYDWT@dell.com	4485628708	3	5770084986463190	2012/11	user4006	password	20	80000	M
4007	KYJDHU	JKLAJOWDYC	4510597471 Dell Way	\N	WWTJUGW	DE	79038	US	1	JKLAJOWDYC@dell.com	4510597471	1	7128580660559238	2010/10	user4007	password	38	100000	M
4008	QYZKIK	VJUKFXIIUF	7590130196 Dell Way	\N	BDZHZDB	MA	27617	US	1	VJUKFXIIUF@dell.com	7590130196	5	9701368644367904	2008/08	user4008	password	68	80000	M
4009	RBYCXH	WHNUPVOUWS	1818698758 Dell Way	\N	UDSYFCD	WA	92324	US	1	WHNUPVOUWS@dell.com	1818698758	5	5968605405185372	2011/08	user4009	password	28	60000	M
4010	BOOILW	WFMRUHNMBR	7884302744 Dell Way	\N	FAWHDVF	HI	78326	US	1	WFMRUHNMBR@dell.com	7884302744	5	4189179396722466	2012/06	user4010	password	19	100000	F
4011	PILMEQ	YVLGJYIBDI	8747229029 Dell Way	\N	YLLTQRN	MD	70068	US	1	YVLGJYIBDI@dell.com	8747229029	2	2107190119568258	2012/04	user4011	password	27	60000	M
4012	OYTFXP	QEZOMARUYD	7487768077 Dell Way	\N	GSTYFEP	AZ	52088	US	1	QEZOMARUYD@dell.com	7487768077	5	7758548740763218	2012/06	user4012	password	43	60000	F
4013	DQGSGK	RVXSNSRQZJ	7865752150 Dell Way	\N	KXOOMPA	GA	59938	US	1	RVXSNSRQZJ@dell.com	7865752150	1	9757750400342048	2008/06	user4013	password	42	40000	F
4014	PYJAQE	YJSQAIPJSM	1427791114 Dell Way	\N	XGZNHFB	AL	34227	US	1	YJSQAIPJSM@dell.com	1427791114	1	7710771046113224	2009/05	user4014	password	79	100000	F
4015	FAZJYI	CPJKESDRQK	9016456409 Dell Way	\N	RDRWFSD	ID	86381	US	1	CPJKESDRQK@dell.com	9016456409	4	3117205432616174	2011/08	user4015	password	60	100000	M
4016	OIPXKE	GUJZYBPIST	7889002867 Dell Way	\N	ZPYRTFN	NM	85905	US	1	GUJZYBPIST@dell.com	7889002867	2	5297364532016218	2009/04	user4016	password	27	100000	M
4017	TVAXCV	HCTIRBBKBQ	8796980130 Dell Way	\N	ITKOHAK	AL	44721	US	1	HCTIRBBKBQ@dell.com	8796980130	2	7164517546538264	2012/04	user4017	password	39	80000	F
4018	IQFDYH	WGZYIJAYST	4975804082 Dell Way	\N	JHAJRBT	MT	50262	US	1	WGZYIJAYST@dell.com	4975804082	3	7692004216369242	2011/04	user4018	password	81	20000	M
4019	CEVKBC	JAKTBJMUST	1846097532 Dell Way	\N	VCKXVYJ	IL	51495	US	1	JAKTBJMUST@dell.com	1846097532	1	7408100862056018	2012/01	user4019	password	62	20000	F
4020	LMINVJ	XPKGCFZVBB	4208569999 Dell Way	\N	GYXEHEQ	MD	26590	US	1	XPKGCFZVBB@dell.com	4208569999	2	3326293578837067	2012/06	user4020	password	55	40000	M
4021	WXSFVI	PCKVBGWCMV	6402866632 Dell Way	\N	ZRDEINI	NV	90552	US	1	PCKVBGWCMV@dell.com	6402866632	4	3870735824573785	2008/01	user4021	password	33	100000	M
4022	YETGUV	RQWXMZJIZA	2873816962 Dell Way	\N	LDJZMAX	AZ	67614	US	1	RQWXMZJIZA@dell.com	2873816962	1	6951624473091216	2010/02	user4022	password	60	40000	F
4023	IPDDGT	ADGZNOZOAC	3039754849 Dell Way	\N	XAOYXQO	CO	84062	US	1	ADGZNOZOAC@dell.com	3039754849	3	9809989731758834	2012/11	user4023	password	40	20000	F
4024	LHTEIX	KHKYHZZJXZ	4329119054 Dell Way	\N	YVXOKAK	NJ	58613	US	1	KHKYHZZJXZ@dell.com	4329119054	3	4709712603129447	2011/07	user4024	password	82	20000	M
4025	QHENRM	XQTXQDUQBP	5363101049 Dell Way	\N	NQZNAPB	MA	13239	US	1	XQTXQDUQBP@dell.com	5363101049	1	6435228615999222	2009/03	user4025	password	51	100000	F
4026	QMDCKT	WIKZCAASNQ	9724415437 Dell Way	\N	SBQIDAJ	NJ	17677	US	1	WIKZCAASNQ@dell.com	9724415437	5	3294593535363674	2010/12	user4026	password	69	20000	F
4027	VEWPAE	ZZHZZANQTO	6772852384 Dell Way	\N	HBSHLHK	MD	36148	US	1	ZZHZZANQTO@dell.com	6772852384	5	3359969547018409	2009/11	user4027	password	71	20000	F
4028	PTBUTA	CTACGRVVYX	4320753450 Dell Way	\N	NGIVQTC	ID	61174	US	1	CTACGRVVYX@dell.com	4320753450	4	5125009213108570	2008/10	user4028	password	55	80000	M
4029	OMHPPB	QRHHNCFLPM	5848976142 Dell Way	\N	ULCNNJC	VT	96470	US	1	QRHHNCFLPM@dell.com	5848976142	1	7681239732075483	2008/09	user4029	password	39	80000	F
4030	PFUQWM	YDZAJLQWFB	9928835492 Dell Way	\N	YSPHUNG	KY	55995	US	1	YDZAJLQWFB@dell.com	9928835492	2	2904559243936091	2009/12	user4030	password	47	100000	F
4031	ENCQLF	QMPBCLHEKZ	1156647535 Dell Way	\N	URUHYDU	WA	55425	US	1	QMPBCLHEKZ@dell.com	1156647535	2	5533400480169803	2010/02	user4031	password	70	80000	M
4032	UGBAXN	QYQCGUMFPE	2249932916 Dell Way	\N	AWCDRBQ	OH	32504	US	1	QYQCGUMFPE@dell.com	2249932916	1	4065295915585011	2012/09	user4032	password	87	80000	M
4033	ZSWNIV	DLBYYHNCHK	8722211928 Dell Way	\N	FKBGBUN	FL	90940	US	1	DLBYYHNCHK@dell.com	8722211928	1	6653799837920815	2012/09	user4033	password	62	80000	F
4034	MHTHLF	JJDQWGYGMI	6579427672 Dell Way	\N	ITKCGPZ	CO	67788	US	1	JJDQWGYGMI@dell.com	6579427672	5	4261057875119150	2009/09	user4034	password	74	80000	F
4035	NZLSJU	WZQCXXOGFH	3169967815 Dell Way	\N	QHOGHRW	VT	63414	US	1	WZQCXXOGFH@dell.com	3169967815	1	3759553877171129	2008/11	user4035	password	41	60000	M
4036	THEODE	EFCBUJHCAO	3184930451 Dell Way	\N	RGWIDUY	LA	91653	US	1	EFCBUJHCAO@dell.com	3184930451	2	7691097164526583	2010/12	user4036	password	60	40000	F
4037	UWIYAO	BCJKJMKYDQ	3129145558 Dell Way	\N	VMTPKCM	NV	54015	US	1	BCJKJMKYDQ@dell.com	3129145558	2	4772249768953771	2012/07	user4037	password	63	60000	F
4038	ZNLOPO	XZXKJWNARA	8142479506 Dell Way	\N	UHLXTCJ	AK	40681	US	1	XZXKJWNARA@dell.com	8142479506	5	8959324569441379	2010/05	user4038	password	38	40000	M
4039	SYNGWN	EGXBUXTVRA	6364573677 Dell Way	\N	GOUJYUS	OR	65748	US	1	EGXBUXTVRA@dell.com	6364573677	1	1228383463341742	2012/07	user4039	password	88	60000	F
4040	MWIABP	XCJUWEMWLB	2009575661 Dell Way	\N	RVAMNTC	CT	91386	US	1	XCJUWEMWLB@dell.com	2009575661	5	5114348739851266	2008/08	user4040	password	87	60000	F
4041	HPNWMP	GHLLUIWVZR	9490698648 Dell Way	\N	VMFPOIM	NV	40149	US	1	GHLLUIWVZR@dell.com	9490698648	4	9395184213295580	2012/04	user4041	password	46	20000	M
4042	XBJMIQ	YTKHQGHICT	2312640515 Dell Way	\N	ORHWEZF	CO	73615	US	1	YTKHQGHICT@dell.com	2312640515	5	1240474392194300	2010/03	user4042	password	85	60000	F
4043	HXOYWH	JDYQLGSEUK	2476270864 Dell Way	\N	MROLXRD	AR	68491	US	1	JDYQLGSEUK@dell.com	2476270864	3	8420486707240344	2008/01	user4043	password	22	40000	M
4044	PIUXSY	WIJDBOYLAP	2096508603 Dell Way	\N	ZLNQPOH	PA	21825	US	1	WIJDBOYLAP@dell.com	2096508603	5	2252549440599978	2008/03	user4044	password	23	80000	M
4045	WSGVOP	FRQTPCUFCF	5837570148 Dell Way	\N	SSVGAOK	DC	47340	US	1	FRQTPCUFCF@dell.com	5837570148	2	6789408696349711	2011/02	user4045	password	33	60000	M
4046	MHJBNB	SGRVBWXGPP	7467889735 Dell Way	\N	CWQRGUB	RI	19780	US	1	SGRVBWXGPP@dell.com	7467889735	2	3039613111410290	2012/11	user4046	password	21	40000	F
4047	LMRMFY	DAZAXGPNIL	3305357055 Dell Way	\N	DZRXBLA	RI	86235	US	1	DAZAXGPNIL@dell.com	3305357055	4	7423499524593354	2009/02	user4047	password	82	80000	M
4048	OFUMJU	LJRSYEAKIA	1750559983 Dell Way	\N	BFCNGWJ	MT	61659	US	1	LJRSYEAKIA@dell.com	1750559983	5	7134918154682965	2012/07	user4048	password	37	60000	M
4049	AADVMN	MEMQEWYFYE	4710366655 Dell Way	\N	HLLEVYS	VT	80276	US	1	MEMQEWYFYE@dell.com	4710366655	5	4044711004942656	2011/05	user4049	password	26	80000	F
4050	GNWUAA	GRFDQKBUSN	3980799776 Dell Way	\N	GWIFPGZ	AK	19426	US	1	GRFDQKBUSN@dell.com	3980799776	4	5431508946232498	2010/05	user4050	password	82	80000	M
4051	TNYTTP	ZXFJYACLGY	6602379632 Dell Way	\N	UMOAMOD	SC	31777	US	1	ZXFJYACLGY@dell.com	6602379632	2	6729354778304697	2010/12	user4051	password	58	40000	F
4052	MAGCZD	HJCHLOOKIB	4552189983 Dell Way	\N	YJNNMIT	CO	61877	US	1	HJCHLOOKIB@dell.com	4552189983	4	5930816252715886	2012/11	user4052	password	19	60000	M
4053	GNWKVF	MCQBRBJTAT	7310872159 Dell Way	\N	GNGOHJD	NY	98212	US	1	MCQBRBJTAT@dell.com	7310872159	4	8661220900714398	2011/01	user4053	password	71	100000	M
4054	OKKUXN	LYFMIYMBFA	5328117822 Dell Way	\N	HUIQYZQ	NM	66317	US	1	LYFMIYMBFA@dell.com	5328117822	2	7320365729741753	2009/05	user4054	password	39	80000	M
4055	SOQGZO	LMWKZXPZFJ	6658993143 Dell Way	\N	IWHHMXY	WV	34841	US	1	LMWKZXPZFJ@dell.com	6658993143	1	6595179887488485	2012/12	user4055	password	44	80000	M
4056	ZWNOIZ	KSZIHZORHK	8017057614 Dell Way	\N	YPXWNXE	CT	16235	US	1	KSZIHZORHK@dell.com	8017057614	1	1322983525227755	2008/09	user4056	password	59	20000	M
4057	CRXCCQ	BLYAZPHKOW	3767770024 Dell Way	\N	ILJFPNH	MA	61150	US	1	BLYAZPHKOW@dell.com	3767770024	3	3448677101638168	2012/08	user4057	password	80	100000	F
4058	TALJCW	ICWXKGLGOX	9873348051 Dell Way	\N	QUMDBWS	LA	44303	US	1	ICWXKGLGOX@dell.com	9873348051	2	1280343392398208	2012/03	user4058	password	44	80000	F
4059	UZHRHK	NFUUQBJOSD	3827124170 Dell Way	\N	AWEXONH	ND	78855	US	1	NFUUQBJOSD@dell.com	3827124170	2	9554126291070134	2011/12	user4059	password	30	60000	M
4060	MDHXQM	SKDTTRMXSI	3932592815 Dell Way	\N	BPXPXLJ	GA	87174	US	1	SKDTTRMXSI@dell.com	3932592815	5	8682401638943703	2010/05	user4060	password	78	100000	F
4061	CWDOOO	RIIIUFBDHQ	2975656285 Dell Way	\N	BXNNGTJ	NH	65018	US	1	RIIIUFBDHQ@dell.com	2975656285	1	9635831725317986	2008/01	user4061	password	50	20000	M
4062	OSMCKV	KTQQUUXLVU	3492890861 Dell Way	\N	ZIBSSRI	VT	77257	US	1	KTQQUUXLVU@dell.com	3492890861	5	8344236948993058	2011/02	user4062	password	72	40000	M
4063	GJGCUZ	SKUMIFIDEQ	4595249815 Dell Way	\N	EXIVFGP	MO	31006	US	1	SKUMIFIDEQ@dell.com	4595249815	1	4203241288196296	2008/06	user4063	password	32	60000	M
4064	LMRKFB	ERKKZNPQRM	8594386442 Dell Way	\N	ZNRGCEM	MT	42726	US	1	ERKKZNPQRM@dell.com	8594386442	4	8558951992541552	2008/01	user4064	password	68	60000	M
4065	JXTLCK	VMKIBBAOBO	6413629260 Dell Way	\N	GHRKUET	NM	84867	US	1	VMKIBBAOBO@dell.com	6413629260	4	9056707976385952	2009/02	user4065	password	49	80000	F
4066	EBDPXQ	AFSBGGDUML	4166007294 Dell Way	\N	LXFQQWL	IA	58703	US	1	AFSBGGDUML@dell.com	4166007294	3	7263906084932388	2011/03	user4066	password	72	100000	F
4067	XOENOK	FQQMTLZEXW	5612254453 Dell Way	\N	KNNHZTV	KS	38284	US	1	FQQMTLZEXW@dell.com	5612254453	1	5656565653160215	2009/01	user4067	password	76	20000	M
4068	ZRFJWV	AJPLIUJEFW	3612256173 Dell Way	\N	SMVLHEU	SC	35587	US	1	AJPLIUJEFW@dell.com	3612256173	1	4284277046099305	2008/03	user4068	password	18	20000	M
4069	FLTBLC	QXLLGPQCIC	7835076367 Dell Way	\N	YTKCOFK	TN	33299	US	1	QXLLGPQCIC@dell.com	7835076367	5	5186744507402182	2011/12	user4069	password	42	100000	F
4070	BAVEQS	PCZFSBNUAH	2069496768 Dell Way	\N	FDVKNRQ	IL	61546	US	1	PCZFSBNUAH@dell.com	2069496768	1	5918260492850096	2010/01	user4070	password	87	60000	F
4071	URRNHT	MNLOAGOHLR	9158839308 Dell Way	\N	DVFUMMJ	NJ	56088	US	1	MNLOAGOHLR@dell.com	9158839308	1	5636760485824198	2012/07	user4071	password	56	80000	F
4072	EDOYQB	JECQTKBKNX	2065224218 Dell Way	\N	QIKCRAP	NE	17470	US	1	JECQTKBKNX@dell.com	2065224218	3	6996763016562910	2011/01	user4072	password	86	100000	F
4073	NTVODA	RTTBVEOSUX	9148495851 Dell Way	\N	DWOEMDG	NH	60552	US	1	RTTBVEOSUX@dell.com	9148495851	2	6642375006340445	2012/01	user4073	password	79	40000	M
4074	RYZSPS	LQOQFHKCKH	9776814888 Dell Way	\N	ROUUVJJ	OK	65305	US	1	LQOQFHKCKH@dell.com	9776814888	3	7245392790995539	2012/12	user4074	password	57	60000	M
4075	NFLGQB	UHHBRKMZBB	4778072044 Dell Way	\N	TVWCEPS	DC	23076	US	1	UHHBRKMZBB@dell.com	4778072044	5	1567437506746500	2012/06	user4075	password	84	60000	M
4076	ISIKMP	SOHCBGDCZY	7785934434 Dell Way	\N	ZCDOVHR	IA	32194	US	1	SOHCBGDCZY@dell.com	7785934434	1	7397668108344079	2011/08	user4076	password	45	20000	F
4077	RKWHDK	OFLUIOTHNW	7002046100 Dell Way	\N	LBRSTXY	MT	20682	US	1	OFLUIOTHNW@dell.com	7002046100	1	8024189566727728	2008/03	user4077	password	28	80000	M
4078	AZSLNY	XIHLCPZYAA	5041309514 Dell Way	\N	QSUORIR	KY	53583	US	1	XIHLCPZYAA@dell.com	5041309514	2	6997569058090449	2010/02	user4078	password	37	80000	F
4079	ZAQYXY	FJBVIZVJQO	6465318558 Dell Way	\N	DEFLVOY	IL	95857	US	1	FJBVIZVJQO@dell.com	6465318558	5	1572842673398554	2012/06	user4079	password	30	100000	M
4080	VVKUBT	VWCURLKFPP	1333693338 Dell Way	\N	LBKAZSZ	NH	62744	US	1	VWCURLKFPP@dell.com	1333693338	3	1600070447660982	2009/05	user4080	password	59	20000	F
4081	ZUFTPB	VKTHVZWKLX	2751512150 Dell Way	\N	VLXOKMD	MN	96380	US	1	VKTHVZWKLX@dell.com	2751512150	4	3764997231774032	2011/09	user4081	password	52	80000	F
4082	RNBTIM	NQHMMSXKOI	1390093388 Dell Way	\N	HCTUFFT	ME	89253	US	1	NQHMMSXKOI@dell.com	1390093388	1	6027080872561783	2010/12	user4082	password	19	40000	F
4083	CYUOLK	WYWOVGDEOF	6419361006 Dell Way	\N	YILEBVB	CO	11984	US	1	WYWOVGDEOF@dell.com	6419361006	4	9568323156330736	2011/10	user4083	password	46	80000	M
4084	EHGODE	KSZRVEFBDO	3707998496 Dell Way	\N	MHPIISJ	WA	40337	US	1	KSZRVEFBDO@dell.com	3707998496	3	2431674227584153	2011/04	user4084	password	86	100000	M
4085	EKSIUK	IMGNSHQGUX	1743717165 Dell Way	\N	WCGPLEY	PA	74324	US	1	IMGNSHQGUX@dell.com	1743717165	3	9870371977332980	2008/04	user4085	password	57	20000	M
4086	FNMQVZ	XIREZYZWUC	9674629941 Dell Way	\N	CKOGIIZ	MD	78096	US	1	XIREZYZWUC@dell.com	9674629941	3	1422250115312635	2010/08	user4086	password	70	80000	F
4087	FJYEGH	WLGUKDPNGZ	2490740581 Dell Way	\N	BMHJMRD	MI	18092	US	1	WLGUKDPNGZ@dell.com	2490740581	5	7179631945211441	2012/09	user4087	password	76	20000	F
4088	THHBDT	HXELMRRLSE	2758539177 Dell Way	\N	TBQKFCN	LA	13287	US	1	HXELMRRLSE@dell.com	2758539177	2	7366379855200649	2012/05	user4088	password	72	80000	M
4089	BUTUCR	YNDPFPIJJK	8863174706 Dell Way	\N	ATPDHYE	MO	27545	US	1	YNDPFPIJJK@dell.com	8863174706	3	5940844675991685	2011/03	user4089	password	31	80000	M
4090	YLCPJQ	TYVJHFSRGM	9303260250 Dell Way	\N	GJTEOFJ	ME	71382	US	1	TYVJHFSRGM@dell.com	9303260250	1	9001502331346274	2008/09	user4090	password	82	20000	F
4091	ZQMPJL	KTSQLJWXPG	4932192306 Dell Way	\N	QUUWEFO	CA	30665	US	1	KTSQLJWXPG@dell.com	4932192306	1	9285824248567224	2009/03	user4091	password	21	40000	M
4092	NWGZHZ	SXKCUISAYM	2454639426 Dell Way	\N	VVRAJTG	SD	94876	US	1	SXKCUISAYM@dell.com	2454639426	1	2544793647713959	2009/06	user4092	password	20	80000	F
4093	HTPGLN	RNHZGIYTDT	3418462863 Dell Way	\N	KEDEKYC	ND	16150	US	1	RNHZGIYTDT@dell.com	3418462863	4	5397554363589734	2009/07	user4093	password	75	60000	F
4094	JVSXMG	FLMOKFSDQW	7886810529 Dell Way	\N	HUGFWVH	DC	64095	US	1	FLMOKFSDQW@dell.com	7886810529	3	2075791124720126	2010/01	user4094	password	45	100000	M
4095	BVIIBU	UPEAHIQDPK	9505089680 Dell Way	\N	KVHFCLV	TX	88671	US	1	UPEAHIQDPK@dell.com	9505089680	3	9084383889101448	2009/05	user4095	password	72	40000	F
4096	CSFXNU	CNCKEFAOPV	1528983091 Dell Way	\N	WVXHRTE	NJ	24249	US	1	CNCKEFAOPV@dell.com	1528983091	5	5493631098885089	2012/04	user4096	password	67	100000	F
4097	XUNSWB	UHFZHUPDQL	5000557464 Dell Way	\N	AXCUCSY	CT	68356	US	1	UHFZHUPDQL@dell.com	5000557464	5	9712052654009312	2008/11	user4097	password	90	20000	M
4098	NSNONV	UNDOCGEOHC	1142519180 Dell Way	\N	RCEKAIB	MO	33097	US	1	UNDOCGEOHC@dell.com	1142519180	3	1982604947406798	2008/08	user4098	password	73	60000	F
4099	HCVDWI	GLLNPAVSSX	5969128264 Dell Way	\N	WCYEDKL	DC	10416	US	1	GLLNPAVSSX@dell.com	5969128264	1	6566634264308960	2009/09	user4099	password	87	80000	M
4100	UTRDAD	PNSPJLHGHJ	3109563324 Dell Way	\N	FMNPYRQ	MO	85838	US	1	PNSPJLHGHJ@dell.com	3109563324	5	5896216255147011	2008/05	user4100	password	43	100000	F
4101	BCDERR	WHBIOHQYNC	5684977949 Dell Way	\N	LDBDTNZ	WV	39770	US	1	WHBIOHQYNC@dell.com	5684977949	1	7685177013743670	2012/02	user4101	password	83	100000	F
4102	BBXSYE	UGTBWRPZDS	6683367495 Dell Way	\N	AHLOGKX	RI	60284	US	1	UGTBWRPZDS@dell.com	6683367495	4	7202753898687661	2010/07	user4102	password	85	60000	M
4103	VHOABV	TDSLTSPLSW	5685445563 Dell Way	\N	WHCHEWV	SC	57047	US	1	TDSLTSPLSW@dell.com	5685445563	2	1696392894256860	2010/11	user4103	password	69	40000	F
4104	HHHCBK	VMDNCPGYLN	5732824237 Dell Way	\N	BSRYOML	CA	83803	US	1	VMDNCPGYLN@dell.com	5732824237	3	7458596229553223	2009/10	user4104	password	84	60000	F
4105	EPDPLQ	TYSJERUSSN	4781038940 Dell Way	\N	KQCWCES	NH	72408	US	1	TYSJERUSSN@dell.com	4781038940	5	5414356219582260	2009/04	user4105	password	60	60000	M
4106	SDJJXH	CGMTBELOOB	1194989466 Dell Way	\N	RLDVDTN	NE	62083	US	1	CGMTBELOOB@dell.com	1194989466	5	9167685149703176	2011/06	user4106	password	79	40000	M
4107	FRLNTS	ZNTEYISAZE	4541354689 Dell Way	\N	EVIXJXM	MA	81757	US	1	ZNTEYISAZE@dell.com	4541354689	5	3057092531118542	2009/04	user4107	password	75	60000	M
4108	GYTYYG	RCFAUFZZJV	2919853157 Dell Way	\N	HHEETOZ	DC	57397	US	1	RCFAUFZZJV@dell.com	2919853157	2	8447559139691294	2008/10	user4108	password	77	40000	M
4109	OFSVXU	AXPFXOPSWW	8209301136 Dell Way	\N	XBQLATZ	IA	24112	US	1	AXPFXOPSWW@dell.com	8209301136	2	9872612074483188	2011/07	user4109	password	73	20000	M
4110	LZPGAN	VFLKVDGRBI	2795178236 Dell Way	\N	HMIBMPF	ID	86356	US	1	VFLKVDGRBI@dell.com	2795178236	5	4228967339731753	2012/01	user4110	password	23	60000	F
4111	RRBFMH	QXCUDUVLBI	6448810069 Dell Way	\N	UDUKIBG	NC	95280	US	1	QXCUDUVLBI@dell.com	6448810069	3	1082170567009598	2011/11	user4111	password	22	40000	M
4112	DOBLFY	NZCIVOJEJN	9742137672 Dell Way	\N	YTWAAKZ	NJ	89786	US	1	NZCIVOJEJN@dell.com	9742137672	2	8215815836563707	2008/08	user4112	password	45	20000	F
4113	LPLKDL	MLHBVLKIJE	3385413782 Dell Way	\N	EKEOJUM	KS	18422	US	1	MLHBVLKIJE@dell.com	3385413782	2	7785131670068950	2011/07	user4113	password	90	20000	F
4114	LMGWZS	DANOLWYQBI	5099107879 Dell Way	\N	UQSPCAS	LA	44151	US	1	DANOLWYQBI@dell.com	5099107879	1	9192323217634112	2010/01	user4114	password	20	100000	M
4115	HTNZXO	NMZJLQLULB	7988882132 Dell Way	\N	MAEMTNW	FL	57078	US	1	NMZJLQLULB@dell.com	7988882132	4	6456164150033147	2012/07	user4115	password	30	20000	F
4116	SCEGPR	GZCWLWHNJI	3876317300 Dell Way	\N	RVBESGS	MO	91228	US	1	GZCWLWHNJI@dell.com	3876317300	2	4801315619144589	2010/05	user4116	password	69	20000	F
4117	XLCORC	RONOWBXFST	8726914112 Dell Way	\N	GXLNPYL	WA	31270	US	1	RONOWBXFST@dell.com	8726914112	3	6718155771959574	2010/08	user4117	password	27	60000	F
4118	GASISH	WGDXEJQXQN	2741783120 Dell Way	\N	JDDIPBO	MI	54234	US	1	WGDXEJQXQN@dell.com	2741783120	1	1836745264474302	2009/06	user4118	password	27	60000	F
4119	WXEDTL	HRPQINGVXK	6730395420 Dell Way	\N	ZGZBULO	WY	50223	US	1	HRPQINGVXK@dell.com	6730395420	2	9164437116123736	2011/11	user4119	password	46	80000	M
4120	OUNABF	PSNDZJBKIH	2624686466 Dell Way	\N	KKBVYBH	NE	41909	US	1	PSNDZJBKIH@dell.com	2624686466	2	2944642686750740	2010/12	user4120	password	88	20000	M
4121	MDVSTN	FXNPYXYFHI	9141766746 Dell Way	\N	HCGIJVR	ND	26307	US	1	FXNPYXYFHI@dell.com	9141766746	1	2346850452944636	2012/04	user4121	password	83	40000	F
4122	SCEGIB	TXZQVFYEMA	6353037525 Dell Way	\N	LVKGNZL	ME	20097	US	1	TXZQVFYEMA@dell.com	6353037525	2	4440220326185227	2010/09	user4122	password	75	20000	M
4123	YLBAEY	AVUFTYSUJO	7012234396 Dell Way	\N	FQBECMH	NY	80338	US	1	AVUFTYSUJO@dell.com	7012234396	1	5070887834299356	2010/05	user4123	password	32	60000	M
4124	GLZFLU	ARNYJHIXMZ	7273083330 Dell Way	\N	ZRBMYTG	NJ	91044	US	1	ARNYJHIXMZ@dell.com	7273083330	1	3330381491687149	2012/07	user4124	password	21	20000	M
4125	AJJUJB	IIKPRICQIU	6321354489 Dell Way	\N	SUSLAII	OR	48538	US	1	IIKPRICQIU@dell.com	6321354489	4	9391209510620684	2011/10	user4125	password	81	80000	F
4126	GLNHTW	SJOBMEJGWE	6987034816 Dell Way	\N	YIFHQXT	IA	58949	US	1	SJOBMEJGWE@dell.com	6987034816	5	3935653157532215	2010/07	user4126	password	53	80000	M
4127	ACSXVB	LWNQGTNKSV	4626112573 Dell Way	\N	PAMNTSB	ME	63756	US	1	LWNQGTNKSV@dell.com	4626112573	5	2102039176039397	2012/10	user4127	password	24	100000	M
4128	UURWGN	KWUEKFXFVX	2247149982 Dell Way	\N	SJRKLCA	TN	17288	US	1	KWUEKFXFVX@dell.com	2247149982	4	8550371287390591	2009/08	user4128	password	68	20000	F
4129	JWRWHO	RLYWIERGWA	9641022298 Dell Way	\N	YHMBHHD	ME	10732	US	1	RLYWIERGWA@dell.com	9641022298	4	6673714954871685	2011/08	user4129	password	22	100000	M
4130	SWVHNG	FKOJCVFDTM	5652456462 Dell Way	\N	PUUWXFX	TX	87248	US	1	FKOJCVFDTM@dell.com	5652456462	3	5722303566057236	2010/07	user4130	password	23	40000	F
4131	WOXDUI	SDKNJNGVCA	2945534655 Dell Way	\N	QZYVWUR	MA	36019	US	1	SDKNJNGVCA@dell.com	2945534655	5	8103104279842228	2009/04	user4131	password	29	20000	M
4132	BHPJAT	UNCHTYKUPK	6214393169 Dell Way	\N	SKHNCRU	KS	66942	US	1	UNCHTYKUPK@dell.com	6214393169	4	9058645700570196	2011/10	user4132	password	71	100000	F
4133	IFBCZP	FHJDSDSCWD	6151649347 Dell Way	\N	JJGBEOR	OR	24045	US	1	FHJDSDSCWD@dell.com	6151649347	3	9348203859757632	2009/04	user4133	password	18	80000	F
4134	BSLRYT	ABLEUNBYXK	8207401780 Dell Way	\N	EYOSQIW	GA	81644	US	1	ABLEUNBYXK@dell.com	8207401780	3	1792619829066097	2012/02	user4134	password	59	100000	M
4135	AOUUOW	FTRTUPRFTP	9906970748 Dell Way	\N	UMGCJLX	DC	95828	US	1	FTRTUPRFTP@dell.com	9906970748	5	1893158025108277	2010/10	user4135	password	89	60000	F
4136	UJYQPS	IIMXZSRPMD	4117609183 Dell Way	\N	VPMHNQG	MS	61814	US	1	IIMXZSRPMD@dell.com	4117609183	1	4621138542890549	2009/08	user4136	password	74	20000	F
4137	STPKBY	XYYQPNDTJS	8382630072 Dell Way	\N	FRFVXSK	ID	80164	US	1	XYYQPNDTJS@dell.com	8382630072	3	4913659574929625	2010/09	user4137	password	51	40000	F
4138	BTMAQK	YGAMJTWCZN	3419786341 Dell Way	\N	IVLBFSV	AR	37681	US	1	YGAMJTWCZN@dell.com	3419786341	4	9894340037833900	2011/12	user4138	password	47	100000	M
4139	WVIHUP	HGZBDCARLV	2197310850 Dell Way	\N	DMBVIDD	NH	78767	US	1	HGZBDCARLV@dell.com	2197310850	2	7537948285229505	2010/02	user4139	password	48	60000	M
4140	TSSJZZ	JBDMCUXXXK	6335253633 Dell Way	\N	ZSSCWHW	AK	65844	US	1	JBDMCUXXXK@dell.com	6335253633	3	7735434071160854	2008/12	user4140	password	69	80000	M
4141	LEQKNS	NZUIXSFHRY	6963767524 Dell Way	\N	ZUVHQVX	IA	43174	US	1	NZUIXSFHRY@dell.com	6963767524	2	3952368353027850	2009/01	user4141	password	89	80000	F
4142	QFSITS	DBQVHXNFXH	5923881271 Dell Way	\N	AFYWCEF	RI	50408	US	1	DBQVHXNFXH@dell.com	5923881271	1	5425609783735126	2010/12	user4142	password	68	20000	F
4143	KNXDQZ	TLGRYMOGMT	3881245096 Dell Way	\N	EJWJOQV	CO	79138	US	1	TLGRYMOGMT@dell.com	3881245096	4	7278652266599239	2008/10	user4143	password	79	60000	F
4144	TOYSIK	ZZJLOPYIUH	3543089199 Dell Way	\N	EEWVZZP	KS	65870	US	1	ZZJLOPYIUH@dell.com	3543089199	2	4885605730582029	2008/10	user4144	password	72	100000	F
4145	RPRCOR	LAFAYOVGSZ	2193794390 Dell Way	\N	COZCDIS	MD	67883	US	1	LAFAYOVGSZ@dell.com	2193794390	3	4637051783036441	2012/05	user4145	password	71	60000	F
4146	KROBCP	HDOVZUOYXC	3832483064 Dell Way	\N	YZFGRQX	SD	24732	US	1	HDOVZUOYXC@dell.com	3832483064	4	6165934713557363	2008/04	user4146	password	60	60000	M
4147	ENATUD	HQDBEBZHAY	8800381519 Dell Way	\N	NHPDFKH	MT	19819	US	1	HQDBEBZHAY@dell.com	8800381519	3	4320678130257875	2010/01	user4147	password	39	80000	M
4148	HJJLQZ	OSEQRLRQYZ	2196955512 Dell Way	\N	GCERJST	IA	35119	US	1	OSEQRLRQYZ@dell.com	2196955512	4	3759684907272458	2010/04	user4148	password	80	80000	M
4149	FEHETZ	JKRVCHTBNW	5842560650 Dell Way	\N	GEFYYMG	AZ	23913	US	1	JKRVCHTBNW@dell.com	5842560650	3	5019690423738212	2009/03	user4149	password	24	60000	F
4150	JUEIDO	AYRHSSUOZY	8663357074 Dell Way	\N	UXWGDYK	OH	48379	US	1	AYRHSSUOZY@dell.com	8663357074	1	6736992624122650	2012/09	user4150	password	20	40000	F
4151	FQPTQN	KXGDSVCRPA	5889308489 Dell Way	\N	NWEMGWX	CO	95157	US	1	KXGDSVCRPA@dell.com	5889308489	1	6560750503558666	2010/05	user4151	password	23	80000	M
4152	RNPFYN	LCGGFXWFLS	8446244052 Dell Way	\N	KXYGVBF	KY	18597	US	1	LCGGFXWFLS@dell.com	8446244052	5	4895419271197170	2012/09	user4152	password	47	60000	F
4153	ATEOEH	ULMRHRCZCZ	5787743213 Dell Way	\N	YIVAOEC	MA	18300	US	1	ULMRHRCZCZ@dell.com	5787743213	2	8147182491607965	2012/10	user4153	password	20	100000	M
4154	FNTMHF	YZNQBNSBLB	9284265864 Dell Way	\N	WLPAOZD	CA	34148	US	1	YZNQBNSBLB@dell.com	9284265864	1	1877962451893836	2012/12	user4154	password	67	20000	M
4155	LQUQPU	EFVRYXCZUO	9654716542 Dell Way	\N	PUDPYFW	TX	32059	US	1	EFVRYXCZUO@dell.com	9654716542	4	3121107367798686	2011/12	user4155	password	71	20000	M
4156	OSFIWK	DNJBQJVFYP	1378301735 Dell Way	\N	IOOOKKU	MA	27729	US	1	DNJBQJVFYP@dell.com	1378301735	1	2414646517019719	2011/01	user4156	password	73	40000	M
4157	YQRJUF	SVWCQBAGKP	5843456168 Dell Way	\N	UZZEUJJ	SD	44134	US	1	SVWCQBAGKP@dell.com	5843456168	4	5136222527362406	2009/12	user4157	password	36	40000	M
4158	YQIDJD	ZLTBMALBUL	3334697430 Dell Way	\N	BZFKJAU	VA	67367	US	1	ZLTBMALBUL@dell.com	3334697430	1	6054824159014971	2010/06	user4158	password	26	60000	F
4159	LPLPOW	JPJJBKENMD	9588822789 Dell Way	\N	SWNTRKK	WI	64483	US	1	JPJJBKENMD@dell.com	9588822789	3	1532927132677286	2008/11	user4159	password	28	60000	F
4160	PCBMMR	VVTGZGSDYP	7484202009 Dell Way	\N	QSGBCFR	AZ	70335	US	1	VVTGZGSDYP@dell.com	7484202009	1	6191167884040624	2012/08	user4160	password	22	60000	M
4161	CXFUTB	NZBTSFSHVL	1058352215 Dell Way	\N	OXNTOPL	IL	75917	US	1	NZBTSFSHVL@dell.com	1058352215	1	4454472482670099	2008/08	user4161	password	28	20000	M
4162	JYGKLG	MFYRXGNIUK	6276403708 Dell Way	\N	WOZMZGF	WV	44820	US	1	MFYRXGNIUK@dell.com	6276403708	1	9833775410428644	2011/03	user4162	password	54	20000	F
4163	TNQAZV	ZQTFDCZOZN	2058819631 Dell Way	\N	NLNTQMD	HI	57332	US	1	ZQTFDCZOZN@dell.com	2058819631	5	7778626692947001	2011/01	user4163	password	86	40000	M
4164	OKNKJE	EPHHPWGDJR	4424327864 Dell Way	\N	QCICGOQ	LA	55236	US	1	EPHHPWGDJR@dell.com	4424327864	5	5930453194770963	2009/05	user4164	password	25	100000	M
4165	QHDUMT	CTIYZLHRBK	6309313286 Dell Way	\N	ZEQOUAB	FL	97649	US	1	CTIYZLHRBK@dell.com	6309313286	3	3964182050433010	2011/05	user4165	password	24	40000	M
4166	GCEZFX	HDXTLOVWOZ	8200584644 Dell Way	\N	MCUMDZM	OR	51032	US	1	HDXTLOVWOZ@dell.com	8200584644	3	8505808869842441	2012/09	user4166	password	55	20000	M
4167	RCBPKF	MERBZNQZAT	1185149074 Dell Way	\N	TNXSZQE	RI	16295	US	1	MERBZNQZAT@dell.com	1185149074	4	8361233411822469	2010/10	user4167	password	67	40000	M
4168	TUIYHM	QJMDALETFR	2759130428 Dell Way	\N	RYQHDLJ	DE	19626	US	1	QJMDALETFR@dell.com	2759130428	4	9198084942065180	2012/11	user4168	password	78	80000	M
4169	DOAQEK	DIKPMEVDWU	3193919229 Dell Way	\N	UEXFOCI	OR	80661	US	1	DIKPMEVDWU@dell.com	3193919229	4	7315483032260091	2008/03	user4169	password	48	40000	M
4170	LWZWZH	HOTLKXIESM	6867807306 Dell Way	\N	CYAEGTY	MS	42020	US	1	HOTLKXIESM@dell.com	6867807306	3	6153494498226792	2008/10	user4170	password	43	60000	M
4171	IJQPQF	JCPHKTZXWY	6222707066 Dell Way	\N	XAEQZSA	NJ	34319	US	1	JCPHKTZXWY@dell.com	6222707066	4	1551474436186254	2012/03	user4171	password	70	40000	M
4172	JWGOGI	ENTYNQULOV	6995473326 Dell Way	\N	QFUIFKP	SC	17966	US	1	ENTYNQULOV@dell.com	6995473326	4	3779336363077164	2009/12	user4172	password	84	80000	M
4173	DHCMMQ	GKDXFPLAGR	6224080093 Dell Way	\N	UOWEERH	TN	44322	US	1	GKDXFPLAGR@dell.com	6224080093	2	4255214422941208	2010/12	user4173	password	33	80000	F
4174	HDSXJD	BHIRTJXKDM	6870170407 Dell Way	\N	GIQXPMH	FL	72692	US	1	BHIRTJXKDM@dell.com	6870170407	4	6833824275527150	2012/04	user4174	password	83	20000	F
4175	QBUTDC	CUVLRFPDLX	6411974295 Dell Way	\N	UJNGRRY	IN	41797	US	1	CUVLRFPDLX@dell.com	6411974295	1	6853194832801819	2010/04	user4175	password	23	20000	F
4176	WWNYZI	UKZZADLXXV	2115456562 Dell Way	\N	LEMDDUM	OR	95116	US	1	UKZZADLXXV@dell.com	2115456562	2	3432879108469933	2008/05	user4176	password	66	20000	F
4177	FAFNVP	NUPQGNOBZT	5565126884 Dell Way	\N	NCXHOQG	NY	86746	US	1	NUPQGNOBZT@dell.com	5565126884	5	2856574843171984	2008/12	user4177	password	49	40000	M
4178	QWUGKP	WAVKPXJJKL	9372088629 Dell Way	\N	GSZWYRS	MI	59072	US	1	WAVKPXJJKL@dell.com	9372088629	4	5489525148179382	2009/12	user4178	password	53	100000	M
4179	HGGXCH	TMXQVGBGNT	9539580608 Dell Way	\N	GKRXCDL	AL	76614	US	1	TMXQVGBGNT@dell.com	9539580608	3	7503453220706434	2010/05	user4179	password	60	80000	M
4180	VQSCJE	AAAGBGUUNE	1628128864 Dell Way	\N	MKHPWIJ	SD	74324	US	1	AAAGBGUUNE@dell.com	1628128864	2	2008508012164384	2011/12	user4180	password	72	60000	M
4181	MPZQPZ	RWBYQWLUIV	2910926988 Dell Way	\N	BYRKHMC	LA	76083	US	1	RWBYQWLUIV@dell.com	2910926988	1	7384137298446149	2012/06	user4181	password	41	60000	F
4182	HBRHTN	JREFCZOYBN	5932501245 Dell Way	\N	PLUCNEV	OR	26131	US	1	JREFCZOYBN@dell.com	5932501245	4	7064160558860750	2012/02	user4182	password	73	20000	F
4183	LMXYVP	DARCPPDCFO	9054557502 Dell Way	\N	WICBEVF	OH	58254	US	1	DARCPPDCFO@dell.com	9054557502	3	6857037025969476	2011/09	user4183	password	79	20000	F
4184	TAAIEB	AGQPKSVZPD	1844485956 Dell Way	\N	BQHXWZL	OR	60993	US	1	AGQPKSVZPD@dell.com	1844485956	2	3696108938660473	2012/06	user4184	password	54	80000	M
4185	NAROBY	ERIWMILQJC	8107294854 Dell Way	\N	YHYYSRM	SD	15991	US	1	ERIWMILQJC@dell.com	8107294854	4	5837659889832140	2009/06	user4185	password	21	80000	F
4186	SINRNE	ZKQHWHRYFY	2330940247 Dell Way	\N	WDROQNP	MD	32860	US	1	ZKQHWHRYFY@dell.com	2330940247	4	7211837652139366	2008/06	user4186	password	29	100000	M
4187	ROJVOT	MWPTONZNKC	6768338942 Dell Way	\N	EYSSODY	OH	83627	US	1	MWPTONZNKC@dell.com	6768338942	5	3755804668646306	2011/10	user4187	password	28	60000	F
4188	MHYFUV	VNJINWTPBR	6080808415 Dell Way	\N	ITFLSYG	KY	83744	US	1	VNJINWTPBR@dell.com	6080808415	1	6646278923843057	2011/08	user4188	password	18	20000	M
4189	YKRUFF	DOSZHHBZPV	6267575033 Dell Way	\N	FBNDIWY	UT	11369	US	1	DOSZHHBZPV@dell.com	6267575033	3	6552026237361134	2010/10	user4189	password	54	60000	F
4190	EIKJLZ	BLHJNGZIMA	4126394352 Dell Way	\N	VQISOFS	DE	82037	US	1	BLHJNGZIMA@dell.com	4126394352	4	6122114530298859	2012/04	user4190	password	72	20000	M
4191	EJBDLN	KUARUIEUEU	7642652865 Dell Way	\N	DXJJQNE	WV	33817	US	1	KUARUIEUEU@dell.com	7642652865	5	6074060425627977	2010/11	user4191	password	31	80000	F
4192	GURTFM	TWGCBBHVFE	5641754038 Dell Way	\N	EPURTTY	MO	62431	US	1	TWGCBBHVFE@dell.com	5641754038	5	4852388617116958	2011/08	user4192	password	65	100000	F
4193	IRPULM	BONDVJIZNX	5821712531 Dell Way	\N	TFRNEDC	NY	20371	US	1	BONDVJIZNX@dell.com	5821712531	2	7621646797750146	2008/04	user4193	password	28	60000	M
4194	TILFKZ	TNUCWUQTOW	4654103373 Dell Way	\N	KBAOESR	OK	17030	US	1	TNUCWUQTOW@dell.com	4654103373	5	4520336819812656	2010/06	user4194	password	46	40000	M
4195	VNDVGR	QJNKAHYWRA	1449642799 Dell Way	\N	WGEPXXR	KS	82931	US	1	QJNKAHYWRA@dell.com	1449642799	5	3161985109094530	2010/02	user4195	password	18	40000	M
4196	DCXVSH	ICHPBEHBBN	2800360251 Dell Way	\N	GQLDHTY	KY	64536	US	1	ICHPBEHBBN@dell.com	2800360251	4	7746929566375912	2009/01	user4196	password	47	40000	F
4197	IEVQNY	YCZCKBDXHU	5102998536 Dell Way	\N	JLBCKKS	NH	26070	US	1	YCZCKBDXHU@dell.com	5102998536	5	3041484287474304	2012/02	user4197	password	44	20000	F
4198	FUVETY	DVIFZGMTQY	6600013856 Dell Way	\N	VSIFKYK	UT	76935	US	1	DVIFZGMTQY@dell.com	6600013856	4	9107241900637748	2012/12	user4198	password	34	20000	M
4199	BJMANH	JSHQEAGDVY	1405011478 Dell Way	\N	LBJKLGD	AZ	99203	US	1	JSHQEAGDVY@dell.com	1405011478	1	9232293198816480	2009/04	user4199	password	65	40000	M
4200	CJCKSV	RIZSODONPP	1513115159 Dell Way	\N	XZBDDDD	DE	26250	US	1	RIZSODONPP@dell.com	1513115159	3	4932044303044677	2011/10	user4200	password	21	100000	F
4201	EFWZXF	ZPUCDHRSFR	5588756626 Dell Way	\N	UJUXMYB	NC	46589	US	1	ZPUCDHRSFR@dell.com	5588756626	2	2798403609544039	2010/01	user4201	password	43	80000	F
4202	FRELQT	FTXMKPSBJB	4732347371 Dell Way	\N	WHNVJCF	TX	40175	US	1	FTXMKPSBJB@dell.com	4732347371	3	4560269748792052	2011/02	user4202	password	66	100000	M
4203	VKLPPF	MCPCURMWNT	2836497331 Dell Way	\N	KICMOZV	WI	44058	US	1	MCPCURMWNT@dell.com	2836497331	4	5567648668307812	2012/09	user4203	password	41	80000	F
4204	UHTZUV	OWQGJMTCWC	1492966157 Dell Way	\N	FJQEEPO	LA	38798	US	1	OWQGJMTCWC@dell.com	1492966157	2	1286052851472050	2009/12	user4204	password	29	20000	F
4205	XCBSRX	JYGWRJTUOC	4280940797 Dell Way	\N	KTHAHQI	KY	89695	US	1	JYGWRJTUOC@dell.com	4280940797	4	8558976199477912	2010/11	user4205	password	25	60000	M
4206	DDRBMP	IJHRCBGFMZ	8751265389 Dell Way	\N	MMHDVQA	FL	41277	US	1	IJHRCBGFMZ@dell.com	8751265389	4	2889560159295797	2012/02	user4206	password	31	20000	F
4207	WDTLLC	SDFUKLGKYT	8849780349 Dell Way	\N	RBPICUR	WI	54170	US	1	SDFUKLGKYT@dell.com	8849780349	5	6441134278662503	2008/01	user4207	password	79	100000	F
4208	PJQSBT	XWEJDOHWGJ	4140343386 Dell Way	\N	MOMGFLT	CA	41180	US	1	XWEJDOHWGJ@dell.com	4140343386	1	4221778692677617	2008/01	user4208	password	55	80000	F
4209	DMMXKI	BTLQBIWLVK	1465139919 Dell Way	\N	XBQJVSS	DE	88479	US	1	BTLQBIWLVK@dell.com	1465139919	2	9367847491055728	2010/02	user4209	password	42	80000	M
4210	VPADRU	PHWYDHTOFV	7361280431 Dell Way	\N	EOQXGUU	IN	23200	US	1	PHWYDHTOFV@dell.com	7361280431	5	3589046981651336	2008/07	user4210	password	84	100000	F
4211	YAVSPD	OOGWHUCDZQ	9810070814 Dell Way	\N	TXXORFR	MA	17304	US	1	OOGWHUCDZQ@dell.com	9810070814	3	6923526812344790	2012/04	user4211	password	79	100000	F
4212	ROWUDL	BZSVBWVSPS	6101836862 Dell Way	\N	QDJVVTX	SD	25230	US	1	BZSVBWVSPS@dell.com	6101836862	4	4976196338422597	2010/07	user4212	password	70	20000	F
4213	PWFAXE	TTGPPZFHPJ	1341734404 Dell Way	\N	RKFLIAP	VA	76051	US	1	TTGPPZFHPJ@dell.com	1341734404	2	3392607814632356	2011/05	user4213	password	42	40000	F
4214	NJESDX	ZTMYYUOILZ	5957959264 Dell Way	\N	NWHOMFH	MT	54570	US	1	ZTMYYUOILZ@dell.com	5957959264	2	8865773909259588	2012/08	user4214	password	26	60000	F
4215	HDDECW	RBVLPEXORT	4776554760 Dell Way	\N	WGGBNTO	AZ	11454	US	1	RBVLPEXORT@dell.com	4776554760	5	6730170341674239	2010/05	user4215	password	64	100000	M
4216	UZQRRS	NCHRZWJTSP	4567396503 Dell Way	\N	ZUDTIFT	OR	25710	US	1	NCHRZWJTSP@dell.com	4567396503	2	6131682191975415	2008/02	user4216	password	25	100000	F
4217	TMTLZV	TQVQZPJPPD	7079844092 Dell Way	\N	SILYCEC	MO	50387	US	1	TQVQZPJPPD@dell.com	7079844092	3	5851177456323058	2011/04	user4217	password	63	60000	M
4218	JZUFTK	BKKQTAFWTN	5066935129 Dell Way	\N	HRPMUCX	MI	63737	US	1	BKKQTAFWTN@dell.com	5066935129	2	9287547538522632	2008/10	user4218	password	70	60000	M
4219	MQNXRX	IIQINNBBUS	3269411817 Dell Way	\N	QGMTEYI	NJ	25337	US	1	IIQINNBBUS@dell.com	3269411817	4	9441797468811276	2012/02	user4219	password	69	60000	M
4220	FJMDRU	UZIHAJCTAJ	3640103358 Dell Way	\N	GTNECEJ	KY	87099	US	1	UZIHAJCTAJ@dell.com	3640103358	2	1009455436374992	2012/10	user4220	password	76	40000	F
4221	HJTCET	KLUUONUXUO	5094705452 Dell Way	\N	LYQPIYL	NH	33573	US	1	KLUUONUXUO@dell.com	5094705452	4	1164343158248811	2009/10	user4221	password	27	60000	F
4222	XQJQBV	KVJYQHSETR	1248049222 Dell Way	\N	UIZTUPA	IA	27770	US	1	KVJYQHSETR@dell.com	1248049222	3	1238210268318653	2008/01	user4222	password	34	20000	M
4223	PRSKCN	UBDBTHULCD	3188232364 Dell Way	\N	LVXAVEF	UT	68013	US	1	UBDBTHULCD@dell.com	3188232364	1	7062214239034802	2010/01	user4223	password	42	20000	M
4224	ALWOGX	RIRZDCBGNX	6800021795 Dell Way	\N	EOTITPZ	AK	67277	US	1	RIRZDCBGNX@dell.com	6800021795	3	7363735570106656	2012/07	user4224	password	51	20000	M
4225	IOGFGO	XGRAHYNFCC	9169367917 Dell Way	\N	YLWOKWF	AR	40281	US	1	XGRAHYNFCC@dell.com	9169367917	1	8797662044409663	2009/01	user4225	password	80	80000	M
4226	CYVQVB	HVJGJOILNT	4218888566 Dell Way	\N	HCDEHEM	FL	28450	US	1	HVJGJOILNT@dell.com	4218888566	3	3046176154166460	2009/04	user4226	password	77	40000	F
4227	QYASGV	BMFQVQDOYG	4019812460 Dell Way	\N	SCNXPSC	WI	35682	US	1	BMFQVQDOYG@dell.com	4019812460	1	5930663262028248	2008/06	user4227	password	71	80000	F
4228	TMQPOD	UEYLIMKOFM	6783898299 Dell Way	\N	CCBVFAC	ND	26504	US	1	UEYLIMKOFM@dell.com	6783898299	4	6807557997759432	2009/06	user4228	password	21	20000	M
4229	RSMVNR	TYZGIOLVQO	7767220410 Dell Way	\N	XLUYOIC	FL	12027	US	1	TYZGIOLVQO@dell.com	7767220410	3	5509213207755238	2011/09	user4229	password	51	60000	F
4230	YHYQAX	PHGESBVGYH	8953292386 Dell Way	\N	AWVJZAJ	OR	64163	US	1	PHGESBVGYH@dell.com	8953292386	3	3746863156091422	2009/01	user4230	password	71	40000	F
4231	RXJONQ	USIVNPUUQR	6128874841 Dell Way	\N	QARRKKG	ID	95561	US	1	USIVNPUUQR@dell.com	6128874841	4	9760913751553744	2009/11	user4231	password	39	100000	M
4232	QNJHHB	QDPFYJWQAW	6814773412 Dell Way	\N	IRGSYNR	MT	21834	US	1	QDPFYJWQAW@dell.com	6814773412	5	1319592881947755	2012/10	user4232	password	80	60000	F
4233	FWPGMT	VSRFOIGLQX	4456164751 Dell Way	\N	SJWFAJJ	NY	26469	US	1	VSRFOIGLQX@dell.com	4456164751	4	9610082912724466	2009/03	user4233	password	36	60000	F
4234	VSOPNG	HTVPZHFXZP	3406496456 Dell Way	\N	TEPDNHI	VT	91264	US	1	HTVPZHFXZP@dell.com	3406496456	1	1934324615169316	2010/08	user4234	password	30	40000	F
4235	SYVZFP	UUPBAMAQGF	5751502034 Dell Way	\N	GJTNRRL	WA	82977	US	1	UUPBAMAQGF@dell.com	5751502034	3	4672782570589334	2011/10	user4235	password	69	60000	M
4236	OJYDET	SGUEHKLMQU	2059243320 Dell Way	\N	GDLXOKS	CO	86731	US	1	SGUEHKLMQU@dell.com	2059243320	4	6943756376393140	2012/03	user4236	password	47	40000	M
4237	JNUCFA	WKIGVVXQBA	9871760682 Dell Way	\N	BYPMRSI	RI	54931	US	1	WKIGVVXQBA@dell.com	9871760682	4	7373407666105778	2009/12	user4237	password	40	80000	F
4238	CVRCSC	KZYFWOHXQF	4641512967 Dell Way	\N	MCWFKRS	MD	33229	US	1	KZYFWOHXQF@dell.com	4641512967	4	3051136656664312	2011/07	user4238	password	69	80000	F
4239	KXBMIA	KNWYVTOAGR	1535014176 Dell Way	\N	XLBODMV	NC	33320	US	1	KNWYVTOAGR@dell.com	1535014176	2	8036332161631436	2011/01	user4239	password	27	20000	M
4240	EQGFBU	BAPVOQBGNN	8371199897 Dell Way	\N	HCRUYFA	WY	51250	US	1	BAPVOQBGNN@dell.com	8371199897	4	5464145181234926	2012/11	user4240	password	49	20000	M
4241	RIPLKP	AFEQHKEVSG	6708093540 Dell Way	\N	MNFRNFD	LA	96411	US	1	AFEQHKEVSG@dell.com	6708093540	2	8828035928308965	2008/06	user4241	password	48	80000	M
4242	AEEQEK	VUSFZNYGAL	5254791144 Dell Way	\N	LRZQVIP	MN	68675	US	1	VUSFZNYGAL@dell.com	5254791144	3	1894471909385174	2012/03	user4242	password	82	100000	F
4243	BNOMIJ	FOITNOTZAL	1381252848 Dell Way	\N	YQHHGTY	OK	32568	US	1	FOITNOTZAL@dell.com	1381252848	4	5420528062153608	2012/07	user4243	password	82	20000	F
4244	LMKVSZ	DLMSFLSRKJ	4590760384 Dell Way	\N	YSPRQIX	NY	95539	US	1	DLMSFLSRKJ@dell.com	4590760384	4	5280191969592124	2009/08	user4244	password	57	80000	F
4245	YOVXSH	KKMWDDGMBY	8732922177 Dell Way	\N	CSPLQHJ	AL	88957	US	1	KKMWDDGMBY@dell.com	8732922177	2	5371248301118613	2009/01	user4245	password	61	40000	M
4246	KGHRRS	ENVHUIJTKC	9776587835 Dell Way	\N	IVSPFTM	CA	16596	US	1	ENVHUIJTKC@dell.com	9776587835	3	2110943363979458	2010/10	user4246	password	70	100000	F
4247	ARTSVG	ODBWMUHPDC	3477101032 Dell Way	\N	ITICGKD	HI	91162	US	1	ODBWMUHPDC@dell.com	3477101032	4	7495010024867953	2012/10	user4247	password	76	20000	F
4248	OTGVHJ	WEWRLLVOUP	9340447959 Dell Way	\N	WWVHABF	IL	86218	US	1	WEWRLLVOUP@dell.com	9340447959	2	6504348333459348	2011/04	user4248	password	20	40000	F
4249	GBIQYN	MQYYLMSAJO	4362026301 Dell Way	\N	WROXWVT	SC	21094	US	1	MQYYLMSAJO@dell.com	4362026301	3	4792826469521970	2010/10	user4249	password	52	80000	M
4250	VHVIUL	GTWTLXCATT	9730268922 Dell Way	\N	PRQLLLO	SD	96108	US	1	GTWTLXCATT@dell.com	9730268922	2	7721653011161835	2010/11	user4250	password	62	40000	F
4251	LOZWVS	TOEQQEKKTB	2537493512 Dell Way	\N	AENMSIL	OH	59191	US	1	TOEQQEKKTB@dell.com	2537493512	1	4919609175529331	2011/05	user4251	password	63	40000	M
4252	PBTIUH	MLYRVIKXJP	7617795346 Dell Way	\N	LVITGAH	ME	23239	US	1	MLYRVIKXJP@dell.com	7617795346	2	5727413132321090	2009/05	user4252	password	51	100000	F
4253	FHHMUS	KLNTWLCLWY	5008857098 Dell Way	\N	TQEUXPX	NV	83414	US	1	KLNTWLCLWY@dell.com	5008857098	1	3063685639761388	2012/12	user4253	password	69	20000	F
4254	ZPBRAN	FUJRXUNVOE	7054371874 Dell Way	\N	AICQGTL	OH	77894	US	1	FUJRXUNVOE@dell.com	7054371874	4	7691161545924843	2009/09	user4254	password	19	40000	F
4255	CBJPGD	YYBTMWHQXQ	9489338810 Dell Way	\N	SNWLZOF	NM	25234	US	1	YYBTMWHQXQ@dell.com	9489338810	1	8983639171347023	2012/05	user4255	password	33	20000	F
4256	PRSTPQ	UICRQTOHLC	7929837160 Dell Way	\N	DXBSCRW	AL	73723	US	1	UICRQTOHLC@dell.com	7929837160	1	1775863562244922	2012/01	user4256	password	55	60000	M
4257	FIIVCR	YTIRIPCKSZ	9499157782 Dell Way	\N	LLCDICW	CA	20031	US	1	YTIRIPCKSZ@dell.com	9499157782	1	2554433163255453	2010/08	user4257	password	82	80000	M
4258	FMBWKV	ECETFPMEAX	6984389223 Dell Way	\N	HEGJBIM	WY	47458	US	1	ECETFPMEAX@dell.com	6984389223	3	1644128387793898	2010/02	user4258	password	21	80000	M
4259	CQAYVC	DOHSBMTZTX	1374575777 Dell Way	\N	FDZOQYZ	IL	46379	US	1	DOHSBMTZTX@dell.com	1374575777	5	5553343592677266	2008/08	user4259	password	25	20000	F
4260	CDBFHP	NZRZSQTQWW	5188590571 Dell Way	\N	PKMOJUY	ME	66779	US	1	NZRZSQTQWW@dell.com	5188590571	3	3110203266143799	2010/09	user4260	password	52	80000	M
4261	NWDDJC	UJUKCKHZAR	2114770038 Dell Way	\N	MOBGNMX	WY	97725	US	1	UJUKCKHZAR@dell.com	2114770038	3	7070977719966323	2010/03	user4261	password	56	20000	F
4262	QFMTAW	NLYYSYZJKO	5936764650 Dell Way	\N	LRCXOCW	NY	67648	US	1	NLYYSYZJKO@dell.com	5936764650	2	8834543579258026	2008/05	user4262	password	89	80000	M
4263	MMPIZA	HYSFYCQMNH	2417307796 Dell Way	\N	OKVQHNH	TN	80227	US	1	HYSFYCQMNH@dell.com	2417307796	5	2366566847544163	2008/08	user4263	password	72	80000	F
4264	JYCJFB	CKZEBMSIBD	6422478953 Dell Way	\N	ERLRZGL	CT	26372	US	1	CKZEBMSIBD@dell.com	6422478953	2	8390694623813034	2009/11	user4264	password	85	80000	M
4265	ABACEL	CJMOBUPFYH	9091947777 Dell Way	\N	QQGXBKC	NY	69768	US	1	CJMOBUPFYH@dell.com	9091947777	1	5836369646713138	2012/09	user4265	password	42	100000	M
4266	IYZUAI	GOKAEQZLGP	3779572569 Dell Way	\N	SDRCFJU	CT	44665	US	1	GOKAEQZLGP@dell.com	3779572569	5	1993316944222897	2011/10	user4266	password	84	100000	M
4267	XTTFAI	QBMGAYNQQR	2634403363 Dell Way	\N	ITXRNAB	TN	96332	US	1	QBMGAYNQQR@dell.com	2634403363	3	7803376676049084	2008/06	user4267	password	53	100000	F
4268	FFGOVH	ACIYQYPHHI	9044879639 Dell Way	\N	EZWEARD	GA	24097	US	1	ACIYQYPHHI@dell.com	9044879639	2	6586597774177790	2009/04	user4268	password	79	80000	F
4269	CEIJEL	RDBQSIXBNW	4213134234 Dell Way	\N	XRXPVCT	OK	47117	US	1	RDBQSIXBNW@dell.com	4213134234	1	7299405410420150	2009/09	user4269	password	31	40000	M
4270	NQBZIE	AYWJVXWRUO	8000234950 Dell Way	\N	OKKRDDC	MO	29588	US	1	AYWJVXWRUO@dell.com	8000234950	4	9367958199232818	2012/12	user4270	password	76	60000	M
4271	VMYZMW	WWRTTIOIXY	9903412878 Dell Way	\N	SOCVQOB	ME	31974	US	1	WWRTTIOIXY@dell.com	9903412878	2	2931004844140261	2011/11	user4271	password	78	80000	F
4272	TPWPMT	HGMQVVNUOC	8894287626 Dell Way	\N	WJTKLER	ME	60059	US	1	HGMQVVNUOC@dell.com	8894287626	2	5031365266535431	2011/11	user4272	password	76	60000	F
4273	RBXKIE	XYZSMTGOQQ	5261579182 Dell Way	\N	HABMSMA	NE	74199	US	1	XYZSMTGOQQ@dell.com	5261579182	2	5943272158969194	2009/09	user4273	password	90	100000	M
4274	XIDCFC	BYPVEELUMM	6601060886 Dell Way	\N	WYEJZTB	MI	12262	US	1	BYPVEELUMM@dell.com	6601060886	4	7902152560185642	2011/08	user4274	password	60	60000	F
4275	SQGVSE	LNIPYDBLZZ	2280359623 Dell Way	\N	PJYJLKJ	AR	20324	US	1	LNIPYDBLZZ@dell.com	2280359623	4	8010314851533622	2011/03	user4275	password	75	60000	M
4276	AHOFSB	NHARJLRJBA	6440106418 Dell Way	\N	IKLSUNV	WA	27221	US	1	NHARJLRJBA@dell.com	6440106418	4	4683257657103241	2009/02	user4276	password	36	60000	F
4277	UPCWDK	WVTIMCKNKV	1768026122 Dell Way	\N	ZDPMYNR	ND	25592	US	1	WVTIMCKNKV@dell.com	1768026122	5	3391424893401563	2009/05	user4277	password	64	20000	M
4278	SZCCWX	WFKYPXJKWM	9800007631 Dell Way	\N	AJLOAZS	CT	93548	US	1	WFKYPXJKWM@dell.com	9800007631	3	3587928961496800	2011/08	user4278	password	36	40000	M
4279	JLMHIR	RGHPQSLCSV	7682446864 Dell Way	\N	OGWNZZL	WI	49610	US	1	RGHPQSLCSV@dell.com	7682446864	3	1355457230936735	2012/11	user4279	password	64	40000	F
4280	CQRUIY	BXOUJRMEFT	5515919790 Dell Way	\N	BTSAERM	WA	30662	US	1	BXOUJRMEFT@dell.com	5515919790	5	2244540062732994	2008/04	user4280	password	54	40000	M
4281	EAGCCE	RWNIJSOCTH	8795347159 Dell Way	\N	VUMMGKS	OR	40195	US	1	RWNIJSOCTH@dell.com	8795347159	5	6636742409318686	2009/02	user4281	password	58	60000	F
4282	VQGZIC	MRMFFPZMKT	3884149908 Dell Way	\N	YXZJQSS	MT	64861	US	1	MRMFFPZMKT@dell.com	3884149908	5	7556654773652554	2012/06	user4282	password	81	80000	F
4283	CRKFEB	RJGHITSBSP	2189518786 Dell Way	\N	BBGUTUK	AZ	68914	US	1	RJGHITSBSP@dell.com	2189518786	5	1712560860440135	2008/08	user4283	password	29	20000	F
4284	OILPAV	WHDPZFHPHJ	4324868469 Dell Way	\N	WCCQMEH	NJ	20396	US	1	WHDPZFHPHJ@dell.com	4324868469	4	7765316813252867	2010/09	user4284	password	21	20000	F
4285	NSBIOJ	MEJSMYZVVB	9767223593 Dell Way	\N	YLOCTEF	CO	82262	US	1	MEJSMYZVVB@dell.com	9767223593	4	5834557366091759	2008/09	user4285	password	61	60000	F
4286	RVZBIE	KAQJZMEBKQ	2316727611 Dell Way	\N	QNJUTMP	OK	19994	US	1	KAQJZMEBKQ@dell.com	2316727611	4	8489133127965034	2011/04	user4286	password	36	60000	F
4287	FLKKWL	AFKMJMXZCK	7909001233 Dell Way	\N	JXDVNWY	NY	63250	US	1	AFKMJMXZCK@dell.com	7909001233	3	8637936526909471	2008/11	user4287	password	87	40000	F
4288	JQEUQJ	FDTSBSULCS	9088142326 Dell Way	\N	PXGLVYB	NH	41610	US	1	FDTSBSULCS@dell.com	9088142326	4	2713556508067995	2012/11	user4288	password	53	40000	F
4289	QZDAFH	TXIMSUOLJL	2454326731 Dell Way	\N	RVHQXXZ	SC	56226	US	1	TXIMSUOLJL@dell.com	2454326731	4	4422390970401466	2011/11	user4289	password	82	40000	M
4290	AIBIBY	QNRLBCVNUR	6348056491 Dell Way	\N	VKOSJJF	NC	98823	US	1	QNRLBCVNUR@dell.com	6348056491	1	8537304013501854	2010/06	user4290	password	68	60000	M
4291	TVVRMJ	JXLLTYFKTQ	2136250999 Dell Way	\N	YMZHRNH	IL	73082	US	1	JXLLTYFKTQ@dell.com	2136250999	4	2652289875317365	2012/03	user4291	password	89	60000	F
4292	VGOEPL	QAEPGPJWOV	3282975609 Dell Way	\N	WVMJDUB	ID	57101	US	1	QAEPGPJWOV@dell.com	3282975609	1	7945435010828079	2009/08	user4292	password	79	20000	M
4293	KGLVWM	ALTQUPEPLZ	2666273320 Dell Way	\N	CVDXXKK	DC	51160	US	1	ALTQUPEPLZ@dell.com	2666273320	2	1716077525634318	2008/06	user4293	password	87	60000	M
4294	KGNXHZ	QXTGBJSBMN	1951034513 Dell Way	\N	EJLOUOA	WY	96028	US	1	QXTGBJSBMN@dell.com	1951034513	1	4449578067287803	2008/06	user4294	password	21	60000	M
4295	OJYNZW	HFXRYYELDO	8201375355 Dell Way	\N	XSILSIK	TN	39717	US	1	HFXRYYELDO@dell.com	8201375355	5	7732481763698161	2012/05	user4295	password	48	60000	M
4296	JYRFGX	CXVBCHFQEX	4385452296 Dell Way	\N	ZQQHBLQ	UT	40515	US	1	CXVBCHFQEX@dell.com	4385452296	4	7110933816526086	2011/02	user4296	password	45	20000	F
4297	BJIYMG	UOICTYHQXY	7643980328 Dell Way	\N	GFASWWB	HI	61841	US	1	UOICTYHQXY@dell.com	7643980328	1	7289413100574166	2008/03	user4297	password	74	20000	M
4298	CDBIYP	QAIPIZNGGS	4614236049 Dell Way	\N	GZODAUS	PA	82971	US	1	QAIPIZNGGS@dell.com	4614236049	5	9904365452006460	2008/01	user4298	password	57	40000	F
4299	POBEFC	NULMHRTAYS	2468885770 Dell Way	\N	OBSJUME	DE	42379	US	1	NULMHRTAYS@dell.com	2468885770	2	4517230079974979	2011/08	user4299	password	57	40000	F
4300	QMJSZD	DMLVFLUXZW	8850900213 Dell Way	\N	QJQDNUM	OH	23137	US	1	DMLVFLUXZW@dell.com	8850900213	3	7711472519207747	2010/09	user4300	password	84	20000	F
4301	HTDLXP	WTVHNSHJJQ	7203216885 Dell Way	\N	ZMEUYXY	TN	36514	US	1	WTVHNSHJJQ@dell.com	7203216885	2	9902383374981584	2011/04	user4301	password	28	100000	F
4302	HIYXER	SMFKTPTKPF	7975395197 Dell Way	\N	PJEMIAU	AK	31934	US	1	SMFKTPTKPF@dell.com	7975395197	4	5657943457830698	2012/07	user4302	password	58	40000	M
4303	MCAEUM	KEGZYQOEGY	2086094918 Dell Way	\N	JTGJNGP	IN	89081	US	1	KEGZYQOEGY@dell.com	2086094918	2	4426346327643842	2011/06	user4303	password	32	20000	M
4304	FIHRTM	XSLOGPUEZN	9681054347 Dell Way	\N	LIBSYJP	AR	62139	US	1	XSLOGPUEZN@dell.com	9681054347	4	1046128555200994	2008/11	user4304	password	55	40000	F
4305	VBYHYR	TNXJHCIVOQ	8506342771 Dell Way	\N	XGOGVQV	SD	40400	US	1	TNXJHCIVOQ@dell.com	8506342771	5	2996055193711072	2009/05	user4305	password	50	20000	F
4306	KMIBFV	ZODCWZRNWX	3405685109 Dell Way	\N	CCTSYOB	RI	57574	US	1	ZODCWZRNWX@dell.com	3405685109	1	8825929878745229	2011/04	user4306	password	36	20000	M
4307	PFZLFO	OHLNYYJWBM	6172315776 Dell Way	\N	QTLEUFS	AZ	38608	US	1	OHLNYYJWBM@dell.com	6172315776	4	6516391401644797	2012/11	user4307	password	45	60000	F
4308	JVHXKP	JYOHHKIUAC	4090877773 Dell Way	\N	FFXKXYS	MS	75577	US	1	JYOHHKIUAC@dell.com	4090877773	2	6695301641244442	2011/09	user4308	password	71	20000	M
4309	AAZQJX	ERFPAAQCGV	3712569592 Dell Way	\N	ZQTYJGR	OK	61152	US	1	ERFPAAQCGV@dell.com	3712569592	3	3771735686808825	2008/07	user4309	password	83	20000	M
4310	WSXUWP	AMPACSGYRX	8301448544 Dell Way	\N	RQGYHZN	NH	48582	US	1	AMPACSGYRX@dell.com	8301448544	4	9721274662762880	2011/09	user4310	password	56	60000	F
4311	LJHAJT	QKVIQTANLQ	2607594047 Dell Way	\N	UKYUXNF	OH	25553	US	1	QKVIQTANLQ@dell.com	2607594047	3	8898197428323329	2011/12	user4311	password	38	20000	F
4312	OESHUC	DDTXDHIUBS	3812735732 Dell Way	\N	SWPGBHL	IA	73797	US	1	DDTXDHIUBS@dell.com	3812735732	5	7212217712774873	2010/02	user4312	password	20	20000	F
4313	TLBWOF	QLJXUDZMWV	8283447326 Dell Way	\N	CDXKODD	UT	17136	US	1	QLJXUDZMWV@dell.com	8283447326	3	2558879394084215	2012/08	user4313	password	50	80000	F
4314	NMPSCB	CZVFYICUKF	1461300966 Dell Way	\N	RVTUYQW	PA	18346	US	1	CZVFYICUKF@dell.com	1461300966	4	7288274607621134	2010/03	user4314	password	71	20000	M
4315	ITUJVT	FBSNDMYIET	5537120666 Dell Way	\N	CYSSVLU	VA	14585	US	1	FBSNDMYIET@dell.com	5537120666	2	3336517623160034	2009/05	user4315	password	86	60000	F
4316	SYZMEA	ERDRPLVIOU	8091390314 Dell Way	\N	AGQMBNN	ND	89609	US	1	ERDRPLVIOU@dell.com	8091390314	5	3547871293034405	2011/05	user4316	password	49	60000	F
4317	KYNKCE	OUTAQCOKCV	7383910748 Dell Way	\N	APWODLL	VT	32863	US	1	OUTAQCOKCV@dell.com	7383910748	4	6803389006759972	2008/02	user4317	password	90	60000	F
4318	NYDRNX	KNONCZQXAF	2279804640 Dell Way	\N	UOIGZGM	NY	88753	US	1	KNONCZQXAF@dell.com	2279804640	5	9663367593195290	2008/05	user4318	password	89	80000	F
4319	CHVASJ	OFMOVKOBFC	5080304990 Dell Way	\N	JLBQYTM	CA	60020	US	1	OFMOVKOBFC@dell.com	5080304990	2	9238100160378964	2010/11	user4319	password	35	60000	F
4320	BOWLDC	YRYIFZNHJZ	6107544741 Dell Way	\N	JZXCMZQ	WA	27692	US	1	YRYIFZNHJZ@dell.com	6107544741	2	1453494296409189	2012/11	user4320	password	33	100000	F
4321	CIPEGG	DPMDDUNCDN	2900645331 Dell Way	\N	ZGZZXYE	MN	36229	US	1	DPMDDUNCDN@dell.com	2900645331	2	2711510707624256	2010/02	user4321	password	65	60000	F
4322	GSSMVI	ZZLTMNXZND	4472708482 Dell Way	\N	ZMAXQLF	TX	74117	US	1	ZZLTMNXZND@dell.com	4472708482	2	8620313252788038	2008/10	user4322	password	40	40000	F
4323	BTHJTH	UMTIJTVMSH	5632064076 Dell Way	\N	MQYYVUR	HI	13913	US	1	UMTIJTVMSH@dell.com	5632064076	2	8313693427946419	2012/07	user4323	password	38	100000	F
4324	PGAWBN	QJXJFJCNWT	1743897598 Dell Way	\N	LVOFNUH	AK	12883	US	1	QJXJFJCNWT@dell.com	1743897598	5	5942338301800192	2009/09	user4324	password	78	100000	M
4325	WVZJLJ	GUOQXBNQNI	6194382142 Dell Way	\N	FTVZAWA	CA	73157	US	1	GUOQXBNQNI@dell.com	6194382142	3	4738244802691043	2010/05	user4325	password	44	40000	F
4326	JQQSWL	GMJIAZVIFO	2440036776 Dell Way	\N	EFOBFRT	SD	19664	US	1	GMJIAZVIFO@dell.com	2440036776	2	5545515653677285	2010/06	user4326	password	69	100000	F
4327	JOZUVM	DEMDZVIOAN	4514154089 Dell Way	\N	DBTUUOX	WI	79914	US	1	DEMDZVIOAN@dell.com	4514154089	3	3276362849865109	2008/05	user4327	password	43	60000	M
4328	IGTUJX	HMXCVLCJPD	7321782279 Dell Way	\N	CJYRGXL	NM	43369	US	1	HMXCVLCJPD@dell.com	7321782279	4	7479622728191317	2008/03	user4328	password	65	40000	F
4329	KEUILH	FOCRQLGUOQ	7533765811 Dell Way	\N	TGWQRMA	MA	30197	US	1	FOCRQLGUOQ@dell.com	7533765811	3	4649216753430665	2009/10	user4329	password	77	80000	F
4330	PCMXIA	ZARLHMAXFG	8972056835 Dell Way	\N	TVYGVIM	NE	78840	US	1	ZARLHMAXFG@dell.com	8972056835	5	6331041827797890	2011/09	user4330	password	61	40000	M
4331	BFEBEE	TQMFQJKWDG	5372526532 Dell Way	\N	VKCDWRX	PA	63679	US	1	TQMFQJKWDG@dell.com	5372526532	3	3849969131406397	2008/10	user4331	password	28	20000	M
4332	HFEMZU	YEKHOHLVCV	5160617331 Dell Way	\N	XGRODLD	NJ	91169	US	1	YEKHOHLVCV@dell.com	5160617331	4	7081338741350920	2011/11	user4332	password	65	100000	F
4333	VJBPIF	AQUIBPLWMR	6316222094 Dell Way	\N	OAUAEKX	NM	20514	US	1	AQUIBPLWMR@dell.com	6316222094	2	9722611169796438	2009/02	user4333	password	21	20000	M
4334	CQVHRL	BZNQKKDBZD	4289335805 Dell Way	\N	WZIHXYK	MO	27690	US	1	BZNQKKDBZD@dell.com	4289335805	4	4017166264820844	2010/10	user4334	password	80	60000	F
4335	RUCDWB	RNLBQNAUKA	6443886459 Dell Way	\N	CRXBBKH	MI	21094	US	1	RNLBQNAUKA@dell.com	6443886459	5	9081701877061280	2010/05	user4335	password	41	20000	F
4336	KHZLYN	XADLAYVBBN	4305916085 Dell Way	\N	YDOIKAM	WY	87262	US	1	XADLAYVBBN@dell.com	4305916085	3	2852445825468749	2011/08	user4336	password	43	20000	M
4337	INVWLV	ZWWYSXZFWC	8610890128 Dell Way	\N	UFMURMQ	AR	93303	US	1	ZWWYSXZFWC@dell.com	8610890128	4	5673450586386025	2008/10	user4337	password	47	60000	F
4338	FKTBKP	YIHVHMRJGX	8041567992 Dell Way	\N	WBOIRPG	NC	39814	US	1	YIHVHMRJGX@dell.com	8041567992	4	2162682832218706	2008/04	user4338	password	50	60000	M
4339	FMAUKJ	CFQPXAWVWY	5000358917 Dell Way	\N	JFQZMDI	ID	89144	US	1	CFQPXAWVWY@dell.com	5000358917	3	2285766361281276	2012/11	user4339	password	76	20000	F
4340	VXSEAY	VPWVMRSKBY	2787716766 Dell Way	\N	AAKEIRB	SC	21769	US	1	VPWVMRSKBY@dell.com	2787716766	4	9875337228178980	2012/10	user4340	password	40	100000	M
4341	AARZVH	VRTMKENIEO	5960869214 Dell Way	\N	TJXLKRO	NJ	42252	US	1	VRTMKENIEO@dell.com	5960869214	4	2125135384500026	2012/06	user4341	password	75	100000	F
4342	LWHSRY	MEIQSRVGKE	3858992895 Dell Way	\N	DWPVKFF	WV	84454	US	1	MEIQSRVGKE@dell.com	3858992895	5	3375283334404230	2008/09	user4342	password	69	60000	M
4343	ZHGYTL	GJDYFKIJNF	3587037805 Dell Way	\N	ZJPFOOA	VA	45805	US	1	GJDYFKIJNF@dell.com	3587037805	5	2009619771037250	2012/07	user4343	password	67	100000	M
4344	YXOJEY	MCDWLNKQMU	4036128807 Dell Way	\N	GRJVSGF	WY	29616	US	1	MCDWLNKQMU@dell.com	4036128807	5	7812102878466249	2008/12	user4344	password	59	100000	M
4345	DIBBUE	ERQRCHEWNW	4826177148 Dell Way	\N	FJOLPOR	WA	60191	US	1	ERQRCHEWNW@dell.com	4826177148	5	5791903193574399	2012/11	user4345	password	48	20000	F
4346	MEARJS	HBUPFRDCWM	3765280745 Dell Way	\N	QIBFZZU	ME	95155	US	1	HBUPFRDCWM@dell.com	3765280745	3	8657206652220339	2011/07	user4346	password	23	40000	M
4347	CWBUEC	PTHGWKDJBM	3043267679 Dell Way	\N	LGMLAXJ	KY	38352	US	1	PTHGWKDJBM@dell.com	3043267679	1	8617741986643524	2009/04	user4347	password	57	60000	F
4348	PFIRUC	ZBZJFIKRUR	2858393016 Dell Way	\N	DFSBPBJ	SD	19673	US	1	ZBZJFIKRUR@dell.com	2858393016	1	4507036432623863	2011/07	user4348	password	58	40000	M
4349	XANAAP	ZKUIULCMPI	7414482118 Dell Way	\N	EQXFASI	GA	82450	US	1	ZKUIULCMPI@dell.com	7414482118	5	3823073452338576	2009/04	user4349	password	20	20000	F
4350	OEJDDT	XMNJPAZXEP	6367558829 Dell Way	\N	UKQMSVH	MI	82108	US	1	XMNJPAZXEP@dell.com	6367558829	4	2005719851702451	2011/11	user4350	password	50	20000	F
4351	UHENFR	BOGBNDGDXQ	5459196379 Dell Way	\N	TKJPRUJ	IL	55122	US	1	BOGBNDGDXQ@dell.com	5459196379	5	4279083325527609	2012/01	user4351	password	46	80000	F
4352	OGOGIC	MKQQQTNHNY	4023718930 Dell Way	\N	RCPMMXZ	WV	80897	US	1	MKQQQTNHNY@dell.com	4023718930	5	8701692467555405	2011/08	user4352	password	33	40000	M
4353	TOGWAQ	NQHGEPTDGV	3354324310 Dell Way	\N	SSHQRGK	AL	25276	US	1	NQHGEPTDGV@dell.com	3354324310	4	8297684399411083	2010/01	user4353	password	70	40000	M
4354	YDQPQH	WWLLQORMHK	1153331965 Dell Way	\N	UXCAIDF	NE	89369	US	1	WWLLQORMHK@dell.com	1153331965	1	9479768219403924	2011/04	user4354	password	57	80000	F
4355	EGBLDY	XOOLGATRUR	7518431111 Dell Way	\N	UVZXBPU	AR	67359	US	1	XOOLGATRUR@dell.com	7518431111	4	9483358942903580	2009/06	user4355	password	44	60000	M
4356	KWWJTL	XFSYZJSQEO	8243516195 Dell Way	\N	QBPFVRW	ND	50712	US	1	XFSYZJSQEO@dell.com	8243516195	5	9345117785502226	2008/04	user4356	password	66	60000	F
4357	NYXZWD	RUDBNTFBKH	7493361954 Dell Way	\N	RQCINRU	IN	54888	US	1	RUDBNTFBKH@dell.com	7493361954	3	7884335454553366	2009/01	user4357	password	84	100000	F
4358	VXWYPQ	BREVWGGDXX	2750744560 Dell Way	\N	GGKYBSL	RI	26965	US	1	BREVWGGDXX@dell.com	2750744560	1	3400511806830764	2008/02	user4358	password	39	100000	F
4359	EWPVYG	ZUDFAHDXOK	5256580986 Dell Way	\N	IMLAXGF	CA	45957	US	1	ZUDFAHDXOK@dell.com	5256580986	1	5447442751377821	2011/02	user4359	password	54	100000	M
4360	CSXISR	MXSTBQHLYT	1250550642 Dell Way	\N	XYRDETN	NM	96174	US	1	MXSTBQHLYT@dell.com	1250550642	2	1663553687278181	2010/04	user4360	password	22	80000	F
4361	ZYTRLR	KESAMEYFBX	7150208279 Dell Way	\N	XFCQTSP	PA	21034	US	1	KESAMEYFBX@dell.com	7150208279	2	4969517709221691	2011/11	user4361	password	53	80000	M
4362	GKHXUL	QUXUTDWRBB	1382280796 Dell Way	\N	TRUMHOP	WY	86298	US	1	QUXUTDWRBB@dell.com	1382280796	4	7732322595547885	2010/06	user4362	password	61	80000	M
4363	WRQIHK	GCEKYWLAPD	9572196521 Dell Way	\N	UCLJRKF	OR	22422	US	1	GCEKYWLAPD@dell.com	9572196521	2	6285921024624259	2010/01	user4363	password	49	60000	M
4364	BTZMAC	QKANWACZVE	5891593078 Dell Way	\N	KEWVJPY	KS	86959	US	1	QKANWACZVE@dell.com	5891593078	5	8927602083422244	2012/04	user4364	password	60	20000	F
4365	ONCQEN	RRJRTJNYTR	2438025535 Dell Way	\N	VOBLNJH	AZ	33804	US	1	RRJRTJNYTR@dell.com	2438025535	1	6245345442555845	2011/01	user4365	password	66	40000	M
4366	UZTHQK	RIEAVDUNYJ	8035144416 Dell Way	\N	OKWYRYF	TN	10883	US	1	RIEAVDUNYJ@dell.com	8035144416	3	1822584847919643	2010/11	user4366	password	67	40000	M
4367	LNMWEU	AFQEZDDIRN	3430798351 Dell Way	\N	FPEEVZE	NH	60355	US	1	AFQEZDDIRN@dell.com	3430798351	1	4918592069298029	2012/04	user4367	password	38	40000	M
4368	TFZOGE	EKDHOMYBRO	2948430414 Dell Way	\N	FVJFAZU	IL	10872	US	1	EKDHOMYBRO@dell.com	2948430414	2	3465038945432752	2010/08	user4368	password	22	40000	M
4369	AUDEYN	IGCUFDMTJI	4577508721 Dell Way	\N	DPICJQD	NE	88416	US	1	IGCUFDMTJI@dell.com	4577508721	1	5500575966667384	2010/04	user4369	password	44	60000	F
4370	MRBAZH	CUMFGGPOJE	8896636491 Dell Way	\N	WMNNQCJ	AK	25536	US	1	CUMFGGPOJE@dell.com	8896636491	3	5337856768630445	2009/12	user4370	password	59	80000	M
4371	QSPXVJ	JBPPQDZUAM	1722240671 Dell Way	\N	INCLXCP	RI	61422	US	1	JBPPQDZUAM@dell.com	1722240671	1	5606921807397157	2011/09	user4371	password	25	40000	F
4372	REGANI	QDYTCTTOBH	8561322591 Dell Way	\N	QMETCYI	DE	95476	US	1	QDYTCTTOBH@dell.com	8561322591	5	7031457511708141	2012/02	user4372	password	26	80000	F
4373	JRUSHX	QBZJUOLCFY	8330986957 Dell Way	\N	GZAFHED	CT	99518	US	1	QBZJUOLCFY@dell.com	8330986957	1	1780106393620371	2012/09	user4373	password	42	40000	F
4374	DARAQS	AANOLPUJWT	6770946523 Dell Way	\N	KBAOFEO	AL	32670	US	1	AANOLPUJWT@dell.com	6770946523	5	9754494500346484	2012/04	user4374	password	44	20000	F
4375	BCXUDY	IRJYLTUEDW	6492671491 Dell Way	\N	FSBKGBQ	VA	12327	US	1	IRJYLTUEDW@dell.com	6492671491	5	3601285721175373	2012/12	user4375	password	58	20000	F
4376	MUFKCX	UAIOVNRRTK	2113070921 Dell Way	\N	TDRVUOV	MA	49636	US	1	UAIOVNRRTK@dell.com	2113070921	2	4817840889096260	2011/05	user4376	password	56	20000	F
4377	TOHQII	ZWEMOVGYOJ	1271268439 Dell Way	\N	PKDEFNP	KY	89388	US	1	ZWEMOVGYOJ@dell.com	1271268439	1	3372960294131190	2010/03	user4377	password	50	40000	M
4378	TXBCXY	GKMCQLRABB	8468468270 Dell Way	\N	EFHRVQO	TX	68132	US	1	GKMCQLRABB@dell.com	8468468270	3	8405389499850572	2009/09	user4378	password	58	20000	M
4379	PDNNJX	AMNMDNNERT	6017478677 Dell Way	\N	MJOCYLT	RI	85684	US	1	AMNMDNNERT@dell.com	6017478677	1	5829382458701730	2008/01	user4379	password	28	80000	F
4380	QGOOHA	BTEPHJHAVR	4826240897 Dell Way	\N	PXPBQJX	GA	47969	US	1	BTEPHJHAVR@dell.com	4826240897	2	5502450587693602	2010/01	user4380	password	68	40000	F
4381	GTOHVI	LKPUSQPJGN	3381372619 Dell Way	\N	ZHEIEJT	NJ	69797	US	1	LKPUSQPJGN@dell.com	3381372619	1	7172249697148801	2012/05	user4381	password	88	40000	F
4382	NMAVYL	LSDBINIWMQ	7425439021 Dell Way	\N	AVVJPLA	TX	66263	US	1	LSDBINIWMQ@dell.com	7425439021	5	1365303540602326	2011/01	user4382	password	34	20000	M
4383	FALRLE	UNNHWJUMJP	4623123318 Dell Way	\N	HSETTBJ	MN	86478	US	1	UNNHWJUMJP@dell.com	4623123318	1	8857400886714459	2011/04	user4383	password	46	100000	F
4384	VNVAII	NQEWKRGAZZ	9668059866 Dell Way	\N	FSSGBFC	MO	40305	US	1	NQEWKRGAZZ@dell.com	9668059866	1	7025664371903986	2009/12	user4384	password	19	20000	F
4385	VFUETK	JQUAWUAWAS	7980238910 Dell Way	\N	OGUUIGC	IL	42356	US	1	JQUAWUAWAS@dell.com	7980238910	4	3797822922933847	2011/11	user4385	password	74	80000	F
4386	OUVYEL	TEINEENXTU	6579994422 Dell Way	\N	RNCYPKI	MA	14155	US	1	TEINEENXTU@dell.com	6579994422	1	9028271452058108	2009/10	user4386	password	87	100000	M
4387	TWUFPZ	NDDRRBKLTX	9057075786 Dell Way	\N	OSNYAXA	NJ	19443	US	1	NDDRRBKLTX@dell.com	9057075786	1	9314792202319952	2012/12	user4387	password	57	80000	M
4388	IVLHIP	LAHMKTGIHY	8361555939 Dell Way	\N	WGYUGOX	DC	62211	US	1	LAHMKTGIHY@dell.com	8361555939	1	5868919598404319	2009/08	user4388	password	46	80000	F
4389	VZTLKU	SXFMDNTBKA	7197473748 Dell Way	\N	AFHOCLD	VT	48991	US	1	SXFMDNTBKA@dell.com	7197473748	2	1459993590600788	2008/12	user4389	password	53	100000	M
4390	GJIACF	FOITIKEIKJ	5729163445 Dell Way	\N	PZLBDJM	SD	65576	US	1	FOITIKEIKJ@dell.com	5729163445	5	6098735801409931	2008/10	user4390	password	53	40000	F
4391	UHGANU	JGCTKLETBE	7669817452 Dell Way	\N	FCHOODE	CO	11594	US	1	JGCTKLETBE@dell.com	7669817452	1	8419975004624576	2009/05	user4391	password	90	20000	M
4392	GAEAJK	DDVPIPRMUT	7784895187 Dell Way	\N	UJIXNLY	ID	59522	US	1	DDVPIPRMUT@dell.com	7784895187	3	9304761092644186	2011/07	user4392	password	60	100000	M
4393	TAXDEB	ZTJOKWJEQS	4812192601 Dell Way	\N	NOGYMNN	HI	99191	US	1	ZTJOKWJEQS@dell.com	4812192601	5	5475128973834217	2008/12	user4393	password	19	80000	M
4394	YXDZWW	IKHETMVMZJ	7258893333 Dell Way	\N	SYVFLBF	TX	12780	US	1	IKHETMVMZJ@dell.com	7258893333	5	9803678644821048	2011/08	user4394	password	86	80000	F
4395	BQIYYT	FDNRYZRHRP	2665717193 Dell Way	\N	DXAECWF	SC	74681	US	1	FDNRYZRHRP@dell.com	2665717193	3	3804342786315829	2008/02	user4395	password	75	20000	M
4396	DCTWIW	JZUJQBBGEY	2263118245 Dell Way	\N	GJBCOWV	PA	42692	US	1	JZUJQBBGEY@dell.com	2263118245	5	5751441064756364	2012/01	user4396	password	40	20000	F
4397	BYLXIL	RRCTTIYSPH	5473219555 Dell Way	\N	TSWPNQZ	NV	54747	US	1	RRCTTIYSPH@dell.com	5473219555	3	5907644787337632	2012/08	user4397	password	68	100000	M
4398	DTWPLO	SEHBDZQLTI	9617752919 Dell Way	\N	HJWXINK	TN	19302	US	1	SEHBDZQLTI@dell.com	9617752919	4	7751994234975428	2011/06	user4398	password	41	100000	F
4399	FKRTDW	BEZBUKVDSE	4112704324 Dell Way	\N	ZQNMAIP	WY	96915	US	1	BEZBUKVDSE@dell.com	4112704324	4	5096522078849375	2011/06	user4399	password	68	100000	M
4400	JQZGRD	FTYQOCITBY	9879401487 Dell Way	\N	GOZOEYN	MS	63234	US	1	FTYQOCITBY@dell.com	9879401487	1	1283486216329038	2011/01	user4400	password	82	20000	M
4401	WHJAMC	ZDRBLKDKQS	9444439406 Dell Way	\N	JFWITJX	OR	58975	US	1	ZDRBLKDKQS@dell.com	9444439406	3	6299357927870006	2012/06	user4401	password	37	80000	M
4402	QSGTRJ	KSVVWFMOOR	9339065389 Dell Way	\N	LWKUUDI	OR	59012	US	1	KSVVWFMOOR@dell.com	9339065389	3	1054650012869387	2008/03	user4402	password	72	100000	M
4403	ZOPJZI	EUEKGTYYEV	1278978106 Dell Way	\N	IYQMHJA	HI	92192	US	1	EUEKGTYYEV@dell.com	1278978106	3	2317429742310196	2011/03	user4403	password	23	80000	M
4404	RDUZIO	ESVXRUBNCA	6262903249 Dell Way	\N	EPINQOL	NV	96741	US	1	ESVXRUBNCA@dell.com	6262903249	3	2783193317707628	2011/03	user4404	password	90	40000	F
4405	UIRIMK	EJCYLQBMUR	5606802884 Dell Way	\N	UIHJTYI	KY	42575	US	1	EJCYLQBMUR@dell.com	5606802884	5	6174521709326655	2010/04	user4405	password	86	40000	M
4406	QQCAUM	DTXTVKOMEW	6545313782 Dell Way	\N	TOPRWYB	LA	94043	US	1	DTXTVKOMEW@dell.com	6545313782	5	3265802477486432	2010/02	user4406	password	82	20000	M
4407	ZFOLII	JCDTQPYMJM	3046348909 Dell Way	\N	CAIBBSZ	OH	62803	US	1	JCDTQPYMJM@dell.com	3046348909	2	7637464563827962	2008/05	user4407	password	55	20000	M
4408	CNZKXB	NQSDPFMCHN	5177966810 Dell Way	\N	LJPDIHS	ND	58781	US	1	NQSDPFMCHN@dell.com	5177966810	4	9626885112375022	2012/09	user4408	password	60	20000	F
4409	OLDQZU	IDKNPMVDXE	5925910509 Dell Way	\N	TBNBTBP	HI	73480	US	1	IDKNPMVDXE@dell.com	5925910509	2	4956661114469171	2008/04	user4409	password	69	80000	M
4410	WHRQQU	ADKNZOKEHL	8752063699 Dell Way	\N	RJFSYLK	MO	68971	US	1	ADKNZOKEHL@dell.com	8752063699	4	9190159362275154	2010/04	user4410	password	62	60000	M
4411	HBFCCJ	NPJBANJMFT	7406522901 Dell Way	\N	SXRDIEU	GA	80281	US	1	NPJBANJMFT@dell.com	7406522901	4	1759723335970193	2009/03	user4411	password	68	80000	F
4412	XSIHGY	RIZFSLKLDI	2196207460 Dell Way	\N	CHRGCWB	SC	65626	US	1	RIZFSLKLDI@dell.com	2196207460	1	8123059520963580	2012/09	user4412	password	19	80000	F
4413	JBSHSB	HYTSIEWQHD	6182860269 Dell Way	\N	IOFEPAU	OR	23499	US	1	HYTSIEWQHD@dell.com	6182860269	3	9093757777940484	2011/04	user4413	password	45	100000	F
4414	CGBDOZ	WGIBCYIGGX	5962928367 Dell Way	\N	MLMNFFQ	SC	79769	US	1	WGIBCYIGGX@dell.com	5962928367	2	1635621753521263	2012/05	user4414	password	47	20000	M
4415	MEELBK	TCNSLUZIGK	9023248458 Dell Way	\N	VTQBKLV	WV	84616	US	1	TCNSLUZIGK@dell.com	9023248458	5	2685448772273958	2009/11	user4415	password	77	80000	F
4416	ZFDKZF	YSRSRAZCVS	2670129842 Dell Way	\N	TWDESCZ	NE	99030	US	1	YSRSRAZCVS@dell.com	2670129842	5	9131263990886510	2012/08	user4416	password	89	100000	M
4417	CJWIHO	ZAFZZIVSBS	8422173158 Dell Way	\N	VGKYFZX	ME	87975	US	1	ZAFZZIVSBS@dell.com	8422173158	3	5718827590811998	2012/05	user4417	password	47	100000	M
4418	GGBUGB	AGAJBTKTOQ	5714012707 Dell Way	\N	EMWDKHZ	IA	73733	US	1	AGAJBTKTOQ@dell.com	5714012707	1	1861826022621244	2012/12	user4418	password	80	20000	F
4419	XZLZAR	AJSTUMILQV	4759737360 Dell Way	\N	IUFPUMI	IL	57151	US	1	AJSTUMILQV@dell.com	4759737360	2	5337989596650005	2009/05	user4419	password	67	20000	F
4420	CEKTET	MXOZGZPBIJ	7822916648 Dell Way	\N	HYDTGLH	NY	69411	US	1	MXOZGZPBIJ@dell.com	7822916648	5	1529727068729698	2010/02	user4420	password	50	60000	F
4421	VHMPUK	ETQEJRMTYK	1600730493 Dell Way	\N	XSQJZIA	OR	33367	US	1	ETQEJRMTYK@dell.com	1600730493	1	4467741684988141	2010/09	user4421	password	67	40000	F
4422	DYVNCP	DHZVTSTDQM	7844641330 Dell Way	\N	UZLDZEJ	AR	41335	US	1	DHZVTSTDQM@dell.com	7844641330	3	1523901436477899	2010/11	user4422	password	23	60000	M
4423	XCZMGG	LBZEVDUHYT	3905670532 Dell Way	\N	TBTXKUG	FL	40241	US	1	LBZEVDUHYT@dell.com	3905670532	4	3141265019308776	2009/03	user4423	password	24	40000	F
4424	BTNHFP	HJKKDSIWLK	9738087696 Dell Way	\N	QJUKQZT	WI	63571	US	1	HJKKDSIWLK@dell.com	9738087696	2	8006328259129078	2008/08	user4424	password	22	20000	F
4425	PLPESY	ODBHMYSWOB	1156577568 Dell Way	\N	RZSQSQG	NY	98939	US	1	ODBHMYSWOB@dell.com	1156577568	4	6591815487947316	2008/11	user4425	password	19	80000	F
4426	PVZOJD	QRPPJLELCD	4596312464 Dell Way	\N	DTVUZNU	AK	33265	US	1	QRPPJLELCD@dell.com	4596312464	1	2085921815596521	2010/09	user4426	password	47	20000	M
4427	KPYNFP	CUZOYKRCOK	8550621642 Dell Way	\N	YJKLDKS	MT	54726	US	1	CUZOYKRCOK@dell.com	8550621642	5	3083788968157023	2009/12	user4427	password	74	80000	M
4428	SETHHO	GVNRNPGYOP	5285983282 Dell Way	\N	IASTSGG	ND	25888	US	1	GVNRNPGYOP@dell.com	5285983282	5	2296700126491487	2009/06	user4428	password	68	100000	M
4429	LGXZNT	NFGDLERANR	3558419046 Dell Way	\N	SGKZNZD	WY	81352	US	1	NFGDLERANR@dell.com	3558419046	2	3274059783667326	2012/03	user4429	password	82	60000	F
4430	UKAOYF	UBQZSRMKKT	8517277199 Dell Way	\N	VJGUNGP	SC	53492	US	1	UBQZSRMKKT@dell.com	8517277199	4	7196882681455464	2011/03	user4430	password	29	60000	M
4431	EBNJVO	AVHRIRCBML	7745877289 Dell Way	\N	IHYPWTB	OH	55091	US	1	AVHRIRCBML@dell.com	7745877289	3	7143655601423234	2012/12	user4431	password	38	20000	M
4432	ULVJMQ	REYJGAWSJD	6142373544 Dell Way	\N	QYAKASX	PA	22177	US	1	REYJGAWSJD@dell.com	6142373544	4	1574085131287574	2012/09	user4432	password	20	80000	F
4433	WAQNSU	LBBMXTWBKU	9666829159 Dell Way	\N	BUUTROX	IA	29244	US	1	LBBMXTWBKU@dell.com	9666829159	1	9552101235836744	2008/10	user4433	password	27	100000	M
4434	UJMPVO	QILKEMUZOO	5366220994 Dell Way	\N	UHGIFMN	DE	61710	US	1	QILKEMUZOO@dell.com	5366220994	1	3956099896691740	2011/01	user4434	password	26	60000	F
4435	PZFDQN	PASCURQJLY	9862567599 Dell Way	\N	PUDCHHR	SC	52580	US	1	PASCURQJLY@dell.com	9862567599	3	5530844871420414	2008/10	user4435	password	83	80000	M
4436	DWLQML	JOGBEQMDFG	5836945919 Dell Way	\N	GHOOYJA	WI	79035	US	1	JOGBEQMDFG@dell.com	5836945919	1	6191823570989073	2010/10	user4436	password	45	60000	M
4437	VFCGOQ	NPVDCYJJFQ	6732805997 Dell Way	\N	YTPHUOB	KS	63445	US	1	NPVDCYJJFQ@dell.com	6732805997	4	4149498587008566	2008/04	user4437	password	88	100000	M
4438	BCCRPS	NSULBEQSCK	8321329832 Dell Way	\N	IKEWLNM	CA	34751	US	1	NSULBEQSCK@dell.com	8321329832	1	6301267773844302	2011/12	user4438	password	25	100000	F
4439	FNPXAI	SMKWDCZNLJ	1672495748 Dell Way	\N	SHVFTYM	NE	13482	US	1	SMKWDCZNLJ@dell.com	1672495748	2	9740265968255700	2008/03	user4439	password	89	40000	M
4440	PHTXZF	IWIKVVVFOD	9764687950 Dell Way	\N	ATXZGMA	KS	84516	US	1	IWIKVVVFOD@dell.com	9764687950	3	1169172328896820	2012/11	user4440	password	71	60000	F
4441	MMDRUZ	AEVWAAKEBE	4445705938 Dell Way	\N	BAKNASJ	WY	29744	US	1	AEVWAAKEBE@dell.com	4445705938	5	1873367438092827	2008/06	user4441	password	36	60000	M
4442	JHTJHY	EEYEPDFTEG	2846625008 Dell Way	\N	ESGXCFC	MN	25595	US	1	EEYEPDFTEG@dell.com	2846625008	3	7007181780878455	2010/03	user4442	password	63	100000	F
4443	JFTHJY	GONJUHOALG	4044920078 Dell Way	\N	GIJMLVR	NV	46180	US	1	GONJUHOALG@dell.com	4044920078	1	6157612175215036	2012/12	user4443	password	19	40000	F
4444	UQOSWC	GFXNUXZAEI	2651130624 Dell Way	\N	KRUFJLP	OH	58789	US	1	GFXNUXZAEI@dell.com	2651130624	4	5452609586995095	2009/12	user4444	password	65	100000	M
4445	FSMHYR	EMLCMMHUWY	1333701297 Dell Way	\N	OCHASZO	VA	68263	US	1	EMLCMMHUWY@dell.com	1333701297	1	6696504964027554	2011/02	user4445	password	35	100000	M
4446	SETKJG	WLSJTMFRBI	3432775277 Dell Way	\N	ZBAZPXQ	NV	10398	US	1	WLSJTMFRBI@dell.com	3432775277	2	1809220339171588	2010/03	user4446	password	82	40000	F
4447	QPTWLF	OUYBAQDJQF	4459447112 Dell Way	\N	JQVHHMH	NC	82709	US	1	OUYBAQDJQF@dell.com	4459447112	1	1276359209790825	2009/04	user4447	password	49	100000	M
4448	FUIKJD	JKEAONRTXH	9063940125 Dell Way	\N	PEOBMCW	UT	24726	US	1	JKEAONRTXH@dell.com	9063940125	1	4841984014026821	2009/01	user4448	password	39	60000	M
4449	QYETHP	XIDLZXIHMN	5994680990 Dell Way	\N	WOZZKWD	IN	99905	US	1	XIDLZXIHMN@dell.com	5994680990	4	1346167270094156	2012/02	user4449	password	80	60000	F
4450	AFKPDS	SOSQXZDKVR	3734107676 Dell Way	\N	KUCGYKG	MO	13418	US	1	SOSQXZDKVR@dell.com	3734107676	2	2776810293085873	2008/10	user4450	password	39	20000	F
4451	RTEKMS	CCQCFAYXLT	6565054824 Dell Way	\N	ZSRJYDK	ID	53040	US	1	CCQCFAYXLT@dell.com	6565054824	3	3557680483441800	2012/07	user4451	password	40	60000	F
4452	MAVFCX	VFDVDAGWAY	4932768725 Dell Way	\N	NKXRVED	MI	63439	US	1	VFDVDAGWAY@dell.com	4932768725	2	2577486330643296	2011/12	user4452	password	55	40000	M
4453	IKBGGH	JBKKIHLHVV	2444399947 Dell Way	\N	FMQKQCZ	CA	50153	US	1	JBKKIHLHVV@dell.com	2444399947	5	4552702084649354	2011/01	user4453	password	43	100000	F
4454	KFSRPU	CADKLLFGQS	8632625841 Dell Way	\N	XAIAALL	FL	32745	US	1	CADKLLFGQS@dell.com	8632625841	5	3739589625503868	2008/11	user4454	password	74	80000	F
4455	MHQHKQ	KUCVAIMSGM	1278004925 Dell Way	\N	BGNMSRS	ND	58275	US	1	KUCVAIMSGM@dell.com	1278004925	4	4345192648936063	2012/05	user4455	password	49	40000	M
4456	COCTZW	VUXDGPKTQR	8801168052 Dell Way	\N	GDJYWYM	UT	72578	US	1	VUXDGPKTQR@dell.com	8801168052	4	1568049188703298	2009/12	user4456	password	71	40000	M
4457	VCNRXI	PBOEMIVDPY	2979385767 Dell Way	\N	NOULBRE	VT	41413	US	1	PBOEMIVDPY@dell.com	2979385767	2	3968476899899542	2012/08	user4457	password	82	80000	M
4458	KLPSAR	HFEPAIFZVT	1887313588 Dell Way	\N	THVKLST	NY	94420	US	1	HFEPAIFZVT@dell.com	1887313588	4	5729315815959126	2012/05	user4458	password	34	40000	M
4459	VCWNJC	SZDAECVYWD	9394265208 Dell Way	\N	TGPMAHK	CT	91327	US	1	SZDAECVYWD@dell.com	9394265208	1	3674047132488340	2008/06	user4459	password	28	100000	M
4460	ANYDFX	GFCIBAEFTL	3527173524 Dell Way	\N	UGMCQQZ	NE	76456	US	1	GFCIBAEFTL@dell.com	3527173524	4	3034917271696031	2010/09	user4460	password	76	60000	F
4461	TPLQVQ	SESTJXNUST	8969038063 Dell Way	\N	HUJXUYR	AZ	70207	US	1	SESTJXNUST@dell.com	8969038063	3	4429419238120318	2011/12	user4461	password	62	60000	M
4462	ABJRUN	KNWIARATZV	2216356680 Dell Way	\N	DXPCORT	MI	24755	US	1	KNWIARATZV@dell.com	2216356680	1	2012667766306549	2011/07	user4462	password	64	80000	M
4463	ZMJNWX	KEYBFSBAVY	6257199947 Dell Way	\N	QYMHRYM	SD	15514	US	1	KEYBFSBAVY@dell.com	6257199947	3	6406612136401237	2009/05	user4463	password	32	40000	M
4464	OTRMDV	KFADGBYFRW	3783370271 Dell Way	\N	SZOQMJS	AR	93715	US	1	KFADGBYFRW@dell.com	3783370271	2	3390957241877913	2010/07	user4464	password	22	20000	F
4465	SOKOZQ	PCWQBCIYUI	1561674839 Dell Way	\N	MLUWEWU	MN	21920	US	1	PCWQBCIYUI@dell.com	1561674839	5	6739622735418380	2008/01	user4465	password	83	100000	M
4466	HKPXAS	URTWZRRIED	7743489754 Dell Way	\N	DBHZVTC	VA	75684	US	1	URTWZRRIED@dell.com	7743489754	1	8090293358080090	2011/11	user4466	password	47	100000	F
4467	AVISQZ	MMZDEHIIKJ	8848777002 Dell Way	\N	PKFJNCC	ID	22141	US	1	MMZDEHIIKJ@dell.com	8848777002	5	1217321631032973	2009/10	user4467	password	42	40000	M
4468	RAHQMU	PQYXYHIIWS	8005658469 Dell Way	\N	NFGQINT	FL	46456	US	1	PQYXYHIIWS@dell.com	8005658469	3	3131534220650792	2008/10	user4468	password	83	80000	M
4469	EKGZAW	YXVFGDBYQH	4072448357 Dell Way	\N	FGPSAUC	SC	31909	US	1	YXVFGDBYQH@dell.com	4072448357	5	1036901223938912	2009/09	user4469	password	74	60000	F
4470	AKCXIZ	SNFVPEMWJT	5518417836 Dell Way	\N	MBTGEOM	MT	52246	US	1	SNFVPEMWJT@dell.com	5518417836	4	2296411558520049	2009/03	user4470	password	33	40000	M
4471	HFXHXK	NTARGWBZJD	9287792671 Dell Way	\N	TPHHCVU	NH	62640	US	1	NTARGWBZJD@dell.com	9287792671	5	7961633156053723	2008/03	user4471	password	43	60000	F
4472	GSHRFA	RXGOYGXCZN	6163217380 Dell Way	\N	KHPFCFU	WY	18560	US	1	RXGOYGXCZN@dell.com	6163217380	1	3510036689694971	2012/07	user4472	password	66	20000	F
4473	YWNZNL	GCKMZMMMWU	7110744976 Dell Way	\N	CCWHXWK	MN	99811	US	1	GCKMZMMMWU@dell.com	7110744976	2	6163889818359167	2009/07	user4473	password	81	40000	F
4474	KGZVNB	FZASMNPGPR	6031207685 Dell Way	\N	DXOZHAZ	WY	48238	US	1	FZASMNPGPR@dell.com	6031207685	2	1014819862786680	2010/08	user4474	password	49	100000	M
4475	KRJLXJ	MPVZFCPWGM	9103853591 Dell Way	\N	LFUMFUX	RI	19290	US	1	MPVZFCPWGM@dell.com	9103853591	1	7365893847309054	2009/01	user4475	password	59	80000	M
4476	YEPHQF	DQKGFHMSSS	1697573988 Dell Way	\N	MEXGCRJ	WY	89109	US	1	DQKGFHMSSS@dell.com	1697573988	2	9187939448747784	2011/01	user4476	password	62	60000	F
4477	FXWKAN	UHSBTKUMXZ	8692481585 Dell Way	\N	KEBBNBY	NJ	42999	US	1	UHSBTKUMXZ@dell.com	8692481585	2	4815274333581329	2010/11	user4477	password	66	80000	M
4478	OBTBWA	TYUESHBSRG	6287122218 Dell Way	\N	TSTURJE	MT	66639	US	1	TYUESHBSRG@dell.com	6287122218	5	5250577507074923	2009/08	user4478	password	32	80000	M
4479	YVPZPN	UUGBWYSCRL	3964527389 Dell Way	\N	WMDFQQW	HI	66909	US	1	UUGBWYSCRL@dell.com	3964527389	3	3522702935617417	2010/04	user4479	password	90	60000	F
4480	OMSCHN	IJJGCMYOIK	2990002235 Dell Way	\N	ROBIKHY	OR	78847	US	1	IJJGCMYOIK@dell.com	2990002235	2	1315228328574448	2009/10	user4480	password	28	80000	F
4481	WWNKEX	ULZGJNPUED	9388242459 Dell Way	\N	VMODLHX	NV	60807	US	1	ULZGJNPUED@dell.com	9388242459	5	3949871279299259	2008/08	user4481	password	60	100000	M
4482	CJSADD	ZKNMZIRCEE	8591924647 Dell Way	\N	RHPYEGN	CT	18914	US	1	ZKNMZIRCEE@dell.com	8591924647	2	7712729959748686	2010/02	user4482	password	37	60000	M
4483	ZORDNB	QAAYSDCWUK	5715531688 Dell Way	\N	LTPRHSU	CT	91789	US	1	QAAYSDCWUK@dell.com	5715531688	3	1655774002894759	2011/01	user4483	password	61	80000	M
4484	GWDIND	JMVNOSIZDC	3296858778 Dell Way	\N	OVJHPME	CT	11089	US	1	JMVNOSIZDC@dell.com	3296858778	5	1772931639570742	2012/08	user4484	password	68	20000	M
4485	VLBZVN	VICNQBRTQM	6932999691 Dell Way	\N	CXBOCEO	KY	18465	US	1	VICNQBRTQM@dell.com	6932999691	1	7785259946715087	2009/04	user4485	password	38	20000	M
4486	IEPVZX	YNOZEHQQKN	7738138559 Dell Way	\N	SYPXNYZ	FL	23003	US	1	YNOZEHQQKN@dell.com	7738138559	3	5155581186525524	2008/09	user4486	password	34	40000	M
4487	VFXTDK	HCOPSFAGYY	4713034267 Dell Way	\N	WVMUVRY	NE	30118	US	1	HCOPSFAGYY@dell.com	4713034267	4	9618871053215116	2011/12	user4487	password	80	60000	F
4488	TFHENK	TCDYDJXCGS	4865317250 Dell Way	\N	OBOGZCM	MD	74860	US	1	TCDYDJXCGS@dell.com	4865317250	1	7215382979251445	2009/07	user4488	password	80	20000	M
4489	EFFOYI	SXLCUNINCJ	6142333340 Dell Way	\N	BIJEVUW	IA	84623	US	1	SXLCUNINCJ@dell.com	6142333340	3	4079295261297375	2010/07	user4489	password	21	60000	M
4490	GDTOVQ	AXLNGYQPZY	9219912763 Dell Way	\N	ZDUTAAO	NH	58368	US	1	AXLNGYQPZY@dell.com	9219912763	1	2027854152955115	2012/08	user4490	password	83	40000	M
4491	QUPHVN	SITRZJQYIU	4214806315 Dell Way	\N	SBVSQLG	ND	51979	US	1	SITRZJQYIU@dell.com	4214806315	3	1783338363282382	2009/09	user4491	password	80	100000	M
4492	MEIZXR	TORCFPLAHN	8544828758 Dell Way	\N	WZEHFST	NE	31024	US	1	TORCFPLAHN@dell.com	8544828758	5	9745019479654730	2011/09	user4492	password	54	20000	M
4493	WDVNXK	FAQULQBYMB	1342323467 Dell Way	\N	DUHVNWB	LA	74050	US	1	FAQULQBYMB@dell.com	1342323467	1	5124416428152472	2010/03	user4493	password	46	40000	F
4494	FYGQDG	GXSXZRKAUE	3915087257 Dell Way	\N	HPSERBW	OK	21877	US	1	GXSXZRKAUE@dell.com	3915087257	2	4142434566281736	2011/08	user4494	password	69	100000	M
4495	YOSFVP	XSOOCPJGWZ	5665607413 Dell Way	\N	ZAQAXJE	HI	65245	US	1	XSOOCPJGWZ@dell.com	5665607413	5	3386956706177443	2009/11	user4495	password	79	20000	F
4496	OKGEIZ	TXBIGIFFHG	1650001076 Dell Way	\N	VIDFNJU	AL	35588	US	1	TXBIGIFFHG@dell.com	1650001076	2	2397625260520726	2012/06	user4496	password	61	60000	M
4497	VQDVJA	WSGFXMMDHV	1683479528 Dell Way	\N	HMIQHJX	MA	64907	US	1	WSGFXMMDHV@dell.com	1683479528	2	1412345203571021	2011/10	user4497	password	82	60000	F
4498	AIUBFN	IKLUXPCSWP	1757322687 Dell Way	\N	BMXLKHA	MS	61910	US	1	IKLUXPCSWP@dell.com	1757322687	1	4133523609954864	2012/09	user4498	password	73	100000	F
4499	OBFBJP	MEMBHFYWHL	9841774306 Dell Way	\N	USWBTIQ	TN	55911	US	1	MEMBHFYWHL@dell.com	9841774306	5	2696755745913833	2011/10	user4499	password	31	40000	M
4500	KJFZWK	MXRRVOZHIR	2523294447 Dell Way	\N	DKLMAHZ	AK	16979	US	1	MXRRVOZHIR@dell.com	2523294447	4	8849886485375465	2009/01	user4500	password	70	80000	F
4501	YSGJFE	BWAPWHYOLI	2847341636 Dell Way	\N	ZXJGWJI	AR	20195	US	1	BWAPWHYOLI@dell.com	2847341636	3	2478144479449838	2012/02	user4501	password	60	100000	M
4502	VFBAHY	BWUIUJUDIR	2017993799 Dell Way	\N	MPOVXPY	CT	99383	US	1	BWUIUJUDIR@dell.com	2017993799	1	2301865826360881	2011/12	user4502	password	19	60000	F
4503	COKBPH	WYCFSFNJRC	6748376732 Dell Way	\N	XNANMDM	NE	27038	US	1	WYCFSFNJRC@dell.com	6748376732	2	1987370692193508	2011/10	user4503	password	37	80000	F
4504	RUYZRW	BWPGJYYMWM	9607688676 Dell Way	\N	NJYRWNW	MS	80378	US	1	BWPGJYYMWM@dell.com	9607688676	1	6240638731513173	2009/11	user4504	password	85	100000	M
4505	WWJTXF	IEPHDCDPPN	4588535269 Dell Way	\N	NHJADWV	AZ	14140	US	1	IEPHDCDPPN@dell.com	4588535269	2	9662074889987708	2009/03	user4505	password	67	40000	F
4506	BYZHHE	XOHZSWPGKW	5679026404 Dell Way	\N	QLZNGBO	NV	42180	US	1	XOHZSWPGKW@dell.com	5679026404	5	5926121485885233	2009/03	user4506	password	62	40000	F
4507	PNKTLZ	AKSXAYIXPT	8747099336 Dell Way	\N	XCAYQRI	DE	69020	US	1	AKSXAYIXPT@dell.com	8747099336	2	8576665506232531	2010/08	user4507	password	89	20000	F
4508	KUPKVA	CTABBXQVVS	1085042613 Dell Way	\N	VTJNCOE	WI	92519	US	1	CTABBXQVVS@dell.com	1085042613	3	5872061810456217	2012/06	user4508	password	69	40000	F
4509	HUBHWV	IXWGOSBHOV	6955486615 Dell Way	\N	RBXFFVD	HI	32423	US	1	IXWGOSBHOV@dell.com	6955486615	2	7335467366967351	2009/08	user4509	password	87	80000	F
4510	AYGVGE	SMSKOAYJRA	1574391649 Dell Way	\N	GWGCZLJ	NV	71198	US	1	SMSKOAYJRA@dell.com	1574391649	1	3562531648203731	2008/08	user4510	password	66	20000	M
4511	XWWCPJ	UAXVYHMZOI	6655184863 Dell Way	\N	FRIRAZI	CA	99150	US	1	UAXVYHMZOI@dell.com	6655184863	1	6876706947106869	2009/02	user4511	password	36	40000	F
4512	DHPMCP	KXORJNFSTW	7025958920 Dell Way	\N	BKXATZA	LA	17201	US	1	KXORJNFSTW@dell.com	7025958920	4	2929014720488340	2012/11	user4512	password	34	20000	F
4513	VNGKXD	ZPNNVFGSHQ	8880608679 Dell Way	\N	PHKPITR	WY	47865	US	1	ZPNNVFGSHQ@dell.com	8880608679	5	3547990814782679	2008/12	user4513	password	49	100000	F
4514	RIKUIA	HVVNCNUTDC	6263307156 Dell Way	\N	DSKWJKH	IA	37539	US	1	HVVNCNUTDC@dell.com	6263307156	2	3383657195139676	2008/04	user4514	password	72	80000	M
4515	EMXETT	ZHVNCOQERJ	5975684953 Dell Way	\N	POSZWYH	MN	36134	US	1	ZHVNCOQERJ@dell.com	5975684953	3	5925816770177335	2009/02	user4515	password	28	60000	M
4516	BQJVQQ	QETFUXXDNM	6859000076 Dell Way	\N	WMIVUUC	KS	34446	US	1	QETFUXXDNM@dell.com	6859000076	4	4711544195655734	2011/02	user4516	password	19	100000	M
4517	JRJAIO	UNJRLMEXJR	7622250131 Dell Way	\N	GELBHTI	WA	44950	US	1	UNJRLMEXJR@dell.com	7622250131	4	5394149424973876	2011/07	user4517	password	34	20000	F
4518	PEOEYB	NQNAVKJMRN	5916711026 Dell Way	\N	XSVRATB	RI	51392	US	1	NQNAVKJMRN@dell.com	5916711026	3	1309929113369435	2011/08	user4518	password	37	40000	M
4519	VOTXBK	KBFUKRLYPE	9946010296 Dell Way	\N	TGFMIZY	TX	53604	US	1	KBFUKRLYPE@dell.com	9946010296	4	2246985135134309	2009/01	user4519	password	88	20000	M
4520	SZQDJR	IECZQBPVUV	6458713795 Dell Way	\N	AHDZGAM	ID	67663	US	1	IECZQBPVUV@dell.com	6458713795	3	7005920493043960	2010/08	user4520	password	35	40000	M
4521	WKZOTE	QTVRIQMDRU	6454604466 Dell Way	\N	HQBHCIY	OK	87168	US	1	QTVRIQMDRU@dell.com	6454604466	2	5258087256457657	2012/08	user4521	password	23	80000	F
4522	BGTFXM	BPUSCYJXGZ	6647857424 Dell Way	\N	ZNCHMVE	CA	20361	US	1	BPUSCYJXGZ@dell.com	6647857424	5	7319211738649756	2011/08	user4522	password	69	80000	M
4523	LZVYBK	TTNRCKXCJL	8600353120 Dell Way	\N	FRXAVAD	MI	93477	US	1	TTNRCKXCJL@dell.com	8600353120	1	6127221447881312	2010/11	user4523	password	52	20000	M
4524	HYYSRR	FJTPHWYSBQ	2269993606 Dell Way	\N	QCLQFWO	AZ	12601	US	1	FJTPHWYSBQ@dell.com	2269993606	4	9385830730199816	2011/08	user4524	password	78	100000	M
4525	TPGKUQ	EKXAJPCZGE	3338819134 Dell Way	\N	KXJHMLI	NJ	15490	US	1	EKXAJPCZGE@dell.com	3338819134	2	7197278177365661	2008/02	user4525	password	37	100000	M
4526	NGNDLX	AMHQOGXSRU	3622943372 Dell Way	\N	CYHOHXP	ND	21112	US	1	AMHQOGXSRU@dell.com	3622943372	4	3308268199674785	2010/06	user4526	password	90	20000	M
4527	NFELGQ	SXFYVYPQAO	2528076708 Dell Way	\N	XOWUEKX	MN	14118	US	1	SXFYVYPQAO@dell.com	2528076708	1	5627483055926860	2008/02	user4527	password	35	80000	F
4528	KCOBVM	GTHEJXFYUU	8150187902 Dell Way	\N	VPYGMKH	NY	47598	US	1	GTHEJXFYUU@dell.com	8150187902	5	5607624219264836	2008/07	user4528	password	78	60000	M
4529	KNKWUE	EZOBENWYIL	3066988436 Dell Way	\N	XPYHWPS	NV	49397	US	1	EZOBENWYIL@dell.com	3066988436	4	9447325723711402	2008/02	user4529	password	57	60000	M
4530	ZIKEMK	SOOGKNPVKE	7870180528 Dell Way	\N	USAKLRV	NV	42637	US	1	SOOGKNPVKE@dell.com	7870180528	4	5510724079329521	2009/03	user4530	password	28	40000	M
4531	OLZYEN	NKXBZTLDNE	7420853433 Dell Way	\N	EYPWTGF	MT	97829	US	1	NKXBZTLDNE@dell.com	7420853433	5	2340168999042362	2012/02	user4531	password	65	60000	M
4532	QKREXC	CYCVKGJOKH	5996003839 Dell Way	\N	EGBLMOK	FL	44649	US	1	CYCVKGJOKH@dell.com	5996003839	1	5370457418262959	2009/06	user4532	password	19	100000	M
4533	SAUUCT	XYEDITOQXU	1940389324 Dell Way	\N	RIHGTMQ	IN	56222	US	1	XYEDITOQXU@dell.com	1940389324	3	9991192430257798	2008/05	user4533	password	82	100000	F
4534	RQLLNJ	PRRIFHGAZP	3286597136 Dell Way	\N	HFITVQG	WA	21687	US	1	PRRIFHGAZP@dell.com	3286597136	1	5284323170781136	2008/11	user4534	password	78	100000	M
4535	GGBQVT	IEYQKYPZFU	5707245045 Dell Way	\N	HZQXFOB	MO	65446	US	1	IEYQKYPZFU@dell.com	5707245045	4	5595917998813093	2009/05	user4535	password	21	80000	M
4536	DGMWOQ	UEATUZZPHY	9044512776 Dell Way	\N	FFDTGPJ	RI	29594	US	1	UEATUZZPHY@dell.com	9044512776	1	6668839562218637	2012/09	user4536	password	38	20000	M
4537	TYOKTS	KMMKLBSJHX	9793693078 Dell Way	\N	NBEDLYJ	KS	16249	US	1	KMMKLBSJHX@dell.com	9793693078	2	8247409258037806	2009/05	user4537	password	75	20000	F
4538	IKABVM	OGYQYIXWVY	8528323835 Dell Way	\N	AYKZHSA	IL	98897	US	1	OGYQYIXWVY@dell.com	8528323835	3	3971398747526109	2011/07	user4538	password	62	100000	M
4539	QZUCNA	BDYJBUEAVD	4885031138 Dell Way	\N	KULCVSC	NM	33974	US	1	BDYJBUEAVD@dell.com	4885031138	2	8347748652100564	2008/03	user4539	password	74	80000	F
4540	OTTOVX	NEYHJYDNJX	8010173943 Dell Way	\N	ZMSSOJZ	AK	65943	US	1	NEYHJYDNJX@dell.com	8010173943	1	8505432090722025	2010/09	user4540	password	20	20000	F
4541	UQHRDM	PLVOOJXLIK	9805198987 Dell Way	\N	EAYNZYD	PA	99602	US	1	PLVOOJXLIK@dell.com	9805198987	2	7222652293741704	2008/05	user4541	password	29	80000	F
4542	LLFXBQ	TQFCORLYVL	5721071225 Dell Way	\N	WJLVNFV	MO	55405	US	1	TQFCORLYVL@dell.com	5721071225	3	9168008339125664	2011/04	user4542	password	87	20000	M
4543	DAUUUK	ZXYRIWNTTW	8236210737 Dell Way	\N	FPJKLWX	WI	41244	US	1	ZXYRIWNTTW@dell.com	8236210737	4	6689562405459583	2011/10	user4543	password	44	100000	M
4544	ESOOSL	NJTKWNETTT	9414403238 Dell Way	\N	CDFYAEH	TN	81186	US	1	NJTKWNETTT@dell.com	9414403238	3	5945337241981179	2009/06	user4544	password	42	60000	F
4545	XAXJOH	DZDRDXKXZN	6397714410 Dell Way	\N	CYNGGJB	FL	94922	US	1	DZDRDXKXZN@dell.com	6397714410	3	4947349716909230	2012/12	user4545	password	64	100000	M
4546	OFOVIN	YZRWKOVXRU	2648872585 Dell Way	\N	LYAUZFT	NE	73522	US	1	YZRWKOVXRU@dell.com	2648872585	3	6888456975575537	2012/05	user4546	password	64	40000	M
4547	EEXSDX	JZHYVFPPQN	2948341071 Dell Way	\N	QLNWECO	LA	65641	US	1	JZHYVFPPQN@dell.com	2948341071	1	9845615556929260	2012/07	user4547	password	58	20000	M
4548	LTWJCV	QBQVQGMEXX	4660405973 Dell Way	\N	STCUILL	MT	67115	US	1	QBQVQGMEXX@dell.com	4660405973	2	2617338504176587	2012/06	user4548	password	83	60000	F
4549	TUHPKI	GGZMSEKQWD	9832614952 Dell Way	\N	SRLECZU	MT	41957	US	1	GGZMSEKQWD@dell.com	9832614952	3	8014010793063790	2012/11	user4549	password	87	80000	M
4550	GFCOLI	OYBTIRQMKI	1187704607 Dell Way	\N	XOLXJYG	KY	48705	US	1	OYBTIRQMKI@dell.com	1187704607	2	3932831708341837	2012/11	user4550	password	90	40000	F
4551	BUNKJM	MCVDSHOAFD	2490532073 Dell Way	\N	LCMKIVV	LA	16975	US	1	MCVDSHOAFD@dell.com	2490532073	2	9478822883218528	2008/07	user4551	password	19	40000	F
4552	OQRBCT	WGMEUNJYZL	3553824493 Dell Way	\N	KJUGFDI	MA	52265	US	1	WGMEUNJYZL@dell.com	3553824493	3	1068403043784201	2009/10	user4552	password	42	100000	F
4553	AXNUUU	GYPTINSUYC	2739480062 Dell Way	\N	OEISNSE	SD	33079	US	1	GYPTINSUYC@dell.com	2739480062	1	1294274350162595	2010/12	user4553	password	50	60000	M
4554	ZHSTOR	IIZVBUTDJY	5339111267 Dell Way	\N	MBMFGHL	MI	48610	US	1	IIZVBUTDJY@dell.com	5339111267	5	4828375202137977	2012/06	user4554	password	43	100000	M
4555	BQJSZR	SVSMOWVNIX	2574540330 Dell Way	\N	ANDIZPT	MN	60308	US	1	SVSMOWVNIX@dell.com	2574540330	2	1522894665133208	2010/04	user4555	password	80	60000	M
4556	FHYWAT	PNILIVUGWI	6418788749 Dell Way	\N	KEHZYTO	CO	24393	US	1	PNILIVUGWI@dell.com	6418788749	4	5127859449945390	2010/03	user4556	password	47	80000	F
4557	IONBDA	JPJFJPCSZG	4381595518 Dell Way	\N	ZZFTNHX	CT	93335	US	1	JPJFJPCSZG@dell.com	4381595518	3	2105701610911637	2011/04	user4557	password	63	20000	M
4558	DEYDOO	MUXCWPCDPB	7313561665 Dell Way	\N	JJPQHSP	NV	36952	US	1	MUXCWPCDPB@dell.com	7313561665	3	6040950898081065	2009/07	user4558	password	45	60000	M
4559	IPHWCC	UEZKGDAIMJ	5415265333 Dell Way	\N	XDQQSHY	ME	75680	US	1	UEZKGDAIMJ@dell.com	5415265333	4	3524503997061402	2012/03	user4559	password	19	20000	M
4560	IBWLWA	KGHOGPBQNE	6158686010 Dell Way	\N	GEXOCIH	NE	16915	US	1	KGHOGPBQNE@dell.com	6158686010	3	3370934937149286	2010/08	user4560	password	20	100000	M
4561	WIOXTV	EICUJSIOZM	2189942914 Dell Way	\N	LOPUVEW	ME	64680	US	1	EICUJSIOZM@dell.com	2189942914	1	3242832844145596	2008/12	user4561	password	88	20000	F
4562	NYAJDI	LYREGFETRS	4150450482 Dell Way	\N	IMOMJZC	MO	98315	US	1	LYREGFETRS@dell.com	4150450482	4	9121648665517568	2009/09	user4562	password	29	100000	M
4563	EFUNQS	EVZKZTCRBP	1880883716 Dell Way	\N	GOYFRKF	AK	15207	US	1	EVZKZTCRBP@dell.com	1880883716	2	7753821741323919	2009/02	user4563	password	46	60000	F
4564	EYZXDV	WOUPRMRGSG	4628318950 Dell Way	\N	EYXPDXQ	HI	29944	US	1	WOUPRMRGSG@dell.com	4628318950	3	4409067105501890	2011/12	user4564	password	71	100000	M
4565	SWAOTO	IIFUAMNGRL	6731148928 Dell Way	\N	DGOAXUG	IN	32894	US	1	IIFUAMNGRL@dell.com	6731148928	1	2586319808848202	2009/01	user4565	password	21	20000	M
4566	BQRQYA	WTAIGGZSKG	5098856141 Dell Way	\N	GLEASMH	KY	61965	US	1	WTAIGGZSKG@dell.com	5098856141	4	6916816885117442	2010/10	user4566	password	61	60000	F
4567	HEKHAD	IJKPICZPJL	5035484221 Dell Way	\N	TJDFRMU	CO	24767	US	1	IJKPICZPJL@dell.com	5035484221	4	9654883367940784	2008/03	user4567	password	46	40000	F
4568	UPJYYS	INBLNRUYKE	6819537531 Dell Way	\N	BQWNKZR	TX	62690	US	1	INBLNRUYKE@dell.com	6819537531	5	7831659916322679	2008/03	user4568	password	25	100000	M
4569	MTTFCH	HOUYJSIOUY	7362801025 Dell Way	\N	KHJJZFY	NJ	19912	US	1	HOUYJSIOUY@dell.com	7362801025	4	4017046403605491	2012/06	user4569	password	30	40000	F
4570	YMJFUX	ASGSAUMZFU	9826808808 Dell Way	\N	IOUNNKQ	HI	15848	US	1	ASGSAUMZFU@dell.com	9826808808	1	6025142993312330	2008/04	user4570	password	77	20000	M
4571	EIPBIH	IAIDNHIIQX	1954240649 Dell Way	\N	CEKMUPO	SC	67612	US	1	IAIDNHIIQX@dell.com	1954240649	5	9680246768053622	2012/01	user4571	password	75	20000	F
4572	JDRRMR	ZPFHXNXUQB	4658419760 Dell Way	\N	ECWUQRL	PA	63978	US	1	ZPFHXNXUQB@dell.com	4658419760	4	6678491948172451	2008/09	user4572	password	89	60000	M
4573	QGJIGY	NNWBLQRNVU	3480534054 Dell Way	\N	JQLBCEQ	MS	87020	US	1	NNWBLQRNVU@dell.com	3480534054	4	6427177165169269	2009/04	user4573	password	53	100000	M
4574	VFTUTH	QUSHMFDHPU	4199626429 Dell Way	\N	SQWXHJT	ND	15724	US	1	QUSHMFDHPU@dell.com	4199626429	5	3942504625767469	2012/09	user4574	password	79	80000	M
4575	PMQWDL	OKYUOFJJXA	9918802458 Dell Way	\N	FVIPOXR	WA	73527	US	1	OKYUOFJJXA@dell.com	9918802458	4	4621874888893217	2012/06	user4575	password	39	60000	M
4576	YGBJVM	IPBNZKLAQG	4076248892 Dell Way	\N	IFVGWTY	UT	57391	US	1	IPBNZKLAQG@dell.com	4076248892	4	9930125182028860	2011/02	user4576	password	86	60000	F
4577	AYFMGU	NUUYFVOMET	6215848058 Dell Way	\N	HKQBINP	NY	30740	US	1	NUUYFVOMET@dell.com	6215848058	2	4068031056318432	2010/11	user4577	password	70	60000	M
4578	XACSOX	NMCIAPNUXX	5947635119 Dell Way	\N	LYGZOXF	CT	31665	US	1	NMCIAPNUXX@dell.com	5947635119	4	2242526419460773	2009/03	user4578	password	90	20000	F
4579	CXSZKF	CTGSGAPEMO	7313343647 Dell Way	\N	KLCIRGO	HI	88927	US	1	CTGSGAPEMO@dell.com	7313343647	3	1394831895828247	2011/08	user4579	password	34	80000	M
4580	YUZEWS	KPZLEDXTOJ	9911605903 Dell Way	\N	VWABLGY	DC	75720	US	1	KPZLEDXTOJ@dell.com	9911605903	5	4494540699757636	2009/08	user4580	password	86	20000	F
4581	XIHQSW	QDAUBTIKPF	8326124310 Dell Way	\N	LRQSQUL	NH	65812	US	1	QDAUBTIKPF@dell.com	8326124310	5	3141152559313923	2011/12	user4581	password	64	80000	F
4582	XIATYE	USGOBQEHCV	6109009022 Dell Way	\N	XULSFBI	AL	89215	US	1	USGOBQEHCV@dell.com	6109009022	4	8809025151655079	2009/06	user4582	password	31	20000	M
4583	FWSKRL	QGNHKUJGSD	5597119024 Dell Way	\N	SKJTTKQ	IN	26012	US	1	QGNHKUJGSD@dell.com	5597119024	3	6721464503090829	2011/08	user4583	password	47	100000	M
4584	DHEOYL	CFWWOCOSUY	3672717167 Dell Way	\N	COSMFZR	OK	55222	US	1	CFWWOCOSUY@dell.com	3672717167	3	2089402639772743	2011/04	user4584	password	63	100000	M
4585	VKOGMT	CJIEXBZWEO	2582882025 Dell Way	\N	OQUOHMB	NH	91199	US	1	CJIEXBZWEO@dell.com	2582882025	2	3015390509273857	2011/02	user4585	password	80	80000	M
4586	KWAEYJ	NDHPDDTRSJ	1622154713 Dell Way	\N	LGRYHHV	MO	61461	US	1	NDHPDDTRSJ@dell.com	1622154713	2	7375925602391363	2012/11	user4586	password	36	40000	M
4587	HNRRAU	YQYCJPUSBB	9578309867 Dell Way	\N	KAJRWVG	WA	20837	US	1	YQYCJPUSBB@dell.com	9578309867	5	1062947602476924	2009/03	user4587	password	72	60000	M
4588	KESFDI	DFRTAKVCVV	4682888312 Dell Way	\N	LMRHTPK	OH	50672	US	1	DFRTAKVCVV@dell.com	4682888312	5	6652090809773654	2008/05	user4588	password	41	60000	M
4589	BUSJYY	BSZMNBIJMV	7545558843 Dell Way	\N	BTOQEGC	NE	23162	US	1	BSZMNBIJMV@dell.com	7545558843	4	5911008973140270	2008/04	user4589	password	26	20000	F
4590	VLATNS	SAGTIPGDQA	6624139216 Dell Way	\N	RHEYJTC	CO	54118	US	1	SAGTIPGDQA@dell.com	6624139216	1	8096144048031420	2011/03	user4590	password	81	60000	M
4591	XHFPAG	VTOLASBAKI	3027434499 Dell Way	\N	EISYKUL	AL	94270	US	1	VTOLASBAKI@dell.com	3027434499	4	2462563225533813	2008/04	user4591	password	79	100000	M
4592	BPQHLK	WWKOYKYGPG	8517944843 Dell Way	\N	YORTZRR	GA	51271	US	1	WWKOYKYGPG@dell.com	8517944843	2	8035301757510752	2011/04	user4592	password	47	80000	M
4593	BBILXF	VLDGKJVRIJ	3390073340 Dell Way	\N	IBJATOM	ND	86800	US	1	VLDGKJVRIJ@dell.com	3390073340	2	2324603046290576	2011/12	user4593	password	21	80000	F
4594	JDYPZK	SFUCBMLLUM	4034277513 Dell Way	\N	UVFIIUE	NE	13675	US	1	SFUCBMLLUM@dell.com	4034277513	2	1367041494697332	2009/12	user4594	password	24	80000	F
4595	AJCLBI	FEKRPVMCPI	2623857470 Dell Way	\N	IYQCDED	MN	49373	US	1	FEKRPVMCPI@dell.com	2623857470	5	4576961022336036	2009/08	user4595	password	55	40000	M
4596	PSAYYF	IQUDCXTKFR	1591369579 Dell Way	\N	BHVGLHR	NJ	21071	US	1	IQUDCXTKFR@dell.com	1591369579	5	7562458784785122	2010/03	user4596	password	67	20000	M
4597	SCVXLL	SOOQHZVZAD	9320176506 Dell Way	\N	UGPBXFF	WY	18545	US	1	SOOQHZVZAD@dell.com	9320176506	3	3472173231653869	2011/09	user4597	password	30	40000	M
4598	ZGHLZW	APEZKDAOYH	7263674417 Dell Way	\N	DAFIFEK	DC	77757	US	1	APEZKDAOYH@dell.com	7263674417	4	5485356077551842	2012/01	user4598	password	44	100000	F
4599	QIHNIW	RIGVJUTQYU	3405934562 Dell Way	\N	VGZARDT	LA	89636	US	1	RIGVJUTQYU@dell.com	3405934562	2	9590306797064842	2011/02	user4599	password	37	40000	F
4600	NUTKLB	QHKLAAJVWQ	8183077191 Dell Way	\N	VWHYQRV	VT	91309	US	1	QHKLAAJVWQ@dell.com	8183077191	3	9978879883885384	2008/10	user4600	password	47	60000	M
4601	DZBFQI	PCIQLEMCZJ	9593384133 Dell Way	\N	JYABUXY	NH	51015	US	1	PCIQLEMCZJ@dell.com	9593384133	4	3388472548220307	2009/03	user4601	password	80	60000	F
4602	XRWFHY	OXJSKMSUWQ	4800516383 Dell Way	\N	UXLSWAE	SD	71859	US	1	OXJSKMSUWQ@dell.com	4800516383	1	9391940358094872	2009/08	user4602	password	29	20000	F
4603	AJQYXO	IQZUITQZNN	1859667892 Dell Way	\N	LFJMJFE	SC	42945	US	1	IQZUITQZNN@dell.com	1859667892	1	1280001502949744	2009/03	user4603	password	46	40000	M
4604	AFOPNE	OHNHXNVLYA	4763935755 Dell Way	\N	VKKAPFK	NY	36662	US	1	OHNHXNVLYA@dell.com	4763935755	5	5902818789239973	2012/03	user4604	password	30	100000	F
4605	SKXWYE	KGCXBOVCJG	6128656425 Dell Way	\N	NKWSUNA	GA	51411	US	1	KGCXBOVCJG@dell.com	6128656425	1	6871734274085612	2011/10	user4605	password	20	60000	F
4606	YIFDSL	GPNULPDSCO	2691071118 Dell Way	\N	OVIBWNN	MI	57327	US	1	GPNULPDSCO@dell.com	2691071118	1	4182780551258475	2009/08	user4606	password	61	20000	M
4607	UHQGNF	THRILJLZXH	7517846453 Dell Way	\N	IZEVNPJ	OK	80141	US	1	THRILJLZXH@dell.com	7517846453	5	4505378102418035	2009/02	user4607	password	40	20000	F
4608	YIXEBF	VKREWRCEZB	2027679733 Dell Way	\N	IVPYFHS	VT	31472	US	1	VKREWRCEZB@dell.com	2027679733	2	4045765917748213	2010/04	user4608	password	71	40000	M
4609	QNTWJD	NNAEQFDSNZ	2583053431 Dell Way	\N	HMEPFCV	KS	38109	US	1	NNAEQFDSNZ@dell.com	2583053431	4	6809298818465323	2012/02	user4609	password	40	60000	M
4610	BKZFXN	FCDLGVYFDL	4703799128 Dell Way	\N	JTQLOYT	PA	73219	US	1	FCDLGVYFDL@dell.com	4703799128	4	8316933276597411	2011/03	user4610	password	50	80000	M
4611	LZNYFP	CQVYPBBAKU	2276889133 Dell Way	\N	RWJQQDI	AR	80028	US	1	CQVYPBBAKU@dell.com	2276889133	4	9795479894615712	2010/07	user4611	password	60	20000	M
4612	CZTRCJ	NAZPCZZXRW	2325120989 Dell Way	\N	GHNKQOE	PA	40508	US	1	NAZPCZZXRW@dell.com	2325120989	2	9010878906585276	2011/05	user4612	password	48	100000	F
4613	ENLOAL	NPONPLEMSM	8062357514 Dell Way	\N	ZCCOGWX	MD	29298	US	1	NPONPLEMSM@dell.com	8062357514	1	6400080316234381	2009/12	user4613	password	88	40000	F
4614	KXMWLC	KYSWCEOPEQ	4115845547 Dell Way	\N	RTXNQIT	MD	49539	US	1	KYSWCEOPEQ@dell.com	4115845547	4	4453846513759345	2009/12	user4614	password	78	80000	M
4615	IPIKAG	CWJHKYMBQF	1793262830 Dell Way	\N	YEVGXGS	IA	87047	US	1	CWJHKYMBQF@dell.com	1793262830	3	8601448501460255	2012/04	user4615	password	72	40000	M
4616	BQXITU	SBFQNGHSFL	5459120435 Dell Way	\N	OMIUEPQ	IL	23003	US	1	SBFQNGHSFL@dell.com	5459120435	1	4932850868441165	2009/06	user4616	password	42	40000	F
4617	GQVAIX	GZKMGDSSSF	2732972147 Dell Way	\N	AMJPDRT	NM	86940	US	1	GZKMGDSSSF@dell.com	2732972147	5	3579080731142312	2010/03	user4617	password	44	80000	M
4618	FUECBE	NOLQGDILEV	6759129481 Dell Way	\N	VUZMNQJ	OK	54644	US	1	NOLQGDILEV@dell.com	6759129481	2	7201253697276116	2008/01	user4618	password	56	40000	M
4619	SHWWUK	ILRLUDPPZK	4504051628 Dell Way	\N	PMXFVQS	MN	90280	US	1	ILRLUDPPZK@dell.com	4504051628	3	9233271107077600	2012/09	user4619	password	72	80000	M
4620	QMTBUE	SGZVWOVGEH	6594647934 Dell Way	\N	EJCVBOS	MN	12603	US	1	SGZVWOVGEH@dell.com	6594647934	2	7267716950736941	2009/12	user4620	password	65	100000	F
4621	KAHPTO	OPKDKRHRVR	1647945049 Dell Way	\N	UQTJJEJ	WV	60598	US	1	OPKDKRHRVR@dell.com	1647945049	2	5973067393992097	2011/04	user4621	password	20	20000	F
4622	ISCWHR	HKCYSTTJOK	4654046871 Dell Way	\N	CXTHGTW	KY	17070	US	1	HKCYSTTJOK@dell.com	4654046871	1	4668779583182186	2010/03	user4622	password	73	80000	M
4623	WQFNXP	QVIJPRXAUU	9968399839 Dell Way	\N	UBBNYKP	KS	51113	US	1	QVIJPRXAUU@dell.com	9968399839	4	6839558410923929	2011/07	user4623	password	59	80000	F
4624	TECJUX	RDNJBNDWHF	4790009085 Dell Way	\N	XVDIKLU	MD	30831	US	1	RDNJBNDWHF@dell.com	4790009085	1	7935557864140720	2012/10	user4624	password	86	80000	M
4625	ACSYUV	LDXZGTHLRC	1447993555 Dell Way	\N	PZMBTWH	FL	12990	US	1	LDXZGTHLRC@dell.com	1447993555	1	8248288498725743	2012/11	user4625	password	71	20000	F
4626	LYUHKY	EJEYQQPTGP	9387434842 Dell Way	\N	FHJCOOD	NJ	75644	US	1	EJEYQQPTGP@dell.com	9387434842	4	6792945054825396	2011/08	user4626	password	66	20000	M
4627	LJYJOI	OMZFCSLSXS	1056994875 Dell Way	\N	BAHQDXJ	AZ	53896	US	1	OMZFCSLSXS@dell.com	1056994875	4	1900884794536978	2011/10	user4627	password	66	20000	F
4628	PNTYBG	XHIPSBNLCN	2706299690 Dell Way	\N	STRPCSC	CO	51153	US	1	XHIPSBNLCN@dell.com	2706299690	4	3574172158725560	2012/11	user4628	password	53	60000	F
4629	GKMMHU	VXMWKYZYQS	1593489962 Dell Way	\N	PGVIIYU	MT	75085	US	1	VXMWKYZYQS@dell.com	1593489962	2	6725443539209665	2010/10	user4629	password	22	80000	F
4630	OHNICK	VYVTXTKPJQ	7507407044 Dell Way	\N	LRZJLMC	MT	88426	US	1	VYVTXTKPJQ@dell.com	7507407044	1	7312345099169762	2011/11	user4630	password	85	40000	F
4631	LRFWMD	RFBLQQUGBM	3755748044 Dell Way	\N	GLYTNLP	IA	57822	US	1	RFBLQQUGBM@dell.com	3755748044	1	4635550877545029	2009/05	user4631	password	57	80000	F
4632	TNNXET	ZPJQKQSWWD	2597772367 Dell Way	\N	UPRGEXU	MS	94739	US	1	ZPJQKQSWWD@dell.com	2597772367	4	3766206505708396	2011/05	user4632	password	42	60000	M
4633	VKCPJS	YZCORYKVTZ	6742736641 Dell Way	\N	MZEKTRI	WA	47171	US	1	YZCORYKVTZ@dell.com	6742736641	4	8240185184869916	2012/02	user4633	password	69	100000	M
4634	UKYMIY	PXQNHLHHXH	4508336344 Dell Way	\N	MIAEQZP	IL	67364	US	1	PXQNHLHHXH@dell.com	4508336344	2	8130768897943199	2008/01	user4634	password	44	100000	F
4635	HJUGYR	WMZHUHFBTO	5346519339 Dell Way	\N	CYEBNLR	VT	74224	US	1	WMZHUHFBTO@dell.com	5346519339	1	8029915940482170	2012/11	user4635	password	35	20000	F
4636	AJGSGS	SOMZUOTIQR	5138748996 Dell Way	\N	NRFZJDR	TX	21822	US	1	SOMZUOTIQR@dell.com	5138748996	4	1279121239669621	2011/11	user4636	password	40	80000	F
4637	OLMGEA	TDUHXDYPQP	1632783330 Dell Way	\N	UPZXHVB	OR	55358	US	1	TDUHXDYPQP@dell.com	1632783330	3	4050709044560790	2009/03	user4637	password	58	100000	M
4638	AEUBYY	WGVZEKQTFF	4441496709 Dell Way	\N	SCMODFB	HI	70042	US	1	WGVZEKQTFF@dell.com	4441496709	3	8614563057664783	2012/07	user4638	password	53	100000	M
4639	HAQGWW	BWAMMUSRNU	9267841571 Dell Way	\N	EBYKCEB	MO	80303	US	1	BWAMMUSRNU@dell.com	9267841571	3	3670811030548066	2010/05	user4639	password	90	80000	F
4640	QXHMZD	NMPIEHVZMX	2840213401 Dell Way	\N	YWZDYMX	UT	91450	US	1	NMPIEHVZMX@dell.com	2840213401	2	3677911986131221	2008/12	user4640	password	69	100000	M
4641	ZHWDVJ	SDNAZNMWMJ	5940985387 Dell Way	\N	WPIJNEG	OK	51177	US	1	SDNAZNMWMJ@dell.com	5940985387	5	4761242854874581	2009/09	user4641	password	39	40000	F
4642	EJWNCZ	BCZPPVBZSR	4228822001 Dell Way	\N	HBEMIWY	TX	79807	US	1	BCZPPVBZSR@dell.com	4228822001	1	5443981033749879	2011/05	user4642	password	55	100000	M
4643	JJVJLY	IBNECNXUVY	1725604074 Dell Way	\N	YHHVGDP	NH	31980	US	1	IBNECNXUVY@dell.com	1725604074	2	6410257933195681	2010/02	user4643	password	41	100000	F
4644	DIXBRY	PWBCTVYSTF	9698979449 Dell Way	\N	ZPLDEBJ	IA	37281	US	1	PWBCTVYSTF@dell.com	9698979449	5	4521967816632241	2009/10	user4644	password	80	60000	F
4645	TMVSCR	TFLPDEJJEY	5920812535 Dell Way	\N	UHCWRJE	NJ	27528	US	1	TFLPDEJJEY@dell.com	5920812535	5	1080973425880074	2009/04	user4645	password	29	20000	M
4646	ZWXRPC	DFGHOPMMJT	2396251571 Dell Way	\N	PGKYKAD	WA	95273	US	1	DFGHOPMMJT@dell.com	2396251571	2	3523068231530488	2009/06	user4646	password	25	40000	F
4647	AZYCCE	IKSYWFHQVO	3948079002 Dell Way	\N	BUYCXWB	AZ	28080	US	1	IKSYWFHQVO@dell.com	3948079002	2	7180690126959235	2010/09	user4647	password	19	60000	M
4648	ZOTDXE	WVBCDSXRTR	4153808658 Dell Way	\N	PWPMXRR	IA	15234	US	1	WVBCDSXRTR@dell.com	4153808658	4	7712285987101496	2009/02	user4648	password	47	40000	M
4649	ENNJJJ	KLMCJDWATT	1833196031 Dell Way	\N	QFRHWXJ	GA	60414	US	1	KLMCJDWATT@dell.com	1833196031	3	6942670806776733	2010/12	user4649	password	40	80000	F
4650	VAVFLG	ROPVLQOEGT	9421527403 Dell Way	\N	VNQSWVH	WV	48282	US	1	ROPVLQOEGT@dell.com	9421527403	3	4391252589877695	2009/02	user4650	password	78	20000	F
4651	QHPXYE	NUPDITJCPX	4039725201 Dell Way	\N	SHUNOTY	MS	31900	US	1	NUPDITJCPX@dell.com	4039725201	4	4549684201367200	2008/10	user4651	password	59	100000	F
4652	ESBJFW	YIESSGHQZO	8493962784 Dell Way	\N	LMDFLQL	SC	45082	US	1	YIESSGHQZO@dell.com	8493962784	5	3003228744957596	2010/10	user4652	password	42	60000	F
4653	KYRGWA	LOTSWKRKVE	8263090088 Dell Way	\N	OAPFLKP	IL	43486	US	1	LOTSWKRKVE@dell.com	8263090088	4	2286849353462457	2008/04	user4653	password	63	60000	F
4654	IVCIGR	CYNMPYHTMH	3671462601 Dell Way	\N	JRTUGAD	AZ	74557	US	1	CYNMPYHTMH@dell.com	3671462601	2	9935477597173304	2012/10	user4654	password	33	40000	M
4655	HOVZRU	MEKKMDXUNO	3400531236 Dell Way	\N	NHVOLXH	PA	20442	US	1	MEKKMDXUNO@dell.com	3400531236	4	8973883654456587	2010/11	user4655	password	52	80000	F
4656	ITECGI	MQUQOODDBL	8788311453 Dell Way	\N	YQXWXRZ	DE	39532	US	1	MQUQOODDBL@dell.com	8788311453	4	3067322840914130	2009/06	user4656	password	69	80000	F
4657	WTKEFB	YWQNATPLSF	6163727846 Dell Way	\N	JOCAOHI	MD	92806	US	1	YWQNATPLSF@dell.com	6163727846	4	4091736365109682	2009/05	user4657	password	55	20000	F
4658	YIJZHF	PUFJJRBOAQ	2951294556 Dell Way	\N	RBEYJOW	WI	38443	US	1	PUFJJRBOAQ@dell.com	2951294556	2	7388158738613129	2011/05	user4658	password	79	80000	M
4659	FRZKGU	QPDHRSIHKJ	1331392313 Dell Way	\N	LITAFSI	MI	94566	US	1	QPDHRSIHKJ@dell.com	1331392313	1	3912453876808286	2012/10	user4659	password	20	20000	F
4660	AMTUDJ	YKAQTIBCTJ	8165676306 Dell Way	\N	VTPNCAM	CT	27581	US	1	YKAQTIBCTJ@dell.com	8165676306	1	1228765510488301	2012/02	user4660	password	55	100000	M
4661	GQSQPD	RGWZHYTQUN	5478067731 Dell Way	\N	GIPHUTM	NH	77211	US	1	RGWZHYTQUN@dell.com	5478067731	3	8594918252900244	2008/04	user4661	password	49	40000	M
4662	EXMHOS	EOZDHQXUXG	7487375427 Dell Way	\N	KEBDQQW	DC	15107	US	1	EOZDHQXUXG@dell.com	7487375427	1	3940395122859627	2008/06	user4662	password	35	40000	F
4663	TPXMTL	MXTDUOABYF	1891751667 Dell Way	\N	CBVSYZU	NY	23111	US	1	MXTDUOABYF@dell.com	1891751667	5	6180722775403411	2009/02	user4663	password	84	20000	M
4664	VONHAK	ADFODGNIIO	9062054578 Dell Way	\N	EBNEVEI	VT	10907	US	1	ADFODGNIIO@dell.com	9062054578	2	2361108585726470	2012/04	user4664	password	83	80000	M
4665	KXXVXA	AMEGZNPORQ	4800714234 Dell Way	\N	BWLGEJH	CA	66437	US	1	AMEGZNPORQ@dell.com	4800714234	5	9640121394768358	2009/07	user4665	password	79	80000	F
4666	SOITOV	XVUKLJCCLZ	5478553324 Dell Way	\N	OSDXZGN	MD	20699	US	1	XVUKLJCCLZ@dell.com	5478553324	4	6675414402503521	2009/06	user4666	password	21	20000	F
4667	JUPESL	ZDWJFYUEMM	3879577948 Dell Way	\N	IKMOYWR	MI	62042	US	1	ZDWJFYUEMM@dell.com	3879577948	4	1267552335746586	2009/10	user4667	password	20	80000	M
4668	PYIBXL	XHRWBWIOFT	5572264502 Dell Way	\N	AURXMCM	SC	88270	US	1	XHRWBWIOFT@dell.com	5572264502	1	7272243237122894	2010/11	user4668	password	41	20000	M
4669	RFSDCA	UYBRHQWARR	4327469001 Dell Way	\N	SPDUBXR	ND	15842	US	1	UYBRHQWARR@dell.com	4327469001	1	9540030465461316	2011/04	user4669	password	73	40000	F
4670	MMOMHN	OZVFWVWNOM	6082658581 Dell Way	\N	QJNOACQ	MA	27625	US	1	OZVFWVWNOM@dell.com	6082658581	1	5157510541379452	2009/06	user4670	password	85	100000	M
4671	MHFAWE	VBARYOFKEO	7018744876 Dell Way	\N	YSOAIZF	VT	14336	US	1	VBARYOFKEO@dell.com	7018744876	2	5459605806507170	2010/01	user4671	password	49	20000	F
4672	QCEVXG	WPEKUPPINI	4772627030 Dell Way	\N	XNRWSPY	MD	83744	US	1	WPEKUPPINI@dell.com	4772627030	5	8728247916791589	2012/01	user4672	password	31	60000	F
4673	JICQFR	VQLKGUXPRL	5684235484 Dell Way	\N	GOEVMOR	VT	59408	US	1	VQLKGUXPRL@dell.com	5684235484	4	6609699594322593	2011/04	user4673	password	75	20000	M
4674	WSVNNM	ZXSTVHLGOA	2298404837 Dell Way	\N	KKMZBKN	NE	24560	US	1	ZXSTVHLGOA@dell.com	2298404837	2	4795529650058597	2012/05	user4674	password	19	100000	F
4675	WIQIHN	BAJJLQXMAH	9475893936 Dell Way	\N	YAJJNYN	NY	31400	US	1	BAJJLQXMAH@dell.com	9475893936	4	6592755086719990	2012/05	user4675	password	70	100000	M
4676	IDAWFA	GOMWLYXTXX	9337985561 Dell Way	\N	DHLBUCH	OR	72874	US	1	GOMWLYXTXX@dell.com	9337985561	4	1921416915953159	2011/07	user4676	password	78	100000	M
4677	VWWWCK	JZWIWQGTTN	1665494542 Dell Way	\N	EVIHDBZ	AR	78465	US	1	JZWIWQGTTN@dell.com	1665494542	4	3570960205048323	2012/09	user4677	password	88	80000	M
4678	VQQGZP	DIMTPFNCKI	5846510877 Dell Way	\N	LRLMQNG	OK	28588	US	1	DIMTPFNCKI@dell.com	5846510877	4	9004848810378463	2010/05	user4678	password	49	40000	M
4679	CPZSSI	EMXJZAUHLL	4268487288 Dell Way	\N	TYCGEUM	OR	48378	US	1	EMXJZAUHLL@dell.com	4268487288	2	8089415064547212	2011/07	user4679	password	74	100000	F
4680	TOVBTH	YCHZXPKIIJ	5086644517 Dell Way	\N	LPOGCHR	MI	55506	US	1	YCHZXPKIIJ@dell.com	5086644517	2	1572146149817854	2009/02	user4680	password	32	100000	M
4681	BALJZO	QYLFJUOSFE	2061564289 Dell Way	\N	HLGODRB	NE	92925	US	1	QYLFJUOSFE@dell.com	2061564289	4	1387362040113657	2009/10	user4681	password	71	40000	M
4682	ESUSJT	DOCYDVDHCP	2395110584 Dell Way	\N	NQSESHC	SD	17299	US	1	DOCYDVDHCP@dell.com	2395110584	1	8618828612379731	2012/07	user4682	password	64	20000	F
4683	KUPEYD	GWGCANEPBV	5798068121 Dell Way	\N	IGOPJJR	MS	55326	US	1	GWGCANEPBV@dell.com	5798068121	2	1114491399377584	2008/06	user4683	password	35	60000	F
4684	VTEZAB	GCBTHRVDZB	5834998614 Dell Way	\N	RPKAGXN	SC	36500	US	1	GCBTHRVDZB@dell.com	5834998614	5	7797386678867043	2011/07	user4684	password	90	80000	F
4685	EOIFVK	GOSXKVXLMM	8016368370 Dell Way	\N	VMTSANA	ND	55358	US	1	GOSXKVXLMM@dell.com	8016368370	2	1642831669654697	2011/12	user4685	password	46	100000	M
4686	SDIDKX	VIHQFSDROQ	5583535157 Dell Way	\N	KHQYIFL	CA	58918	US	1	VIHQFSDROQ@dell.com	5583535157	5	5387153725139797	2012/10	user4686	password	18	80000	M
4687	ITJGOS	NFXGIOVYZC	8499774423 Dell Way	\N	PXLUJNI	TX	45279	US	1	NFXGIOVYZC@dell.com	8499774423	4	2858716469723731	2012/05	user4687	password	30	20000	F
4688	OKRGYW	DFFSAESDTP	7138830315 Dell Way	\N	OOZCXVM	OR	62082	US	1	DFFSAESDTP@dell.com	7138830315	3	9478198821190746	2012/10	user4688	password	21	60000	F
4689	SQCOUI	UNIYFMSVAG	2359705153 Dell Way	\N	UDEQPXF	ID	53586	US	1	UNIYFMSVAG@dell.com	2359705153	1	3143812434747815	2008/07	user4689	password	47	100000	F
4690	NMZVGN	EFTQXPREKU	9523455750 Dell Way	\N	IAJFGQS	MA	79648	US	1	EFTQXPREKU@dell.com	9523455750	3	3772086796350777	2009/06	user4690	password	54	100000	M
4691	MSFZWK	TMHIDLSYTT	1272316848 Dell Way	\N	HZZYSJS	NM	94256	US	1	TMHIDLSYTT@dell.com	1272316848	5	4680429728701711	2010/11	user4691	password	43	20000	M
4692	OAKYTX	GBBRUZLNHL	2849740004 Dell Way	\N	NGDWYUU	WY	79873	US	1	GBBRUZLNHL@dell.com	2849740004	3	6749802531674505	2010/07	user4692	password	32	20000	M
4693	PBGNHI	OZCNLQVWDB	2847815963 Dell Way	\N	AZZUUZO	WY	54328	US	1	OZCNLQVWDB@dell.com	2847815963	3	1063572490122169	2009/08	user4693	password	56	20000	M
4694	UNACBA	FPLVKIYLIY	9293685706 Dell Way	\N	LDSKSSX	VT	34464	US	1	FPLVKIYLIY@dell.com	9293685706	2	9430426340084524	2010/04	user4694	password	66	40000	M
4695	SIWSNL	EJVNHHWGSZ	9192025672 Dell Way	\N	ZDRSBPZ	WV	90841	US	1	EJVNHHWGSZ@dell.com	9192025672	3	2852207469288260	2010/08	user4695	password	19	40000	M
4696	WZMIEV	ERDLNKENJH	9198140765 Dell Way	\N	FBJUBIS	WI	76488	US	1	ERDLNKENJH@dell.com	9198140765	3	4414981883484870	2012/10	user4696	password	42	100000	M
4697	VDZRHQ	UTEEXSOEYP	9763476950 Dell Way	\N	NSRWLPP	KY	22328	US	1	UTEEXSOEYP@dell.com	9763476950	2	9453080256469548	2009/01	user4697	password	71	20000	F
4698	SUNJPG	NTDGHIEXWX	3315463011 Dell Way	\N	OSIEIRI	IL	95828	US	1	NTDGHIEXWX@dell.com	3315463011	4	1317232646979391	2012/09	user4698	password	36	80000	M
4699	TBCAOW	DVEMZCIXRB	9006558299 Dell Way	\N	FVJXEQW	ME	32375	US	1	DVEMZCIXRB@dell.com	9006558299	3	9873315207194538	2008/02	user4699	password	55	100000	F
4700	QXSMBO	RNNTWKKXQG	2318274508 Dell Way	\N	GOKXKVE	IL	32087	US	1	RNNTWKKXQG@dell.com	2318274508	3	4130091534927487	2011/04	user4700	password	53	40000	F
4701	FUGTLU	HFQSPNJWUX	7482875870 Dell Way	\N	HSHDWOJ	AK	99459	US	1	HFQSPNJWUX@dell.com	7482875870	4	3835949287749827	2009/12	user4701	password	57	60000	M
4702	UEEPMK	FEATNWOKEG	6229773295 Dell Way	\N	SHDHREG	MA	85064	US	1	FEATNWOKEG@dell.com	6229773295	3	8178969807457180	2008/01	user4702	password	57	100000	F
4703	SNRCTW	DNKZBUEINL	3280923556 Dell Way	\N	MUCQBNL	NJ	18962	US	1	DNKZBUEINL@dell.com	3280923556	4	2121090026572346	2011/09	user4703	password	42	60000	F
4704	AQYWTL	GTMBXVOJHI	2715095488 Dell Way	\N	MXJZJAB	NH	77292	US	1	GTMBXVOJHI@dell.com	2715095488	3	4737702606711537	2010/12	user4704	password	61	60000	M
4705	NKIYRB	LSYGHHNQUK	2530896091 Dell Way	\N	ATUAUJT	WY	80135	US	1	LSYGHHNQUK@dell.com	2530896091	3	7318673477973790	2011/01	user4705	password	37	40000	F
4706	OGDQRV	PXDXLTRWTK	5323850750 Dell Way	\N	QTFZMFU	NY	74208	US	1	PXDXLTRWTK@dell.com	5323850750	3	7886809775605799	2011/09	user4706	password	34	40000	M
4707	IYQENO	HKZACVTMLN	4172023954 Dell Way	\N	RLAWGRP	OK	20487	US	1	HKZACVTMLN@dell.com	4172023954	3	8625519424676896	2010/10	user4707	password	77	100000	M
4708	LCGAJR	AKTWEFHRXT	3849546084 Dell Way	\N	RTAJJSM	OH	26535	US	1	AKTWEFHRXT@dell.com	3849546084	2	9624729768838734	2008/03	user4708	password	67	60000	F
4709	XPQPQB	IMFNUWKOOE	4693917057 Dell Way	\N	OXNGJGL	NY	56286	US	1	IMFNUWKOOE@dell.com	4693917057	5	7331285207998008	2008/05	user4709	password	89	20000	F
4710	QPQRXC	WLWTWLHAZE	1158664523 Dell Way	\N	OGOURGI	CO	15302	US	1	WLWTWLHAZE@dell.com	1158664523	1	5260411541443318	2012/03	user4710	password	54	80000	M
4711	DHRGEC	DXYOEZNJOT	7268822926 Dell Way	\N	YILEROF	NY	76560	US	1	DXYOEZNJOT@dell.com	7268822926	4	9367041110061110	2008/04	user4711	password	69	40000	M
4712	JPSMTQ	LHVKVEYPCH	3499735121 Dell Way	\N	BGYPMQJ	FL	37384	US	1	LHVKVEYPCH@dell.com	3499735121	2	6329413760453463	2012/09	user4712	password	30	40000	F
4713	XVBNHJ	IRENQUPYVW	4962857122 Dell Way	\N	XLJOUOW	AZ	94215	US	1	IRENQUPYVW@dell.com	4962857122	1	6949004876893014	2011/06	user4713	password	89	60000	F
4714	BAOKIG	PVWKLVFITR	8557998412 Dell Way	\N	RHMGDOE	NE	65845	US	1	PVWKLVFITR@dell.com	8557998412	1	1369908801279962	2012/09	user4714	password	40	100000	M
4715	VHACWW	YGIUMRNEIV	8871964787 Dell Way	\N	QPYFTNV	NH	73210	US	1	YGIUMRNEIV@dell.com	8871964787	3	4411381759680808	2008/04	user4715	password	23	20000	M
4716	CCLZBS	IWEZKJHFAX	7815941702 Dell Way	\N	DFRRBGJ	WA	72843	US	1	IWEZKJHFAX@dell.com	7815941702	1	9972218923736364	2012/02	user4716	password	59	100000	F
4717	AXHSFE	XEOGMTGJXM	1076837065 Dell Way	\N	BOOIYMA	OK	62327	US	1	XEOGMTGJXM@dell.com	1076837065	3	7452708910685033	2010/06	user4717	password	87	60000	F
4718	GHPKFU	YLGSSQPFSE	5625462250 Dell Way	\N	TACFAVU	AL	41836	US	1	YLGSSQPFSE@dell.com	5625462250	4	8381598247215153	2010/03	user4718	password	32	80000	F
4719	UDSOCD	VUWMJBFOVF	6858226434 Dell Way	\N	RAFMVGV	KY	88285	US	1	VUWMJBFOVF@dell.com	6858226434	5	1614823175594210	2012/07	user4719	password	59	80000	M
4720	GFUKBO	HOYJTMEZEF	4527976647 Dell Way	\N	FQALMJI	CO	26656	US	1	HOYJTMEZEF@dell.com	4527976647	5	7525348118040711	2012/08	user4720	password	47	40000	M
4721	EQXTYL	SHFFLEJRJZ	9759729950 Dell Way	\N	RVLBDOG	NC	57254	US	1	SHFFLEJRJZ@dell.com	9759729950	3	2198374178726226	2009/09	user4721	password	88	60000	F
4722	WIHIAP	NFASORCOJX	2961727117 Dell Way	\N	ZLBOSPC	NY	18559	US	1	NFASORCOJX@dell.com	2961727117	1	8384688956663013	2008/08	user4722	password	31	20000	M
4723	MJYBWD	CPSURGEOGP	2189214866 Dell Way	\N	QVHFXZI	CO	11626	US	1	CPSURGEOGP@dell.com	2189214866	2	6636600679717959	2009/05	user4723	password	57	100000	M
4724	MWOQYD	ITVPXJVNAR	4899557810 Dell Way	\N	VFOUNRU	NV	97541	US	1	ITVPXJVNAR@dell.com	4899557810	5	3765223652124405	2012/10	user4724	password	90	60000	M
4725	OCPSKI	NAGXVTXNOD	1137615771 Dell Way	\N	BJRTEIS	NH	38748	US	1	NAGXVTXNOD@dell.com	1137615771	3	1953548933379352	2008/01	user4725	password	72	60000	F
4726	JHNRUN	XSJRPWFTYP	2552465607 Dell Way	\N	KRTTJIB	MD	91246	US	1	XSJRPWFTYP@dell.com	2552465607	3	9406908987089992	2012/12	user4726	password	21	40000	F
4727	OYACWT	MNIJTCHINY	3196032219 Dell Way	\N	BGIKITI	MO	22407	US	1	MNIJTCHINY@dell.com	3196032219	3	1947902401443571	2009/09	user4727	password	43	100000	M
4728	JZNCLB	LUVOCDBBFH	4272180178 Dell Way	\N	KQQDYCG	FL	56967	US	1	LUVOCDBBFH@dell.com	4272180178	3	2892912849318236	2011/05	user4728	password	80	20000	F
4729	JFTLQO	GFQKGRQOBG	1059041430 Dell Way	\N	EFFHLKU	SD	88564	US	1	GFQKGRQOBG@dell.com	1059041430	3	2986349306069314	2012/08	user4729	password	57	40000	M
4730	HRLWXR	NHXEXLGEQL	8629332008 Dell Way	\N	JXXTSSQ	OH	32914	US	1	NHXEXLGEQL@dell.com	8629332008	3	8789999677333982	2009/10	user4730	password	67	80000	F
4731	DOJUBQ	SGOEMSUYBR	7475319756 Dell Way	\N	WVJPLCW	IN	67933	US	1	SGOEMSUYBR@dell.com	7475319756	4	4972564711235464	2009/05	user4731	password	83	60000	M
4732	GIYXAE	LERDZQFQNB	2774120544 Dell Way	\N	ACNCZUT	NY	53905	US	1	LERDZQFQNB@dell.com	2774120544	1	8717925066594035	2008/08	user4732	password	74	40000	M
4733	SGYXRD	PVCFBTTCUW	7767194556 Dell Way	\N	PXVKRMX	TX	60859	US	1	PVCFBTTCUW@dell.com	7767194556	5	2505925786215812	2010/04	user4733	password	24	40000	M
4734	BDFETB	HZCASFVOVS	6247936862 Dell Way	\N	JFJWCFK	UT	25301	US	1	HZCASFVOVS@dell.com	6247936862	2	5184550623875112	2011/08	user4734	password	18	80000	M
4735	FXNHEM	JEEPATKSCQ	9570613394 Dell Way	\N	CYTIJPM	WI	98665	US	1	JEEPATKSCQ@dell.com	9570613394	4	6522432792466134	2012/05	user4735	password	46	20000	F
4736	XLKKVO	PKPIUHKKKJ	4155329675 Dell Way	\N	DSTTFRT	DE	38394	US	1	PKPIUHKKKJ@dell.com	4155329675	1	6887285407632590	2011/04	user4736	password	82	80000	M
4737	GBOVQY	LYTTJEDTIW	2183466947 Dell Way	\N	MCBEVFM	DE	39948	US	1	LYTTJEDTIW@dell.com	2183466947	5	6562169371172786	2008/07	user4737	password	43	40000	M
4738	XCFVOD	PHNUKGCGSE	5433662910 Dell Way	\N	IWZOJEW	MO	16637	US	1	PHNUKGCGSE@dell.com	5433662910	3	6678865164984018	2012/10	user4738	password	34	80000	M
4739	LPLPES	CYCIBJBGRY	1908007610 Dell Way	\N	GFHKCTM	NH	33629	US	1	CYCIBJBGRY@dell.com	1908007610	3	1282371087931096	2009/02	user4739	password	84	80000	M
4740	IJXAMW	DVYNWEEUKK	2328653039 Dell Way	\N	CUNWGCD	LA	58815	US	1	DVYNWEEUKK@dell.com	2328653039	4	7372384524904192	2008/06	user4740	password	50	60000	M
4741	JLHGPC	ECYIGTSRVM	5995620040 Dell Way	\N	FSTHVCW	WI	80808	US	1	ECYIGTSRVM@dell.com	5995620040	1	3145681540481746	2008/06	user4741	password	21	40000	M
4742	IQLKUN	JCUDVMZIRR	2758302028 Dell Way	\N	BZMEVLY	LA	51152	US	1	JCUDVMZIRR@dell.com	2758302028	2	8938418548088522	2009/10	user4742	password	72	60000	F
4743	EZESJH	MMCYMKQDMP	4461275273 Dell Way	\N	PQKBPTN	SC	22768	US	1	MMCYMKQDMP@dell.com	4461275273	1	9055695010814816	2008/08	user4743	password	37	40000	M
4744	LAZSNM	UMYFCCSRSI	8943672211 Dell Way	\N	CTYVGTZ	NM	81744	US	1	UMYFCCSRSI@dell.com	8943672211	4	4801652571652085	2008/01	user4744	password	21	60000	F
4745	AHPNCC	MHEOZWGIYZ	3304181674 Dell Way	\N	HUGAUWV	NV	66664	US	1	MHEOZWGIYZ@dell.com	3304181674	5	7349948512855918	2009/05	user4745	password	76	40000	M
4746	KVUNIC	RWCODKMDSG	6090821537 Dell Way	\N	JTBFOSW	TN	55227	US	1	RWCODKMDSG@dell.com	6090821537	1	9048342422116548	2009/06	user4746	password	60	80000	F
4747	JHQLZM	NNPYATQHCJ	4701040271 Dell Way	\N	IIYAEUN	PA	92468	US	1	NNPYATQHCJ@dell.com	4701040271	1	4381741992197931	2012/11	user4747	password	67	40000	F
4748	HUEUHS	KFSDVZFFHO	3243178023 Dell Way	\N	EITYVMW	IA	64054	US	1	KFSDVZFFHO@dell.com	3243178023	2	5565358682069928	2012/07	user4748	password	69	40000	F
4749	WAQPKV	HORHUXPIBX	6766773463 Dell Way	\N	BATNXAD	DC	31773	US	1	HORHUXPIBX@dell.com	6766773463	1	8367178766988219	2009/04	user4749	password	30	40000	F
4750	UVSQCH	HKBEZJGXKH	7524932086 Dell Way	\N	RYERCIX	OK	44198	US	1	HKBEZJGXKH@dell.com	7524932086	1	7113076415378601	2012/04	user4750	password	90	80000	F
4751	SHFZPQ	AUQKANUHET	8533455726 Dell Way	\N	MWVUTOE	MO	65466	US	1	AUQKANUHET@dell.com	8533455726	2	9230358156841248	2012/01	user4751	password	20	60000	F
4752	GNYXOT	NZUATBFNOB	4871136755 Dell Way	\N	JIVXMIN	KS	72219	US	1	NZUATBFNOB@dell.com	4871136755	1	7699854384176434	2010/09	user4752	password	25	80000	F
4753	BPUUCT	ODNQJBELKN	1334918269 Dell Way	\N	HHZPVHH	IA	50890	US	1	ODNQJBELKN@dell.com	1334918269	4	2354160666931420	2008/06	user4753	password	46	20000	F
4754	EZDYNH	MEROJDYWKG	7763652158 Dell Way	\N	VACDHIP	KY	14001	US	1	MEROJDYWKG@dell.com	7763652158	3	5276539618149400	2008/08	user4754	password	55	40000	M
4755	RHEZUI	QIRUHOENKF	5237785155 Dell Way	\N	QNNYDVZ	VA	38839	US	1	QIRUHOENKF@dell.com	5237785155	1	9876553920097650	2012/05	user4755	password	63	80000	M
4756	UQKDGS	VBZJFNTKDH	1617414218 Dell Way	\N	XCLTCIC	ND	39899	US	1	VBZJFNTKDH@dell.com	1617414218	3	7093615132384003	2011/03	user4756	password	40	60000	M
4757	SQCKMD	KWJYPTCXRF	6930224040 Dell Way	\N	ILHQNWZ	NH	47296	US	1	KWJYPTCXRF@dell.com	6930224040	2	6540540490299464	2012/10	user4757	password	49	80000	F
4758	NCXQMT	ZLJTOHLTQX	9327867962 Dell Way	\N	AHLXGAI	VT	39946	US	1	ZLJTOHLTQX@dell.com	9327867962	5	2136839325074106	2009/07	user4758	password	58	100000	M
4759	MNCFNO	PHCXTVNQWU	6210863483 Dell Way	\N	CTADBYL	WY	84253	US	1	PHCXTVNQWU@dell.com	6210863483	2	4250247541815043	2008/03	user4759	password	89	80000	M
4760	CVHQLP	TIIOVZLQBF	8132500305 Dell Way	\N	REHPQHL	HI	66382	US	1	TIIOVZLQBF@dell.com	8132500305	2	8799979062285275	2011/12	user4760	password	64	100000	M
4761	YNGNGO	WVKWHAXMRC	5601979854 Dell Way	\N	THTASZQ	MS	39058	US	1	WVKWHAXMRC@dell.com	5601979854	2	3597372130956501	2008/02	user4761	password	24	20000	M
4762	IPXXMS	HIAHGMZIFG	6920654870 Dell Way	\N	CGYBXMJ	MD	76139	US	1	HIAHGMZIFG@dell.com	6920654870	3	8832613704726101	2011/08	user4762	password	55	20000	F
4763	KYSDGA	DOHQNPWUSC	8188036818 Dell Way	\N	TTZFCKY	RI	94260	US	1	DOHQNPWUSC@dell.com	8188036818	3	6132668524049223	2009/08	user4763	password	77	80000	M
4764	NWUOAI	VQWLNQDPJX	5311355097 Dell Way	\N	POZZMTX	IL	35235	US	1	VQWLNQDPJX@dell.com	5311355097	3	8801051945891232	2009/04	user4764	password	48	100000	F
4765	FKFOGW	KSJAWZKTOY	6869346873 Dell Way	\N	TOLNLSU	WA	39027	US	1	KSJAWZKTOY@dell.com	6869346873	2	6860808450728656	2008/01	user4765	password	80	40000	F
4766	CVSZFK	JGGIRZXQSL	7845669295 Dell Way	\N	BFXUAVC	NV	13953	US	1	JGGIRZXQSL@dell.com	7845669295	4	1852311213035136	2011/01	user4766	password	57	80000	M
4767	GRBQAI	WJZWGPOSRU	5921882962 Dell Way	\N	PLVKOML	IN	28115	US	1	WJZWGPOSRU@dell.com	5921882962	5	2817480205092579	2008/08	user4767	password	19	40000	F
4768	BYIJVR	JRYYGQPBFB	7764357676 Dell Way	\N	WQPJBXO	NJ	85533	US	1	JRYYGQPBFB@dell.com	7764357676	4	5256874952465296	2011/01	user4768	password	74	100000	F
4769	CFVUON	SNUICWODSE	9677253988 Dell Way	\N	TCGQQWM	MA	60587	US	1	SNUICWODSE@dell.com	9677253988	1	6419536461122335	2011/12	user4769	password	62	100000	F
4770	LQUZIH	TQJPENIJHK	6377624103 Dell Way	\N	PYBLKLZ	MA	61873	US	1	TQJPENIJHK@dell.com	6377624103	1	6119446838740260	2009/12	user4770	password	74	80000	M
4771	OPXVJO	FZTTHCASRY	3960996939 Dell Way	\N	TCJECTT	OH	87032	US	1	FZTTHCASRY@dell.com	3960996939	5	8361633463297040	2008/07	user4771	password	46	80000	F
4772	HMMVRL	OLTRLMIJFL	2213917336 Dell Way	\N	SKNLEFI	MS	19846	US	1	OLTRLMIJFL@dell.com	2213917336	4	6774747591000051	2010/04	user4772	password	74	100000	M
4773	GRLSGW	MXHYGRERJP	2356111739 Dell Way	\N	EVTKEGN	IN	87427	US	1	MXHYGRERJP@dell.com	2356111739	5	2083061759360134	2012/08	user4773	password	80	20000	F
4774	HXODJM	KISBMJLBOH	1449168148 Dell Way	\N	VYLBLTY	NH	62256	US	1	KISBMJLBOH@dell.com	1449168148	3	3089717810973525	2012/09	user4774	password	58	20000	M
4775	CIAOTI	GUVQGWEORC	6229143018 Dell Way	\N	ATOTRDJ	OR	70996	US	1	GUVQGWEORC@dell.com	6229143018	4	4561706708744168	2008/11	user4775	password	19	40000	F
4776	AVXJCS	ESYBWNTZNM	7800330797 Dell Way	\N	NHERQXJ	HI	61044	US	1	ESYBWNTZNM@dell.com	7800330797	2	4648819434456527	2011/08	user4776	password	59	100000	F
4777	LEMEIF	DJBQCBEPPL	7036759245 Dell Way	\N	UGCSQIG	MA	71809	US	1	DJBQCBEPPL@dell.com	7036759245	1	3556484641507268	2009/12	user4777	password	68	80000	F
4778	EWMKZV	MPYNTOCFIJ	6612633792 Dell Way	\N	IAZQHJI	WI	56407	US	1	MPYNTOCFIJ@dell.com	6612633792	1	5351319043897093	2009/11	user4778	password	63	60000	M
4779	CXSYJI	WWCLYHTIQU	6891758142 Dell Way	\N	HHBRQAE	IA	30001	US	1	WWCLYHTIQU@dell.com	6891758142	3	2015298661310225	2009/01	user4779	password	80	40000	M
4780	OHIXEE	ZPDHIMXDTE	5943823709 Dell Way	\N	EKUFPAL	IA	63419	US	1	ZPDHIMXDTE@dell.com	5943823709	3	6925520942546428	2010/11	user4780	password	63	100000	F
4781	YWICVX	GCGSAKMEOX	3413033234 Dell Way	\N	ZUMAFSP	RI	31046	US	1	GCGSAKMEOX@dell.com	3413033234	1	1954309884458780	2012/02	user4781	password	37	100000	F
4782	PYWNEZ	UXZEKETHEN	8373433682 Dell Way	\N	TETMUNS	AZ	73736	US	1	UXZEKETHEN@dell.com	8373433682	5	8810207117348910	2008/10	user4782	password	83	80000	M
4783	TEWTZU	TDEYWLCKFH	3284838152 Dell Way	\N	DRBRKDK	HI	16566	US	1	TDEYWLCKFH@dell.com	3284838152	2	8510514080524445	2008/12	user4783	password	56	100000	F
4784	KRDEKH	JIDVLOASSS	8317370749 Dell Way	\N	UJDXTIZ	AK	67978	US	1	JIDVLOASSS@dell.com	8317370749	1	6665873495861889	2009/01	user4784	password	76	80000	M
4785	YYEFHM	JCYXDQPWKZ	6190625327 Dell Way	\N	ZITHHTY	CO	93315	US	1	JCYXDQPWKZ@dell.com	6190625327	3	1052372012753039	2009/03	user4785	password	72	40000	F
4786	XOLKYO	IWRZMNJLMS	9052507787 Dell Way	\N	FUZZTCX	KS	59963	US	1	IWRZMNJLMS@dell.com	9052507787	4	7750314195640386	2011/01	user4786	password	82	60000	M
4787	IYNWHJ	NGVBQHOINJ	7460106019 Dell Way	\N	HMDKJLZ	IA	23245	US	1	NGVBQHOINJ@dell.com	7460106019	5	2678479492198676	2010/06	user4787	password	75	100000	F
4788	ITRSHX	OJNVYWIHEU	2765969906 Dell Way	\N	KOEWNKA	IA	36835	US	1	OJNVYWIHEU@dell.com	2765969906	5	7690944018773735	2012/10	user4788	password	28	40000	M
4789	VZVTNF	GJDCSLHNWV	2084340561 Dell Way	\N	RTJCTQJ	WI	53443	US	1	GJDCSLHNWV@dell.com	2084340561	5	3216266448143870	2009/03	user4789	password	74	20000	F
4790	PVTVBC	YEVKMIHHAA	1336742729 Dell Way	\N	RCUIMSU	NH	67691	US	1	YEVKMIHHAA@dell.com	1336742729	5	8741181985475124	2012/12	user4790	password	23	60000	M
4791	VGVXFA	TPMCXUCYLE	9287705474 Dell Way	\N	STRKOGB	NH	19066	US	1	TPMCXUCYLE@dell.com	9287705474	3	1260257762391120	2012/10	user4791	password	73	80000	F
4792	PSGPMW	BOUVQSHVKB	8869089199 Dell Way	\N	MVPTXEV	SD	62924	US	1	BOUVQSHVKB@dell.com	8869089199	5	4725067616906017	2011/08	user4792	password	52	40000	F
4793	TVUQWI	KSZDZVNAIJ	8348191120 Dell Way	\N	QBGVXBK	RI	89427	US	1	KSZDZVNAIJ@dell.com	8348191120	3	5393366618081928	2009/08	user4793	password	77	20000	F
4794	PRIYBA	YEATSBBCRD	8127362790 Dell Way	\N	IMAKXUH	OK	30442	US	1	YEATSBBCRD@dell.com	8127362790	1	8835576879326255	2011/01	user4794	password	41	40000	M
4795	QEURCZ	SVRTXTLACX	9525253149 Dell Way	\N	BNVWVNB	NJ	58333	US	1	SVRTXTLACX@dell.com	9525253149	2	6255563883576543	2009/06	user4795	password	39	100000	M
4796	BPRAHN	SBKMMKPKMD	8821665673 Dell Way	\N	FIYTKPH	KY	83605	US	1	SBKMMKPKMD@dell.com	8821665673	4	3358326681423932	2008/07	user4796	password	80	40000	F
4797	OGLBZN	LMZWBJJEPR	8245540148 Dell Way	\N	DJBSQKO	MS	99971	US	1	LMZWBJJEPR@dell.com	8245540148	4	5819802991114557	2011/11	user4797	password	67	40000	F
4798	DGEQSQ	PPRZYWPPAY	6313949706 Dell Way	\N	RTPBHCB	CA	77857	US	1	PPRZYWPPAY@dell.com	6313949706	4	6898820574395359	2009/12	user4798	password	78	40000	F
4799	ZAYPQO	HQNEFDEEUX	3143161303 Dell Way	\N	TVEVXGP	MO	99493	US	1	HQNEFDEEUX@dell.com	3143161303	4	9541785183362664	2008/02	user4799	password	30	20000	F
4800	CQURYK	ECQHGUCENX	5644826977 Dell Way	\N	IJVOYIO	FL	15854	US	1	ECQHGUCENX@dell.com	5644826977	2	2936534289270639	2011/04	user4800	password	46	80000	M
4801	ELXPQZ	GXGAAKOXTY	3981364344 Dell Way	\N	THWBWBD	MA	38163	US	1	GXGAAKOXTY@dell.com	3981364344	1	6483482809271664	2011/11	user4801	password	58	100000	F
4802	LNYLTW	STWCIUVGOD	2075388919 Dell Way	\N	DPAFSKN	AR	51641	US	1	STWCIUVGOD@dell.com	2075388919	4	3966215034946799	2011/08	user4802	password	65	20000	F
4803	POXMGR	JJZEEGSIJH	5634967626 Dell Way	\N	IOASCBE	GA	83335	US	1	JJZEEGSIJH@dell.com	5634967626	5	5246405582409352	2008/01	user4803	password	63	80000	M
4804	NHVEQF	EVKKNSUVBI	2683966369 Dell Way	\N	VULXYQS	MN	55380	US	1	EVKKNSUVBI@dell.com	2683966369	4	5600369288120419	2012/06	user4804	password	24	40000	M
4805	YNIDRD	NBRFVNHEIB	3261083935 Dell Way	\N	PGZGYMT	DC	19928	US	1	NBRFVNHEIB@dell.com	3261083935	5	5817239402793348	2009/04	user4805	password	35	40000	M
4806	OKMSXO	KDKXKPGLFM	6045406516 Dell Way	\N	LLLXEPA	ME	60744	US	1	KDKXKPGLFM@dell.com	6045406516	4	8785105123650283	2011/01	user4806	password	67	40000	F
4807	ECHSML	DKVSQHXDSI	6584322095 Dell Way	\N	PQNERYT	HI	72322	US	1	DKVSQHXDSI@dell.com	6584322095	1	7447701775468887	2009/05	user4807	password	27	60000	F
4808	LEZWIK	SAAZYESGTJ	2013294296 Dell Way	\N	UYASSGK	KY	35036	US	1	SAAZYESGTJ@dell.com	2013294296	4	7050290239974857	2009/02	user4808	password	29	80000	F
4809	DOPOGQ	PFOTYVNHPM	5756809263 Dell Way	\N	IHFPSNW	SD	24877	US	1	PFOTYVNHPM@dell.com	5756809263	1	3404356372077018	2011/09	user4809	password	58	100000	F
4810	EKMUZS	JSREGZTSHB	8931967516 Dell Way	\N	XWTLSOP	IA	64967	US	1	JSREGZTSHB@dell.com	8931967516	5	3945317579898983	2010/10	user4810	password	60	80000	F
4811	CKDUTW	MYCLSVTTTP	1232475977 Dell Way	\N	NFICVPS	OH	57133	US	1	MYCLSVTTTP@dell.com	1232475977	1	3825122991111130	2011/09	user4811	password	53	80000	F
4812	QMXMZV	PKNLDHETUJ	5386570122 Dell Way	\N	BXFQPXE	NJ	11835	US	1	PKNLDHETUJ@dell.com	5386570122	2	7850039523094893	2012/12	user4812	password	83	80000	F
4813	UCKQSU	DDYLISGSTD	6223937060 Dell Way	\N	XKTUPJV	AZ	62226	US	1	DDYLISGSTD@dell.com	6223937060	1	5484524114988745	2010/09	user4813	password	84	40000	M
4814	HXMCBQ	BNZTTSNWQX	1419932590 Dell Way	\N	QKNZGPO	SD	67062	US	1	BNZTTSNWQX@dell.com	1419932590	2	3708885540720075	2012/08	user4814	password	23	40000	M
4815	PJOFKB	FDVXQSOOIY	6328509478 Dell Way	\N	BHFRVAH	UT	38375	US	1	FDVXQSOOIY@dell.com	6328509478	5	9130087033379824	2011/02	user4815	password	47	40000	F
4816	ZMWBRA	WPRODGWCID	5853350171 Dell Way	\N	HZZIGVQ	TX	71165	US	1	WPRODGWCID@dell.com	5853350171	3	7971972153987736	2012/10	user4816	password	34	100000	F
4817	CYYCVO	UJSAFVIJDH	6635350954 Dell Way	\N	ILOECKW	NJ	93553	US	1	UJSAFVIJDH@dell.com	6635350954	3	7325341193936766	2012/06	user4817	password	87	100000	F
4818	XBGLVP	EVVZEECLNO	1312364705 Dell Way	\N	ARQKNHI	DE	86016	US	1	EVVZEECLNO@dell.com	1312364705	1	3975933030247688	2012/12	user4818	password	74	100000	F
4819	AIWQNS	LMWQPHDEHV	3403380517 Dell Way	\N	VSJCBNY	AZ	58681	US	1	LMWQPHDEHV@dell.com	3403380517	1	5577704102266580	2008/12	user4819	password	57	20000	F
4820	KSUCDH	YUWGYBOUWG	7376746949 Dell Way	\N	DYHRXJF	DE	48922	US	1	YUWGYBOUWG@dell.com	7376746949	2	4432667179498822	2009/04	user4820	password	66	80000	M
4821	LSCTRX	QXVRLPNSTM	2721891837 Dell Way	\N	AKKJPOV	IN	77269	US	1	QXVRLPNSTM@dell.com	2721891837	3	1101583763025701	2012/03	user4821	password	88	40000	M
4822	CBOZRM	VJYKXQEKQO	1711994470 Dell Way	\N	UAEIVMB	AL	12140	US	1	VJYKXQEKQO@dell.com	1711994470	5	2893773146905005	2008/03	user4822	password	26	20000	F
4823	RCZEXI	CIFTNPKBJL	9415571956 Dell Way	\N	FSHSTHS	TN	27661	US	1	CIFTNPKBJL@dell.com	9415571956	5	4709232077002525	2008/01	user4823	password	68	80000	F
4824	RXBZAJ	FTXUDYEPEW	7862738093 Dell Way	\N	WWQEPMJ	NC	42429	US	1	FTXUDYEPEW@dell.com	7862738093	3	4410696174483746	2010/05	user4824	password	54	20000	F
4825	OCGYHA	VBETGTYCPV	9494155613 Dell Way	\N	TTLFCZO	TX	62150	US	1	VBETGTYCPV@dell.com	9494155613	2	9254841100890190	2010/06	user4825	password	29	100000	M
4826	KXUKTW	PNCILFXHYQ	2910937771 Dell Way	\N	TDTSSPH	NV	91288	US	1	PNCILFXHYQ@dell.com	2910937771	1	3900466032791883	2009/02	user4826	password	78	80000	F
4827	QFTMUG	PCSUAATQTX	2885654519 Dell Way	\N	KLPZTHX	WV	44523	US	1	PCSUAATQTX@dell.com	2885654519	2	5350679659750313	2008/02	user4827	password	54	80000	F
4828	GDDNSG	GNGGGXADHM	9174826665 Dell Way	\N	THFBEFL	LA	58461	US	1	GNGGGXADHM@dell.com	9174826665	3	7056043314281852	2010/01	user4828	password	19	80000	F
4829	EFXKLK	QSRNSVVFPC	8472031266 Dell Way	\N	LQGQBQE	WV	11979	US	1	QSRNSVVFPC@dell.com	8472031266	2	1738688815850764	2012/01	user4829	password	37	20000	F
4830	EKSPAL	GOECKJRMUH	5039351962 Dell Way	\N	SKJIOIJ	MA	72634	US	1	GOECKJRMUH@dell.com	5039351962	2	7720725490711630	2011/03	user4830	password	18	100000	M
4831	SMRDTG	HWQQNCLVVV	9659516485 Dell Way	\N	FEJNOTF	WY	99206	US	1	HWQQNCLVVV@dell.com	9659516485	4	3048612040001899	2012/08	user4831	password	80	80000	F
4832	NVWTCT	KTHMECIAIM	4197728866 Dell Way	\N	JVADBAD	AK	76846	US	1	KTHMECIAIM@dell.com	4197728866	5	4239392000716180	2009/08	user4832	password	52	80000	F
4833	JNOCXI	JJNMSNUEXQ	4216819237 Dell Way	\N	FARGERZ	MT	69675	US	1	JJNMSNUEXQ@dell.com	4216819237	4	3801600483246148	2012/06	user4833	password	74	20000	M
4834	IHWRRG	EEYSZDPPJQ	9512984586 Dell Way	\N	HPUZPHQ	WI	12143	US	1	EEYSZDPPJQ@dell.com	9512984586	4	5455244190990925	2011/12	user4834	password	52	20000	F
4835	ITZOYD	NQCQFSZWZP	5016775813 Dell Way	\N	QYFYPEY	MT	95703	US	1	NQCQFSZWZP@dell.com	5016775813	2	9483898716513068	2012/04	user4835	password	34	40000	F
4836	FVZIIP	KZVCZRCOIA	8243846970 Dell Way	\N	TGPXFDW	NM	44311	US	1	KZVCZRCOIA@dell.com	8243846970	3	7245820452459157	2008/10	user4836	password	72	40000	M
4837	SOZIYY	EBXWDMEEFL	9867249982 Dell Way	\N	UDQXZGH	SC	83901	US	1	EBXWDMEEFL@dell.com	9867249982	5	6691250462085009	2011/01	user4837	password	37	60000	M
4838	GUOFZQ	DVUPAYVLSY	7979105480 Dell Way	\N	BQYIXTD	VT	63605	US	1	DVUPAYVLSY@dell.com	7979105480	4	6955059875734151	2008/02	user4838	password	37	40000	M
4839	VNWMQS	GFTEAEXZGN	9641541875 Dell Way	\N	YOLSSJH	MO	99916	US	1	GFTEAEXZGN@dell.com	9641541875	3	1888799942564219	2009/10	user4839	password	18	20000	F
4840	WOYPUE	IZFNXETLDI	4225226056 Dell Way	\N	XVAGDMG	CA	11524	US	1	IZFNXETLDI@dell.com	4225226056	2	8546645007561893	2009/05	user4840	password	29	40000	M
4841	CVTGET	LRRQLCUTZP	2037930621 Dell Way	\N	TGTGNVH	UT	24292	US	1	LRRQLCUTZP@dell.com	2037930621	2	6068026285152883	2009/06	user4841	password	55	40000	F
4842	HQMACE	STQUNJUDDB	4722244097 Dell Way	\N	WKORRLW	SC	71941	US	1	STQUNJUDDB@dell.com	4722244097	1	2487908897921443	2012/06	user4842	password	53	40000	F
4843	ZGFEYY	UTLENOIPLS	5158911425 Dell Way	\N	EDKPZFH	MA	36450	US	1	UTLENOIPLS@dell.com	5158911425	2	7757161384914071	2012/07	user4843	password	80	100000	M
4844	BCSZWM	LBZAJPLCTO	7899445779 Dell Way	\N	NINSQXA	CO	31271	US	1	LBZAJPLCTO@dell.com	7899445779	1	7939779200125486	2011/12	user4844	password	58	80000	F
4845	HQXTCZ	TCIINKBCXK	5822871454 Dell Way	\N	PQBNRDT	ME	28085	US	1	TCIINKBCXK@dell.com	5822871454	1	2537858171854168	2008/09	user4845	password	34	40000	F
4846	DDLCWN	LEBWGDUQTK	3009715344 Dell Way	\N	SGBWAMB	NE	58515	US	1	LEBWGDUQTK@dell.com	3009715344	4	3191979674156755	2010/01	user4846	password	61	60000	F
4847	ASAODF	PZLSTCMEUT	5750359769 Dell Way	\N	GRUTSIH	WA	10247	US	1	PZLSTCMEUT@dell.com	5750359769	2	1343050794675946	2008/12	user4847	password	32	20000	M
4848	FSVLHU	WAOZNTUGZL	4543043005 Dell Way	\N	ASEJACJ	NC	53567	US	1	WAOZNTUGZL@dell.com	4543043005	4	5115111446939409	2010/10	user4848	password	27	100000	M
4849	YGVTCW	ICJBXPAJQT	6152383221 Dell Way	\N	NZUQIIC	OK	98704	US	1	ICJBXPAJQT@dell.com	6152383221	2	8241207911167295	2011/02	user4849	password	42	80000	F
4850	EKLASO	KTMZUVPOJP	4999008580 Dell Way	\N	IZXRCQQ	NY	93395	US	1	KTMZUVPOJP@dell.com	4999008580	2	1355572385713458	2011/01	user4850	password	46	100000	F
4851	VYDKIX	WISSYGBNPB	1121721918 Dell Way	\N	LGDBWVZ	KS	28270	US	1	WISSYGBNPB@dell.com	1121721918	1	3106790800578892	2009/01	user4851	password	66	40000	M
4852	UQISNR	KGQQHDGIOM	7758484832 Dell Way	\N	MQJIPRN	NJ	79383	US	1	KGQQHDGIOM@dell.com	7758484832	1	8210186998825521	2010/03	user4852	password	75	40000	M
4853	DYLUIR	KZYOFHDSUT	3627106165 Dell Way	\N	BCJSQYM	MA	96819	US	1	KZYOFHDSUT@dell.com	3627106165	4	2929137947037816	2008/01	user4853	password	26	40000	M
4854	OZHFKG	EZMMCEHWFJ	4104973452 Dell Way	\N	FYAELJD	OK	25156	US	1	EZMMCEHWFJ@dell.com	4104973452	4	2635163983330130	2010/01	user4854	password	27	20000	M
4855	KFKRKJ	DWMHDINNOL	3345171695 Dell Way	\N	NSXXVPC	FL	46252	US	1	DWMHDINNOL@dell.com	3345171695	4	4635927669238299	2009/08	user4855	password	47	80000	M
4856	VLHEPE	RXIAKWOWJH	2502680619 Dell Way	\N	THDJJIT	NM	96817	US	1	RXIAKWOWJH@dell.com	2502680619	1	6642785204108805	2010/10	user4856	password	55	40000	F
4857	UOVZGS	HGDDUANCTV	1972829653 Dell Way	\N	FDENWVM	AR	84436	US	1	HGDDUANCTV@dell.com	1972829653	4	6670991402119399	2011/12	user4857	password	82	60000	M
4858	SKULRB	OVWOIYIDDL	6298730047 Dell Way	\N	IQIDDJY	IA	98082	US	1	OVWOIYIDDL@dell.com	6298730047	5	9752442379947752	2010/04	user4858	password	56	20000	M
4859	IPJJEE	FSNDARHMZY	1867922989 Dell Way	\N	UCBDBID	NV	25383	US	1	FSNDARHMZY@dell.com	1867922989	1	5124930280726403	2011/04	user4859	password	28	100000	M
4860	NIBRNU	ERVVZHVXBY	9135447029 Dell Way	\N	ZFZHIQL	ME	79227	US	1	ERVVZHVXBY@dell.com	9135447029	1	1591653382405638	2008/01	user4860	password	88	60000	F
4861	AFWUKO	PGNWCKYAJD	5344931296 Dell Way	\N	ARMQCXK	AK	95590	US	1	PGNWCKYAJD@dell.com	5344931296	1	9622313563711942	2010/08	user4861	password	38	60000	M
4862	DGGSWM	FTOQROAVOR	2049698666 Dell Way	\N	IFUFQUE	CT	85530	US	1	FTOQROAVOR@dell.com	2049698666	3	4903074174188078	2010/01	user4862	password	36	60000	F
4863	MGEZMX	OCPCDLRVTX	6860642652 Dell Way	\N	PZOJDRF	IA	32339	US	1	OCPCDLRVTX@dell.com	6860642652	4	3577970367856324	2012/03	user4863	password	60	40000	F
4864	TJYRXB	HAETSZNPPM	4447577956 Dell Way	\N	EYPWEVC	TN	53486	US	1	HAETSZNPPM@dell.com	4447577956	4	7156180067453534	2012/02	user4864	password	28	80000	F
4865	CKJDSJ	ILBHZRWLWV	1325112918 Dell Way	\N	ASAWUVJ	FL	61556	US	1	ILBHZRWLWV@dell.com	1325112918	1	7171909551136196	2008/11	user4865	password	29	40000	F
4866	NKAXSM	YALQWWNSXF	8586763591 Dell Way	\N	TUAPDFE	DE	42973	US	1	YALQWWNSXF@dell.com	8586763591	2	3324038784019649	2012/08	user4866	password	59	60000	M
4867	PKRBJS	NAPJNHHTBB	6310320422 Dell Way	\N	TQEZUJI	NJ	72559	US	1	NAPJNHHTBB@dell.com	6310320422	4	3676203167531639	2008/02	user4867	password	39	80000	M
4868	ZUXRIX	GRLOZEPBYF	6163614443 Dell Way	\N	FXAPFQH	SD	33347	US	1	GRLOZEPBYF@dell.com	6163614443	5	4559840423520655	2012/09	user4868	password	86	100000	M
4869	VNVTUN	EIMIXOHDTE	4990625939 Dell Way	\N	DJKUQFB	GA	26210	US	1	EIMIXOHDTE@dell.com	4990625939	1	9041980599518866	2009/11	user4869	password	48	40000	F
4870	GYETDN	GMLUTPOXTX	6254429569 Dell Way	\N	HNONOTR	AK	82920	US	1	GMLUTPOXTX@dell.com	6254429569	2	7440792555920780	2012/08	user4870	password	28	40000	M
4871	IARWGD	HBWWQUPOCD	4486048080 Dell Way	\N	CPRWHSR	UT	18255	US	1	HBWWQUPOCD@dell.com	4486048080	5	7186390663497151	2010/02	user4871	password	34	100000	F
4872	XSJAZL	XWCSLRUOUK	7642985580 Dell Way	\N	GQRYIOB	OH	47773	US	1	XWCSLRUOUK@dell.com	7642985580	2	5758079150691629	2012/01	user4872	password	64	100000	M
4873	AXTMVQ	ONBGIQASXQ	8876896648 Dell Way	\N	JWYYXQJ	NM	88554	US	1	ONBGIQASXQ@dell.com	8876896648	4	9561494553927332	2010/06	user4873	password	71	60000	F
4874	NAFDPS	EVAVVTSMCO	9140481016 Dell Way	\N	LALCJCY	ID	72203	US	1	EVAVVTSMCO@dell.com	9140481016	4	2502617172431201	2011/04	user4874	password	58	20000	F
4875	TGXMLT	NGOGYAJNMK	9125969415 Dell Way	\N	YOTBNAT	MD	82040	US	1	NGOGYAJNMK@dell.com	9125969415	1	2030768071301281	2010/03	user4875	password	50	40000	F
4876	JRWCED	RKCRUPEEOS	8775793269 Dell Way	\N	YPFYIPT	IA	68624	US	1	RKCRUPEEOS@dell.com	8775793269	4	8483903055079282	2009/11	user4876	password	37	80000	M
4877	DTTHKE	JCYZGCNZAD	3347533158 Dell Way	\N	EZMUSTL	NH	48784	US	1	JCYZGCNZAD@dell.com	3347533158	5	3975525447633118	2010/07	user4877	password	84	80000	F
4878	RYSVIV	UHCXVBXZFX	9618288234 Dell Way	\N	MZQFLFQ	OH	19742	US	1	UHCXVBXZFX@dell.com	9618288234	2	7027300904970617	2012/11	user4878	password	90	60000	M
4879	SJEODM	QBHRZHXWTX	5264059236 Dell Way	\N	MYISOAU	MT	32073	US	1	QBHRZHXWTX@dell.com	5264059236	2	2245587544981390	2010/11	user4879	password	89	20000	F
4880	DSLQJM	XBLEYHYWUW	6481145490 Dell Way	\N	FMKFHYM	PA	38122	US	1	XBLEYHYWUW@dell.com	6481145490	2	2955141607206315	2010/05	user4880	password	53	80000	F
4881	XJMJHN	VMMDKIXGNJ	2132284749 Dell Way	\N	RTRPFKX	TN	67442	US	1	VMMDKIXGNJ@dell.com	2132284749	3	1302264550235122	2011/03	user4881	password	29	60000	M
4882	QXVDSH	QVRYTXMDPG	8862970284 Dell Way	\N	UEMFCIV	HI	76748	US	1	QVRYTXMDPG@dell.com	8862970284	5	9265817542560400	2008/05	user4882	password	51	80000	F
4883	HUZOKV	GJOEWRTCMY	5841603202 Dell Way	\N	ORAWNGQ	MA	15822	US	1	GJOEWRTCMY@dell.com	5841603202	3	4764058239758015	2012/01	user4883	password	67	40000	M
4884	RVGMBQ	BFMSZOEXDV	6745776846 Dell Way	\N	XAJEQSF	FL	21501	US	1	BFMSZOEXDV@dell.com	6745776846	1	2630606595892459	2009/06	user4884	password	20	100000	F
4885	HLJYMP	KFOZKLDGJD	6576154077 Dell Way	\N	PNUITZL	MD	22750	US	1	KFOZKLDGJD@dell.com	6576154077	4	6307542110327632	2011/09	user4885	password	81	100000	F
4886	FWQUHV	JGFVJMFNBT	1146790962 Dell Way	\N	IJMHUWL	ME	62726	US	1	JGFVJMFNBT@dell.com	1146790962	1	3402289139106870	2012/01	user4886	password	47	20000	M
4887	AXEWHK	CCUOHIPAQZ	3185556776 Dell Way	\N	NYTKJEZ	MA	33138	US	1	CCUOHIPAQZ@dell.com	3185556776	2	3448370797559619	2011/05	user4887	password	29	80000	F
4888	INOTQR	OEZWUZNTNM	3140604881 Dell Way	\N	NXVSWFZ	CO	52608	US	1	OEZWUZNTNM@dell.com	3140604881	4	8677283078897745	2009/06	user4888	password	28	80000	M
4889	SLPKZT	JWOJKHWWVT	2880093545 Dell Way	\N	RNQWMTJ	OR	55184	US	1	JWOJKHWWVT@dell.com	2880093545	1	9354074670467528	2009/11	user4889	password	82	20000	F
4890	MMHFVD	TFNBBJWVBK	6655608195 Dell Way	\N	LYXFHPS	MS	76252	US	1	TFNBBJWVBK@dell.com	6655608195	5	6144810129888356	2010/12	user4890	password	80	100000	F
4891	DFGHYM	UANEWJFHVE	1759334880 Dell Way	\N	EALUSYN	KY	83602	US	1	UANEWJFHVE@dell.com	1759334880	5	7848570397589356	2012/10	user4891	password	31	20000	F
4892	LIZXDZ	LIWVOEQSIQ	7261929146 Dell Way	\N	ECIDPRY	OH	57324	US	1	LIWVOEQSIQ@dell.com	7261929146	4	4180735739879310	2012/09	user4892	password	45	40000	F
4893	JGEJSM	FNAJDTSTXU	6923848296 Dell Way	\N	CAKUYCH	NM	75510	US	1	FNAJDTSTXU@dell.com	6923848296	3	4901097096968442	2008/11	user4893	password	53	40000	F
4894	RTVEZI	FJMYBFVWIW	5670887127 Dell Way	\N	GCUJKLC	AZ	97507	US	1	FJMYBFVWIW@dell.com	5670887127	1	8460061653517187	2008/07	user4894	password	86	80000	F
4895	TVGCAP	OZRUVNCRUF	7385201012 Dell Way	\N	LDQXFSW	OR	84284	US	1	OZRUVNCRUF@dell.com	7385201012	4	3987721343059093	2011/05	user4895	password	60	40000	F
4896	VMHKAG	BUBOXSJDEM	6624941423 Dell Way	\N	TCSMYLH	NY	26349	US	1	BUBOXSJDEM@dell.com	6624941423	2	6286446947138757	2009/09	user4896	password	78	20000	F
4897	CLFINZ	JBXCLAGXTI	8498772521 Dell Way	\N	QFHBNZG	DC	35520	US	1	JBXCLAGXTI@dell.com	8498772521	2	9948876425623896	2011/05	user4897	password	31	80000	M
4898	JCIJMK	GOVGVTAEJG	7456552620 Dell Way	\N	MLTLRXS	MS	33906	US	1	GOVGVTAEJG@dell.com	7456552620	1	6838238533586264	2012/12	user4898	password	52	40000	F
4899	UQMEXB	AEWTFBDLNO	1315562288 Dell Way	\N	FYFDRSK	MD	89924	US	1	AEWTFBDLNO@dell.com	1315562288	2	8244375143200160	2010/07	user4899	password	77	40000	F
4900	HMDIMH	FGMGJYTXDS	5888339357 Dell Way	\N	DGJWQUT	OH	15668	US	1	FGMGJYTXDS@dell.com	5888339357	1	6662447078619153	2009/06	user4900	password	79	80000	M
4901	ZZLGES	TKBSEZVWCC	7526914930 Dell Way	\N	GYTARLC	HI	68019	US	1	TKBSEZVWCC@dell.com	7526914930	3	2167825188487768	2010/03	user4901	password	24	60000	F
4902	OUJGOU	IGYHCVKFCI	2870397754 Dell Way	\N	ZDALFGC	WI	86088	US	1	IGYHCVKFCI@dell.com	2870397754	3	1633772072847932	2009/01	user4902	password	37	100000	M
4903	QCLKKR	JSUFCAHLZK	6775966793 Dell Way	\N	MLQSNOO	OK	16361	US	1	JSUFCAHLZK@dell.com	6775966793	1	2094778758939355	2012/11	user4903	password	89	60000	M
4904	KYJCIC	XNEXUQXFCI	6069141162 Dell Way	\N	VVVJJOL	AL	60220	US	1	XNEXUQXFCI@dell.com	6069141162	5	4811239415314049	2010/06	user4904	password	46	100000	F
4905	UBTWYG	BVBRSGTBBO	4640135426 Dell Way	\N	WLYKWZZ	MI	92256	US	1	BVBRSGTBBO@dell.com	4640135426	5	4485940963495523	2011/12	user4905	password	77	60000	M
4906	OLXVMS	WDLCXMEMJP	7378346203 Dell Way	\N	LUMKUXI	FL	89012	US	1	WDLCXMEMJP@dell.com	7378346203	5	8201559463981540	2010/07	user4906	password	73	20000	M
4907	QXLJUP	VXNIBZSRKM	7358606209 Dell Way	\N	DVHADMX	TN	50369	US	1	VXNIBZSRKM@dell.com	7358606209	2	9969722851645202	2010/06	user4907	password	89	20000	F
4908	LMDAIA	NQBNISXVVS	1241589788 Dell Way	\N	CWWPUSA	MO	15827	US	1	NQBNISXVVS@dell.com	1241589788	5	5610328518785537	2008/01	user4908	password	80	60000	M
4909	ZLXZZN	BNWTKRPDUM	3516382167 Dell Way	\N	AKGSKTT	MI	72018	US	1	BNWTKRPDUM@dell.com	3516382167	3	7869370794389398	2008/11	user4909	password	42	20000	F
4910	FCITDV	PXGHNKCZKM	4841292641 Dell Way	\N	GCXZWIR	DC	79550	US	1	PXGHNKCZKM@dell.com	4841292641	2	6804341107141227	2011/05	user4910	password	89	100000	M
4911	HSQDIO	JPBTRBDEHG	8191350087 Dell Way	\N	BGCJYGE	LA	56903	US	1	JPBTRBDEHG@dell.com	8191350087	1	9292325969319792	2011/02	user4911	password	49	20000	M
4912	BFDQOS	SIKTMPBSQI	5542580688 Dell Way	\N	VAGBEPP	WV	75977	US	1	SIKTMPBSQI@dell.com	5542580688	4	8462887230794878	2012/10	user4912	password	64	20000	F
4913	UQPNIX	XCKNEDDMYE	9268378842 Dell Way	\N	TAIJPHC	CA	13171	US	1	XCKNEDDMYE@dell.com	9268378842	1	8679120962042362	2010/01	user4913	password	81	40000	M
4914	MVAJTD	UGHXKTVONV	1591142555 Dell Way	\N	XWLEYNF	UT	58493	US	1	UGHXKTVONV@dell.com	1591142555	3	6083173947408796	2012/10	user4914	password	34	60000	M
4915	GUJJOQ	QMBKIPXDMU	2815716556 Dell Way	\N	PRTCWQQ	WI	14764	US	1	QMBKIPXDMU@dell.com	2815716556	5	8422670695930720	2010/04	user4915	password	49	80000	F
4916	VBQLRC	MCKCAOPVDH	1436477285 Dell Way	\N	OGEEWCF	CA	99532	US	1	MCKCAOPVDH@dell.com	1436477285	3	3549477471038699	2010/03	user4916	password	43	40000	F
4917	ZTXCGA	NIBBYWFFKL	7847072446 Dell Way	\N	JPIMUKM	TX	94021	US	1	NIBBYWFFKL@dell.com	7847072446	2	2124397621955722	2008/08	user4917	password	44	20000	F
4918	HFPHSY	IUXFADPMME	3676727677 Dell Way	\N	VZZGLWE	HI	26508	US	1	IUXFADPMME@dell.com	3676727677	2	8314510005526245	2011/06	user4918	password	31	100000	M
4919	UGJTPE	QUETKRGPMG	4737587619 Dell Way	\N	OSSKXXP	GA	32233	US	1	QUETKRGPMG@dell.com	4737587619	5	7210382981225849	2010/10	user4919	password	43	40000	F
4920	SDPXUJ	COTTVIGBXZ	6541878208 Dell Way	\N	TIWRYBY	LA	92406	US	1	COTTVIGBXZ@dell.com	6541878208	5	7323797591030598	2012/05	user4920	password	70	80000	F
4921	IOHSQV	MKRVQSTPMB	2292146075 Dell Way	\N	MEANCJL	OK	38593	US	1	MKRVQSTPMB@dell.com	2292146075	4	6978625994641334	2012/05	user4921	password	29	20000	M
4922	LXOGJY	YEPRXEDZQI	4019776561 Dell Way	\N	ZEKJPDR	PA	82476	US	1	YEPRXEDZQI@dell.com	4019776561	4	2365761966910213	2010/10	user4922	password	22	100000	M
4923	QEBODG	DUEIYDZGDD	7884685118 Dell Way	\N	RMTVDMP	MO	19386	US	1	DUEIYDZGDD@dell.com	7884685118	5	9216467922553420	2012/11	user4923	password	62	60000	F
4924	RAFYEZ	CMXFLEIPVV	8393239876 Dell Way	\N	IQZUGLX	AK	48571	US	1	CMXFLEIPVV@dell.com	8393239876	5	3880316884722561	2010/04	user4924	password	47	20000	F
4925	PBLODY	MIKQRZLMHC	7060851349 Dell Way	\N	MCIYAJJ	TN	28224	US	1	MIKQRZLMHC@dell.com	7060851349	2	5421702534426004	2008/05	user4925	password	75	80000	F
4926	GGOFSX	PIOOUBWWNY	3490070417 Dell Way	\N	FLZPVUU	MO	15153	US	1	PIOOUBWWNY@dell.com	3490070417	3	4953594599384815	2008/03	user4926	password	81	40000	F
4927	KNEHDM	WRHYOEMNKY	7877008644 Dell Way	\N	MZTGTGI	AL	81428	US	1	WRHYOEMNKY@dell.com	7877008644	1	1180633458308875	2011/06	user4927	password	53	20000	M
4928	QIBDFT	LDHPPUZOHY	4035103084 Dell Way	\N	HOSNWTI	NM	85957	US	1	LDHPPUZOHY@dell.com	4035103084	2	3417211416177452	2012/04	user4928	password	33	60000	M
4929	HPWABZ	IQPDPDKOLY	2173450845 Dell Way	\N	HZVAHLW	NJ	74200	US	1	IQPDPDKOLY@dell.com	2173450845	3	1158256236929446	2009/11	user4929	password	66	80000	M
4930	NQONZE	DCUHMJSLQR	4833879807 Dell Way	\N	GRZSNPK	NV	11900	US	1	DCUHMJSLQR@dell.com	4833879807	5	9323163246735932	2008/08	user4930	password	50	80000	F
4931	ZDFEGI	ZNUJFFZXMQ	4603088902 Dell Way	\N	WEELOVM	WY	84758	US	1	ZNUJFFZXMQ@dell.com	4603088902	1	5055947724729777	2012/09	user4931	password	70	100000	M
4932	YABGZO	BIUGISTZOX	3453099934 Dell Way	\N	EAMZMLV	VA	59168	US	1	BIUGISTZOX@dell.com	3453099934	4	3135928768664598	2012/07	user4932	password	21	100000	M
4933	CEORFX	LMGDFFSCJT	8399104849 Dell Way	\N	PJGBEDP	MN	88286	US	1	LMGDFFSCJT@dell.com	8399104849	3	4952060958370567	2012/05	user4933	password	19	100000	M
4934	PQUMBG	SFMYXPIRER	3948160281 Dell Way	\N	XFWAUIX	NJ	80333	US	1	SFMYXPIRER@dell.com	3948160281	3	2416316506452858	2009/06	user4934	password	69	100000	F
4935	MLDTDI	FCGVKXZCUF	3096149098 Dell Way	\N	YVZHSPB	AL	17760	US	1	FCGVKXZCUF@dell.com	3096149098	2	5806254034396262	2012/04	user4935	password	61	60000	M
4936	TEXCKZ	IFJGFMBKLW	6474375318 Dell Way	\N	KSPZUQB	AL	11344	US	1	IFJGFMBKLW@dell.com	6474375318	5	3975059916730970	2009/05	user4936	password	23	100000	M
4937	YAZYJF	IQKURUFOEY	2276869888 Dell Way	\N	EETUGUV	TX	79008	US	1	IQKURUFOEY@dell.com	2276869888	1	2574165353551507	2009/01	user4937	password	73	20000	F
4938	TCKYKA	IFSDLHIJLN	8772918372 Dell Way	\N	DGTXBPR	GA	70738	US	1	IFSDLHIJLN@dell.com	8772918372	3	7203975917305798	2011/08	user4938	password	71	40000	M
4939	DHCEQI	XUTFCDRQHX	4063299505 Dell Way	\N	JFZZXFQ	PA	65408	US	1	XUTFCDRQHX@dell.com	4063299505	2	2859016659203917	2008/09	user4939	password	83	40000	F
4940	AKRIHM	CMPGDFNBOS	1500665598 Dell Way	\N	BOPGEJW	NC	74771	US	1	CMPGDFNBOS@dell.com	1500665598	4	5071281331125647	2012/10	user4940	password	53	100000	F
4941	EIMQKZ	FRCKEEZWFN	1033222184 Dell Way	\N	MLSVHFO	KY	84312	US	1	FRCKEEZWFN@dell.com	1033222184	2	6744677538517863	2010/04	user4941	password	79	80000	M
4942	IHAHMR	KWVPVSUJFG	7550853159 Dell Way	\N	BANGPWC	NE	26021	US	1	KWVPVSUJFG@dell.com	7550853159	1	5094172509852797	2010/09	user4942	password	21	100000	F
4943	BEMSPJ	OEFGZOLFPM	3118867471 Dell Way	\N	SWBPYQU	OH	74913	US	1	OEFGZOLFPM@dell.com	3118867471	2	5037456638645381	2009/02	user4943	password	51	40000	F
4944	YBYIPC	NVCCHHSUAP	6909733984 Dell Way	\N	VPNMKFF	NM	52934	US	1	NVCCHHSUAP@dell.com	6909733984	5	6587930945213885	2008/03	user4944	password	87	20000	F
4945	WJWZXS	BAAJSUJHQZ	2494332222 Dell Way	\N	VCJBIAO	WV	92532	US	1	BAAJSUJHQZ@dell.com	2494332222	1	2445393387228250	2008/02	user4945	password	50	20000	M
4946	IZLABL	ALEVUMLUIO	3090452350 Dell Way	\N	DKWEYVB	CO	93162	US	1	ALEVUMLUIO@dell.com	3090452350	2	1611890582367777	2011/03	user4946	password	61	100000	F
4947	AAHMBS	RWNEIHMWLX	6101740244 Dell Way	\N	TPVORYM	VA	27296	US	1	RWNEIHMWLX@dell.com	6101740244	3	4848258643876761	2008/07	user4947	password	66	20000	M
4948	YRRRIO	FMWMZTYXMN	3809927392 Dell Way	\N	TBESOCX	CT	69835	US	1	FMWMZTYXMN@dell.com	3809927392	2	3161164885386824	2012/06	user4948	password	79	100000	F
4949	NPMBVZ	YIYRGVETOF	9512481932 Dell Way	\N	YGTBDXS	MN	24833	US	1	YIYRGVETOF@dell.com	9512481932	3	6636761914007366	2011/05	user4949	password	73	40000	M
4950	FJUEHC	DZIZDCOJBV	8128324567 Dell Way	\N	CCZAULE	PA	88846	US	1	DZIZDCOJBV@dell.com	8128324567	3	3179145098663866	2010/11	user4950	password	34	80000	F
4951	AYNDCM	MCPPQYQLBT	9930617132 Dell Way	\N	LBOWGHT	AL	86029	US	1	MCPPQYQLBT@dell.com	9930617132	3	7198428581003100	2009/05	user4951	password	83	40000	F
4952	KJKWVM	MKCLBONUAP	2574073232 Dell Way	\N	IWVQQWM	NJ	50300	US	1	MKCLBONUAP@dell.com	2574073232	5	8181478527840228	2008/01	user4952	password	25	60000	F
4953	NJGZVR	CHSRVNRKWO	4257951483 Dell Way	\N	GMEDZUO	DE	66976	US	1	CHSRVNRKWO@dell.com	4257951483	2	7342117145657540	2010/09	user4953	password	28	100000	F
4954	KYXCBE	VSZIKKEYQR	3324248013 Dell Way	\N	DTRXIVO	OH	15462	US	1	VSZIKKEYQR@dell.com	3324248013	1	7848873537499458	2009/02	user4954	password	77	100000	F
4955	SWDWSW	WAGHFFYXIS	2905337315 Dell Way	\N	OGAKVSL	AZ	89256	US	1	WAGHFFYXIS@dell.com	2905337315	3	1125674635171890	2008/04	user4955	password	25	80000	F
4956	GPVDMW	KTBPRYYJNF	9973601556 Dell Way	\N	JXACJCZ	NE	59679	US	1	KTBPRYYJNF@dell.com	9973601556	3	8379187607672066	2008/04	user4956	password	88	40000	M
4957	VMJRWC	TMUSLDGQND	1987930599 Dell Way	\N	QQNTPBH	NH	70208	US	1	TMUSLDGQND@dell.com	1987930599	4	9839054098352792	2008/01	user4957	password	83	100000	M
4958	GPKJIX	DAIHHZUKQK	6750672652 Dell Way	\N	XJAZQPR	PA	38087	US	1	DAIHHZUKQK@dell.com	6750672652	5	4311054657679051	2010/09	user4958	password	84	80000	F
4959	IEQFIR	OPYNKJDVHN	2154745169 Dell Way	\N	VGDLXXT	ND	77337	US	1	OPYNKJDVHN@dell.com	2154745169	1	5361377558205277	2008/11	user4959	password	76	40000	F
4960	LOJDDZ	BQKLUFSHBY	6254914365 Dell Way	\N	LMWJGLC	MA	56233	US	1	BQKLUFSHBY@dell.com	6254914365	3	4543175284750760	2009/10	user4960	password	50	100000	F
4961	VYMUAD	ELXKDFLCQY	3628929166 Dell Way	\N	YZEKCOX	NY	98097	US	1	ELXKDFLCQY@dell.com	3628929166	1	7730545720085502	2011/11	user4961	password	24	60000	M
4962	OJVROG	PYJUJMLILL	8074767181 Dell Way	\N	MVNBSFA	WY	35121	US	1	PYJUJMLILL@dell.com	8074767181	4	2458384570199996	2012/04	user4962	password	89	60000	M
4963	VDFBSD	LNNXYVIKID	6316760074 Dell Way	\N	YJWDKWL	GA	62872	US	1	LNNXYVIKID@dell.com	6316760074	1	8914660433307291	2010/07	user4963	password	56	40000	M
4964	SLJWXW	JVVFEFNHEX	5294781204 Dell Way	\N	EIIATOP	KS	66309	US	1	JVVFEFNHEX@dell.com	5294781204	5	2356733383145183	2008/04	user4964	password	76	80000	M
4965	EPQAZL	WEPCSXGPCO	3378397349 Dell Way	\N	YCIMRQC	DE	58973	US	1	WEPCSXGPCO@dell.com	3378397349	1	8496079546399415	2008/11	user4965	password	59	40000	F
4966	FGLRDQ	HGIFMYHBXJ	4504444190 Dell Way	\N	JJBAMFO	PA	44796	US	1	HGIFMYHBXJ@dell.com	4504444190	5	3569559102877975	2012/01	user4966	password	74	20000	F
4967	GVLWDR	EIEDQFAZPK	9379109068 Dell Way	\N	BPXGERQ	ND	52953	US	1	EIEDQFAZPK@dell.com	9379109068	3	5696236027404666	2011/09	user4967	password	78	100000	M
4968	HURYZA	CDQIDPYOQO	2019233185 Dell Way	\N	LXSCOHP	MO	82141	US	1	CDQIDPYOQO@dell.com	2019233185	1	5476470530964434	2012/02	user4968	password	20	40000	M
4969	SEXSGA	IPEYOTPCFN	4535120401 Dell Way	\N	VIBCXOX	AK	76275	US	1	IPEYOTPCFN@dell.com	4535120401	5	8775806583929808	2010/03	user4969	password	75	20000	F
4970	SWPTFF	XDTRTVWGQE	5080803122 Dell Way	\N	HTCWQCP	AL	15446	US	1	XDTRTVWGQE@dell.com	5080803122	3	3103935777675360	2009/08	user4970	password	59	100000	F
4971	ERQJPU	CGNXDUOHCH	7992880543 Dell Way	\N	JYYMNYO	WY	46395	US	1	CGNXDUOHCH@dell.com	7992880543	2	1004540145862847	2009/03	user4971	password	51	60000	M
4972	CWLXYS	LWVFKDHSNG	9913891166 Dell Way	\N	QZUPOTZ	KS	98816	US	1	LWVFKDHSNG@dell.com	9913891166	4	2401834337972104	2010/02	user4972	password	18	60000	F
4973	LLYEWU	ZCFDKYQQOQ	3795689686 Dell Way	\N	KDEEDME	CT	24358	US	1	ZCFDKYQQOQ@dell.com	3795689686	3	3841874673031271	2009/02	user4973	password	41	80000	M
4974	GXLBXN	HAXFROUHYX	5102923451 Dell Way	\N	MDBZHED	NH	78396	US	1	HAXFROUHYX@dell.com	5102923451	5	8925191502552480	2011/08	user4974	password	50	20000	M
4975	XCMKKN	IPEWJMVHYZ	2624272840 Dell Way	\N	JYGOBVH	MT	76552	US	1	IPEWJMVHYZ@dell.com	2624272840	2	4639155707787723	2011/05	user4975	password	89	60000	F
4976	MYWZGL	DDVQZDOYMN	2442111976 Dell Way	\N	EAPAICT	MS	47113	US	1	DDVQZDOYMN@dell.com	2442111976	1	7854666002560408	2008/08	user4976	password	34	80000	M
4977	BPVNTY	JJXMYWYLBZ	3655900756 Dell Way	\N	ABHDVUN	WV	90686	US	1	JJXMYWYLBZ@dell.com	3655900756	1	5764021538663656	2010/09	user4977	password	24	60000	F
4978	XCBWML	UYJQXURWVS	4058712027 Dell Way	\N	DYOXMNV	PA	67086	US	1	UYJQXURWVS@dell.com	4058712027	2	4301667697262019	2010/11	user4978	password	68	40000	M
4979	TELEYK	NPHIGDDZHB	1385349276 Dell Way	\N	NENBAHR	KY	60433	US	1	NPHIGDDZHB@dell.com	1385349276	4	4797771276906133	2011/02	user4979	password	47	60000	F
4980	VRFFFU	NNBQRBXTOC	5794685210 Dell Way	\N	GPCOHLC	KS	29572	US	1	NNBQRBXTOC@dell.com	5794685210	1	3814949347171933	2012/07	user4980	password	60	80000	F
4981	UZKPNY	RDQSBJHEQW	3331730559 Dell Way	\N	HEESHMY	SD	59574	US	1	RDQSBJHEQW@dell.com	3331730559	4	1894896976649761	2012/07	user4981	password	41	80000	M
4982	TGARYD	HQFRXJHURL	1870963839 Dell Way	\N	YKSLINZ	NH	34733	US	1	HQFRXJHURL@dell.com	1870963839	3	8079734255559743	2010/02	user4982	password	39	20000	F
4983	HVHLDX	RUVBBQSNPC	8471281581 Dell Way	\N	GALTAAB	CT	52655	US	1	RUVBBQSNPC@dell.com	8471281581	3	6092235970776529	2008/09	user4983	password	85	60000	M
4984	FWQDOL	YPNPIAEKGE	9318653581 Dell Way	\N	WAFWBIJ	VT	86746	US	1	YPNPIAEKGE@dell.com	9318653581	1	5777173746377230	2012/06	user4984	password	20	20000	F
4985	REXDDM	QSURWFYBBY	9560028232 Dell Way	\N	GYAOHYK	HI	95878	US	1	QSURWFYBBY@dell.com	9560028232	1	4680959653574974	2012/02	user4985	password	72	80000	F
4986	QVKDLD	XCZDAAEZHD	3745326103 Dell Way	\N	AVLYGRX	HI	76590	US	1	XCZDAAEZHD@dell.com	3745326103	2	8743177259806544	2008/11	user4986	password	29	80000	M
4987	OUDSSG	RWHSBHAEHW	8941632165 Dell Way	\N	PGCHDIA	MI	58491	US	1	RWHSBHAEHW@dell.com	8941632165	3	4849537931848318	2008/03	user4987	password	27	80000	M
4988	HISNAO	VSPCSUKOKQ	9798929450 Dell Way	\N	RRUASFO	NE	74468	US	1	VSPCSUKOKQ@dell.com	9798929450	4	9045066091232004	2008/03	user4988	password	81	40000	M
4989	PXNDSG	TVZNGOXWFO	5466848889 Dell Way	\N	RGGXUVP	RI	50549	US	1	TVZNGOXWFO@dell.com	5466848889	5	7040033481083811	2009/03	user4989	password	32	100000	F
4990	TCWZVS	ZIYNGVTVMZ	1364117191 Dell Way	\N	CJTXZNJ	MN	46541	US	1	ZIYNGVTVMZ@dell.com	1364117191	5	6837722711265088	2009/10	user4990	password	75	100000	M
4991	RZSJYB	HLHCEDOEFY	5693748119 Dell Way	\N	YCXMMJW	MT	27550	US	1	HLHCEDOEFY@dell.com	5693748119	4	9847718408796936	2009/09	user4991	password	81	100000	M
4992	PIQQQC	YSGBHKGGJJ	7076545063 Dell Way	\N	DVWMRJR	GA	23119	US	1	YSGBHKGGJJ@dell.com	7076545063	3	9005558736622334	2010/07	user4992	password	61	20000	M
4993	GTLISE	OTLZASJJVE	6830069094 Dell Way	\N	GIWPABT	OH	63796	US	1	OTLZASJJVE@dell.com	6830069094	2	1880505269858986	2009/05	user4993	password	85	60000	F
4994	JUVOJO	AJPSSZNWFW	5467614597 Dell Way	\N	SVWUOOK	HI	82116	US	1	AJPSSZNWFW@dell.com	5467614597	3	2416953371837735	2010/12	user4994	password	37	80000	M
4995	CICRIM	GAEFOBKKUF	8321152978 Dell Way	\N	HOUWZAR	MN	53722	US	1	GAEFOBKKUF@dell.com	8321152978	5	4871297947596759	2008/09	user4995	password	30	20000	F
4996	HVJTCK	XHZYSKSYRH	7214037654 Dell Way	\N	TNHUETG	WY	67159	US	1	XHZYSKSYRH@dell.com	7214037654	1	3939996358007193	2012/04	user4996	password	44	20000	F
4997	SWEDTM	CSFMLEETXS	7425582318 Dell Way	\N	ASWTYWK	NM	96954	US	1	CSFMLEETXS@dell.com	7425582318	3	3053772056940943	2008/08	user4997	password	42	80000	F
4998	NYGAAZ	GNKKSEIKEA	4097078416 Dell Way	\N	HXZDIQD	AL	21094	US	1	GNKKSEIKEA@dell.com	4097078416	1	7802041673567147	2011/11	user4998	password	36	20000	M
4999	NFWMLK	XVCBEMGETE	6833843025 Dell Way	\N	DXMTANX	KY	63659	US	1	XVCBEMGETE@dell.com	6833843025	1	5395677450112999	2012/03	user4999	password	40	60000	F
5000	EXWOVS	QXWCDBWIFT	4374727722 Dell Way	\N	UZTHWCX	MS	19743	US	1	QXWCDBWIFT@dell.com	4374727722	3	3916635029949248	2011/10	user5000	password	72	100000	M
5001	PKOIBL	EEPGAXLTRK	1078738261 Dell Way	\N	MZGOWTR	IA	24162	US	1	EEPGAXLTRK@dell.com	1078738261	5	9767712954431772	2011/10	user5001	password	68	40000	F
5002	GSGRWL	HCLEOFWYSV	1624339623 Dell Way	\N	EHSYYYC	WV	87440	US	1	HCLEOFWYSV@dell.com	1624339623	4	6812315356452019	2011/02	user5002	password	80	20000	M
5003	DSROZU	ADIFAGXVLE	9819092436 Dell Way	\N	NKDMMCI	ND	82944	US	1	ADIFAGXVLE@dell.com	9819092436	2	9138455869164320	2012/04	user5003	password	68	100000	F
5004	JNADNE	MSETQAEUOO	7480412173 Dell Way	\N	XABAJPV	KS	92801	US	1	MSETQAEUOO@dell.com	7480412173	1	3250857011880725	2010/02	user5004	password	38	80000	M
5005	HXDLKV	PDLPIGDXEE	7413756194 Dell Way	\N	YENOZVM	OH	99761	US	1	PDLPIGDXEE@dell.com	7413756194	1	1952017777599394	2012/11	user5005	password	70	40000	M
5006	VSFRII	DYQJCNNGMR	7220430330 Dell Way	\N	TARPMJP	FL	51542	US	1	DYQJCNNGMR@dell.com	7220430330	1	4098851255606860	2010/06	user5006	password	28	40000	F
5007	IXNRAL	IKNWXUIONI	4505153174 Dell Way	\N	GCVPSAB	MA	26970	US	1	IKNWXUIONI@dell.com	4505153174	4	6886386523954571	2010/01	user5007	password	79	100000	M
5008	JOZVWJ	ISGCAVQJBT	1225603659 Dell Way	\N	EQLERVJ	AZ	64882	US	1	ISGCAVQJBT@dell.com	1225603659	4	6789168458431960	2012/06	user5008	password	60	40000	F
5009	OAXXJP	EMQZCABWER	4187373570 Dell Way	\N	HJJCTLS	PA	16336	US	1	EMQZCABWER@dell.com	4187373570	4	6068809351883829	2012/11	user5009	password	62	60000	M
5010	NKHDOT	TNWTPSYGAI	7620605442 Dell Way	\N	QCBCVVE	DE	50872	US	1	TNWTPSYGAI@dell.com	7620605442	1	3820215072482824	2009/08	user5010	password	33	100000	M
5011	MZOGSC	CMRVLYVUOY	4802663098 Dell Way	\N	VRTRWXC	NE	12722	US	1	CMRVLYVUOY@dell.com	4802663098	5	6670159125234932	2011/10	user5011	password	63	20000	M
5012	EJMGLZ	XHKVCFKBAC	4357882028 Dell Way	\N	URYSUNT	GA	49647	US	1	XHKVCFKBAC@dell.com	4357882028	5	2903753575403243	2012/12	user5012	password	87	20000	F
5013	KKTKIA	UEDZOEAQZS	7789880248 Dell Way	\N	PRMCLSO	SC	59457	US	1	UEDZOEAQZS@dell.com	7789880248	4	5550632650498301	2011/12	user5013	password	77	20000	F
5014	ONSPIW	TILXICXBRP	3666929333 Dell Way	\N	NTAGIVU	AZ	65102	US	1	TILXICXBRP@dell.com	3666929333	4	6203919206280262	2008/11	user5014	password	88	80000	F
5015	RHSNAA	YYJAVKSKYM	4828378605 Dell Way	\N	KEUGZWW	IL	65688	US	1	YYJAVKSKYM@dell.com	4828378605	2	5618442456703634	2009/01	user5015	password	84	20000	F
5016	QOIRNH	BOCLGNKSYP	5399340773 Dell Way	\N	NEOJAVZ	MI	30290	US	1	BOCLGNKSYP@dell.com	5399340773	5	3516730909235776	2010/11	user5016	password	62	20000	F
5017	YSZFTN	IFUVPNUEAY	1949866432 Dell Way	\N	TJZPJLV	TX	33257	US	1	IFUVPNUEAY@dell.com	1949866432	2	2230248155072331	2011/04	user5017	password	60	80000	F
5018	OWTCFY	WBOKVTKUNU	6336834104 Dell Way	\N	UCEFYAL	AL	32840	US	1	WBOKVTKUNU@dell.com	6336834104	4	5930137041956187	2008/05	user5018	password	58	80000	F
5019	IVMGSO	VCJONEBIYE	3405678692 Dell Way	\N	MDCMPDS	FL	90674	US	1	VCJONEBIYE@dell.com	3405678692	2	3722930827643722	2012/02	user5019	password	60	20000	M
5020	CKQQFS	ZUFEWNCBZF	5531055772 Dell Way	\N	EMVHEZF	MN	41932	US	1	ZUFEWNCBZF@dell.com	5531055772	2	5072004836052656	2008/05	user5020	password	45	20000	M
5021	ZUASUU	YYRMASMGWY	8739940231 Dell Way	\N	BEDBJPK	UT	86705	US	1	YYRMASMGWY@dell.com	8739940231	5	3271471770480275	2009/02	user5021	password	21	40000	M
5022	BYSWXQ	NJRFWXCUZG	6484880931 Dell Way	\N	YAQNKMJ	IL	51615	US	1	NJRFWXCUZG@dell.com	6484880931	3	6358725485391915	2011/10	user5022	password	55	80000	M
5023	FOPWCZ	NIVKKQJROK	8532558921 Dell Way	\N	HBUUKCG	AK	64625	US	1	NIVKKQJROK@dell.com	8532558921	4	4229277327656746	2009/05	user5023	password	22	60000	M
5024	RKAQXI	LITBSKQCRR	9508468438 Dell Way	\N	XLBZSCP	NC	78093	US	1	LITBSKQCRR@dell.com	9508468438	5	2247372441925108	2008/06	user5024	password	24	80000	M
5025	DHULTD	FVVPLXGCUS	2400216278 Dell Way	\N	ETKGJYA	IN	84643	US	1	FVVPLXGCUS@dell.com	2400216278	2	3533079224638641	2009/12	user5025	password	28	40000	F
5026	YVABAV	WQHTWJOPOI	1646942276 Dell Way	\N	AVRYVZU	WY	35388	US	1	WQHTWJOPOI@dell.com	1646942276	2	3287864929065108	2009/08	user5026	password	56	20000	F
5027	NFLJCB	QWYAKNPSOK	9213153969 Dell Way	\N	KNFJHFR	MA	49783	US	1	QWYAKNPSOK@dell.com	9213153969	3	1296298491768539	2010/10	user5027	password	50	100000	M
5028	WJBYZX	WAHKPAZALM	9336006631 Dell Way	\N	GUULLEX	MA	77905	US	1	WAHKPAZALM@dell.com	9336006631	5	5597888990771026	2009/10	user5028	password	53	40000	F
5029	NFDLBE	SMUTLUEXAZ	2025456580 Dell Way	\N	RMLWJVP	IL	66357	US	1	SMUTLUEXAZ@dell.com	2025456580	4	4658657077234239	2010/12	user5029	password	57	20000	F
5030	ROEVHQ	PBCJFZKFRW	5519537151 Dell Way	\N	QOGMDNC	ID	27433	US	1	PBCJFZKFRW@dell.com	5519537151	5	2038895625621080	2008/12	user5030	password	34	80000	M
5031	KNVBDW	DMBDXHVTYJ	8591664942 Dell Way	\N	AKNNMUS	WY	67118	US	1	DMBDXHVTYJ@dell.com	8591664942	1	6491324482019991	2008/09	user5031	password	28	60000	F
5032	YOJUSW	WWUESOCCOM	6700892651 Dell Way	\N	PCZKVZA	NV	12113	US	1	WWUESOCCOM@dell.com	6700892651	4	7847535043954850	2011/03	user5032	password	19	80000	M
5033	KNLHKI	BOAPRCDERG	9231428475 Dell Way	\N	DCBDCSD	OR	48623	US	1	BOAPRCDERG@dell.com	9231428475	3	6781538420356811	2012/03	user5033	password	47	40000	M
5034	WQEERT	EHKGLOYRSA	5283987316 Dell Way	\N	SVDKZWV	VT	44410	US	1	EHKGLOYRSA@dell.com	5283987316	5	6542826398741455	2012/03	user5034	password	45	80000	M
5035	OXMHCT	SJEGIVZJOU	4354833400 Dell Way	\N	NYUJUST	ID	57889	US	1	SJEGIVZJOU@dell.com	4354833400	1	7397059653420002	2011/11	user5035	password	55	40000	M
5036	ZPXTIG	XPPTOYIJLG	1698607254 Dell Way	\N	DVBVPHJ	WI	49469	US	1	XPPTOYIJLG@dell.com	1698607254	4	3877201733645052	2010/01	user5036	password	26	60000	M
5037	AIYHGN	WABVIKHOOD	7001695636 Dell Way	\N	PKSXTRJ	TN	44324	US	1	WABVIKHOOD@dell.com	7001695636	3	4609592479653657	2011/12	user5037	password	19	100000	F
5038	ZCOMZO	OUWYCLNFBX	4408408283 Dell Way	\N	YYQPHMZ	WV	91553	US	1	OUWYCLNFBX@dell.com	4408408283	4	9122917928732932	2010/07	user5038	password	33	40000	M
5039	TWPIKK	EINPWTQTRP	7200125501 Dell Way	\N	KGXWGWU	NJ	64449	US	1	EINPWTQTRP@dell.com	7200125501	1	2416103962343186	2012/05	user5039	password	76	80000	F
5040	KZQVEZ	JUVCLOTBYA	6024608730 Dell Way	\N	YVGUQWK	IN	91296	US	1	JUVCLOTBYA@dell.com	6024608730	2	3665142911020666	2009/11	user5040	password	57	80000	M
5041	EPBDZV	YBHNVIMWGH	2681095350 Dell Way	\N	CBYZMGX	AL	51180	US	1	YBHNVIMWGH@dell.com	2681095350	2	4106087930966169	2011/02	user5041	password	34	100000	M
5042	HATDZU	KMQTYMAGPB	3140717634 Dell Way	\N	FONLLOX	NM	93854	US	1	KMQTYMAGPB@dell.com	3140717634	2	1796070155687630	2010/04	user5042	password	80	80000	F
5043	PWGKGT	AASNAZCBEQ	2529487001 Dell Way	\N	PPCDMTC	OR	21464	US	1	AASNAZCBEQ@dell.com	2529487001	1	4470887362957001	2008/12	user5043	password	66	80000	M
5044	YABRBB	JOBIQDNHTC	7061668531 Dell Way	\N	KXPEZIH	DC	55577	US	1	JOBIQDNHTC@dell.com	7061668531	1	4930220359005034	2009/10	user5044	password	34	40000	M
5045	HYWJHL	LQBODJIGTF	1888186022 Dell Way	\N	VYEEFIR	VA	54721	US	1	LQBODJIGTF@dell.com	1888186022	2	3647571177221835	2009/06	user5045	password	26	80000	F
5046	ZZTLKJ	NZNWHUQMQO	8169130349 Dell Way	\N	RUUALRN	NC	90193	US	1	NZNWHUQMQO@dell.com	8169130349	5	4465063172392547	2012/06	user5046	password	77	100000	F
5047	OIWYVV	MSDGIQWXIQ	6429039192 Dell Way	\N	RICIVQF	NJ	53836	US	1	MSDGIQWXIQ@dell.com	6429039192	3	9742560258600862	2010/06	user5047	password	49	100000	M
5048	HXQDJI	HPQXMOFDFN	3532149516 Dell Way	\N	FNJVTZI	LA	55587	US	1	HPQXMOFDFN@dell.com	3532149516	4	9524164214264602	2011/09	user5048	password	70	20000	M
5049	IDZRKP	IIBWNEBBKP	8732910543 Dell Way	\N	LFJKNSX	SC	53502	US	1	IIBWNEBBKP@dell.com	8732910543	3	2994153675157577	2010/07	user5049	password	80	100000	M
5050	WPCLXK	NTYSUACKLH	2536777991 Dell Way	\N	TWVMTQY	NM	23288	US	1	NTYSUACKLH@dell.com	2536777991	2	7052632550243289	2008/02	user5050	password	43	100000	M
5051	LIPVVJ	UNEUQOGYIC	2926456836 Dell Way	\N	TUWKTNO	VT	75056	US	1	UNEUQOGYIC@dell.com	2926456836	5	8729579671286047	2010/10	user5051	password	60	100000	F
5052	EVYOPM	SKDGRBPUVJ	7926776613 Dell Way	\N	RFCETAX	WV	95415	US	1	SKDGRBPUVJ@dell.com	7926776613	3	7792089978232981	2009/07	user5052	password	82	60000	F
5053	VBYIUJ	LBBNQWIANO	8491999960 Dell Way	\N	CSHDQHC	MD	82123	US	1	LBBNQWIANO@dell.com	8491999960	4	3861271905712783	2011/04	user5053	password	66	60000	F
5054	QWDAIE	BVUXEULSXE	4714755235 Dell Way	\N	ABUHDFC	WI	95771	US	1	BVUXEULSXE@dell.com	4714755235	4	3100998733658343	2008/03	user5054	password	60	80000	F
5055	SSKXUG	RRKMDDKIEL	5659509557 Dell Way	\N	DLOIONH	WI	26703	US	1	RRKMDDKIEL@dell.com	5659509557	1	4559932398144156	2008/09	user5055	password	53	100000	F
5056	XSFDKX	OXBSHJWTMI	4743465236 Dell Way	\N	IVWVCVA	NJ	86896	US	1	OXBSHJWTMI@dell.com	4743465236	4	6295619946904481	2012/07	user5056	password	19	80000	F
5057	GYRDMO	EFWOBPBJXW	5514453213 Dell Way	\N	GTZBTPX	FL	39858	US	1	EFWOBPBJXW@dell.com	5514453213	1	8979149367194624	2010/11	user5057	password	29	80000	M
5058	VXHJCN	GQOVRYTOFN	3990776970 Dell Way	\N	NGHCELL	NY	58348	US	1	GQOVRYTOFN@dell.com	3990776970	1	4677785552572459	2010/12	user5058	password	33	40000	M
5059	NRYAYO	PTGONUTAHA	7219147430 Dell Way	\N	HKETWVH	FL	12556	US	1	PTGONUTAHA@dell.com	7219147430	4	9876070787198844	2012/12	user5059	password	79	60000	M
5060	ULPJBJ	PPWJJXRJEB	4408070719 Dell Way	\N	NYYJFDK	VT	80986	US	1	PPWJJXRJEB@dell.com	4408070719	5	7921337931882591	2009/03	user5060	password	49	20000	M
5061	AJTKYJ	HISEZCJBPH	6911498659 Dell Way	\N	ZZNCJKX	PA	30411	US	1	HISEZCJBPH@dell.com	6911498659	5	5167365526314825	2008/12	user5061	password	29	20000	F
5062	XNGGUO	ZZOBIPRQPQ	3162126557 Dell Way	\N	DRAOPTU	HI	76248	US	1	ZZOBIPRQPQ@dell.com	3162126557	2	7369895413983614	2009/06	user5062	password	20	40000	M
5063	HOUWNT	LOCAGSQXWI	2089168491 Dell Way	\N	XKXREDK	ME	51190	US	1	LOCAGSQXWI@dell.com	2089168491	5	9255556349642576	2008/02	user5063	password	83	60000	M
5064	RIELTT	NUZGKWCSUM	1925149046 Dell Way	\N	PMRSWCE	AK	91403	US	1	NUZGKWCSUM@dell.com	1925149046	1	1045777847990393	2008/08	user5064	password	65	80000	M
5065	VDQORK	NXVKANFNDR	2640779971 Dell Way	\N	EWOHAOE	CT	73060	US	1	NXVKANFNDR@dell.com	2640779971	1	3667800494004041	2012/10	user5065	password	33	80000	M
5066	WFQHTN	CDOPJBSAFO	2075160977 Dell Way	\N	OMPDRTV	TX	88707	US	1	CDOPJBSAFO@dell.com	2075160977	4	7344393121544272	2009/05	user5066	password	66	20000	M
5067	HLHVNK	JDUKWUQKJD	3955385280 Dell Way	\N	AMVTIRQ	MI	42153	US	1	JDUKWUQKJD@dell.com	3955385280	4	7231492146383972	2012/12	user5067	password	34	40000	F
5068	MDXXMB	RXXMOIWRIJ	2925760077 Dell Way	\N	MBRESCN	AL	87972	US	1	RXXMOIWRIJ@dell.com	2925760077	1	8254301374312491	2010/04	user5068	password	32	100000	F
5069	CWXEOV	BAJJXBSGOT	7174671828 Dell Way	\N	XSMAGMW	MN	56419	US	1	BAJJXBSGOT@dell.com	7174671828	5	8455605632625521	2012/10	user5069	password	36	100000	M
5070	EDFAFG	KODLGJAAHS	4043148039 Dell Way	\N	NHZZEKN	UT	38137	US	1	KODLGJAAHS@dell.com	4043148039	4	2294758399948478	2010/09	user5070	password	78	80000	M
5071	BUCHER	LQYVQZCIMK	2591314203 Dell Way	\N	HMPSZLA	KS	28125	US	1	LQYVQZCIMK@dell.com	2591314203	5	9467125899624080	2008/09	user5071	password	78	20000	F
5072	YJRPUH	OPXNSGZDOL	3753486561 Dell Way	\N	SGLEHTJ	MO	69418	US	1	OPXNSGZDOL@dell.com	3753486561	3	4190355004742742	2008/07	user5072	password	79	20000	M
5073	NRRUFH	RSAYSDMEVT	4123781885 Dell Way	\N	PABIJNZ	NY	10594	US	1	RSAYSDMEVT@dell.com	4123781885	5	5859798792749644	2008/11	user5073	password	49	80000	M
5074	CMTKEM	KCENOIJIXJ	4860309595 Dell Way	\N	JGTWGKX	NE	30083	US	1	KCENOIJIXJ@dell.com	4860309595	4	1904432254843413	2012/06	user5074	password	65	100000	M
5075	KJCWTE	AHSJRAGAKN	5560868668 Dell Way	\N	UHTEEIK	NH	18990	US	1	AHSJRAGAKN@dell.com	5560868668	3	6008123652078212	2008/05	user5075	password	53	60000	M
5076	OKNSLV	LUMMBNXOHE	3771512665 Dell Way	\N	IMIQWXT	MA	43490	US	1	LUMMBNXOHE@dell.com	3771512665	3	8045789718627930	2011/01	user5076	password	58	40000	F
5077	CCXXNS	JAUWXJECRQ	5357740947 Dell Way	\N	KIMICWS	MA	45757	US	1	JAUWXJECRQ@dell.com	5357740947	1	5242285483051092	2008/07	user5077	password	87	20000	M
5078	WADPJE	JGCTLEKBOT	3520222998 Dell Way	\N	OXVKPFV	CA	44626	US	1	JGCTLEKBOT@dell.com	3520222998	1	9242152810562404	2009/03	user5078	password	56	20000	F
5079	RSQWCX	YVICFJRYXP	3534536305 Dell Way	\N	UIFZDHJ	MD	47182	US	1	YVICFJRYXP@dell.com	3534536305	4	6860164121259005	2012/09	user5079	password	83	60000	F
5080	NINKHI	SJOCBNZRHH	2872298736 Dell Way	\N	WHKDQVO	VT	50758	US	1	SJOCBNZRHH@dell.com	2872298736	4	2777313454542309	2008/03	user5080	password	65	80000	M
5081	EBVNTF	BVGPVYWDUD	1059873648 Dell Way	\N	NYUJMSV	OH	47682	US	1	BVGPVYWDUD@dell.com	1059873648	4	6645937411580235	2011/06	user5081	password	30	100000	F
5082	ZIFEKB	LZXJWADZOB	5596375650 Dell Way	\N	UXOMSGW	OK	13157	US	1	LZXJWADZOB@dell.com	5596375650	2	5108235834632069	2011/03	user5082	password	84	80000	M
5083	DVYFHY	CQUCUURWOO	2430911256 Dell Way	\N	LAHRXZS	MD	43737	US	1	CQUCUURWOO@dell.com	2430911256	1	6175640705972911	2008/09	user5083	password	26	40000	M
5084	BKWZNN	TPINGFCVQC	1500487491 Dell Way	\N	CHACZKM	DE	54798	US	1	TPINGFCVQC@dell.com	1500487491	2	3225347045809030	2008/06	user5084	password	79	40000	M
5085	SFJGYZ	OMGUPBKRES	8568795087 Dell Way	\N	RHSCTWP	TN	17849	US	1	OMGUPBKRES@dell.com	8568795087	5	5803074690513313	2011/03	user5085	password	46	40000	F
5086	TQJTFW	ZZLBJDGBVO	3210962769 Dell Way	\N	UXIQMDS	KY	21079	US	1	ZZLBJDGBVO@dell.com	3210962769	1	3994420151691884	2011/05	user5086	password	71	60000	F
5087	CDGYDF	KFPNMRIALG	9146425441 Dell Way	\N	IBTLUCO	AL	18757	US	1	KFPNMRIALG@dell.com	9146425441	4	5569337491877378	2011/01	user5087	password	58	80000	F
5088	USJACP	PQBHYBSEJU	6473065323 Dell Way	\N	YVOAKPC	IN	32610	US	1	PQBHYBSEJU@dell.com	6473065323	5	3892224073875696	2008/09	user5088	password	57	100000	F
5089	XZMMOD	OWBPOGZJEV	1753452012 Dell Way	\N	YEFNHNT	VA	52281	US	1	OWBPOGZJEV@dell.com	1753452012	1	2477235856000334	2011/01	user5089	password	58	60000	M
5090	BAOEPK	GEZMEIRZGW	4246657824 Dell Way	\N	FTDSNAF	NJ	17931	US	1	GEZMEIRZGW@dell.com	4246657824	2	1816716141067445	2012/10	user5090	password	22	100000	M
5091	PDKAKP	ZXTHOTOLYI	8135830037 Dell Way	\N	ORWPWMS	IA	74662	US	1	ZXTHOTOLYI@dell.com	8135830037	1	5481671531219036	2012/02	user5091	password	40	60000	F
5092	SLRHLP	BTDUHPTQEL	2648117812 Dell Way	\N	MUIZMOR	ID	73934	US	1	BTDUHPTQEL@dell.com	2648117812	1	8664489893242718	2010/07	user5092	password	28	20000	F
5093	VMLKNE	OIMDBCIMPC	9221431731 Dell Way	\N	UOOJGVB	MI	94684	US	1	OIMDBCIMPC@dell.com	9221431731	5	5628228265792132	2008/02	user5093	password	57	100000	M
5094	ZIDEWL	RANUIAJLUY	3298775271 Dell Way	\N	ZEFUFQT	CT	60711	US	1	RANUIAJLUY@dell.com	3298775271	1	7199845944065601	2011/02	user5094	password	39	80000	F
5095	LZHWQI	JLRKUCFTBJ	8536284920 Dell Way	\N	YWOPPSD	TX	91220	US	1	JLRKUCFTBJ@dell.com	8536284920	4	9932560573332012	2008/06	user5095	password	46	60000	F
5096	RLCAVN	RFITKBVTAR	9378594025 Dell Way	\N	IPHATDY	NE	82887	US	1	RFITKBVTAR@dell.com	9378594025	4	3368758982513100	2009/04	user5096	password	68	20000	M
5097	UANHRS	PLDQGWRYFG	5058538927 Dell Way	\N	FGAJEPE	CO	37257	US	1	PLDQGWRYFG@dell.com	5058538927	3	6198315681889654	2008/06	user5097	password	38	100000	F
5098	UFDNUP	RLVNCUTJAZ	8497227464 Dell Way	\N	JJEYOHG	AK	74672	US	1	RLVNCUTJAZ@dell.com	8497227464	1	2518581018317491	2008/02	user5098	password	64	100000	F
5099	ULBJDN	FRQZKZZKIJ	7504391235 Dell Way	\N	OHYVOYO	MA	20318	US	1	FRQZKZZKIJ@dell.com	7504391235	3	2810001967474818	2009/06	user5099	password	53	20000	M
5100	ONACSR	SRBRRLAAAI	3003673568 Dell Way	\N	YVWXKGA	CT	77645	US	1	SRBRRLAAAI@dell.com	3003673568	3	2604887736029923	2011/08	user5100	password	22	40000	F
5101	BJVSBN	USEGTFGBEC	1898949484 Dell Way	\N	XBMECPX	IN	16461	US	1	USEGTFGBEC@dell.com	1898949484	1	7159357781056315	2008/04	user5101	password	76	40000	M
5102	QYSDTK	HZENFFRIDS	2315604348 Dell Way	\N	UHVKFDM	KS	23260	US	1	HZENFFRIDS@dell.com	2315604348	3	4976109254639596	2012/09	user5102	password	24	60000	M
5103	USLFAK	JNQPEYSXTA	4889544055 Dell Way	\N	SDGVPPZ	OR	17130	US	1	JNQPEYSXTA@dell.com	4889544055	4	8217400284484030	2010/04	user5103	password	53	40000	M
5104	XNYIWM	YMQXENRFGU	9519940766 Dell Way	\N	MCKBCDD	MT	83668	US	1	YMQXENRFGU@dell.com	9519940766	1	1689109456259757	2010/05	user5104	password	20	40000	M
5105	ZRTLQF	CNKQEQWZCZ	4477684411 Dell Way	\N	JEBMIOI	IA	64722	US	1	CNKQEQWZCZ@dell.com	4477684411	4	9578058636281640	2010/01	user5105	password	77	60000	M
5106	OWHTYV	EPAUMZWLJB	6593739876 Dell Way	\N	MVJBDPR	NC	36097	US	1	EPAUMZWLJB@dell.com	6593739876	5	3806293263565749	2010/05	user5106	password	90	100000	F
5107	HTFCXU	DSGCORLQEH	2607909558 Dell Way	\N	ZGLOXZW	MT	94096	US	1	DSGCORLQEH@dell.com	2607909558	5	3707229645457119	2008/12	user5107	password	57	60000	M
5108	TOPNSH	TVWLHNQOMW	3037411474 Dell Way	\N	ABTZXHY	CA	32461	US	1	TVWLHNQOMW@dell.com	3037411474	2	2765779151115566	2011/09	user5108	password	83	60000	F
5109	NAAVUV	SGCFWQRSRS	3008027309 Dell Way	\N	MQQUOSA	SC	99551	US	1	SGCFWQRSRS@dell.com	3008027309	3	7480036769062281	2008/01	user5109	password	19	80000	F
5110	ALWVDC	XIYOZRFSDW	8117850733 Dell Way	\N	JYLBYGB	FL	82635	US	1	XIYOZRFSDW@dell.com	8117850733	2	8800807990599425	2012/12	user5110	password	86	100000	F
5111	URMWOU	VDUMJNQFWO	6166967422 Dell Way	\N	RYNXASS	SC	10500	US	1	VDUMJNQFWO@dell.com	6166967422	4	9316286645364016	2010/06	user5111	password	38	40000	F
5112	TEROAU	JMDWDJSSAQ	8911016786 Dell Way	\N	GXQYQLY	GA	14344	US	1	JMDWDJSSAQ@dell.com	8911016786	4	5334979571402073	2008/01	user5112	password	60	100000	F
5113	GMFBVS	FRWOKOPBVN	7223370668 Dell Way	\N	STDESIF	NH	14753	US	1	FRWOKOPBVN@dell.com	7223370668	4	1693641358520835	2009/08	user5113	password	38	60000	F
5114	NOYFTQ	CHBQXDLKVF	9877725450 Dell Way	\N	NAYWFNX	VT	34065	US	1	CHBQXDLKVF@dell.com	9877725450	1	9327974396292120	2009/09	user5114	password	21	80000	F
5115	AZZRCH	SSEVEORKCR	1308672163 Dell Way	\N	IYXVWUC	TX	96896	US	1	SSEVEORKCR@dell.com	1308672163	1	6836059066932649	2008/11	user5115	password	82	20000	M
5116	WTZEMS	JHWYZHARPZ	9705375357 Dell Way	\N	OLVJORI	NE	82569	US	1	JHWYZHARPZ@dell.com	9705375357	4	7343765782192350	2012/10	user5116	password	62	80000	M
5117	PXZHGH	EFHLFYAFNM	3122151903 Dell Way	\N	BWASEPN	DC	33822	US	1	EFHLFYAFNM@dell.com	3122151903	5	1265260798856616	2012/09	user5117	password	57	60000	M
5118	NSXVWC	CHIBINOUOK	7286021589 Dell Way	\N	VHOKVSR	AR	73762	US	1	CHIBINOUOK@dell.com	7286021589	5	4930390637367964	2009/04	user5118	password	23	80000	M
5119	ZPWBSD	JTMXHHLRCS	1929276308 Dell Way	\N	GMNYDOR	TX	51189	US	1	JTMXHHLRCS@dell.com	1929276308	1	7834458910394461	2008/11	user5119	password	73	20000	F
5120	QFEUPX	GMENXVPQCB	9603102434 Dell Way	\N	EBFTSBF	SD	25314	US	1	GMENXVPQCB@dell.com	9603102434	5	1350435050204396	2011/02	user5120	password	54	40000	F
5121	RCXOJK	SWHOLYRNCS	1424679857 Dell Way	\N	TVKVAGA	WY	30647	US	1	SWHOLYRNCS@dell.com	1424679857	4	4270230212714523	2010/01	user5121	password	69	40000	F
5122	QTMAMJ	HBVGSJIKCE	7056753743 Dell Way	\N	VYFCYFI	AK	92044	US	1	HBVGSJIKCE@dell.com	7056753743	3	9559595323633404	2009/10	user5122	password	24	100000	M
5123	PZAYHC	TOUCWFFBBE	4097888095 Dell Way	\N	HDDMLDK	CT	73691	US	1	TOUCWFFBBE@dell.com	4097888095	3	5309604541398585	2010/06	user5123	password	19	20000	F
5124	BZUDSI	YVFEBHGGOJ	7542317360 Dell Way	\N	KBVOLZG	RI	53094	US	1	YVFEBHGGOJ@dell.com	7542317360	2	9786027157213540	2011/03	user5124	password	52	80000	F
5125	GXYPWU	VAWCGCRQMS	9191526186 Dell Way	\N	MADLHYY	AK	22713	US	1	VAWCGCRQMS@dell.com	9191526186	4	4434720485936850	2009/07	user5125	password	61	80000	F
5126	NGIHCJ	DEPGWGTOSU	2464892409 Dell Way	\N	SEBQDBU	AL	82474	US	1	DEPGWGTOSU@dell.com	2464892409	3	4096521870233119	2011/01	user5126	password	76	40000	F
5127	DPJMTO	CZLISZBNSG	7805509845 Dell Way	\N	OJJPDJK	IN	80817	US	1	CZLISZBNSG@dell.com	7805509845	1	8567284082062543	2010/04	user5127	password	28	80000	M
5128	NEQCGQ	NOJNQWGWKP	2978276330 Dell Way	\N	FATPLAJ	FL	17355	US	1	NOJNQWGWKP@dell.com	2978276330	4	4691649857442826	2009/06	user5128	password	41	100000	M
5129	ZZWPNK	ZBBVHXGXDG	2421323474 Dell Way	\N	QSRRCWT	IN	66281	US	1	ZBBVHXGXDG@dell.com	2421323474	4	1583470327313989	2010/07	user5129	password	66	60000	M
5130	NBCYAD	ZVLWBJZIZS	6229662662 Dell Way	\N	ARUXKCN	ND	79588	US	1	ZVLWBJZIZS@dell.com	6229662662	1	4076611518394202	2009/06	user5130	password	84	80000	M
5131	ASOERJ	POLZOUYHUQ	3578817602 Dell Way	\N	BRAEFPY	RI	66354	US	1	POLZOUYHUQ@dell.com	3578817602	1	2034985451027751	2008/10	user5131	password	65	20000	M
5132	FJFPZT	AYIVXPPNRH	8672674176 Dell Way	\N	NWMCUHT	CA	37310	US	1	AYIVXPPNRH@dell.com	8672674176	2	1936420870479196	2010/06	user5132	password	62	80000	M
5133	UHUOIS	XDPNSDEAQB	2591058475 Dell Way	\N	MTVUMYB	KY	28236	US	1	XDPNSDEAQB@dell.com	2591058475	5	7098684934899212	2011/07	user5133	password	54	60000	M
5134	HEDABG	QOZTTZKUMD	5012886707 Dell Way	\N	QGQOIZT	MS	85047	US	1	QOZTTZKUMD@dell.com	5012886707	2	4469520111102611	2012/11	user5134	password	33	40000	F
5135	JGCQXR	PQLPAFCEWI	1088291799 Dell Way	\N	ULRUFEQ	NM	53403	US	1	PQLPAFCEWI@dell.com	1088291799	3	4320543265435845	2009/11	user5135	password	48	60000	F
5136	NFZEVQ	PKQVMVSVQD	5945347279 Dell Way	\N	NKISBZE	AR	61006	US	1	PKQVMVSVQD@dell.com	5945347279	2	4678103134501726	2012/11	user5136	password	55	60000	F
5137	NRWDGH	UCUPUPFXDQ	2599054941 Dell Way	\N	GVRFATT	ND	11356	US	1	UCUPUPFXDQ@dell.com	2599054941	3	8912720362190158	2011/12	user5137	password	87	20000	M
5138	VIXDDZ	XSUNYRQPXL	9259469491 Dell Way	\N	HCLAWAB	AZ	57062	US	1	XSUNYRQPXL@dell.com	9259469491	4	5613800319842995	2012/12	user5138	password	29	80000	F
5139	BVKBSC	VFBNWRKHYN	8218127037 Dell Way	\N	TZKTAMH	WA	29119	US	1	VFBNWRKHYN@dell.com	8218127037	4	2426529046613723	2012/06	user5139	password	49	20000	F
5140	VBAYXG	AKCRUKQIEP	6114372061 Dell Way	\N	TXQFFOK	AK	41216	US	1	AKCRUKQIEP@dell.com	6114372061	5	8610609418712557	2008/12	user5140	password	29	100000	F
5141	EUYLUJ	NMEYCMCSFA	1481922811 Dell Way	\N	IKFWVGF	MD	28765	US	1	NMEYCMCSFA@dell.com	1481922811	3	2817476470954716	2009/03	user5141	password	37	60000	F
5142	FVUPJH	THJGKBLKJW	3416647812 Dell Way	\N	QGSWLCB	MS	56547	US	1	THJGKBLKJW@dell.com	3416647812	4	7792769369203598	2010/02	user5142	password	74	80000	M
5143	OIIVCQ	FIAGULQRBW	7769364509 Dell Way	\N	JXIMZVZ	IA	57257	US	1	FIAGULQRBW@dell.com	7769364509	4	6777916729915888	2010/07	user5143	password	61	20000	M
5144	YYZODH	PKBBBSCYCA	3032256260 Dell Way	\N	GOZBOGP	KS	12310	US	1	PKBBBSCYCA@dell.com	3032256260	5	6145794873591513	2012/12	user5144	password	51	80000	M
5145	LIASYL	UZMNCKPCRD	9273641173 Dell Way	\N	CSSIHAJ	MT	88128	US	1	UZMNCKPCRD@dell.com	9273641173	2	8210178943816573	2009/02	user5145	password	67	100000	F
5146	RNKDIJ	PVLAKOROQK	9746393717 Dell Way	\N	HYRHHFE	GA	60307	US	1	PVLAKOROQK@dell.com	9746393717	3	7048685034271330	2011/05	user5146	password	26	40000	M
5147	NLGXBB	ICMXTANDHM	3306200271 Dell Way	\N	VPTAUZP	OR	60706	US	1	ICMXTANDHM@dell.com	3306200271	2	9705856876913460	2009/09	user5147	password	83	100000	F
5148	DUGFDI	RABSNFAZAP	3261584297 Dell Way	\N	TBJSQDH	VA	55950	US	1	RABSNFAZAP@dell.com	3261584297	2	3108482042327523	2008/02	user5148	password	48	40000	M
5149	RNBZFC	BYQGYPHOJI	8153647445 Dell Way	\N	YCYBJVO	NJ	18455	US	1	BYQGYPHOJI@dell.com	8153647445	4	3250486246775836	2009/01	user5149	password	31	100000	M
5150	GWVIXT	YDROKFYTDA	8715570351 Dell Way	\N	RFJNTZP	ND	78684	US	1	YDROKFYTDA@dell.com	8715570351	4	8554597128648312	2008/08	user5150	password	50	40000	F
5151	GQJZPN	REYWCRACJF	1739752303 Dell Way	\N	MXZMMNG	KY	36775	US	1	REYWCRACJF@dell.com	1739752303	2	9367772204801440	2010/09	user5151	password	48	80000	F
5152	UTYILD	HIFZIIIOVF	3811488702 Dell Way	\N	OHSCNBJ	NJ	52017	US	1	HIFZIIIOVF@dell.com	3811488702	1	2501919948961586	2011/11	user5152	password	55	60000	M
5153	LVCODK	UCTDLIYQWF	1648095509 Dell Way	\N	JYTLIJX	NV	56758	US	1	UCTDLIYQWF@dell.com	1648095509	2	4910173872485757	2010/11	user5153	password	26	20000	M
5154	FPWQKY	KNJSLAPRJO	7912353076 Dell Way	\N	LVXVSOI	SC	94918	US	1	KNJSLAPRJO@dell.com	7912353076	2	8570272871758790	2012/06	user5154	password	60	20000	F
5155	LTLJDY	TWKTMCDANY	3561516113 Dell Way	\N	YIRMRML	MI	87277	US	1	TWKTMCDANY@dell.com	3561516113	2	3508797178044915	2012/05	user5155	password	40	40000	F
5156	TRHSKE	CEQEHRSGPA	6013764970 Dell Way	\N	YCSKODH	TN	50129	US	1	CEQEHRSGPA@dell.com	6013764970	4	8760565639473499	2012/12	user5156	password	19	80000	M
5157	IICMLG	DQOUIVKJTM	5589208926 Dell Way	\N	BEBFLWQ	AK	60721	US	1	DQOUIVKJTM@dell.com	5589208926	5	6023164378013462	2010/07	user5157	password	34	100000	M
5158	IIGOMW	DGFYQPSDQX	2513341553 Dell Way	\N	EWJBMJP	AK	33583	US	1	DGFYQPSDQX@dell.com	2513341553	3	7895068523474038	2009/05	user5158	password	61	80000	M
5159	WHFTKL	YJCNCGEZKA	7681703917 Dell Way	\N	IMNSBNZ	IA	17024	US	1	YJCNCGEZKA@dell.com	7681703917	4	5247099088504911	2009/05	user5159	password	33	20000	M
5160	KXBWWK	ZKNFOMQPVC	2826381882 Dell Way	\N	DNEQNKT	IA	13315	US	1	ZKNFOMQPVC@dell.com	2826381882	3	4484389175660908	2010/10	user5160	password	19	100000	M
5161	BROMQY	ZWMMMCHOFV	5831386617 Dell Way	\N	SWICPPD	RI	25735	US	1	ZWMMMCHOFV@dell.com	5831386617	1	9517877371981740	2010/01	user5161	password	64	80000	M
5162	ECICCF	PORRWFWRYS	7513700994 Dell Way	\N	ABIPFCU	OR	35948	US	1	PORRWFWRYS@dell.com	7513700994	2	3711438622325659	2009/12	user5162	password	90	60000	F
5163	IQDNGS	FYOLVGJOGL	5917536262 Dell Way	\N	WWQYQJG	LA	69799	US	1	FYOLVGJOGL@dell.com	5917536262	4	6297679150011391	2010/04	user5163	password	63	100000	M
5164	TKEMQC	ABYHLMOWIK	1968951434 Dell Way	\N	MHBWOKN	CA	22579	US	1	ABYHLMOWIK@dell.com	1968951434	4	4599606577772647	2011/07	user5164	password	40	60000	M
5165	MZOPAQ	NHBZVXIGKP	3348356805 Dell Way	\N	HGDSUGW	VA	87395	US	1	NHBZVXIGKP@dell.com	3348356805	4	4368312963750214	2010/02	user5165	password	40	20000	F
5166	WQCNDK	OCGMKMXAUE	6646713496 Dell Way	\N	ENYKJVG	NM	50328	US	1	OCGMKMXAUE@dell.com	6646713496	2	6132246034219862	2012/04	user5166	password	66	100000	M
5167	TIZEXC	KJNXGNSKRF	2803280950 Dell Way	\N	JCPEIGQ	WV	49862	US	1	KJNXGNSKRF@dell.com	2803280950	5	7281723643187434	2012/09	user5167	password	59	80000	F
5168	OUXRFH	ECOSUZKAIM	9900573994 Dell Way	\N	QNVWDUH	KY	70266	US	1	ECOSUZKAIM@dell.com	9900573994	2	4468700327444822	2010/11	user5168	password	48	20000	M
5169	IVWQZZ	FSUECUNOKA	2769740346 Dell Way	\N	JGEDONV	NC	76231	US	1	FSUECUNOKA@dell.com	2769740346	1	6239455906674266	2011/03	user5169	password	34	100000	F
5170	CPBBUT	VZVQMKBNTH	5674324785 Dell Way	\N	RXWFSKY	VT	54779	US	1	VZVQMKBNTH@dell.com	5674324785	3	7664967612363399	2011/06	user5170	password	75	100000	F
5171	VXXPSW	KJIUKVORNM	2526295734 Dell Way	\N	OSFYQCL	DE	68212	US	1	KJIUKVORNM@dell.com	2526295734	5	2276255558244884	2012/10	user5171	password	35	100000	M
5172	DJJZUS	HPCDEUQQIJ	7676436034 Dell Way	\N	VGAYREP	TX	18052	US	1	HPCDEUQQIJ@dell.com	7676436034	5	8582866446580739	2012/08	user5172	password	53	20000	M
5173	WBUOJJ	RNOLDETNAA	6505847638 Dell Way	\N	NZRRPOT	KS	41870	US	1	RNOLDETNAA@dell.com	6505847638	2	9733056726865472	2008/05	user5173	password	88	100000	F
5174	TNVDEI	RPMWJZXJNX	9213965358 Dell Way	\N	BEMPYUY	ND	19312	US	1	RPMWJZXJNX@dell.com	9213965358	4	5523061343934387	2012/08	user5174	password	88	80000	F
5175	VUHELW	QIFQGODDQI	1166013495 Dell Way	\N	PFHKEVN	AZ	55480	US	1	QIFQGODDQI@dell.com	1166013495	5	2018190811853856	2012/08	user5175	password	34	100000	F
5176	MYVJPE	PGKEKNUSDZ	5150953068 Dell Way	\N	ZODVBFJ	CA	24305	US	1	PGKEKNUSDZ@dell.com	5150953068	1	7681237003766001	2011/11	user5176	password	25	20000	M
5177	XOLBDR	MHCABUEBUS	3758509353 Dell Way	\N	FQUKZXO	MI	97490	US	1	MHCABUEBUS@dell.com	3758509353	1	8707691831514240	2010/04	user5177	password	68	40000	M
5178	DKZVWH	XXISBJMTOD	3471250773 Dell Way	\N	OZCLOOK	TX	72349	US	1	XXISBJMTOD@dell.com	3471250773	2	1088833563961088	2012/07	user5178	password	81	20000	M
5179	WYWDVT	LNUVAOKDCJ	5740708515 Dell Way	\N	GOYVZUN	IA	12087	US	1	LNUVAOKDCJ@dell.com	5740708515	2	6419657248537988	2010/04	user5179	password	60	40000	F
5180	LKCEWQ	ZSQNCUQMBE	8231906316 Dell Way	\N	KXDEKKF	WA	65209	US	1	ZSQNCUQMBE@dell.com	8231906316	2	9455056009348484	2009/08	user5180	password	32	100000	M
5181	HZWXZO	OMQJCDLHNI	4388624469 Dell Way	\N	LSSVXRL	OK	99148	US	1	OMQJCDLHNI@dell.com	4388624469	1	6275041389744729	2010/12	user5181	password	60	100000	M
5182	LUXZJJ	PSMSDTGMEZ	4892151615 Dell Way	\N	FZXWLPW	SD	73529	US	1	PSMSDTGMEZ@dell.com	4892151615	2	6662963814567775	2008/04	user5182	password	58	60000	F
5183	LKKUAC	HSGAZTEZYE	8146019812 Dell Way	\N	WUQLQLE	AZ	83665	US	1	HSGAZTEZYE@dell.com	8146019812	1	1648341844789683	2009/07	user5183	password	26	80000	M
5184	NPXQWQ	WWQQBPOGLI	2829242944 Dell Way	\N	WXZIBBD	UT	21483	US	1	WWQQBPOGLI@dell.com	2829242944	2	6753881077747793	2009/01	user5184	password	57	100000	M
5185	LLLCII	SYKIMRUVOR	6663901980 Dell Way	\N	VWTWZQZ	FL	86922	US	1	SYKIMRUVOR@dell.com	6663901980	3	8709353082813323	2008/04	user5185	password	50	80000	M
5186	XSBGLA	QUNHOIVGDR	4260873041 Dell Way	\N	AARQAWN	NM	41898	US	1	QUNHOIVGDR@dell.com	4260873041	5	7073941531591118	2012/06	user5186	password	49	80000	F
5187	NYQNOK	AWYJSFNKFN	9409017890 Dell Way	\N	BWNXJDG	OR	96284	US	1	AWYJSFNKFN@dell.com	9409017890	3	4596744061447680	2009/04	user5187	password	59	100000	F
5188	EKUPKQ	OUJTHTZUUV	8442104838 Dell Way	\N	IRFMYYL	VA	55250	US	1	OUJTHTZUUV@dell.com	8442104838	2	7849883548449726	2009/02	user5188	password	88	60000	M
5189	TEYKTS	TMZMMUGHCY	7697821391 Dell Way	\N	NOXMZUZ	SD	12612	US	1	TMZMMUGHCY@dell.com	7697821391	2	2372520760633051	2011/10	user5189	password	66	60000	M
5190	PVSHOF	HBRBHZEGMS	1861200963 Dell Way	\N	DZSXZOY	OK	78131	US	1	HBRBHZEGMS@dell.com	1861200963	3	6037252152804286	2011/11	user5190	password	57	40000	M
5191	GRGMYH	DAPCEVPXZP	5373267107 Dell Way	\N	QXOEVGY	WA	69560	US	1	DAPCEVPXZP@dell.com	5373267107	4	5696783315390349	2008/01	user5191	password	33	40000	M
5192	MTRUWS	KZWGPUFEKC	2248472851 Dell Way	\N	SOYYNWQ	WY	60975	US	1	KZWGPUFEKC@dell.com	2248472851	1	6632497662678362	2009/04	user5192	password	43	100000	F
5193	AQYSAX	PGMJMRUOJJ	6163634614 Dell Way	\N	NIWJYWY	AZ	87690	US	1	PGMJMRUOJJ@dell.com	6163634614	3	2502014224417507	2012/04	user5193	password	34	100000	M
5194	DRXBHE	OQQFLFPUSX	5696937617 Dell Way	\N	QCVMBXJ	NJ	41716	US	1	OQQFLFPUSX@dell.com	5696937617	3	6605205448344350	2011/07	user5194	password	56	100000	F
5195	LYLPNC	GTNLIIEFZH	9704647301 Dell Way	\N	BLIZVYI	KY	54673	US	1	GTNLIIEFZH@dell.com	9704647301	1	9996605857275428	2010/12	user5195	password	31	100000	M
5196	QNLTUE	HGNPKSOSUA	5210023764 Dell Way	\N	AUVZDEM	CO	32429	US	1	HGNPKSOSUA@dell.com	5210023764	3	2969523364678025	2011/07	user5196	password	28	40000	F
5197	PAVTHC	GXNZMFUMFP	9761194725 Dell Way	\N	IFSNRVT	CT	47769	US	1	GXNZMFUMFP@dell.com	9761194725	4	9447769604157656	2008/01	user5197	password	90	80000	F
5198	VMKYTI	LTUQNHWDQB	1307053366 Dell Way	\N	WDTRWWC	TX	69207	US	1	LTUQNHWDQB@dell.com	1307053366	5	7574093344155700	2008/09	user5198	password	78	100000	F
5199	GUXOFQ	JWEQTHGUDJ	8188989329 Dell Way	\N	NVGKXCB	WI	16199	US	1	JWEQTHGUDJ@dell.com	8188989329	5	7706813191063703	2011/11	user5199	password	83	100000	M
5200	ULWKUT	PKMWRHAAUV	2757477295 Dell Way	\N	HFTJHRL	CA	69313	US	1	PKMWRHAAUV@dell.com	2757477295	4	5511164070572705	2008/08	user5200	password	28	100000	F
5201	AHUTXF	FTWMUXHQFM	2842802018 Dell Way	\N	JOUBAWS	HI	62731	US	1	FTWMUXHQFM@dell.com	2842802018	2	2592648376245051	2009/03	user5201	password	32	40000	F
5202	ACJFHD	CTYABOFNXU	9589772509 Dell Way	\N	IYVERAU	UT	41142	US	1	CTYABOFNXU@dell.com	9589772509	2	5844064594246448	2008/07	user5202	password	20	20000	M
5203	KKYOMR	NNSBSGZNPY	3177770961 Dell Way	\N	IUPJOLS	MS	69838	US	1	NNSBSGZNPY@dell.com	3177770961	4	2986251635942608	2009/10	user5203	password	80	80000	F
5204	UGSMTF	FVYLULBSUV	6785046292 Dell Way	\N	HDJTVWK	CA	59273	US	1	FVYLULBSUV@dell.com	6785046292	2	4376565165352076	2010/01	user5204	password	61	40000	F
5205	HTBNYW	MKQXLJSHRV	5095275932 Dell Way	\N	QKRNVTC	MO	19906	US	1	MKQXLJSHRV@dell.com	5095275932	5	2379823569208383	2008/04	user5205	password	50	40000	F
5206	NWZJIK	AGWJYDBUUM	5298144405 Dell Way	\N	LIIFKUI	TX	80496	US	1	AGWJYDBUUM@dell.com	5298144405	5	1530583690851926	2012/03	user5206	password	24	60000	F
5207	CULMVS	IFQLGLGSXO	6978691314 Dell Way	\N	ACYVLUP	VT	70919	US	1	IFQLGLGSXO@dell.com	6978691314	5	9243409295566380	2011/04	user5207	password	19	100000	F
5208	MIXEQC	VCJGIBDXCG	2912585750 Dell Way	\N	VXRQNPH	FL	48386	US	1	VCJGIBDXCG@dell.com	2912585750	5	7259685654193164	2009/10	user5208	password	73	80000	F
5209	RWTTRV	CXEEBCGIXE	7285605432 Dell Way	\N	ZOROVWA	AR	83273	US	1	CXEEBCGIXE@dell.com	7285605432	2	6315640583634377	2010/12	user5209	password	67	20000	M
5210	KWNGZL	LDNOKVLPUZ	5959133456 Dell Way	\N	HJVDKWY	CA	25246	US	1	LDNOKVLPUZ@dell.com	5959133456	3	2413325990084559	2009/09	user5210	password	18	80000	M
5211	OXNZJR	NXCIJRDJYN	4750623440 Dell Way	\N	FCXCBZG	NH	58054	US	1	NXCIJRDJYN@dell.com	4750623440	5	2860689175780862	2010/06	user5211	password	73	100000	F
5212	HYUZLR	BUBTXLRKQU	1392140399 Dell Way	\N	ISVHZLV	MD	33786	US	1	BUBTXLRKQU@dell.com	1392140399	5	7766722450032831	2012/10	user5212	password	29	20000	M
5213	YBFQDZ	RWXCOHTIQL	6469169259 Dell Way	\N	EYLPTVW	SD	70320	US	1	RWXCOHTIQL@dell.com	6469169259	4	5160911745857448	2011/09	user5213	password	33	80000	M
5214	KIXKZU	HCJPVRFHVD	7339148053 Dell Way	\N	SLXOHSG	VA	39397	US	1	HCJPVRFHVD@dell.com	7339148053	4	1282797756139189	2012/05	user5214	password	76	40000	M
5215	SSRNAT	WPONUWJYPV	9338832820 Dell Way	\N	WECOKAX	CO	70195	US	1	WPONUWJYPV@dell.com	9338832820	1	1246343903709203	2011/05	user5215	password	68	60000	F
5216	JYBCUR	RILNSKDNGH	3944174875 Dell Way	\N	QVRQSUH	NV	82484	US	1	RILNSKDNGH@dell.com	3944174875	2	2352183086797595	2008/10	user5216	password	33	40000	M
5217	HMPYEX	KSQUVDBCTW	5758530034 Dell Way	\N	UKPOSGJ	AK	66736	US	1	KSQUVDBCTW@dell.com	5758530034	1	5118862637784332	2011/06	user5217	password	35	20000	M
5218	VZCSJU	IEPMFSGCMQ	1388642895 Dell Way	\N	SBIYLIP	WV	44428	US	1	IEPMFSGCMQ@dell.com	1388642895	4	8286007704213262	2009/09	user5218	password	70	20000	M
5219	UVBPDF	EQLXWNJMGL	3926745700 Dell Way	\N	UFWDUWN	TN	61448	US	1	EQLXWNJMGL@dell.com	3926745700	1	3811398483812809	2008/03	user5219	password	19	100000	F
5220	BLDHPU	TMQHWCNIXS	9398154080 Dell Way	\N	FAMBOIQ	UT	47488	US	1	TMQHWCNIXS@dell.com	9398154080	5	6492804717738182	2012/10	user5220	password	62	20000	F
5221	TIUNBH	EIEGVMDORE	4347537582 Dell Way	\N	ASSIIPT	ID	55095	US	1	EIEGVMDORE@dell.com	4347537582	2	3392910275608301	2012/03	user5221	password	51	80000	M
5222	GHPOLY	SSUEWIVAJO	1834181340 Dell Way	\N	TSWILDV	TN	41974	US	1	SSUEWIVAJO@dell.com	1834181340	5	6332879421766848	2010/07	user5222	password	29	100000	M
5223	TJHSBA	MGWUCWDQPV	6345791228 Dell Way	\N	NYHQTDA	TX	93733	US	1	MGWUCWDQPV@dell.com	6345791228	3	5476541873533279	2011/03	user5223	password	43	60000	M
5224	QFQQRW	NMYJQPZLCX	3579079859 Dell Way	\N	TSRWTOU	KS	95540	US	1	NMYJQPZLCX@dell.com	3579079859	1	2499905316624790	2011/07	user5224	password	72	40000	M
5225	JYMGLY	FVOUUAWSUP	1653792638 Dell Way	\N	KQIYKRX	OH	76454	US	1	FVOUUAWSUP@dell.com	1653792638	2	3866629345808178	2012/08	user5225	password	25	20000	M
5226	PLAORW	DLRDIKXYUO	1047943518 Dell Way	\N	HTZYRRR	OR	11012	US	1	DLRDIKXYUO@dell.com	1047943518	3	6837432760279626	2008/09	user5226	password	34	80000	F
5227	GGVDJH	UNQEKOYZWS	3276520287 Dell Way	\N	YUJPMCP	MO	68838	US	1	UNQEKOYZWS@dell.com	3276520287	4	4505251409951598	2010/04	user5227	password	59	80000	M
5228	KWXSQK	IVVXUUTMSO	1122804265 Dell Way	\N	WIAZXNQ	DE	20449	US	1	IVVXUUTMSO@dell.com	1122804265	4	4779806092381478	2010/05	user5228	password	88	100000	F
5229	WSYHBT	DYNXRZQGWY	3790221576 Dell Way	\N	GVWULBX	MN	74026	US	1	DYNXRZQGWY@dell.com	3790221576	1	2090778344776481	2009/01	user5229	password	47	20000	M
5230	ILUBOT	OMLODRKCYG	8595623451 Dell Way	\N	YSRAPDS	VA	26756	US	1	OMLODRKCYG@dell.com	8595623451	1	3091469444334507	2009/04	user5230	password	90	60000	M
5231	UQINEV	YTYQEAOKZG	6596320119 Dell Way	\N	BZVFSTK	ND	92472	US	1	YTYQEAOKZG@dell.com	6596320119	4	3221959751099348	2011/05	user5231	password	19	40000	M
5232	JXEEWY	CMCDBMCHOC	1264341270 Dell Way	\N	DTUWDJU	PA	23958	US	1	CMCDBMCHOC@dell.com	1264341270	2	5710658210795373	2008/10	user5232	password	55	60000	M
5233	SOOQRA	TUCFXJTZMM	8387501336 Dell Way	\N	UJQDDJH	DE	76386	US	1	TUCFXJTZMM@dell.com	8387501336	2	5427791433874518	2009/08	user5233	password	29	20000	F
5234	SSWTLR	VQOEJORWIB	1907085873 Dell Way	\N	MMEWTJP	NE	61582	US	1	VQOEJORWIB@dell.com	1907085873	5	2740176975727081	2009/12	user5234	password	45	100000	M
5235	GSCXNT	LSDZKZILMU	7595397598 Dell Way	\N	PJOZZDO	AZ	17045	US	1	LSDZKZILMU@dell.com	7595397598	2	1506129090208560	2008/04	user5235	password	71	40000	F
5236	VGNOSG	RSQRABDVRN	7074276468 Dell Way	\N	KRMOFNQ	WA	88010	US	1	RSQRABDVRN@dell.com	7074276468	1	2487793604843318	2010/05	user5236	password	30	40000	M
5237	SUJZLC	PDDRHYJUIA	8331713241 Dell Way	\N	GWFUMDQ	DE	26703	US	1	PDDRHYJUIA@dell.com	8331713241	3	6258311680983753	2012/10	user5237	password	35	80000	M
5238	PRBSGE	VYLTIFCILZ	5274542839 Dell Way	\N	OGMSWQX	OH	30040	US	1	VYLTIFCILZ@dell.com	5274542839	4	1212706157006323	2011/05	user5238	password	62	40000	F
5239	QAIVVG	GPPLSYXRMD	1419863527 Dell Way	\N	DFAUCSA	ND	46630	US	1	GPPLSYXRMD@dell.com	1419863527	2	8146966267842800	2011/08	user5239	password	79	40000	M
5240	EDMLJB	AVTYSLLWPQ	8178612524 Dell Way	\N	WKSPKHA	MN	60343	US	1	AVTYSLLWPQ@dell.com	8178612524	1	2496983422897756	2011/06	user5240	password	76	100000	M
5241	GGXIGS	CFLOQHDGEN	9959978453 Dell Way	\N	ZTYHUKV	ND	58478	US	1	CFLOQHDGEN@dell.com	9959978453	2	9677057793363930	2011/01	user5241	password	55	20000	F
5242	KKMDMR	OBIWEPBSPU	6337076420 Dell Way	\N	RWOCRDQ	NY	41781	US	1	OBIWEPBSPU@dell.com	6337076420	3	4289885042235255	2008/07	user5242	password	62	60000	M
5243	CQLUFM	DCQSDJHYBE	4396857970 Dell Way	\N	NDVRTNA	LA	98828	US	1	DCQSDJHYBE@dell.com	4396857970	3	5669295538682491	2012/12	user5243	password	50	20000	M
5244	WXWIAY	ZTCJBAKFNO	1499987259 Dell Way	\N	AEHOFQN	NE	19777	US	1	ZTCJBAKFNO@dell.com	1499987259	3	1714181652292609	2010/08	user5244	password	69	40000	M
5245	OSOMSI	OBJPMODAPI	2469711865 Dell Way	\N	IDNZRCC	OK	69141	US	1	OBJPMODAPI@dell.com	2469711865	2	3871382785961032	2012/08	user5245	password	81	60000	F
5246	LXATMC	CBPQEPFMYJ	1661468584 Dell Way	\N	AXACZTT	DC	96946	US	1	CBPQEPFMYJ@dell.com	1661468584	1	6083844705019147	2012/06	user5246	password	82	40000	F
5247	XDVAGX	PXCFDPDMPB	8010758237 Dell Way	\N	NRBGLFF	MT	30019	US	1	PXCFDPDMPB@dell.com	8010758237	3	6926346136722714	2011/11	user5247	password	18	60000	F
5248	VPGTED	VKHKOTZPHR	7655422845 Dell Way	\N	RNDWTQC	MT	19295	US	1	VKHKOTZPHR@dell.com	7655422845	1	9634093117434532	2011/09	user5248	password	88	60000	F
5249	FINJDY	QNMKNCRFTF	1211590714 Dell Way	\N	IPYYRLB	ME	65600	US	1	QNMKNCRFTF@dell.com	1211590714	1	4236199430190027	2012/09	user5249	password	68	40000	F
5250	FOEDFS	PQFSIKLNTB	8998914770 Dell Way	\N	MSSXTDN	SC	37918	US	1	PQFSIKLNTB@dell.com	8998914770	4	1484884289093315	2010/12	user5250	password	25	80000	M
5251	HXUZNK	FFTQQHJRTB	9282478838 Dell Way	\N	KQVOEPW	AZ	44863	US	1	FFTQQHJRTB@dell.com	9282478838	4	4273639065679163	2008/06	user5251	password	84	40000	F
5252	RHWCMB	VDSCMKVOVM	7629757890 Dell Way	\N	JJRZGSJ	DE	43114	US	1	VDSCMKVOVM@dell.com	7629757890	1	8107623265590520	2011/06	user5252	password	27	40000	M
5253	ZLHBHK	TKXEGLZSVJ	3456999820 Dell Way	\N	KUQCEUM	VT	97858	US	1	TKXEGLZSVJ@dell.com	3456999820	3	5281040138565004	2009/11	user5253	password	37	40000	F
5254	OKPZEA	WJGIJYDSIY	6258633655 Dell Way	\N	JLCDYAC	GA	61033	US	1	WJGIJYDSIY@dell.com	6258633655	4	5166050024330616	2012/12	user5254	password	76	60000	F
5255	KKPKGY	QOHPSAYQJK	7802674632 Dell Way	\N	SNISPOH	FL	24897	US	1	QOHPSAYQJK@dell.com	7802674632	1	2350866365246475	2010/06	user5255	password	58	100000	M
5256	DJCCAR	JPJKOZTYSG	2430228722 Dell Way	\N	HLWVSBA	MO	20469	US	1	JPJKOZTYSG@dell.com	2430228722	1	6184486581012607	2011/12	user5256	password	48	100000	F
5257	NYJEHZ	OSNNMMFSTR	4283431425 Dell Way	\N	PPJRQVU	RI	88351	US	1	OSNNMMFSTR@dell.com	4283431425	3	8711173833347858	2011/05	user5257	password	33	40000	F
5258	PMOOBG	CPTOVLIMBY	4679459045 Dell Way	\N	VTORNIO	VA	82672	US	1	CPTOVLIMBY@dell.com	4679459045	4	2299673799425363	2011/12	user5258	password	48	40000	F
5259	ZTNGVC	ZKXLSKNQFG	5231241361 Dell Way	\N	FXTNLQI	UT	39127	US	1	ZKXLSKNQFG@dell.com	5231241361	3	3757838197983801	2012/09	user5259	password	75	100000	F
5260	ICHLCR	JNKTABYHGW	3815500323 Dell Way	\N	AUIRCEA	NE	69307	US	1	JNKTABYHGW@dell.com	3815500323	3	4108367657754570	2008/04	user5260	password	75	60000	F
5261	BVNTEB	EXCFWJMTKG	2976054317 Dell Way	\N	BCJFCYW	MD	45102	US	1	EXCFWJMTKG@dell.com	2976054317	3	7348066771402956	2008/11	user5261	password	27	20000	M
5262	QWYSAW	UGTETMOZNQ	4554431141 Dell Way	\N	JTSHPDR	TN	65289	US	1	UGTETMOZNQ@dell.com	4554431141	5	5762434517499060	2010/12	user5262	password	38	20000	M
5263	GXUCRA	WVTIKTWADP	1065198508 Dell Way	\N	TLEWCAM	MS	86762	US	1	WVTIKTWADP@dell.com	1065198508	1	7972113535739482	2009/03	user5263	password	57	60000	F
5264	IQUJMQ	DVAXRBAGUL	1770726071 Dell Way	\N	LROLDBI	DC	19010	US	1	DVAXRBAGUL@dell.com	1770726071	3	3861736279912293	2011/12	user5264	password	48	100000	M
5265	FICVLY	WIPYIWSUHK	8365209811 Dell Way	\N	ITOKBRN	DC	22402	US	1	WIPYIWSUHK@dell.com	8365209811	4	2042342469561845	2009/09	user5265	password	71	60000	F
5266	VHMUEV	JCEFVYNFHH	7232873421 Dell Way	\N	TSILFMO	AK	33875	US	1	JCEFVYNFHH@dell.com	7232873421	2	1010742217767983	2010/09	user5266	password	21	40000	F
5267	OAEJKG	OQBNDHULAM	5652205646 Dell Way	\N	TMRGBSN	OR	96092	US	1	OQBNDHULAM@dell.com	5652205646	1	6978269558399916	2010/06	user5267	password	66	20000	F
5268	VNWCBN	EORLJCMWWY	8803181221 Dell Way	\N	OCZGPSF	CT	88737	US	1	EORLJCMWWY@dell.com	8803181221	4	3707921667955816	2010/10	user5268	password	73	40000	F
5269	QLJDQY	UBHWNDSMRV	3974555464 Dell Way	\N	LYLEDOA	AK	33925	US	1	UBHWNDSMRV@dell.com	3974555464	3	1805016014259308	2008/11	user5269	password	48	80000	F
5270	UWZSRB	ANOEGBWCMU	4894652088 Dell Way	\N	NQYCRYI	WY	53222	US	1	ANOEGBWCMU@dell.com	4894652088	1	4518734183162451	2012/10	user5270	password	73	80000	M
5271	TJIUJW	JNDKKFXESN	9275733987 Dell Way	\N	CUEBDEN	NE	34740	US	1	JNDKKFXESN@dell.com	9275733987	3	1809023092035204	2011/01	user5271	password	74	60000	F
5272	CFUZPI	CASHXWALZV	2646325530 Dell Way	\N	QBYVONC	MO	95632	US	1	CASHXWALZV@dell.com	2646325530	1	1041287679225206	2012/08	user5272	password	48	20000	M
5273	FALNDL	FLJCLUCHLD	7579918360 Dell Way	\N	GGSUIES	MT	41289	US	1	FLJCLUCHLD@dell.com	7579918360	3	9504795010667296	2008/07	user5273	password	74	40000	M
5274	FWRQBD	AEPUGWFJCM	5839641543 Dell Way	\N	BWVGPIP	KY	82809	US	1	AEPUGWFJCM@dell.com	5839641543	3	4040693156421185	2009/10	user5274	password	83	60000	M
5275	PETSEX	HYDDENGRPD	9600151908 Dell Way	\N	MVTVLCQ	WV	60840	US	1	HYDDENGRPD@dell.com	9600151908	2	4508603827562183	2012/10	user5275	password	22	60000	M
5276	VDCSLB	WOGKVXZZJV	7702288769 Dell Way	\N	SEGUUFJ	PA	52667	US	1	WOGKVXZZJV@dell.com	7702288769	4	3289474338293076	2012/01	user5276	password	31	80000	F
5277	HIPIFE	OPZLOZVJRA	5966194321 Dell Way	\N	QMUVVOH	ND	23311	US	1	OPZLOZVJRA@dell.com	5966194321	2	2638903037179261	2011/12	user5277	password	43	20000	F
5278	YJODXD	DJSCFCTFSF	8901089293 Dell Way	\N	ANBOVPS	MA	98373	US	1	DJSCFCTFSF@dell.com	8901089293	1	9818676099181176	2009/02	user5278	password	41	20000	F
5279	WHKZKU	SNZUGEMMEA	1918575354 Dell Way	\N	NTWDLGD	IN	42668	US	1	SNZUGEMMEA@dell.com	1918575354	3	5564918766263873	2010/09	user5279	password	18	40000	F
5280	KGLFYY	ETFJFSOGGH	2961316291 Dell Way	\N	CKSJNAS	NJ	61429	US	1	ETFJFSOGGH@dell.com	2961316291	1	3652397606987506	2009/04	user5280	password	41	80000	M
5281	TVNSAG	YJMRXSXFVH	8455595901 Dell Way	\N	YEUZXKN	CO	50173	US	1	YJMRXSXFVH@dell.com	8455595901	2	7728750970214606	2008/12	user5281	password	40	100000	M
5282	VQUBPE	OGCGDHCLFH	8752200118 Dell Way	\N	GEERSHC	ND	64368	US	1	OGCGDHCLFH@dell.com	8752200118	4	6072824987582863	2008/08	user5282	password	43	100000	F
5283	DBVHPC	JWGRZRXGYC	8643742440 Dell Way	\N	KPURSJH	NE	14789	US	1	JWGRZRXGYC@dell.com	8643742440	4	7007232776377351	2008/09	user5283	password	85	40000	M
5284	TQKVAG	BRFTPLRRWH	5932617167 Dell Way	\N	MOZVVOW	NY	37142	US	1	BRFTPLRRWH@dell.com	5932617167	5	1305555444676429	2010/03	user5284	password	78	40000	M
5285	FBWMDO	RXDDPUAWGO	7679839941 Dell Way	\N	WCKKZBS	MT	94735	US	1	RXDDPUAWGO@dell.com	7679839941	5	2402087148744613	2010/03	user5285	password	18	80000	F
5286	WGLKYI	OCXICTPRPS	2917970976 Dell Way	\N	BARDSFB	MN	27219	US	1	OCXICTPRPS@dell.com	2917970976	1	4707950018811971	2009/10	user5286	password	69	20000	F
5287	DMAMAD	JJGDZXTRZU	2404328633 Dell Way	\N	JCNODZT	KY	11089	US	1	JJGDZXTRZU@dell.com	2404328633	3	8518208655063064	2012/08	user5287	password	84	100000	F
5288	YLECVO	IZNGTFFNOH	8501895149 Dell Way	\N	ADKZWTZ	AL	39731	US	1	IZNGTFFNOH@dell.com	8501895149	5	9821028999984264	2011/11	user5288	password	27	80000	F
5289	IUEWCD	KJWQOKFVKI	3913863440 Dell Way	\N	GKEAKFI	HI	18400	US	1	KJWQOKFVKI@dell.com	3913863440	5	9720834851730616	2010/09	user5289	password	40	80000	F
5290	MQOQAY	NRMXWIHEOR	6735783874 Dell Way	\N	JOBOXHR	IA	33462	US	1	NRMXWIHEOR@dell.com	6735783874	4	9399832041468472	2012/06	user5290	password	46	60000	F
5291	ZBDXOU	JLQRTVGKEV	9754437763 Dell Way	\N	MTTUKZB	AR	70195	US	1	JLQRTVGKEV@dell.com	9754437763	5	2091378371696919	2009/05	user5291	password	32	40000	F
5292	IFZCPL	TGEONPSICM	8377801504 Dell Way	\N	BWXAXYS	UT	95382	US	1	TGEONPSICM@dell.com	8377801504	2	4271988170221448	2008/07	user5292	password	77	40000	M
5293	VLJGEQ	LSDALLCYMY	1769007500 Dell Way	\N	VNWUFSS	AR	96245	US	1	LSDALLCYMY@dell.com	1769007500	1	5687383685726673	2012/05	user5293	password	39	80000	M
5294	RZAHKT	KKFWNDJMZW	5771360540 Dell Way	\N	ITCBMEA	ND	30382	US	1	KKFWNDJMZW@dell.com	5771360540	3	6755740141961724	2012/03	user5294	password	54	60000	F
5295	NUOHEZ	NBMRKZQHHK	4752611929 Dell Way	\N	KJWOJKU	VA	87480	US	1	NBMRKZQHHK@dell.com	4752611929	4	1339876140467822	2012/03	user5295	password	31	60000	M
5296	TTESHF	FYPEPXMZHV	2160320216 Dell Way	\N	VVFFQCC	AL	81993	US	1	FYPEPXMZHV@dell.com	2160320216	5	1072140949312597	2009/05	user5296	password	90	20000	F
5297	EUKJAJ	ZFYWRXENTA	6500656683 Dell Way	\N	SZQUBRP	FL	65067	US	1	ZFYWRXENTA@dell.com	6500656683	3	1077244040556252	2011/07	user5297	password	29	80000	F
5298	ODJYDP	WAHUEUOENN	1926495620 Dell Way	\N	VIPMYUC	NC	36223	US	1	WAHUEUOENN@dell.com	1926495620	1	8846253353636713	2009/11	user5298	password	35	100000	F
5299	QTEFQE	MLJHZOVNJD	1367165877 Dell Way	\N	CVBWYPE	AR	77735	US	1	MLJHZOVNJD@dell.com	1367165877	2	6932871469296516	2009/02	user5299	password	69	100000	M
5300	WDOBPA	KXAYSNIWQE	9498393114 Dell Way	\N	XMCNRDH	OK	49612	US	1	KXAYSNIWQE@dell.com	9498393114	5	6165750491898507	2011/11	user5300	password	52	60000	F
5301	AOQAZO	BXGOFCEKAR	6720651043 Dell Way	\N	MOIQWBB	SC	13769	US	1	BXGOFCEKAR@dell.com	6720651043	3	9500241583678872	2008/12	user5301	password	88	20000	M
5302	PENDFL	KURNYBOQNC	1134384291 Dell Way	\N	ZDYAFTB	TN	26453	US	1	KURNYBOQNC@dell.com	1134384291	5	2294707161374390	2012/02	user5302	password	67	60000	F
5303	ETMPDH	GQFHEWVHVZ	3792232361 Dell Way	\N	GWEZYAE	WI	96946	US	1	GQFHEWVHVZ@dell.com	3792232361	5	1559474279638379	2012/07	user5303	password	42	20000	F
5304	VTKCAB	IIGFDOACUX	3771033538 Dell Way	\N	GUWHYUG	IA	77150	US	1	IIGFDOACUX@dell.com	3771033538	2	3531917111482471	2011/05	user5304	password	58	60000	F
5305	ZOEBXM	HCQVDSQBZK	7509121352 Dell Way	\N	XHISNPL	TN	84029	US	1	HCQVDSQBZK@dell.com	7509121352	3	2960749791935086	2009/12	user5305	password	45	40000	M
5306	OHLBPN	RLRKBSKMPR	5017136830 Dell Way	\N	VHEKTAF	MN	52551	US	1	RLRKBSKMPR@dell.com	5017136830	4	4749041519593448	2012/12	user5306	password	86	40000	F
5307	JLWWCI	OMKGXWVORD	6587789488 Dell Way	\N	SCWTIIF	PA	14736	US	1	OMKGXWVORD@dell.com	6587789488	3	1387481117621064	2010/12	user5307	password	42	100000	F
5308	FUMNIZ	XPWULLMOEO	8518079154 Dell Way	\N	KXWTCQU	OK	29532	US	1	XPWULLMOEO@dell.com	8518079154	2	2623698411509394	2008/03	user5308	password	59	40000	M
5309	BXIBVX	YPJJCXNQIK	5813324681 Dell Way	\N	NBMDWFJ	OH	51438	US	1	YPJJCXNQIK@dell.com	5813324681	5	6799692268949003	2008/03	user5309	password	63	20000	F
5310	YFZWDP	FMRDZHLJVN	2434328717 Dell Way	\N	WYKBHCN	TN	95681	US	1	FMRDZHLJVN@dell.com	2434328717	5	2723778146784752	2011/02	user5310	password	42	80000	F
5311	IQLXVY	OZYWLHRYEQ	6197291865 Dell Way	\N	IFYLTUK	VA	75142	US	1	OZYWLHRYEQ@dell.com	6197291865	4	8472285117022694	2012/06	user5311	password	28	40000	F
5312	PDWNSW	MPHTHFYXOE	2703367487 Dell Way	\N	WAXQKUJ	WV	53188	US	1	MPHTHFYXOE@dell.com	2703367487	5	9176527868956328	2009/02	user5312	password	87	100000	F
5313	VMYRYN	YSUEQSTUOT	8926146754 Dell Way	\N	SFEMODZ	PA	11046	US	1	YSUEQSTUOT@dell.com	8926146754	1	2129637363366782	2012/01	user5313	password	45	80000	F
5314	IJLWID	QNUJGOYAHD	5018202552 Dell Way	\N	ETSITLI	NJ	57917	US	1	QNUJGOYAHD@dell.com	5018202552	3	6006488053593785	2012/02	user5314	password	21	20000	F
5315	MZUQQH	KZOZYPGBTZ	3555226668 Dell Way	\N	TCSFKIS	TX	81651	US	1	KZOZYPGBTZ@dell.com	3555226668	4	9260418993420900	2009/10	user5315	password	46	100000	M
5316	ELKMVK	BUIQAJKADM	8248048487 Dell Way	\N	TIWCBSX	KY	44529	US	1	BUIQAJKADM@dell.com	8248048487	4	2616715427022427	2009/06	user5316	password	87	40000	M
5317	JWTUYO	COOMZPQLIY	6483417149 Dell Way	\N	IKABHJL	CO	12315	US	1	COOMZPQLIY@dell.com	6483417149	2	5703856321517379	2010/09	user5317	password	51	100000	M
5318	FSNTUC	IHBXXMFWVQ	7831844347 Dell Way	\N	WWYFHBG	VT	42122	US	1	IHBXXMFWVQ@dell.com	7831844347	3	1546124154236167	2009/05	user5318	password	65	60000	F
5319	EEXGMF	HKDUQZQGVM	6896765880 Dell Way	\N	EBUGHRP	AR	24600	US	1	HKDUQZQGVM@dell.com	6896765880	2	6128915816079826	2009/09	user5319	password	67	60000	M
5320	PSJVAT	YVJXLQTYVU	2168782104 Dell Way	\N	SBBKQCO	IN	42940	US	1	YVJXLQTYVU@dell.com	2168782104	4	1427373763173818	2012/01	user5320	password	84	60000	M
5321	HFVAEQ	KBBAUZVPSX	2538565642 Dell Way	\N	QCNTRVD	SC	50088	US	1	KBBAUZVPSX@dell.com	2538565642	4	5676484537776560	2008/01	user5321	password	40	40000	F
5322	DJKTUM	VUGVQVNNMQ	8820820463 Dell Way	\N	BGHXJCJ	NC	72645	US	1	VUGVQVNNMQ@dell.com	8820820463	4	7468883733265103	2008/12	user5322	password	88	40000	F
5323	JBDVXX	CSOYGCLXDR	7240717788 Dell Way	\N	EBBHKPZ	ID	29331	US	1	CSOYGCLXDR@dell.com	7240717788	3	2678519352339208	2011/10	user5323	password	57	20000	M
5324	RWSPZL	DYSFJPJBUK	1891960070 Dell Way	\N	CBVSBBX	OR	57362	US	1	DYSFJPJBUK@dell.com	1891960070	2	3558849130291492	2011/06	user5324	password	26	40000	F
5325	VWIHAG	ZFPPPRJZTL	7169069984 Dell Way	\N	UMMWJFK	MO	64066	US	1	ZFPPPRJZTL@dell.com	7169069984	1	1329329325817525	2011/05	user5325	password	43	80000	F
5326	RXHXXM	NMBEWBYHWK	6452768574 Dell Way	\N	TTUZDHO	SD	45005	US	1	NMBEWBYHWK@dell.com	6452768574	4	8131331851705910	2012/03	user5326	password	22	80000	F
5327	INBVBO	XGKZERVPLO	8753258568 Dell Way	\N	KKSRZNB	NH	22642	US	1	XGKZERVPLO@dell.com	8753258568	3	4484832695685327	2012/03	user5327	password	57	40000	M
5328	PCTDAA	OZEGUURJFC	2110824160 Dell Way	\N	BWCPYST	SD	32581	US	1	OZEGUURJFC@dell.com	2110824160	4	4908854020293802	2011/12	user5328	password	28	40000	F
5329	XKCXZC	CFXXXGCAIZ	5294866754 Dell Way	\N	CYXURSB	SC	50436	US	1	CFXXXGCAIZ@dell.com	5294866754	3	5037170354742557	2011/09	user5329	password	58	60000	F
5330	RLDTOI	QLFXOFGNIE	1380910786 Dell Way	\N	LCVDEQP	NM	17652	US	1	QLFXOFGNIE@dell.com	1380910786	2	8375551261473448	2010/10	user5330	password	89	40000	F
5331	CZVLQH	RNVWTJFXUI	3544646087 Dell Way	\N	TYMJNCM	ND	43168	US	1	RNVWTJFXUI@dell.com	3544646087	1	2562619374133646	2009/05	user5331	password	50	40000	F
5332	GUAOLO	KIHTNFOVZM	9669886119 Dell Way	\N	IJZKVOU	CA	73939	US	1	KIHTNFOVZM@dell.com	9669886119	2	2030528415925800	2010/09	user5332	password	55	80000	M
5333	NFYBQH	JJUPXQOKYX	7814668545 Dell Way	\N	JJSYEVQ	CT	25222	US	1	JJUPXQOKYX@dell.com	7814668545	3	8953769802581520	2009/03	user5333	password	46	80000	F
5334	IWBQGL	LVJBJTAHDK	8775371248 Dell Way	\N	ZBPVSSZ	MN	33642	US	1	LVJBJTAHDK@dell.com	8775371248	4	5244793541263789	2009/07	user5334	password	84	60000	F
5335	ZFQKQL	USVOTCRECT	3032802844 Dell Way	\N	TXLMWXT	OR	68641	US	1	USVOTCRECT@dell.com	3032802844	5	2601424400694668	2008/08	user5335	password	59	20000	M
5336	ENLQIE	LWYNODPHWM	5506734171 Dell Way	\N	TJJRDCI	LA	19042	US	1	LWYNODPHWM@dell.com	5506734171	3	7213139181490988	2008/08	user5336	password	54	40000	F
5337	YXMDII	CVXFLECYYL	2944916003 Dell Way	\N	IPPLYYN	ME	49421	US	1	CVXFLECYYL@dell.com	2944916003	3	1369099939242005	2011/10	user5337	password	31	80000	M
5338	QVZZXV	WCGBEFZQNP	6975980862 Dell Way	\N	GYNEMYQ	OH	49473	US	1	WCGBEFZQNP@dell.com	6975980862	3	2767461943905800	2012/01	user5338	password	79	60000	M
5339	ULUQIX	WJCCITPXZO	1051830286 Dell Way	\N	LEAJUSV	MI	19811	US	1	WJCCITPXZO@dell.com	1051830286	2	2713781537022441	2012/10	user5339	password	24	80000	F
5340	XHOUDX	XFGQVEPJPU	4531422913 Dell Way	\N	KZOCUAF	RI	37306	US	1	XFGQVEPJPU@dell.com	4531422913	4	1713362526614219	2010/04	user5340	password	40	40000	M
5341	WESUBY	ASTEHDUBNT	1253056957 Dell Way	\N	QPNQUIY	GA	94723	US	1	ASTEHDUBNT@dell.com	1253056957	4	3019627062603831	2009/01	user5341	password	74	40000	F
5342	MZHKZZ	EEHHZJUSAK	7505198345 Dell Way	\N	GQFOPKM	NJ	18083	US	1	EEHHZJUSAK@dell.com	7505198345	5	2338336450979113	2010/03	user5342	password	45	100000	F
5343	RKDROI	YVHIQAIAGZ	8854223290 Dell Way	\N	FUPQHFS	AL	25390	US	1	YVHIQAIAGZ@dell.com	8854223290	3	4063315577805042	2009/07	user5343	password	53	100000	M
5344	QPLYOG	GXWGFXMFDH	5470460341 Dell Way	\N	UTPZMQE	LA	23599	US	1	GXWGFXMFDH@dell.com	5470460341	4	6931567203253508	2012/07	user5344	password	58	80000	F
5345	ZOSGUP	DAVANAEVUY	8537865852 Dell Way	\N	KUKAYUE	MI	45516	US	1	DAVANAEVUY@dell.com	8537865852	3	9468549674842508	2009/01	user5345	password	24	40000	M
5346	UQJKTK	FUXFZSAXDU	4936701816 Dell Way	\N	IETCIEM	DE	62904	US	1	FUXFZSAXDU@dell.com	4936701816	3	6520229877438397	2010/12	user5346	password	32	40000	M
5347	OSIZXD	WDCPDATYIX	1309411832 Dell Way	\N	RLFVYKK	MA	96127	US	1	WDCPDATYIX@dell.com	1309411832	5	9083058395888656	2009/03	user5347	password	52	80000	M
5348	VTVYQY	BGBCZZLWRW	4161404242 Dell Way	\N	CMUMXEL	WI	17218	US	1	BGBCZZLWRW@dell.com	4161404242	1	3657175157684833	2012/12	user5348	password	33	80000	M
5349	APJZRQ	ATQAEMSAPE	4600920017 Dell Way	\N	VCCAOBC	VA	30317	US	1	ATQAEMSAPE@dell.com	4600920017	4	2787917467299849	2011/05	user5349	password	86	80000	M
5350	IPPYQI	ORNBJOROKT	2148066767 Dell Way	\N	RKHSNEY	VT	91985	US	1	ORNBJOROKT@dell.com	2148066767	3	3367657533381134	2008/03	user5350	password	32	40000	M
5351	UILDXC	QYMFPAPJRA	1138476475 Dell Way	\N	QKNVILT	MI	97747	US	1	QYMFPAPJRA@dell.com	1138476475	3	2345291054341942	2009/11	user5351	password	86	20000	F
5352	JECMUB	YZQZPZQPQB	7044219504 Dell Way	\N	CMJOGUN	ID	37684	US	1	YZQZPZQPQB@dell.com	7044219504	3	2699339840561151	2011/06	user5352	password	46	100000	M
5353	MLLNJL	EIAEZPVASH	7219347506 Dell Way	\N	KGOFUUN	MN	34994	US	1	EIAEZPVASH@dell.com	7219347506	1	7922571404371411	2008/01	user5353	password	48	60000	F
5354	WCVHGE	IKEYGEQNPX	9369571879 Dell Way	\N	CURWHDE	WV	27667	US	1	IKEYGEQNPX@dell.com	9369571879	1	2963378038257360	2009/08	user5354	password	66	40000	M
5355	MNZRVJ	VUPZKDPIFJ	6105802437 Dell Way	\N	ACQDHPJ	GA	69258	US	1	VUPZKDPIFJ@dell.com	6105802437	3	3498982748948038	2009/10	user5355	password	89	80000	F
5356	YJCIFW	YEHCUQIDQL	3750851014 Dell Way	\N	TUSJDXA	OK	51203	US	1	YEHCUQIDQL@dell.com	3750851014	5	2907114555127919	2009/09	user5356	password	52	40000	F
5357	POGLNL	TPFJXIAJCU	6718719689 Dell Way	\N	BMYZNQL	SD	63193	US	1	TPFJXIAJCU@dell.com	6718719689	1	3385958429891616	2008/05	user5357	password	41	80000	M
5358	ODKAXA	GHYOHHRCIE	5767766820 Dell Way	\N	AHRRSMG	LA	62196	US	1	GHYOHHRCIE@dell.com	5767766820	3	9272320541553200	2012/02	user5358	password	78	60000	F
5359	GLFGRM	EGTLYVUCWB	7735221112 Dell Way	\N	UOUGUDV	KS	64845	US	1	EGTLYVUCWB@dell.com	7735221112	1	7893729577306659	2010/08	user5359	password	22	100000	F
5360	GBTTFZ	MRYILBEMVS	8239941409 Dell Way	\N	HBNLXWB	NM	14843	US	1	MRYILBEMVS@dell.com	8239941409	2	7017943478189409	2012/01	user5360	password	71	20000	F
5361	MWHMJY	KRJLWWGPEI	7592578131 Dell Way	\N	DPFAQWB	ME	17300	US	1	KRJLWWGPEI@dell.com	7592578131	2	1910410672426223	2010/06	user5361	password	30	100000	F
5362	LKRKVJ	UHGQNVUWZK	2322248749 Dell Way	\N	CZAZBLB	SC	77083	US	1	UHGQNVUWZK@dell.com	2322248749	2	2656062113121152	2009/03	user5362	password	54	80000	M
5363	EEKNYR	TPFPKCPUEO	2479710650 Dell Way	\N	UDQGFLZ	KY	71285	US	1	TPFPKCPUEO@dell.com	2479710650	4	8826059530023486	2011/06	user5363	password	51	100000	M
5364	WIOOCD	TSNWHHAWCE	5170416920 Dell Way	\N	MIJXHSP	MN	43942	US	1	TSNWHHAWCE@dell.com	5170416920	1	8271601484157146	2012/12	user5364	password	47	80000	F
5365	YJKCCC	PZJXZFZESI	5170334916 Dell Way	\N	OPQHFCR	NV	30623	US	1	PZJXZFZESI@dell.com	5170334916	3	2627328027039766	2012/05	user5365	password	52	100000	M
5366	WXWYNV	ILUNLZFTOV	9112767259 Dell Way	\N	KVAMMRS	WI	35413	US	1	ILUNLZFTOV@dell.com	9112767259	5	7045542390551419	2009/08	user5366	password	47	40000	M
5367	GFCBNN	WAZWGSKBDG	7574191454 Dell Way	\N	CPSUIRB	HI	53479	US	1	WAZWGSKBDG@dell.com	7574191454	4	2182085827458650	2008/11	user5367	password	68	40000	F
5368	ULOIIO	HEVAPWDVYT	8499511064 Dell Way	\N	OTCFUIS	MT	92712	US	1	HEVAPWDVYT@dell.com	8499511064	4	7946137565188111	2010/01	user5368	password	77	40000	M
5369	JQVYYA	TYQQCMPVAI	9182846663 Dell Way	\N	XGDFYQD	RI	37776	US	1	TYQQCMPVAI@dell.com	9182846663	2	4278230328578502	2011/08	user5369	password	82	20000	F
5370	SBFTUE	JLGWABWJZD	8118927414 Dell Way	\N	MFBDIVL	IA	22964	US	1	JLGWABWJZD@dell.com	8118927414	5	7959950367454440	2011/01	user5370	password	21	40000	F
5371	GDXKNJ	QJJSGSSJFX	2573635667 Dell Way	\N	KIFGTMK	NC	50330	US	1	QJJSGSSJFX@dell.com	2573635667	2	5680074993055314	2009/08	user5371	password	64	60000	M
5372	OWGXNQ	HGWAYFFVQN	5567606012 Dell Way	\N	BXHOIVZ	MO	12316	US	1	HGWAYFFVQN@dell.com	5567606012	4	6562289584428073	2008/03	user5372	password	43	80000	F
5373	PPPFXV	CXTIDPZRRW	4655769746 Dell Way	\N	YFETERU	OH	43952	US	1	CXTIDPZRRW@dell.com	4655769746	5	5998714986722917	2011/07	user5373	password	62	40000	F
5374	FOAARY	UZBJYSBVRG	6589623758 Dell Way	\N	ALLRFDB	NJ	96659	US	1	UZBJYSBVRG@dell.com	6589623758	2	5507337895222009	2009/09	user5374	password	65	60000	F
5375	RLZQFY	RPXKQTCXTN	9118068205 Dell Way	\N	ILTLNJK	CT	76290	US	1	RPXKQTCXTN@dell.com	9118068205	2	5216294680722058	2010/10	user5375	password	74	40000	F
5376	TWMSOB	PYSIBPCOXN	8695428889 Dell Way	\N	HJAQTDK	NV	55691	US	1	PYSIBPCOXN@dell.com	8695428889	2	3648070814087987	2011/06	user5376	password	56	40000	F
5377	ZBVBRU	UAVJCKHPRQ	6218079442 Dell Way	\N	QIKUSBH	NE	33671	US	1	UAVJCKHPRQ@dell.com	6218079442	2	7269227432552726	2008/07	user5377	password	89	20000	M
5378	VEIPYI	LHKVPANGQW	6880296539 Dell Way	\N	QKPSSEY	IL	43684	US	1	LHKVPANGQW@dell.com	6880296539	2	9611316137947144	2011/06	user5378	password	62	60000	M
5379	YBOGMW	RILRWSISIS	8223403290 Dell Way	\N	HALMZSV	NM	19114	US	1	RILRWSISIS@dell.com	8223403290	2	6287230403628201	2010/09	user5379	password	34	40000	M
5380	UPHRGP	DXMVGEDYME	8074084949 Dell Way	\N	KZDCVUF	NJ	13708	US	1	DXMVGEDYME@dell.com	8074084949	1	7848495794460178	2008/05	user5380	password	57	100000	M
5381	VMFKPD	WKJBNIOSSN	4713657566 Dell Way	\N	VUIPAYQ	SC	96860	US	1	WKJBNIOSSN@dell.com	4713657566	5	3963042983319610	2012/08	user5381	password	38	80000	F
5382	MERQBB	ZDPIRHAFDV	7985477109 Dell Way	\N	OTVMKPL	SD	47246	US	1	ZDPIRHAFDV@dell.com	7985477109	4	1206240780185908	2008/07	user5382	password	25	60000	M
5383	TETVEW	LMOSNUWIIP	2914149926 Dell Way	\N	EUAUGVE	AL	61322	US	1	LMOSNUWIIP@dell.com	2914149926	1	1801976803224533	2009/08	user5383	password	75	20000	M
5384	OXAKIN	ZBATXJCNNW	9872047289 Dell Way	\N	NIDINDX	OK	30659	US	1	ZBATXJCNNW@dell.com	9872047289	1	8869878740981222	2011/02	user5384	password	69	40000	F
5385	STIGSK	HMHQOVELIM	8383607037 Dell Way	\N	ORZSOSY	NC	75927	US	1	HMHQOVELIM@dell.com	8383607037	2	8530019112862647	2010/08	user5385	password	79	40000	F
5386	ENBPUO	WLDSPOACDS	4357062731 Dell Way	\N	CWGUUUN	NJ	19813	US	1	WLDSPOACDS@dell.com	4357062731	1	7590452618896962	2009/05	user5386	password	24	60000	M
5387	EZSSWD	WOTKPVOHYL	2648750641 Dell Way	\N	OTGIHWL	NV	11495	US	1	WOTKPVOHYL@dell.com	2648750641	5	4897769514936954	2009/04	user5387	password	43	60000	F
5388	BDDEZR	XKHTZPSKDL	9510200659 Dell Way	\N	QMTMXKN	CO	33664	US	1	XKHTZPSKDL@dell.com	9510200659	2	5859757629223168	2009/10	user5388	password	76	40000	M
5389	XNYPLJ	XFIMYTPKJB	3830658718 Dell Way	\N	DWZNKCU	KY	50693	US	1	XFIMYTPKJB@dell.com	3830658718	4	3272189642768353	2008/12	user5389	password	32	20000	M
5390	DQZNNF	WADPPNZRQW	4869361510 Dell Way	\N	QEGSYPE	IA	29753	US	1	WADPPNZRQW@dell.com	4869361510	2	2866042915266007	2011/05	user5390	password	71	80000	F
5391	SHOXDO	BTEPSVGOMK	8467708296 Dell Way	\N	VFIKKPQ	SD	94637	US	1	BTEPSVGOMK@dell.com	8467708296	3	4034017691388726	2010/03	user5391	password	45	40000	M
5392	YERNGK	SVCOBRAMMG	6823684452 Dell Way	\N	UXQJNLI	KY	89497	US	1	SVCOBRAMMG@dell.com	6823684452	5	2007091713603586	2008/03	user5392	password	63	100000	F
5393	HMQRFL	UTNMTZZZUW	1341332056 Dell Way	\N	PDJBMTY	CO	68256	US	1	UTNMTZZZUW@dell.com	1341332056	1	8487233570776881	2011/02	user5393	password	33	100000	M
5394	VQUHKN	VXHVWGPSWT	3784379146 Dell Way	\N	CXFVVIM	VA	51603	US	1	VXHVWGPSWT@dell.com	3784379146	3	6085178420878947	2010/07	user5394	password	29	40000	F
5395	YQOMML	THHAXAXQCV	2940479667 Dell Way	\N	WYREKOQ	OR	18476	US	1	THHAXAXQCV@dell.com	2940479667	2	6400078539270908	2009/08	user5395	password	72	40000	F
5396	HUSTOZ	BOWBMNEHJD	2625127756 Dell Way	\N	YONMFGP	MI	55403	US	1	BOWBMNEHJD@dell.com	2625127756	5	1880676906090229	2012/02	user5396	password	42	40000	M
5397	BZMABB	XDNLHUVKTJ	8366457621 Dell Way	\N	YGPFVAS	WY	86174	US	1	XDNLHUVKTJ@dell.com	8366457621	5	9849911123048516	2008/02	user5397	password	85	20000	F
5398	KGEMDH	ZPPUKAOUYU	3275183658 Dell Way	\N	KEPLXPH	OK	55850	US	1	ZPPUKAOUYU@dell.com	3275183658	5	6896483037620784	2008/01	user5398	password	75	60000	F
5399	YBLGAB	VVLVJFUDPZ	5387599763 Dell Way	\N	TAWIIPV	ND	51998	US	1	VVLVJFUDPZ@dell.com	5387599763	4	5821325907483697	2009/04	user5399	password	79	40000	F
5400	HMJIIF	UEOAZSQYLR	4851508098 Dell Way	\N	VTZLPNX	AZ	33296	US	1	UEOAZSQYLR@dell.com	4851508098	2	6117576031479985	2009/07	user5400	password	85	60000	F
5401	HXJMRN	BRNTHLEYHX	3465546377 Dell Way	\N	XSMLPOS	AL	90287	US	1	BRNTHLEYHX@dell.com	3465546377	2	5173840404022485	2008/11	user5401	password	55	60000	M
5402	XZLKAC	YTKJXJRVHJ	2825795694 Dell Way	\N	HSZWKZT	OH	36391	US	1	YTKJXJRVHJ@dell.com	2825795694	5	2348266701214015	2011/05	user5402	password	83	80000	F
5403	IAJLYC	VIAEZVLJCE	7961247441 Dell Way	\N	IZPISHQ	VT	24566	US	1	VIAEZVLJCE@dell.com	7961247441	4	5812799202743918	2011/03	user5403	password	82	100000	F
5404	GLFIGO	JKOEWXHAGG	6032407085 Dell Way	\N	POYWFWA	WV	52840	US	1	JKOEWXHAGG@dell.com	6032407085	4	7358931046444923	2010/08	user5404	password	88	80000	F
5405	EAITJS	HOPEVPLCEA	1599168471 Dell Way	\N	ABFWBEJ	NJ	83192	US	1	HOPEVPLCEA@dell.com	1599168471	1	5113905513193459	2008/09	user5405	password	56	40000	M
5406	VYDOGR	DKNSWPXWQY	5458991048 Dell Way	\N	BNAFWQA	WA	72601	US	1	DKNSWPXWQY@dell.com	5458991048	5	4914352226071060	2008/03	user5406	password	32	100000	F
5407	IKJAOU	NHQCENTDOG	9199893547 Dell Way	\N	DUCUVBM	KS	10958	US	1	NHQCENTDOG@dell.com	9199893547	2	2773115868680179	2008/03	user5407	password	42	60000	M
5408	SLENYL	DBQRUUFAYA	4555222514 Dell Way	\N	DSVEEDF	CO	53633	US	1	DBQRUUFAYA@dell.com	4555222514	2	7127135180402548	2011/08	user5408	password	39	60000	F
5409	MYAXCC	OTXJZYHZBA	1914411224 Dell Way	\N	UGEYLHK	TX	54834	US	1	OTXJZYHZBA@dell.com	1914411224	3	2234615336172282	2009/01	user5409	password	33	100000	M
5410	GUBIJV	GSUEZTGZNM	2019565846 Dell Way	\N	EMYMXVZ	WY	45433	US	1	GSUEZTGZNM@dell.com	2019565846	2	4766786561813206	2009/03	user5410	password	46	60000	F
5411	LXJGDC	AIBTOBHBGT	6533686624 Dell Way	\N	ZTQUSQF	TN	11208	US	1	AIBTOBHBGT@dell.com	6533686624	1	3310271751135588	2008/09	user5411	password	38	60000	M
5412	RSUTSC	VMQXURDORW	1815163519 Dell Way	\N	EMPVRKV	IL	60803	US	1	VMQXURDORW@dell.com	1815163519	2	3606897786725313	2009/09	user5412	password	85	20000	F
5413	SUEVPR	LMLDPZUMEH	4112253994 Dell Way	\N	CAYMVGB	WA	57296	US	1	LMLDPZUMEH@dell.com	4112253994	2	3340423673857003	2009/04	user5413	password	68	100000	F
5414	WURNGE	ZKTZEGDMID	5001861331 Dell Way	\N	KVZRWXE	HI	29732	US	1	ZKTZEGDMID@dell.com	5001861331	3	5949001898057759	2008/06	user5414	password	65	20000	F
5415	INOMMY	GLDNPPWTAR	4920008292 Dell Way	\N	TRORWUX	IN	36926	US	1	GLDNPPWTAR@dell.com	4920008292	3	8167750856373460	2008/06	user5415	password	25	60000	M
5416	RXMPEY	TROINHJFBB	6927024412 Dell Way	\N	USXOPFW	AL	71503	US	1	TROINHJFBB@dell.com	6927024412	1	2271560653112828	2011/07	user5416	password	27	60000	F
5417	PAPOTH	CCVKLALMUD	5114394324 Dell Way	\N	KJTQFUI	UT	92515	US	1	CCVKLALMUD@dell.com	5114394324	4	5134571212809533	2010/01	user5417	password	84	20000	F
5418	NSUVVW	QFIRQULUFV	7408229256 Dell Way	\N	OVAIEXG	NJ	58396	US	1	QFIRQULUFV@dell.com	7408229256	1	6242236917372794	2011/05	user5418	password	64	20000	F
5419	LYXIPC	QGTLSNQNBM	6042301998 Dell Way	\N	NKQLRHZ	MA	52150	US	1	QGTLSNQNBM@dell.com	6042301998	5	8664028997533024	2008/02	user5419	password	88	80000	F
5420	WYSZOY	TAQHREJEST	4569006965 Dell Way	\N	UDKBCUO	NY	81536	US	1	TAQHREJEST@dell.com	4569006965	5	9439823383931072	2009/06	user5420	password	20	40000	F
5421	TFARZA	IGRMPVEIQI	3624653830 Dell Way	\N	TSLOHCJ	NY	96634	US	1	IGRMPVEIQI@dell.com	3624653830	1	5160192511510104	2009/04	user5421	password	84	20000	F
5422	XTLYCR	QOGMTPDBJW	1040584559 Dell Way	\N	MYDPHUO	NE	82954	US	1	QOGMTPDBJW@dell.com	1040584559	5	1610671929083764	2012/12	user5422	password	58	100000	M
5423	ZUURKJ	YXDOAEXWRV	6862771664 Dell Way	\N	ZGDUURP	SC	63342	US	1	YXDOAEXWRV@dell.com	6862771664	4	6079864273313433	2009/07	user5423	password	38	20000	F
5424	CWSMVP	PJQUHMLDMR	1836735357 Dell Way	\N	GGMYVHN	MO	98531	US	1	PJQUHMLDMR@dell.com	1836735357	4	5664862098637969	2009/11	user5424	password	78	60000	M
5425	OYPENZ	UHGHTJTLQA	7283426263 Dell Way	\N	XOWFCIE	FL	11786	US	1	UHGHTJTLQA@dell.com	7283426263	3	9162865404505284	2010/01	user5425	password	67	20000	M
5426	GGNFBU	MIOWCZMCXA	2886139156 Dell Way	\N	YCDHHHH	WV	87445	US	1	MIOWCZMCXA@dell.com	2886139156	3	9046950749587268	2012/07	user5426	password	81	20000	M
5427	JJWEWF	SSHSEKPFIR	4439191191 Dell Way	\N	IQYQYYM	DC	48691	US	1	SSHSEKPFIR@dell.com	4439191191	1	1102728102356195	2009/03	user5427	password	79	80000	M
5428	SUKXNC	FFGPUMYMUO	8230390063 Dell Way	\N	LLMJXQU	IN	68495	US	1	FFGPUMYMUO@dell.com	8230390063	3	8358794759958983	2011/02	user5428	password	44	40000	M
5429	THLVMQ	CBLOAXJOIU	2383446973 Dell Way	\N	BSSRMAI	IN	59465	US	1	CBLOAXJOIU@dell.com	2383446973	5	7406248021405191	2010/04	user5429	password	66	40000	M
5430	CCBTFC	ETCCDRLYTD	9086767199 Dell Way	\N	QKQQTXE	VT	87565	US	1	ETCCDRLYTD@dell.com	9086767199	3	2438364754896611	2010/09	user5430	password	71	80000	M
5431	TLZWPS	ZSWRDUKHKU	8632974498 Dell Way	\N	XBOVGMR	CT	89930	US	1	ZSWRDUKHKU@dell.com	8632974498	4	6095909520052374	2010/05	user5431	password	42	40000	M
5432	HFKAFD	XWGRGOCBLD	5814890198 Dell Way	\N	PHJCYNZ	SD	28707	US	1	XWGRGOCBLD@dell.com	5814890198	2	6161707317456604	2012/09	user5432	password	44	20000	M
5433	UFDXCZ	DTGRWHDZXK	6853692030 Dell Way	\N	JZJWYEB	MS	60292	US	1	DTGRWHDZXK@dell.com	6853692030	2	3577931471634656	2008/07	user5433	password	34	80000	M
5434	JRVJVP	QNLXQLVBUV	4993093295 Dell Way	\N	LRTPTGE	MA	66260	US	1	QNLXQLVBUV@dell.com	4993093295	3	2499679302796721	2011/03	user5434	password	84	20000	M
5435	TLRJBF	VYWGUXAPIS	4673844796 Dell Way	\N	JYLQCVG	NC	29585	US	1	VYWGUXAPIS@dell.com	4673844796	2	4653536840807647	2009/04	user5435	password	37	20000	M
5436	YLSEGR	AMLXNBGFKE	1724698044 Dell Way	\N	QAGLGUR	NY	10382	US	1	AMLXNBGFKE@dell.com	1724698044	5	3337202843744308	2009/01	user5436	password	86	40000	M
5437	RMTIMG	UKTVQZGVPG	2318734754 Dell Way	\N	CBNWTFX	TN	26848	US	1	UKTVQZGVPG@dell.com	2318734754	1	3306974922306836	2008/06	user5437	password	73	80000	M
5438	NCKTWU	NSLMZGCGIE	4604430740 Dell Way	\N	TFXYCSD	ID	91321	US	1	NSLMZGCGIE@dell.com	4604430740	2	4441620787139982	2008/02	user5438	password	41	80000	F
5439	TLBNYU	ZKTGNZORTU	6287921546 Dell Way	\N	OSXHWEF	IA	55815	US	1	ZKTGNZORTU@dell.com	6287921546	3	6379121061414481	2012/02	user5439	password	74	80000	M
5440	VELPEW	JKJIZACUPU	9605139291 Dell Way	\N	RXQWCXJ	OH	36684	US	1	JKJIZACUPU@dell.com	9605139291	4	4427144842222333	2011/04	user5440	password	82	60000	F
5441	IEPENA	OWZOYTETLB	9470823442 Dell Way	\N	JHEGQWO	NH	52182	US	1	OWZOYTETLB@dell.com	9470823442	2	7480236954055727	2012/11	user5441	password	29	20000	F
5442	TJOTXK	TMJMQCXSME	9396565907 Dell Way	\N	WTVTHLF	IA	77132	US	1	TMJMQCXSME@dell.com	9396565907	1	6604738035704941	2008/03	user5442	password	66	100000	M
5443	FPMQIY	ZVPCTHPYEI	5956032713 Dell Way	\N	TXQEDWY	AZ	96319	US	1	ZVPCTHPYEI@dell.com	5956032713	1	2790244321338832	2009/01	user5443	password	75	60000	M
5444	HBYFBU	UENCTLHCFE	7823887126 Dell Way	\N	SKIPIJO	UT	57248	US	1	UENCTLHCFE@dell.com	7823887126	1	5738461746368558	2010/07	user5444	password	28	100000	M
5445	CAQWVU	KYOVFQAKJL	2220401057 Dell Way	\N	SZTCNPP	IL	70967	US	1	KYOVFQAKJL@dell.com	2220401057	5	2654314109124243	2009/08	user5445	password	73	40000	M
5446	KGNFQM	TMRKNCTYUS	2123743426 Dell Way	\N	RWGGMNY	NJ	41988	US	1	TMRKNCTYUS@dell.com	2123743426	5	9976257727015764	2012/04	user5446	password	67	40000	F
5447	FMDRGP	JQCLKAFDRC	3377411181 Dell Way	\N	JYOXWEG	AK	16697	US	1	JQCLKAFDRC@dell.com	3377411181	5	3977047186344862	2012/02	user5447	password	78	20000	M
5448	YUWNDN	QPXQUAHWKG	1274597723 Dell Way	\N	LIDQPDS	TX	10844	US	1	QPXQUAHWKG@dell.com	1274597723	5	2505279755219817	2012/12	user5448	password	76	100000	M
5449	RIXEYM	BPGCXDNDPW	6066246048 Dell Way	\N	GFLKXIK	WA	20342	US	1	BPGCXDNDPW@dell.com	6066246048	4	1508546506520360	2009/08	user5449	password	76	20000	M
5450	SEXEGM	LJJPXNETUK	7221804325 Dell Way	\N	FEHNOGQ	CT	13197	US	1	LJJPXNETUK@dell.com	7221804325	3	6721854081377388	2010/07	user5450	password	59	40000	M
5451	MKZYVI	ILGWQZQAFV	2956939014 Dell Way	\N	HSJOJNP	AR	98966	US	1	ILGWQZQAFV@dell.com	2956939014	3	5518808864988387	2011/09	user5451	password	33	40000	F
5452	EFZNOK	TKATBAYWIQ	3069317863 Dell Way	\N	GWZTLAS	NY	60889	US	1	TKATBAYWIQ@dell.com	3069317863	3	3735727764200419	2010/09	user5452	password	49	80000	M
5453	KDNUWX	VPZVNVEECB	1492009531 Dell Way	\N	EVNEOFT	RI	69772	US	1	VPZVNVEECB@dell.com	1492009531	2	4555103034712374	2010/10	user5453	password	43	100000	M
5454	WRVTMK	TIYPNCROGM	4083934871 Dell Way	\N	CLAHFVY	IA	12578	US	1	TIYPNCROGM@dell.com	4083934871	4	8682423792313785	2011/08	user5454	password	76	60000	F
5455	PHUABD	YQQBHFIUHT	5661199286 Dell Way	\N	VPZQNFR	UT	95480	US	1	YQQBHFIUHT@dell.com	5661199286	3	6083041567821056	2009/02	user5455	password	80	100000	F
5456	QYLUXC	KZJQHEYBZN	7869868251 Dell Way	\N	AQBGHYF	SD	57173	US	1	KZJQHEYBZN@dell.com	7869868251	1	6629245806951076	2011/01	user5456	password	20	40000	F
5457	MBXOMX	YCFCBGCPHS	8010152917 Dell Way	\N	ROAQTVD	MS	94066	US	1	YCFCBGCPHS@dell.com	8010152917	1	9879425581078976	2012/05	user5457	password	90	40000	F
5458	XVXUUA	ZXCGZROSJC	4937992126 Dell Way	\N	SZWNDJL	VT	53622	US	1	ZXCGZROSJC@dell.com	4937992126	4	8949228068348021	2010/01	user5458	password	41	40000	M
5459	GDQGDN	IKNAYFJBXJ	6654452687 Dell Way	\N	XLMGWKT	KS	19763	US	1	IKNAYFJBXJ@dell.com	6654452687	4	2013735469896346	2012/02	user5459	password	88	20000	F
5460	PMJDVT	QVSVFUTORE	6771046959 Dell Way	\N	AYBKRKN	IN	23417	US	1	QVSVFUTORE@dell.com	6771046959	2	3138403500430286	2011/06	user5460	password	52	40000	M
5461	VITPYO	IUTCOITTJS	6473805625 Dell Way	\N	VTKFHSJ	WA	97238	US	1	IUTCOITTJS@dell.com	6473805625	3	4923117915634066	2008/09	user5461	password	44	100000	F
5462	CNARVV	LXJTRDCJYW	8721886052 Dell Way	\N	TEELNCK	DC	68068	US	1	LXJTRDCJYW@dell.com	8721886052	2	4481333888135851	2009/02	user5462	password	50	40000	M
5463	MZLHLI	REZUHJSECW	5176341023 Dell Way	\N	IOKLZOC	TN	79004	US	1	REZUHJSECW@dell.com	5176341023	1	8998052436392755	2012/05	user5463	password	55	40000	F
5464	YRVHIA	GCHQVLTSUH	3788271291 Dell Way	\N	CFHRHDK	PA	26860	US	1	GCHQVLTSUH@dell.com	3788271291	4	6195655701681972	2012/01	user5464	password	88	80000	M
5465	UBBUIE	CYZNRRIZUN	2245469745 Dell Way	\N	GLVJWPO	DE	32921	US	1	CYZNRRIZUN@dell.com	2245469745	5	3813626335002482	2008/09	user5465	password	21	100000	M
5466	CRCGTB	GHSXPRRDYC	1872055142 Dell Way	\N	YIYNWCU	AK	17494	US	1	GHSXPRRDYC@dell.com	1872055142	1	8456207457464189	2008/12	user5466	password	63	40000	M
5467	SMKTSR	MQGEHJCKIK	4328572382 Dell Way	\N	JWHLQHO	OR	45903	US	1	MQGEHJCKIK@dell.com	4328572382	5	4488871528301388	2012/02	user5467	password	20	80000	M
5468	LMICYZ	ICHSFRAPAW	9651611324 Dell Way	\N	XMNEAGO	MD	19862	US	1	ICHSFRAPAW@dell.com	9651611324	2	2949233094695955	2012/02	user5468	password	77	60000	M
5469	DNNDWP	KOUBPKCMHP	5919926618 Dell Way	\N	ZMPFBAI	AK	45178	US	1	KOUBPKCMHP@dell.com	5919926618	1	5347011001314968	2009/06	user5469	password	21	60000	M
5470	OQUDAJ	YCYJEKRTKD	3204626122 Dell Way	\N	JQEJYET	MS	26038	US	1	YCYJEKRTKD@dell.com	3204626122	5	6474294399376959	2009/05	user5470	password	58	100000	F
5471	JZBSYD	QHIBYBMBLC	2739844176 Dell Way	\N	GUAKONP	SD	44733	US	1	QHIBYBMBLC@dell.com	2739844176	1	7893473191652448	2011/12	user5471	password	75	20000	M
5472	VUVYLC	GNBIZDTBJO	8012180742 Dell Way	\N	CTDQIYA	NC	13319	US	1	GNBIZDTBJO@dell.com	8012180742	2	9679141802713276	2010/05	user5472	password	81	40000	F
5473	SIQVPD	WYDZRFIGHC	3902555641 Dell Way	\N	JYLIYZJ	OK	32933	US	1	WYDZRFIGHC@dell.com	3902555641	2	6661182429641486	2008/09	user5473	password	76	100000	F
5474	KSPOON	ROFXXMEZWD	3502966730 Dell Way	\N	KEBKOUQ	TX	15692	US	1	ROFXXMEZWD@dell.com	3502966730	1	7585669205058367	2008/12	user5474	password	71	60000	M
5475	JBFWTT	CQRPVQLYBQ	6347896301 Dell Way	\N	ALEUCAW	MA	17356	US	1	CQRPVQLYBQ@dell.com	6347896301	3	1210763986222446	2009/12	user5475	password	66	80000	F
5476	WOUQRL	HGGYSFAIGL	6756912271 Dell Way	\N	NBONXYQ	MS	46889	US	1	HGGYSFAIGL@dell.com	6756912271	5	4349490809254348	2009/07	user5476	password	47	20000	F
5477	EVTPDA	WCSCCBJOOK	8550896116 Dell Way	\N	CCHBSUM	LA	66768	US	1	WCSCCBJOOK@dell.com	8550896116	4	2307931042741984	2009/11	user5477	password	34	60000	M
5478	ZAVZXX	SAZUJNJTQL	6637075698 Dell Way	\N	BREWEOM	WY	28775	US	1	SAZUJNJTQL@dell.com	6637075698	2	1556589781772345	2012/08	user5478	password	72	100000	M
5479	OVPMOP	LIZZSSPEUH	2359476277 Dell Way	\N	IQLWCLC	OR	72044	US	1	LIZZSSPEUH@dell.com	2359476277	3	4090130920521915	2012/06	user5479	password	20	60000	F
5480	QYUGJD	FJVYZZSGII	2929969771 Dell Way	\N	SFLEHFW	MN	80769	US	1	FJVYZZSGII@dell.com	2929969771	2	2870104345493018	2009/10	user5480	password	51	100000	M
5481	GCDKHM	GGMFYTOHLT	9460084019 Dell Way	\N	TQBYNNT	OR	88058	US	1	GGMFYTOHLT@dell.com	9460084019	5	7161224858369679	2009/11	user5481	password	49	80000	M
5482	OBGBHM	NNKGBSSVLJ	9646151805 Dell Way	\N	XKWKDPH	AZ	62417	US	1	NNKGBSSVLJ@dell.com	9646151805	3	4758249253965914	2009/02	user5482	password	43	100000	F
5483	PBLBOZ	MVAEOWQYTA	4931544955 Dell Way	\N	VEELLGA	MA	73444	US	1	MVAEOWQYTA@dell.com	4931544955	4	8479046718683095	2011/10	user5483	password	18	40000	M
5484	MKJLWF	MBUIRSBSOF	6638877715 Dell Way	\N	WZQCABU	MI	84680	US	1	MBUIRSBSOF@dell.com	6638877715	2	6298286372795702	2011/08	user5484	password	46	20000	F
5485	TOXZAY	TIPMKHAPEA	7489166090 Dell Way	\N	GGAHBLD	NY	71805	US	1	TIPMKHAPEA@dell.com	7489166090	2	3542619485873729	2008/05	user5485	password	39	100000	M
5486	EVZDPH	TBRBCHFDOL	6070156529 Dell Way	\N	DWNPZEH	OK	54728	US	1	TBRBCHFDOL@dell.com	6070156529	5	9221077252645046	2012/09	user5486	password	81	20000	M
5487	VEDDXF	VYHCDKRPON	7437700383 Dell Way	\N	DDNHLGU	WY	14759	US	1	VYHCDKRPON@dell.com	7437700383	5	7673161765094847	2010/11	user5487	password	37	60000	F
5488	KOZPJX	XMBIDRWRUA	2990410078 Dell Way	\N	FCLLXLM	NJ	37718	US	1	XMBIDRWRUA@dell.com	2990410078	2	2852680443320423	2010/08	user5488	password	37	100000	F
5489	GMOEJB	GSEXPWSPBV	1365884067 Dell Way	\N	BMSNZIV	FL	59315	US	1	GSEXPWSPBV@dell.com	1365884067	4	2629967869725078	2009/07	user5489	password	45	60000	F
5490	YSLZYD	EWSAPICKKO	2610554455 Dell Way	\N	CYOLTSZ	SD	46821	US	1	EWSAPICKKO@dell.com	2610554455	1	9779776386450976	2010/09	user5490	password	19	60000	F
5491	LLJPPF	IQUQSEBHHZ	9542695198 Dell Way	\N	VTTOTOZ	WA	69887	US	1	IQUQSEBHHZ@dell.com	9542695198	3	4099501896649599	2012/12	user5491	password	72	60000	F
5492	CAAIIQ	DZJIARQZMJ	3665995446 Dell Way	\N	TBDHABY	WY	57334	US	1	DZJIARQZMJ@dell.com	3665995446	5	5331362214405090	2008/05	user5492	password	82	20000	F
5493	XMTOPS	XXTOOTBXMD	1803689091 Dell Way	\N	AUECSDP	AL	19385	US	1	XXTOOTBXMD@dell.com	1803689091	1	5422260060906410	2012/03	user5493	password	83	100000	M
5494	QKHJIF	CXTWZRICRC	1020354479 Dell Way	\N	GUVKJWN	MN	92754	US	1	CXTWZRICRC@dell.com	1020354479	3	2148865440860390	2012/04	user5494	password	77	60000	M
5495	CXBHAY	AWXRFAJIHD	1717500911 Dell Way	\N	ERNAFZY	GA	48740	US	1	AWXRFAJIHD@dell.com	1717500911	1	7693382716737688	2012/08	user5495	password	52	100000	M
5496	NHPMHM	KZSLJASNFK	2796844998 Dell Way	\N	AGPAFUL	ID	89551	US	1	KZSLJASNFK@dell.com	2796844998	1	5797591479960830	2011/02	user5496	password	25	40000	F
5497	RRSECS	WNCXFPCPQI	4575745394 Dell Way	\N	FRNZCVW	IN	97526	US	1	WNCXFPCPQI@dell.com	4575745394	5	2026754778344184	2010/03	user5497	password	56	20000	M
5498	GIZYEM	ACSQEIGNNX	9576285914 Dell Way	\N	BNAWJIV	PA	38613	US	1	ACSQEIGNNX@dell.com	9576285914	2	5531201165169478	2010/06	user5498	password	45	80000	M
5499	IRZVSB	NIFWPTJNUW	7214671355 Dell Way	\N	NRGWNAE	MN	34011	US	1	NIFWPTJNUW@dell.com	7214671355	5	7327900289557875	2008/08	user5499	password	52	60000	F
5500	LGBMUK	SQZMANHXBY	2164724584 Dell Way	\N	DXLECXL	SC	87244	US	1	SQZMANHXBY@dell.com	2164724584	5	5718444043304772	2011/04	user5500	password	81	20000	M
5501	YOHIGX	ISYVAVWYZU	7256465473 Dell Way	\N	KDWIORE	OH	57104	US	1	ISYVAVWYZU@dell.com	7256465473	2	8081523754168303	2010/05	user5501	password	38	60000	M
5502	OVEMDW	KZXGVVFQFJ	5264456798 Dell Way	\N	MNXESPR	MD	92514	US	1	KZXGVVFQFJ@dell.com	5264456798	5	3425267824903131	2011/06	user5502	password	29	40000	F
5503	IUKFFJ	CLFXQVDAIR	7511807593 Dell Way	\N	XMKNEUL	NM	78766	US	1	CLFXQVDAIR@dell.com	7511807593	3	3001482052728534	2012/09	user5503	password	54	40000	M
5504	XKSHNE	MKUHOVQGTC	4815505963 Dell Way	\N	QGHLSXF	MI	38346	US	1	MKUHOVQGTC@dell.com	4815505963	2	1364056900143623	2012/07	user5504	password	59	100000	M
5505	HCLLPW	GXLBNSUPIB	2344417354 Dell Way	\N	WUUUZFC	MD	60060	US	1	GXLBNSUPIB@dell.com	2344417354	2	1883370480965823	2011/02	user5505	password	21	100000	F
5506	NLVKRS	VTFONVWPSR	3137621996 Dell Way	\N	JNQPQBD	RI	42722	US	1	VTFONVWPSR@dell.com	3137621996	3	5580828213598580	2009/06	user5506	password	73	100000	M
5507	PFPHBI	NPWIMLBDVO	7063923950 Dell Way	\N	TKEUNYE	RI	47911	US	1	NPWIMLBDVO@dell.com	7063923950	1	9056602779310198	2010/11	user5507	password	76	20000	F
5508	KHCTVR	QEDBFHWUAH	2928337609 Dell Way	\N	YVVXZPI	NY	68491	US	1	QEDBFHWUAH@dell.com	2928337609	1	5656390500720591	2008/02	user5508	password	60	60000	F
5509	REFJUJ	NWPUTJVAIR	6248269406 Dell Way	\N	VFRKNIB	OR	48215	US	1	NWPUTJVAIR@dell.com	6248269406	4	5767463181633503	2008/03	user5509	password	86	100000	F
5510	DFENTA	COTLJUTAPZ	9684702382 Dell Way	\N	RANACGL	NV	10363	US	1	COTLJUTAPZ@dell.com	9684702382	5	2755369590129703	2012/09	user5510	password	58	20000	M
5511	SORTRF	MDOGXPWWHW	8223851236 Dell Way	\N	JHYPTQP	OH	51149	US	1	MDOGXPWWHW@dell.com	8223851236	3	2275475701782852	2009/08	user5511	password	21	20000	F
5512	SVWXHA	MOXCKTKHCS	5264948112 Dell Way	\N	GSLWIDI	CT	75589	US	1	MOXCKTKHCS@dell.com	5264948112	3	4378960595931858	2010/07	user5512	password	60	40000	F
5513	MERMRG	JTQCEYFWEY	5598695132 Dell Way	\N	HBHKKKD	UT	90475	US	1	JTQCEYFWEY@dell.com	5598695132	2	5201212384738028	2008/08	user5513	password	80	60000	M
5514	NALUKF	KNJJTFORNQ	7474297210 Dell Way	\N	YXAJBXG	ND	35717	US	1	KNJJTFORNQ@dell.com	7474297210	4	9329299629665912	2010/03	user5514	password	71	20000	F
5515	EWRKHE	URXAFPNVOL	9488497162 Dell Way	\N	VXMTEAA	UT	72417	US	1	URXAFPNVOL@dell.com	9488497162	3	9254794254433364	2011/07	user5515	password	30	100000	F
5516	VHSZBJ	XCPMPKAAGY	2436518649 Dell Way	\N	NZCOAZG	WI	46562	US	1	XCPMPKAAGY@dell.com	2436518649	4	9587346258573236	2009/06	user5516	password	45	20000	M
5517	CEVMBX	BOMMPNSNAS	9465455646 Dell Way	\N	QPSPVRZ	WY	36786	US	1	BOMMPNSNAS@dell.com	9465455646	2	8002093750983477	2009/06	user5517	password	56	60000	M
5518	IWTGYH	SKXGDLHVBW	3856998878 Dell Way	\N	OQRGPRO	ND	10082	US	1	SKXGDLHVBW@dell.com	3856998878	5	5455028604250402	2012/04	user5518	password	29	20000	F
5519	XKCFDM	CJPNRLONAE	4541753055 Dell Way	\N	FGUXUJX	CO	29225	US	1	CJPNRLONAE@dell.com	4541753055	5	5418371100910008	2010/02	user5519	password	65	60000	M
5520	TQSFTC	VGTHVHHANO	8695776386 Dell Way	\N	UKJDHMJ	OH	49500	US	1	VGTHVHHANO@dell.com	8695776386	2	6300107764545829	2010/09	user5520	password	29	40000	F
5521	WLCYHJ	SOEZWEMLZX	3609578457 Dell Way	\N	UDFGMXS	LA	22879	US	1	SOEZWEMLZX@dell.com	3609578457	5	8566557748243214	2010/02	user5521	password	31	40000	M
5522	HGVQZK	UZGZMRYJMC	5112812148 Dell Way	\N	PTPMLYQ	OR	82228	US	1	UZGZMRYJMC@dell.com	5112812148	1	9036419680342080	2011/06	user5522	password	49	100000	M
5523	GOTRIS	YIEPHOCJDV	6401917030 Dell Way	\N	YPGXFZS	NY	25506	US	1	YIEPHOCJDV@dell.com	6401917030	2	6932857354171575	2008/03	user5523	password	48	40000	M
5524	DZDWXL	ANSPPBSLAI	5681039213 Dell Way	\N	RYNRQFW	HI	57842	US	1	ANSPPBSLAI@dell.com	5681039213	2	7934007253963501	2012/07	user5524	password	58	20000	M
5525	RYLCYY	UNNWGZWOQV	6476332630 Dell Way	\N	CILHFRV	OK	95554	US	1	UNNWGZWOQV@dell.com	6476332630	4	5743227931205184	2008/09	user5525	password	23	100000	M
5526	NYPLSD	ZPKYMYPHBY	8892906976 Dell Way	\N	SJDKFWJ	SD	57069	US	1	ZPKYMYPHBY@dell.com	8892906976	5	3309634873177856	2012/10	user5526	password	84	60000	M
5527	NXLRWA	BVMAKTCJML	2339593028 Dell Way	\N	NXQJGLX	CO	46744	US	1	BVMAKTCJML@dell.com	2339593028	1	2805050022900104	2008/07	user5527	password	85	60000	F
5528	JHHJJC	WKNQMXDXKA	6452549986 Dell Way	\N	OTGZQJK	SC	47474	US	1	WKNQMXDXKA@dell.com	6452549986	5	9351069594733418	2010/06	user5528	password	42	100000	M
5529	QGCTDM	GTYDXWOXKH	8554191406 Dell Way	\N	DKYMVTX	ME	65696	US	1	GTYDXWOXKH@dell.com	8554191406	5	1741772480309009	2008/10	user5529	password	78	80000	F
5530	XNFKUZ	JYWFMUQUXB	2639283722 Dell Way	\N	SKWMIHC	DE	33092	US	1	JYWFMUQUXB@dell.com	2639283722	2	1805623844731599	2008/02	user5530	password	31	100000	M
5531	KILKRK	HXWBNQZPJJ	2062722207 Dell Way	\N	MWRUYWA	DC	26363	US	1	HXWBNQZPJJ@dell.com	2062722207	1	3822386077605188	2009/01	user5531	password	89	80000	F
5532	LCBVKZ	RLMIKCSUOO	8300090231 Dell Way	\N	MINIJRM	MO	82917	US	1	RLMIKCSUOO@dell.com	8300090231	4	8909912181552500	2011/06	user5532	password	37	40000	M
5533	IAZHSL	UBVXUPLICU	3033126767 Dell Way	\N	WKDNXPJ	OH	44950	US	1	UBVXUPLICU@dell.com	3033126767	3	8886437961831690	2010/09	user5533	password	52	100000	M
5534	MDMXYN	SVHIHQKBNV	1804062895 Dell Way	\N	FBSVKKF	NJ	91692	US	1	SVHIHQKBNV@dell.com	1804062895	1	6522442691493780	2010/12	user5534	password	43	20000	F
5535	VXBIQX	QZFHKHUGMW	8952383251 Dell Way	\N	YIGJNWH	NJ	99877	US	1	QZFHKHUGMW@dell.com	8952383251	1	9635518799535932	2009/03	user5535	password	22	20000	F
5536	DKUABU	FIEMDLZZJH	1616985346 Dell Way	\N	GTVCALC	VA	66408	US	1	FIEMDLZZJH@dell.com	1616985346	1	8523991677910090	2008/03	user5536	password	88	40000	M
5537	THQNNY	SACDZBNHHG	1263161559 Dell Way	\N	DKGONDF	NE	33408	US	1	SACDZBNHHG@dell.com	1263161559	4	4959196841344238	2012/12	user5537	password	19	80000	F
5538	QHTPZT	RDTSQAAXDK	9732287410 Dell Way	\N	DSYHXNN	WI	30503	US	1	RDTSQAAXDK@dell.com	9732287410	5	2783356266096234	2012/09	user5538	password	50	80000	M
5539	FFYYWB	SPSSPPWASP	9137652015 Dell Way	\N	ZANMNLS	MS	45524	US	1	SPSSPPWASP@dell.com	9137652015	3	1714661549776792	2009/02	user5539	password	20	60000	F
5540	ZNFBFU	TXKJULCKKC	8588945002 Dell Way	\N	XXPJPCT	MS	64225	US	1	TXKJULCKKC@dell.com	8588945002	5	7472316424362362	2012/05	user5540	password	21	100000	M
5541	GXCBRA	MAVYCFJEDG	2966735040 Dell Way	\N	UNWXHJM	CT	30030	US	1	MAVYCFJEDG@dell.com	2966735040	5	6694419370498509	2009/11	user5541	password	57	60000	M
5542	QPKRBK	NANTJRWPMK	7149071589 Dell Way	\N	MJRVWUB	AZ	80554	US	1	NANTJRWPMK@dell.com	7149071589	2	6714618026278914	2009/11	user5542	password	46	100000	F
5543	UONFBN	SVWKRMWCYF	9642740638 Dell Way	\N	TUCOVEI	MT	55138	US	1	SVWKRMWCYF@dell.com	9642740638	4	4331614066381008	2009/08	user5543	password	78	20000	F
5544	IJGWBB	TMTGIVEOPZ	6948265215 Dell Way	\N	QDUUMIH	ME	15679	US	1	TMTGIVEOPZ@dell.com	6948265215	4	7188297022599728	2010/11	user5544	password	81	100000	F
5545	DSIFLV	YRDUWSKVIO	7431418344 Dell Way	\N	QDAZKLA	AZ	28957	US	1	YRDUWSKVIO@dell.com	7431418344	3	2138423555064946	2010/05	user5545	password	46	80000	F
5546	TXNOWF	SRCKCXTQOW	4741476068 Dell Way	\N	QNHCOJH	ID	94469	US	1	SRCKCXTQOW@dell.com	4741476068	5	3977108613122255	2012/07	user5546	password	48	60000	F
5547	YCJEVB	GGDEZUSWKG	8352318771 Dell Way	\N	EMVOUCM	GA	95049	US	1	GGDEZUSWKG@dell.com	8352318771	1	5713188363704831	2009/07	user5547	password	19	20000	M
5548	KJNLPT	PTTJMQUTUH	2005818075 Dell Way	\N	OIBQVGP	NM	34471	US	1	PTTJMQUTUH@dell.com	2005818075	5	8548853395972402	2008/01	user5548	password	56	60000	F
5549	AZAUPT	NYGDTZYAOH	4986825802 Dell Way	\N	BECIUTP	VA	66358	US	1	NYGDTZYAOH@dell.com	4986825802	1	7236156067810953	2012/07	user5549	password	25	100000	M
5550	DUCWHB	DLUDJURRWW	8443082692 Dell Way	\N	TFQNVND	IA	59825	US	1	DLUDJURRWW@dell.com	8443082692	2	1952127303928136	2012/03	user5550	password	64	20000	M
5551	TYHVBS	PECKWTHSNM	5869196834 Dell Way	\N	JAHWENL	WY	77467	US	1	PECKWTHSNM@dell.com	5869196834	5	9621338555589320	2008/12	user5551	password	86	100000	M
5552	FTZYIE	ATAUASIMCI	1013010000 Dell Way	\N	TYMHKMB	WA	46361	US	1	ATAUASIMCI@dell.com	1013010000	1	4425561580341309	2012/01	user5552	password	39	20000	M
5553	GCDLDW	LXWEFIGOCF	3905655608 Dell Way	\N	BKPNLOY	MI	69327	US	1	LXWEFIGOCF@dell.com	3905655608	2	7358909454662354	2011/07	user5553	password	53	100000	M
5554	PITMTR	IYXRELTKND	9111971150 Dell Way	\N	ZBONZAF	KS	44312	US	1	IYXRELTKND@dell.com	9111971150	5	9192639911081644	2009/10	user5554	password	56	20000	F
5555	HMXYUV	VMZHFJUJJW	3117367018 Dell Way	\N	YXWYCEI	AK	19032	US	1	VMZHFJUJJW@dell.com	3117367018	2	9241335788741708	2011/05	user5555	password	21	20000	M
5556	YZRTVD	TDJCYSMURK	8412360041 Dell Way	\N	QPMUYNX	DE	90984	US	1	TDJCYSMURK@dell.com	8412360041	5	3742227272130549	2012/12	user5556	password	31	80000	M
5557	WOUAHX	JKVCWQTHGJ	5300317007 Dell Way	\N	UBHHZLE	SC	43192	US	1	JKVCWQTHGJ@dell.com	5300317007	4	4071803524624556	2011/06	user5557	password	40	60000	F
5558	COHAXR	VAOLTVSCPU	5890583339 Dell Way	\N	KWUVBOF	MT	31913	US	1	VAOLTVSCPU@dell.com	5890583339	1	7398913944140077	2012/09	user5558	password	70	100000	F
5559	AYERUE	GGYBYBRTLO	1505386650 Dell Way	\N	NHPCMCI	AL	37251	US	1	GGYBYBRTLO@dell.com	1505386650	5	1180372051894664	2011/10	user5559	password	38	80000	M
5560	LMNQST	OUSQLMBZAI	1171789787 Dell Way	\N	PCVSLVZ	MS	73439	US	1	OUSQLMBZAI@dell.com	1171789787	2	5594289436936379	2009/01	user5560	password	36	80000	M
5561	UJGNYA	GOLSQLSYAV	8375737310 Dell Way	\N	TSHPSUI	PA	14756	US	1	GOLSQLSYAV@dell.com	8375737310	1	2041646926663816	2008/10	user5561	password	65	100000	F
5562	WJCXQR	JIHVBFVWZO	1848773857 Dell Way	\N	DPHYXBZ	OR	17991	US	1	JIHVBFVWZO@dell.com	1848773857	5	8909264063462616	2011/08	user5562	password	21	80000	F
5563	DNQUWZ	CRBINYICCX	4706946591 Dell Way	\N	KAVLZON	CA	41553	US	1	CRBINYICCX@dell.com	4706946591	5	9998755224514754	2010/06	user5563	password	19	80000	M
5564	RKWRMN	SUBQCETAOT	7626939906 Dell Way	\N	VATKOVT	WI	67984	US	1	SUBQCETAOT@dell.com	7626939906	3	1833833680488169	2011/01	user5564	password	22	60000	F
5565	XCXLUS	NLVREVGYRG	2937306895 Dell Way	\N	RBUMUTD	NC	25459	US	1	NLVREVGYRG@dell.com	2937306895	2	2654165569227189	2009/09	user5565	password	62	20000	M
5566	NQQFDC	BVGXBEOIWQ	3283209544 Dell Way	\N	DILXLZB	NV	34373	US	1	BVGXBEOIWQ@dell.com	3283209544	5	1029858363326638	2012/02	user5566	password	78	40000	M
5567	MPXOQT	VNUZCDWSHE	4657202573 Dell Way	\N	EEQDGHK	MS	30723	US	1	VNUZCDWSHE@dell.com	4657202573	2	4224465754814446	2009/09	user5567	password	26	80000	F
5568	AGYTBM	OBPSXHZBMD	6180154264 Dell Way	\N	SPKZAXF	MD	31790	US	1	OBPSXHZBMD@dell.com	6180154264	4	9692818294279278	2011/05	user5568	password	38	80000	M
5569	GMQSAS	ISPQSRCWJR	4040164656 Dell Way	\N	GJRDOCJ	DC	76840	US	1	ISPQSRCWJR@dell.com	4040164656	5	1790076063945889	2011/07	user5569	password	67	100000	F
5570	IPBAXU	PNNHPJQHPA	9051222879 Dell Way	\N	ZSPBCSU	MI	61514	US	1	PNNHPJQHPA@dell.com	9051222879	1	2200203948188573	2010/12	user5570	password	30	100000	M
5571	GXKANX	NUNWLUMLTF	5288556279 Dell Way	\N	BVHUQTI	NC	80846	US	1	NUNWLUMLTF@dell.com	5288556279	1	7345782581251115	2011/12	user5571	password	33	100000	M
5572	QXKOLF	BIRWUDQAEL	5767748141 Dell Way	\N	HYCAHPV	RI	74576	US	1	BIRWUDQAEL@dell.com	5767748141	3	7405723678879441	2011/04	user5572	password	62	40000	F
5573	AXQGYZ	YVUBLUGWCF	1079847673 Dell Way	\N	ZDMPYGH	MO	71396	US	1	YVUBLUGWCF@dell.com	1079847673	2	9762333717197180	2011/07	user5573	password	30	80000	F
5574	VXLUWG	OYRIEOKKNN	8310159328 Dell Way	\N	XCMEKYV	ME	25441	US	1	OYRIEOKKNN@dell.com	8310159328	1	7768041065894068	2012/09	user5574	password	35	100000	M
5575	RPMYDK	PMPEWZSKWV	7905598050 Dell Way	\N	XAFVWQA	NY	70573	US	1	PMPEWZSKWV@dell.com	7905598050	4	4317526731640101	2008/06	user5575	password	89	80000	F
5576	LPEWFQ	LKNKCYGXVH	8350573206 Dell Way	\N	DRDURUL	MI	51009	US	1	LKNKCYGXVH@dell.com	8350573206	3	9189336623996496	2011/02	user5576	password	87	40000	M
5577	DCYTNI	GYLEFJAMNR	7976424113 Dell Way	\N	PHIKSUW	NC	30096	US	1	GYLEFJAMNR@dell.com	7976424113	2	4088273742236197	2011/08	user5577	password	22	100000	M
5578	APFJWD	UBIEBVRSKY	4688903447 Dell Way	\N	BVRVRFB	MN	58075	US	1	UBIEBVRSKY@dell.com	4688903447	1	2097544791176915	2010/01	user5578	password	76	60000	M
5579	AVMEQN	MUPHLISJJO	8978445450 Dell Way	\N	AFGFHST	OH	90030	US	1	MUPHLISJJO@dell.com	8978445450	1	9241550839040428	2011/08	user5579	password	57	80000	M
5580	AWDOJY	DRKLKTVYUB	7171092864 Dell Way	\N	EAIWUAU	NY	27940	US	1	DRKLKTVYUB@dell.com	7171092864	2	8776486368849874	2009/02	user5580	password	45	40000	M
5581	NUILXA	VJKPEIKFNL	6791592806 Dell Way	\N	OKGPEXU	TX	36024	US	1	VJKPEIKFNL@dell.com	6791592806	1	4389229563064873	2008/04	user5581	password	42	60000	F
5582	RZARVJ	CKOKVUYGIJ	1655727667 Dell Way	\N	MXNKSJS	KY	51758	US	1	CKOKVUYGIJ@dell.com	1655727667	2	8013031267095358	2010/11	user5582	password	81	20000	M
5583	WTRGVC	UGYPFFXORV	7267705459 Dell Way	\N	BCNLUWX	UT	29311	US	1	UGYPFFXORV@dell.com	7267705459	2	1865501449443400	2010/05	user5583	password	88	60000	F
5584	QSYTNE	RCJWAYOVZQ	5854613395 Dell Way	\N	JLLFJHL	AZ	62035	US	1	RCJWAYOVZQ@dell.com	5854613395	4	9366054103244096	2010/02	user5584	password	20	20000	M
5585	ZXHDOK	NLKMZGLQPX	9105299029 Dell Way	\N	CVHKHIZ	SD	97979	US	1	NLKMZGLQPX@dell.com	9105299029	2	1586983023677021	2012/06	user5585	password	80	100000	F
5586	EBXOPI	YBIENZUKBQ	1755746089 Dell Way	\N	SMXBLTA	KY	14391	US	1	YBIENZUKBQ@dell.com	1755746089	2	5559538732748479	2012/03	user5586	password	80	20000	F
5587	TQVCPW	LUJLPUNFMZ	4789680301 Dell Way	\N	DNKWOTX	NM	11759	US	1	LUJLPUNFMZ@dell.com	4789680301	3	2739050695206970	2009/09	user5587	password	48	20000	F
5588	GDYCPS	MAHHNNTMRH	8812052376 Dell Way	\N	XNWRLMR	TX	16790	US	1	MAHHNNTMRH@dell.com	8812052376	1	7779263688251377	2009/02	user5588	password	23	60000	F
5589	AQXSCX	AJLNDYELVS	6720188936 Dell Way	\N	IMDUEZW	AR	21098	US	1	AJLNDYELVS@dell.com	6720188936	2	3564360663294792	2011/11	user5589	password	60	80000	F
5590	MLPKLZ	VZDTEOPWWC	4712412238 Dell Way	\N	ARHAOID	GA	67871	US	1	VZDTEOPWWC@dell.com	4712412238	5	5483209241647274	2012/08	user5590	password	89	60000	F
5591	OWNORM	RLQGBNDDNU	8917997210 Dell Way	\N	LNJTRPJ	AZ	55542	US	1	RLQGBNDDNU@dell.com	8917997210	1	2297448378987610	2012/07	user5591	password	33	60000	F
5592	SZCFQO	WWPJZTXUEL	4592183233 Dell Way	\N	EXCTHEG	FL	30708	US	1	WWPJZTXUEL@dell.com	4592183233	1	7999886862933636	2011/06	user5592	password	31	40000	F
5593	HOCWKY	LUYFRSKDXI	4363685935 Dell Way	\N	FQQJXVP	IL	86792	US	1	LUYFRSKDXI@dell.com	4363685935	5	3976831955835223	2010/03	user5593	password	75	100000	M
5594	WSEVEZ	TJRMUUJCZA	7416291951 Dell Way	\N	SIXNYFJ	IN	19123	US	1	TJRMUUJCZA@dell.com	7416291951	5	4066782291047275	2010/09	user5594	password	27	40000	F
5595	IEPHYZ	YLTSUWRVPA	4222583598 Dell Way	\N	SCZXMHA	GA	24576	US	1	YLTSUWRVPA@dell.com	4222583598	4	9094950870610774	2010/01	user5595	password	43	80000	F
5596	YCFYAQ	STLOLGEMYG	8073137249 Dell Way	\N	LWTSXZX	IA	70468	US	1	STLOLGEMYG@dell.com	8073137249	4	7638115192297847	2008/07	user5596	password	90	20000	M
5597	EAQVTK	GIVMMHLTTI	9020447230 Dell Way	\N	NMFMJMD	CT	27948	US	1	GIVMMHLTTI@dell.com	9020447230	2	7615304437931628	2012/05	user5597	password	44	20000	F
5598	AWDKDM	GPYOBSHJFT	9742524497 Dell Way	\N	ORCAVGG	OR	54930	US	1	GPYOBSHJFT@dell.com	9742524497	4	8710522806737573	2009/09	user5598	password	36	40000	M
5599	KTRWZH	UNIMVRSOGJ	3115867902 Dell Way	\N	QHFWNYJ	MS	60628	US	1	UNIMVRSOGJ@dell.com	3115867902	5	3163221946917474	2010/03	user5599	password	76	100000	M
5600	MTXTNL	BAGTSUZCLH	1640552957 Dell Way	\N	IIVGSIV	WI	22172	US	1	BAGTSUZCLH@dell.com	1640552957	3	3725395421497524	2012/04	user5600	password	34	40000	F
5601	DCOODP	VXHQXKBESK	7650560721 Dell Way	\N	ZZCHVBL	VA	52755	US	1	VXHQXKBESK@dell.com	7650560721	4	8013626549858601	2012/02	user5601	password	77	20000	F
5602	JQIZMF	GCDRDHJOHJ	9554389725 Dell Way	\N	QPESABE	RI	82403	US	1	GCDRDHJOHJ@dell.com	9554389725	4	9064538564067336	2011/10	user5602	password	23	20000	F
5603	KCYQJA	TAEBKSJTJY	7190116000 Dell Way	\N	YBZZFTU	FL	54032	US	1	TAEBKSJTJY@dell.com	7190116000	5	3761960091069341	2011/02	user5603	password	74	20000	F
5604	SUOTOP	XQAQZUZYSA	5300561544 Dell Way	\N	YSGRMLE	FL	45545	US	1	XQAQZUZYSA@dell.com	5300561544	5	5366581181995571	2009/02	user5604	password	67	100000	M
5605	GSMWPC	WFCRFAJGYC	8521134458 Dell Way	\N	NQOYUTJ	IL	73051	US	1	WFCRFAJGYC@dell.com	8521134458	3	8332518998067827	2010/07	user5605	password	71	80000	F
5606	FQVINA	KEFLOMJQZA	5276902898 Dell Way	\N	FYVYHCR	CO	65787	US	1	KEFLOMJQZA@dell.com	5276902898	4	2097194775473326	2009/05	user5606	password	41	60000	F
5607	DTOEDT	KPHWZYVZDU	6480572176 Dell Way	\N	UCBWTEM	HI	82637	US	1	KPHWZYVZDU@dell.com	6480572176	3	2979021519422531	2012/11	user5607	password	37	20000	M
5608	VGTPQI	XNHVIHYDBB	4305499048 Dell Way	\N	EXUIKBD	AK	53078	US	1	XNHVIHYDBB@dell.com	4305499048	5	4070429575629532	2011/01	user5608	password	87	60000	F
5609	SBXBYK	IUTPTWRUAP	5043094952 Dell Way	\N	PJZQNAC	VA	96704	US	1	IUTPTWRUAP@dell.com	5043094952	3	9883080396801234	2009/01	user5609	password	36	20000	F
5610	DDAOMV	HCOETIEJXO	3796052685 Dell Way	\N	JOCJQZI	CO	54633	US	1	HCOETIEJXO@dell.com	3796052685	3	5521406320389361	2010/08	user5610	password	60	80000	M
5611	PGFKOI	YSBHXLFMUT	5639778913 Dell Way	\N	ODKNMMA	RI	98907	US	1	YSBHXLFMUT@dell.com	5639778913	2	6240564560052008	2008/01	user5611	password	41	80000	F
5612	NDWVCO	XJMJOYDHMG	7710369850 Dell Way	\N	RZSEANE	MT	85118	US	1	XJMJOYDHMG@dell.com	7710369850	4	8885884718503804	2008/04	user5612	password	30	60000	F
5613	ALNPJW	BSLZVSMCKM	1340443025 Dell Way	\N	VPMITAE	MS	66900	US	1	BSLZVSMCKM@dell.com	1340443025	3	9583828512113542	2009/02	user5613	password	46	40000	M
5614	XVYUXQ	FXMYJOJWKY	9455914194 Dell Way	\N	ISSJWEZ	VT	76922	US	1	FXMYJOJWKY@dell.com	9455914194	1	9023452771361918	2009/05	user5614	password	52	40000	F
5615	KBDBGA	NFKCOGMNPF	1322157191 Dell Way	\N	FYCKYAD	UT	22796	US	1	NFKCOGMNPF@dell.com	1322157191	2	5681268630549312	2010/06	user5615	password	71	100000	F
5616	WZTWMZ	HPOOBBDHHC	1338321012 Dell Way	\N	JRAJVXN	UT	19840	US	1	HPOOBBDHHC@dell.com	1338321012	2	6111425097566099	2011/04	user5616	password	22	80000	F
5617	VNTUUJ	JILLMSSOBK	2506872195 Dell Way	\N	PLFMZCP	AK	51428	US	1	JILLMSSOBK@dell.com	2506872195	4	7802441280800850	2009/05	user5617	password	19	20000	M
5618	UWTDFC	OROHJDJTSU	3593852083 Dell Way	\N	ZFTBUUN	WV	59437	US	1	OROHJDJTSU@dell.com	3593852083	2	9674825663212688	2009/04	user5618	password	83	20000	F
5619	QGJSVA	GCKKLECGDI	3700584455 Dell Way	\N	AFDUTCI	AL	37111	US	1	GCKKLECGDI@dell.com	3700584455	2	6152926842216403	2008/06	user5619	password	70	100000	M
5620	CNNCUQ	NFBRHIVQIA	7360869315 Dell Way	\N	TDUVMVD	PA	25044	US	1	NFBRHIVQIA@dell.com	7360869315	5	6592643381096423	2010/10	user5620	password	41	60000	F
5621	WQDMDI	OUQWPGFQZI	1245037537 Dell Way	\N	KVUGYOK	NV	56091	US	1	OUQWPGFQZI@dell.com	1245037537	1	3688964480999857	2009/08	user5621	password	63	20000	F
5622	TRIBFD	SBTYHKYPVT	7821450766 Dell Way	\N	KBSYLJL	MO	49514	US	1	SBTYHKYPVT@dell.com	7821450766	5	1236143135931342	2009/01	user5622	password	35	20000	M
5623	OFXSXZ	LWGWUWRNGS	1445883138 Dell Way	\N	FFEPRRA	ME	54666	US	1	LWGWUWRNGS@dell.com	1445883138	4	5785328902304173	2009/12	user5623	password	35	100000	F
5624	DOADAW	KWRGNENGKS	2008131777 Dell Way	\N	LZJCAUP	AZ	62038	US	1	KWRGNENGKS@dell.com	2008131777	2	5557043570093811	2009/03	user5624	password	64	60000	M
5625	RQUOAR	FGFKTLULWU	7153924279 Dell Way	\N	VYUPNWE	NM	29588	US	1	FGFKTLULWU@dell.com	7153924279	5	4792859314009547	2009/06	user5625	password	31	100000	F
5626	ZODQTJ	VDDHYPDSKC	1280975878 Dell Way	\N	NAQKEHP	UT	35347	US	1	VDDHYPDSKC@dell.com	1280975878	1	7912063967902214	2009/03	user5626	password	81	20000	M
5627	ZVLJRP	MYNCCGMFTM	2716066686 Dell Way	\N	WERDTNK	SC	74766	US	1	MYNCCGMFTM@dell.com	2716066686	1	9057816805783660	2008/03	user5627	password	62	20000	F
5628	BLSRXR	EZULMAFZWJ	8059742012 Dell Way	\N	QZDEKXX	NJ	94086	US	1	EZULMAFZWJ@dell.com	8059742012	4	2366204535588622	2009/09	user5628	password	33	60000	F
5629	YDCQIB	KTOKYNGHEG	4629223219 Dell Way	\N	KIRIFHG	AK	96276	US	1	KTOKYNGHEG@dell.com	4629223219	2	7244413223117591	2011/11	user5629	password	80	60000	M
5630	YEHAOA	OZZCGGGNRO	2057326621 Dell Way	\N	EZUMFUL	NM	26332	US	1	OZZCGGGNRO@dell.com	2057326621	2	1361525720451027	2012/10	user5630	password	19	100000	M
5631	IXNJMN	IOTPUHGJLF	2498352891 Dell Way	\N	EXLYIBD	MN	38081	US	1	IOTPUHGJLF@dell.com	2498352891	3	1890769685618579	2008/04	user5631	password	21	60000	F
5632	PWSCFH	WUCDALPGPM	2655050773 Dell Way	\N	SOVURHC	TX	74947	US	1	WUCDALPGPM@dell.com	2655050773	1	1492342657409608	2009/07	user5632	password	39	100000	F
5633	AXQHUL	KXMVMSLZLA	9023510040 Dell Way	\N	VFSCHOV	MO	63681	US	1	KXMVMSLZLA@dell.com	9023510040	4	2391756159719080	2008/07	user5633	password	60	40000	F
5634	FNFRXD	DTQWFPHFLM	2951061632 Dell Way	\N	XOUMJGB	ID	96792	US	1	DTQWFPHFLM@dell.com	2951061632	3	5434344887733460	2012/09	user5634	password	86	20000	F
5635	ESCHVV	XSANZGYMEN	9824631864 Dell Way	\N	GQXNREM	VA	66161	US	1	XSANZGYMEN@dell.com	9824631864	4	3718330105766654	2012/09	user5635	password	54	20000	F
5636	PJGKHY	LVYSULWHRM	3256147551 Dell Way	\N	EFEISBY	NY	78383	US	1	LVYSULWHRM@dell.com	3256147551	4	5474172292742878	2011/09	user5636	password	85	40000	F
5637	ETJDFE	CXYNTGFFKK	7124954376 Dell Way	\N	JTCLRUE	WA	45804	US	1	CXYNTGFFKK@dell.com	7124954376	4	1736072035972029	2011/01	user5637	password	28	80000	M
5638	NYYRAW	QNPWSVHDEA	5727849238 Dell Way	\N	GPSBUQL	MN	37678	US	1	QNPWSVHDEA@dell.com	5727849238	1	3834459228441119	2011/11	user5638	password	23	20000	M
5639	AWVXMJ	MJCHRGMRMC	6760379093 Dell Way	\N	KNWAZJI	MS	48444	US	1	MJCHRGMRMC@dell.com	6760379093	1	3740113347768784	2011/05	user5639	password	26	80000	F
5640	ZQRIDB	LLSRXKDZUR	9605430319 Dell Way	\N	WVQFDDQ	RI	37004	US	1	LLSRXKDZUR@dell.com	9605430319	3	6719865743070841	2008/03	user5640	password	78	20000	M
5641	NJZOUK	HMIRPIMHFH	9853610815 Dell Way	\N	XLLBCFJ	AL	72590	US	1	HMIRPIMHFH@dell.com	9853610815	1	9390602359082552	2012/02	user5641	password	76	40000	M
5642	UWIFEU	OWKXIRCQPN	9032686011 Dell Way	\N	BQPGZQY	WV	78466	US	1	OWKXIRCQPN@dell.com	9032686011	4	9277454754803332	2011/02	user5642	password	51	60000	M
5643	USDPHZ	AEIRGYHUZX	7449261957 Dell Way	\N	KGXAFWU	CO	69645	US	1	AEIRGYHUZX@dell.com	7449261957	5	7803766577038915	2008/04	user5643	password	70	100000	F
5644	WOIVOM	DGTBNOBLYI	6753112888 Dell Way	\N	IZOFURW	MO	52633	US	1	DGTBNOBLYI@dell.com	6753112888	4	8075529582798482	2009/08	user5644	password	78	40000	F
5645	DATQEZ	KGMYIXWQGW	1964724265 Dell Way	\N	EMQWJCI	WY	78955	US	1	KGMYIXWQGW@dell.com	1964724265	2	4469081360381097	2012/07	user5645	password	58	20000	M
5646	HSUGDA	TBIRYZXUDK	7166125258 Dell Way	\N	LZTNITH	ME	19996	US	1	TBIRYZXUDK@dell.com	7166125258	2	7154059881810100	2009/06	user5646	password	39	60000	F
5647	BUHCOJ	LFHKDCONNO	8444957996 Dell Way	\N	HBWAJHD	AR	68997	US	1	LFHKDCONNO@dell.com	8444957996	2	1871446909382939	2008/10	user5647	password	37	20000	M
5648	OHEXSK	FCNHRBVFJX	2071270877 Dell Way	\N	BJGJNHA	KY	62967	US	1	FCNHRBVFJX@dell.com	2071270877	3	4767888161819428	2009/08	user5648	password	21	100000	M
5649	GVRQAU	EILGEQPBSZ	6619212069 Dell Way	\N	ICMQCVF	HI	37277	US	1	EILGEQPBSZ@dell.com	6619212069	4	9707733698189260	2011/07	user5649	password	85	100000	F
5650	POKJST	VYXMOZENHH	1838374832 Dell Way	\N	ZXJVDPD	PA	28820	US	1	VYXMOZENHH@dell.com	1838374832	3	7695158934220672	2008/05	user5650	password	26	80000	M
5651	NZPGVO	EHCDMQLTPJ	6988692857 Dell Way	\N	CLMSOGX	NV	70157	US	1	EHCDMQLTPJ@dell.com	6988692857	4	1059611986391246	2011/04	user5651	password	83	40000	F
5652	NNBCSJ	FWVVHOLRRW	1766369099 Dell Way	\N	EJKKHBC	WI	75972	US	1	FWVVHOLRRW@dell.com	1766369099	4	1094311133492738	2012/01	user5652	password	38	60000	M
5653	JOGSTC	NOKBZCTWGC	1702703914 Dell Way	\N	GRKITJB	TN	17599	US	1	NOKBZCTWGC@dell.com	1702703914	5	1919541683048010	2009/04	user5653	password	65	80000	M
5654	XKQAYE	LAENTBUWIL	8015084355 Dell Way	\N	GQEPSAR	SC	83246	US	1	LAENTBUWIL@dell.com	8015084355	1	1969175759702921	2010/11	user5654	password	88	40000	F
5655	PJFUVF	ZIZACVIOBY	6931051242 Dell Way	\N	SQRTIMO	CO	64822	US	1	ZIZACVIOBY@dell.com	6931051242	3	5175302786286921	2011/11	user5655	password	71	40000	F
5656	YZCEYK	DYNZHBAGUR	4972638539 Dell Way	\N	XOAJCCZ	PA	68975	US	1	DYNZHBAGUR@dell.com	4972638539	2	5948226458858699	2008/08	user5656	password	77	20000	M
5657	XHNILM	VKTXLZSCXH	4772955240 Dell Way	\N	CGJFGDW	NY	55277	US	1	VKTXLZSCXH@dell.com	4772955240	5	1852212440688163	2009/12	user5657	password	67	20000	F
5658	FLSRHD	LFOLYRIFTP	3667059730 Dell Way	\N	OZVSVMF	ID	41805	US	1	LFOLYRIFTP@dell.com	3667059730	3	4008620076347143	2012/08	user5658	password	62	20000	F
5659	IWJMHP	ASNRBTLQIK	6609998006 Dell Way	\N	LAGYFNH	MT	11914	US	1	ASNRBTLQIK@dell.com	6609998006	3	6935613851994277	2009/08	user5659	password	72	60000	M
5660	DAUTBN	GTOAEEIPQJ	1431798863 Dell Way	\N	WOOJWCK	MO	62365	US	1	GTOAEEIPQJ@dell.com	1431798863	4	3150761053431779	2011/04	user5660	password	72	100000	F
5661	ORJCYD	QYHVHXMQTA	2112788313 Dell Way	\N	FCXHMJX	NC	16768	US	1	QYHVHXMQTA@dell.com	2112788313	2	4253319312352687	2012/04	user5661	password	68	60000	M
5662	BNWFEU	MACJMSDNYF	2806763003 Dell Way	\N	KFSTCGV	IA	62733	US	1	MACJMSDNYF@dell.com	2806763003	1	8698385660070927	2012/07	user5662	password	75	100000	F
5663	QDFLQG	OASGDGEJQK	7794586096 Dell Way	\N	BKNIGTX	MI	88877	US	1	OASGDGEJQK@dell.com	7794586096	2	4764049815945327	2010/04	user5663	password	52	20000	F
5664	SRBYFC	RMGXQPNBQY	6926638996 Dell Way	\N	PZEJWPG	NJ	93798	US	1	RMGXQPNBQY@dell.com	6926638996	1	2934176133014262	2008/05	user5664	password	65	100000	F
5665	SUFVLR	BIIQWKHUAG	7207361141 Dell Way	\N	YJDOPTM	ID	92240	US	1	BIIQWKHUAG@dell.com	7207361141	3	3475068957079202	2009/03	user5665	password	39	20000	F
5666	NWLFYT	NOPYWKYDII	2763600321 Dell Way	\N	GWYAIFX	AL	63817	US	1	NOPYWKYDII@dell.com	2763600321	2	8520945518277586	2010/06	user5666	password	79	20000	F
5667	HFGBTV	RRSBQVJYCG	5535399388 Dell Way	\N	WCPBAQR	GA	10205	US	1	RRSBQVJYCG@dell.com	5535399388	4	4930482100695372	2009/09	user5667	password	72	80000	M
5668	ASQVJI	NKYJUXLBTN	7419534762 Dell Way	\N	QVNHNTH	AK	49845	US	1	NKYJUXLBTN@dell.com	7419534762	2	2277282814960927	2010/01	user5668	password	21	60000	M
5669	RHBZVM	YEHVPIPDZL	9962134027 Dell Way	\N	RGYKNYW	IA	37178	US	1	YEHVPIPDZL@dell.com	9962134027	4	3725917148869485	2008/03	user5669	password	90	80000	F
5670	BSHOQL	VMBDBEDMWJ	9813282901 Dell Way	\N	LGWJDDR	CO	83961	US	1	VMBDBEDMWJ@dell.com	9813282901	1	9930042481981220	2012/11	user5670	password	51	20000	M
5671	TPFFKS	GOTLRGIARO	8520831339 Dell Way	\N	XBSATVV	OK	96866	US	1	GOTLRGIARO@dell.com	8520831339	4	8492223384790123	2009/09	user5671	password	47	20000	F
5672	QGSING	CZXIHYAWVC	2467280589 Dell Way	\N	OWVJSOI	MT	32242	US	1	CZXIHYAWVC@dell.com	2467280589	5	9867760201450438	2010/11	user5672	password	40	20000	F
5673	ANQGPP	EYWCYTYBHU	6902777151 Dell Way	\N	WQMLZAR	DC	84245	US	1	EYWCYTYBHU@dell.com	6902777151	4	7221963582094759	2012/11	user5673	password	76	100000	F
5674	LGAAKY	XNXQLYYGVP	3029948454 Dell Way	\N	SGOSYSN	NE	48850	US	1	XNXQLYYGVP@dell.com	3029948454	3	4103836178779602	2008/07	user5674	password	74	60000	M
5675	UMETKS	RBDPZKLOCS	6651697673 Dell Way	\N	DUQWIFH	ND	76484	US	1	RBDPZKLOCS@dell.com	6651697673	3	3255342055112123	2010/01	user5675	password	18	20000	M
5676	EYZWPA	AFZKRONJSI	2574963092 Dell Way	\N	ZOREVFY	MN	83528	US	1	AFZKRONJSI@dell.com	2574963092	5	8900155428331346	2008/01	user5676	password	49	40000	F
5677	KGQKGV	KRNZFWRNWG	1802473594 Dell Way	\N	EBCKZOF	DC	47080	US	1	KRNZFWRNWG@dell.com	1802473594	2	5296352836303413	2010/09	user5677	password	53	100000	M
5678	CIEYTW	MTBILPERTG	2600386452 Dell Way	\N	TEFHJIS	MN	70095	US	1	MTBILPERTG@dell.com	2600386452	5	4149443945381790	2011/11	user5678	password	37	80000	F
5679	LTAIFT	KNEZSVTYOX	5716589450 Dell Way	\N	EWGNOSE	OR	72998	US	1	KNEZSVTYOX@dell.com	5716589450	3	6442172456998379	2011/03	user5679	password	80	40000	M
5680	WPDPZQ	TZJPSIEPMA	9103267847 Dell Way	\N	WZPPEIH	OH	77370	US	1	TZJPSIEPMA@dell.com	9103267847	3	9447606404311956	2011/09	user5680	password	80	80000	F
5681	ZFHQYG	AOZISPVTLV	4373653711 Dell Way	\N	JBARJSL	IA	26953	US	1	AOZISPVTLV@dell.com	4373653711	5	9361335888039322	2009/08	user5681	password	36	40000	M
5682	OWTUWI	UEBJAUVVDW	6942579729 Dell Way	\N	VVFOGLT	NM	50874	US	1	UEBJAUVVDW@dell.com	6942579729	5	1511588961351662	2012/02	user5682	password	80	60000	M
5683	QGUYAZ	ZKAUFWXBST	3186092200 Dell Way	\N	HGATZQE	NM	57081	US	1	ZKAUFWXBST@dell.com	3186092200	3	6565090808086098	2008/12	user5683	password	59	80000	F
5684	JRHJQR	JKWFIYXBFD	8698069280 Dell Way	\N	BYCSDTG	MA	34258	US	1	JKWFIYXBFD@dell.com	8698069280	3	3349011101294309	2010/03	user5684	password	55	80000	M
5685	UDNMMY	JRGIPIOSJN	1701534290 Dell Way	\N	VCQOIAV	FL	57286	US	1	JRGIPIOSJN@dell.com	1701534290	4	7658340930007399	2010/05	user5685	password	63	40000	M
5686	DWZBGR	IOGQCZAPUC	5914109254 Dell Way	\N	GILHDQU	HI	31286	US	1	IOGQCZAPUC@dell.com	5914109254	5	6595221696421505	2008/03	user5686	password	27	40000	F
5687	DJIURW	BIYAIOULUD	4357643538 Dell Way	\N	WCGNXMT	MI	37268	US	1	BIYAIOULUD@dell.com	4357643538	3	5554938572458923	2010/11	user5687	password	60	80000	F
5688	XLYTMH	SMPGHBBKYD	9877789509 Dell Way	\N	RLAEFMM	ND	15986	US	1	SMPGHBBKYD@dell.com	9877789509	1	9683068116661162	2010/09	user5688	password	34	60000	F
5689	EFQLXD	BEKCGVAKNM	9377687832 Dell Way	\N	LSRXEGZ	DE	37799	US	1	BEKCGVAKNM@dell.com	9377687832	4	1150209974497556	2008/03	user5689	password	29	40000	F
5690	UUIXWN	IYTEZDRLOK	7033359373 Dell Way	\N	CMOILTQ	LA	52624	US	1	IYTEZDRLOK@dell.com	7033359373	3	6989064992871136	2012/11	user5690	password	22	80000	M
5691	JNNWVM	QZLURXJBZV	5589519224 Dell Way	\N	QIGJZQV	NY	25340	US	1	QZLURXJBZV@dell.com	5589519224	3	1417942739091813	2010/02	user5691	password	70	100000	M
5692	GVLSML	DGCAPEALVJ	5960446925 Dell Way	\N	SEJIABN	NC	58372	US	1	DGCAPEALVJ@dell.com	5960446925	1	6752990747801960	2009/01	user5692	password	36	60000	M
5693	SFKDJQ	GKGKLRGVJK	4644392318 Dell Way	\N	ESLFFZT	PA	17407	US	1	GKGKLRGVJK@dell.com	4644392318	1	2364740824792534	2011/07	user5693	password	22	40000	M
5694	LMCCTN	IDYAKTJUYC	4969261885 Dell Way	\N	GEHFYBH	KS	17590	US	1	IDYAKTJUYC@dell.com	4969261885	5	6584862984251232	2010/05	user5694	password	44	100000	M
5695	MBOZJS	YKCRUXPWDU	9217503594 Dell Way	\N	DISFQAH	AZ	11855	US	1	YKCRUXPWDU@dell.com	9217503594	3	4259971555322409	2009/07	user5695	password	31	80000	M
5696	TTYLRJ	OJDLYZOSDX	8542242182 Dell Way	\N	LJNLQPM	ND	25840	US	1	OJDLYZOSDX@dell.com	8542242182	5	7337586538400502	2008/08	user5696	password	38	80000	F
5697	GFAPUJ	SFISUBWSMF	7654537532 Dell Way	\N	GYVWKKA	IA	30903	US	1	SFISUBWSMF@dell.com	7654537532	2	8477241441141815	2008/01	user5697	password	30	40000	F
5698	FWBOPH	XHCYDUKIBI	6796154908 Dell Way	\N	EXTPYZV	OH	32269	US	1	XHCYDUKIBI@dell.com	6796154908	4	3591643548570573	2012/12	user5698	password	58	20000	M
5699	PPKXMS	ZKWUVEVDJT	4648134599 Dell Way	\N	XYSWUKD	ME	19612	US	1	ZKWUVEVDJT@dell.com	4648134599	2	1714313109871000	2012/04	user5699	password	84	60000	M
5700	IMIALS	WFNBBRLUPK	1834731922 Dell Way	\N	NLEXOOA	WV	82817	US	1	WFNBBRLUPK@dell.com	1834731922	5	1574040883220732	2008/07	user5700	password	83	40000	M
5701	FIKYFQ	MGRESMTCZE	7292115807 Dell Way	\N	GXTVXSQ	AK	69178	US	1	MGRESMTCZE@dell.com	7292115807	1	2482790090609342	2011/05	user5701	password	27	100000	M
5702	OTXEFE	WJWIDYIHFG	6412645396 Dell Way	\N	BAEUREL	LA	27534	US	1	WJWIDYIHFG@dell.com	6412645396	5	5765884332824499	2011/10	user5702	password	33	40000	M
5703	CLTGID	CQGBZOGGPH	3875664065 Dell Way	\N	KKYPVIU	MI	36234	US	1	CQGBZOGGPH@dell.com	3875664065	1	1672515211626887	2010/06	user5703	password	62	80000	M
5704	JWFNZW	TBWIHCYPNI	3284625897 Dell Way	\N	ODDXXPE	HI	77723	US	1	TBWIHCYPNI@dell.com	3284625897	4	2823364158626646	2012/05	user5704	password	25	40000	F
5705	ISFEMH	BUPESERBTU	7671216597 Dell Way	\N	FQSUVYO	AZ	72918	US	1	BUPESERBTU@dell.com	7671216597	5	1673855825792998	2012/02	user5705	password	41	20000	M
5706	OJJVKE	KPXPGYIBDZ	5570240222 Dell Way	\N	UYUTMVL	GA	79176	US	1	KPXPGYIBDZ@dell.com	5570240222	1	9319470268208534	2012/03	user5706	password	77	40000	M
5707	EFAIPP	GFWENYIMSG	8186916119 Dell Way	\N	GLTCWYW	MD	10484	US	1	GFWENYIMSG@dell.com	8186916119	2	3134344861377030	2011/08	user5707	password	78	80000	M
5708	VDKLJQ	HODFWQYDXJ	1572723566 Dell Way	\N	WAGVWQV	NY	88858	US	1	HODFWQYDXJ@dell.com	1572723566	2	5331374070607126	2012/01	user5708	password	39	80000	F
5709	SEOILD	MQACODAYAA	2967214322 Dell Way	\N	FWXWRPT	OR	87755	US	1	MQACODAYAA@dell.com	2967214322	4	9414376525208356	2010/05	user5709	password	27	40000	M
5710	SOYVAP	VDEZEDAEIW	5128784677 Dell Way	\N	CENRXHN	DC	91046	US	1	VDEZEDAEIW@dell.com	5128784677	4	3367689577396959	2010/11	user5710	password	75	40000	F
5711	TDMIZQ	NYUQYZYVBD	8057512049 Dell Way	\N	JSBQGEN	OH	85854	US	1	NYUQYZYVBD@dell.com	8057512049	2	7483926106244326	2010/08	user5711	password	29	40000	M
5712	QQRGDQ	BUPASKBWTU	6890439086 Dell Way	\N	XKACXSY	OH	98687	US	1	BUPASKBWTU@dell.com	6890439086	2	6165733137167991	2012/07	user5712	password	39	60000	F
5713	ZSJPTD	FTWQUSJOPT	8510065812 Dell Way	\N	PRRHQJG	IL	66004	US	1	FTWQUSJOPT@dell.com	8510065812	1	2658226819243282	2008/07	user5713	password	46	20000	F
5714	TSYWXS	SNNKXCARRS	5817686405 Dell Way	\N	JYISEPJ	AL	70852	US	1	SNNKXCARRS@dell.com	5817686405	1	2837650714442134	2012/04	user5714	password	49	80000	M
5715	KOXCGL	PRJRRAIJKG	2458187482 Dell Way	\N	RDLHMMY	AK	66331	US	1	PRJRRAIJKG@dell.com	2458187482	5	8940195012837649	2010/08	user5715	password	80	100000	F
5716	TBKERC	NITOQDYXVC	4051460989 Dell Way	\N	JCOVBOL	HI	56457	US	1	NITOQDYXVC@dell.com	4051460989	5	2119031644891947	2008/10	user5716	password	37	100000	M
5717	RCNTQV	NEMRDKMFTP	9866361668 Dell Way	\N	TPRIBXW	MA	76205	US	1	NEMRDKMFTP@dell.com	9866361668	3	5800414743833244	2009/07	user5717	password	46	100000	M
5718	XSGTFK	GXNRKTKZNA	8740803626 Dell Way	\N	RWBPSLI	OH	13614	US	1	GXNRKTKZNA@dell.com	8740803626	5	6006553025916219	2009/11	user5718	password	30	20000	M
5719	KXVVES	JVCCGCPGUM	4473933535 Dell Way	\N	IJEUSWV	ND	85258	US	1	JVCCGCPGUM@dell.com	4473933535	5	7606094281189144	2010/12	user5719	password	42	100000	M
5720	EUBWEX	ZGDCWKWITG	9584293095 Dell Way	\N	NNYJJNF	PA	39346	US	1	ZGDCWKWITG@dell.com	9584293095	2	3759399360977113	2009/04	user5720	password	33	60000	F
5721	HIGEIM	IKJTHRMNEA	6627094897 Dell Way	\N	MOJZUDI	PA	49200	US	1	IKJTHRMNEA@dell.com	6627094897	1	7480941159650684	2012/06	user5721	password	76	20000	M
5722	BHDNPN	XJVPVJUVVI	5486680158 Dell Way	\N	FVDIDXU	RI	93388	US	1	XJVPVJUVVI@dell.com	5486680158	3	4701610739342868	2009/09	user5722	password	34	40000	M
5723	JWPXTY	SJUBDQWMVS	8489073188 Dell Way	\N	PEWMZQK	MN	29521	US	1	SJUBDQWMVS@dell.com	8489073188	4	9338171987328680	2008/02	user5723	password	85	60000	M
5724	NHTMZC	GBFXYRTQHX	3307264047 Dell Way	\N	MUWCFII	AL	19195	US	1	GBFXYRTQHX@dell.com	3307264047	1	2848023780621588	2008/06	user5724	password	31	80000	M
5725	YFUAMV	GJUXCKEAXZ	5789491233 Dell Way	\N	WAEFJEI	NJ	33810	US	1	GJUXCKEAXZ@dell.com	5789491233	4	7791865661740304	2011/07	user5725	password	57	80000	M
5726	IREEXN	YVPJAPHZMH	3958774151 Dell Way	\N	DSRIBHO	NE	16069	US	1	YVPJAPHZMH@dell.com	3958774151	2	6140220174565912	2012/12	user5726	password	37	20000	M
5727	LJNYHI	OQJEXIRFLJ	8071631515 Dell Way	\N	WTKDIZF	NV	36223	US	1	OQJEXIRFLJ@dell.com	8071631515	3	3091351054143160	2008/09	user5727	password	79	60000	F
5728	JLJSZA	BDXJUDVEAP	2116938214 Dell Way	\N	PEXPJOX	DE	18466	US	1	BDXJUDVEAP@dell.com	2116938214	2	8321160299703480	2012/09	user5728	password	82	40000	F
5729	GBDGCH	EMCIHGIWWM	3311665887 Dell Way	\N	UMWJJAL	MO	29745	US	1	EMCIHGIWWM@dell.com	3311665887	3	9278153294231744	2008/10	user5729	password	22	40000	M
5730	EQYLVK	ODSULPRXJD	9238341270 Dell Way	\N	USNUEZZ	ME	50148	US	1	ODSULPRXJD@dell.com	9238341270	3	3137632943689823	2012/12	user5730	password	23	20000	M
5731	APKKDN	DYZSQXBURU	9615250724 Dell Way	\N	HLYHLJS	KY	91824	US	1	DYZSQXBURU@dell.com	9615250724	2	8696453912183643	2008/06	user5731	password	50	20000	F
5732	WLGJPE	JHVGJPXDWJ	2768908262 Dell Way	\N	CDULWDI	TN	51258	US	1	JHVGJPXDWJ@dell.com	2768908262	5	9397043026052416	2011/11	user5732	password	19	60000	F
5733	GWYLFF	GLOWJSSSUW	1192294085 Dell Way	\N	MFTQOPC	RI	49232	US	1	GLOWJSSSUW@dell.com	1192294085	3	3988560685887933	2008/11	user5733	password	67	40000	M
5734	QSZVZK	KVUDOMXLZD	5745599213 Dell Way	\N	EQSTSMF	OR	89786	US	1	KVUDOMXLZD@dell.com	5745599213	4	8004027418326587	2009/01	user5734	password	56	100000	M
5735	MRTXBO	SFDFDOEHTU	2227277214 Dell Way	\N	ZMMMSFJ	HI	99052	US	1	SFDFDOEHTU@dell.com	2227277214	3	1347723412327468	2011/04	user5735	password	77	20000	M
5736	OCADUF	GZIVEPOYPB	7355862678 Dell Way	\N	LBTRKZR	ND	46201	US	1	GZIVEPOYPB@dell.com	7355862678	2	6970138341188431	2010/05	user5736	password	60	20000	F
5737	PFGULG	DGKSVJIWUJ	6912852752 Dell Way	\N	QMUPDIZ	TX	61335	US	1	DGKSVJIWUJ@dell.com	6912852752	2	9661001411266626	2009/06	user5737	password	50	100000	M
5738	SQCYTJ	IMERUBMDRZ	8274832209 Dell Way	\N	YHDHHZV	WA	41360	US	1	IMERUBMDRZ@dell.com	8274832209	1	8108807393815369	2009/01	user5738	password	49	100000	M
5739	NXJXGV	CYPDLTVKRC	6756577116 Dell Way	\N	NYJNUHW	NJ	53109	US	1	CYPDLTVKRC@dell.com	6756577116	5	5369844655040652	2008/10	user5739	password	26	60000	M
5740	MMYIPW	YSHRORJRFI	3806540462 Dell Way	\N	BSDJOTV	GA	62950	US	1	YSHRORJRFI@dell.com	3806540462	2	4560846402775496	2010/11	user5740	password	25	100000	F
5741	AGYXER	EWFWGWCOYU	4660440176 Dell Way	\N	RHJKCOA	MD	84995	US	1	EWFWGWCOYU@dell.com	4660440176	5	7348133524879814	2010/10	user5741	password	23	60000	F
5742	ALFRQC	XNIUPXSKPZ	8630748525 Dell Way	\N	TABIAMD	MI	38977	US	1	XNIUPXSKPZ@dell.com	8630748525	5	1738459872547537	2012/06	user5742	password	24	100000	M
5743	HQNJNB	SHQPAAFZTF	9529893630 Dell Way	\N	BCGOFRW	AZ	64950	US	1	SHQPAAFZTF@dell.com	9529893630	5	1756375012919306	2008/12	user5743	password	90	40000	M
5744	NSBOLJ	FBJFGIZMKB	1812399867 Dell Way	\N	SYHKVJA	PA	41097	US	1	FBJFGIZMKB@dell.com	1812399867	5	3403107162564993	2008/02	user5744	password	76	80000	M
5745	WFIFKJ	OQQXQCISVH	9612758093 Dell Way	\N	ZFCIFWR	IN	68925	US	1	OQQXQCISVH@dell.com	9612758093	2	8213145349640400	2011/01	user5745	password	67	80000	F
5746	ZVPJKG	ZIWBQOWXOC	3751682134 Dell Way	\N	AXIWPQN	NC	12320	US	1	ZIWBQOWXOC@dell.com	3751682134	2	1379787410609424	2012/12	user5746	password	36	100000	M
5747	WIDCHM	ZICOFACIAZ	4068898541 Dell Way	\N	QWOHJCH	NY	45857	US	1	ZICOFACIAZ@dell.com	4068898541	4	3847593314480037	2010/08	user5747	password	22	60000	M
5748	FOFROO	UCUVECVETS	5784572414 Dell Way	\N	SABVITF	NV	47439	US	1	UCUVECVETS@dell.com	5784572414	2	1337225703056901	2010/09	user5748	password	88	100000	F
5749	EMVSHY	MCCPXHIPZJ	9090896502 Dell Way	\N	RVRLAIW	ND	62621	US	1	MCCPXHIPZJ@dell.com	9090896502	1	3700535132549703	2012/12	user5749	password	61	20000	F
5750	LTSJGU	MWSTFITOAO	5109123515 Dell Way	\N	GMPOIDE	HI	35631	US	1	MWSTFITOAO@dell.com	5109123515	1	3183444910217076	2008/02	user5750	password	68	60000	M
5751	KWEFIA	YCFGVUGKAT	6778040518 Dell Way	\N	ZPBCTHK	GA	43076	US	1	YCFGVUGKAT@dell.com	6778040518	2	5479309586342424	2009/09	user5751	password	46	80000	M
5752	OYXOWA	UDWOKGPDGE	3840770617 Dell Way	\N	EJYLTDV	MD	45097	US	1	UDWOKGPDGE@dell.com	3840770617	4	2118932218756526	2011/06	user5752	password	69	40000	F
5753	QVHQPK	NEUTTXZYBJ	5590185015 Dell Way	\N	WNCZIMK	NV	29187	US	1	NEUTTXZYBJ@dell.com	5590185015	2	7042811139021069	2009/08	user5753	password	23	100000	F
5754	IMATZE	NTYKTWMCSZ	6116064845 Dell Way	\N	FSIRCZX	NJ	39161	US	1	NTYKTWMCSZ@dell.com	6116064845	5	9411332343705000	2011/09	user5754	password	44	100000	F
5755	KSEOFY	NQRJCUCCZV	6607252866 Dell Way	\N	KQYJOOR	CO	46139	US	1	NQRJCUCCZV@dell.com	6607252866	4	1801128965336829	2012/09	user5755	password	37	40000	F
5756	LYRJMI	BWKVYMUUXL	8143083774 Dell Way	\N	TGZHYCS	ND	86398	US	1	BWKVYMUUXL@dell.com	8143083774	3	6323610424064100	2008/12	user5756	password	21	60000	M
5757	TWIBYE	MTDZNYWZRD	5340536186 Dell Way	\N	YZBBRQX	MO	26102	US	1	MTDZNYWZRD@dell.com	5340536186	3	1929181282408535	2010/01	user5757	password	89	40000	M
5758	IIWNVQ	QUEPQDHTCG	7556425507 Dell Way	\N	VDYLALQ	MS	99453	US	1	QUEPQDHTCG@dell.com	7556425507	1	1460596400313079	2011/04	user5758	password	90	20000	M
5759	WNLMEG	QUXTBQVIMY	7917858331 Dell Way	\N	HXZSNMS	ID	54038	US	1	QUXTBQVIMY@dell.com	7917858331	5	8153976967092604	2011/12	user5759	password	50	80000	M
5760	XCRDTL	AMNRIVDHCB	1146677501 Dell Way	\N	HVOTOVF	KS	82745	US	1	AMNRIVDHCB@dell.com	1146677501	1	8182143916841597	2010/09	user5760	password	40	40000	M
5761	AMNMNA	ZEJVIRXJYT	4399719095 Dell Way	\N	YRHUXQP	VT	73668	US	1	ZEJVIRXJYT@dell.com	4399719095	2	4635627337265760	2011/09	user5761	password	32	80000	F
5762	SESTDX	CYFUWPSPNJ	6953690071 Dell Way	\N	XHHOWEG	IA	58599	US	1	CYFUWPSPNJ@dell.com	6953690071	5	3288649261463434	2012/08	user5762	password	51	60000	M
5763	EIXCLV	IFSXYIKIGR	6174071668 Dell Way	\N	PUNUBUI	OK	73351	US	1	IFSXYIKIGR@dell.com	6174071668	3	3905740010086447	2008/02	user5763	password	25	40000	F
5764	ZIYVQE	ONCWXLCPAX	9293582219 Dell Way	\N	DVYXDQP	OK	29575	US	1	ONCWXLCPAX@dell.com	9293582219	4	4315545300021768	2008/12	user5764	password	80	20000	F
5765	UWXYKK	BHHMJWNGZI	4989645131 Dell Way	\N	FXMWMEB	ME	92845	US	1	BHHMJWNGZI@dell.com	4989645131	3	8967270244844259	2009/06	user5765	password	29	20000	F
5766	BASLBZ	TOJQBQQKVN	8526059543 Dell Way	\N	WRAATLY	GA	87637	US	1	TOJQBQQKVN@dell.com	8526059543	3	3808952028397471	2012/08	user5766	password	63	20000	M
5767	IMRIGF	RWHIMRDANV	6737499934 Dell Way	\N	AOPMNVI	KY	38465	US	1	RWHIMRDANV@dell.com	6737499934	2	9102205391041936	2009/05	user5767	password	54	60000	M
5768	EXDKPZ	SXMJBMXXNM	5705371522 Dell Way	\N	MZZHIIQ	WI	72099	US	1	SXMJBMXXNM@dell.com	5705371522	2	1725319336634129	2008/10	user5768	password	88	40000	M
5769	CQIBIG	ORHAPFOBSO	2520283537 Dell Way	\N	BAWKQVC	DC	12923	US	1	ORHAPFOBSO@dell.com	2520283537	1	8573931388091297	2008/05	user5769	password	59	40000	F
5770	XHIEVZ	MWPRKRJZSJ	5783411889 Dell Way	\N	VCZRFDR	LA	37616	US	1	MWPRKRJZSJ@dell.com	5783411889	3	7245428866706789	2008/09	user5770	password	68	20000	M
5771	AEUAQQ	PHBGQAZAWC	2089821018 Dell Way	\N	ZNHDFQL	PA	22491	US	1	PHBGQAZAWC@dell.com	2089821018	5	8611853335052729	2012/11	user5771	password	78	100000	F
5772	QVQHLY	ISPJRPGTPU	6869808997 Dell Way	\N	ASZRDTU	IA	63131	US	1	ISPJRPGTPU@dell.com	6869808997	1	5071659141220153	2010/11	user5772	password	52	20000	M
5773	DJFBSX	RCOGIIVCJO	8788503935 Dell Way	\N	CARVVYK	MO	10210	US	1	RCOGIIVCJO@dell.com	8788503935	5	9160333759617060	2009/01	user5773	password	65	60000	F
5774	WODTFF	IMOQIQZWTA	4366626575 Dell Way	\N	NOVMZHM	TN	32562	US	1	IMOQIQZWTA@dell.com	4366626575	1	3750146959442645	2008/08	user5774	password	71	100000	F
5775	WQKCYX	RPFIPBBPPP	3346388307 Dell Way	\N	KBOSNKY	VA	63532	US	1	RPFIPBBPPP@dell.com	3346388307	5	3270599277224392	2012/10	user5775	password	51	100000	F
5776	WZKUQZ	ZYOAZDQPOR	4987529765 Dell Way	\N	EGFPFCE	MN	13593	US	1	ZYOAZDQPOR@dell.com	4987529765	3	8638125312514604	2012/04	user5776	password	38	80000	F
5777	ROYQNX	FOXIENWWSC	1714730901 Dell Way	\N	CHIEMUF	WA	30559	US	1	FOXIENWWSC@dell.com	1714730901	5	6038087300490589	2009/08	user5777	password	81	20000	F
5778	VRSTWG	QFLEBIWEKD	1544797219 Dell Way	\N	NPQHVON	VA	43873	US	1	QFLEBIWEKD@dell.com	1544797219	2	9894762728828938	2012/04	user5778	password	29	80000	M
5779	WMWCDB	OHDWDIGHVV	8370627869 Dell Way	\N	XCQLPNV	NV	81020	US	1	OHDWDIGHVV@dell.com	8370627869	3	1727535704616457	2012/05	user5779	password	21	100000	M
5780	XYZYMG	CIKKPRFKPH	5049015878 Dell Way	\N	BBWPWNJ	OH	19868	US	1	CIKKPRFKPH@dell.com	5049015878	4	5057695355731994	2010/06	user5780	password	38	60000	F
5781	GJXNLG	YVVQAFFIGG	3601240928 Dell Way	\N	FVDSFVV	NV	55769	US	1	YVVQAFFIGG@dell.com	3601240928	1	1047115679364651	2010/07	user5781	password	49	100000	M
5782	IJIOHE	JXFPCNWJSS	8737612841 Dell Way	\N	NLXIHPW	ND	77205	US	1	JXFPCNWJSS@dell.com	8737612841	1	3815687071997672	2009/12	user5782	password	34	80000	F
5783	OEQTON	YEQLAAESNP	3514910372 Dell Way	\N	QWWFSLZ	NE	63352	US	1	YEQLAAESNP@dell.com	3514910372	5	6142150979489089	2010/06	user5783	password	84	20000	M
5784	NVGBTK	RFLSJDFZUC	5217917605 Dell Way	\N	WAUHZJX	IA	31797	US	1	RFLSJDFZUC@dell.com	5217917605	4	7614640800748021	2009/11	user5784	password	48	100000	M
5785	RYLBQQ	MIAQOALQWL	8040865635 Dell Way	\N	LEKUBRB	MT	47504	US	1	MIAQOALQWL@dell.com	8040865635	5	3370789662003517	2008/10	user5785	password	86	100000	M
5786	JYKALT	BBIBNYXYJB	7115571238 Dell Way	\N	IEDZGRK	AK	60454	US	1	BBIBNYXYJB@dell.com	7115571238	2	4315119650214911	2011/01	user5786	password	27	100000	F
5787	OALHCN	QDAOBZYDID	8630056033 Dell Way	\N	GIJXSKM	MD	65151	US	1	QDAOBZYDID@dell.com	8630056033	1	7249811449553818	2012/01	user5787	password	69	60000	F
5788	EVDRLH	SAISZMADSI	2780409046 Dell Way	\N	MQBXDLN	WV	53701	US	1	SAISZMADSI@dell.com	2780409046	5	5588524954859168	2012/06	user5788	password	59	20000	F
5789	STTZMU	IETUEWNNJD	1089122626 Dell Way	\N	OGHAUGN	WV	27575	US	1	IETUEWNNJD@dell.com	1089122626	5	7095088914036751	2010/12	user5789	password	90	40000	M
5790	TGFOOJ	IIOFWBOZQV	4441256857 Dell Way	\N	GQPNDPS	DC	51701	US	1	IIOFWBOZQV@dell.com	4441256857	4	4746503772679717	2009/12	user5790	password	27	20000	F
5791	IRVSZE	HEAJTAZPHQ	7134999132 Dell Way	\N	FUUUMYG	UT	69942	US	1	HEAJTAZPHQ@dell.com	7134999132	2	6991153381764889	2012/05	user5791	password	84	20000	F
5792	TWBXDG	XNAXNPEDVZ	2765912004 Dell Way	\N	YQLWXIN	NE	62115	US	1	XNAXNPEDVZ@dell.com	2765912004	2	9625307051464916	2008/07	user5792	password	19	100000	F
5793	BTOIQC	IOPYTSTSQK	1458804688 Dell Way	\N	ENHNBWC	IA	33385	US	1	IOPYTSTSQK@dell.com	1458804688	2	8221829277928919	2008/03	user5793	password	33	20000	M
5794	ULPWUE	LSXEMQVWUI	1763212860 Dell Way	\N	EIJAKQH	MN	98554	US	1	LSXEMQVWUI@dell.com	1763212860	3	2690149624366313	2009/09	user5794	password	27	20000	F
5795	SYXWJQ	UNCKIZFRDN	8743345631 Dell Way	\N	BDYRKKR	MS	93517	US	1	UNCKIZFRDN@dell.com	8743345631	5	6401050697546453	2012/11	user5795	password	71	80000	M
5796	QPEGKS	JUBIASLNUP	4615966808 Dell Way	\N	MMAWDNU	AK	38088	US	1	JUBIASLNUP@dell.com	4615966808	5	2708386072423309	2008/09	user5796	password	90	80000	F
5797	EASWKN	XSNQDBKSNW	7660412027 Dell Way	\N	SKAGFAO	NJ	11899	US	1	XSNQDBKSNW@dell.com	7660412027	4	7672880108002574	2011/07	user5797	password	22	100000	M
5798	UTYHRR	VHVWROKOHV	4243607842 Dell Way	\N	ONBPBRQ	SC	46321	US	1	VHVWROKOHV@dell.com	4243607842	3	9303060785867276	2010/06	user5798	password	52	40000	F
5799	LNWCID	XFULQJSLYF	5302053113 Dell Way	\N	MNHDECO	MT	66436	US	1	XFULQJSLYF@dell.com	5302053113	5	1546446048654615	2012/02	user5799	password	36	40000	M
5800	CMZFJE	AUUKNGITTW	8289727659 Dell Way	\N	AXADLNT	WA	52863	US	1	AUUKNGITTW@dell.com	8289727659	5	6641300676856191	2008/04	user5800	password	38	20000	M
5801	GJCLKX	GUKNDEGZEE	6855544908 Dell Way	\N	AIQOBOA	UT	51136	US	1	GUKNDEGZEE@dell.com	6855544908	5	7553306614048780	2012/02	user5801	password	51	20000	F
5802	OQWLWR	WKUAQUFVVN	2706047219 Dell Way	\N	LJPAKLL	AL	43884	US	1	WKUAQUFVVN@dell.com	2706047219	5	5178297770209611	2011/02	user5802	password	86	40000	M
5803	VRRMNB	HOSCTNXHZG	2293476442 Dell Way	\N	WZQHLRR	NJ	68955	US	1	HOSCTNXHZG@dell.com	2293476442	2	8332032508216799	2008/06	user5803	password	62	100000	F
5804	HJRJRF	BTZPRGOYDO	7679550946 Dell Way	\N	PKZHCQY	IA	90502	US	1	BTZPRGOYDO@dell.com	7679550946	2	4435327025596053	2009/03	user5804	password	56	80000	M
5805	FZGLBA	KRRRGPUUEF	7024584124 Dell Way	\N	ULIKKOH	CT	89752	US	1	KRRRGPUUEF@dell.com	7024584124	3	1834070305805653	2008/02	user5805	password	67	60000	F
5806	XVEXGV	PYBETWJYQV	8348738580 Dell Way	\N	HAFVIIS	WY	84109	US	1	PYBETWJYQV@dell.com	8348738580	1	9460145999677480	2010/08	user5806	password	21	60000	F
5807	FIRBXQ	DCJZMIQHPR	6628319493 Dell Way	\N	NKZWDZR	WI	24599	US	1	DCJZMIQHPR@dell.com	6628319493	3	7828162915073336	2011/11	user5807	password	32	100000	F
5808	WYCNBE	WBQERYTIME	2975565606 Dell Way	\N	IIIHAHL	NM	75603	US	1	WBQERYTIME@dell.com	2975565606	2	6227214505895973	2010/03	user5808	password	73	40000	F
5809	VUFARH	RWYQPHCUQK	7260538395 Dell Way	\N	CYLKKBC	NH	44491	US	1	RWYQPHCUQK@dell.com	7260538395	1	6290671212598682	2010/04	user5809	password	71	40000	F
5810	YHUFZQ	EPGMRACCDA	6079560819 Dell Way	\N	NNLPQAZ	KY	14712	US	1	EPGMRACCDA@dell.com	6079560819	4	4328192296903581	2009/01	user5810	password	54	40000	F
5811	HMJYRY	EDQFGSJHGX	2552388791 Dell Way	\N	SVNTVWU	MA	69449	US	1	EDQFGSJHGX@dell.com	2552388791	4	7643206037580968	2011/12	user5811	password	27	100000	F
5812	MXBLCF	BHMURTBOMX	4311392507 Dell Way	\N	CGSZACQ	GA	80531	US	1	BHMURTBOMX@dell.com	4311392507	5	7492735545150936	2010/10	user5812	password	28	100000	M
5813	FKULMC	XHURIIEFLK	5904863797 Dell Way	\N	YKLBAQV	MD	56440	US	1	XHURIIEFLK@dell.com	5904863797	5	4137743692845106	2011/11	user5813	password	23	100000	F
5814	WIUZGB	TXKCBQOLOY	4483039823 Dell Way	\N	WPZNLKA	WV	36365	US	1	TXKCBQOLOY@dell.com	4483039823	4	2486505842767656	2010/07	user5814	password	50	40000	M
5815	FICHCA	RFBHTNWSKL	5903447172 Dell Way	\N	RYWCZVJ	KY	54138	US	1	RFBHTNWSKL@dell.com	5903447172	5	1319121307693421	2012/02	user5815	password	84	40000	F
5816	ANOAEU	CLNPIFATXY	9979967238 Dell Way	\N	QZXMJGZ	VT	16772	US	1	CLNPIFATXY@dell.com	9979967238	5	3044493239838630	2012/02	user5816	password	69	100000	M
5817	HYUBAG	OQPUQIRPZR	1603154367 Dell Way	\N	NLBTKZV	MD	89272	US	1	OQPUQIRPZR@dell.com	1603154367	2	1129086572676897	2011/03	user5817	password	65	20000	F
5818	LCESRV	HLMQDBPUOB	7362317909 Dell Way	\N	VILVEVS	HI	23475	US	1	HLMQDBPUOB@dell.com	7362317909	1	4334888163488358	2009/01	user5818	password	56	100000	F
5819	SNUNVG	ZLJABDPCZX	9202167268 Dell Way	\N	OUCKMIO	GA	38273	US	1	ZLJABDPCZX@dell.com	9202167268	3	4277797311078757	2010/05	user5819	password	55	20000	M
5820	HRSOQE	XRGAHIAEXV	3360039326 Dell Way	\N	HHIPVNX	OR	17598	US	1	XRGAHIAEXV@dell.com	3360039326	1	5047690192237497	2011/04	user5820	password	43	20000	M
5821	BQPGNH	MOOVOTSKAZ	8128599506 Dell Way	\N	SPUGNNI	PA	72064	US	1	MOOVOTSKAZ@dell.com	8128599506	3	9983949313405902	2008/08	user5821	password	88	20000	F
5822	OLTWXH	KSWELGEKZU	4677253951 Dell Way	\N	FGHSPBK	MA	63196	US	1	KSWELGEKZU@dell.com	4677253951	3	2823699757456779	2009/09	user5822	password	49	100000	F
5823	EVBLGU	IKFPPQOJVV	5662651681 Dell Way	\N	RNKSYUI	LA	39554	US	1	IKFPPQOJVV@dell.com	5662651681	4	1425834355410188	2012/09	user5823	password	32	20000	F
5824	GOSBXD	HMSXBCSWTG	5192662319 Dell Way	\N	HMFCUOK	IN	36031	US	1	HMSXBCSWTG@dell.com	5192662319	2	9754240989685060	2011/05	user5824	password	52	100000	M
5825	FZVIGI	AEJCWFWDMI	2298533290 Dell Way	\N	IPDWALE	MO	72247	US	1	AEJCWFWDMI@dell.com	2298533290	1	1630146954208612	2011/01	user5825	password	19	100000	F
5826	WDIEDM	NGJTDMGLVV	7981022991 Dell Way	\N	PSVAWHS	AL	48954	US	1	NGJTDMGLVV@dell.com	7981022991	4	5552033526357264	2011/06	user5826	password	59	80000	M
5827	XVSKJZ	UCCGIOCDDU	2832375831 Dell Way	\N	ZDRGWSS	NM	39588	US	1	UCCGIOCDDU@dell.com	2832375831	3	7925880169030280	2011/02	user5827	password	42	80000	M
5828	BCHAWK	DDSRFWVAVZ	5276667127 Dell Way	\N	RCVJUMS	AK	90621	US	1	DDSRFWVAVZ@dell.com	5276667127	4	9920349284540864	2012/06	user5828	password	85	100000	M
5829	FXKPAN	ISSFOSBNKD	7367999645 Dell Way	\N	JUYVMYS	WV	76421	US	1	ISSFOSBNKD@dell.com	7367999645	4	2782848268281668	2011/08	user5829	password	71	100000	M
5830	DMOQUH	JAVCBJMFSH	1419560831 Dell Way	\N	DOUCGTW	WV	57265	US	1	JAVCBJMFSH@dell.com	1419560831	3	2521593004930764	2011/06	user5830	password	69	100000	M
5831	HOSOXT	KZUUMZMUDA	9956806833 Dell Way	\N	OGHHCGV	DC	86419	US	1	KZUUMZMUDA@dell.com	9956806833	5	3689566649496555	2011/11	user5831	password	33	100000	F
5832	YOHRZH	LTULGOPHDV	9874774324 Dell Way	\N	PKYVGBR	IA	10199	US	1	LTULGOPHDV@dell.com	9874774324	5	8592755906283856	2009/12	user5832	password	35	20000	M
5833	NVMVGG	PSNEHUHCJS	9642419565 Dell Way	\N	BFYCXFD	VA	23256	US	1	PSNEHUHCJS@dell.com	9642419565	1	1750633962452411	2008/03	user5833	password	60	80000	F
5834	BOIIEA	VJHQQKAJLF	7745308250 Dell Way	\N	IODNRAR	NV	21432	US	1	VJHQQKAJLF@dell.com	7745308250	5	4297523688524962	2009/07	user5834	password	48	60000	F
5835	TSHTOQ	BEHMEQYKZN	1495265573 Dell Way	\N	NMFOEWR	VT	73399	US	1	BEHMEQYKZN@dell.com	1495265573	2	3521128696855158	2010/08	user5835	password	48	40000	F
5836	SYXJAC	RMGILQHYET	9977100020 Dell Way	\N	ETXALVS	MO	15623	US	1	RMGILQHYET@dell.com	9977100020	5	7369277043268085	2010/03	user5836	password	23	20000	F
5837	ZMDBDQ	ILCZTAENEX	1134235688 Dell Way	\N	KFJGXVH	VT	82066	US	1	ILCZTAENEX@dell.com	1134235688	2	9712518101092428	2008/06	user5837	password	24	20000	M
5838	GECWMN	YMHZQUEOFJ	5584425433 Dell Way	\N	XLHTTEO	PA	55595	US	1	YMHZQUEOFJ@dell.com	5584425433	5	9559162846766412	2011/12	user5838	password	82	100000	F
5839	ZSPNRB	URSOVGTFEE	2091127308 Dell Way	\N	MXYRLRE	WI	58765	US	1	URSOVGTFEE@dell.com	2091127308	3	5310344441328198	2008/05	user5839	password	60	100000	F
5840	EMUFGM	XUHEONISZF	4250981834 Dell Way	\N	QQRIVPW	WA	23521	US	1	XUHEONISZF@dell.com	4250981834	5	5883975198026747	2012/11	user5840	password	66	20000	F
5841	LIQYGL	GKZTTSSYJJ	9153181594 Dell Way	\N	PSEFPDJ	WA	15691	US	1	GKZTTSSYJJ@dell.com	9153181594	5	9805454070214184	2010/12	user5841	password	44	20000	F
5842	AYNLEY	LXRDQQMAGE	4165071190 Dell Way	\N	EMTIVSJ	OR	62693	US	1	LXRDQQMAGE@dell.com	4165071190	2	6054855084046722	2011/04	user5842	password	80	80000	F
5843	KELIPJ	ATARGAXLFJ	1416187794 Dell Way	\N	ENFXXYM	IA	30524	US	1	ATARGAXLFJ@dell.com	1416187794	5	5950072120409459	2012/09	user5843	password	78	40000	M
5844	HQMRRG	RIMSFXYPCL	5526637466 Dell Way	\N	UZJSMPY	MT	62986	US	1	RIMSFXYPCL@dell.com	5526637466	3	3629479032009840	2009/09	user5844	password	30	80000	F
5845	RGAXYI	JROGPDIBYI	9123737733 Dell Way	\N	KRUAPHP	CO	73341	US	1	JROGPDIBYI@dell.com	9123737733	3	4737584861926735	2008/01	user5845	password	73	80000	F
5846	TQGCZY	QGNTPOSXZJ	1725314353 Dell Way	\N	RZZYPCR	MS	56785	US	1	QGNTPOSXZJ@dell.com	1725314353	3	6111317570321262	2012/04	user5846	password	82	80000	M
5847	DRYBIF	PCUDURDDIC	3409279948 Dell Way	\N	CHSEZFS	AR	80792	US	1	PCUDURDDIC@dell.com	3409279948	5	1935721694026142	2008/07	user5847	password	22	40000	F
5848	AJNFZP	ZCJQFNZIPH	2265514601 Dell Way	\N	BUGGMIA	PA	28778	US	1	ZCJQFNZIPH@dell.com	2265514601	5	7394133166410030	2008/03	user5848	password	83	20000	M
5849	KKOAJR	JAXXAGMHHH	8164602131 Dell Way	\N	ONUWONC	OH	48973	US	1	JAXXAGMHHH@dell.com	8164602131	5	6774146432522685	2011/02	user5849	password	34	20000	F
5850	UDWLNW	IKWOXEVETJ	5905015916 Dell Way	\N	YQXMSQX	MS	56750	US	1	IKWOXEVETJ@dell.com	5905015916	1	6526535243727267	2011/04	user5850	password	25	60000	F
5851	ZZYVII	SXFXTKQCIG	7965466083 Dell Way	\N	AVZQSME	ID	69542	US	1	SXFXTKQCIG@dell.com	7965466083	1	9784971842076630	2012/07	user5851	password	48	100000	M
5852	JRXSKU	XINIYPRFQM	3482764885 Dell Way	\N	EHFQLLH	GA	53975	US	1	XINIYPRFQM@dell.com	3482764885	1	1636686460580676	2011/12	user5852	password	64	20000	M
5853	OTAIRI	WZHLQNCDRJ	3918541510 Dell Way	\N	IIUTQAG	VA	17664	US	1	WZHLQNCDRJ@dell.com	3918541510	3	1124718750361353	2012/08	user5853	password	63	60000	F
5854	RVAZRA	HDQUFULPCU	5400841515 Dell Way	\N	KVKKCHM	ME	87653	US	1	HDQUFULPCU@dell.com	5400841515	2	5428494315128774	2008/11	user5854	password	80	80000	M
5855	XTKXBO	OVUIHJKBTG	1701516747 Dell Way	\N	LDJSQUP	CO	24786	US	1	OVUIHJKBTG@dell.com	1701516747	2	1528490385971963	2012/01	user5855	password	75	100000	M
5856	ETUTHQ	NQXWAYQHKU	6744393169 Dell Way	\N	QDKKSNP	RI	75981	US	1	NQXWAYQHKU@dell.com	6744393169	4	7599645898677409	2010/07	user5856	password	54	80000	F
5857	HIPXWF	VSGUJOEDEH	5403375800 Dell Way	\N	NPZAEUT	SD	54444	US	1	VSGUJOEDEH@dell.com	5403375800	2	1458610325120389	2012/11	user5857	password	43	40000	F
5858	YFBEAT	KUDZYGDGTT	5965723878 Dell Way	\N	GUYANTN	AL	99334	US	1	KUDZYGDGTT@dell.com	5965723878	1	8618403721135111	2012/04	user5858	password	21	100000	F
5859	CANWLH	ZKGFONZHTT	8432184730 Dell Way	\N	GTHZGIZ	SD	40253	US	1	ZKGFONZHTT@dell.com	8432184730	4	6656786972191185	2012/07	user5859	password	26	100000	M
5860	QVZYUK	FAYSAGMTMF	4149450026 Dell Way	\N	BMMKLHS	ID	98816	US	1	FAYSAGMTMF@dell.com	4149450026	1	5832819391041995	2010/02	user5860	password	25	20000	M
5861	CBSMGT	KZTQLNDQOP	9330873378 Dell Way	\N	DYAKRHK	AL	49479	US	1	KZTQLNDQOP@dell.com	9330873378	3	5858553376048804	2008/08	user5861	password	51	20000	M
5862	FPXYZW	SQHFUYUJBT	7049454782 Dell Way	\N	KMLSWMD	RI	96816	US	1	SQHFUYUJBT@dell.com	7049454782	5	6154327395372093	2008/11	user5862	password	34	40000	F
5863	DHMZZD	HEXGZGHSQU	2311996957 Dell Way	\N	DJQPMKO	DC	29984	US	1	HEXGZGHSQU@dell.com	2311996957	2	2211946797557175	2009/08	user5863	password	63	60000	M
5864	CMWGUB	DAAKITBCWK	5573813993 Dell Way	\N	TMWDBAJ	GA	38485	US	1	DAAKITBCWK@dell.com	5573813993	3	9412347756791860	2008/01	user5864	password	78	40000	M
5865	RMJTQJ	TASMCUJMNW	6708024926 Dell Way	\N	JRXJBDS	ND	72440	US	1	TASMCUJMNW@dell.com	6708024926	4	7917027018498630	2010/12	user5865	password	42	20000	F
5866	RXBBQC	TDEOMRCIAU	8372865720 Dell Way	\N	GKVJCKB	OR	19929	US	1	TDEOMRCIAU@dell.com	8372865720	1	1571535067167133	2008/05	user5866	password	54	100000	F
5867	PXWRQZ	WFMNHUNBAX	5440663292 Dell Way	\N	XKAILSL	ID	92586	US	1	WFMNHUNBAX@dell.com	5440663292	3	3306232708971947	2012/04	user5867	password	53	60000	F
5868	IGUICA	UPHODJPBHZ	9563595100 Dell Way	\N	BQLUBSS	NC	19947	US	1	UPHODJPBHZ@dell.com	9563595100	3	4270519593730569	2010/02	user5868	password	55	80000	F
5869	ICMIWC	QLFABGIBIY	7094843923 Dell Way	\N	NCZFUNI	OR	14841	US	1	QLFABGIBIY@dell.com	7094843923	1	2530672634486109	2008/12	user5869	password	57	60000	F
5870	AVYCLK	IMLPUNXSAA	4792108798 Dell Way	\N	RGUFONG	HI	72875	US	1	IMLPUNXSAA@dell.com	4792108798	3	6810348865576089	2012/12	user5870	password	68	100000	M
5871	QCFAKR	MZLZXEAXWG	6083888844 Dell Way	\N	SBVFHBX	OK	51304	US	1	MZLZXEAXWG@dell.com	6083888844	4	4418796617537737	2009/08	user5871	password	27	100000	M
5872	IXDAJD	MJAQJYMQQN	4038763856 Dell Way	\N	LWVMUNY	KY	29446	US	1	MJAQJYMQQN@dell.com	4038763856	3	8821323800832034	2010/06	user5872	password	61	80000	F
5873	TUSWGB	XXLWJCMXOJ	3991679935 Dell Way	\N	SBDGZMM	KY	15935	US	1	XXLWJCMXOJ@dell.com	3991679935	5	5868142671417445	2012/08	user5873	password	83	80000	F
5874	QNRRLO	DHYFUVTDNU	3911278591 Dell Way	\N	GUUSGDU	NE	93561	US	1	DHYFUVTDNU@dell.com	3911278591	3	5737953719217331	2009/03	user5874	password	85	100000	M
5875	PNDDQL	CWFXPILKPF	7944055223 Dell Way	\N	EILICAG	ME	57606	US	1	CWFXPILKPF@dell.com	7944055223	4	7313011242542417	2011/06	user5875	password	47	40000	F
5876	OLQZNN	FLCOWNDBSL	8013152243 Dell Way	\N	NAOOGYC	AL	63668	US	1	FLCOWNDBSL@dell.com	8013152243	4	1694023401476442	2008/01	user5876	password	23	80000	F
5877	TTAGYL	JNHWQJOCXP	3480838158 Dell Way	\N	QLWPNWF	IN	65354	US	1	JNHWQJOCXP@dell.com	3480838158	3	6777047974988819	2009/03	user5877	password	26	20000	M
5878	DIYORL	WOCFCEDRVO	7046039219 Dell Way	\N	NLCKQKA	VT	90824	US	1	WOCFCEDRVO@dell.com	7046039219	2	2218965941574424	2011/05	user5878	password	26	100000	M
5879	BLJMIX	ONZTRROGFZ	7979199060 Dell Way	\N	IQQTRNQ	KS	80327	US	1	ONZTRROGFZ@dell.com	7979199060	1	2165743832010776	2012/01	user5879	password	76	100000	F
5880	EKUBYI	BRZSGGYGOO	3536605994 Dell Way	\N	WIGJYOD	OR	71778	US	1	BRZSGGYGOO@dell.com	3536605994	4	7408542047720403	2008/07	user5880	password	32	40000	M
5881	ZHXIIO	IBVOZBDOXL	7830599291 Dell Way	\N	UGJJKCB	OH	75148	US	1	IBVOZBDOXL@dell.com	7830599291	4	3382767271716148	2012/01	user5881	password	32	100000	F
5882	CGQRPR	MDRNGGKRAR	2526897148 Dell Way	\N	BKCELUX	FL	60101	US	1	MDRNGGKRAR@dell.com	2526897148	1	6205486462917179	2009/02	user5882	password	82	60000	F
5883	NDYFPC	WCICMADECN	2335067667 Dell Way	\N	GHYAEDO	LA	36424	US	1	WCICMADECN@dell.com	2335067667	4	4488547001965344	2008/03	user5883	password	72	60000	F
5884	STXUQZ	DSMEWRGJXO	2359790254 Dell Way	\N	IXTMMCT	NJ	85267	US	1	DSMEWRGJXO@dell.com	2359790254	4	1276137013919651	2012/03	user5884	password	43	80000	M
5885	GKPGNH	TREKYNHNWE	2965827423 Dell Way	\N	GIRJCHE	IA	94977	US	1	TREKYNHNWE@dell.com	2965827423	1	2374279011506587	2010/09	user5885	password	26	100000	F
5886	RBQZUI	EEHRLUOQAW	7173466841 Dell Way	\N	HJYPOFN	SC	40443	US	1	EEHRLUOQAW@dell.com	7173466841	2	1728378064930439	2011/02	user5886	password	33	60000	F
5887	WMZEQE	MIQGWGHTOR	3749827131 Dell Way	\N	RDGXRAF	LA	45004	US	1	MIQGWGHTOR@dell.com	3749827131	1	5943793706130237	2010/08	user5887	password	73	40000	F
5888	TOUXBC	NHZUPSIGKM	5326082298 Dell Way	\N	NHEONOY	SD	73609	US	1	NHZUPSIGKM@dell.com	5326082298	2	4240879293996841	2009/09	user5888	password	54	100000	F
5889	HXHJLP	IFEBOLLBYS	8611910839 Dell Way	\N	GNFULAM	VT	40466	US	1	IFEBOLLBYS@dell.com	8611910839	1	1346037627197802	2009/02	user5889	password	40	80000	F
5890	PZMFIS	KJGWVIVNOI	2064087938 Dell Way	\N	SITTVRC	NY	83775	US	1	KJGWVIVNOI@dell.com	2064087938	1	9648468659725040	2010/08	user5890	password	18	20000	M
5891	MGZERI	LNDUJRIRKR	8863980990 Dell Way	\N	LDNCFFX	KS	29322	US	1	LNDUJRIRKR@dell.com	8863980990	4	8665048718918116	2012/10	user5891	password	53	40000	F
5892	LOSUZG	YUPPDGZVRD	6343340363 Dell Way	\N	IUINSRT	NE	48764	US	1	YUPPDGZVRD@dell.com	6343340363	3	3024101469200104	2008/10	user5892	password	38	60000	F
5893	ZHJGGD	VWGCVBUZKO	6798553239 Dell Way	\N	IYGZRVK	ID	35698	US	1	VWGCVBUZKO@dell.com	6798553239	2	1880523358006030	2012/11	user5893	password	51	100000	F
5894	VDKYZG	FBCHWBRLKP	9262967565 Dell Way	\N	SJHNUOV	MI	89110	US	1	FBCHWBRLKP@dell.com	9262967565	2	7652399342507125	2009/04	user5894	password	84	20000	F
5895	IDKOIM	RQITHTDXMN	3959477175 Dell Way	\N	EAHSVTP	OR	18448	US	1	RQITHTDXMN@dell.com	3959477175	1	4267417669296265	2009/04	user5895	password	75	60000	F
5896	EDUQUK	ZORTRPFETF	7124835839 Dell Way	\N	MMBFBUI	MA	91528	US	1	ZORTRPFETF@dell.com	7124835839	4	2888119301758706	2010/03	user5896	password	65	80000	F
5897	LHCVHR	NBICHNWMAI	5083571577 Dell Way	\N	OGKIOUG	IA	45330	US	1	NBICHNWMAI@dell.com	5083571577	4	6102608731016517	2008/05	user5897	password	81	60000	M
5898	ZJXQXZ	ZZGNWSNEHT	3676253676 Dell Way	\N	OPIIWOS	IN	32531	US	1	ZZGNWSNEHT@dell.com	3676253676	3	6311058322899044	2008/12	user5898	password	34	20000	F
5899	DUFCTF	IGBBUFINUY	3186882018 Dell Way	\N	WDVKWDQ	DE	58766	US	1	IGBBUFINUY@dell.com	3186882018	2	5445554304402322	2010/06	user5899	password	77	80000	F
5900	ASAFBG	GDBMLPHKLK	4516861204 Dell Way	\N	FVHJMLX	OR	78469	US	1	GDBMLPHKLK@dell.com	4516861204	1	3094579000491649	2009/10	user5900	password	53	40000	M
5901	MLOTRS	UEDJLOVWUQ	6088271707 Dell Way	\N	DDDOBWI	MI	15865	US	1	UEDJLOVWUQ@dell.com	6088271707	4	8859883903991432	2008/11	user5901	password	46	60000	F
5902	ZHZRCE	VMPKHMEYPI	9065817273 Dell Way	\N	CEKYNVA	CA	52371	US	1	VMPKHMEYPI@dell.com	9065817273	1	3997245661914349	2009/09	user5902	password	63	40000	M
5903	PYBTTO	JDWVIVLRXQ	7212175996 Dell Way	\N	BWDXXFJ	SC	41746	US	1	JDWVIVLRXQ@dell.com	7212175996	1	1217497382778674	2009/05	user5903	password	90	100000	F
5904	BRAQBE	MXNIIEFZGC	7381941633 Dell Way	\N	CDZIMTR	DE	85398	US	1	MXNIIEFZGC@dell.com	7381941633	3	2643786447122693	2011/05	user5904	password	51	80000	F
5905	MKDRXA	EFJJLIPNLT	3566610579 Dell Way	\N	NUFGLKC	DE	90105	US	1	EFJJLIPNLT@dell.com	3566610579	5	3722822227515280	2011/08	user5905	password	46	40000	F
5906	OXYOCE	YMQHCDSVRM	6889696868 Dell Way	\N	BXYMACJ	IN	98463	US	1	YMQHCDSVRM@dell.com	6889696868	1	6677104931790382	2008/04	user5906	password	68	60000	F
5907	QEIVCV	LJXPCTGOVE	3146537102 Dell Way	\N	NHFQQNP	IL	61652	US	1	LJXPCTGOVE@dell.com	3146537102	2	8882790090516210	2012/12	user5907	password	25	60000	F
5908	LKFGWO	ELRYSFTXTA	1691172908 Dell Way	\N	CJRQZYF	GA	36340	US	1	ELRYSFTXTA@dell.com	1691172908	1	3009803878609091	2008/09	user5908	password	41	80000	F
5909	NWZCBL	TZDZTBSUEC	9224841850 Dell Way	\N	LUBKZGR	AZ	46274	US	1	TZDZTBSUEC@dell.com	9224841850	2	2027394841425121	2009/11	user5909	password	34	80000	M
5910	FVUQPU	TONVGHZITT	2569899677 Dell Way	\N	KDTRVVB	OR	14526	US	1	TONVGHZITT@dell.com	2569899677	5	9155281739309432	2010/09	user5910	password	64	60000	M
5911	KFDEZR	SUYZUHSNRW	1435272789 Dell Way	\N	HIRCJKD	ND	44561	US	1	SUYZUHSNRW@dell.com	1435272789	5	1890950156375765	2011/07	user5911	password	65	20000	M
5912	UHTLAO	KZIRSWIPEQ	2455347823 Dell Way	\N	GGARKPB	MI	59846	US	1	KZIRSWIPEQ@dell.com	2455347823	1	2007117404136806	2012/03	user5912	password	82	60000	M
5913	QANFKN	OCGLKVPBCV	4129957336 Dell Way	\N	CTGRVRG	WY	82580	US	1	OCGLKVPBCV@dell.com	4129957336	5	1341593475081026	2009/05	user5913	password	59	100000	F
5914	CCVQRX	WCIRRJUNMO	3676649185 Dell Way	\N	UDJLJJG	OR	25854	US	1	WCIRRJUNMO@dell.com	3676649185	5	6068289707414806	2012/11	user5914	password	89	100000	M
5915	VOQTLS	BDKLXYXLSB	9574238885 Dell Way	\N	VELFLEK	OR	21468	US	1	BDKLXYXLSB@dell.com	9574238885	3	9842481018509716	2012/07	user5915	password	86	80000	F
5916	OMOHOR	SZPQXBJYXN	6829267466 Dell Way	\N	JCYNNRR	MN	34676	US	1	SZPQXBJYXN@dell.com	6829267466	2	8396953474730254	2010/02	user5916	password	86	20000	M
5917	NLFFDF	UUCWDBTQLW	4475779833 Dell Way	\N	PZJHQVO	IL	28898	US	1	UUCWDBTQLW@dell.com	4475779833	5	4241480729077011	2009/01	user5917	password	18	100000	F
5918	FAPLVJ	NRMPLDAHTZ	1388796355 Dell Way	\N	RAPMPXR	WY	78963	US	1	NRMPLDAHTZ@dell.com	1388796355	2	8124568766448648	2008/02	user5918	password	36	40000	F
5919	WSAFGR	SVCVVKPVBQ	8954600009 Dell Way	\N	LNFIFFC	IA	57991	US	1	SVCVVKPVBQ@dell.com	8954600009	2	7170021435245872	2008/07	user5919	password	81	100000	F
5920	WFNOXI	RTDBJZCZKQ	6759675156 Dell Way	\N	FSVKVBY	OH	42967	US	1	RTDBJZCZKQ@dell.com	6759675156	5	9445782380644232	2010/10	user5920	password	33	40000	F
5921	SYYAPS	EQBDSAOIGH	5777336036 Dell Way	\N	ERCFPUP	IA	66760	US	1	EQBDSAOIGH@dell.com	5777336036	4	5144110866356641	2011/02	user5921	password	54	60000	F
5922	LMQDRH	FVZGJIMQMD	6645152785 Dell Way	\N	TSTNIZE	TX	76868	US	1	FVZGJIMQMD@dell.com	6645152785	3	8901628581341357	2008/01	user5922	password	86	60000	M
5923	PSFWXA	WDKEQBRTUK	1784168682 Dell Way	\N	MISMNOF	CT	22610	US	1	WDKEQBRTUK@dell.com	1784168682	2	2600518400780856	2008/10	user5923	password	69	80000	M
5924	XMLXIP	IMGJEZEOMN	2433161499 Dell Way	\N	HYAVDDZ	HI	45876	US	1	IMGJEZEOMN@dell.com	2433161499	2	2985569805838168	2012/11	user5924	password	73	80000	F
5925	FRQVAD	BKIBOWNCEL	8725452464 Dell Way	\N	CAPGZVQ	DC	15995	US	1	BKIBOWNCEL@dell.com	8725452464	1	9359460743144156	2011/10	user5925	password	36	100000	F
5926	XRMATW	IVKFIMJUPK	2577484080 Dell Way	\N	JVJEMNG	KS	58713	US	1	IVKFIMJUPK@dell.com	2577484080	5	3814811557065696	2010/10	user5926	password	74	40000	F
5927	GJFCRA	MXJZHDORMK	4933762626 Dell Way	\N	BRWPXED	CA	20982	US	1	MXJZHDORMK@dell.com	4933762626	3	9132932878099384	2009/11	user5927	password	44	60000	F
5928	ONWPAU	YZBBOSOZUG	1302170568 Dell Way	\N	VJEAMGD	VT	80055	US	1	YZBBOSOZUG@dell.com	1302170568	1	6618669274263085	2009/07	user5928	password	77	100000	F
5929	ROCMNC	NPQGEQAKLJ	2894194806 Dell Way	\N	OLWVPTP	NJ	90033	US	1	NPQGEQAKLJ@dell.com	2894194806	1	5036844684276730	2008/12	user5929	password	56	80000	M
5930	PEBRSR	IYVYYFKHTW	3285836965 Dell Way	\N	DOLXEBU	LA	14912	US	1	IYVYYFKHTW@dell.com	3285836965	2	1345651544164866	2011/02	user5930	password	61	40000	F
5931	RCZIKX	DJWIUECQIR	2708967692 Dell Way	\N	BFVCAED	IL	61825	US	1	DJWIUECQIR@dell.com	2708967692	1	7189921489916743	2011/06	user5931	password	89	60000	M
5932	ZTYXXI	TFCXISFZTL	3238855098 Dell Way	\N	UWMZATO	GA	82807	US	1	TFCXISFZTL@dell.com	3238855098	5	3317051042802632	2009/06	user5932	password	75	20000	F
5933	SCBBVH	DSQWYPQJKM	6810420627 Dell Way	\N	VKNPYSK	GA	72962	US	1	DSQWYPQJKM@dell.com	6810420627	3	2167253873776644	2010/08	user5933	password	41	20000	M
5934	KFOSIH	IEFXVOIHKS	4072434451 Dell Way	\N	UZRNJWF	AL	36052	US	1	IEFXVOIHKS@dell.com	4072434451	3	9268337335437536	2011/08	user5934	password	64	20000	M
5935	ETDLBI	RZDGHLQAGQ	7644489428 Dell Way	\N	RTANZAV	IN	53288	US	1	RZDGHLQAGQ@dell.com	7644489428	5	1781709478702396	2009/01	user5935	password	83	60000	M
5936	AAVJRV	NXCYODEEUY	8004190567 Dell Way	\N	EIXFDFR	UT	25880	US	1	NXCYODEEUY@dell.com	8004190567	2	2767497135326266	2011/10	user5936	password	88	80000	M
5937	UBMPPJ	SNXVSBQRGY	2375587866 Dell Way	\N	OLCUDZY	WA	29402	US	1	SNXVSBQRGY@dell.com	2375587866	4	1156351227313280	2008/04	user5937	password	77	100000	F
5938	HNZQGM	OCFPSWWRLI	9477269167 Dell Way	\N	TFMSEKY	KY	99757	US	1	OCFPSWWRLI@dell.com	9477269167	3	3735244463663548	2011/05	user5938	password	67	20000	M
5939	QRDDFF	JVYGSPSAIY	2618296949 Dell Way	\N	MBCWZLW	VT	91851	US	1	JVYGSPSAIY@dell.com	2618296949	4	3548982817213982	2012/09	user5939	password	31	60000	F
5940	IRQOAM	MGEBZEKXRL	6789282368 Dell Way	\N	ZOKLKHJ	NH	97124	US	1	MGEBZEKXRL@dell.com	6789282368	3	7150236824527384	2012/12	user5940	password	24	20000	M
5941	SRQEEX	JFWOPTFBTT	4467925261 Dell Way	\N	LFETPTS	HI	29198	US	1	JFWOPTFBTT@dell.com	4467925261	1	2678456320427358	2010/03	user5941	password	77	20000	M
5942	MKBKTG	HHWBMXVFJA	5837627221 Dell Way	\N	JCPDUVJ	DE	88436	US	1	HHWBMXVFJA@dell.com	5837627221	4	1568910378962755	2009/11	user5942	password	86	100000	F
5943	ZFZGMG	DNTBIZKJJM	7572598146 Dell Way	\N	ZMGUVLR	MA	17206	US	1	DNTBIZKJJM@dell.com	7572598146	4	9271595838014036	2011/07	user5943	password	28	80000	M
5944	CXHJAU	CCDCMNLYMY	6795094128 Dell Way	\N	FHUQYDS	NY	89782	US	1	CCDCMNLYMY@dell.com	6795094128	2	5037597475573421	2011/01	user5944	password	34	100000	M
5945	MHYHKA	LMMYXLKVQR	1828171822 Dell Way	\N	PHQTAHQ	NV	66638	US	1	LMMYXLKVQR@dell.com	1828171822	3	6676720089279116	2009/05	user5945	password	57	100000	M
5946	MDANOM	AMKLXGCPVK	7861542184 Dell Way	\N	FPKNGCD	KS	57849	US	1	AMKLXGCPVK@dell.com	7861542184	4	8985797708388419	2009/06	user5946	password	55	80000	M
5947	NIDAIQ	KUNQWDMGIC	2632077406 Dell Way	\N	RWITZQH	OR	37325	US	1	KUNQWDMGIC@dell.com	2632077406	1	7945627220440657	2011/11	user5947	password	43	40000	F
5948	MGMDRG	RICUVJDXBZ	9676189604 Dell Way	\N	GVYXDSE	IN	76896	US	1	RICUVJDXBZ@dell.com	9676189604	5	6257444564718754	2009/03	user5948	password	71	100000	F
5949	FYELPN	OJIYNGAMMV	5237219850 Dell Way	\N	LJYDOGX	NC	32590	US	1	OJIYNGAMMV@dell.com	5237219850	5	5375872102566064	2009/08	user5949	password	89	60000	M
5950	EWERLO	AJBGJOTFAD	2270497073 Dell Way	\N	DDSKAFR	MS	17304	US	1	AJBGJOTFAD@dell.com	2270497073	4	7693213976453990	2008/02	user5950	password	42	40000	M
5951	NYKCZU	DGDSZJSDNW	8838485420 Dell Way	\N	VXXBOKD	OH	20321	US	1	DGDSZJSDNW@dell.com	8838485420	5	3155303424689919	2009/02	user5951	password	34	80000	F
5952	QVBKZH	ORGXKKKGFI	9162639671 Dell Way	\N	DGXOJPR	IA	48054	US	1	ORGXKKKGFI@dell.com	9162639671	3	5804794380441309	2008/03	user5952	password	61	80000	M
5953	QEYXTQ	ERAOCHUKKA	8672529374 Dell Way	\N	HZKXQQI	ND	19179	US	1	ERAOCHUKKA@dell.com	8672529374	4	3583926866762340	2010/06	user5953	password	38	20000	M
5954	GAKWFB	XUDEOOPOVO	1025309957 Dell Way	\N	ZTFPBTS	VT	49972	US	1	XUDEOOPOVO@dell.com	1025309957	2	9081848619040104	2009/06	user5954	password	57	60000	F
5955	YKRZHL	CMZQBOMQNF	9451404294 Dell Way	\N	VDHPWFB	TX	60422	US	1	CMZQBOMQNF@dell.com	9451404294	1	1187789336312562	2010/09	user5955	password	54	40000	F
5956	EJJQMV	PDXEQNSVJV	9185090699 Dell Way	\N	DYRIZOX	WA	72321	US	1	PDXEQNSVJV@dell.com	9185090699	3	4285881229210645	2010/10	user5956	password	50	60000	F
5957	VFRQUU	OZKBRGLMKK	8087910965 Dell Way	\N	ESKSPIK	MT	76221	US	1	OZKBRGLMKK@dell.com	8087910965	5	5925778133794666	2009/06	user5957	password	71	20000	M
5958	KSMEGL	PICVTPFDUY	2192022368 Dell Way	\N	NNOWYBP	OR	97220	US	1	PICVTPFDUY@dell.com	2192022368	5	5157644412945956	2012/12	user5958	password	28	40000	M
5959	QLYCAG	FWZUCDPBRC	1588336981 Dell Way	\N	PNBQCUP	HI	76301	US	1	FWZUCDPBRC@dell.com	1588336981	1	7597225766628981	2009/05	user5959	password	48	100000	M
5960	JYVPDS	PYUTNVKQKX	9529936562 Dell Way	\N	SBAMRGF	OK	40076	US	1	PYUTNVKQKX@dell.com	9529936562	5	7176870250608773	2009/10	user5960	password	53	80000	M
5961	HIWAYU	URIQBZBZRD	3285062645 Dell Way	\N	ZDUGJNO	IN	50138	US	1	URIQBZBZRD@dell.com	3285062645	4	3076895242556929	2011/05	user5961	password	87	20000	M
5962	UBRPWI	XMKWOJORJR	6894718261 Dell Way	\N	MPBZEJL	ME	12128	US	1	XMKWOJORJR@dell.com	6894718261	1	4808675252832472	2011/03	user5962	password	28	60000	F
5963	UZCDXP	NUEXIVGAIW	8725692257 Dell Way	\N	BHBKSML	LA	65929	US	1	NUEXIVGAIW@dell.com	8725692257	5	8374457460828126	2008/05	user5963	password	22	100000	F
5964	EYHTMB	XJKTQKBNMJ	5126042027 Dell Way	\N	OXBAILQ	FL	46572	US	1	XJKTQKBNMJ@dell.com	5126042027	1	8059480953961612	2010/01	user5964	password	29	80000	M
5965	LLLNIU	XCLIDZVMNS	2534768987 Dell Way	\N	ONAZEFK	NM	47704	US	1	XCLIDZVMNS@dell.com	2534768987	1	4890077304095030	2009/10	user5965	password	46	80000	F
5966	VHPQER	CNUBIHOAVC	2156184501 Dell Way	\N	BVHHFXS	MA	15523	US	1	CNUBIHOAVC@dell.com	2156184501	4	9050992017146200	2010/06	user5966	password	29	40000	M
5967	TZXKBL	FDTNRTJUVE	9323532884 Dell Way	\N	BCJZUTA	WA	50372	US	1	FDTNRTJUVE@dell.com	9323532884	3	9241664292290808	2008/10	user5967	password	65	100000	M
5968	OGWZMZ	TZQNILINNL	9997669386 Dell Way	\N	XMFQNDC	ME	62359	US	1	TZQNILINNL@dell.com	9997669386	3	4374758668243885	2011/05	user5968	password	29	40000	M
5969	AFBZZB	QMKBUXOFUA	5865286240 Dell Way	\N	LLNPNYE	MT	51802	US	1	QMKBUXOFUA@dell.com	5865286240	1	8199443557299674	2011/05	user5969	password	46	80000	M
5970	LRPMHC	XJXUXDPYOA	7328891022 Dell Way	\N	MDOLIBX	TX	32100	US	1	XJXUXDPYOA@dell.com	7328891022	3	6827380301896483	2008/03	user5970	password	38	60000	M
5971	WAFZXO	WSLZIKNJWR	8930355341 Dell Way	\N	XIZZFVG	WA	44135	US	1	WSLZIKNJWR@dell.com	8930355341	1	6579756846185774	2008/07	user5971	password	56	20000	M
5972	SAMGWF	SVODIXAAVI	8475608742 Dell Way	\N	ZVOVBMF	WA	54611	US	1	SVODIXAAVI@dell.com	8475608742	1	1402184882666915	2009/02	user5972	password	63	20000	F
5973	DIZIBU	XEDUEEQNDL	1699661832 Dell Way	\N	BZMNFKA	AL	54341	US	1	XEDUEEQNDL@dell.com	1699661832	2	6573043964337558	2011/06	user5973	password	72	100000	M
5974	SEWNBA	RWFVMSZXUY	9177476536 Dell Way	\N	KIEUIEH	ME	60584	US	1	RWFVMSZXUY@dell.com	9177476536	1	1168884150683879	2011/12	user5974	password	77	40000	F
5975	RXERPA	XKMPJKJIUR	3312307531 Dell Way	\N	MPARWLG	SC	61092	US	1	XKMPJKJIUR@dell.com	3312307531	3	5579232274089009	2008/10	user5975	password	62	80000	M
5976	UKIUIS	HXCRHLMZYB	5839105181 Dell Way	\N	AQYLWSA	CO	24953	US	1	HXCRHLMZYB@dell.com	5839105181	1	9958386901766064	2008/12	user5976	password	71	100000	F
5977	BSQUZO	XRWJDWHFWX	1314011020 Dell Way	\N	DIUWJXB	VA	17026	US	1	XRWJDWHFWX@dell.com	1314011020	1	9956592512317004	2011/12	user5977	password	42	100000	M
5978	ZQRONJ	KWNGESDCWL	8421390934 Dell Way	\N	WTUTURV	TN	75717	US	1	KWNGESDCWL@dell.com	8421390934	4	7302485089283437	2008/06	user5978	password	46	20000	F
5979	BRPLCL	YJQRMSOXOI	8482644361 Dell Way	\N	SICKDYD	WV	58808	US	1	YJQRMSOXOI@dell.com	8482644361	1	9802642536815256	2009/04	user5979	password	20	40000	M
5980	QTACRJ	SJWKYTZGMI	8555236831 Dell Way	\N	JWMIALW	TX	61460	US	1	SJWKYTZGMI@dell.com	8555236831	1	8527958145365120	2012/05	user5980	password	74	60000	F
5981	VPUFHE	BSCVSJHATE	4074742282 Dell Way	\N	MBEYXAN	PA	18540	US	1	BSCVSJHATE@dell.com	4074742282	4	5062036825343967	2008/02	user5981	password	57	100000	M
5982	IDAMET	OZMYHMRLZT	3033779767 Dell Way	\N	QXQRKKU	PA	14568	US	1	OZMYHMRLZT@dell.com	3033779767	5	2732047610916197	2011/10	user5982	password	85	20000	M
5983	YODSDD	EBKQTWQMNO	7999728239 Dell Way	\N	DEZNZSP	FL	65022	US	1	EBKQTWQMNO@dell.com	7999728239	5	4873462984804064	2011/01	user5983	password	45	80000	M
5984	NISQNU	ADNWUZKIDP	1576003103 Dell Way	\N	HROAGTQ	AK	72123	US	1	ADNWUZKIDP@dell.com	1576003103	4	7578661992680282	2010/05	user5984	password	42	100000	M
5985	BOFWPJ	JMEJWMNLUE	2354118619 Dell Way	\N	ZUKSLKK	MS	21990	US	1	JMEJWMNLUE@dell.com	2354118619	5	5495511532761157	2010/11	user5985	password	33	60000	F
5986	LKBUUN	YDKLQWFUVA	3264941798 Dell Way	\N	FOLQZYT	DC	90799	US	1	YDKLQWFUVA@dell.com	3264941798	4	8099763148464263	2010/02	user5986	password	36	100000	M
5987	HSIVQM	FCDCIYXIDM	4865780061 Dell Way	\N	UTMTNQQ	PA	31915	US	1	FCDCIYXIDM@dell.com	4865780061	2	4638097073417157	2011/02	user5987	password	87	100000	M
5988	HVLTBO	WDWUBEYNZR	3537448186 Dell Way	\N	ASFQJYW	SC	25128	US	1	WDWUBEYNZR@dell.com	3537448186	3	3524650387000293	2009/06	user5988	password	24	60000	F
5989	OGICDL	YYMDWACOAV	2372734180 Dell Way	\N	TQESNZW	SD	49863	US	1	YYMDWACOAV@dell.com	2372734180	1	9044130251742900	2009/07	user5989	password	29	80000	M
5990	MWZXVX	JYUKBIKXCB	4451431712 Dell Way	\N	BUPBRKM	TN	50320	US	1	JYUKBIKXCB@dell.com	4451431712	1	1107131388504058	2010/11	user5990	password	79	20000	M
5991	UXNSHM	MROVCLYDMS	6299032177 Dell Way	\N	SOKDAFO	ME	35956	US	1	MROVCLYDMS@dell.com	6299032177	5	2211627526674419	2010/12	user5991	password	80	40000	M
5992	JYFWLW	KGZVECIXVW	9576884524 Dell Way	\N	HZXNOIV	CT	36422	US	1	KGZVECIXVW@dell.com	9576884524	3	3429703163448721	2012/10	user5992	password	30	20000	M
5993	JBEGMK	FHPIQNDNVD	3875892828 Dell Way	\N	LJRTEUB	CT	42666	US	1	FHPIQNDNVD@dell.com	3875892828	5	2429736549500376	2010/02	user5993	password	83	100000	F
5994	BCQMHY	CPOPTBKWMT	8728047212 Dell Way	\N	NGYIHBS	NJ	96810	US	1	CPOPTBKWMT@dell.com	8728047212	1	1684211281593889	2011/12	user5994	password	35	100000	F
5995	WHIVKX	JZRLKOYECF	2457700929 Dell Way	\N	CKNDCDC	WV	31545	US	1	JZRLKOYECF@dell.com	2457700929	4	2741001256275922	2010/07	user5995	password	34	40000	M
5996	OCFMMF	DXPRWTTBVE	2115285420 Dell Way	\N	OYHRBGY	GA	98693	US	1	DXPRWTTBVE@dell.com	2115285420	4	5758506443351508	2009/11	user5996	password	45	100000	M
5997	PJLVNJ	KFFEYGADVZ	2687128354 Dell Way	\N	KNARLFR	NE	85498	US	1	KFFEYGADVZ@dell.com	2687128354	5	7611218327190728	2010/10	user5997	password	70	20000	F
5998	EZSNJX	TOWZOAVNKI	4148477172 Dell Way	\N	OCUUTJP	WI	35493	US	1	TOWZOAVNKI@dell.com	4148477172	3	2021380264312029	2008/08	user5998	password	41	40000	M
5999	BTAZMO	VMDWIQHQFJ	2727232232 Dell Way	\N	LZDUPBC	WI	61362	US	1	VMDWIQHQFJ@dell.com	2727232232	1	3060826685745269	2010/04	user5999	password	80	60000	F
6000	WNNKJZ	NFHEMYJWKJ	8793646936 Dell Way	\N	ZEYBGXQ	MN	92028	US	1	NFHEMYJWKJ@dell.com	8793646936	5	2458527770824730	2011/07	user6000	password	30	60000	F
6001	RZKRNQ	ZRDXBZHLZM	4214268075 Dell Way	\N	KBTHSEF	ND	23997	US	1	ZRDXBZHLZM@dell.com	4214268075	2	7078812733292580	2010/11	user6001	password	70	40000	M
6002	DWJTVB	WTDWAOWNYY	3489225920 Dell Way	\N	GFQLKEP	RI	52130	US	1	WTDWAOWNYY@dell.com	3489225920	2	3912235591094941	2012/07	user6002	password	29	20000	F
6003	NWFOTY	RQZFNMELTJ	1417712199 Dell Way	\N	BEUGUOS	AR	87910	US	1	RQZFNMELTJ@dell.com	1417712199	1	4310177059844136	2009/03	user6003	password	71	80000	F
6004	YHVWZL	VFYHJKATMF	4016342332 Dell Way	\N	NSZCLBZ	MS	19290	US	1	VFYHJKATMF@dell.com	4016342332	4	3474716225638986	2008/06	user6004	password	41	100000	M
6005	DWRPRX	OZGYAZKFND	6864665391 Dell Way	\N	FQPHPBJ	WA	80032	US	1	OZGYAZKFND@dell.com	6864665391	5	2885506633203477	2012/12	user6005	password	85	20000	M
6006	QRNNGM	TENTPTGSYX	4346576920 Dell Way	\N	IGMJPKE	ID	47119	US	1	TENTPTGSYX@dell.com	4346576920	2	4656908620614559	2009/05	user6006	password	36	100000	F
6007	ULHHEL	UYBNFTMCBS	8344167894 Dell Way	\N	PLIZQOK	WY	82898	US	1	UYBNFTMCBS@dell.com	8344167894	2	2384260470978915	2008/03	user6007	password	31	100000	M
6008	LDVXXU	YKZSXBUPRG	5160827029 Dell Way	\N	YRWMBWI	UT	23912	US	1	YKZSXBUPRG@dell.com	5160827029	5	4376068076584488	2011/10	user6008	password	20	20000	M
6009	WAVQYG	QRDSLTJSRA	9577528418 Dell Way	\N	OECLMZP	WA	92030	US	1	QRDSLTJSRA@dell.com	9577528418	3	7351745659951121	2012/09	user6009	password	63	100000	M
6010	LNRRDI	UVUOFMFFBJ	8913455597 Dell Way	\N	HMWGBUE	AK	43422	US	1	UVUOFMFFBJ@dell.com	8913455597	1	1611454564146697	2010/11	user6010	password	74	100000	F
6011	LPMUKI	PYNCETENBQ	6496386962 Dell Way	\N	KISEMSO	LA	75807	US	1	PYNCETENBQ@dell.com	6496386962	5	6280685352627189	2009/10	user6011	password	87	100000	F
6012	LQUUGT	IIXBMLDDVL	9137850867 Dell Way	\N	WAYPOII	DE	26908	US	1	IIXBMLDDVL@dell.com	9137850867	3	9890882850624622	2012/05	user6012	password	46	40000	F
6013	EBHYKP	WMCHPGDBCD	5435791310 Dell Way	\N	ZSRIAVN	VT	45324	US	1	WMCHPGDBCD@dell.com	5435791310	4	8090131788514555	2012/01	user6013	password	78	20000	F
6014	CANSWA	VDPCHREKRW	2037575228 Dell Way	\N	CZXYMUI	WV	61671	US	1	VDPCHREKRW@dell.com	2037575228	5	6736652033869178	2012/11	user6014	password	74	20000	M
6015	ITUIPX	XRFOWPFSSF	6738728411 Dell Way	\N	QQRLYQA	AZ	54211	US	1	XRFOWPFSSF@dell.com	6738728411	1	4667972623836249	2010/01	user6015	password	41	80000	M
6016	CAKAYB	FNXVTQNYGD	2258979299 Dell Way	\N	PRCGSET	KS	26538	US	1	FNXVTQNYGD@dell.com	2258979299	4	3178283531218767	2010/06	user6016	password	22	60000	F
6017	MPLNUY	LPRCCPJGFB	9500792270 Dell Way	\N	JLTNECS	KS	84075	US	1	LPRCCPJGFB@dell.com	9500792270	4	3602430089842528	2008/05	user6017	password	75	60000	M
6018	FATELI	WOLMXSRZBD	9266680472 Dell Way	\N	SPIUHQQ	HI	49359	US	1	WOLMXSRZBD@dell.com	9266680472	2	8166522874031217	2011/09	user6018	password	71	100000	M
6019	MCEVZS	HLQZDQBHJQ	5241244802 Dell Way	\N	PDXGUDR	OH	42900	US	1	HLQZDQBHJQ@dell.com	5241244802	3	1609305846504867	2009/05	user6019	password	74	80000	F
6020	YNLRUW	HUAYVHHLWL	9344340326 Dell Way	\N	JCFMUXW	ID	38439	US	1	HUAYVHHLWL@dell.com	9344340326	3	6900624603033066	2011/02	user6020	password	25	80000	M
6021	NHLKPF	KNBSUMOFWR	3859316508 Dell Way	\N	LJLIFSR	CT	25995	US	1	KNBSUMOFWR@dell.com	3859316508	5	3974199070129544	2010/06	user6021	password	90	100000	M
6022	LJKRUY	SMSEAYBSKK	4489559644 Dell Way	\N	ETPWKSB	OK	60919	US	1	SMSEAYBSKK@dell.com	4489559644	1	1397111333440989	2009/02	user6022	password	78	100000	F
6023	FMGDES	WJTVKMFUQY	7573563586 Dell Way	\N	KNJDOCR	WI	30287	US	1	WJTVKMFUQY@dell.com	7573563586	2	3938322772737593	2010/02	user6023	password	75	80000	M
6024	AXUTUD	NPOZVIPUSC	8097950343 Dell Way	\N	EWRGNQM	ID	95881	US	1	NPOZVIPUSC@dell.com	8097950343	5	1902839223854243	2010/08	user6024	password	70	80000	M
6025	MJHQWX	EVTNKOGNSC	8808093176 Dell Way	\N	EYQVKXT	FL	74596	US	1	EVTNKOGNSC@dell.com	8808093176	4	3836668438278139	2010/05	user6025	password	78	20000	M
6026	DSPBXL	ULWIRJATOZ	3953599574 Dell Way	\N	KJJHDOA	AK	38486	US	1	ULWIRJATOZ@dell.com	3953599574	4	7262559046037496	2008/09	user6026	password	50	40000	F
6027	BIIMDT	IMKSNEHMOR	4618219566 Dell Way	\N	VWVKWVS	GA	50082	US	1	IMKSNEHMOR@dell.com	4618219566	2	2157020454294979	2012/08	user6027	password	56	100000	M
6028	VJDOSP	ZLCDSOSKKP	6713300152 Dell Way	\N	FUMBNRN	VT	14569	US	1	ZLCDSOSKKP@dell.com	6713300152	4	7369511388707907	2008/08	user6028	password	69	20000	F
6029	VPSKOD	NSWBLGMAMH	9450725700 Dell Way	\N	MNUEARG	NY	47907	US	1	NSWBLGMAMH@dell.com	9450725700	5	1466459700837731	2011/11	user6029	password	21	60000	F
6030	TWZXKR	TMDAYDMFQZ	2292459076 Dell Way	\N	ZVARBSC	WY	58254	US	1	TMDAYDMFQZ@dell.com	2292459076	4	4413677470758557	2008/02	user6030	password	76	100000	M
6031	UWJMPV	PQTTCZJCZF	7637140435 Dell Way	\N	DQGVTGJ	UT	88064	US	1	PQTTCZJCZF@dell.com	7637140435	1	9647187971975656	2010/01	user6031	password	86	40000	M
6032	HUNCJD	WDFWMHVRLM	9945283208 Dell Way	\N	YGFEPCA	KY	25390	US	1	WDFWMHVRLM@dell.com	9945283208	5	2842612537089735	2012/03	user6032	password	24	40000	M
6033	PIJSFM	YBZGXRRJPX	1524260005 Dell Way	\N	PTNRUWW	SC	76302	US	1	YBZGXRRJPX@dell.com	1524260005	4	9465680805034936	2008/12	user6033	password	86	80000	F
6034	IMMVKN	UQLMIUBFKV	3452594635 Dell Way	\N	TBPPXKI	WY	20369	US	1	UQLMIUBFKV@dell.com	3452594635	1	1418261628597974	2009/11	user6034	password	40	60000	F
6035	UIUHDL	SPTNRZXMSZ	6847702297 Dell Way	\N	CIXMQWP	VT	11647	US	1	SPTNRZXMSZ@dell.com	6847702297	1	9162269426044078	2012/08	user6035	password	37	80000	M
6036	BADMTS	GHJFFWYEYG	9003973136 Dell Way	\N	CLXZAUZ	NY	93851	US	1	GHJFFWYEYG@dell.com	9003973136	4	6267945060972125	2008/05	user6036	password	60	40000	F
6037	SSELYL	VEQRCVPIXB	5868328766 Dell Way	\N	FWBAVTY	OR	45506	US	1	VEQRCVPIXB@dell.com	5868328766	5	7871427658945323	2008/02	user6037	password	29	100000	M
6038	IGTTBX	KTZFIIDJOZ	4302123714 Dell Way	\N	LOVFNOP	AZ	50518	US	1	KTZFIIDJOZ@dell.com	4302123714	1	6044022630900145	2010/01	user6038	password	45	100000	F
6039	DQIAAB	AGKJJUXIGL	7589554585 Dell Way	\N	ELZSBBE	ME	30271	US	1	AGKJJUXIGL@dell.com	7589554585	5	3089318568352610	2008/10	user6039	password	54	40000	F
6040	VGLXHS	HQBCNKIZOU	5195151652 Dell Way	\N	ZHWAMHG	GA	30546	US	1	HQBCNKIZOU@dell.com	5195151652	2	1331065691541880	2012/07	user6040	password	51	80000	M
6041	XRCPZS	RBGCKFQFFY	6287193447 Dell Way	\N	BFKILPO	VT	91960	US	1	RBGCKFQFFY@dell.com	6287193447	5	4987513014115393	2008/08	user6041	password	35	100000	F
6042	IPIAGJ	HIUNZZSYBX	3811370928 Dell Way	\N	JJJYXGW	MS	21068	US	1	HIUNZZSYBX@dell.com	3811370928	3	7987614872399718	2010/07	user6042	password	25	100000	F
6043	KXJUES	PSSPKQQIZA	8470208127 Dell Way	\N	RYXYVKB	CT	97802	US	1	PSSPKQQIZA@dell.com	8470208127	4	5491754700895399	2012/07	user6043	password	62	40000	F
6044	ZEQRTI	JJTAZBZZTY	8236868436 Dell Way	\N	XRTISWH	ND	58632	US	1	JJTAZBZZTY@dell.com	8236868436	3	1757289813831448	2010/11	user6044	password	56	40000	F
6045	EBUNKD	GKDIKDBIAT	6044650821 Dell Way	\N	BJMYRAM	MO	56318	US	1	GKDIKDBIAT@dell.com	6044650821	5	4326526192482561	2008/04	user6045	password	46	40000	F
6046	EUSIAD	LJNOKWPEYZ	5707686645 Dell Way	\N	QWQQJCD	VT	99364	US	1	LJNOKWPEYZ@dell.com	5707686645	1	3262826185207814	2012/04	user6046	password	58	20000	F
6047	HKBKWL	YKWVAATZQQ	9939436969 Dell Way	\N	QGZTKXT	WA	91136	US	1	YKWVAATZQQ@dell.com	9939436969	5	2552164324559271	2010/12	user6047	password	33	100000	F
6048	HGESFP	OAQOUQEKHL	4387039141 Dell Way	\N	KAWHTUF	PA	68438	US	1	OAQOUQEKHL@dell.com	4387039141	2	6272647975012661	2010/02	user6048	password	85	100000	F
6049	CPPSEQ	JTKZYVHKFH	3579577958 Dell Way	\N	GNBBTVS	CO	21950	US	1	JTKZYVHKFH@dell.com	3579577958	4	3466144036501646	2009/08	user6049	password	66	40000	F
6050	GBJWKD	HKBCRLIZSW	3458355844 Dell Way	\N	BTPWLSZ	OR	47551	US	1	HKBCRLIZSW@dell.com	3458355844	5	1106587977148592	2012/04	user6050	password	33	20000	F
6051	PBTSID	ULVGTUYQWS	4260551612 Dell Way	\N	FSEYSXJ	WY	86782	US	1	ULVGTUYQWS@dell.com	4260551612	5	2179518572054803	2010/02	user6051	password	51	20000	F
6052	EXNIRY	EYSYWIVOON	6509482173 Dell Way	\N	SMGQVFM	GA	23278	US	1	EYSYWIVOON@dell.com	6509482173	4	3352042010053992	2008/12	user6052	password	49	40000	M
6053	YPOXTM	PSIYNXNBQA	9185465785 Dell Way	\N	HHWNTBQ	LA	85777	US	1	PSIYNXNBQA@dell.com	9185465785	3	8209756202530117	2009/09	user6053	password	66	40000	F
6054	FFARVT	ATGYGHOHOV	8412365376 Dell Way	\N	DBPESZA	NJ	45659	US	1	ATGYGHOHOV@dell.com	8412365376	5	1786571707576513	2010/04	user6054	password	44	80000	F
6055	KJHDJA	JHHRWOFSRH	7862982736 Dell Way	\N	IWAHXQR	OK	63228	US	1	JHHRWOFSRH@dell.com	7862982736	2	8712841308210046	2008/11	user6055	password	41	60000	F
6056	PRPPAX	XSUMXMEFVB	3543078579 Dell Way	\N	FCYVTRL	NC	87227	US	1	XSUMXMEFVB@dell.com	3543078579	4	7674968140665442	2011/03	user6056	password	89	20000	M
6057	PUWMSO	HFMUJSPKXR	6430692556 Dell Way	\N	ITLAEZW	MI	67854	US	1	HFMUJSPKXR@dell.com	6430692556	1	8473697107285262	2010/03	user6057	password	67	20000	F
6058	ORTCYY	PSIHISEZBY	9062209254 Dell Way	\N	LBCKYOB	NC	62779	US	1	PSIHISEZBY@dell.com	9062209254	1	8411309776362033	2010/04	user6058	password	81	20000	M
6059	QFXOVQ	WCYPHYRFJT	3301515281 Dell Way	\N	HURVWFL	PA	38535	US	1	WCYPHYRFJT@dell.com	3301515281	2	6465690606273711	2008/06	user6059	password	59	80000	M
6060	MILCEO	AUVYLBIEJC	9788421100 Dell Way	\N	WFYBQSJ	VA	12148	US	1	AUVYLBIEJC@dell.com	9788421100	1	5067725417669863	2010/10	user6060	password	25	20000	F
6061	OCGCDB	YCNAKRJNOP	6811343026 Dell Way	\N	MPGEZDF	WA	23927	US	1	YCNAKRJNOP@dell.com	6811343026	3	9232791197020560	2011/06	user6061	password	89	40000	M
6062	GKTHJV	UKFMUSAJEP	8273155484 Dell Way	\N	PJPTONX	GA	99952	US	1	UKFMUSAJEP@dell.com	8273155484	5	5449612084310502	2011/03	user6062	password	25	20000	M
6063	VIBQCL	WPFPPOUFED	8311996415 Dell Way	\N	UXSIVXI	NJ	85114	US	1	WPFPPOUFED@dell.com	8311996415	3	1730334325693547	2012/06	user6063	password	72	80000	M
6064	UKWFGM	LWCAQHEUCC	3562194276 Dell Way	\N	MKXJTOF	ND	95766	US	1	LWCAQHEUCC@dell.com	3562194276	3	4584774485789240	2008/03	user6064	password	30	100000	M
6065	BBWNMS	PMJXRDZUPK	6364545363 Dell Way	\N	SZEGESF	MN	25118	US	1	PMJXRDZUPK@dell.com	6364545363	3	4309379320591688	2011/04	user6065	password	87	100000	F
6066	UIVNXI	WUZZUUPFMO	6465363330 Dell Way	\N	JSTBXFG	MT	73585	US	1	WUZZUUPFMO@dell.com	6465363330	2	1183792170137167	2010/02	user6066	password	45	40000	F
6067	FWINTC	NTXHICUXMM	6245208440 Dell Way	\N	QOKWUYO	MA	29122	US	1	NTXHICUXMM@dell.com	6245208440	5	3672571167349815	2012/04	user6067	password	69	20000	F
6068	ASYDFR	ANADHXPUOD	6677712644 Dell Way	\N	EKYDZII	ND	34532	US	1	ANADHXPUOD@dell.com	6677712644	3	6393936351872981	2009/09	user6068	password	77	40000	F
6069	TLPLMC	LPJJEDXIII	5033316820 Dell Way	\N	GLHOUVW	ME	41226	US	1	LPJJEDXIII@dell.com	5033316820	4	1235349524766206	2009/01	user6069	password	47	20000	M
6070	ZMACYP	LHUPFDXNJJ	1165348932 Dell Way	\N	VYDQVOZ	ID	37942	US	1	LHUPFDXNJJ@dell.com	1165348932	3	4535964048467577	2010/07	user6070	password	85	60000	F
6071	YMYNYF	INLLLYVUTU	3046397817 Dell Way	\N	YKPNKWV	ME	43552	US	1	INLLLYVUTU@dell.com	3046397817	5	9181653574574740	2008/03	user6071	password	84	20000	M
6072	WQRBYE	MKQLFLFAJP	7872699591 Dell Way	\N	QXAMTLW	WV	33319	US	1	MKQLFLFAJP@dell.com	7872699591	1	5486713396850974	2011/03	user6072	password	34	60000	M
6073	WPUBCE	ROKCTLMJBK	6071703350 Dell Way	\N	JODUKCB	DE	31392	US	1	ROKCTLMJBK@dell.com	6071703350	5	5089999688323587	2011/05	user6073	password	39	80000	M
6074	CSBHKP	RNJDATEKDT	4118598156 Dell Way	\N	OXDRZHX	ND	22871	US	1	RNJDATEKDT@dell.com	4118598156	2	5596478446386755	2011/01	user6074	password	52	80000	M
6075	NZDDRQ	NVRGABJTPH	8535928015 Dell Way	\N	WGHEDVI	MS	24322	US	1	NVRGABJTPH@dell.com	8535928015	1	2467391809448600	2009/11	user6075	password	83	100000	M
6076	AZORNJ	ITJKDCZKZG	8405693771 Dell Way	\N	REKNNXR	KY	12459	US	1	ITJKDCZKZG@dell.com	8405693771	4	8996336220763625	2011/07	user6076	password	72	80000	M
6077	HLAQUU	AEXDEHDLZI	6693498492 Dell Way	\N	VMVSDET	WI	83023	US	1	AEXDEHDLZI@dell.com	6693498492	4	3861955353524536	2009/06	user6077	password	78	80000	M
6078	VIQPJV	NMZUPKUXGG	1147796070 Dell Way	\N	TYKXSJS	KS	12789	US	1	NMZUPKUXGG@dell.com	1147796070	4	5135899203829468	2012/05	user6078	password	41	80000	M
6079	ZHBUUO	TPDEJBKQUJ	8666895323 Dell Way	\N	ARBJKKK	MD	20070	US	1	TPDEJBKQUJ@dell.com	8666895323	2	5461008258163929	2008/11	user6079	password	33	20000	F
6080	GXZURO	YWYAHOVRON	7658457740 Dell Way	\N	TXXDHHG	DE	58312	US	1	YWYAHOVRON@dell.com	7658457740	2	5073691186960787	2012/06	user6080	password	65	40000	F
6081	QACFZY	DZGRVXFIQD	5491222730 Dell Way	\N	FTLNAPB	PA	94486	US	1	DZGRVXFIQD@dell.com	5491222730	4	4720162099692971	2008/11	user6081	password	77	80000	M
6082	XZXWDW	CURZAAQEFK	6112147144 Dell Way	\N	PSKFUEE	ID	88043	US	1	CURZAAQEFK@dell.com	6112147144	3	7972713386639953	2009/03	user6082	password	68	40000	F
6083	PDILFC	DFDDWHJGXC	5337455325 Dell Way	\N	RDWVHDS	TX	60018	US	1	DFDDWHJGXC@dell.com	5337455325	2	7883792323991657	2008/06	user6083	password	88	80000	M
6084	HFVKJB	NMXVWETYVW	3371001887 Dell Way	\N	VRDYJZM	TX	30259	US	1	NMXVWETYVW@dell.com	3371001887	1	7509836597368122	2009/10	user6084	password	43	60000	F
6085	EXJFLW	DGSHARCWMU	9708814896 Dell Way	\N	ALEAXAG	FL	14016	US	1	DGSHARCWMU@dell.com	9708814896	3	8526815142948181	2009/12	user6085	password	79	60000	M
6086	FSGBWN	UDNLGKYAKJ	1723633178 Dell Way	\N	ELHFRMG	NM	89869	US	1	UDNLGKYAKJ@dell.com	1723633178	5	8268524030689151	2012/06	user6086	password	63	20000	F
6087	WFAKZD	XLKIJLSTQE	2855394294 Dell Way	\N	AVVNBMK	DC	49287	US	1	XLKIJLSTQE@dell.com	2855394294	1	8932309783529491	2012/03	user6087	password	21	80000	F
6088	BDJFBV	QJFBCYRGZN	8943839506 Dell Way	\N	CMOOXSA	CA	81135	US	1	QJFBCYRGZN@dell.com	8943839506	5	9904292269609870	2012/08	user6088	password	45	100000	M
6089	TFVOVE	TWGSONRBPE	2075754470 Dell Way	\N	QEBIEED	AR	19411	US	1	TWGSONRBPE@dell.com	2075754470	5	7816215672995896	2010/12	user6089	password	56	40000	F
6090	JVZNPW	UHKHZLXEBB	3576531832 Dell Way	\N	GKFLNGN	NV	29036	US	1	UHKHZLXEBB@dell.com	3576531832	1	2520149108953774	2012/05	user6090	password	41	20000	F
6091	HRVDMD	OUDZRHBSOM	5785700099 Dell Way	\N	XZADNRJ	SC	84197	US	1	OUDZRHBSOM@dell.com	5785700099	4	3146822816226631	2012/10	user6091	password	52	20000	F
6092	HIYLWS	OWKWXCKKAK	2141135670 Dell Way	\N	KEXBNSX	AR	38574	US	1	OWKWXCKKAK@dell.com	2141135670	5	1872543149162084	2011/01	user6092	password	59	100000	F
6093	NJGGXC	QUASFKSPVW	6706346257 Dell Way	\N	NWKFTLN	VA	42022	US	1	QUASFKSPVW@dell.com	6706346257	3	4840657104272396	2009/05	user6093	password	77	80000	M
6094	BZREPL	EIRPBGKYUH	6076470805 Dell Way	\N	IZBUNYD	DE	48131	US	1	EIRPBGKYUH@dell.com	6076470805	2	8454785295762123	2009/02	user6094	password	60	60000	F
6095	GPQSUZ	JJAQUYKBHJ	3622457976 Dell Way	\N	CBXBFBM	RI	49789	US	1	JJAQUYKBHJ@dell.com	3622457976	1	5767099599819631	2012/08	user6095	password	60	20000	F
6096	GVZFEJ	GUDEFFMPIO	5835088422 Dell Way	\N	MJTOVOA	CO	72616	US	1	GUDEFFMPIO@dell.com	5835088422	5	3542486691381782	2008/02	user6096	password	52	40000	M
6097	LODUUY	XZDCMSKAFU	3811456901 Dell Way	\N	UTPITRA	IN	69532	US	1	XZDCMSKAFU@dell.com	3811456901	3	7900766155682505	2011/10	user6097	password	69	40000	F
6098	VZDTXC	XAOPLPUFKO	9208002816 Dell Way	\N	USIMTQD	AZ	15168	US	1	XAOPLPUFKO@dell.com	9208002816	5	8527911521028728	2011/01	user6098	password	30	60000	F
6099	HFYKCZ	ZSLPMQZBLR	9148917075 Dell Way	\N	JYLABMB	WY	40651	US	1	ZSLPMQZBLR@dell.com	9148917075	4	4559133041184396	2008/01	user6099	password	50	40000	F
6100	KUJKUB	VJOMIQXAAV	7284342132 Dell Way	\N	MAXZCXH	WY	56253	US	1	VJOMIQXAAV@dell.com	7284342132	1	6089929648209364	2008/06	user6100	password	78	60000	F
6101	FYAGTK	VFTLDTMZGM	8992126066 Dell Way	\N	XFOVMOI	FL	66506	US	1	VFTLDTMZGM@dell.com	8992126066	2	1742631868459284	2011/11	user6101	password	42	100000	M
6102	JEPUAU	NMYHYXNKVS	3307454748 Dell Way	\N	ZQFOYKE	TN	77070	US	1	NMYHYXNKVS@dell.com	3307454748	3	6686086170375348	2010/06	user6102	password	51	100000	M
6103	ATQVGD	TOBRBMMUMC	8088696831 Dell Way	\N	AAAKFWE	MN	46087	US	1	TOBRBMMUMC@dell.com	8088696831	1	8711750860325993	2009/01	user6103	password	53	40000	M
6104	DCAHWO	INQVALHCLI	3188019836 Dell Way	\N	DWNZAZK	SC	12992	US	1	INQVALHCLI@dell.com	3188019836	1	1390231999568641	2011/04	user6104	password	76	100000	F
6105	VDHJMU	AIVMQXXYAT	5900028529 Dell Way	\N	MATMKON	NV	63844	US	1	AIVMQXXYAT@dell.com	5900028529	2	9184185634367168	2009/04	user6105	password	41	20000	F
6106	PNXKOF	FAVCYUDRGE	5688637325 Dell Way	\N	LSOAFFP	RI	64259	US	1	FAVCYUDRGE@dell.com	5688637325	1	8773531211540104	2012/04	user6106	password	37	60000	M
6107	EVJJBJ	EEHYIZFMLY	7662018485 Dell Way	\N	BLEHBYW	NE	12828	US	1	EEHYIZFMLY@dell.com	7662018485	3	3601216210052371	2008/11	user6107	password	23	20000	M
6108	LOTUTY	CSGCXSNVUZ	3230050173 Dell Way	\N	ABBYYQY	NY	16557	US	1	CSGCXSNVUZ@dell.com	3230050173	4	9501389849931004	2009/11	user6108	password	66	80000	F
6109	KODJRV	PTTIHPCGPE	9829218777 Dell Way	\N	INCZMTA	OK	50562	US	1	PTTIHPCGPE@dell.com	9829218777	1	3790034139994532	2011/10	user6109	password	69	20000	F
6110	WKARAT	KIAZLHOPQC	3117705698 Dell Way	\N	SPOMQHY	NH	38592	US	1	KIAZLHOPQC@dell.com	3117705698	2	2040426291059702	2012/04	user6110	password	52	80000	M
6111	MMTGWB	GWNOLDFNVU	8210453778 Dell Way	\N	CIKJGAR	MO	33041	US	1	GWNOLDFNVU@dell.com	8210453778	3	6056931159924716	2009/03	user6111	password	38	80000	M
6112	AZOCGL	QVXTALPUNX	1192384911 Dell Way	\N	EXEFPQL	MA	16029	US	1	QVXTALPUNX@dell.com	1192384911	4	3597147944383323	2009/05	user6112	password	89	40000	F
6113	OKPZAL	XULIJFWHKT	5061190894 Dell Way	\N	LPICBSE	CA	43710	US	1	XULIJFWHKT@dell.com	5061190894	2	7941834459546954	2010/09	user6113	password	28	100000	F
6114	TZEEWY	PFIVBPGVBW	1312581386 Dell Way	\N	EEXXIAG	RI	46376	US	1	PFIVBPGVBW@dell.com	1312581386	2	2084924528375268	2008/03	user6114	password	36	100000	F
6115	KDBJTG	ROIHUEJQIN	1839482400 Dell Way	\N	OFWOMQZ	MT	85758	US	1	ROIHUEJQIN@dell.com	1839482400	4	1329794701654464	2009/08	user6115	password	33	80000	M
6116	HCMNTB	WBVBKMJYBP	3556321064 Dell Way	\N	UPCKPPG	NY	36541	US	1	WBVBKMJYBP@dell.com	3556321064	1	9359270432032646	2010/10	user6116	password	67	80000	M
6117	EHQFES	BFCOPAPFUF	1838724290 Dell Way	\N	HFUWLME	OR	55199	US	1	BFCOPAPFUF@dell.com	1838724290	2	3499621433205903	2011/01	user6117	password	29	100000	F
6118	UEMMFS	PTIPJNKOUQ	6603205065 Dell Way	\N	JRBVVUI	VT	13738	US	1	PTIPJNKOUQ@dell.com	6603205065	4	1410360490437597	2011/08	user6118	password	44	60000	M
6119	WBAOQU	XGDKRSEHBV	3291326030 Dell Way	\N	JXREGOF	UT	33539	US	1	XGDKRSEHBV@dell.com	3291326030	4	9040828117169440	2011/03	user6119	password	68	60000	F
6120	SAYMYF	PIWINEKJNH	7822981033 Dell Way	\N	AROPXLW	DC	19377	US	1	PIWINEKJNH@dell.com	7822981033	4	3990397969726473	2010/03	user6120	password	63	20000	F
6121	OQFTGN	QOBUYKIGLA	7343715800 Dell Way	\N	VBXGXBJ	NY	84961	US	1	QOBUYKIGLA@dell.com	7343715800	1	1573470867704600	2009/04	user6121	password	42	100000	M
6122	NQCBHR	CBPNKWZKRA	3412979334 Dell Way	\N	HYYJIQF	AL	75996	US	1	CBPNKWZKRA@dell.com	3412979334	2	9933321205899120	2010/03	user6122	password	81	20000	M
6123	ZEEQHF	GVPDUAVVIU	1919969080 Dell Way	\N	TRCJXDC	DE	55869	US	1	GVPDUAVVIU@dell.com	1919969080	4	7807781068608166	2012/11	user6123	password	65	100000	F
6124	VPJAWE	QZZRVUZPOR	2071652974 Dell Way	\N	SXOWASJ	CT	52003	US	1	QZZRVUZPOR@dell.com	2071652974	1	4152870006393641	2011/01	user6124	password	48	60000	M
6125	UPNYGN	XXISXYGOQE	6681132381 Dell Way	\N	CMFVVIH	WV	49373	US	1	XXISXYGOQE@dell.com	6681132381	4	5477767848409713	2008/04	user6125	password	29	100000	M
6126	RTEFRC	NJZLQOCUQO	3220866780 Dell Way	\N	ZLKITJT	LA	19618	US	1	NJZLQOCUQO@dell.com	3220866780	3	4680879095103592	2010/03	user6126	password	41	20000	F
6127	MHRPVB	OGRCJLTXLF	3004830451 Dell Way	\N	ITYSMIV	PA	77137	US	1	OGRCJLTXLF@dell.com	3004830451	1	9860054960940034	2010/03	user6127	password	90	20000	M
6128	RQISEP	KHYWBWHGFB	3523072099 Dell Way	\N	FXOOSHH	WI	50201	US	1	KHYWBWHGFB@dell.com	3523072099	3	7169561109505594	2009/07	user6128	password	33	100000	F
6129	ORIDBQ	CYRZFYEHEC	3208147179 Dell Way	\N	VSVCATO	IN	32216	US	1	CYRZFYEHEC@dell.com	3208147179	3	7936481277458371	2010/07	user6129	password	84	20000	F
6130	GDGWGE	OGJNKQRNMK	1895450555 Dell Way	\N	IPKCDSI	MA	35824	US	1	OGJNKQRNMK@dell.com	1895450555	5	8136006040964276	2008/11	user6130	password	88	40000	M
6131	FDGJRM	TFXKWLWHTL	5427210320 Dell Way	\N	SVPKEZS	ID	83362	US	1	TFXKWLWHTL@dell.com	5427210320	2	6935386974830181	2010/07	user6131	password	65	80000	M
6132	XAJKTO	IDKTARNLJJ	5267739566 Dell Way	\N	AUNZMUV	WY	14574	US	1	IDKTARNLJJ@dell.com	5267739566	3	6259555869735778	2008/02	user6132	password	36	20000	F
6133	PLWDUZ	OOZGBLQKMK	4005323838 Dell Way	\N	YMXSHXT	PA	40185	US	1	OOZGBLQKMK@dell.com	4005323838	5	4850692870095372	2010/12	user6133	password	56	20000	F
6134	KIEJXT	JDUVTFHEDT	7820717907 Dell Way	\N	CVAZPUI	VT	69202	US	1	JDUVTFHEDT@dell.com	7820717907	3	6299175223335624	2009/09	user6134	password	89	80000	F
6135	EBXXLA	RGUXNZAGCW	3772881505 Dell Way	\N	HBLBKJS	DE	86896	US	1	RGUXNZAGCW@dell.com	3772881505	3	5820250123739243	2009/02	user6135	password	57	60000	F
6136	LIQMAW	HYKGYRIVYK	1064261469 Dell Way	\N	GAVQSZM	AL	48485	US	1	HYKGYRIVYK@dell.com	1064261469	2	6001702561043203	2010/10	user6136	password	72	100000	F
6137	JMDFTB	QZAHIVFTCG	5582330854 Dell Way	\N	OSYNEZY	GA	38532	US	1	QZAHIVFTCG@dell.com	5582330854	4	1790951897390186	2009/09	user6137	password	32	80000	F
6138	IVYKLY	LSHHYAJEOC	5871532778 Dell Way	\N	DCHDBML	ND	31866	US	1	LSHHYAJEOC@dell.com	5871532778	5	9896988991647960	2011/05	user6138	password	32	20000	F
6139	EMSCXL	KFKKOOZRSB	7216788083 Dell Way	\N	ZWCLHRS	TX	52757	US	1	KFKKOOZRSB@dell.com	7216788083	3	9020480162929744	2012/09	user6139	password	28	20000	F
6140	WEBHOH	RYWGYNZAMV	2353614929 Dell Way	\N	CYDUQZG	KY	59691	US	1	RYWGYNZAMV@dell.com	2353614929	2	2974055078346282	2009/04	user6140	password	45	20000	F
6141	LLASCZ	OJXCIXPDAN	9869293046 Dell Way	\N	GUEFBNT	GA	79585	US	1	OJXCIXPDAN@dell.com	9869293046	3	1579704145435243	2009/08	user6141	password	55	100000	F
6142	NNEMCN	KFWHUZIIFD	9042172406 Dell Way	\N	NLEBFKV	FL	91234	US	1	KFWHUZIIFD@dell.com	9042172406	3	5972999031189830	2010/05	user6142	password	64	100000	M
6143	VLAJVF	FDAELIKOWW	6497600691 Dell Way	\N	TXBETGB	NM	83364	US	1	FDAELIKOWW@dell.com	6497600691	1	2633448949549347	2009/12	user6143	password	24	20000	F
6144	CKGHPK	HUVQFKMBEK	4514619100 Dell Way	\N	DIDKKTF	WY	83091	US	1	HUVQFKMBEK@dell.com	4514619100	2	8163743745069952	2010/04	user6144	password	33	60000	M
6145	MWIWED	RVICHKHSOP	2931080859 Dell Way	\N	VYZPDZK	NC	30456	US	1	RVICHKHSOP@dell.com	2931080859	1	5740128324367106	2010/07	user6145	password	35	100000	F
6146	OTPRLL	ANSLVLZKGX	2320817410 Dell Way	\N	KWBKHOQ	MS	62095	US	1	ANSLVLZKGX@dell.com	2320817410	5	2342526032123714	2009/10	user6146	password	60	100000	M
6147	FQAQRO	JCJUBUBYEY	3695015821 Dell Way	\N	ZPFOFSD	KY	69474	US	1	JCJUBUBYEY@dell.com	3695015821	4	5437804405111820	2012/09	user6147	password	23	20000	F
6148	CSZQBB	AWDUXBZVBO	9277159841 Dell Way	\N	BQTTUCL	CA	85436	US	1	AWDUXBZVBO@dell.com	9277159841	5	5657232328783721	2012/01	user6148	password	78	20000	M
6149	USWWSS	ZNPBMLDBMU	3414163840 Dell Way	\N	UGOXRRT	NE	68398	US	1	ZNPBMLDBMU@dell.com	3414163840	3	7464285789988936	2008/08	user6149	password	54	100000	F
6150	JUCBTP	QVCCYDOTYU	4081310455 Dell Way	\N	IWLZPAQ	VA	62818	US	1	QVCCYDOTYU@dell.com	4081310455	5	3127462195698172	2012/11	user6150	password	62	20000	M
6151	SGKHXG	KZFONYMHGJ	6219274442 Dell Way	\N	TFZTVWI	FL	86044	US	1	KZFONYMHGJ@dell.com	6219274442	1	7603702635038645	2008/03	user6151	password	46	100000	F
6152	VEJBPJ	GDWFQELAXQ	4789854431 Dell Way	\N	ZRMVARR	NH	73035	US	1	GDWFQELAXQ@dell.com	4789854431	4	9304772621951998	2012/09	user6152	password	46	80000	M
6153	TSLDYP	ZDFEPFCGFU	1214473208 Dell Way	\N	SBUKTKC	DE	26365	US	1	ZDFEPFCGFU@dell.com	1214473208	5	8655091059859843	2010/08	user6153	password	69	20000	F
6154	EHGTHK	ZMZFOGKIZL	6065303801 Dell Way	\N	DJENMJS	MO	39462	US	1	ZMZFOGKIZL@dell.com	6065303801	5	9447652890346944	2009/02	user6154	password	35	60000	F
6155	NERYDD	YISETBDEEM	9990618253 Dell Way	\N	JSYTLLB	WY	40985	US	1	YISETBDEEM@dell.com	9990618253	2	4888759077992290	2009/09	user6155	password	77	80000	M
6156	NRZRPI	JUBLXGQJQI	5920605259 Dell Way	\N	IJUULUC	ME	13613	US	1	JUBLXGQJQI@dell.com	5920605259	4	7599859892856330	2009/06	user6156	password	61	100000	F
6157	PNSXXM	ZIJGYTWHCG	6469877878 Dell Way	\N	BWRVZCW	MT	80114	US	1	ZIJGYTWHCG@dell.com	6469877878	5	2883051364216953	2009/10	user6157	password	41	80000	F
6158	BSENSN	XYLRVTUBUQ	8583492176 Dell Way	\N	TQQWNDQ	CO	13481	US	1	XYLRVTUBUQ@dell.com	8583492176	2	8204918863717467	2008/02	user6158	password	24	40000	M
6159	GTNTRM	FIHYCJTTDJ	4153642344 Dell Way	\N	JZWNPZO	MN	35623	US	1	FIHYCJTTDJ@dell.com	4153642344	4	4526285674422979	2010/10	user6159	password	33	80000	M
6160	TMFFRO	NQRXJKASUA	3116936759 Dell Way	\N	PHPOVBV	FL	71827	US	1	NQRXJKASUA@dell.com	3116936759	4	5606900031212718	2010/04	user6160	password	23	20000	M
6161	HLMVYC	NWLXWERWTZ	7845449031 Dell Way	\N	MIUOEZG	MA	63888	US	1	NWLXWERWTZ@dell.com	7845449031	5	9255598502233624	2012/01	user6161	password	69	20000	F
6162	EZKGMG	SKDWBAQANY	3975660291 Dell Way	\N	VBCVIMK	CA	38798	US	1	SKDWBAQANY@dell.com	3975660291	5	4251869201194495	2008/01	user6162	password	78	20000	F
6163	GLNNDX	QAZRQAEOVG	8371655562 Dell Way	\N	RQODBRL	MD	61852	US	1	QAZRQAEOVG@dell.com	8371655562	3	6630655714310706	2011/08	user6163	password	65	100000	F
6164	EKGBAG	ASXAWMWDDN	6008053679 Dell Way	\N	SHPJSZY	NC	47009	US	1	ASXAWMWDDN@dell.com	6008053679	1	1377875687088817	2009/01	user6164	password	27	40000	F
6165	JKNQLF	NLBZIFDVXK	8625334809 Dell Way	\N	KGDKERU	OR	88246	US	1	NLBZIFDVXK@dell.com	8625334809	5	9518655338324608	2012/04	user6165	password	48	40000	M
6166	XZDCMP	EMXJPTHAEN	6718975899 Dell Way	\N	DOSVJLR	GA	45515	US	1	EMXJPTHAEN@dell.com	6718975899	1	7315655196551234	2008/07	user6166	password	48	100000	F
6167	OBZEGL	CQBVXCALFO	7359869526 Dell Way	\N	EBYPTDA	LA	38887	US	1	CQBVXCALFO@dell.com	7359869526	3	8592021835967899	2008/05	user6167	password	41	80000	F
6168	HWSTZJ	VVGXVSDJWE	6510371933 Dell Way	\N	IMXLMGT	GA	71424	US	1	VVGXVSDJWE@dell.com	6510371933	2	1532123697921633	2012/01	user6168	password	55	40000	M
6169	FZWOVR	VSNOVWLAFX	9308241124 Dell Way	\N	XQKEKPW	AL	93827	US	1	VSNOVWLAFX@dell.com	9308241124	5	9623435435350984	2010/03	user6169	password	80	80000	F
6170	SFAKBT	XPPUAPZYNQ	8449524909 Dell Way	\N	ISBYOBW	MO	13208	US	1	XPPUAPZYNQ@dell.com	8449524909	5	3175016173161566	2011/07	user6170	password	50	60000	M
6171	MVVFTK	UNLKNJXERP	6041939991 Dell Way	\N	FQEHMQI	KS	59821	US	1	UNLKNJXERP@dell.com	6041939991	1	2044586233794689	2008/06	user6171	password	83	60000	F
6172	SRZDLN	OVBXTFPILF	8270811850 Dell Way	\N	MSSDBAR	NH	13223	US	1	OVBXTFPILF@dell.com	8270811850	4	5163481100928039	2011/01	user6172	password	70	60000	M
6173	SNFGBB	IYUOODZTQS	9792727780 Dell Way	\N	LTTMLJN	ID	95841	US	1	IYUOODZTQS@dell.com	9792727780	5	1238466201350092	2011/05	user6173	password	74	60000	M
6174	ZRYAZX	UNMYMFOERI	3324280719 Dell Way	\N	YDUHRBG	NM	12435	US	1	UNMYMFOERI@dell.com	3324280719	2	4605485669802874	2008/09	user6174	password	39	100000	F
6175	GAJEUW	QTIWHNNQLR	9131590549 Dell Way	\N	KTIMZYN	HI	36165	US	1	QTIWHNNQLR@dell.com	9131590549	2	1257377455476671	2009/03	user6175	password	48	60000	F
6176	UQBQHU	ZDCNRSYIDS	9384753768 Dell Way	\N	QPRPCWX	WY	22061	US	1	ZDCNRSYIDS@dell.com	9384753768	2	4403860472608358	2009/08	user6176	password	63	20000	F
6177	RTPLTS	NGJGFSJXJY	9555314891 Dell Way	\N	OZBLWBO	SD	31996	US	1	NGJGFSJXJY@dell.com	9555314891	1	9142357158940286	2010/04	user6177	password	32	40000	F
6178	USUNGB	XMGPVDYUSY	1207853299 Dell Way	\N	VDVWSQD	NV	80044	US	1	XMGPVDYUSY@dell.com	1207853299	2	1607981954235583	2009/06	user6178	password	26	20000	F
6179	XNLYKY	FATIZOAXJE	2662276586 Dell Way	\N	SGWIJND	MD	78088	US	1	FATIZOAXJE@dell.com	2662276586	4	3163616302888840	2009/08	user6179	password	49	40000	F
6180	WEOUJP	OSOCTMMXFT	3780617830 Dell Way	\N	UNCIRNB	TN	21783	US	1	OSOCTMMXFT@dell.com	3780617830	1	7913001270033420	2011/05	user6180	password	85	80000	M
6181	NKYCZQ	RCKDPIIICW	8667577870 Dell Way	\N	LKNYMJC	SC	56909	US	1	RCKDPIIICW@dell.com	8667577870	3	9020746225491168	2011/02	user6181	password	50	40000	M
6182	JJOABR	LFGTNPWKAH	7643865659 Dell Way	\N	YZUIBOW	VT	20215	US	1	LFGTNPWKAH@dell.com	7643865659	4	3485097158234566	2008/12	user6182	password	80	60000	F
6183	LPKCAP	ITDXQOYXNX	6766809232 Dell Way	\N	RVZGRWJ	ME	61385	US	1	ITDXQOYXNX@dell.com	6766809232	3	5945807211101056	2010/02	user6183	password	84	100000	M
6184	IATYJN	BGDQFBDCSY	1719030113 Dell Way	\N	CZQYIBN	WV	68862	US	1	BGDQFBDCSY@dell.com	1719030113	3	8253623533993960	2012/05	user6184	password	57	40000	F
6185	HGTUIA	YYGZBIRALR	2666865657 Dell Way	\N	RKZSXZJ	WY	50619	US	1	YYGZBIRALR@dell.com	2666865657	5	8697331216651947	2011/04	user6185	password	37	20000	M
6186	BUWBSU	IRWRJXCAOM	3751373093 Dell Way	\N	AHKZRJL	TX	43184	US	1	IRWRJXCAOM@dell.com	3751373093	3	7057609711773694	2010/08	user6186	password	34	80000	F
6187	CSCXAU	TREQTEFFFN	1245402569 Dell Way	\N	PFEZRAJ	WV	65393	US	1	TREQTEFFFN@dell.com	1245402569	3	2812630720902234	2009/03	user6187	password	60	40000	M
6188	RFWMZO	QQHVWNBJDG	4583011088 Dell Way	\N	OCYPMXF	MS	50558	US	1	QQHVWNBJDG@dell.com	4583011088	4	6611740223132075	2012/01	user6188	password	54	80000	F
6189	JDHYUX	FQUTRDWYRZ	8422171800 Dell Way	\N	WGLTLYF	TX	70013	US	1	FQUTRDWYRZ@dell.com	8422171800	5	7691142556723208	2009/07	user6189	password	21	80000	M
6190	IQLGVB	APSDLQVKMC	2749138772 Dell Way	\N	WGOULKL	ID	31022	US	1	APSDLQVKMC@dell.com	2749138772	3	7677260825876147	2009/04	user6190	password	47	60000	M
6191	VUTXVI	QYUGUFTWBA	8037306407 Dell Way	\N	KVLUHSB	MO	38381	US	1	QYUGUFTWBA@dell.com	8037306407	4	6413144342135639	2008/04	user6191	password	54	20000	F
6192	GYXPOW	JVROONQPYL	7049228055 Dell Way	\N	ATTTUGB	ND	96649	US	1	JVROONQPYL@dell.com	7049228055	4	3266321652568877	2008/10	user6192	password	43	60000	M
6193	GAGDJB	UYQIOFGAFZ	3024827254 Dell Way	\N	UZUABJZ	OK	18578	US	1	UYQIOFGAFZ@dell.com	3024827254	5	8777850184123964	2010/05	user6193	password	58	100000	F
6194	UYTVTR	LBGRIGWIAW	4658487402 Dell Way	\N	CBXLAQO	IA	59365	US	1	LBGRIGWIAW@dell.com	4658487402	5	8971244754735381	2012/08	user6194	password	35	80000	M
6195	ZPJQBK	XSSDPBELDF	5098080865 Dell Way	\N	JPFADMO	NC	34986	US	1	XSSDPBELDF@dell.com	5098080865	3	9251308204140516	2011/04	user6195	password	55	80000	M
6196	WIXHFQ	AJFBNRETBU	6708918508 Dell Way	\N	ZBXLQLS	CA	95586	US	1	AJFBNRETBU@dell.com	6708918508	4	2870569008868187	2008/06	user6196	password	22	20000	M
6197	ZHZPHI	UIWMNPNHPP	8390991950 Dell Way	\N	FAFRTHP	MA	18482	US	1	UIWMNPNHPP@dell.com	8390991950	3	5963969001546503	2012/07	user6197	password	42	100000	M
6198	ILCQGL	NSZDFGSUMS	9582371511 Dell Way	\N	ADMITVK	NE	42903	US	1	NSZDFGSUMS@dell.com	9582371511	3	9108385904692114	2009/04	user6198	password	70	60000	M
6199	VGZHTR	GXWNPRZIRD	9232141310 Dell Way	\N	UZWQJLA	KS	91847	US	1	GXWNPRZIRD@dell.com	9232141310	4	2950708653312176	2011/03	user6199	password	88	60000	F
6200	YTFPZD	MMTDLBVPWU	1284121866 Dell Way	\N	LNEXNNV	MI	20360	US	1	MMTDLBVPWU@dell.com	1284121866	1	3932440101634711	2012/07	user6200	password	75	100000	F
6201	ANGDAT	WEFYZUVUFI	9074166085 Dell Way	\N	YDWLYIO	WV	46778	US	1	WEFYZUVUFI@dell.com	9074166085	5	9652794920373708	2011/11	user6201	password	36	80000	F
6202	NVLGSP	LRPFMKLVIP	4353122017 Dell Way	\N	RUNAJNK	ID	52424	US	1	LRPFMKLVIP@dell.com	4353122017	5	4290791281033307	2011/08	user6202	password	75	20000	F
6203	GKFWVW	LBIVNDECVZ	9630644052 Dell Way	\N	QVIDGPP	NJ	59674	US	1	LBIVNDECVZ@dell.com	9630644052	2	2799244754482060	2011/05	user6203	password	68	100000	M
6204	XVPTHR	CDFGHHBGXW	9661912742 Dell Way	\N	PACFQST	NE	95977	US	1	CDFGHHBGXW@dell.com	9661912742	2	3955495058558881	2011/04	user6204	password	25	60000	F
6205	SHLKKO	PQWWRDUOSV	7089120248 Dell Way	\N	RYLKSAJ	NV	42408	US	1	PQWWRDUOSV@dell.com	7089120248	2	7116737903095782	2011/11	user6205	password	78	60000	F
6206	HWOVLE	RIWUDKNYCM	5053519554 Dell Way	\N	KMEKVVU	MS	23085	US	1	RIWUDKNYCM@dell.com	5053519554	2	1063705481588840	2009/10	user6206	password	30	60000	M
6207	SJCXBL	UWOEKNHWXT	1067816549 Dell Way	\N	AHPWBCA	MT	42300	US	1	UWOEKNHWXT@dell.com	1067816549	5	2074978872202336	2008/05	user6207	password	73	100000	M
6208	WVUHPR	VUBIBXGUYN	9420884561 Dell Way	\N	JUPLUCV	SC	92304	US	1	VUBIBXGUYN@dell.com	9420884561	5	3419807576574385	2011/11	user6208	password	18	60000	M
6209	UVHLRB	NACKGXIUHD	7011295665 Dell Way	\N	JTXMOSK	MS	71915	US	1	NACKGXIUHD@dell.com	7011295665	1	6129651407711208	2011/09	user6209	password	37	60000	M
6210	OYFQLG	TWMQFGYIQR	3013286022 Dell Way	\N	GCFZNSQ	FL	91091	US	1	TWMQFGYIQR@dell.com	3013286022	5	6622188604902477	2010/04	user6210	password	30	20000	F
6211	KRSQKO	CBTJZCZRIC	2107265694 Dell Way	\N	WHQPYUM	DE	69362	US	1	CBTJZCZRIC@dell.com	2107265694	4	9858999025542290	2009/09	user6211	password	35	80000	F
6212	YIVMLW	FUWHUNQXKY	9936064787 Dell Way	\N	OZWJMBA	NJ	75155	US	1	FUWHUNQXKY@dell.com	9936064787	5	5021106864791364	2009/08	user6212	password	79	20000	M
6213	RQJOWE	KEZXVWITKH	8749309631 Dell Way	\N	QTURUKK	RI	38961	US	1	KEZXVWITKH@dell.com	8749309631	1	9315734110306948	2011/03	user6213	password	79	40000	M
6214	FXSJIW	IGSFOLQWCK	3875071963 Dell Way	\N	RUEBEYK	AR	94506	US	1	IGSFOLQWCK@dell.com	3875071963	4	1974507802631706	2008/02	user6214	password	85	40000	F
6215	QTJMBQ	EGEQWBSGSM	4732067935 Dell Way	\N	LURJESH	MS	52241	US	1	EGEQWBSGSM@dell.com	4732067935	4	6418216554448009	2009/01	user6215	password	65	100000	M
6216	ALVQQB	VHYWZFOMQJ	9291083700 Dell Way	\N	DANWIAI	OR	71807	US	1	VHYWZFOMQJ@dell.com	9291083700	1	7452068214770407	2010/01	user6216	password	52	80000	F
6217	HGDJCK	IYJNNVEXZE	8609473343 Dell Way	\N	KVMLDFD	AZ	36629	US	1	IYJNNVEXZE@dell.com	8609473343	4	3931668756995350	2009/04	user6217	password	76	80000	M
6218	YZPIHO	SVBOZYNEJJ	5468679380 Dell Way	\N	QVNWYPE	SC	30613	US	1	SVBOZYNEJJ@dell.com	5468679380	1	5339099565986544	2009/09	user6218	password	90	40000	M
6219	POADGV	FUUDIYNRPI	5289279637 Dell Way	\N	EMHTQBZ	DC	25765	US	1	FUUDIYNRPI@dell.com	5289279637	3	9132147925440224	2010/09	user6219	password	62	20000	F
6220	QEMLJH	GNPEAHUJLH	8027266823 Dell Way	\N	QFYSFCW	OH	58429	US	1	GNPEAHUJLH@dell.com	8027266823	1	3008622034452855	2009/03	user6220	password	51	20000	F
6221	YLTFRG	VWGCRQOYGT	7564169401 Dell Way	\N	WZZZWRN	NM	84914	US	1	VWGCRQOYGT@dell.com	7564169401	1	1330709536094218	2008/01	user6221	password	47	20000	F
6222	DJEJEA	QGSHVQOPNN	1946331989 Dell Way	\N	OMJGAZB	OR	11896	US	1	QGSHVQOPNN@dell.com	1946331989	5	1492684136144816	2010/01	user6222	password	56	80000	F
6223	RAPSRW	KZRBNGPAVB	5297051145 Dell Way	\N	KBBKCUK	HI	74827	US	1	KZRBNGPAVB@dell.com	5297051145	4	7962326846551151	2008/05	user6223	password	31	80000	F
6224	UKCQVB	HWPOLQJNAK	9011502197 Dell Way	\N	PLNKWTD	KS	52369	US	1	HWPOLQJNAK@dell.com	9011502197	2	8732598514296115	2008/01	user6224	password	38	100000	F
6225	KMHMUD	BIPRRDSBSD	6921234257 Dell Way	\N	PDZIGIU	CT	69666	US	1	BIPRRDSBSD@dell.com	6921234257	2	7330496169161052	2012/01	user6225	password	29	40000	M
6226	LUHPWP	FNHIGJBJYE	1585127437 Dell Way	\N	JHKSBNJ	OR	75288	US	1	FNHIGJBJYE@dell.com	1585127437	4	7959458429366351	2009/01	user6226	password	39	80000	M
6227	PGRFLF	MTLWVVUZFB	4614472130 Dell Way	\N	JXDXGXQ	KS	60454	US	1	MTLWVVUZFB@dell.com	4614472130	3	6121399914380164	2011/03	user6227	password	45	40000	F
6228	BMXGZR	RVMNQMSSWQ	8792418707 Dell Way	\N	WTXTJFH	SC	79935	US	1	RVMNQMSSWQ@dell.com	8792418707	3	9933903664350512	2009/10	user6228	password	51	40000	F
6229	JNGBFC	OSSALKWBGQ	9594646925 Dell Way	\N	ZZAEHUZ	DC	35684	US	1	OSSALKWBGQ@dell.com	9594646925	2	1528798819053918	2010/09	user6229	password	41	80000	F
6230	OVKQKD	JKPTHRAYQA	1814380129 Dell Way	\N	YUHTTLA	OK	86064	US	1	JKPTHRAYQA@dell.com	1814380129	1	5730741959065199	2010/12	user6230	password	71	100000	M
6231	DQEHAO	WTWNUUDUTY	9101747743 Dell Way	\N	CMSNNLJ	NJ	63228	US	1	WTWNUUDUTY@dell.com	9101747743	1	5649502571206540	2011/01	user6231	password	38	80000	M
6232	LBRAYL	XMFRQZLPBX	8860408275 Dell Way	\N	IPLTZBJ	UT	16743	US	1	XMFRQZLPBX@dell.com	8860408275	3	1843804826028645	2008/04	user6232	password	73	60000	F
6233	KPHWNT	BEJBPZDNHS	2653295959 Dell Way	\N	ZBSAKPC	ID	18720	US	1	BEJBPZDNHS@dell.com	2653295959	3	4447590793482959	2012/01	user6233	password	71	40000	M
6234	AFDUHI	EIYDLMKELL	9647611291 Dell Way	\N	XLVMOCP	OR	56908	US	1	EIYDLMKELL@dell.com	9647611291	4	5905792047269643	2011/01	user6234	password	31	80000	F
6235	IMNQQW	PTHBDMNPJZ	6084567237 Dell Way	\N	KWNMLGA	MD	91627	US	1	PTHBDMNPJZ@dell.com	6084567237	1	9468668957706542	2011/10	user6235	password	31	20000	F
6236	SSYOIS	WKVJXLTWVP	5042974751 Dell Way	\N	JIBPILN	VT	58624	US	1	WKVJXLTWVP@dell.com	5042974751	4	4134969915729016	2011/09	user6236	password	65	40000	F
6237	PXUHUE	DDBOXXJMHS	8785565520 Dell Way	\N	NWBZKYN	TN	65442	US	1	DDBOXXJMHS@dell.com	8785565520	3	4132602950092405	2010/10	user6237	password	76	20000	M
6238	PJNTMR	UBOSLBZDPW	1848030109 Dell Way	\N	EOGDCCT	WI	60890	US	1	UBOSLBZDPW@dell.com	1848030109	3	4549438158981502	2012/07	user6238	password	28	60000	M
6239	RFKJAM	XTXZSAOPED	9104558677 Dell Way	\N	WIFYBDN	DE	63011	US	1	XTXZSAOPED@dell.com	9104558677	1	2206030540168285	2008/07	user6239	password	21	80000	M
6240	MBUYZN	VZGWNWAQSJ	7299914078 Dell Way	\N	VQLZDPO	AR	68406	US	1	VZGWNWAQSJ@dell.com	7299914078	1	2716621770057827	2011/10	user6240	password	87	40000	M
6241	TEWHZW	NVJKWACGWT	1795669924 Dell Way	\N	RVXGKYX	CO	13352	US	1	NVJKWACGWT@dell.com	1795669924	5	8646954759024084	2008/01	user6241	password	71	80000	F
6242	QBGMPB	WAYWCETVVP	6049737303 Dell Way	\N	TCZRZCS	AZ	95941	US	1	WAYWCETVVP@dell.com	6049737303	1	1339271281380206	2009/11	user6242	password	38	100000	M
6243	NKPPGP	NDSSWOOLHQ	5638126958 Dell Way	\N	LYQNRSM	HI	83704	US	1	NDSSWOOLHQ@dell.com	5638126958	3	7611825545784087	2011/06	user6243	password	70	40000	M
6244	IXBYLE	QDBERMLIXK	2764302913 Dell Way	\N	YLBQXHL	ME	81547	US	1	QDBERMLIXK@dell.com	2764302913	2	3075747106224298	2012/07	user6244	password	22	40000	F
6245	DEWIVZ	JZRVLZTVYE	2815101018 Dell Way	\N	XPCEBNZ	IA	76471	US	1	JZRVLZTVYE@dell.com	2815101018	1	3448465089779347	2009/05	user6245	password	69	40000	M
6246	ORKOBK	FWVFQRDUOS	4814950854 Dell Way	\N	XTTKSZD	WA	23628	US	1	FWVFQRDUOS@dell.com	4814950854	1	5999973018188030	2008/07	user6246	password	28	80000	F
6247	NFHYLE	TQVLUQANNT	9721570724 Dell Way	\N	GYMGCKK	MS	63408	US	1	TQVLUQANNT@dell.com	9721570724	4	2419050582684576	2008/04	user6247	password	48	80000	M
6248	SOZXIQ	SUKIUXVOEU	2858800741 Dell Way	\N	BLWLWJB	TN	98500	US	1	SUKIUXVOEU@dell.com	2858800741	5	3633300324901938	2011/07	user6248	password	78	40000	F
6249	UGMKYG	VHBTCPXWRJ	4261846235 Dell Way	\N	TCFCEAB	LA	96590	US	1	VHBTCPXWRJ@dell.com	4261846235	5	5861432874109597	2008/04	user6249	password	68	100000	M
6250	EKNLFU	NYWDWTUFMX	9575622733 Dell Way	\N	KPBLRLK	AK	47698	US	1	NYWDWTUFMX@dell.com	9575622733	2	7701570679433645	2011/03	user6250	password	40	100000	M
6251	UHVPUT	MXQFSVSPGI	3179880070 Dell Way	\N	QSZCDZM	AZ	27168	US	1	MXQFSVSPGI@dell.com	3179880070	4	4437545296270400	2010/07	user6251	password	89	40000	M
6252	UYQOKN	EQFAJVHRMZ	2779323703 Dell Way	\N	QOCQBEV	IL	92349	US	1	EQFAJVHRMZ@dell.com	2779323703	5	5202486584894359	2008/03	user6252	password	39	100000	F
6253	XNNLRD	RSNMZEYZVN	6948452182 Dell Way	\N	CLOHGVF	MN	69391	US	1	RSNMZEYZVN@dell.com	6948452182	4	8604343078564853	2012/07	user6253	password	88	100000	F
6254	MIUQAM	DMLHLLDYNO	8489202421 Dell Way	\N	MUVIZGZ	NV	89932	US	1	DMLHLLDYNO@dell.com	8489202421	4	5230923670809716	2011/06	user6254	password	58	40000	M
6255	IXVVAI	HITSLSFAFA	5025018346 Dell Way	\N	VOACNRZ	LA	35593	US	1	HITSLSFAFA@dell.com	5025018346	1	7972159464377911	2008/06	user6255	password	61	40000	F
6256	KEJSLS	MDEFJELKAZ	2289188411 Dell Way	\N	KCNCBWJ	MT	13954	US	1	MDEFJELKAZ@dell.com	2289188411	3	5345956365112216	2011/11	user6256	password	78	20000	F
6257	FWMXJP	CPZGAJHAUJ	9350464107 Dell Way	\N	NWLKGZL	MA	54605	US	1	CPZGAJHAUJ@dell.com	9350464107	1	4313160568941385	2011/04	user6257	password	47	100000	F
6258	WWNMYC	LFDVMDPWQM	2317007558 Dell Way	\N	IBSHMCU	ME	27197	US	1	LFDVMDPWQM@dell.com	2317007558	1	5079747338313610	2010/02	user6258	password	61	60000	M
6259	CWYFIE	IDRLTNBFWC	6621544560 Dell Way	\N	XDPZXAE	AR	26311	US	1	IDRLTNBFWC@dell.com	6621544560	4	3723564621061087	2009/01	user6259	password	39	40000	M
6260	GNFKVJ	BGCPIHLLFP	5964200987 Dell Way	\N	BENBJOG	WY	25097	US	1	BGCPIHLLFP@dell.com	5964200987	2	2633288658224046	2012/07	user6260	password	23	20000	F
6261	HMWROD	TELBQXHFZM	6814138747 Dell Way	\N	TAVHHVM	TN	11216	US	1	TELBQXHFZM@dell.com	6814138747	4	5792258896399290	2011/10	user6261	password	59	20000	F
6262	LRVOLZ	ANQYUWXGPY	4899876117 Dell Way	\N	BXFXJBX	WY	75214	US	1	ANQYUWXGPY@dell.com	4899876117	4	5406195313669741	2012/09	user6262	password	72	60000	F
6263	OZWOZJ	FXDBUKQSMN	2787817316 Dell Way	\N	YJWZGWS	OH	64108	US	1	FXDBUKQSMN@dell.com	2787817316	4	4051368817687035	2012/02	user6263	password	73	60000	F
6264	PCBZHZ	CIUNZNZNMI	2900128859 Dell Way	\N	KLOHEGW	LA	95661	US	1	CIUNZNZNMI@dell.com	2900128859	2	1579018120188266	2012/10	user6264	password	29	60000	M
6265	FOEFQN	ADMNDZALJL	3681961568 Dell Way	\N	AQPHNZG	OR	33974	US	1	ADMNDZALJL@dell.com	3681961568	4	1746449942700565	2010/04	user6265	password	89	80000	M
6266	DXLRXP	DLSDLEMXED	8380883949 Dell Way	\N	NMQMSJT	WY	15792	US	1	DLSDLEMXED@dell.com	8380883949	3	3958213460631669	2011/02	user6266	password	27	100000	F
6267	PPYFTJ	XWVCITGMGS	9003879313 Dell Way	\N	DSLMLKO	ID	87911	US	1	XWVCITGMGS@dell.com	9003879313	1	9929868083912880	2008/01	user6267	password	19	80000	M
6268	YUJISF	EUOXBBDUEW	5446635393 Dell Way	\N	FRHQFON	CT	66364	US	1	EUOXBBDUEW@dell.com	5446635393	1	6802726932801307	2010/10	user6268	password	37	60000	M
6269	QUHWZB	LWDMAYRWDI	9941183594 Dell Way	\N	EUOSHRJ	RI	83518	US	1	LWDMAYRWDI@dell.com	9941183594	2	6110977830830962	2009/10	user6269	password	26	100000	M
6270	KUOMFK	PSLOJHSRMM	3743991440 Dell Way	\N	GEUXNOT	MT	86625	US	1	PSLOJHSRMM@dell.com	3743991440	4	6504584422335029	2010/09	user6270	password	30	100000	F
6271	SHRDXJ	OLTWELIQRN	4918277492 Dell Way	\N	KPBZIPV	NM	44387	US	1	OLTWELIQRN@dell.com	4918277492	1	1742463723290711	2011/11	user6271	password	58	40000	F
6272	GLCQAO	JXSUGIMTTB	8803955122 Dell Way	\N	VTKKOAU	WY	17663	US	1	JXSUGIMTTB@dell.com	8803955122	4	9728021051269026	2010/12	user6272	password	28	80000	F
6273	GHKUQI	MLOVXHPZDI	4924483901 Dell Way	\N	JNWJHWM	DE	52231	US	1	MLOVXHPZDI@dell.com	4924483901	3	4578550143167377	2010/04	user6273	password	75	100000	M
6274	FPFNCQ	BYOJNNMVWA	5089141016 Dell Way	\N	SGIPSMB	DE	17728	US	1	BYOJNNMVWA@dell.com	5089141016	4	4104468396399170	2009/07	user6274	password	82	60000	F
6275	CYHSAF	HKSUWORWHX	2046990381 Dell Way	\N	FWQRYUU	MA	59342	US	1	HKSUWORWHX@dell.com	2046990381	4	2060170207638293	2008/01	user6275	password	39	20000	F
6276	OVBUCL	NWHCOEJMJG	6233714055 Dell Way	\N	CBFXVPM	WI	30042	US	1	NWHCOEJMJG@dell.com	6233714055	5	3649816399905831	2012/01	user6276	password	41	60000	M
6277	JGYUTV	CWJHFVRMYS	8207407237 Dell Way	\N	RWOHINN	VT	51486	US	1	CWJHFVRMYS@dell.com	8207407237	4	5580134347081185	2008/03	user6277	password	45	60000	F
6278	IHGDJC	NRIJIVIANE	1516695954 Dell Way	\N	PUNCHLO	CO	30344	US	1	NRIJIVIANE@dell.com	1516695954	2	5277718143071980	2010/09	user6278	password	88	80000	M
6279	FXJILA	QUIMDJZHYU	9639020729 Dell Way	\N	VBBGPEM	NV	46272	US	1	QUIMDJZHYU@dell.com	9639020729	1	2046264927834272	2012/10	user6279	password	26	20000	M
6280	MLENCZ	WOCGOKFIFG	1744457304 Dell Way	\N	KMVOYMZ	VT	60718	US	1	WOCGOKFIFG@dell.com	1744457304	5	4562012723647058	2008/12	user6280	password	27	80000	F
6281	HFOGBC	JHQTMZYTJK	1072507607 Dell Way	\N	OXJBWHP	WV	22436	US	1	JHQTMZYTJK@dell.com	1072507607	1	2131179092917591	2008/11	user6281	password	59	60000	F
6282	DSCGBK	XUXWTQFEFD	1846931996 Dell Way	\N	NGZVWYZ	UT	20748	US	1	XUXWTQFEFD@dell.com	1846931996	1	9642534716520460	2011/06	user6282	password	18	80000	F
6283	CAFNXZ	KTSBZXGCKM	2051379489 Dell Way	\N	BGJAFFE	IN	30659	US	1	KTSBZXGCKM@dell.com	2051379489	5	7098078717943282	2008/10	user6283	password	78	40000	M
6284	ATSAEL	TFKQLMBYOI	4857975541 Dell Way	\N	HPNNTVT	UT	84036	US	1	TFKQLMBYOI@dell.com	4857975541	1	6304135533049703	2009/03	user6284	password	45	40000	M
6285	BIDNBI	YSULUTACAP	8771553610 Dell Way	\N	POJLHGH	OR	33307	US	1	YSULUTACAP@dell.com	8771553610	5	5382935746107251	2009/04	user6285	password	51	40000	M
6286	PVRXUK	SFELFGMVVA	2935841998 Dell Way	\N	FHIMOBS	MI	14407	US	1	SFELFGMVVA@dell.com	2935841998	4	4003054815344513	2011/12	user6286	password	86	40000	M
6287	PEPZWV	DIAKUWFUBN	6083968656 Dell Way	\N	DOCEHNG	MO	27524	US	1	DIAKUWFUBN@dell.com	6083968656	1	2603460851125419	2010/05	user6287	password	90	20000	M
6288	PCMKGU	LQOHWJJKMX	4484484750 Dell Way	\N	MREAXRF	MN	84979	US	1	LQOHWJJKMX@dell.com	4484484750	5	3241480792872608	2009/02	user6288	password	79	100000	F
6289	IKLCVC	RDZANKNKWF	4315231724 Dell Way	\N	PXCHCOD	MO	58514	US	1	RDZANKNKWF@dell.com	4315231724	5	6620487899985165	2009/11	user6289	password	77	60000	F
6290	HQBKHF	JHSTVDQATO	8633754003 Dell Way	\N	DAQRDDF	MT	10588	US	1	JHSTVDQATO@dell.com	8633754003	4	8775507572107018	2011/03	user6290	password	26	100000	M
6291	EIDKSL	CMHGDHZRKA	3817205541 Dell Way	\N	ICELIRL	DE	46531	US	1	CMHGDHZRKA@dell.com	3817205541	5	6883293019142003	2010/10	user6291	password	55	80000	F
6292	RAWCCI	KIMRIDCILE	3057893090 Dell Way	\N	MXNEIRO	NV	56573	US	1	KIMRIDCILE@dell.com	3057893090	1	3758668940979987	2011/09	user6292	password	49	60000	M
6293	HNUQXD	CPLFRURWHO	8956318835 Dell Way	\N	JLXBAOP	IA	67703	US	1	CPLFRURWHO@dell.com	8956318835	5	3969219176098704	2009/05	user6293	password	19	80000	M
6294	VGVYIK	KOCFGZMUIY	3229149261 Dell Way	\N	SKYHZFX	UT	27940	US	1	KOCFGZMUIY@dell.com	3229149261	1	6445526861120016	2009/10	user6294	password	56	20000	F
6295	JBJULX	WRDVDYEBRP	1232896372 Dell Way	\N	AYOFWLK	CO	66144	US	1	WRDVDYEBRP@dell.com	1232896372	2	4795465662609786	2010/06	user6295	password	51	100000	M
6296	VRZSOQ	WKUVOVMDWK	2818575380 Dell Way	\N	SCHENJU	MT	78172	US	1	WKUVOVMDWK@dell.com	2818575380	1	2980594970285892	2011/12	user6296	password	71	60000	M
6297	SEGIBQ	CWFYJJUUBW	4802845852 Dell Way	\N	BFJLAXF	GA	98269	US	1	CWFYJJUUBW@dell.com	4802845852	5	9788941205479206	2008/04	user6297	password	66	100000	M
6298	XEPNGL	SEVBZPDWRJ	1667323913 Dell Way	\N	FCJDIPC	OR	50366	US	1	SEVBZPDWRJ@dell.com	1667323913	5	8016144913621248	2011/09	user6298	password	39	80000	M
6299	WEEIWI	EYIUCELLKO	6780743199 Dell Way	\N	VNWKPPW	NY	54007	US	1	EYIUCELLKO@dell.com	6780743199	3	2985558871645480	2012/01	user6299	password	26	100000	F
6300	HEBQIA	YCCCOOMCKZ	3381081453 Dell Way	\N	YVPORHB	KS	70975	US	1	YCCCOOMCKZ@dell.com	3381081453	2	7451627695467324	2009/01	user6300	password	84	80000	F
6301	ZHPAFR	DIFRVICUGX	1548805294 Dell Way	\N	KVORWWI	CT	22212	US	1	DIFRVICUGX@dell.com	1548805294	3	2967189180664718	2012/03	user6301	password	52	100000	F
6302	BZRTCZ	YTUGWPNTZJ	5768834180 Dell Way	\N	HQFEZII	AR	87183	US	1	YTUGWPNTZJ@dell.com	5768834180	1	1234944515395909	2012/12	user6302	password	52	20000	M
6303	DUACTU	WAQLOKLXRC	4058310722 Dell Way	\N	CWBLEDI	OH	22935	US	1	WAQLOKLXRC@dell.com	4058310722	4	2151247150264680	2012/09	user6303	password	23	100000	M
6304	DAGXXH	OJVYUSQWVN	3916548495 Dell Way	\N	YHRBPJF	WA	16745	US	1	OJVYUSQWVN@dell.com	3916548495	4	8408554422669114	2010/08	user6304	password	43	60000	M
6305	QLPXAY	SZSKPPGCNN	1514333041 Dell Way	\N	UOCEUAG	CA	78110	US	1	SZSKPPGCNN@dell.com	1514333041	3	4806908062659204	2010/01	user6305	password	26	20000	F
6306	SYMQQL	JBBYHDMUYB	1857399661 Dell Way	\N	XCVXIXR	MA	47921	US	1	JBBYHDMUYB@dell.com	1857399661	4	4956802240572870	2009/10	user6306	password	83	100000	M
6307	JOKUXL	VWTZJOYKLA	1222698127 Dell Way	\N	GJJEATP	CT	57805	US	1	VWTZJOYKLA@dell.com	1222698127	2	4235732533037663	2012/03	user6307	password	26	40000	M
6308	NCSZXP	SXYGVJRWPB	8495303336 Dell Way	\N	FUBYJEM	MA	55950	US	1	SXYGVJRWPB@dell.com	8495303336	2	7751794779207558	2012/08	user6308	password	57	60000	M
6309	GLPWDN	UJIEBFUCKO	6536093031 Dell Way	\N	EJXJVHW	NV	62748	US	1	UJIEBFUCKO@dell.com	6536093031	4	2569060196168721	2008/01	user6309	password	79	60000	F
6310	LGQYBA	HGCMAEXOJG	5521623814 Dell Way	\N	LSBTPSI	FL	38304	US	1	HGCMAEXOJG@dell.com	5521623814	2	4414165167603642	2009/10	user6310	password	81	80000	F
6311	MSCNAI	PMJUJXDPJW	1644512413 Dell Way	\N	RCLJLQR	WA	98238	US	1	PMJUJXDPJW@dell.com	1644512413	2	7753402880858631	2012/01	user6311	password	75	60000	M
6312	XYUFNH	OHRMLHVHYY	1584014916 Dell Way	\N	SIJIAII	CA	63777	US	1	OHRMLHVHYY@dell.com	1584014916	1	6986666880082340	2012/06	user6312	password	51	80000	F
6313	GZXOOF	FAQMWXLVQT	7904667378 Dell Way	\N	EZTNHVC	KY	87702	US	1	FAQMWXLVQT@dell.com	7904667378	1	3913929452188313	2009/12	user6313	password	70	60000	M
6314	QALWGM	NTILEDBXIA	7184601403 Dell Way	\N	RVHNYQJ	OH	85834	US	1	NTILEDBXIA@dell.com	7184601403	5	7997036139946432	2010/05	user6314	password	67	20000	F
6315	DXRPLK	XWPBXMKYDF	5623410599 Dell Way	\N	GQEXAWT	OH	80671	US	1	XWPBXMKYDF@dell.com	5623410599	1	2785206814296543	2008/02	user6315	password	65	40000	F
6316	IXNTVJ	IWHVGFZMMQ	5326863282 Dell Way	\N	QJQMCIH	NJ	48952	US	1	IWHVGFZMMQ@dell.com	5326863282	5	6375533837359399	2008/02	user6316	password	67	60000	F
6317	EFWOOT	VKABJMOZDX	9626692592 Dell Way	\N	PQAYXQJ	MA	49197	US	1	VKABJMOZDX@dell.com	9626692592	3	6050563377793879	2011/12	user6317	password	61	100000	F
6318	LKTEGD	EHMRVMUTBK	4483954150 Dell Way	\N	TAIKJSV	KS	30573	US	1	EHMRVMUTBK@dell.com	4483954150	5	2823234566021710	2012/10	user6318	password	46	60000	F
6319	DPKHUS	UMOGGIIRCI	2411456628 Dell Way	\N	AMSSHAY	OH	99003	US	1	UMOGGIIRCI@dell.com	2411456628	4	8049002619460226	2010/02	user6319	password	88	80000	M
6320	KZMCUY	RAFZJXBSXO	2878207885 Dell Way	\N	KQWLPNL	OR	28363	US	1	RAFZJXBSXO@dell.com	2878207885	2	3673243014607579	2008/01	user6320	password	90	60000	M
6321	MRULIV	RIEOKXMYHC	8629193003 Dell Way	\N	VTRJELO	LA	74905	US	1	RIEOKXMYHC@dell.com	8629193003	3	7490683567244560	2012/02	user6321	password	70	40000	M
6322	MUDHLL	MAWJMVROQK	2024265814 Dell Way	\N	GZORNYK	MA	54542	US	1	MAWJMVROQK@dell.com	2024265814	2	6443808495532722	2012/07	user6322	password	45	40000	F
6323	NPUYCU	VMGQDVGOBG	2556669723 Dell Way	\N	DTTBDDO	IA	41466	US	1	VMGQDVGOBG@dell.com	2556669723	1	9155422626528890	2010/05	user6323	password	36	20000	F
6324	AACVVO	CLSXSGZYKS	1768202963 Dell Way	\N	SMWVACE	GA	26454	US	1	CLSXSGZYKS@dell.com	1768202963	4	6186801612377167	2009/10	user6324	password	60	40000	M
6325	REQGHC	ZEUGETQXLC	6500801539 Dell Way	\N	THDWLIA	NC	19592	US	1	ZEUGETQXLC@dell.com	6500801539	5	9333619637414814	2008/03	user6325	password	73	100000	F
6326	KDSMDX	HJBBAYMCSU	6592624882 Dell Way	\N	GOGPPUS	GA	67983	US	1	HJBBAYMCSU@dell.com	6592624882	2	8954164502210916	2009/04	user6326	password	41	80000	F
6327	AHOXPY	ZQYYDBQXHE	4973361888 Dell Way	\N	DWTXOZO	FL	42079	US	1	ZQYYDBQXHE@dell.com	4973361888	3	6716397282201797	2011/05	user6327	password	22	80000	M
6328	QSFORV	MQZNGWULAR	2409897045 Dell Way	\N	FYGEMLN	WA	98923	US	1	MQZNGWULAR@dell.com	2409897045	4	3962889037095010	2009/06	user6328	password	87	100000	F
6329	DJWZWM	YJSVEEWVJU	8156147150 Dell Way	\N	BNHMBFM	GA	92967	US	1	YJSVEEWVJU@dell.com	8156147150	3	4571077202912420	2011/04	user6329	password	59	100000	M
6330	LWMXVW	QRAUNVEIWS	2345349312 Dell Way	\N	PJTVVYT	NJ	44128	US	1	QRAUNVEIWS@dell.com	2345349312	2	6786717464216054	2011/03	user6330	password	38	20000	F
6331	UBYQSP	QNCMRLIJAS	1846684810 Dell Way	\N	DWNBPDL	PA	55969	US	1	QNCMRLIJAS@dell.com	1846684810	3	7845257257577033	2009/08	user6331	password	82	20000	M
6332	VUKKLY	NXPYGZZYCV	8981349495 Dell Way	\N	MELQQFD	OK	72300	US	1	NXPYGZZYCV@dell.com	8981349495	1	3970636685844511	2011/03	user6332	password	20	60000	F
6333	LALJOJ	ZMPYMNBIZF	1007210238 Dell Way	\N	TPVZSOR	NJ	66959	US	1	ZMPYMNBIZF@dell.com	1007210238	2	8933348879683764	2008/12	user6333	password	84	60000	M
6334	JWNSVA	IUMVVVVAPK	9294239201 Dell Way	\N	WODKFTB	HI	23479	US	1	IUMVVVVAPK@dell.com	9294239201	2	2084508417174220	2012/09	user6334	password	25	40000	M
6335	QYLQGF	DCAYXBNIYB	5693889811 Dell Way	\N	MJHGKNK	IN	79874	US	1	DCAYXBNIYB@dell.com	5693889811	1	5709908315446228	2011/05	user6335	password	27	40000	F
6336	OWOUZR	VXOXKXVMKE	6172926612 Dell Way	\N	TQOHBWB	ND	11565	US	1	VXOXKXVMKE@dell.com	6172926612	1	4454539374448359	2011/06	user6336	password	68	40000	F
6337	GAGYVE	NSPKOBUSVL	6024339457 Dell Way	\N	HCMEEBE	OR	29912	US	1	NSPKOBUSVL@dell.com	6024339457	3	6758368434384466	2009/09	user6337	password	85	60000	M
6338	ELOJYH	YJWAEPWPWY	9694638391 Dell Way	\N	BACCFVI	PA	34822	US	1	YJWAEPWPWY@dell.com	9694638391	1	9711730206385256	2012/07	user6338	password	68	20000	M
6339	GLYOKH	KLMAHBWGDX	4968878865 Dell Way	\N	JFCFOWM	MT	89372	US	1	KLMAHBWGDX@dell.com	4968878865	3	4788497463800013	2008/06	user6339	password	48	40000	M
6340	JZIRJT	DKAEGHHEQN	4920083356 Dell Way	\N	GVBDHPA	OR	99322	US	1	DKAEGHHEQN@dell.com	4920083356	5	5274224972352386	2012/04	user6340	password	47	40000	F
6341	SWQMZA	NEGUMKKZRG	2116075452 Dell Way	\N	BVNRVGQ	ID	22323	US	1	NEGUMKKZRG@dell.com	2116075452	1	4661854899022728	2010/04	user6341	password	64	40000	F
6342	GTFGGJ	NAWYLWQRXL	1149659983 Dell Way	\N	FOHMFOP	KY	71055	US	1	NAWYLWQRXL@dell.com	1149659983	5	1047727704979479	2011/02	user6342	password	32	100000	M
6343	KECURD	QQPMGGKSMZ	3073729251 Dell Way	\N	ZYEOONF	ND	46732	US	1	QQPMGGKSMZ@dell.com	3073729251	2	5785813053604216	2010/02	user6343	password	46	100000	F
6344	MPZQGP	FSWLCOYBOW	7665042898 Dell Way	\N	GCKUIZF	ND	26873	US	1	FSWLCOYBOW@dell.com	7665042898	5	3865970402490348	2008/10	user6344	password	63	80000	F
6345	PGRFLK	BXMQVOERVH	6124500744 Dell Way	\N	CQPBVEG	NE	23091	US	1	BXMQVOERVH@dell.com	6124500744	4	9719182992354036	2008/04	user6345	password	47	80000	M
6346	CZAMBY	ZSTOXLJEOA	1394445527 Dell Way	\N	UPWYWLB	ME	24376	US	1	ZSTOXLJEOA@dell.com	1394445527	4	5436499988194555	2010/05	user6346	password	23	60000	F
6347	CZMAZE	UNBFWFUXZJ	8620082863 Dell Way	\N	TYGFARJ	AR	35516	US	1	UNBFWFUXZJ@dell.com	8620082863	3	7183029210194946	2012/01	user6347	password	24	20000	F
6348	OAZTVM	UBJAVGAFZY	1720380782 Dell Way	\N	LFYCOZK	MD	53202	US	1	UBJAVGAFZY@dell.com	1720380782	2	5507349780760706	2008/04	user6348	password	55	80000	F
6349	MLEZGF	IGAPHFPFRU	2145520789 Dell Way	\N	EUIDESQ	IA	13453	US	1	IGAPHFPFRU@dell.com	2145520789	3	4216113184113056	2011/02	user6349	password	69	20000	M
6350	WDWBMD	CBKIQQZLUT	9031048783 Dell Way	\N	TYYMOEN	NY	62725	US	1	CBKIQQZLUT@dell.com	9031048783	2	7571442977990956	2010/06	user6350	password	42	60000	M
6351	FOBIQD	SYTIYFDSZB	2010042432 Dell Way	\N	QMPUAHJ	VA	65741	US	1	SYTIYFDSZB@dell.com	2010042432	3	1814444854855537	2010/12	user6351	password	68	80000	M
6352	TYDWRC	QABVDTUFJG	8259705841 Dell Way	\N	UEHCOES	NY	69188	US	1	QABVDTUFJG@dell.com	8259705841	1	6577433638274670	2010/10	user6352	password	27	40000	M
6353	HCKJTK	LOOEJTOQOS	4091301998 Dell Way	\N	XQHBJYS	DE	16209	US	1	LOOEJTOQOS@dell.com	4091301998	4	8427022873423994	2010/11	user6353	password	57	80000	F
6354	YCTINH	WSRQHHEZFV	2167929090 Dell Way	\N	HGEGZJH	KS	12322	US	1	WSRQHHEZFV@dell.com	2167929090	4	9342742136213928	2011/07	user6354	password	85	60000	M
6355	RYEYVX	QLEXQECLLJ	9585001236 Dell Way	\N	QRJAZRA	CT	52245	US	1	QLEXQECLLJ@dell.com	9585001236	4	1020413601305335	2012/05	user6355	password	65	60000	F
6356	VNDSDO	XAEBDQNNGF	9964365910 Dell Way	\N	WGENHHZ	IA	17864	US	1	XAEBDQNNGF@dell.com	9964365910	1	5202962790150196	2011/09	user6356	password	74	60000	F
6357	XFHLCI	QEMGRZMWVT	9215606837 Dell Way	\N	BJBJIHL	KY	46500	US	1	QEMGRZMWVT@dell.com	9215606837	5	1679877959191799	2011/06	user6357	password	36	60000	M
6358	OAUXQY	JWPIJMEDON	9434341740 Dell Way	\N	EXWLJFW	ID	26619	US	1	JWPIJMEDON@dell.com	9434341740	5	6806850703433157	2008/07	user6358	password	40	80000	M
6359	CQEAZB	QILDMORZTO	8987774999 Dell Way	\N	WFXBBEG	AK	20566	US	1	QILDMORZTO@dell.com	8987774999	1	6771593795157970	2008/12	user6359	password	31	40000	M
6360	JHOLYW	WBJLSJFGFK	1925623286 Dell Way	\N	EGMINMM	MA	69882	US	1	WBJLSJFGFK@dell.com	1925623286	3	6360354751348496	2009/11	user6360	password	29	80000	F
6361	SCCOZD	XLVGQCLBHS	3322313419 Dell Way	\N	NQFZCPR	FL	28405	US	1	XLVGQCLBHS@dell.com	3322313419	3	1675053511746227	2010/02	user6361	password	35	20000	F
6362	IRFMOR	HVIKGJRZWH	1858116929 Dell Way	\N	FWJVOOA	SC	13116	US	1	HVIKGJRZWH@dell.com	1858116929	2	2544653074815869	2009/04	user6362	password	48	80000	M
6363	QDNHLI	PWPZNPWVUT	9727123332 Dell Way	\N	FPHTQCU	OK	36103	US	1	PWPZNPWVUT@dell.com	9727123332	1	6414442912675441	2009/09	user6363	password	59	20000	M
6364	CIHLYD	BXRQUMKNSA	7839091726 Dell Way	\N	UMQWGJE	HI	46723	US	1	BXRQUMKNSA@dell.com	7839091726	4	2192490807734430	2009/08	user6364	password	90	60000	M
6365	HWXLXV	DNPQYCIYWU	5374770653 Dell Way	\N	PTBYXHJ	NV	90511	US	1	DNPQYCIYWU@dell.com	5374770653	5	5754287739284337	2010/06	user6365	password	53	80000	F
6366	JFFEJS	UZRWHQTCFM	8483457494 Dell Way	\N	DEJKNBH	AK	13618	US	1	UZRWHQTCFM@dell.com	8483457494	3	5160882367286831	2009/04	user6366	password	72	80000	F
6367	YXVRRV	JNCZGEFTIJ	7099453639 Dell Way	\N	DSWEAXF	TX	43599	US	1	JNCZGEFTIJ@dell.com	7099453639	1	6738622757606209	2010/11	user6367	password	27	40000	M
6368	ZBLUKY	WJFBOYJYCC	7461926862 Dell Way	\N	VGCSMYC	DC	21271	US	1	WJFBOYJYCC@dell.com	7461926862	3	9954233714845032	2012/12	user6368	password	73	100000	F
6369	EPKDMU	JNJHXHKZDQ	2364859701 Dell Way	\N	BVDAXHE	NM	87249	US	1	JNJHXHKZDQ@dell.com	2364859701	3	8353732672985644	2012/04	user6369	password	78	20000	M
6370	GFIAOW	KWTSGSVXUR	9901661638 Dell Way	\N	AVOIZFE	DC	71381	US	1	KWTSGSVXUR@dell.com	9901661638	1	9732398072723300	2012/02	user6370	password	79	20000	F
6371	ECYBMV	UFCNBZISAE	2232468135 Dell Way	\N	HIDMNHE	MS	40279	US	1	UFCNBZISAE@dell.com	2232468135	2	5286147697363049	2012/05	user6371	password	79	20000	F
6372	UFZPAE	ROFRWYSBFB	3601621022 Dell Way	\N	EROMWBV	WY	45420	US	1	ROFRWYSBFB@dell.com	3601621022	5	8012966651003809	2008/02	user6372	password	37	100000	F
6373	GNKLEY	RWVPOWUPBM	4615970734 Dell Way	\N	ENIFJIQ	NM	38271	US	1	RWVPOWUPBM@dell.com	4615970734	4	5170801796484739	2011/09	user6373	password	78	100000	F
6374	GIJEZF	AOTWJJYWNM	3707491663 Dell Way	\N	ETVNJMV	RI	30709	US	1	AOTWJJYWNM@dell.com	3707491663	3	9177731200121344	2008/05	user6374	password	24	40000	M
6375	LORROG	LLPUJLIWQB	3531183456 Dell Way	\N	RELDAFJ	IN	69233	US	1	LLPUJLIWQB@dell.com	3531183456	3	1015763396862894	2009/10	user6375	password	67	100000	F
6376	JNXPYJ	FTSRBPHDGM	5073518670 Dell Way	\N	OKMUUUL	AZ	29102	US	1	FTSRBPHDGM@dell.com	5073518670	3	1166613069828599	2008/04	user6376	password	45	60000	M
6377	HBSQHL	JYMYFQFSFQ	2476065591 Dell Way	\N	EZKYLMD	VA	91127	US	1	JYMYFQFSFQ@dell.com	2476065591	1	2511881664860993	2010/07	user6377	password	86	100000	M
6378	QLWCVU	PTAFZSKPWK	5791714671 Dell Way	\N	ZUWMYTJ	CO	80176	US	1	PTAFZSKPWK@dell.com	5791714671	4	3625725309830159	2010/06	user6378	password	82	20000	M
6379	TFTNUM	OZMGKBDVBY	5432254214 Dell Way	\N	RNXKWAF	ME	69074	US	1	OZMGKBDVBY@dell.com	5432254214	5	2128708283882588	2009/12	user6379	password	21	20000	F
6380	UQZGEZ	SLJUPFVNWJ	2767679873 Dell Way	\N	KHGKMRB	WY	59217	US	1	SLJUPFVNWJ@dell.com	2767679873	2	5882692062761635	2009/06	user6380	password	71	20000	F
6381	SHHRAT	BUIGQVDAGL	1089980526 Dell Way	\N	GRXXTXM	WA	33285	US	1	BUIGQVDAGL@dell.com	1089980526	1	7513247080612928	2011/03	user6381	password	78	60000	F
6382	DDMWFH	ELYAPYGAFY	8385273267 Dell Way	\N	YDRVPPC	NH	78019	US	1	ELYAPYGAFY@dell.com	8385273267	2	9490833199117334	2011/10	user6382	password	48	80000	M
6383	XQDEUP	DVECBFHZDK	9438532558 Dell Way	\N	QZAGCPZ	VA	96630	US	1	DVECBFHZDK@dell.com	9438532558	3	7908901471644641	2009/04	user6383	password	69	40000	M
6384	WLTLOO	QQQVYQZJHZ	7287415043 Dell Way	\N	JNBZNYY	MI	54236	US	1	QQQVYQZJHZ@dell.com	7287415043	4	8241319507826120	2010/01	user6384	password	72	40000	F
6385	MSBAIS	QERGEANDJB	4774377846 Dell Way	\N	EIODGZP	WI	81126	US	1	QERGEANDJB@dell.com	4774377846	2	8558279307093472	2008/08	user6385	password	42	80000	F
6386	KRRDHV	UOZUCDDEIM	4013755815 Dell Way	\N	SLTSBSM	MN	16277	US	1	UOZUCDDEIM@dell.com	4013755815	4	7217666289303452	2011/04	user6386	password	18	20000	M
6387	RFFMZU	MUXQXBYKUJ	6472645490 Dell Way	\N	DMKWZWX	IN	55342	US	1	MUXQXBYKUJ@dell.com	6472645490	5	7894719744101167	2011/01	user6387	password	68	40000	F
6388	XUGSHA	QXYSVIMFMY	7878685242 Dell Way	\N	QIYMGGZ	TX	29814	US	1	QXYSVIMFMY@dell.com	7878685242	3	3471428989898413	2010/09	user6388	password	56	40000	M
6389	TCVTSS	SKOAWTMVJV	5489219657 Dell Way	\N	TWBAWXF	NM	42577	US	1	SKOAWTMVJV@dell.com	5489219657	1	2002254295162856	2008/06	user6389	password	65	80000	M
6390	LOGEGR	SHOMTKWPET	1026089084 Dell Way	\N	QEPNKGX	VA	39252	US	1	SHOMTKWPET@dell.com	1026089084	5	8041584538761527	2011/09	user6390	password	42	20000	F
6391	PHNHAU	VMOFJDKCTO	1378834140 Dell Way	\N	SHYYEVG	FL	77247	US	1	VMOFJDKCTO@dell.com	1378834140	5	5065079858526588	2009/12	user6391	password	70	100000	F
6392	FGFABS	OHBRRDLGWT	2901880396 Dell Way	\N	EUYABCT	CA	95089	US	1	OHBRRDLGWT@dell.com	2901880396	3	8931964989751578	2012/06	user6392	password	24	20000	M
6393	HESASA	BKSFWYBPCW	5177336403 Dell Way	\N	NDXQXZP	CA	49593	US	1	BKSFWYBPCW@dell.com	5177336403	1	8745569115504623	2010/03	user6393	password	55	100000	F
6394	GWBGYL	YEIWGXZCLD	3564835753 Dell Way	\N	ABAZQCL	CO	21567	US	1	YEIWGXZCLD@dell.com	3564835753	4	3699495445471257	2012/07	user6394	password	63	20000	F
6395	RHJDGN	LDUIDWUGWW	8095991937 Dell Way	\N	GWNJHQM	NE	36474	US	1	LDUIDWUGWW@dell.com	8095991937	2	8480631317477674	2010/05	user6395	password	35	20000	M
6396	PFYDRB	XAEUULRQRN	8960148741 Dell Way	\N	DBVTNKB	KS	78794	US	1	XAEUULRQRN@dell.com	8960148741	4	2592688684817403	2008/11	user6396	password	82	80000	F
6397	VWSXUS	CONNFDFTHG	9181720399 Dell Way	\N	PBUZCCT	WY	85934	US	1	CONNFDFTHG@dell.com	9181720399	1	7116078025195748	2011/11	user6397	password	71	80000	M
6398	LNMEPB	SCHWHADOPF	9599514678 Dell Way	\N	IOHLIHH	HI	46707	US	1	SCHWHADOPF@dell.com	9599514678	1	3277205637656152	2011/08	user6398	password	88	20000	F
6399	LJSMBV	TXDUBRKGAZ	5676880620 Dell Way	\N	OLHWSMG	NY	55315	US	1	TXDUBRKGAZ@dell.com	5676880620	2	2125761395320296	2010/07	user6399	password	36	100000	M
6400	ZKXUEV	XYXPJEPISB	7557748775 Dell Way	\N	PPTCWLP	LA	80948	US	1	XYXPJEPISB@dell.com	7557748775	5	3772619462106377	2012/10	user6400	password	30	100000	F
6401	CTJYRH	VHQZWZRXPH	2775940561 Dell Way	\N	RRDCHMX	AK	39731	US	1	VHQZWZRXPH@dell.com	2775940561	5	1908464096952229	2009/12	user6401	password	38	60000	M
6402	QKJYFR	PENOWLDDDV	2504290170 Dell Way	\N	GGCTDCB	KS	19845	US	1	PENOWLDDDV@dell.com	2504290170	4	1553825606126338	2010/02	user6402	password	73	20000	M
6403	DATUPX	IDUUHXYCEE	5419234059 Dell Way	\N	FXHIZPL	DC	37416	US	1	IDUUHXYCEE@dell.com	5419234059	3	5153314380440861	2009/08	user6403	password	18	60000	M
6404	TFGROK	LJRJHUOLZL	2083435902 Dell Way	\N	TILJTPR	IA	25066	US	1	LJRJHUOLZL@dell.com	2083435902	3	8496276282239706	2008/11	user6404	password	54	100000	F
6405	TOREAA	WKHQYTQKNZ	4768656254 Dell Way	\N	VWSKNYP	NM	50785	US	1	WKHQYTQKNZ@dell.com	4768656254	4	4219588078092784	2012/08	user6405	password	52	80000	F
6406	DWFESP	MJOGZYTZUP	5019969918 Dell Way	\N	RFCQUTC	GA	54606	US	1	MJOGZYTZUP@dell.com	5019969918	1	2221379468683153	2012/10	user6406	password	42	20000	M
6407	NGJDSS	RYSQRRKGJQ	7535611452 Dell Way	\N	JALCCQP	NC	79564	US	1	RYSQRRKGJQ@dell.com	7535611452	3	6324961075559259	2008/07	user6407	password	36	60000	M
6408	QSMJKK	BBBTLIDCRD	5628434007 Dell Way	\N	NUFDJTX	CO	28682	US	1	BBBTLIDCRD@dell.com	5628434007	1	7579662448260934	2011/09	user6408	password	53	60000	F
6409	YTXJVY	KPKTSMLVZF	7529122111 Dell Way	\N	ADPUBSZ	NE	87389	US	1	KPKTSMLVZF@dell.com	7529122111	2	6485036428552122	2009/09	user6409	password	24	20000	M
6410	ZNIXYX	HRPTDLTJMW	2152843626 Dell Way	\N	YGYRGNN	WV	86870	US	1	HRPTDLTJMW@dell.com	2152843626	1	6415250827558339	2009/05	user6410	password	25	20000	M
6411	LCUIJM	YDPJWZVTXC	6941338729 Dell Way	\N	SPIFCIB	HI	55441	US	1	YDPJWZVTXC@dell.com	6941338729	3	8687519972678275	2011/08	user6411	password	70	20000	M
6412	NNCZMG	PVCORWMTOB	8068343668 Dell Way	\N	CUELVKY	MO	84575	US	1	PVCORWMTOB@dell.com	8068343668	2	5141765094362200	2010/06	user6412	password	31	20000	M
6413	HALNPG	QEYNRSBSVV	6056730287 Dell Way	\N	XGRHEEC	WI	47025	US	1	QEYNRSBSVV@dell.com	6056730287	3	8689932690933348	2011/06	user6413	password	77	20000	F
6414	GOBNEG	LRXDTQYPNF	7046136281 Dell Way	\N	GUJKXIV	MN	78833	US	1	LRXDTQYPNF@dell.com	7046136281	1	3069099213462323	2010/03	user6414	password	69	80000	M
6415	UGYASP	YWJOUYCZEW	6992394712 Dell Way	\N	JPTRKFL	AZ	47434	US	1	YWJOUYCZEW@dell.com	6992394712	3	6765624128282071	2009/04	user6415	password	47	20000	M
6416	IEGYCC	HRXGTXKQHZ	6905760949 Dell Way	\N	JYKPKLA	AR	11715	US	1	HRXGTXKQHZ@dell.com	6905760949	3	3915918494574726	2008/07	user6416	password	82	60000	M
6417	DJVGRM	EXGCIWJHGI	5342107755 Dell Way	\N	RVSDWTE	MS	25781	US	1	EXGCIWJHGI@dell.com	5342107755	3	7597997832112015	2009/12	user6417	password	51	60000	F
6418	HTATYX	ABFWKNCTFY	2006021813 Dell Way	\N	LIUFMHJ	WY	86357	US	1	ABFWKNCTFY@dell.com	2006021813	2	8442074856255204	2010/11	user6418	password	30	100000	M
6419	EQOCQP	IMAVOTAMFJ	2975254239 Dell Way	\N	GKWOUWK	VT	28149	US	1	IMAVOTAMFJ@dell.com	2975254239	3	1546811306849122	2009/04	user6419	password	68	60000	M
6420	GROWZB	XVPRWCWFJH	2922981380 Dell Way	\N	CXCYHZD	MT	51279	US	1	XVPRWCWFJH@dell.com	2922981380	5	8028626342769713	2012/06	user6420	password	70	20000	F
6421	HBDIYY	YQUBMAKUCI	1902298578 Dell Way	\N	WBQWFDI	MI	15321	US	1	YQUBMAKUCI@dell.com	1902298578	2	5881749387830496	2012/06	user6421	password	68	20000	M
6422	VLMTJC	OKPOVKRDHT	5658881053 Dell Way	\N	UDZXLKZ	ND	76373	US	1	OKPOVKRDHT@dell.com	5658881053	2	3135934283956885	2009/06	user6422	password	74	20000	M
6423	HUHJJS	ZYOKPSRJMU	7461345330 Dell Way	\N	IJGTJUM	UT	25573	US	1	ZYOKPSRJMU@dell.com	7461345330	1	6922224528621883	2010/02	user6423	password	60	80000	M
6424	WDGPDE	DNUVEEHZNR	8637557857 Dell Way	\N	FGAASXE	MI	98560	US	1	DNUVEEHZNR@dell.com	8637557857	5	1833039365243166	2010/09	user6424	password	90	40000	M
6425	GXZLBN	FXSKFRXWXD	9091033282 Dell Way	\N	XXWVCIU	WI	32560	US	1	FXSKFRXWXD@dell.com	9091033282	2	9658016887959094	2012/09	user6425	password	78	20000	M
6426	VORIUO	BEUSBRQFPO	6314449586 Dell Way	\N	BKQJFPQ	CO	99022	US	1	BEUSBRQFPO@dell.com	6314449586	1	7185927575919778	2010/02	user6426	password	39	40000	M
6427	ZONOQR	IITZZZONBZ	4881171951 Dell Way	\N	DKETBHT	NM	37440	US	1	IITZZZONBZ@dell.com	4881171951	1	5059494053479284	2011/04	user6427	password	30	80000	M
6428	RGMJPV	DOUCDHDDLO	4392429178 Dell Way	\N	IEPQYGY	LA	35963	US	1	DOUCDHDDLO@dell.com	4392429178	1	6125162261538208	2010/10	user6428	password	48	40000	F
6429	XPQSSF	MVJTZMFNUK	3101563958 Dell Way	\N	DLIJJRR	OR	80407	US	1	MVJTZMFNUK@dell.com	3101563958	2	6224654404446483	2011/06	user6429	password	64	60000	F
6430	GGVMTQ	VNQISECCHO	5357451038 Dell Way	\N	LRXDIQX	ND	90240	US	1	VNQISECCHO@dell.com	5357451038	2	4499441569205374	2008/10	user6430	password	53	40000	F
6431	HWUYRH	PZATCDAQOS	4807067599 Dell Way	\N	NRADPPA	AZ	83641	US	1	PZATCDAQOS@dell.com	4807067599	1	6338549909181893	2012/07	user6431	password	63	40000	F
6432	KECSTB	SMEWNUKFIC	3165375743 Dell Way	\N	GLRVMTQ	VT	93775	US	1	SMEWNUKFIC@dell.com	3165375743	5	5443722347263247	2012/01	user6432	password	84	40000	F
6433	ZZYBSK	FOXAZDIBJU	9308356463 Dell Way	\N	TEHMVFL	AZ	12189	US	1	FOXAZDIBJU@dell.com	9308356463	5	1480053048115223	2012/03	user6433	password	35	100000	F
6434	EWYPCM	MCMPKOZFHD	7908544151 Dell Way	\N	MUZRFBS	DC	98156	US	1	MCMPKOZFHD@dell.com	7908544151	5	2785022429190576	2008/10	user6434	password	47	20000	M
6435	ITTVGV	HWGWVMEZYY	2555561476 Dell Way	\N	YQEZJIZ	CT	39097	US	1	HWGWVMEZYY@dell.com	2555561476	1	2083432013168931	2010/04	user6435	password	75	100000	F
6436	NTIJBF	QXBCBABAZR	9928990255 Dell Way	\N	FZAOYEW	CT	36178	US	1	QXBCBABAZR@dell.com	9928990255	4	6467497141100467	2011/08	user6436	password	68	40000	F
6437	ARKGII	HKJILKIDPH	3086427515 Dell Way	\N	EDGIAJQ	AK	16586	US	1	HKJILKIDPH@dell.com	3086427515	4	7244427522644401	2012/02	user6437	password	22	100000	M
6438	MFCUMN	DVZODDDKHH	8028608057 Dell Way	\N	QQHAGHC	MO	18272	US	1	DVZODDDKHH@dell.com	8028608057	3	2734136829618364	2012/05	user6438	password	89	40000	M
6439	CCAPGW	PUZSXJAFAQ	1726341618 Dell Way	\N	MBWUDJX	VT	78241	US	1	PUZSXJAFAQ@dell.com	1726341618	4	2005730111151933	2008/01	user6439	password	66	20000	F
6440	STJOJD	NBBXBGXSTZ	8171774593 Dell Way	\N	OOCYLZR	MT	76712	US	1	NBBXBGXSTZ@dell.com	8171774593	3	8124709284864367	2010/09	user6440	password	85	20000	F
6441	HSWLFY	NDZTBSNAGB	6589223346 Dell Way	\N	CEMCWZV	NY	60004	US	1	NDZTBSNAGB@dell.com	6589223346	1	3545484290458262	2010/04	user6441	password	74	100000	M
6442	QHFOUI	OOJGBJNCMS	4523931545 Dell Way	\N	OOPOKGC	AK	44742	US	1	OOJGBJNCMS@dell.com	4523931545	3	7044399086385966	2008/05	user6442	password	66	100000	M
6443	WJMFYA	PECYSELKTZ	3711128852 Dell Way	\N	ZHJGKJQ	SD	94247	US	1	PECYSELKTZ@dell.com	3711128852	5	4029127923771739	2012/10	user6443	password	19	100000	F
6444	NBCNQG	QOYUZJOZJW	1074422763 Dell Way	\N	JPHTFCR	MT	14938	US	1	QOYUZJOZJW@dell.com	1074422763	3	8525746374856681	2008/04	user6444	password	89	60000	F
6445	BCZISO	HNOQBNZXXO	2498049860 Dell Way	\N	FQUHHII	IN	82360	US	1	HNOQBNZXXO@dell.com	2498049860	2	2110710682347417	2008/11	user6445	password	53	40000	M
6446	LNRAVE	OLFCLDZAIP	1524256238 Dell Way	\N	VQXDYFY	CO	60068	US	1	OLFCLDZAIP@dell.com	1524256238	2	4927989150863141	2010/06	user6446	password	46	20000	F
6447	BAVFOH	LRSPRTYGOO	4484858013 Dell Way	\N	ERNKQQY	NY	89439	US	1	LRSPRTYGOO@dell.com	4484858013	2	4291362775955349	2011/03	user6447	password	46	100000	F
6448	FBUNMM	GCDZAKNOOF	9466004233 Dell Way	\N	BYVRXMO	IN	73840	US	1	GCDZAKNOOF@dell.com	9466004233	1	9317578854039312	2009/11	user6448	password	28	60000	M
6449	YBMKHO	NGPXUEMZGL	9504423361 Dell Way	\N	VYJINQA	MI	75804	US	1	NGPXUEMZGL@dell.com	9504423361	4	6826696401461960	2008/04	user6449	password	63	20000	F
6450	CLRQZY	GXTKKSQVOO	2936662863 Dell Way	\N	EWBVWNO	TN	36781	US	1	GXTKKSQVOO@dell.com	2936662863	5	6585119076538832	2012/12	user6450	password	18	100000	F
6451	ROKQVH	JFRCWNQKSM	9461847404 Dell Way	\N	MOJACFI	KS	20080	US	1	JFRCWNQKSM@dell.com	9461847404	1	1645721448119729	2012/01	user6451	password	53	80000	M
6452	WGMEPR	WRNKIYCULQ	5928099099 Dell Way	\N	EMTJUBM	OR	30765	US	1	WRNKIYCULQ@dell.com	5928099099	4	3823974020779133	2008/04	user6452	password	89	100000	M
6453	LCDDZV	RJDQLYCCCO	5122910832 Dell Way	\N	VMJXYCD	MO	80783	US	1	RJDQLYCCCO@dell.com	5122910832	3	1799324538558721	2010/06	user6453	password	64	100000	M
6454	TAMPRW	SHIQKKTYGF	3655540497 Dell Way	\N	IEDKIQF	RI	23519	US	1	SHIQKKTYGF@dell.com	3655540497	1	6245979445520789	2012/01	user6454	password	26	80000	F
6455	PHTMZB	UQLEJKLPSP	1864833793 Dell Way	\N	TDXJIRN	NM	88680	US	1	UQLEJKLPSP@dell.com	1864833793	3	9521631773095580	2009/04	user6455	password	19	100000	M
6456	UHNVBE	HGORSDJHWM	7425228593 Dell Way	\N	FFVXTLT	TN	11455	US	1	HGORSDJHWM@dell.com	7425228593	1	3400264326948673	2011/11	user6456	password	76	60000	F
6457	IJFMQM	BHEERMBESG	7674994627 Dell Way	\N	ZPALJVM	AZ	90256	US	1	BHEERMBESG@dell.com	7674994627	5	7810023349244148	2010/04	user6457	password	84	100000	M
6458	DJIPKP	UOGHPLZWLO	4422117242 Dell Way	\N	XXYTJAQ	CO	83510	US	1	UOGHPLZWLO@dell.com	4422117242	4	2342482739593833	2009/07	user6458	password	78	60000	M
6459	DAHTVV	ACLLBIWQFT	5880426484 Dell Way	\N	OYDOOFK	WI	88726	US	1	ACLLBIWQFT@dell.com	5880426484	2	4480013030115515	2009/08	user6459	password	36	60000	M
6460	NGNJHP	VSREPIJJXI	9821531352 Dell Way	\N	MMXSWWP	ME	18760	US	1	VSREPIJJXI@dell.com	9821531352	4	7831380539108069	2009/04	user6460	password	50	80000	M
6461	ZDWOZP	GDEPNOMVBZ	4946267776 Dell Way	\N	STVPJGR	KS	14121	US	1	GDEPNOMVBZ@dell.com	4946267776	3	4205712759401649	2012/05	user6461	password	86	100000	F
6462	ULLJRO	OHBCTXETQX	3120949943 Dell Way	\N	PFGVWPW	KS	24994	US	1	OHBCTXETQX@dell.com	3120949943	2	5534310436341912	2008/01	user6462	password	89	100000	F
6463	KIEZXL	BAFYEYOCNT	6568909699 Dell Way	\N	JJQYGZC	MO	25669	US	1	BAFYEYOCNT@dell.com	6568909699	4	3115230526309460	2010/08	user6463	password	70	20000	M
6464	XAWIBW	OABNODBIMK	4133555649 Dell Way	\N	ZLQYODC	DE	79461	US	1	OABNODBIMK@dell.com	4133555649	4	4431688474956900	2008/10	user6464	password	42	100000	M
6465	EIWBWW	CJKGLTTVSE	7770481373 Dell Way	\N	MRSPTXJ	CO	69230	US	1	CJKGLTTVSE@dell.com	7770481373	1	5021697202231735	2008/02	user6465	password	35	40000	F
6466	CIIYLS	JRDCKZVPLM	3631394933 Dell Way	\N	HBGEKJV	DE	59504	US	1	JRDCKZVPLM@dell.com	3631394933	2	7342932134866715	2010/07	user6466	password	30	80000	M
6467	NOHGYZ	JBJJWYVIGW	2785702138 Dell Way	\N	PLHYHLM	NE	74376	US	1	JBJJWYVIGW@dell.com	2785702138	1	3166101767681539	2009/09	user6467	password	24	100000	F
6468	JCGJMH	SWDRRMYNBJ	3044359929 Dell Way	\N	VARHNGZ	OH	41986	US	1	SWDRRMYNBJ@dell.com	3044359929	1	1866530051454901	2009/12	user6468	password	47	80000	F
6469	RBOYUK	CLCOKQQTLQ	2092575814 Dell Way	\N	LSDRRWA	VT	92591	US	1	CLCOKQQTLQ@dell.com	2092575814	2	8814041226170958	2010/12	user6469	password	86	20000	M
6470	MDTXFF	AUPQLJBCUT	8885292788 Dell Way	\N	GMLCMJA	NJ	62740	US	1	AUPQLJBCUT@dell.com	8885292788	1	5699558902997524	2012/04	user6470	password	55	40000	F
6471	GFSMFN	CVYLXBGQHS	5873307390 Dell Way	\N	CJFLKUA	ID	95216	US	1	CVYLXBGQHS@dell.com	5873307390	1	3521526757627726	2008/05	user6471	password	72	40000	M
6472	LUVYWR	XIOZOFGGHQ	5449808669 Dell Way	\N	MTAGTHF	IL	42538	US	1	XIOZOFGGHQ@dell.com	5449808669	2	7685860348399729	2009/08	user6472	password	43	80000	F
6473	ERIWOQ	LNFQUMYLYR	8544178431 Dell Way	\N	LFLTLSC	VT	15834	US	1	LNFQUMYLYR@dell.com	8544178431	1	7496649059932680	2008/11	user6473	password	30	40000	M
6474	MFCDQQ	JHKVGVUXHZ	8662017445 Dell Way	\N	IAKBDID	WI	54086	US	1	JHKVGVUXHZ@dell.com	8662017445	1	4159716579597443	2008/07	user6474	password	81	60000	M
6475	ZRJPAR	AWXWQVDQEE	2751088390 Dell Way	\N	AFHJJGV	GA	46484	US	1	AWXWQVDQEE@dell.com	2751088390	2	9229497226420792	2008/09	user6475	password	64	20000	F
6476	AQLRQH	PNYKROOVOU	7436103438 Dell Way	\N	DYDKUIU	WV	60606	US	1	PNYKROOVOU@dell.com	7436103438	1	3799503536429256	2009/01	user6476	password	71	40000	M
6477	EBILQV	KBMYPINKLL	7544032947 Dell Way	\N	NWFWQEK	LA	27965	US	1	KBMYPINKLL@dell.com	7544032947	4	3340078951325268	2010/02	user6477	password	87	80000	F
6478	HCUCMV	PKLXXVJIJF	2564268287 Dell Way	\N	OFWSQFX	KY	94281	US	1	PKLXXVJIJF@dell.com	2564268287	5	1298101766034960	2008/06	user6478	password	31	40000	M
6479	ZMZVBJ	HZHDIQMNER	6068805990 Dell Way	\N	JWIPURN	WV	52186	US	1	HZHDIQMNER@dell.com	6068805990	1	9039956017863006	2011/06	user6479	password	46	80000	M
6480	JOATWA	AZIQLWUDGR	5323833157 Dell Way	\N	LVLDJKP	WA	54849	US	1	AZIQLWUDGR@dell.com	5323833157	4	9741209820844234	2012/06	user6480	password	86	40000	M
6481	ZZWZZV	IPHEKLKBXG	4620259339 Dell Way	\N	NAQYPOL	CA	31106	US	1	IPHEKLKBXG@dell.com	4620259339	5	6901211042888463	2009/03	user6481	password	65	40000	F
6482	NHEIPU	QUECFGZLTZ	5709318464 Dell Way	\N	CRPQDRW	MT	66554	US	1	QUECFGZLTZ@dell.com	5709318464	5	8458590386435390	2008/02	user6482	password	18	80000	F
6483	EABYRV	DTAJSMDSOV	4762812416 Dell Way	\N	HFYYBLP	NE	37999	US	1	DTAJSMDSOV@dell.com	4762812416	4	5291670541744679	2010/06	user6483	password	85	60000	F
6484	ZNDURW	VAPIDHWYOB	2025014976 Dell Way	\N	WNDIDSQ	NC	53823	US	1	VAPIDHWYOB@dell.com	2025014976	5	9358974521514028	2008/07	user6484	password	46	20000	F
6485	NVTKRU	ZZXGWWVYSJ	2913759652 Dell Way	\N	BBMUSAH	SD	10056	US	1	ZZXGWWVYSJ@dell.com	2913759652	5	6036715731956065	2011/11	user6485	password	65	20000	M
6486	KNJEMI	CTEYODRYET	1224365099 Dell Way	\N	LZLMHGM	MO	17310	US	1	CTEYODRYET@dell.com	1224365099	1	9546027226839216	2011/03	user6486	password	65	20000	M
6487	ZHFIJZ	NIOQZMVSXV	4701864342 Dell Way	\N	DJCJWPM	UT	70470	US	1	NIOQZMVSXV@dell.com	4701864342	3	9034041227307172	2008/08	user6487	password	64	20000	M
6488	WKHVXP	JOOWJHUFLE	4960653528 Dell Way	\N	HVAWHXO	OH	49413	US	1	JOOWJHUFLE@dell.com	4960653528	4	1722526247613132	2008/10	user6488	password	90	100000	F
6489	HTCWDQ	LAATUGEYNA	4322373202 Dell Way	\N	ZKHWYZH	MA	76963	US	1	LAATUGEYNA@dell.com	4322373202	3	5984099172987044	2009/05	user6489	password	72	80000	F
6490	WMHNYH	NRCTVBHVAS	4750702200 Dell Way	\N	DWQDDAW	MT	55054	US	1	NRCTVBHVAS@dell.com	4750702200	5	9041493372060360	2008/07	user6490	password	21	20000	F
6491	INYQBP	TVLUDGUVKQ	9038262303 Dell Way	\N	LNUMJIZ	SC	27532	US	1	TVLUDGUVKQ@dell.com	9038262303	5	7386053288355470	2012/12	user6491	password	70	40000	M
6492	QYOGRK	RLNYGIIWUW	9046136896 Dell Way	\N	RHFZHAE	DE	98646	US	1	RLNYGIIWUW@dell.com	9046136896	1	9702149892225864	2011/05	user6492	password	52	40000	F
6493	ANZKEL	XCRGLOAHFH	5477688195 Dell Way	\N	NFOOKSN	IN	85064	US	1	XCRGLOAHFH@dell.com	5477688195	5	3059437443967908	2012/02	user6493	password	58	20000	M
6494	OLVZIY	RPKFPSLWFR	2997084537 Dell Way	\N	LTBEHJZ	SC	33176	US	1	RPKFPSLWFR@dell.com	2997084537	4	4817628734745085	2011/10	user6494	password	24	40000	F
6495	YINXZC	HESZQPFHAZ	4294398575 Dell Way	\N	IEGREBY	MA	83331	US	1	HESZQPFHAZ@dell.com	4294398575	1	6221052683889866	2010/06	user6495	password	74	40000	M
6496	HHUKPY	DOPSUWSTEX	5087152515 Dell Way	\N	AWBBVLW	FL	64457	US	1	DOPSUWSTEX@dell.com	5087152515	4	1861872148234397	2009/01	user6496	password	83	60000	F
6497	RYXQBM	FTGCMAHJAD	6066280871 Dell Way	\N	KBZWYDM	MD	81646	US	1	FTGCMAHJAD@dell.com	6066280871	4	8542121562641115	2010/02	user6497	password	30	20000	F
6498	CUDOAX	VCKVJUVNEX	3307912836 Dell Way	\N	MBVQNGK	CA	87297	US	1	VCKVJUVNEX@dell.com	3307912836	3	1034088232088834	2010/09	user6498	password	24	60000	F
6499	GCMEXO	OTXIOKNMWP	4825002890 Dell Way	\N	IMCOXEK	DE	76025	US	1	OTXIOKNMWP@dell.com	4825002890	4	4789983084890992	2010/02	user6499	password	82	80000	F
6500	JYCXMV	UVKFJWCYFP	4480183438 Dell Way	\N	BTNGERZ	NJ	35181	US	1	UVKFJWCYFP@dell.com	4480183438	1	4513288477435708	2009/11	user6500	password	60	80000	M
6501	RNINID	XONUQLZGMT	1780243416 Dell Way	\N	TSYKROS	AZ	70734	US	1	XONUQLZGMT@dell.com	1780243416	2	6083437139168382	2011/12	user6501	password	45	40000	M
6502	SVWVTK	JOBUNHHHAA	1058337823 Dell Way	\N	FLSTDUL	HI	21794	US	1	JOBUNHHHAA@dell.com	1058337823	5	2011590989306569	2009/03	user6502	password	63	20000	F
6503	MYVXHJ	YBXFJEGJKR	1847021004 Dell Way	\N	BEVWPAZ	NJ	92674	US	1	YBXFJEGJKR@dell.com	1847021004	1	2303066529799253	2011/02	user6503	password	33	40000	F
6504	BCHKBJ	HGSMNCWFEA	1943056391 Dell Way	\N	AAQBZGY	CA	32782	US	1	HGSMNCWFEA@dell.com	1943056391	5	4056724246125668	2009/01	user6504	password	43	40000	F
6505	QUDABK	SOYULDYMDY	9574124766 Dell Way	\N	CEYJDAP	HI	84764	US	1	SOYULDYMDY@dell.com	9574124766	3	8544526485726238	2009/11	user6505	password	86	100000	M
6506	CYTMRI	KMTNKFRJIV	1204074963 Dell Way	\N	IRYJHEE	IA	76661	US	1	KMTNKFRJIV@dell.com	1204074963	3	6911376468371601	2012/06	user6506	password	43	20000	F
6507	COCKZO	ENZJEJRASJ	5903259145 Dell Way	\N	YBQDGWX	ID	47916	US	1	ENZJEJRASJ@dell.com	5903259145	2	9244290652684868	2012/04	user6507	password	44	100000	M
6508	MKUBOI	BYMKPMDZLE	8316391005 Dell Way	\N	PPKMMRX	AL	91637	US	1	BYMKPMDZLE@dell.com	8316391005	5	2681034551933408	2008/11	user6508	password	19	80000	F
6509	VSXDTV	PELCHKOMZD	6890140577 Dell Way	\N	WMQOJQM	FL	60639	US	1	PELCHKOMZD@dell.com	6890140577	2	5238209987990558	2011/01	user6509	password	75	60000	M
6510	RQLNGP	YIXIWJIAGU	3877985458 Dell Way	\N	QUEHGJW	VT	73804	US	1	YIXIWJIAGU@dell.com	3877985458	3	7404284162446857	2008/01	user6510	password	47	80000	M
6511	WHYLFG	IODRXDYRUS	6689632000 Dell Way	\N	WCZFYXX	IA	53134	US	1	IODRXDYRUS@dell.com	6689632000	2	5995295673143119	2008/02	user6511	password	36	100000	F
6512	EIRLRF	OJCSHUNAQP	9295076323 Dell Way	\N	ZWNXUTJ	ME	20418	US	1	OJCSHUNAQP@dell.com	9295076323	3	3339446922298521	2008/05	user6512	password	68	40000	M
6513	JUJOJT	RBBMPBDEBZ	8339040479 Dell Way	\N	RYTLIEO	IA	66999	US	1	RBBMPBDEBZ@dell.com	8339040479	3	9841172339394690	2010/10	user6513	password	67	100000	M
6514	BLWUCY	WONYRRZRJY	2943094884 Dell Way	\N	LVGPJMG	FL	91661	US	1	WONYRRZRJY@dell.com	2943094884	4	6973439172375948	2012/07	user6514	password	32	100000	M
6515	CTCAPR	ONIGNAPLLL	8089237745 Dell Way	\N	SAUFGZD	MO	69358	US	1	ONIGNAPLLL@dell.com	8089237745	2	2904875530861318	2012/04	user6515	password	32	20000	F
6516	HCRYQF	HXSHNESYXT	6016886575 Dell Way	\N	SDARGMI	AL	88232	US	1	HXSHNESYXT@dell.com	6016886575	1	2656620393972844	2011/01	user6516	password	36	20000	F
6517	XZVCGS	VOFAHDXAWA	6396759510 Dell Way	\N	BOHOXIK	MN	39317	US	1	VOFAHDXAWA@dell.com	6396759510	2	4679906463250518	2012/03	user6517	password	60	80000	F
6518	KWMDSB	JSINQJJRKX	1096150106 Dell Way	\N	ZYVHJHP	WV	53363	US	1	JSINQJJRKX@dell.com	1096150106	5	7543731827754528	2010/07	user6518	password	87	20000	F
6519	LDEMMX	UZOEJFOHFN	6180070608 Dell Way	\N	CMWJBVW	CA	67216	US	1	UZOEJFOHFN@dell.com	6180070608	4	2859294385183602	2010/09	user6519	password	65	100000	M
6520	VLISGI	GKRMYYRMAD	9971924756 Dell Way	\N	IKFEGHU	TN	97700	US	1	GKRMYYRMAD@dell.com	9971924756	2	6981769434642047	2011/04	user6520	password	54	60000	M
6521	VEADKK	UXJSOVTSEE	8610242668 Dell Way	\N	XIKFCGE	CO	63816	US	1	UXJSOVTSEE@dell.com	8610242668	4	9242705844342710	2009/03	user6521	password	67	20000	F
6522	SHVCBS	MUHIOZNSXV	9161994394 Dell Way	\N	DCYKHBZ	CT	84274	US	1	MUHIOZNSXV@dell.com	9161994394	3	1498051253147423	2010/08	user6522	password	51	40000	M
6523	HKYZXT	HGIGTADOEG	5202892516 Dell Way	\N	NPNPOQK	MO	19208	US	1	HGIGTADOEG@dell.com	5202892516	1	7462883690372110	2012/05	user6523	password	62	40000	M
6524	OFQIMW	QSPRWEVCSL	1658384337 Dell Way	\N	PHZGSMJ	FL	58326	US	1	QSPRWEVCSL@dell.com	1658384337	1	8964356909040363	2011/04	user6524	password	64	40000	M
6525	HOZDES	TVOYRRRCHZ	9999755986 Dell Way	\N	CNRPWWC	WI	96546	US	1	TVOYRRRCHZ@dell.com	9999755986	4	3432983433827758	2011/11	user6525	password	74	100000	F
6526	TBQLVL	ATDRKGYKJL	2390198005 Dell Way	\N	BYIXBHW	AR	93108	US	1	ATDRKGYKJL@dell.com	2390198005	4	8219676733948291	2012/08	user6526	password	35	80000	M
6527	WDLIDF	LVQSTABFCZ	6193050761 Dell Way	\N	OABWWCU	AL	80528	US	1	LVQSTABFCZ@dell.com	6193050761	5	4328913802746683	2012/08	user6527	password	18	80000	M
6528	LZYQLU	HDNHFTJFIJ	5561854103 Dell Way	\N	GEGJYHD	MT	33497	US	1	HDNHFTJFIJ@dell.com	5561854103	2	9280647501349450	2010/01	user6528	password	70	100000	M
6529	RPLLXO	ZEUTOZBXFG	6695016845 Dell Way	\N	EPELSSS	HI	13545	US	1	ZEUTOZBXFG@dell.com	6695016845	4	1439756076317280	2009/09	user6529	password	20	20000	F
6530	MMFAMJ	UFXUHVANZP	5251135733 Dell Way	\N	RLHJENL	SC	33114	US	1	UFXUHVANZP@dell.com	5251135733	1	9571206044871360	2010/03	user6530	password	37	100000	M
6531	LACVVI	TPPOPCOFUA	3023877961 Dell Way	\N	MEEAPYH	AR	18075	US	1	TPPOPCOFUA@dell.com	3023877961	3	3316982583608478	2010/07	user6531	password	83	100000	M
6532	AUKINZ	XCPARUURHY	2186331986 Dell Way	\N	VHNUPOW	SC	22098	US	1	XCPARUURHY@dell.com	2186331986	2	7140398867428303	2008/03	user6532	password	36	20000	F
6533	QJNQHQ	GHHABYIZUQ	9090566452 Dell Way	\N	NPFCLAF	NE	36819	US	1	GHHABYIZUQ@dell.com	9090566452	4	5757177475839854	2008/08	user6533	password	56	80000	F
6534	BKIRQP	ZRRYARSQEH	7028407291 Dell Way	\N	VHTVMID	MA	96356	US	1	ZRRYARSQEH@dell.com	7028407291	3	6623872152063996	2009/04	user6534	password	66	40000	M
6535	ZYJPXB	HVBYORDWNK	5730564157 Dell Way	\N	PJXYNHX	DE	84088	US	1	HVBYORDWNK@dell.com	5730564157	2	2270437540952116	2008/08	user6535	password	81	20000	M
6536	GTMIBH	JZWBDSPOHY	7254018385 Dell Way	\N	LGLSDQO	NY	10571	US	1	JZWBDSPOHY@dell.com	7254018385	5	6777956401463599	2010/01	user6536	password	33	100000	M
6537	RDVZNV	VOYODNVCYC	8435796546 Dell Way	\N	ORFEFXE	WA	77721	US	1	VOYODNVCYC@dell.com	8435796546	3	8035112041514368	2008/04	user6537	password	60	80000	F
6538	KSYGON	FCRSYTRAII	7243222179 Dell Way	\N	GMOERMX	MS	97885	US	1	FCRSYTRAII@dell.com	7243222179	3	3605068260338157	2009/04	user6538	password	71	80000	M
6539	RYOFER	WWQQNRZWXM	2606864012 Dell Way	\N	LCDXZQX	NY	27272	US	1	WWQQNRZWXM@dell.com	2606864012	5	5206507911905647	2012/08	user6539	password	51	80000	M
6540	AVTSSQ	IJEZIAXULZ	3111679155 Dell Way	\N	YJZOGRT	MI	65205	US	1	IJEZIAXULZ@dell.com	3111679155	2	3401188201270998	2011/12	user6540	password	81	80000	M
6541	QLMGTV	KSELQYXPWG	1897492303 Dell Way	\N	OLNFFZV	MN	38167	US	1	KSELQYXPWG@dell.com	1897492303	1	3436514226719737	2012/11	user6541	password	21	60000	F
6542	NVBJGU	NSKMPZJWOV	9503060447 Dell Way	\N	KUAJPMR	OK	67469	US	1	NSKMPZJWOV@dell.com	9503060447	4	5688704937696457	2012/04	user6542	password	78	60000	F
6543	XXJRKB	BXRBGOQBYK	7577054058 Dell Way	\N	CIAOZSF	WA	45857	US	1	BXRBGOQBYK@dell.com	7577054058	5	6989316194318236	2010/06	user6543	password	74	60000	F
6544	DCTFEQ	XFXLVYKGBS	1253969151 Dell Way	\N	GQSZVQJ	ND	60122	US	1	XFXLVYKGBS@dell.com	1253969151	1	1032736478373408	2012/07	user6544	password	42	100000	M
6545	CEVTBB	QNXPXDQQJG	5748403848 Dell Way	\N	IJCZSQN	OR	78203	US	1	QNXPXDQQJG@dell.com	5748403848	3	3882818648125976	2012/06	user6545	password	90	100000	M
6546	VSSXIG	UYEYPUIVDR	6784186875 Dell Way	\N	YCKOQDI	DC	70117	US	1	UYEYPUIVDR@dell.com	6784186875	1	2444768516346812	2011/12	user6546	password	77	60000	M
6547	OJAUEY	YCOTLJXCHZ	4912857556 Dell Way	\N	MWPPETH	TN	79450	US	1	YCOTLJXCHZ@dell.com	4912857556	3	7738261513411999	2009/12	user6547	password	49	100000	F
6548	LPLKOO	YIZIFBQEON	1513562840 Dell Way	\N	UESNLNI	UT	10026	US	1	YIZIFBQEON@dell.com	1513562840	1	9397388062905520	2010/12	user6548	password	34	100000	M
6549	RICFHK	FQPHGTVTOZ	9300781725 Dell Way	\N	LCKZKHZ	MI	46660	US	1	FQPHGTVTOZ@dell.com	9300781725	5	4030489425640553	2008/11	user6549	password	81	100000	F
6550	YBMIGC	YNJSIDGIPI	7925187459 Dell Way	\N	TOSAOEL	MO	18436	US	1	YNJSIDGIPI@dell.com	7925187459	4	9626948965713384	2011/06	user6550	password	29	60000	M
6551	RYTUWH	DOQGUYWCRL	1325077383 Dell Way	\N	VSZZDMC	VT	19717	US	1	DOQGUYWCRL@dell.com	1325077383	3	6081794914789498	2008/02	user6551	password	23	100000	F
6552	VQXCTM	SAGRWJJIEC	5017649560 Dell Way	\N	HEGUGDW	IL	73212	US	1	SAGRWJJIEC@dell.com	5017649560	3	8545684806071223	2010/05	user6552	password	83	40000	M
6553	VLSHET	NWQXFYCHGG	3008210495 Dell Way	\N	NAMRXUK	LA	32749	US	1	NWQXFYCHGG@dell.com	3008210495	5	6313072209246457	2008/03	user6553	password	58	100000	M
6554	HFWBTS	SQXQSFXZTY	1652726975 Dell Way	\N	LLVFVFM	AR	16968	US	1	SQXQSFXZTY@dell.com	1652726975	1	3677016664762050	2011/02	user6554	password	88	100000	F
6555	VYCNRS	LHLRFKKDWW	6126722326 Dell Way	\N	ZCRFPSH	NV	89232	US	1	LHLRFKKDWW@dell.com	6126722326	2	9879559775348754	2010/03	user6555	password	40	40000	F
6556	KWVCHC	OZIZJMVFMY	5240902603 Dell Way	\N	XRNPYEM	MS	50069	US	1	OZIZJMVFMY@dell.com	5240902603	1	6744768016971648	2011/05	user6556	password	75	20000	F
6557	PHOSVN	BUXNQDZOAQ	3983835061 Dell Way	\N	CQOGCBS	NE	20360	US	1	BUXNQDZOAQ@dell.com	3983835061	2	5569498365744949	2008/07	user6557	password	74	80000	M
6558	ILRWML	UACXZRXQTO	9063776292 Dell Way	\N	FAQHSFK	AL	63155	US	1	UACXZRXQTO@dell.com	9063776292	1	2127132033463567	2011/11	user6558	password	86	20000	F
6559	PWUBQU	EOUVMKPAPP	6433511725 Dell Way	\N	RWHXGHM	DE	50540	US	1	EOUVMKPAPP@dell.com	6433511725	5	3921279270667583	2010/10	user6559	password	64	20000	M
6560	LFJGJX	AFJLUJAJAX	7408737945 Dell Way	\N	QXEYKIK	AK	24467	US	1	AFJLUJAJAX@dell.com	7408737945	3	9917686714325100	2009/09	user6560	password	68	80000	M
6561	BAGYBM	HMGRNPSLGQ	1747712747 Dell Way	\N	PEAYOAC	ID	60316	US	1	HMGRNPSLGQ@dell.com	1747712747	4	3279611218720675	2011/06	user6561	password	29	100000	F
6562	LTNXBZ	DSNTKYZAND	8791736374 Dell Way	\N	BLSBOZP	NM	64579	US	1	DSNTKYZAND@dell.com	8791736374	3	1222543556708842	2008/03	user6562	password	52	60000	M
6563	ZIAZMT	MFEKEEYIFK	6631911947 Dell Way	\N	AHYZXOP	PA	97747	US	1	MFEKEEYIFK@dell.com	6631911947	4	2801424405537546	2008/03	user6563	password	30	20000	M
6564	FBAYNF	CYJHWRNGSU	9237829190 Dell Way	\N	ESSTHLS	WA	31417	US	1	CYJHWRNGSU@dell.com	9237829190	1	5169618766289205	2008/02	user6564	password	19	40000	F
6565	BGRGJP	QQMIESAZWS	8361735785 Dell Way	\N	RQADIYJ	IA	97455	US	1	QQMIESAZWS@dell.com	8361735785	2	1705463840160519	2012/08	user6565	password	35	100000	M
6566	XDFNUW	ZCASDZOWRF	8846944164 Dell Way	\N	WUNVDUU	WI	20406	US	1	ZCASDZOWRF@dell.com	8846944164	4	7783334493637086	2008/08	user6566	password	64	20000	M
6567	WOOTOR	TGUTVRKANE	2665791013 Dell Way	\N	OJIIDGL	AK	13632	US	1	TGUTVRKANE@dell.com	2665791013	1	7334793055430055	2012/02	user6567	password	54	80000	M
6568	CLGTFN	OYIFJITOXC	8920301437 Dell Way	\N	WFGDQGE	SD	45506	US	1	OYIFJITOXC@dell.com	8920301437	4	5933948230464012	2009/04	user6568	password	36	60000	M
6569	NFYAUX	JAHSTVPWSU	3885032803 Dell Way	\N	CWKJAGU	VT	88210	US	1	JAHSTVPWSU@dell.com	3885032803	2	2751237450167537	2010/10	user6569	password	86	20000	M
6570	XDUUMU	BEOXTKQNNM	3133165661 Dell Way	\N	YXNERLB	WY	75202	US	1	BEOXTKQNNM@dell.com	3133165661	3	5398567559663207	2008/08	user6570	password	52	20000	M
6571	GWGBYK	PVEZMRNYQK	2029164730 Dell Way	\N	MVBXWBQ	CA	64214	US	1	PVEZMRNYQK@dell.com	2029164730	2	3343992067966610	2010/05	user6571	password	20	100000	F
6572	HXDSMZ	WMLOZKEJWZ	3915996199 Dell Way	\N	KUWLKYB	MT	28549	US	1	WMLOZKEJWZ@dell.com	3915996199	1	5925300931092352	2009/12	user6572	password	72	80000	M
6573	XJIWFV	IUUSZDPYOK	5502887280 Dell Way	\N	VAUTCIY	ME	50250	US	1	IUUSZDPYOK@dell.com	5502887280	4	4735653830692172	2009/06	user6573	password	38	20000	M
6574	QAZLIT	FBSJRRYBMY	1597671094 Dell Way	\N	WGBFFMQ	OH	32008	US	1	FBSJRRYBMY@dell.com	1597671094	5	7041521030012519	2009/02	user6574	password	50	100000	F
6575	LKLFPM	YYEPXFCVCJ	3471025074 Dell Way	\N	XHOJYGP	AL	26931	US	1	YYEPXFCVCJ@dell.com	3471025074	2	3492231783922762	2011/04	user6575	password	45	20000	M
6576	UJIHHH	LXERAAUJXB	6417653290 Dell Way	\N	XGADWBI	DC	47617	US	1	LXERAAUJXB@dell.com	6417653290	5	7699539182707668	2012/01	user6576	password	51	80000	F
6577	UBRBNO	FEOGYYDAVK	3520398151 Dell Way	\N	BZHDHKN	VA	35263	US	1	FEOGYYDAVK@dell.com	3520398151	5	3751060624606907	2011/08	user6577	password	68	60000	M
6578	JPFYVK	NBJLFKHPMG	8987671834 Dell Way	\N	WPNHDKP	MD	35389	US	1	NBJLFKHPMG@dell.com	8987671834	1	9351021013222636	2010/08	user6578	password	64	100000	F
6579	WXBHKC	QWIBDXNJUC	5619490349 Dell Way	\N	XCFHRQP	NE	78784	US	1	QWIBDXNJUC@dell.com	5619490349	1	4856994774658233	2008/02	user6579	password	67	20000	M
6580	THKWYG	EZJCNTXQQZ	6889571345 Dell Way	\N	VYRMNGF	AL	47901	US	1	EZJCNTXQQZ@dell.com	6889571345	1	5736201708670706	2009/03	user6580	password	55	20000	M
6581	XXLECL	OEZHBPYBLW	9639989539 Dell Way	\N	TXKACKL	RI	64780	US	1	OEZHBPYBLW@dell.com	9639989539	1	8361452233977617	2010/03	user6581	password	41	60000	F
6582	UOEGDI	FLKUJLFFFC	5139734284 Dell Way	\N	PFFARZQ	NJ	18680	US	1	FLKUJLFFFC@dell.com	5139734284	1	3373018573503941	2011/06	user6582	password	43	60000	F
6583	NVFWAQ	GVZSBFYEVD	7703617674 Dell Way	\N	KWUKNKM	WV	56123	US	1	GVZSBFYEVD@dell.com	7703617674	4	1078119576442986	2008/04	user6583	password	23	80000	F
6584	HMEXSZ	XLADJEYNOV	3322281593 Dell Way	\N	IYITLHG	FL	13298	US	1	XLADJEYNOV@dell.com	3322281593	2	4246554450131953	2009/11	user6584	password	54	80000	F
6585	RNCQLN	ROXVNKKITJ	3925600653 Dell Way	\N	QMUYSZZ	WY	34002	US	1	ROXVNKKITJ@dell.com	3925600653	2	2411292112898081	2012/12	user6585	password	55	60000	F
6586	PCXDTM	BPZLAHFKYR	6488396373 Dell Way	\N	FWKEVJL	DE	73556	US	1	BPZLAHFKYR@dell.com	6488396373	5	6837379992008210	2008/06	user6586	password	27	80000	M
6587	BWINXY	MJZUOJTGOQ	4413237521 Dell Way	\N	QTMAEQS	SC	66724	US	1	MJZUOJTGOQ@dell.com	4413237521	5	1858197567984461	2010/08	user6587	password	66	60000	M
6588	ABLYOU	XJJHCPVTGO	6162290421 Dell Way	\N	FHTWAOM	MA	54444	US	1	XJJHCPVTGO@dell.com	6162290421	5	2391356669832021	2009/06	user6588	password	67	40000	F
6589	DFAYDJ	HKMXGFDVLL	8078476550 Dell Way	\N	OHLDTVQ	KS	72796	US	1	HKMXGFDVLL@dell.com	8078476550	3	2144759213551879	2010/10	user6589	password	62	60000	F
6590	QNEAVO	NSUSWPEHEL	4132987536 Dell Way	\N	SIENYNF	OR	16609	US	1	NSUSWPEHEL@dell.com	4132987536	2	9039129063487054	2012/10	user6590	password	85	80000	F
6591	CQDQDV	LWSBAZGLSP	1895154514 Dell Way	\N	QFNDLHF	SC	54703	US	1	LWSBAZGLSP@dell.com	1895154514	4	3731506424024701	2008/05	user6591	password	63	20000	M
6592	TTDPEZ	HGAHMLZCBF	7252086620 Dell Way	\N	PFRXKLK	MT	28685	US	1	HGAHMLZCBF@dell.com	7252086620	3	6047220716718585	2009/08	user6592	password	57	20000	F
6593	RROQZU	QHHCGJEMZJ	4355803052 Dell Way	\N	DXUPHHV	WV	84938	US	1	QHHCGJEMZJ@dell.com	4355803052	2	5171217467635870	2012/05	user6593	password	78	60000	F
6594	KFAFVI	MYPWCBWLFT	8554101489 Dell Way	\N	GVBOQAJ	AK	37968	US	1	MYPWCBWLFT@dell.com	8554101489	5	7162444500718266	2011/06	user6594	password	71	20000	M
6595	UGNCTM	RQOSNAYGGT	3857859486 Dell Way	\N	HUKIEKQ	AK	38314	US	1	RQOSNAYGGT@dell.com	3857859486	4	8204973735846580	2008/10	user6595	password	53	100000	F
6596	AXTMOK	BHXBGEIAMD	9281216188 Dell Way	\N	KUHULID	OR	10648	US	1	BHXBGEIAMD@dell.com	9281216188	4	7833037234842778	2010/08	user6596	password	73	60000	M
6597	NYCXZK	VBRZJRLMCG	8768640790 Dell Way	\N	UXRCAKC	WA	28189	US	1	VBRZJRLMCG@dell.com	8768640790	2	8444956122897566	2011/10	user6597	password	44	20000	M
6598	MCSXXT	OWCGIOJOJG	6969084702 Dell Way	\N	FLGQOFV	ME	59300	US	1	OWCGIOJOJG@dell.com	6969084702	1	4034426686353982	2008/03	user6598	password	22	60000	F
6599	TKEMZB	PGJEPYNVEZ	2591892806 Dell Way	\N	CVNHQYV	IN	10265	US	1	PGJEPYNVEZ@dell.com	2591892806	2	2895699945278466	2009/11	user6599	password	54	100000	F
6600	RMGTCM	DGBBUXGTZB	5067493716 Dell Way	\N	HHRGCZG	IL	40072	US	1	DGBBUXGTZB@dell.com	5067493716	3	2603929521050304	2012/07	user6600	password	49	80000	F
6601	RJCDMI	EOCCUWBVDI	1245615453 Dell Way	\N	NKLNQTW	CA	33590	US	1	EOCCUWBVDI@dell.com	1245615453	1	8025502193719149	2010/08	user6601	password	75	20000	F
6602	WGNFLB	INVFPQJYET	2360574775 Dell Way	\N	JRJCNLJ	ND	53934	US	1	INVFPQJYET@dell.com	2360574775	1	2322833743877709	2012/02	user6602	password	30	100000	F
6603	RAWSJJ	NOZEXXJRGA	2132190025 Dell Way	\N	AJOMTDZ	VA	22431	US	1	NOZEXXJRGA@dell.com	2132190025	5	3492829145397991	2009/08	user6603	password	67	100000	M
6604	NRBXFQ	WKOTTFAUGJ	8939502194 Dell Way	\N	ISDMSAP	TN	86210	US	1	WKOTTFAUGJ@dell.com	8939502194	1	5465089788194746	2010/02	user6604	password	31	20000	M
6605	GZZWVJ	KPDPPXWZGP	5146464559 Dell Way	\N	CSHDIDZ	GA	32449	US	1	KPDPPXWZGP@dell.com	5146464559	4	4067441640887410	2011/10	user6605	password	25	100000	M
6606	CTQLDF	OTVMPUSEXL	2532182600 Dell Way	\N	LATPZYV	MI	73886	US	1	OTVMPUSEXL@dell.com	2532182600	1	5875619085971267	2009/12	user6606	password	43	40000	M
6607	ZVVFKP	AWEUPJSAVS	9858599271 Dell Way	\N	UKSTFDL	MD	29529	US	1	AWEUPJSAVS@dell.com	9858599271	4	2593368834350258	2009/01	user6607	password	81	40000	M
6608	SNGHNC	MISVASRTNB	9760494857 Dell Way	\N	LGHPRRU	NV	40608	US	1	MISVASRTNB@dell.com	9760494857	5	4355068479664624	2012/04	user6608	password	34	60000	M
6609	MWIOIR	HERZVLNXWT	5885237168 Dell Way	\N	ELKVGCE	HI	16942	US	1	HERZVLNXWT@dell.com	5885237168	1	4413350320886821	2011/08	user6609	password	31	40000	M
6610	NUWEBA	WBWHOTEIXQ	3464879940 Dell Way	\N	TTXVXDX	MN	28571	US	1	WBWHOTEIXQ@dell.com	3464879940	2	8614752895198763	2010/06	user6610	password	43	100000	F
6611	FEIFAK	CIZWNHUDAN	3068765831 Dell Way	\N	BVLETXJ	AK	23153	US	1	CIZWNHUDAN@dell.com	3068765831	3	6426378755364568	2010/06	user6611	password	80	80000	M
6612	EAQPCY	OYMWTQWHRS	4538498509 Dell Way	\N	SVLQFLU	MN	93731	US	1	OYMWTQWHRS@dell.com	4538498509	1	4445399332325906	2009/10	user6612	password	90	60000	M
6613	QAXPPW	BLQRIXIBQE	3488526362 Dell Way	\N	NGKZBWX	MI	92001	US	1	BLQRIXIBQE@dell.com	3488526362	4	7492781825829298	2009/02	user6613	password	56	100000	F
6614	LMUIOG	YFOVOQLTDS	7037285407 Dell Way	\N	ECTAZFY	ID	91093	US	1	YFOVOQLTDS@dell.com	7037285407	3	1384169570170342	2009/06	user6614	password	34	80000	M
6615	ZZLGXR	VTGLEZOXDQ	8224398607 Dell Way	\N	REQWDXT	SD	48990	US	1	VTGLEZOXDQ@dell.com	8224398607	1	8774765547364951	2008/08	user6615	password	75	20000	M
6616	GGOXBH	ENMDBJHSBM	5978297789 Dell Way	\N	JXQGRLR	MN	50151	US	1	ENMDBJHSBM@dell.com	5978297789	3	2005058540496975	2009/07	user6616	password	72	60000	M
6617	HMVPRI	CUKMCCNPMK	2802219642 Dell Way	\N	FSBQKNC	WV	11620	US	1	CUKMCCNPMK@dell.com	2802219642	2	5716959851328284	2012/11	user6617	password	39	40000	F
6618	DWALYV	WLYYYNKJSD	5525382577 Dell Way	\N	LJOYLNZ	NV	83362	US	1	WLYYYNKJSD@dell.com	5525382577	4	7206694847438485	2011/11	user6618	password	22	100000	M
6619	CJRXFC	WEBJPKCSVM	3753643629 Dell Way	\N	HUYUUPQ	IL	27660	US	1	WEBJPKCSVM@dell.com	3753643629	1	1588641777168959	2009/12	user6619	password	76	60000	F
6620	MJOPFS	QPHBSAWEIR	9465644377 Dell Way	\N	CDLRTSW	AR	80812	US	1	QPHBSAWEIR@dell.com	9465644377	3	7882213701494039	2011/11	user6620	password	25	40000	F
6621	RUMJLB	RMUSJYABAE	7865508526 Dell Way	\N	MSXFPYZ	NC	41430	US	1	RMUSJYABAE@dell.com	7865508526	2	2948696946259588	2012/06	user6621	password	51	60000	F
6622	YXTAPF	UHPTIQTMDM	8994473141 Dell Way	\N	JJBIJPR	CO	88528	US	1	UHPTIQTMDM@dell.com	8994473141	5	4212881692219526	2009/07	user6622	password	65	40000	F
6623	JHZPCH	FVPWPCABMJ	9789984291 Dell Way	\N	DVSTMVQ	LA	81530	US	1	FVPWPCABMJ@dell.com	9789984291	4	3710782193578780	2011/01	user6623	password	69	20000	F
6624	SQKZVF	PSUSSWEBAZ	7065127034 Dell Way	\N	TTMPJWJ	LA	61521	US	1	PSUSSWEBAZ@dell.com	7065127034	5	6216282785870135	2009/12	user6624	password	82	20000	M
6625	HBLMQD	HJWENXENRY	1163100784 Dell Way	\N	AGIWQRL	IN	68674	US	1	HJWENXENRY@dell.com	1163100784	4	6756553655955941	2012/10	user6625	password	36	20000	M
6626	SRMWZV	SDJQIXHGXO	5798038755 Dell Way	\N	OUEGFMX	HI	26249	US	1	SDJQIXHGXO@dell.com	5798038755	1	9504555418156088	2011/04	user6626	password	73	60000	M
6627	GIZBAC	KQLHYRFNGZ	3806337230 Dell Way	\N	SMEEJKJ	VT	58345	US	1	KQLHYRFNGZ@dell.com	3806337230	4	8673100408632309	2008/03	user6627	password	79	40000	M
6628	VJNYUE	JCDAHQHGIT	3125006654 Dell Way	\N	LNDWWBJ	FL	79045	US	1	JCDAHQHGIT@dell.com	3125006654	2	9497130678035320	2008/07	user6628	password	50	100000	M
6629	ZVSDEU	HFCXMJFGUS	2701213975 Dell Way	\N	KQPMAUG	ID	12742	US	1	HFCXMJFGUS@dell.com	2701213975	2	6439771276433021	2011/03	user6629	password	58	80000	F
6630	HTGCAL	EYYNDFIWPY	8629662335 Dell Way	\N	LCZFIGG	MT	61734	US	1	EYYNDFIWPY@dell.com	8629662335	1	8351404419168831	2009/10	user6630	password	82	80000	M
6631	DTOPYM	NLQTUMJSXL	3950003269 Dell Way	\N	SDUYJHN	HI	51185	US	1	NLQTUMJSXL@dell.com	3950003269	4	3024252603296190	2009/04	user6631	password	72	40000	F
6632	HYZUMK	KFEWOXUAPX	7909135259 Dell Way	\N	UOHCBNO	MA	20387	US	1	KFEWOXUAPX@dell.com	7909135259	4	4595924051478505	2010/12	user6632	password	49	100000	M
6633	KPJVAP	ZWDXRENPYB	8960765271 Dell Way	\N	WADJONM	KY	21159	US	1	ZWDXRENPYB@dell.com	8960765271	5	1666371196974069	2009/09	user6633	password	88	80000	F
6634	INHXNE	BLWFYLEAIF	8975233937 Dell Way	\N	ERUREDV	AR	98159	US	1	BLWFYLEAIF@dell.com	8975233937	2	6977049844805152	2012/02	user6634	password	87	20000	M
6635	GCDLEP	HJOTOOBTTT	3608950439 Dell Way	\N	NLXQGYQ	CT	39279	US	1	HJOTOOBTTT@dell.com	3608950439	5	4712465949356556	2009/02	user6635	password	20	60000	F
6636	EYKTGU	HAIWBCQVPB	4736346611 Dell Way	\N	SGHRWKA	DE	46117	US	1	HAIWBCQVPB@dell.com	4736346611	3	6029637755360455	2010/12	user6636	password	76	80000	M
6637	FJDZRE	IOGKEBAFUG	9142751514 Dell Way	\N	NLDYLHI	UT	74813	US	1	IOGKEBAFUG@dell.com	9142751514	2	6802013561595232	2011/12	user6637	password	56	100000	F
6638	RXZVGO	BQSDQYXXMJ	7274125183 Dell Way	\N	AKUITRB	NY	98975	US	1	BQSDQYXXMJ@dell.com	7274125183	2	9306278099771590	2009/04	user6638	password	35	100000	F
6639	FTLUUC	NYSLVPYEQJ	6149762292 Dell Way	\N	ZZDRAUQ	OK	25387	US	1	NYSLVPYEQJ@dell.com	6149762292	5	5284381802193821	2012/11	user6639	password	68	20000	M
6640	DVJFIH	YTDNSIEBHD	6403237741 Dell Way	\N	EZDYQWD	FL	82578	US	1	YTDNSIEBHD@dell.com	6403237741	5	6786630501970649	2009/01	user6640	password	33	60000	M
6641	PRDXPX	ADPJHRRLVQ	9155106813 Dell Way	\N	PUGLXLG	MS	48234	US	1	ADPJHRRLVQ@dell.com	9155106813	5	5090698319952935	2008/03	user6641	password	39	80000	M
6642	LPMJQP	ZZXQRJMHYG	8494218747 Dell Way	\N	NKEYRRJ	ND	51974	US	1	ZZXQRJMHYG@dell.com	8494218747	4	7327858099248261	2008/05	user6642	password	61	60000	M
6643	CYQSXQ	POHYAOXHCH	3461274691 Dell Way	\N	LBYCLNO	ID	26580	US	1	POHYAOXHCH@dell.com	3461274691	2	6174912792164833	2012/12	user6643	password	59	100000	M
6644	FQVVGJ	DFKSCRUJCV	6187156137 Dell Way	\N	IFHVUNA	AR	92297	US	1	DFKSCRUJCV@dell.com	6187156137	5	8853155310265721	2008/11	user6644	password	73	40000	M
6645	OFUYIZ	IABAVLCRTI	3341879761 Dell Way	\N	YOCMOEK	DC	17725	US	1	IABAVLCRTI@dell.com	3341879761	2	9664873661939056	2008/08	user6645	password	53	80000	M
6646	GOEFWF	HWBSZSMHRB	6508303682 Dell Way	\N	KDQONUQ	SC	16698	US	1	HWBSZSMHRB@dell.com	6508303682	5	7561259602662177	2008/06	user6646	password	60	40000	M
6647	UOVZWS	BPRTCZLDKO	4077205900 Dell Way	\N	TYCNPXP	GA	73657	US	1	BPRTCZLDKO@dell.com	4077205900	2	2126228648703545	2012/08	user6647	password	24	80000	F
6648	XRCPSR	HMTHXXRMRP	3838866923 Dell Way	\N	PFFMVKE	DC	74805	US	1	HMTHXXRMRP@dell.com	3838866923	1	4365566184744239	2009/10	user6648	password	61	40000	F
6649	SYEJFR	DMPBEBSTRX	5327627778 Dell Way	\N	ZDSKIWC	NV	95008	US	1	DMPBEBSTRX@dell.com	5327627778	1	7462071555200965	2008/05	user6649	password	30	80000	F
6650	JENAIA	PJERBYJZXN	2856706296 Dell Way	\N	RHVOKNM	VA	60118	US	1	PJERBYJZXN@dell.com	2856706296	5	9325264229439200	2009/09	user6650	password	34	80000	M
6651	TTFTJO	YBQWKPUXHB	7766163356 Dell Way	\N	TVMHHJV	MT	39153	US	1	YBQWKPUXHB@dell.com	7766163356	5	1634361450560391	2012/08	user6651	password	89	80000	F
6652	FLUTKV	KGGZAEHCYC	3784394095 Dell Way	\N	OFKXBXG	SC	82563	US	1	KGGZAEHCYC@dell.com	3784394095	4	4974421059712768	2009/06	user6652	password	79	60000	M
6653	QGIMRO	SRPXYRWAGC	6202552159 Dell Way	\N	KEDIKYD	OH	73704	US	1	SRPXYRWAGC@dell.com	6202552159	5	2712298116181046	2010/06	user6653	password	27	20000	M
6654	MNJAGB	QDZIAZOCKS	1492902799 Dell Way	\N	FTCEWUW	MN	81324	US	1	QDZIAZOCKS@dell.com	1492902799	5	3406728945206851	2008/11	user6654	password	90	80000	F
6655	JRRKIU	KQUJEXUXCN	8647977062 Dell Way	\N	ZGKUDVP	FL	74631	US	1	KQUJEXUXCN@dell.com	8647977062	2	6703391221351922	2012/01	user6655	password	22	40000	M
6656	SQANAR	HKWFETHSSO	3634921376 Dell Way	\N	CNSYCXR	WI	33528	US	1	HKWFETHSSO@dell.com	3634921376	4	3578646192327142	2009/01	user6656	password	90	20000	M
6657	AORSWC	OBHHJZAYBN	1690629610 Dell Way	\N	QAQNROU	WV	42137	US	1	OBHHJZAYBN@dell.com	1690629610	2	4364945802371949	2008/05	user6657	password	20	20000	M
6658	SUVVJW	CQGBQEDEVD	1687234667 Dell Way	\N	UJVIDUS	HI	19701	US	1	CQGBQEDEVD@dell.com	1687234667	2	5339633987750858	2008/05	user6658	password	48	100000	F
6659	GQOCTF	JUWOYAJCUT	3671284809 Dell Way	\N	XDXSVCV	VT	47444	US	1	JUWOYAJCUT@dell.com	3671284809	1	8452678977977485	2011/11	user6659	password	21	100000	F
6660	QBFVLA	RZYRJBMCZP	4060358467 Dell Way	\N	ZRLCMJN	RI	43790	US	1	RZYRJBMCZP@dell.com	4060358467	3	3071418222039938	2009/06	user6660	password	71	20000	M
6661	YVYZNY	YEHZQJYGJQ	6819265722 Dell Way	\N	RLCBZXK	IN	45703	US	1	YEHZQJYGJQ@dell.com	6819265722	4	8659600335173310	2009/09	user6661	password	45	40000	M
6662	IIAGGF	NGWXFCGWUS	2012252463 Dell Way	\N	ZVRWGZG	VA	71187	US	1	NGWXFCGWUS@dell.com	2012252463	2	4409613127820194	2010/08	user6662	password	84	100000	M
6663	YBFDOL	ZMRCTOXLNS	2589029217 Dell Way	\N	DJZDQWU	PA	23524	US	1	ZMRCTOXLNS@dell.com	2589029217	2	7819523662328721	2008/01	user6663	password	68	20000	F
6664	WERIED	AGWOEIBXLL	6940471152 Dell Way	\N	WOCTJVX	NC	15560	US	1	AGWOEIBXLL@dell.com	6940471152	4	1874581120908260	2009/08	user6664	password	31	40000	M
6665	VOZZPG	WEKEGHQSEF	7919908846 Dell Way	\N	UYOPVDR	MS	77761	US	1	WEKEGHQSEF@dell.com	7919908846	5	4642704182304442	2012/01	user6665	password	34	80000	M
6666	FTGLQK	WURELJIQDG	5311505163 Dell Way	\N	FTCIKPB	FL	48760	US	1	WURELJIQDG@dell.com	5311505163	1	5476444622501731	2011/12	user6666	password	27	100000	M
6667	JJIUFC	LJNUSDXZJR	6330230379 Dell Way	\N	BRBRTGC	HI	43847	US	1	LJNUSDXZJR@dell.com	6330230379	5	3679176848847419	2011/10	user6667	password	90	20000	F
6668	HXJKIT	YCLCAKLRMC	7062388171 Dell Way	\N	TEWZGCJ	TX	10994	US	1	YCLCAKLRMC@dell.com	7062388171	3	8554128672461958	2011/09	user6668	password	19	100000	M
6669	KJXDHA	PJAAUSNXMR	7294593259 Dell Way	\N	TMXWWTW	MT	40190	US	1	PJAAUSNXMR@dell.com	7294593259	1	1108014078345149	2011/02	user6669	password	60	20000	M
6670	MGUMWE	NWZFJWSAQE	1574088894 Dell Way	\N	YMASJOB	AR	77101	US	1	NWZFJWSAQE@dell.com	1574088894	4	9033563048113138	2011/11	user6670	password	47	20000	F
6671	FOZJCV	IIFFAGWFFI	4827129906 Dell Way	\N	FXSUZTN	AL	56081	US	1	IIFFAGWFFI@dell.com	4827129906	4	4509091163985431	2012/10	user6671	password	56	20000	F
6672	NKLIST	OYTUUZADEY	5122734683 Dell Way	\N	VZXONYB	WA	64858	US	1	OYTUUZADEY@dell.com	5122734683	4	4513623103965074	2012/10	user6672	password	72	60000	F
6673	EVXYKV	SFPRFSWDNV	9729306743 Dell Way	\N	ABJZDHP	NH	14554	US	1	SFPRFSWDNV@dell.com	9729306743	3	8522916112095118	2011/01	user6673	password	18	100000	M
6674	XVHSOM	HFRZCUMXVO	5033358152 Dell Way	\N	HVSOKHP	LA	87163	US	1	HFRZCUMXVO@dell.com	5033358152	1	9218969434499742	2010/12	user6674	password	76	40000	M
6675	BBJNIP	FIRAVPWJWR	2067982652 Dell Way	\N	BLBJBLF	MS	55580	US	1	FIRAVPWJWR@dell.com	2067982652	5	5433219223283232	2012/04	user6675	password	41	100000	F
6676	SNRITA	ATVPPEMHGY	7971710370 Dell Way	\N	JPZUUMH	WA	51322	US	1	ATVPPEMHGY@dell.com	7971710370	5	7893870954867453	2008/10	user6676	password	26	100000	F
6677	VDCVDV	QTLVFTCECR	8924686937 Dell Way	\N	EWMRDKC	VT	32592	US	1	QTLVFTCECR@dell.com	8924686937	1	1709555491339415	2008/10	user6677	password	49	100000	M
6678	NQBJHU	UCAOEEQWIM	1750219007 Dell Way	\N	IZQTCOA	WY	59883	US	1	UCAOEEQWIM@dell.com	1750219007	5	4388248427771032	2010/10	user6678	password	41	20000	F
6679	JKSEEU	FTZJJVSVES	9375564579 Dell Way	\N	LYVZYUO	AL	80897	US	1	FTZJJVSVES@dell.com	9375564579	3	6319779961369932	2009/07	user6679	password	20	80000	M
6680	TVDOAW	NKGJCBOUNM	8147193358 Dell Way	\N	QNLKCMF	AL	11290	US	1	NKGJCBOUNM@dell.com	8147193358	2	6291873856447638	2012/11	user6680	password	58	60000	M
6681	SCSPQC	VAFXOALBQZ	6205900440 Dell Way	\N	NBBZGBZ	AR	41153	US	1	VAFXOALBQZ@dell.com	6205900440	5	3242115076631307	2008/06	user6681	password	88	100000	M
6682	RKEUGE	ADSAOUQNHR	3278960858 Dell Way	\N	PGYRGZA	TN	85675	US	1	ADSAOUQNHR@dell.com	3278960858	5	3365974019747227	2009/10	user6682	password	75	100000	F
6683	YSKCSO	VSCPJQWBFD	1521920671 Dell Way	\N	ZWJYWFU	CT	24582	US	1	VSCPJQWBFD@dell.com	1521920671	2	9479850932024420	2012/03	user6683	password	27	80000	M
6684	OWQCSJ	FHSVETBHSY	9927239338 Dell Way	\N	RRUXMYB	NC	35336	US	1	FHSVETBHSY@dell.com	9927239338	2	5769451578613371	2008/02	user6684	password	52	80000	F
6685	DUTMZA	EVFYXMQVEI	4320735910 Dell Way	\N	QBUOCIV	CO	74483	US	1	EVFYXMQVEI@dell.com	4320735910	2	8916583904065193	2012/11	user6685	password	85	100000	M
6686	RLRSPN	XNKKEFONVQ	3224303456 Dell Way	\N	IKTQFWJ	NH	16918	US	1	XNKKEFONVQ@dell.com	3224303456	3	9847157936077566	2008/05	user6686	password	66	100000	M
6687	IOLWLY	GVDLKQHAYR	7207585018 Dell Way	\N	UPXQZNS	HI	95269	US	1	GVDLKQHAYR@dell.com	7207585018	2	4133755327668041	2009/03	user6687	password	30	80000	M
6688	POFOUB	SGLIOMHFHX	9335389354 Dell Way	\N	DXWQPCP	IN	54145	US	1	SGLIOMHFHX@dell.com	9335389354	4	7514001418370754	2008/05	user6688	password	54	80000	M
6689	SHSTZZ	FINSQSZNVX	7425325124 Dell Way	\N	KMNMBUZ	WV	51751	US	1	FINSQSZNVX@dell.com	7425325124	1	8433263556566090	2009/10	user6689	password	72	100000	F
6690	LSBKXJ	XQZQQNMNXY	1978137497 Dell Way	\N	AKAVKZH	CT	16752	US	1	XQZQQNMNXY@dell.com	1978137497	2	8811549780890346	2012/04	user6690	password	86	40000	M
6691	ZSWJQM	JHCWTQUSQF	7028106711 Dell Way	\N	TLPSTSU	TX	14964	US	1	JHCWTQUSQF@dell.com	7028106711	4	3839261199813336	2011/12	user6691	password	37	60000	M
6692	DYJQHQ	TEKJYCADWL	8407211440 Dell Way	\N	SOFLJBN	AR	76864	US	1	TEKJYCADWL@dell.com	8407211440	4	7679199237376452	2008/03	user6692	password	51	40000	F
6693	VWMLPQ	VZPYZSULLJ	2423721800 Dell Way	\N	QXTRKUK	HI	50910	US	1	VZPYZSULLJ@dell.com	2423721800	2	7316604396793992	2011/07	user6693	password	83	60000	F
6694	KWZASZ	QRYIMJUWZR	6073794220 Dell Way	\N	PRBKCHW	IA	65107	US	1	QRYIMJUWZR@dell.com	6073794220	5	2397512691561132	2010/04	user6694	password	58	100000	F
6695	OXXNNO	LVAVPXVHMM	4758905435 Dell Way	\N	JXOQTUG	KS	68942	US	1	LVAVPXVHMM@dell.com	4758905435	4	9502019314095380	2012/08	user6695	password	26	60000	M
6696	ABBONW	PIMMDUZQDX	6175267526 Dell Way	\N	EURZBZQ	MN	81090	US	1	PIMMDUZQDX@dell.com	6175267526	3	4909692893736065	2011/12	user6696	password	88	80000	F
6697	AGNXWW	KJZEJPIGUC	2209208090 Dell Way	\N	XTDXKQS	WV	14995	US	1	KJZEJPIGUC@dell.com	2209208090	4	1209585293661803	2008/05	user6697	password	20	20000	M
6698	OAMKKV	KPEAXKUZIO	8508532535 Dell Way	\N	DGZTYYV	AZ	63076	US	1	KPEAXKUZIO@dell.com	8508532535	1	9456208810210228	2012/04	user6698	password	57	60000	F
6699	AWSVGH	AHELCETQHA	1688815461 Dell Way	\N	QBYOWAD	OH	28865	US	1	AHELCETQHA@dell.com	1688815461	3	5527018054854125	2011/01	user6699	password	76	80000	M
6700	NMDUMK	ZXMDRDLSTM	4490605811 Dell Way	\N	QHJRLBX	MT	67315	US	1	ZXMDRDLSTM@dell.com	4490605811	1	6883889513090254	2008/10	user6700	password	56	80000	F
6701	RMTBLR	OOJSABMMSU	2735400715 Dell Way	\N	VJFXGTO	NM	89243	US	1	OOJSABMMSU@dell.com	2735400715	5	6966106008738280	2011/07	user6701	password	85	40000	F
6702	RLMIZB	RSBTEOLYJU	4813709784 Dell Way	\N	DHBWVRT	AK	57193	US	1	RSBTEOLYJU@dell.com	4813709784	4	1517268429975956	2009/02	user6702	password	23	20000	M
6703	OJOPBG	RUKFFIPAMW	4002465052 Dell Way	\N	BJRTCSH	NC	50056	US	1	RUKFFIPAMW@dell.com	4002465052	5	5979484675452114	2010/11	user6703	password	25	100000	F
6704	QOHWFB	HKHPZHBWJK	3354683156 Dell Way	\N	OCNGJBS	OK	94241	US	1	HKHPZHBWJK@dell.com	3354683156	1	8481035748496652	2009/02	user6704	password	23	100000	M
6705	JWXLDH	STHAUEJFSM	6030796607 Dell Way	\N	TZWURPS	WI	73779	US	1	STHAUEJFSM@dell.com	6030796607	2	8241798466537149	2011/04	user6705	password	52	20000	F
6706	JLIREB	ZFWDPCWBVV	1174539089 Dell Way	\N	YPNNIMF	VA	81605	US	1	ZFWDPCWBVV@dell.com	1174539089	3	1970006603281945	2010/07	user6706	password	39	100000	M
6707	QNERMJ	OPYQMALHYB	2980332989 Dell Way	\N	VLKIRHC	OH	82787	US	1	OPYQMALHYB@dell.com	2980332989	1	4144419296178967	2010/01	user6707	password	43	20000	M
6708	NVAXJQ	WACXLKVNGH	3913120648 Dell Way	\N	XOZERRZ	VA	85211	US	1	WACXLKVNGH@dell.com	3913120648	3	8765556199476124	2011/07	user6708	password	47	20000	F
6709	KCTBYT	EVEORSUZPJ	3596803682 Dell Way	\N	YTAPSXL	AR	39231	US	1	EVEORSUZPJ@dell.com	3596803682	4	8764445329084993	2011/11	user6709	password	34	20000	M
6710	YEYSIU	WWLORKEBJX	2664316510 Dell Way	\N	BYQZJRI	NV	44160	US	1	WWLORKEBJX@dell.com	2664316510	2	3510129326488823	2010/06	user6710	password	37	40000	M
6711	FBYZYV	LNNWROFPQE	5758877883 Dell Way	\N	FQOWYFG	CT	59700	US	1	LNNWROFPQE@dell.com	5758877883	3	1134088720660656	2011/11	user6711	password	64	20000	M
6712	PZXKLK	YHCMNRDRWT	9852221393 Dell Way	\N	FTSKZVZ	MT	44338	US	1	YHCMNRDRWT@dell.com	9852221393	2	3590379494708031	2011/04	user6712	password	36	40000	F
6713	DQTOOA	RBOIEFFXLZ	2059519059 Dell Way	\N	PWYLVMV	SC	82513	US	1	RBOIEFFXLZ@dell.com	2059519059	3	2168313543312251	2009/08	user6713	password	50	60000	F
6714	ECVFTW	TCBZIYKHOG	7030477487 Dell Way	\N	GACTVXO	WV	38668	US	1	TCBZIYKHOG@dell.com	7030477487	2	9664711593650282	2008/11	user6714	password	35	40000	M
6715	BNSYHV	ZGDYRLNYRN	2683201768 Dell Way	\N	AKJXYIF	NJ	69646	US	1	ZGDYRLNYRN@dell.com	2683201768	4	5619476703926921	2010/01	user6715	password	51	60000	M
6716	ELVZLC	DKTOXRGLRR	3978931853 Dell Way	\N	VPPEVGV	AK	97781	US	1	DKTOXRGLRR@dell.com	3978931853	3	1104303761851042	2011/12	user6716	password	59	100000	F
6717	KYVMBG	FQEWWPONLE	4269064101 Dell Way	\N	DPZJKAJ	OR	49383	US	1	FQEWWPONLE@dell.com	4269064101	3	4338582885451615	2012/06	user6717	password	73	40000	F
6718	PUNVZD	ZWAPLNAQRP	4811015924 Dell Way	\N	PBAPKTB	RI	34180	US	1	ZWAPLNAQRP@dell.com	4811015924	4	7753023733850569	2008/01	user6718	password	30	80000	M
6719	RPTVPQ	VFCJGSAWIC	6668911294 Dell Way	\N	WYMPZGW	MD	94857	US	1	VFCJGSAWIC@dell.com	6668911294	3	9527906537055970	2012/05	user6719	password	71	60000	M
6720	MHODDU	FMAXNWFPTD	2892391008 Dell Way	\N	BIDIFNG	TX	19348	US	1	FMAXNWFPTD@dell.com	2892391008	4	5154440007172525	2012/02	user6720	password	49	60000	F
6721	AOOUUA	VSORXDKBFT	3486012231 Dell Way	\N	ENZSUVV	WY	54989	US	1	VSORXDKBFT@dell.com	3486012231	5	6831128039397300	2011/05	user6721	password	24	80000	M
6722	RNSSIK	GZIJKKOEPB	2189126999 Dell Way	\N	DHVZDVM	MA	77490	US	1	GZIJKKOEPB@dell.com	2189126999	1	2010607448406517	2009/10	user6722	password	21	100000	F
6723	TPQEVQ	NEAXSENUIV	3821883833 Dell Way	\N	QIYLUIF	WA	47542	US	1	NEAXSENUIV@dell.com	3821883833	1	3072713200934231	2009/01	user6723	password	57	20000	M
6724	EHLUVP	VTIAGDJBTR	9586847904 Dell Way	\N	ZFMHKKS	OK	61133	US	1	VTIAGDJBTR@dell.com	9586847904	1	6537935449276120	2010/03	user6724	password	35	80000	M
6725	RMIHHB	QHITQKNIJS	4399650200 Dell Way	\N	URDFKWT	LA	93464	US	1	QHITQKNIJS@dell.com	4399650200	5	2166538436431437	2011/07	user6725	password	64	40000	F
6726	ZPHAGP	JAGTNPDGJU	3519967061 Dell Way	\N	JOFFIOD	OK	47619	US	1	JAGTNPDGJU@dell.com	3519967061	2	9585846497211606	2012/08	user6726	password	88	100000	F
6727	GXMWHM	DAASDGCYQR	1593267280 Dell Way	\N	DVZSZSC	IL	12766	US	1	DAASDGCYQR@dell.com	1593267280	1	6956010915804655	2008/01	user6727	password	83	40000	M
6728	JEGWIH	WBLCEJSVMO	2973752793 Dell Way	\N	VEONHVO	LA	12779	US	1	WBLCEJSVMO@dell.com	2973752793	2	1942033556289971	2008/09	user6728	password	25	60000	M
6729	JIFQEG	CHKLAGYPBD	2045554687 Dell Way	\N	DPKZDUA	LA	26245	US	1	CHKLAGYPBD@dell.com	2045554687	3	8869677856098861	2009/12	user6729	password	72	60000	F
6730	YFMFIU	PTUWRJXUNM	1498179316 Dell Way	\N	FMQAMAE	NJ	53359	US	1	PTUWRJXUNM@dell.com	1498179316	5	5013414951507002	2012/05	user6730	password	72	80000	M
6731	GYYAOR	UKJEIERVJE	4498142286 Dell Way	\N	LJRLOHY	NJ	19051	US	1	UKJEIERVJE@dell.com	4498142286	3	5552934199571610	2008/03	user6731	password	28	40000	F
6732	CJRUEC	DIKHAGRESB	7310775218 Dell Way	\N	VEQCCFF	MO	68250	US	1	DIKHAGRESB@dell.com	7310775218	4	8331212510820479	2012/12	user6732	password	86	100000	F
6733	PSOSVW	DDXJVBBWWF	2695799827 Dell Way	\N	MZHSEUJ	UT	47074	US	1	DDXJVBBWWF@dell.com	2695799827	4	4600389087107033	2008/08	user6733	password	73	80000	F
6734	ILEEOI	BYDDZAAFNZ	2029209867 Dell Way	\N	NGDHQAS	SD	73968	US	1	BYDDZAAFNZ@dell.com	2029209867	5	4121862350031734	2012/09	user6734	password	67	20000	F
6735	WJSELQ	IPQJPVXOID	7732539808 Dell Way	\N	RQTRJPK	MN	56326	US	1	IPQJPVXOID@dell.com	7732539808	2	2680434219073504	2010/07	user6735	password	40	40000	M
6736	ZMJQVY	GENCBCLFTB	3362263024 Dell Way	\N	ZLLOWXB	NH	32077	US	1	GENCBCLFTB@dell.com	3362263024	1	8068579250015319	2010/05	user6736	password	69	60000	M
6737	BFQALV	OOXQZDKACV	4452187450 Dell Way	\N	LRSJTIP	AK	41420	US	1	OOXQZDKACV@dell.com	4452187450	3	7172661965247244	2008/02	user6737	password	55	20000	F
6738	DEUZSI	XIHASIDOUU	6539563386 Dell Way	\N	HDNPTNY	CT	18460	US	1	XIHASIDOUU@dell.com	6539563386	2	3096648932434618	2008/05	user6738	password	59	40000	M
6739	JGGSDP	AEIJHWDBDH	4879699862 Dell Way	\N	PTBCREF	IL	46384	US	1	AEIJHWDBDH@dell.com	4879699862	3	8009290348272771	2008/09	user6739	password	41	40000	M
6740	PBCECG	MLOJPPNWEG	3676446854 Dell Way	\N	YHYCMFN	VT	64854	US	1	MLOJPPNWEG@dell.com	3676446854	5	3613711427431554	2011/04	user6740	password	35	40000	F
6741	IJLPWW	DGLSUIXBGF	1652631962 Dell Way	\N	ZJREXPU	FL	56061	US	1	DGLSUIXBGF@dell.com	1652631962	5	8180577473249287	2009/01	user6741	password	29	80000	F
6742	PFGMJN	XBHGZIMEHW	7890408164 Dell Way	\N	WMTLGYZ	KS	76110	US	1	XBHGZIMEHW@dell.com	7890408164	4	7709704943466932	2012/04	user6742	password	28	60000	F
6743	KZVXXX	FDXOPCVMYH	6573524829 Dell Way	\N	FKODJWW	CT	56199	US	1	FDXOPCVMYH@dell.com	6573524829	1	7994425504002721	2011/07	user6743	password	37	20000	M
6744	CCLAHO	XVEZRQYZVI	7297122192 Dell Way	\N	NZRKWVX	MO	88009	US	1	XVEZRQYZVI@dell.com	7297122192	2	4910617681685835	2012/05	user6744	password	89	20000	F
6745	KBTZZP	DYGUWFQFTP	9959687609 Dell Way	\N	WDLSBYO	RI	25269	US	1	DYGUWFQFTP@dell.com	9959687609	4	6074435461312533	2012/10	user6745	password	20	40000	M
6746	UJVJNU	QHQVXVOMSS	6627475871 Dell Way	\N	YKUXZOB	WV	35264	US	1	QHQVXVOMSS@dell.com	6627475871	5	1618450528010726	2011/05	user6746	password	85	60000	M
6747	TVFNLM	DHJZVWSOVD	3153460608 Dell Way	\N	ISCXUBE	MD	10352	US	1	DHJZVWSOVD@dell.com	3153460608	1	4067906103096902	2008/07	user6747	password	21	100000	F
6748	GKUTOC	COYZGMVJVO	8918121157 Dell Way	\N	MSINWTO	CT	83412	US	1	COYZGMVJVO@dell.com	8918121157	2	4072981052100659	2012/03	user6748	password	68	20000	M
6749	MXEPAS	NAZZVJVJVN	6517728918 Dell Way	\N	SJKLXNH	SC	82482	US	1	NAZZVJVJVN@dell.com	6517728918	4	9884785259142520	2009/11	user6749	password	60	100000	M
6750	TKVLXV	LWQURAQFTZ	9338926325 Dell Way	\N	PFXDMRY	CA	45894	US	1	LWQURAQFTZ@dell.com	9338926325	2	3545352736487985	2010/03	user6750	password	23	40000	M
6751	WRMSCJ	JXBKNGDNWI	7948960942 Dell Way	\N	KAUCYWM	UT	34882	US	1	JXBKNGDNWI@dell.com	7948960942	2	5306412737816572	2012/08	user6751	password	23	80000	F
6752	OLKXUI	ZEVFHICQTC	1565586187 Dell Way	\N	LVAIIXP	CA	34082	US	1	ZEVFHICQTC@dell.com	1565586187	5	8941929773427547	2008/08	user6752	password	31	80000	F
6753	PPWXOB	TUICWZVYKR	1189621012 Dell Way	\N	ZSZWHBD	KY	10475	US	1	TUICWZVYKR@dell.com	1189621012	3	7026225171517581	2009/02	user6753	password	73	100000	M
6754	QTIRMC	AOYAKXKBWC	8009721391 Dell Way	\N	ATKCXTC	VT	30511	US	1	AOYAKXKBWC@dell.com	8009721391	1	4536791803315282	2010/12	user6754	password	29	20000	M
6755	MWDOXS	NXDKIEHKFB	2640465696 Dell Way	\N	VIYOLWU	GA	97685	US	1	NXDKIEHKFB@dell.com	2640465696	4	9158162469509990	2009/12	user6755	password	59	100000	M
6756	SJSLXQ	OIYTPJZREH	4120363653 Dell Way	\N	PTSMNYL	OK	71211	US	1	OIYTPJZREH@dell.com	4120363653	1	6547994680237026	2012/11	user6756	password	49	80000	F
6757	DCDURL	SKBCJSHRIA	6469555468 Dell Way	\N	JUOIFHZ	NE	40993	US	1	SKBCJSHRIA@dell.com	6469555468	3	2848545964807272	2008/02	user6757	password	49	20000	F
6758	OYWZRH	AURTBIBCSV	5552108909 Dell Way	\N	RABYAQH	NJ	20859	US	1	AURTBIBCSV@dell.com	5552108909	4	3267352710478008	2012/10	user6758	password	52	60000	M
6759	IMMQNG	HGIPHKHDCI	2602653217 Dell Way	\N	EAIUIYY	TN	61695	US	1	HGIPHKHDCI@dell.com	2602653217	4	4599067202303559	2011/04	user6759	password	31	100000	M
6760	QQGXXM	FMUQUXSCBS	3923190939 Dell Way	\N	KWBJUXY	WV	71509	US	1	FMUQUXSCBS@dell.com	3923190939	4	9637906761839988	2010/08	user6760	password	70	20000	F
6761	ZBDLGP	FWKCPNEIYA	9283057290 Dell Way	\N	JHVHFUY	NC	47619	US	1	FWKCPNEIYA@dell.com	9283057290	1	1248418998904526	2011/03	user6761	password	36	80000	F
6762	JBNZHK	KKZXOHVPRD	7149074313 Dell Way	\N	LYIGXWR	TN	92274	US	1	KKZXOHVPRD@dell.com	7149074313	3	2019394117873162	2012/01	user6762	password	44	40000	F
6763	WHKHRU	GPJOLZFOKE	8220736675 Dell Way	\N	XRBUIXR	WY	41992	US	1	GPJOLZFOKE@dell.com	8220736675	5	4762819339986891	2008/03	user6763	password	57	20000	M
6764	YIGTPV	DEHDJVOOTF	3584704623 Dell Way	\N	QNNNFNW	AK	51040	US	1	DEHDJVOOTF@dell.com	3584704623	1	7312590144108982	2012/03	user6764	password	35	80000	M
6765	MNEIRI	PUSKIGEOWR	7661113609 Dell Way	\N	BJWPGWB	MT	15364	US	1	PUSKIGEOWR@dell.com	7661113609	2	3572650834918022	2012/02	user6765	password	79	60000	M
6766	AUIIJD	ATMGYACPBM	7365339095 Dell Way	\N	MRSJSGK	MI	63163	US	1	ATMGYACPBM@dell.com	7365339095	3	7506426675710828	2010/11	user6766	password	46	60000	M
6767	TWAWXU	IDSJGHLSUC	9833959858 Dell Way	\N	LDUROFG	ID	67864	US	1	IDSJGHLSUC@dell.com	9833959858	5	5729267775081099	2009/05	user6767	password	31	20000	F
6768	EZDYIH	QRNYCGSERW	4223133417 Dell Way	\N	ZJKEPRV	NE	55062	US	1	QRNYCGSERW@dell.com	4223133417	5	8902430876158179	2010/01	user6768	password	27	80000	F
6769	HRJOIA	CHDIZHAWHJ	3979666543 Dell Way	\N	HMZYHOL	NV	56566	US	1	CHDIZHAWHJ@dell.com	3979666543	1	6260474383831025	2010/11	user6769	password	63	80000	M
6770	ZHXAKE	DTELTASDHE	7778443481 Dell Way	\N	CGLQSCE	AL	37169	US	1	DTELTASDHE@dell.com	7778443481	3	2883490710053593	2009/03	user6770	password	75	40000	M
6771	RJYWMR	AYLBQOIUQP	8948074617 Dell Way	\N	GHHJMHR	HI	81539	US	1	AYLBQOIUQP@dell.com	8948074617	4	1260177568532526	2011/12	user6771	password	59	40000	F
6772	NFVEGT	QHKEQFVFLD	6670560597 Dell Way	\N	NVPUNVP	MA	50139	US	1	QHKEQFVFLD@dell.com	6670560597	1	4733823181129992	2008/06	user6772	password	73	80000	M
6773	PXXJNF	TSVYNBKROG	9868761541 Dell Way	\N	HJTDZDO	NJ	26576	US	1	TSVYNBKROG@dell.com	9868761541	5	6428066434804351	2011/07	user6773	password	35	40000	F
6774	DRYILQ	EKDGUVVACF	7236311258 Dell Way	\N	UGEXUUC	SC	64266	US	1	EKDGUVVACF@dell.com	7236311258	3	2065009880810976	2012/11	user6774	password	56	20000	M
6775	LLZBQJ	FWEBSFEXZK	6525585251 Dell Way	\N	CXFXZZM	NY	56226	US	1	FWEBSFEXZK@dell.com	6525585251	4	4339335999451578	2008/09	user6775	password	84	60000	F
6776	XRTGXQ	LYIQCGQMIN	5962963449 Dell Way	\N	RFNRSEE	KY	81887	US	1	LYIQCGQMIN@dell.com	5962963449	3	5477740074973554	2010/01	user6776	password	63	40000	M
6777	JQQZBO	ISQOIDWWVC	8583863649 Dell Way	\N	JMVOREI	HI	68230	US	1	ISQOIDWWVC@dell.com	8583863649	4	7447164709214122	2010/01	user6777	password	50	100000	M
6778	BVSQDK	HRTKOPGRZT	1442350815 Dell Way	\N	NNKRWQI	OH	37379	US	1	HRTKOPGRZT@dell.com	1442350815	1	4109602538403124	2010/01	user6778	password	18	60000	M
6779	SFZDMR	XXFNDXMWLZ	5950753233 Dell Way	\N	HCVXLOF	MS	74285	US	1	XXFNDXMWLZ@dell.com	5950753233	5	7482189732138068	2010/07	user6779	password	58	40000	M
6780	NLGEID	KVHIHETHLW	1883481386 Dell Way	\N	DJIROVJ	CO	82757	US	1	KVHIHETHLW@dell.com	1883481386	4	4365090746432543	2011/12	user6780	password	28	20000	F
6781	KJSNTO	VCVAVCMSFV	1110039049 Dell Way	\N	AXKVHNQ	LA	26827	US	1	VCVAVCMSFV@dell.com	1110039049	1	2302769697271287	2008/03	user6781	password	56	60000	M
6782	GBHUXJ	QYFSKXYGYW	5310157638 Dell Way	\N	QTDDKMI	ME	55101	US	1	QYFSKXYGYW@dell.com	5310157638	3	7203088550362737	2008/02	user6782	password	34	40000	F
6783	NBCXRA	DKKAIQZEHT	9811492171 Dell Way	\N	HKDUTOH	HI	20296	US	1	DKKAIQZEHT@dell.com	9811492171	2	2938814539927989	2009/07	user6783	password	46	80000	M
6784	MQFMTP	WUYNTDUMLF	5582938910 Dell Way	\N	QFYENEH	MO	48931	US	1	WUYNTDUMLF@dell.com	5582938910	4	9399721488356592	2012/06	user6784	password	52	40000	F
6785	RVVHSP	FGJIAWTGMZ	7792425199 Dell Way	\N	FRMKZZV	MO	69677	US	1	FGJIAWTGMZ@dell.com	7792425199	2	1782278329133987	2009/09	user6785	password	28	100000	M
6786	ZEIOKO	YSPUMVHMAZ	7052855202 Dell Way	\N	YKYXGKP	WY	81246	US	1	YSPUMVHMAZ@dell.com	7052855202	2	5818300308659673	2012/02	user6786	password	27	80000	F
6787	LJSZHL	PCYLKKLJJW	1515633883 Dell Way	\N	IHDSWCN	NC	40872	US	1	PCYLKKLJJW@dell.com	1515633883	2	5366231338120997	2008/02	user6787	password	77	80000	M
6788	OQUZFX	YQHJCRSZZA	1260261802 Dell Way	\N	CSWFGKO	IL	80352	US	1	YQHJCRSZZA@dell.com	1260261802	3	9358567311894150	2012/02	user6788	password	49	40000	M
6789	FJYDIO	LRRCKQCKSU	4556780538 Dell Way	\N	GXARLIM	MO	82106	US	1	LRRCKQCKSU@dell.com	4556780538	2	9086844669189304	2012/09	user6789	password	62	20000	F
6790	OEKCPC	USMKUWCODA	6643405766 Dell Way	\N	PVMYHZS	OH	36318	US	1	USMKUWCODA@dell.com	6643405766	3	1064969916827976	2009/07	user6790	password	25	80000	M
6791	NXJQRB	CBVZEKDFZY	9420822598 Dell Way	\N	RYGQRYY	IL	52115	US	1	CBVZEKDFZY@dell.com	9420822598	3	1353334262501448	2008/04	user6791	password	75	60000	F
6792	DEXEHY	AGDKKIKJZI	1621556161 Dell Way	\N	PQZOOHA	MS	82111	US	1	AGDKKIKJZI@dell.com	1621556161	3	2043496867176145	2012/02	user6792	password	42	100000	F
6793	FEOEFV	HQFQAPQJEG	6051669286 Dell Way	\N	JTVQUIL	TX	87380	US	1	HQFQAPQJEG@dell.com	6051669286	4	9639989073853940	2012/09	user6793	password	35	20000	M
6794	UHCQPT	WFTLWDQCNK	1656137320 Dell Way	\N	YDEGPAC	DE	76123	US	1	WFTLWDQCNK@dell.com	1656137320	1	5012648841366172	2009/02	user6794	password	43	20000	F
6795	LTBEPG	YBCCRFPBDT	5005888111 Dell Way	\N	GKJGNNZ	NE	60977	US	1	YBCCRFPBDT@dell.com	5005888111	5	7587777702137829	2011/01	user6795	password	31	40000	M
6796	FLJMKL	PMDVCEZWLJ	1168081977 Dell Way	\N	FSWSSLH	DC	42416	US	1	PMDVCEZWLJ@dell.com	1168081977	5	4392187674995512	2009/03	user6796	password	28	60000	M
6797	NXAYNN	BIPGHLRRRK	7586595619 Dell Way	\N	NJCZRFJ	NY	23059	US	1	BIPGHLRRRK@dell.com	7586595619	5	3934197702910751	2012/04	user6797	password	87	60000	F
6798	ZJTMLC	BSKNKBEUPO	5865558325 Dell Way	\N	WPGBYXF	NY	82526	US	1	BSKNKBEUPO@dell.com	5865558325	3	2131791261024773	2010/12	user6798	password	44	60000	F
6799	DXTFZL	QNVRSQGGMV	4073592520 Dell Way	\N	MOUKTLF	IN	98252	US	1	QNVRSQGGMV@dell.com	4073592520	4	9358707842882724	2011/03	user6799	password	35	100000	F
6800	ZBDLRR	HJJXPQJLCX	5948038788 Dell Way	\N	FNRQTZQ	AZ	79019	US	1	HJJXPQJLCX@dell.com	5948038788	4	1030744560994207	2011/08	user6800	password	29	80000	M
6801	HFJYMS	IKHYUTBSYO	2129396739 Dell Way	\N	JPHJFJD	PA	23762	US	1	IKHYUTBSYO@dell.com	2129396739	3	7965341138187797	2009/04	user6801	password	51	60000	M
6802	VOANWL	VUFOVXNKHC	9763383135 Dell Way	\N	RQIBTBF	UT	65453	US	1	VUFOVXNKHC@dell.com	9763383135	1	9464642861392350	2010/10	user6802	password	53	40000	F
6803	NTEYPY	EEUBREIUVZ	7521482941 Dell Way	\N	CXTECQU	AZ	80664	US	1	EEUBREIUVZ@dell.com	7521482941	3	5838289655745030	2009/09	user6803	password	79	80000	M
6804	ZRCYVG	SXYWGTSFVP	9143051142 Dell Way	\N	ZZSPUTJ	MS	32082	US	1	SXYWGTSFVP@dell.com	9143051142	4	9823837599717082	2011/06	user6804	password	53	80000	F
6805	PRYVKW	UHCNZIJPHJ	3457619414 Dell Way	\N	HWDBGQH	DC	41864	US	1	UHCNZIJPHJ@dell.com	3457619414	5	8108274388592691	2011/08	user6805	password	83	40000	F
6806	WERSZY	UMYCVOKEVG	1895259598 Dell Way	\N	IWMYEQI	MI	56125	US	1	UMYCVOKEVG@dell.com	1895259598	2	2130171847995370	2012/07	user6806	password	48	100000	M
6807	CORBID	ZLZNVEJCMG	8810891617 Dell Way	\N	PLKFTWT	TX	15949	US	1	ZLZNVEJCMG@dell.com	8810891617	5	6409441158641130	2009/09	user6807	password	40	40000	F
6808	ZLODKA	DYWHIYTOOF	5536012365 Dell Way	\N	ZUYVNUX	MA	67356	US	1	DYWHIYTOOF@dell.com	5536012365	4	3963766190689057	2012/01	user6808	password	59	80000	F
6809	DYWDBV	ZIDYCRMHRG	1065883841 Dell Way	\N	GMUBKER	VT	84700	US	1	ZIDYCRMHRG@dell.com	1065883841	4	8865704352036119	2010/07	user6809	password	42	80000	F
6810	FVMBVV	ETYWGGNNMA	2373686431 Dell Way	\N	HNKLFIH	GA	13653	US	1	ETYWGGNNMA@dell.com	2373686431	4	5996904558502138	2010/06	user6810	password	18	80000	F
6811	MTDIYX	GUEMIRZJYN	7232257036 Dell Way	\N	UKSCRXD	TN	72061	US	1	GUEMIRZJYN@dell.com	7232257036	2	2523934066295624	2011/01	user6811	password	53	20000	M
6812	QNTOUO	SHXKGGJTAT	3080052366 Dell Way	\N	MDLJGHB	WI	66515	US	1	SHXKGGJTAT@dell.com	3080052366	4	7101893569342793	2011/10	user6812	password	53	40000	F
6813	GXDUQK	SARYJLYDXB	2751747011 Dell Way	\N	PHIXIHN	ND	91986	US	1	SARYJLYDXB@dell.com	2751747011	2	7681607077363879	2011/08	user6813	password	25	100000	M
6814	GSEQKF	IJPTITRKIY	6757310474 Dell Way	\N	SFGZTVX	WA	19927	US	1	IJPTITRKIY@dell.com	6757310474	4	7770453997887672	2011/07	user6814	password	40	100000	F
6815	MQRSYB	HSJAJTIILO	3351277991 Dell Way	\N	OLHKIFN	WY	84643	US	1	HSJAJTIILO@dell.com	3351277991	4	4293152572121471	2010/09	user6815	password	63	20000	F
6816	ITGJBZ	SBJLKRXZFJ	7089341275 Dell Way	\N	GQSMDSI	MD	47328	US	1	SBJLKRXZFJ@dell.com	7089341275	5	1935032923705876	2009/01	user6816	password	48	80000	M
6817	RZVQRX	ZDHQBHWLNN	4191104887 Dell Way	\N	DAQVIBG	AK	10579	US	1	ZDHQBHWLNN@dell.com	4191104887	2	1264635140076279	2011/12	user6817	password	77	60000	M
6818	QCPNCT	VTUCQFQDJQ	8634425955 Dell Way	\N	UFZVLZV	SD	35713	US	1	VTUCQFQDJQ@dell.com	8634425955	3	2920023784041405	2011/01	user6818	password	26	40000	F
6819	SVFLQY	GTOLKRVALA	5389199060 Dell Way	\N	AGMZCHH	WA	88345	US	1	GTOLKRVALA@dell.com	5389199060	3	9013313639909030	2011/11	user6819	password	90	40000	M
6820	FTJDZC	RLMJGNUHOB	8446851086 Dell Way	\N	UNDBVBY	IN	68484	US	1	RLMJGNUHOB@dell.com	8446851086	5	5778104313649238	2012/03	user6820	password	35	20000	M
6821	PDXSVJ	FEPTZXHARV	4720354422 Dell Way	\N	ETQGRYW	MS	84122	US	1	FEPTZXHARV@dell.com	4720354422	2	1259688601829111	2011/05	user6821	password	89	40000	F
6822	XYIGDM	WXMTEMLZRE	4531057441 Dell Way	\N	QXWOUJJ	FL	72865	US	1	WXMTEMLZRE@dell.com	4531057441	5	1469899101648479	2009/02	user6822	password	58	40000	F
6823	WNEJJB	VDGIPFZTVX	7595248911 Dell Way	\N	QJRZTWR	DC	73337	US	1	VDGIPFZTVX@dell.com	7595248911	3	8095674451906235	2009/10	user6823	password	77	20000	F
6824	ANRBJU	HRJNRDJOTT	6256440865 Dell Way	\N	FTNCKQU	DC	23558	US	1	HRJNRDJOTT@dell.com	6256440865	3	9290562886279076	2010/08	user6824	password	32	60000	F
6825	WMMRUD	AIVESJXLPQ	7074710055 Dell Way	\N	YSBPMFT	CA	67431	US	1	AIVESJXLPQ@dell.com	7074710055	3	3019985233899206	2012/11	user6825	password	42	80000	F
6826	UKDYLL	TPEDNPTEOL	3887293364 Dell Way	\N	GEYLYAC	NH	54786	US	1	TPEDNPTEOL@dell.com	3887293364	3	4475751096382737	2011/03	user6826	password	72	60000	M
6827	XKBJDR	NHFDAKRLRW	3588306930 Dell Way	\N	KDUKFJX	NC	86724	US	1	NHFDAKRLRW@dell.com	3588306930	1	1679476650431752	2008/08	user6827	password	69	100000	F
6828	UHEMUL	SXLCPXTLHW	5722509220 Dell Way	\N	FSCPPQL	VA	83571	US	1	SXLCPXTLHW@dell.com	5722509220	5	5103773921262473	2009/11	user6828	password	53	20000	F
6829	QMYCEW	OHLMAXUXDM	9207867100 Dell Way	\N	ASCQEZL	OH	93400	US	1	OHLMAXUXDM@dell.com	9207867100	5	8119994845706970	2009/12	user6829	password	86	20000	F
6830	XDPTSW	EEXCYVFLVY	3221809987 Dell Way	\N	NLCNXUL	TN	72949	US	1	EEXCYVFLVY@dell.com	3221809987	2	6667787231039256	2008/04	user6830	password	20	20000	F
6831	QVDMAH	JCGEHRZFFL	4792298401 Dell Way	\N	ITJCFEU	MN	46920	US	1	JCGEHRZFFL@dell.com	4792298401	4	7100788197480143	2010/09	user6831	password	24	20000	M
6832	FOONYQ	TCYLCEROML	2740414736 Dell Way	\N	XOQCJCN	RI	76780	US	1	TCYLCEROML@dell.com	2740414736	2	5152479098644108	2009/04	user6832	password	90	60000	M
6833	NZUETX	CFZGWOSHMH	3028920560 Dell Way	\N	YOQACKT	IL	68550	US	1	CFZGWOSHMH@dell.com	3028920560	3	9700772800017148	2009/01	user6833	password	79	80000	F
6834	QXUOAZ	NHWCZDOHBC	9627928349 Dell Way	\N	YCFIWMZ	CA	13087	US	1	NHWCZDOHBC@dell.com	9627928349	2	1799284992739558	2011/01	user6834	password	28	60000	M
6835	YZZYNH	UPHYDOAGMC	1430194667 Dell Way	\N	LVZYVBY	RI	41583	US	1	UPHYDOAGMC@dell.com	1430194667	3	4685211005154997	2008/01	user6835	password	46	20000	M
6836	KBMRWC	YUGMUMZXYU	7112320908 Dell Way	\N	WWPXVJH	UT	95988	US	1	YUGMUMZXYU@dell.com	7112320908	1	9687449031509460	2008/03	user6836	password	87	60000	F
6837	LCCOBX	UNSGMQFHMB	2752138408 Dell Way	\N	XKXHRTF	LA	83616	US	1	UNSGMQFHMB@dell.com	2752138408	3	1052287531550973	2008/11	user6837	password	36	60000	M
6838	JDAGXO	ZEBPJIBLFM	9101094466 Dell Way	\N	IMEBSNX	VT	94248	US	1	ZEBPJIBLFM@dell.com	9101094466	1	8307801381684841	2008/08	user6838	password	76	60000	M
6839	VURJTW	KJFTLQZXZL	3993926805 Dell Way	\N	BBEPYCN	TN	24512	US	1	KJFTLQZXZL@dell.com	3993926805	5	8341568540781737	2008/07	user6839	password	61	100000	F
6840	HIBDTL	JNWAMTZYVA	2667809098 Dell Way	\N	CKYFYUJ	IL	81305	US	1	JNWAMTZYVA@dell.com	2667809098	3	3791045416612178	2011/05	user6840	password	63	20000	M
6841	RFLDPY	ZPKTPJOPLZ	5228286661 Dell Way	\N	ORYJAFE	HI	66376	US	1	ZPKTPJOPLZ@dell.com	5228286661	1	9922560614999384	2008/02	user6841	password	68	80000	F
6842	DXXCWN	NPCWESIEHZ	9614973665 Dell Way	\N	DQAIUGZ	ID	33614	US	1	NPCWESIEHZ@dell.com	9614973665	2	4150040426757187	2011/02	user6842	password	66	80000	F
6843	OXXBKM	EHRWPWDPZU	5463013716 Dell Way	\N	QIPWHWD	IA	29287	US	1	EHRWPWDPZU@dell.com	5463013716	5	4162075364496559	2008/09	user6843	password	45	80000	M
6844	HUZUZG	LVWIZLHTCP	7952661066 Dell Way	\N	JZXFCDK	NJ	12106	US	1	LVWIZLHTCP@dell.com	7952661066	4	7319047461729497	2008/06	user6844	password	37	60000	F
6845	GFGMRC	JZBUHVWXEW	6833784163 Dell Way	\N	UKZXVOY	NE	40384	US	1	JZBUHVWXEW@dell.com	6833784163	4	8453293773811311	2012/03	user6845	password	26	20000	F
6846	JQBLAB	NUIJRFONAY	3100804281 Dell Way	\N	MYTBWIK	MT	16907	US	1	NUIJRFONAY@dell.com	3100804281	3	3272033261600882	2009/08	user6846	password	64	80000	F
6847	SEGTSB	CBTHPHIOUG	9629917584 Dell Way	\N	HVDQGRS	MO	19352	US	1	CBTHPHIOUG@dell.com	9629917584	5	7376214949879796	2011/07	user6847	password	88	40000	M
6848	FBLHDM	ALCHTQBAYX	6597423936 Dell Way	\N	DOEVGQX	HI	52671	US	1	ALCHTQBAYX@dell.com	6597423936	5	1196952135302126	2010/02	user6848	password	72	100000	F
6849	ECIRDU	TKOJMOIKSW	7476879218 Dell Way	\N	PNDFLJS	AZ	27267	US	1	TKOJMOIKSW@dell.com	7476879218	4	3903466179966927	2010/06	user6849	password	55	80000	M
6850	VHRQAC	EKPTTALPPZ	6687481950 Dell Way	\N	TVKDNMI	HI	21217	US	1	EKPTTALPPZ@dell.com	6687481950	4	6267993114423007	2008/04	user6850	password	28	100000	M
6851	VPRXUB	NNVNYLCYEX	5779857070 Dell Way	\N	IHKVPQY	HI	40019	US	1	NNVNYLCYEX@dell.com	5779857070	2	6940168314147741	2011/05	user6851	password	38	60000	M
6852	YKTAXG	VKFGNDKKMS	5092493786 Dell Way	\N	VHILGOU	RI	93322	US	1	VKFGNDKKMS@dell.com	5092493786	3	3590450535528362	2011/12	user6852	password	36	80000	F
6853	ZRFGMQ	LSDPDNBWJJ	9420282657 Dell Way	\N	EVPSPJQ	AZ	84598	US	1	LSDPDNBWJJ@dell.com	9420282657	4	7859222011175007	2008/06	user6853	password	24	20000	F
6854	ILPYWI	BLMPNJYWNU	4981811802 Dell Way	\N	MGKWXLR	TN	32188	US	1	BLMPNJYWNU@dell.com	4981811802	1	7333305913023651	2010/03	user6854	password	78	100000	M
6855	LUNUWY	GLMQKIDFUJ	9813878423 Dell Way	\N	PRHAICH	RI	20424	US	1	GLMQKIDFUJ@dell.com	9813878423	2	3879204287659377	2012/02	user6855	password	87	40000	M
6856	LAUKHG	XXRFBWALLR	3088648112 Dell Way	\N	SMAUTUX	OR	20316	US	1	XXRFBWALLR@dell.com	3088648112	3	3444319153204560	2008/10	user6856	password	33	80000	M
6857	ABCHYA	YEBVFMGWET	1836598786 Dell Way	\N	XZMSXFV	CT	79355	US	1	YEBVFMGWET@dell.com	1836598786	2	6017897613346577	2009/12	user6857	password	45	40000	F
6858	MPZMND	OJIBQFFJDF	4792011459 Dell Way	\N	WVCCQGW	OR	59388	US	1	OJIBQFFJDF@dell.com	4792011459	1	5547805095091463	2011/05	user6858	password	56	40000	M
6859	MTMQIW	ZJMEPVHUSD	2851933079 Dell Way	\N	XUUDRNS	CA	60730	US	1	ZJMEPVHUSD@dell.com	2851933079	5	9390025910455734	2011/02	user6859	password	83	40000	M
6860	KWFGVP	SZEOHZGKXB	2802655455 Dell Way	\N	EBSSTUG	WI	69432	US	1	SZEOHZGKXB@dell.com	2802655455	4	8211915552616120	2008/11	user6860	password	69	60000	M
6861	YSONLO	RZWRGGOHLP	3248752559 Dell Way	\N	ZEJULHL	NJ	98837	US	1	RZWRGGOHLP@dell.com	3248752559	4	9024429669603706	2012/03	user6861	password	65	100000	M
6862	FKJUBI	QSPWHWIXWM	4791662369 Dell Way	\N	GRXOCON	LA	33212	US	1	QSPWHWIXWM@dell.com	4791662369	2	5091920464299619	2008/03	user6862	password	45	40000	M
6863	SBQBRJ	QORNXOKJUB	5915192791 Dell Way	\N	HIDVWNC	IL	84174	US	1	QORNXOKJUB@dell.com	5915192791	2	1143188973888754	2012/08	user6863	password	61	80000	M
6864	GSJPIX	HWUVGEPHLY	8156882231 Dell Way	\N	LHUYJBU	WA	46825	US	1	HWUVGEPHLY@dell.com	8156882231	5	1314443484880030	2009/06	user6864	password	69	80000	F
6865	BGNYNK	TIQXYYJWJQ	2351961544 Dell Way	\N	QIASCYC	VA	80309	US	1	TIQXYYJWJQ@dell.com	2351961544	2	3375068242195994	2012/11	user6865	password	50	100000	F
6866	ZWRJQZ	ANXYWUHNKQ	5562466921 Dell Way	\N	NDSMGQG	MD	91257	US	1	ANXYWUHNKQ@dell.com	5562466921	2	8354260535910726	2012/03	user6866	password	88	100000	F
6867	QHRQIE	OGBINOTDCW	2859066007 Dell Way	\N	WODMUNK	IL	79739	US	1	OGBINOTDCW@dell.com	2859066007	2	9554859150201084	2008/03	user6867	password	18	100000	F
6868	RLUWAA	XIOMCSOZPC	4089937143 Dell Way	\N	CCWQMEK	NY	47133	US	1	XIOMCSOZPC@dell.com	4089937143	5	6376922199036927	2009/09	user6868	password	24	20000	F
6869	XWDYUL	MGOFUNUWPX	9275383703 Dell Way	\N	TFJXQAI	WV	88804	US	1	MGOFUNUWPX@dell.com	9275383703	2	5892893283162267	2008/04	user6869	password	66	100000	F
6870	UVZFIF	UNAHIWXFQD	1209867390 Dell Way	\N	PNTPWSM	RI	12970	US	1	UNAHIWXFQD@dell.com	1209867390	4	4261711148079485	2011/09	user6870	password	59	60000	M
6871	ORVTMJ	TTSQQYHUNU	6813525573 Dell Way	\N	NDRGPLH	NJ	29978	US	1	TTSQQYHUNU@dell.com	6813525573	2	9117206302937120	2009/10	user6871	password	47	80000	F
6872	FNXPHR	HYIFFCTAQW	3033441444 Dell Way	\N	RWLCDBI	SC	42664	US	1	HYIFFCTAQW@dell.com	3033441444	1	2125454592518508	2011/10	user6872	password	60	100000	F
6873	MLODSM	MYRORRENIA	5671922703 Dell Way	\N	ZLEATZK	WV	98814	US	1	MYRORRENIA@dell.com	5671922703	4	7680041865911335	2008/06	user6873	password	18	60000	M
6874	OTQAFP	RTGIXURYTC	8645034255 Dell Way	\N	DUWDEVC	OK	50002	US	1	RTGIXURYTC@dell.com	8645034255	5	9202167628798636	2012/05	user6874	password	77	60000	F
6875	LLIBCC	ILACDZWFCR	3438385675 Dell Way	\N	CGWXIOJ	FL	44259	US	1	ILACDZWFCR@dell.com	3438385675	1	7974961647763849	2008/06	user6875	password	84	60000	M
6876	GPZJXL	JAOIXULOWR	2491691403 Dell Way	\N	LUAADFK	ME	32328	US	1	JAOIXULOWR@dell.com	2491691403	3	7316979222930969	2008/01	user6876	password	60	40000	M
6877	OROABP	OJMJVBGMMA	7013943323 Dell Way	\N	NNESXPZ	AZ	18199	US	1	OJMJVBGMMA@dell.com	7013943323	1	2334165578242391	2009/06	user6877	password	76	100000	F
6878	JVEYKO	LUJMAWZAKM	1220764162 Dell Way	\N	FCJUCLW	PA	62050	US	1	LUJMAWZAKM@dell.com	1220764162	5	1387131466530263	2012/10	user6878	password	31	20000	M
6879	JDBYPV	HCWEBWPOCS	1031334747 Dell Way	\N	YWUJTNY	RI	57299	US	1	HCWEBWPOCS@dell.com	1031334747	3	4122925900388509	2008/10	user6879	password	18	60000	M
6880	BMNXUP	TZRQOFSGEP	4807252164 Dell Way	\N	AOIONCB	MS	74034	US	1	TZRQOFSGEP@dell.com	4807252164	4	5519306553062052	2010/03	user6880	password	50	60000	M
6881	YKNODM	FUALNHPCHD	7979626243 Dell Way	\N	LWROYEH	KY	87545	US	1	FUALNHPCHD@dell.com	7979626243	4	1997601907234639	2009/04	user6881	password	79	20000	M
6882	JTVVYP	WKCDAFLERH	9676556123 Dell Way	\N	VFFZMOW	ID	41423	US	1	WKCDAFLERH@dell.com	9676556123	3	6543143427465112	2012/08	user6882	password	38	20000	F
6883	CZJRVT	UZUAKYRSTX	5116188928 Dell Way	\N	XTKMPRV	NE	23229	US	1	UZUAKYRSTX@dell.com	5116188928	2	8269321149680764	2011/07	user6883	password	32	100000	M
6884	ONIIHH	CHSAZKUWIN	8682648817 Dell Way	\N	GVDXRSB	CT	18329	US	1	CHSAZKUWIN@dell.com	8682648817	5	6555267997086049	2008/09	user6884	password	26	80000	F
6885	LXMTZU	MATXUPFIVB	9115190212 Dell Way	\N	MSSETWH	NJ	74058	US	1	MATXUPFIVB@dell.com	9115190212	4	4529233749024570	2008/04	user6885	password	59	60000	F
6886	BGFVSF	OPZDVIZXUR	6203050836 Dell Way	\N	QZLMHCE	FL	78195	US	1	OPZDVIZXUR@dell.com	6203050836	2	1380519389640539	2008/09	user6886	password	35	40000	M
6887	LAQQPG	QSCZRZTJPT	7396524083 Dell Way	\N	VCBXGFR	TX	47711	US	1	QSCZRZTJPT@dell.com	7396524083	1	1863252383656799	2012/03	user6887	password	18	40000	F
6888	QAVXRN	ZQFZKPPEKR	9502065108 Dell Way	\N	FIYLZUW	OK	79949	US	1	ZQFZKPPEKR@dell.com	9502065108	4	9825074416585268	2012/01	user6888	password	33	80000	F
6889	ANTOMK	TLUIAZTSEC	2415573630 Dell Way	\N	QPCKMUE	MD	50978	US	1	TLUIAZTSEC@dell.com	2415573630	2	5545563300605864	2009/12	user6889	password	60	40000	F
6890	IYYTRK	NALNUDSXTI	7569209640 Dell Way	\N	ZDUUIEF	MO	59367	US	1	NALNUDSXTI@dell.com	7569209640	5	5671123233623803	2009/03	user6890	password	90	80000	F
6891	YKWJYW	ULRXDORLOV	5264548056 Dell Way	\N	FIDKNQY	ID	54329	US	1	ULRXDORLOV@dell.com	5264548056	3	7549986408092082	2010/03	user6891	password	83	60000	M
6892	TTOQOZ	HMDWDPKZUS	9788668177 Dell Way	\N	DFGTENG	NM	18257	US	1	HMDWDPKZUS@dell.com	9788668177	1	3958684695418924	2012/07	user6892	password	87	80000	F
6893	NGVNNH	QKKFUJANMG	7311364718 Dell Way	\N	TGKHNBJ	MO	24407	US	1	QKKFUJANMG@dell.com	7311364718	2	7042751677799971	2011/12	user6893	password	86	20000	F
6894	TRSAID	LOYVPLIVFP	2294547628 Dell Way	\N	GMCIWOM	NE	92044	US	1	LOYVPLIVFP@dell.com	2294547628	2	8795755463186652	2008/05	user6894	password	21	100000	F
6895	UWKXIZ	VEOHMKMCRZ	5627690026 Dell Way	\N	EZWTLLQ	NH	69674	US	1	VEOHMKMCRZ@dell.com	5627690026	4	1597142095677554	2010/07	user6895	password	29	40000	F
6896	OGSOBX	DIKNVMFVQE	8501460263 Dell Way	\N	RJQCAGT	NC	93386	US	1	DIKNVMFVQE@dell.com	8501460263	1	5043680947739631	2012/06	user6896	password	79	60000	M
6897	OCTMFC	WTXIZSZEKJ	4802440629 Dell Way	\N	UMKBGYZ	CA	14879	US	1	WTXIZSZEKJ@dell.com	4802440629	1	5569153022952378	2009/08	user6897	password	32	100000	M
6898	YIZAET	YNSRNWBWRO	7926930928 Dell Way	\N	GSUFSXG	CT	98672	US	1	YNSRNWBWRO@dell.com	7926930928	2	6646453808061779	2012/03	user6898	password	45	100000	M
6899	JYTCXG	VOTSPQJDXC	5202035315 Dell Way	\N	YCUWJXV	CT	38048	US	1	VOTSPQJDXC@dell.com	5202035315	1	5945618002209813	2012/01	user6899	password	25	40000	M
6900	VHWCDK	VVAMFDJHCL	8897586224 Dell Way	\N	CYUAUYI	ID	11702	US	1	VVAMFDJHCL@dell.com	8897586224	1	1267274940852075	2012/04	user6900	password	90	100000	M
6901	VXTGTO	GFTKOBMAEL	8010943879 Dell Way	\N	UEGSNMT	MA	64218	US	1	GFTKOBMAEL@dell.com	8010943879	2	9193497228901834	2011/03	user6901	password	56	80000	F
6902	GWVVCB	PMPRZQVLLZ	7163678015 Dell Way	\N	REMEXWU	NY	30138	US	1	PMPRZQVLLZ@dell.com	7163678015	3	4628888697829098	2009/01	user6902	password	53	60000	M
6903	IIAJXN	ZONQJYBJQF	4069546521 Dell Way	\N	WUCSOUY	ID	32004	US	1	ZONQJYBJQF@dell.com	4069546521	3	3801584817469120	2012/12	user6903	password	35	20000	F
6904	GOEUOT	HECGFMWKIR	8740144238 Dell Way	\N	NBGHZNO	KS	97599	US	1	HECGFMWKIR@dell.com	8740144238	1	9274855568539352	2008/04	user6904	password	31	40000	M
6905	JDKCLO	FSURPEZGSA	9210863735 Dell Way	\N	NAAAOIZ	ME	54058	US	1	FSURPEZGSA@dell.com	9210863735	3	8249383062124253	2008/11	user6905	password	66	60000	F
6906	BNMQSE	KJTPJAIKNI	1583032984 Dell Way	\N	LOWUOHG	MN	80841	US	1	KJTPJAIKNI@dell.com	1583032984	3	6884012789931149	2011/12	user6906	password	66	100000	M
6907	DLFHWP	BMZCUKPCVE	7235135768 Dell Way	\N	ZPSGWEB	VT	74921	US	1	BMZCUKPCVE@dell.com	7235135768	4	7369160002563149	2009/06	user6907	password	33	60000	M
6908	LUUAWH	ZYBJOEFSDU	1236579397 Dell Way	\N	LKQPLOI	CT	28810	US	1	ZYBJOEFSDU@dell.com	1236579397	3	6982241570483894	2009/12	user6908	password	59	80000	M
6909	JRQQRO	RBCWGVABGK	2259464276 Dell Way	\N	SVVGEYM	FL	50202	US	1	RBCWGVABGK@dell.com	2259464276	3	4830819394439459	2011/02	user6909	password	32	20000	M
6910	VSLJKN	MGUHGVOQNJ	3844317746 Dell Way	\N	MUNLHSX	ME	22201	US	1	MGUHGVOQNJ@dell.com	3844317746	1	2971936866641044	2010/03	user6910	password	90	40000	M
6911	LSHYFN	SNUOBLCKYW	1238081698 Dell Way	\N	YJERGOU	NE	73565	US	1	SNUOBLCKYW@dell.com	1238081698	1	9170854016207160	2008/06	user6911	password	76	60000	F
6912	CKJQCW	KQXWSIUPHD	9516408183 Dell Way	\N	TYKITZA	SC	16736	US	1	KQXWSIUPHD@dell.com	9516408183	5	5525616843719036	2011/04	user6912	password	65	100000	M
6913	AMTWXJ	UTCCOSKSLI	7083894073 Dell Way	\N	CUCCVXE	RI	73428	US	1	UTCCOSKSLI@dell.com	7083894073	3	9603608638513834	2009/05	user6913	password	61	40000	M
6914	IFTSZN	UCBMMTYVWS	5332956624 Dell Way	\N	XZOVDHN	SD	84320	US	1	UCBMMTYVWS@dell.com	5332956624	1	2745992101263255	2008/06	user6914	password	21	60000	M
6915	UCRHXT	JKFDIAABYZ	9375243812 Dell Way	\N	PTDXHYT	PA	18224	US	1	JKFDIAABYZ@dell.com	9375243812	5	6177858360577375	2012/03	user6915	password	37	80000	F
6916	XBGRLR	WOAWOBVORO	3475343619 Dell Way	\N	RPWPIQS	IA	51652	US	1	WOAWOBVORO@dell.com	3475343619	2	7365534871350975	2010/12	user6916	password	22	60000	F
6917	IDNZZB	AWQBRETGWI	9266976248 Dell Way	\N	DMRTEXF	MI	22826	US	1	AWQBRETGWI@dell.com	9266976248	5	2232148579787463	2012/06	user6917	password	32	40000	M
6918	SHOUHK	LJCQDJMMMY	3877588524 Dell Way	\N	DGDBLOE	LA	58110	US	1	LJCQDJMMMY@dell.com	3877588524	2	9735859203618020	2010/08	user6918	password	56	40000	M
6919	BAGMLQ	PCUYOGLNJR	7203772861 Dell Way	\N	QKDEPNS	VT	88037	US	1	PCUYOGLNJR@dell.com	7203772861	3	5749499560333789	2009/08	user6919	password	53	40000	M
6920	TUDKJF	EIUKTHTLXE	5494860095 Dell Way	\N	PCTCVRZ	MT	17717	US	1	EIUKTHTLXE@dell.com	5494860095	4	7741187434643508	2012/01	user6920	password	49	80000	M
6921	ODDUIL	OSFWMRURGX	9138136434 Dell Way	\N	KJSBIFE	SD	95115	US	1	OSFWMRURGX@dell.com	9138136434	5	9634301240090282	2009/07	user6921	password	72	100000	M
6922	WSAIHT	ODFFYWLVHU	6771297721 Dell Way	\N	NJCTNYR	ME	76541	US	1	ODFFYWLVHU@dell.com	6771297721	4	3651840717531741	2009/09	user6922	password	90	40000	F
6923	APRTDU	ZISWUNDOBN	6667159916 Dell Way	\N	RUBPMMI	CO	30396	US	1	ZISWUNDOBN@dell.com	6667159916	3	9113934686873108	2011/10	user6923	password	38	80000	F
6924	YJMTJV	LFPZJDAWVV	5605653960 Dell Way	\N	XKHJTJP	MA	88638	US	1	LFPZJDAWVV@dell.com	5605653960	1	6678805280476809	2011/08	user6924	password	90	80000	F
6925	MLJHXP	XXYBXVWSTH	9049777290 Dell Way	\N	ADAKTKG	IA	46592	US	1	XXYBXVWSTH@dell.com	9049777290	1	1387601029127836	2012/10	user6925	password	22	40000	F
6926	LRDAOA	YPYUMRNTRR	6712415392 Dell Way	\N	UCKEIRP	HI	73038	US	1	YPYUMRNTRR@dell.com	6712415392	1	5251484206877649	2011/06	user6926	password	69	20000	F
6927	VDSWCI	VXUNKOFCIH	3845387641 Dell Way	\N	MNPDCWV	OR	96708	US	1	VXUNKOFCIH@dell.com	3845387641	3	4957653900608421	2008/07	user6927	password	60	100000	M
6928	HTUPOR	JBCXHEGORT	4653844180 Dell Way	\N	EVVARPZ	WV	10479	US	1	JBCXHEGORT@dell.com	4653844180	5	6046471722424031	2012/11	user6928	password	36	40000	M
6929	BWETGG	WENAKBSDFN	2235891476 Dell Way	\N	ZFFOEEO	NH	25690	US	1	WENAKBSDFN@dell.com	2235891476	3	1337006403133273	2009/11	user6929	password	64	60000	M
6930	VFYBBC	OBNQURWIQB	9120742183 Dell Way	\N	NFGRUVW	WA	47071	US	1	OBNQURWIQB@dell.com	9120742183	2	3295534617733210	2010/10	user6930	password	88	40000	M
6931	XKAAZC	NQWEMFVNSB	3539782077 Dell Way	\N	UKVPGUA	DE	19334	US	1	NQWEMFVNSB@dell.com	3539782077	4	8960628123022617	2009/01	user6931	password	80	20000	F
6932	WEMYRC	VVOARCTSWD	3747820658 Dell Way	\N	OMKINOK	SC	35592	US	1	VVOARCTSWD@dell.com	3747820658	1	4154743173159659	2008/03	user6932	password	78	20000	F
6933	HZZJVV	YWNAPFWSTJ	4079220821 Dell Way	\N	DBWSMQZ	SC	70781	US	1	YWNAPFWSTJ@dell.com	4079220821	5	8637014090083540	2008/12	user6933	password	30	60000	M
6934	EWUAUQ	NUGSRZMACN	1553316137 Dell Way	\N	XVANUUF	DC	78250	US	1	NUGSRZMACN@dell.com	1553316137	2	7705228529404850	2009/10	user6934	password	70	60000	M
6935	NKKEYF	KQWKCXMQUH	9658064560 Dell Way	\N	RICLOGF	NJ	61674	US	1	KQWKCXMQUH@dell.com	9658064560	5	4224246375262737	2011/04	user6935	password	90	40000	M
6936	KJPPUG	MEJKRAFZRN	3579142396 Dell Way	\N	CDCJISY	IN	58731	US	1	MEJKRAFZRN@dell.com	3579142396	5	8204314738046379	2009/03	user6936	password	53	80000	M
6937	CHJJTO	SEGTJGKWIN	9961056579 Dell Way	\N	YRWQQEF	VT	25532	US	1	SEGTJGKWIN@dell.com	9961056579	1	4323608464561403	2010/11	user6937	password	87	60000	F
6938	IYXXQB	DKKJUHSIGK	9449863424 Dell Way	\N	FXAKCXO	CA	18517	US	1	DKKJUHSIGK@dell.com	9449863424	3	9524434924591334	2012/02	user6938	password	23	40000	F
6939	ZCSAGC	LQXSIGYTLW	7386106048 Dell Way	\N	TWYRKAT	LA	63318	US	1	LQXSIGYTLW@dell.com	7386106048	2	7533433645498008	2011/06	user6939	password	75	80000	M
6940	MUVPFL	MXUTWNESHA	1087444460 Dell Way	\N	RYLRSVH	MD	15126	US	1	MXUTWNESHA@dell.com	1087444460	1	5646928576752544	2011/12	user6940	password	24	40000	M
6941	XWZJJW	DCTQHMXIDW	2534936408 Dell Way	\N	UVOPDZR	CT	25721	US	1	DCTQHMXIDW@dell.com	2534936408	5	2227022065315395	2009/03	user6941	password	82	20000	F
6942	WNLTQO	MHWZFFCBZY	9260753833 Dell Way	\N	QPBPGFU	MD	20542	US	1	MHWZFFCBZY@dell.com	9260753833	4	3912907798774540	2012/10	user6942	password	47	80000	F
6943	WJYLWG	HVLMYNMXDB	6490531289 Dell Way	\N	ZTHENRH	MI	40741	US	1	HVLMYNMXDB@dell.com	6490531289	2	2383958148304373	2008/11	user6943	password	52	100000	F
6944	KIDQQZ	CDYPPWTQVM	2009520315 Dell Way	\N	YAAQHLY	VA	72518	US	1	CDYPPWTQVM@dell.com	2009520315	5	6331557264551521	2010/10	user6944	password	81	100000	F
6945	AQTATW	ZIMVBDRNBR	3422265125 Dell Way	\N	NRYZQWR	OR	78844	US	1	ZIMVBDRNBR@dell.com	3422265125	2	6118872162885964	2008/04	user6945	password	68	20000	M
6946	LESIEA	UZBXQPZIDQ	5036504894 Dell Way	\N	GDGCUZW	AZ	37746	US	1	UZBXQPZIDQ@dell.com	5036504894	2	6609887973405421	2008/05	user6946	password	60	60000	M
6947	HXSHSS	JQJZPRCFYG	4565514481 Dell Way	\N	MBAMYCU	MA	38172	US	1	JQJZPRCFYG@dell.com	4565514481	3	7201475968584419	2012/02	user6947	password	36	40000	F
6948	ZOTRXK	BXZSAFRGRS	4423973381 Dell Way	\N	HDRJXBR	KS	62035	US	1	BXZSAFRGRS@dell.com	4423973381	2	7356668548658491	2011/07	user6948	password	73	80000	F
6949	NHAXIX	XBXCSEULLY	4846696500 Dell Way	\N	CVWDNES	UT	51148	US	1	XBXCSEULLY@dell.com	4846696500	3	1069846466183662	2008/02	user6949	password	25	80000	F
6950	DQTBNU	YQMCKYOJAJ	8419342196 Dell Way	\N	FEWJXTV	KS	32045	US	1	YQMCKYOJAJ@dell.com	8419342196	3	4253226801287383	2012/03	user6950	password	73	20000	M
6951	MCJHBZ	UEKSSTTBYX	3240932666 Dell Way	\N	XHUQCDX	WA	67075	US	1	UEKSSTTBYX@dell.com	3240932666	5	8585616687312723	2008/12	user6951	password	66	60000	F
6952	AUCZOG	JHZDAABYYI	4042305708 Dell Way	\N	TOLWLJM	OK	32031	US	1	JHZDAABYYI@dell.com	4042305708	4	2551078469958156	2008/03	user6952	password	32	20000	F
6953	HAPOKW	NNWNOULXNA	2364002483 Dell Way	\N	JJMTWFZ	GA	93006	US	1	NNWNOULXNA@dell.com	2364002483	2	2386923259124160	2009/03	user6953	password	30	80000	F
6954	TERPRE	MFTGRRURAE	5066530858 Dell Way	\N	ETBJTGH	VA	52936	US	1	MFTGRRURAE@dell.com	5066530858	2	7542129245586694	2011/11	user6954	password	90	40000	F
6955	RZTWLY	PSPHNHHRMB	2445990509 Dell Way	\N	SWUYDRL	NH	91595	US	1	PSPHNHHRMB@dell.com	2445990509	2	8064487318042667	2008/08	user6955	password	79	100000	M
6956	PRBNHT	DOGLWYXXQT	1563000269 Dell Way	\N	SPXJAMH	FL	74305	US	1	DOGLWYXXQT@dell.com	1563000269	2	3831629384774715	2012/02	user6956	password	83	60000	M
6957	YADSES	ZPOXNMOGFD	7175580242 Dell Way	\N	EOERVIJ	VT	71379	US	1	ZPOXNMOGFD@dell.com	7175580242	5	8619644837919624	2010/04	user6957	password	68	60000	F
6958	VGNNFC	CDQPRWUVBJ	8583133481 Dell Way	\N	ZSFIBCZ	PA	93094	US	1	CDQPRWUVBJ@dell.com	8583133481	2	3059210638049990	2010/11	user6958	password	58	40000	F
6959	BXJEAN	UPERKASTZK	3096508929 Dell Way	\N	ZHMCHGA	CT	64959	US	1	UPERKASTZK@dell.com	3096508929	4	5464577892795205	2011/01	user6959	password	64	100000	M
6960	ZAYMVN	RMYRFSRQRY	5429300788 Dell Way	\N	DTGKTJZ	WY	11970	US	1	RMYRFSRQRY@dell.com	5429300788	4	1397674438077956	2008/08	user6960	password	88	20000	M
6961	XPMKHZ	JZEBQUSPXM	3238203078 Dell Way	\N	VHFEHFF	SC	99686	US	1	JZEBQUSPXM@dell.com	3238203078	5	6721808395814151	2009/01	user6961	password	39	20000	M
6962	UNYTWX	XXOSQDQCZY	2693083596 Dell Way	\N	IDFOJAO	NH	93371	US	1	XXOSQDQCZY@dell.com	2693083596	5	9605750428512692	2010/11	user6962	password	61	40000	F
6963	NAHLYF	AQWEGZDEIH	3585357494 Dell Way	\N	KWQKLGI	NJ	14842	US	1	AQWEGZDEIH@dell.com	3585357494	1	9706618217751384	2012/05	user6963	password	46	60000	F
6964	SWIXXY	UBETEJBMTY	4211862050 Dell Way	\N	CDJIMZK	RI	17717	US	1	UBETEJBMTY@dell.com	4211862050	4	5124234176240862	2011/01	user6964	password	79	60000	M
6965	DJWCDX	HXCQZOJXQN	8225733832 Dell Way	\N	HZZGJTI	OR	47647	US	1	HXCQZOJXQN@dell.com	8225733832	3	5462515512946993	2011/12	user6965	password	51	80000	F
6966	HXLFEI	HUHWDFNRMM	4094427542 Dell Way	\N	RTWLCPW	VA	16736	US	1	HUHWDFNRMM@dell.com	4094427542	3	1088412750512361	2011/05	user6966	password	40	20000	F
6967	TIJCPE	KMIPZZBLQV	9824924543 Dell Way	\N	HCXXYUZ	ID	39494	US	1	KMIPZZBLQV@dell.com	9824924543	1	6968933681491763	2009/03	user6967	password	82	20000	F
6968	HDCLNO	TCNTEZKZHM	7139293738 Dell Way	\N	XEKRDRA	CT	76250	US	1	TCNTEZKZHM@dell.com	7139293738	3	9155456799548120	2010/06	user6968	password	46	100000	M
6969	MHCAAF	OTJNEJUQHY	3962478386 Dell Way	\N	AZCRZFK	NV	66166	US	1	OTJNEJUQHY@dell.com	3962478386	2	1666845876723528	2011/01	user6969	password	65	20000	F
6970	TGJYUD	IIHRCXYBYX	1625183216 Dell Way	\N	EQXJBOZ	MA	81823	US	1	IIHRCXYBYX@dell.com	1625183216	1	8831823760643602	2011/04	user6970	password	33	60000	M
6971	PKITSQ	AKSYJUXHYN	4697981744 Dell Way	\N	EIPTIYO	MA	15201	US	1	AKSYJUXHYN@dell.com	4697981744	1	4183545974083245	2011/07	user6971	password	82	40000	M
6972	FYRVZC	OYLJWSHJXQ	4007382936 Dell Way	\N	ZQYXEIZ	NE	47087	US	1	OYLJWSHJXQ@dell.com	4007382936	2	9800177984870972	2009/06	user6972	password	86	60000	F
6973	QGKSVJ	DEFWMPTCOJ	7449549222 Dell Way	\N	AMOILDT	SC	41344	US	1	DEFWMPTCOJ@dell.com	7449549222	1	8059070047922433	2011/06	user6973	password	31	40000	M
6974	OZNXDR	DZESSGGCGT	9332005408 Dell Way	\N	RPEUIZD	AR	97525	US	1	DZESSGGCGT@dell.com	9332005408	4	4599777937401086	2008/12	user6974	password	24	80000	M
6975	PPCHSC	LLVRSYYLPN	9580632530 Dell Way	\N	PKVPNXO	MN	63202	US	1	LLVRSYYLPN@dell.com	9580632530	3	6227603845298291	2008/03	user6975	password	58	80000	M
6976	RXOUIA	PZSNXDDLTN	4092646015 Dell Way	\N	HIBEXMT	TN	15297	US	1	PZSNXDDLTN@dell.com	4092646015	5	3703199655748904	2012/07	user6976	password	28	60000	F
6977	SJTSYS	LMQPPCIDJR	1266768577 Dell Way	\N	EOORIKS	NV	35810	US	1	LMQPPCIDJR@dell.com	1266768577	3	8161197591107339	2008/02	user6977	password	32	100000	F
6978	YQLRBX	IQNKZRURVI	7428766046 Dell Way	\N	FMQQFHX	ID	85423	US	1	IQNKZRURVI@dell.com	7428766046	3	9754238320048900	2012/04	user6978	password	51	100000	M
6979	XNAUVR	IFQZAIVINI	1418356025 Dell Way	\N	YEOGCUB	SC	31569	US	1	IFQZAIVINI@dell.com	1418356025	4	6085127044003457	2010/07	user6979	password	55	40000	F
6980	NFXEND	VNDDIMRRLW	8362378430 Dell Way	\N	FRYATTG	SC	50605	US	1	VNDDIMRRLW@dell.com	8362378430	2	1219112965278327	2009/09	user6980	password	26	100000	M
6981	ABKEWY	IAHVSYGODX	7171858387 Dell Way	\N	MDRFKLR	HI	76618	US	1	IAHVSYGODX@dell.com	7171858387	3	4815438421908766	2012/05	user6981	password	40	100000	F
6982	SAIQJI	XEBVKPZIBD	6414740327 Dell Way	\N	ZHNLYTE	NJ	36909	US	1	XEBVKPZIBD@dell.com	6414740327	3	7350167511031032	2012/04	user6982	password	29	80000	F
6983	MGQVEU	WAFLZNNDNU	4667976747 Dell Way	\N	RZSKDIS	OR	78991	US	1	WAFLZNNDNU@dell.com	4667976747	4	1205026762094348	2010/04	user6983	password	39	20000	M
6984	XWSSST	XETLRWZMNY	3954355748 Dell Way	\N	FXCOQVH	AL	52669	US	1	XETLRWZMNY@dell.com	3954355748	3	7679320129565895	2011/08	user6984	password	38	60000	F
6985	ZGFSEJ	LQBHPNVOST	7106890436 Dell Way	\N	QGJMOJY	VA	96349	US	1	LQBHPNVOST@dell.com	7106890436	3	6259037876501680	2012/01	user6985	password	23	100000	F
6986	HRNQCD	SKTGFHZYYG	3030739089 Dell Way	\N	IKVRISQ	AK	31446	US	1	SKTGFHZYYG@dell.com	3030739089	5	3761702816933394	2009/11	user6986	password	64	60000	M
6987	DFRGYB	AEHHEGFKOQ	5326901260 Dell Way	\N	FGYYWYE	CO	92138	US	1	AEHHEGFKOQ@dell.com	5326901260	3	8293624880257995	2008/12	user6987	password	44	40000	F
6988	ANDCNI	JVMQBXERDL	3532015238 Dell Way	\N	PBIOFLM	OK	84443	US	1	JVMQBXERDL@dell.com	3532015238	5	8210261203814299	2011/01	user6988	password	90	80000	M
6989	DTCMDX	YTYWYPZJFA	7746391385 Dell Way	\N	SUGDGZY	MT	81237	US	1	YTYWYPZJFA@dell.com	7746391385	1	8753169347532094	2011/11	user6989	password	50	100000	M
6990	OJSLHM	KELADUFENZ	1393879141 Dell Way	\N	KQGKOTE	KS	93275	US	1	KELADUFENZ@dell.com	1393879141	1	7830035331659020	2010/12	user6990	password	43	20000	F
6991	BMQNWU	YWXTCCHCNX	7829243635 Dell Way	\N	IXMBBUZ	CT	88365	US	1	YWXTCCHCNX@dell.com	7829243635	4	8480074520222844	2008/08	user6991	password	28	20000	F
6992	TSZOQW	LKYNRAAPIY	6016015884 Dell Way	\N	BKAWKDS	FL	75194	US	1	LKYNRAAPIY@dell.com	6016015884	2	4179195661563426	2011/06	user6992	password	51	60000	F
6993	LAUHLF	FZXGAMPYNA	2397650800 Dell Way	\N	YKLCDPU	NY	90043	US	1	FZXGAMPYNA@dell.com	2397650800	2	3980072030797601	2011/11	user6993	password	52	20000	M
6994	GIHLNH	JUIVJHJJFT	6659299787 Dell Way	\N	UHWKCOH	ID	93526	US	1	JUIVJHJJFT@dell.com	6659299787	5	7887135429307819	2008/11	user6994	password	62	40000	F
6995	XUTEEN	NZWUJGACBI	3058810356 Dell Way	\N	ZMLNTRM	MA	60821	US	1	NZWUJGACBI@dell.com	3058810356	3	5285176046192646	2012/10	user6995	password	68	80000	M
6996	LYUZLU	WFDCFGENFQ	7234865460 Dell Way	\N	ZTJQFUF	MI	32965	US	1	WFDCFGENFQ@dell.com	7234865460	2	1785423227585852	2009/01	user6996	password	70	100000	M
6997	NVJHRP	LUURYIWOHQ	1467214688 Dell Way	\N	YYVSEHZ	UT	61033	US	1	LUURYIWOHQ@dell.com	1467214688	2	6221081245224923	2011/02	user6997	password	55	40000	M
6998	XPOMAI	HRHPOVXETW	5081221815 Dell Way	\N	AMBHLXW	MS	23992	US	1	HRHPOVXETW@dell.com	5081221815	2	3247187552973628	2012/07	user6998	password	29	100000	F
6999	SIEBPV	IFKEDOYAPK	4143966908 Dell Way	\N	BXVYTIC	GA	64471	US	1	IFKEDOYAPK@dell.com	4143966908	1	2526340737007558	2010/01	user6999	password	41	40000	F
7000	MHZIQF	SUIHSJWDKT	1730905062 Dell Way	\N	ZINHLTX	RI	93147	US	1	SUIHSJWDKT@dell.com	1730905062	2	9740658019203694	2010/07	user7000	password	43	100000	M
7001	IGLOZF	XGYGDBQXBY	1525305354 Dell Way	\N	LIKEGEC	KY	51596	US	1	XGYGDBQXBY@dell.com	1525305354	4	9787327907048168	2010/08	user7001	password	75	80000	M
7002	FHWLED	JKHLAEMZPV	1022471647 Dell Way	\N	KTCOWLA	VT	25600	US	1	JKHLAEMZPV@dell.com	1022471647	2	8396921594161541	2011/01	user7002	password	70	100000	F
7003	PLNSVY	ZGZETZTPJN	1904603400 Dell Way	\N	RYJCZHH	WV	63607	US	1	ZGZETZTPJN@dell.com	1904603400	4	6946112881414593	2012/09	user7003	password	19	40000	F
7004	OCZNCG	MGAMZPVNHU	4724257862 Dell Way	\N	WJTERST	PA	50950	US	1	MGAMZPVNHU@dell.com	4724257862	3	2812378744129091	2010/12	user7004	password	45	100000	F
7005	JMEQZK	RLKGHXNBUX	2571418997 Dell Way	\N	VYPNRIZ	CO	92452	US	1	RLKGHXNBUX@dell.com	2571418997	3	8969290534965695	2010/07	user7005	password	87	100000	F
7006	COZNFK	XMSUAUOYPN	6877975673 Dell Way	\N	NCEWCHT	ID	84164	US	1	XMSUAUOYPN@dell.com	6877975673	5	4067200673744083	2011/10	user7006	password	43	80000	F
7007	IFOTDB	LXBGMZVZNY	6572381307 Dell Way	\N	EJALDHH	RI	19668	US	1	LXBGMZVZNY@dell.com	6572381307	2	8747660534456373	2012/02	user7007	password	31	40000	F
7008	TALUMJ	WSVWOVJMZS	8010637999 Dell Way	\N	NLWVSQX	KS	12990	US	1	WSVWOVJMZS@dell.com	8010637999	2	2331095773261040	2012/07	user7008	password	53	80000	M
7009	YNBIJU	EGIZPVYIJJ	1093598768 Dell Way	\N	EECVCKW	TX	73806	US	1	EGIZPVYIJJ@dell.com	1093598768	5	3536592801101506	2010/07	user7009	password	82	60000	F
7010	YTLTYR	CXHXVPGFUK	7464395756 Dell Way	\N	IQMSMJL	MS	26425	US	1	CXHXVPGFUK@dell.com	7464395756	5	7557388424873353	2010/06	user7010	password	75	60000	F
7011	FHDXJA	EHWTOCOZKE	7614230716 Dell Way	\N	MDQVODA	IL	21985	US	1	EHWTOCOZKE@dell.com	7614230716	5	6164759440813214	2010/06	user7011	password	75	80000	M
7012	XQCYVK	UPYXDXHHJK	8242739180 Dell Way	\N	YFZCFGG	WA	21397	US	1	UPYXDXHHJK@dell.com	8242739180	3	5975312784314156	2010/03	user7012	password	37	60000	M
7013	JLRTGG	SDJPKRZVQE	7559448013 Dell Way	\N	UTJBZHE	RI	78559	US	1	SDJPKRZVQE@dell.com	7559448013	2	9770234239287676	2008/11	user7013	password	78	40000	F
7014	NDNTVR	DKBVKXMOSF	9565188320 Dell Way	\N	XTEFYYZ	NV	37639	US	1	DKBVKXMOSF@dell.com	9565188320	4	2487526896875351	2011/01	user7014	password	51	40000	F
7015	ZBZQEK	SAUQMJIRGB	3449905322 Dell Way	\N	WMZULQC	MD	37410	US	1	SAUQMJIRGB@dell.com	3449905322	1	4016147930640727	2011/06	user7015	password	54	80000	M
7016	MJSXCT	SSFBAXHCTU	4500957226 Dell Way	\N	COGTQQB	WA	85699	US	1	SSFBAXHCTU@dell.com	4500957226	4	3942970638629049	2012/05	user7016	password	80	40000	M
7017	PGVIYO	NAPKHRECUS	2315783720 Dell Way	\N	INJZPHV	WV	93724	US	1	NAPKHRECUS@dell.com	2315783720	5	3722735106013715	2008/03	user7017	password	21	60000	M
7018	WXMKLM	ZWURAWLSFZ	6304393134 Dell Way	\N	CEPJZOH	DC	47698	US	1	ZWURAWLSFZ@dell.com	6304393134	1	6899920426774771	2011/09	user7018	password	29	60000	M
7019	QXCCXY	WPZTBRYATD	3229280392 Dell Way	\N	QDCEKGP	AK	46621	US	1	WPZTBRYATD@dell.com	3229280392	4	2340678266715258	2010/02	user7019	password	76	20000	F
7020	XDZVAO	UTPMSQGVGJ	7649129088 Dell Way	\N	YLUEAUP	ID	48369	US	1	UTPMSQGVGJ@dell.com	7649129088	4	6062997864093632	2010/09	user7020	password	63	60000	M
7021	PGWDBP	TOHJVCQFAB	7971303869 Dell Way	\N	ZFBUVIF	ND	10852	US	1	TOHJVCQFAB@dell.com	7971303869	1	7491274449508638	2009/07	user7021	password	59	100000	M
7022	KCWAVK	IFFLVLMWKS	1141793827 Dell Way	\N	YFNHKBH	FL	23203	US	1	IFFLVLMWKS@dell.com	1141793827	3	6987478281836957	2010/07	user7022	password	50	20000	M
7023	HANSJS	YUOJHLUZKZ	4206935632 Dell Way	\N	MRKOZPR	WY	25430	US	1	YUOJHLUZKZ@dell.com	4206935632	3	7551819760818035	2012/07	user7023	password	46	20000	M
7024	XVZQTU	EDBQXAAXNR	8120996738 Dell Way	\N	HBRXTQB	CO	29371	US	1	EDBQXAAXNR@dell.com	8120996738	5	8101075536571444	2008/01	user7024	password	46	20000	M
7025	JSPDXT	ENRFOOSGWU	5904270111 Dell Way	\N	XTNOVQT	NH	60127	US	1	ENRFOOSGWU@dell.com	5904270111	4	6215222563128919	2012/11	user7025	password	49	40000	M
7026	ALNUQA	LVPZOVWJSP	7133299257 Dell Way	\N	XGKOAAC	NC	83958	US	1	LVPZOVWJSP@dell.com	7133299257	3	7352301283739508	2008/10	user7026	password	40	20000	F
7027	VYWWJS	LJHGFQYVOF	8213570865 Dell Way	\N	GCFHFTC	UT	31413	US	1	LJHGFQYVOF@dell.com	8213570865	5	1306151221971958	2008/02	user7027	password	37	100000	F
7028	DUKWFU	DLZUKVJPBL	8395455544 Dell Way	\N	UIQOLNU	HI	56634	US	1	DLZUKVJPBL@dell.com	8395455544	2	6860756851732732	2008/04	user7028	password	69	40000	F
7029	DCGXGS	XBCSKSTVNC	2684857089 Dell Way	\N	MBNAWTN	NY	18576	US	1	XBCSKSTVNC@dell.com	2684857089	4	4259762401692569	2012/01	user7029	password	47	20000	F
7030	RYIJVK	MNUFHQSKCU	2295984236 Dell Way	\N	YDQRRIU	TX	17546	US	1	MNUFHQSKCU@dell.com	2295984236	4	1825817211531102	2010/10	user7030	password	32	40000	M
7031	OPNYCB	SHJIATKUSO	9282129396 Dell Way	\N	LJFTEBV	IN	80559	US	1	SHJIATKUSO@dell.com	9282129396	5	5939468933269382	2008/01	user7031	password	35	80000	M
7032	TPTVHB	EPBYAVQOHA	2169787450 Dell Way	\N	TAFUVNP	RI	43528	US	1	EPBYAVQOHA@dell.com	2169787450	5	5074899295810610	2009/07	user7032	password	27	20000	F
7033	WYKYDZ	ZCAVTOCUIC	3875630193 Dell Way	\N	ZCYMRSW	SD	63972	US	1	ZCAVTOCUIC@dell.com	3875630193	1	2219193841330707	2010/04	user7033	password	36	40000	F
7034	QGLQFO	QBHFDBNGBQ	6847152842 Dell Way	\N	FOIXKDN	OR	39206	US	1	QBHFDBNGBQ@dell.com	6847152842	1	6914014529902489	2012/07	user7034	password	87	60000	M
7035	KEZYVB	FAEHNKJDQX	6033047392 Dell Way	\N	LNIPBBX	OH	32503	US	1	FAEHNKJDQX@dell.com	6033047392	3	7867741452995688	2010/02	user7035	password	56	100000	F
7036	NVDOBD	TJRESUUQGI	1190884110 Dell Way	\N	YVJATBG	IL	69828	US	1	TJRESUUQGI@dell.com	1190884110	5	8256644644308836	2010/09	user7036	password	27	20000	M
7037	GQPKKY	BORWJHDRFY	6340200456 Dell Way	\N	BFRDMZU	MS	80293	US	1	BORWJHDRFY@dell.com	6340200456	1	5354658708442003	2011/02	user7037	password	19	100000	M
7038	PKEOLT	FICMMUSLVY	4253459663 Dell Way	\N	DZKCTXW	KY	96919	US	1	FICMMUSLVY@dell.com	4253459663	1	1879325898364186	2009/01	user7038	password	82	100000	F
7039	BOXUUG	XHSSZDOXGN	3620111555 Dell Way	\N	IIHFFQF	NE	71881	US	1	XHSSZDOXGN@dell.com	3620111555	5	7623623455874623	2008/12	user7039	password	30	40000	M
7040	BAHHYO	AQODELKSUT	1166667510 Dell Way	\N	ZZYPFNH	MO	55217	US	1	AQODELKSUT@dell.com	1166667510	4	5191058828029782	2008/11	user7040	password	90	40000	M
7041	HOVWOM	KSRWCJQVJQ	3677017943 Dell Way	\N	UYVIFIV	IA	98007	US	1	KSRWCJQVJQ@dell.com	3677017943	3	8703581274952740	2009/09	user7041	password	73	60000	F
7042	PLVCWO	TTRDKNMAHL	1286766809 Dell Way	\N	WQRFLXE	PA	42489	US	1	TTRDKNMAHL@dell.com	1286766809	1	1546832743566483	2011/08	user7042	password	41	60000	F
7043	EMYSGR	KKBXXCFIZV	4153609998 Dell Way	\N	AEHYIBH	MA	17404	US	1	KKBXXCFIZV@dell.com	4153609998	1	7345604084432126	2011/07	user7043	password	74	100000	F
7044	SOIJZS	LWPOBYNXYR	1034748612 Dell Way	\N	EWAFEKH	MT	60374	US	1	LWPOBYNXYR@dell.com	1034748612	1	2149314518086612	2011/01	user7044	password	31	60000	M
7045	NWPFIL	VWNTJKSBPP	2246964410 Dell Way	\N	BVTLCGA	CO	50421	US	1	VWNTJKSBPP@dell.com	2246964410	5	5383851116988808	2009/05	user7045	password	25	100000	F
7046	RBODWL	RQUCIVRXXM	8515425632 Dell Way	\N	QJPXJSJ	MS	64890	US	1	RQUCIVRXXM@dell.com	8515425632	5	9924633949995042	2012/08	user7046	password	35	80000	M
7047	VTOGLE	BNMWEKURAD	6357764776 Dell Way	\N	HYMZHZP	CO	83090	US	1	BNMWEKURAD@dell.com	6357764776	1	5169165301136673	2012/09	user7047	password	29	80000	F
7048	SXWWYJ	JVOTPFUTMS	5475508657 Dell Way	\N	GMZFCCA	OH	23942	US	1	JVOTPFUTMS@dell.com	5475508657	3	8404216150753201	2011/03	user7048	password	36	40000	F
7049	CGBLPW	AJMFDGSWMF	9512738255 Dell Way	\N	WSHZSZD	HI	56992	US	1	AJMFDGSWMF@dell.com	9512738255	5	7399766098707915	2008/03	user7049	password	76	40000	F
7050	WTCTTL	FZPMSLYXIQ	4930430007 Dell Way	\N	FHJFKOS	LA	50843	US	1	FZPMSLYXIQ@dell.com	4930430007	3	7225586039479823	2009/11	user7050	password	30	20000	M
7051	GVJSBJ	HNBTLYBBEJ	2307067790 Dell Way	\N	KJUZCDL	NC	71996	US	1	HNBTLYBBEJ@dell.com	2307067790	4	5874215112999082	2009/11	user7051	password	29	60000	M
7052	NGTWOG	YHSXJUBSFL	8750921040 Dell Way	\N	MFNQRBI	SC	86854	US	1	YHSXJUBSFL@dell.com	8750921040	1	7571473555173726	2008/09	user7052	password	49	60000	M
7053	EKMLIU	EFDYHWDSJJ	9069185482 Dell Way	\N	GZAIHVE	DE	93173	US	1	EFDYHWDSJJ@dell.com	9069185482	1	6416975408326835	2009/09	user7053	password	57	60000	F
7054	AZLUDR	XBYTFQDOWC	9157430029 Dell Way	\N	OEKJJOH	IA	77045	US	1	XBYTFQDOWC@dell.com	9157430029	3	5089786012656987	2010/02	user7054	password	59	60000	F
7055	AGERDG	PXMGBBDDPI	3855132505 Dell Way	\N	OZRDHXW	GA	55102	US	1	PXMGBBDDPI@dell.com	3855132505	4	6378081085160375	2012/02	user7055	password	66	100000	F
7056	WPMCEK	PLLQOPFWDF	5917587975 Dell Way	\N	NGNLDSY	MI	42377	US	1	PLLQOPFWDF@dell.com	5917587975	2	5123331047128886	2009/03	user7056	password	75	20000	M
7057	HEZRTK	DJZSPVWVJD	8770577085 Dell Way	\N	IUGBTRK	IN	10713	US	1	DJZSPVWVJD@dell.com	8770577085	3	3111956584267318	2011/07	user7057	password	20	100000	M
7058	AQMLTV	KMLGJGPMOK	6861724676 Dell Way	\N	SPDKALK	UT	95830	US	1	KMLGJGPMOK@dell.com	6861724676	3	5625798062887043	2011/06	user7058	password	35	80000	F
7059	SEWNOJ	YUSFKETUXJ	8742384595 Dell Way	\N	YIKKTHJ	MD	83253	US	1	YUSFKETUXJ@dell.com	8742384595	1	3619101758114994	2008/10	user7059	password	46	100000	M
7060	GINQHI	IMSNGNLQMT	4638819484 Dell Way	\N	AWNHFXC	AZ	98406	US	1	IMSNGNLQMT@dell.com	4638819484	1	8034400543663652	2011/12	user7060	password	71	20000	F
7061	GRPPAC	INIVYZISZE	9000374026 Dell Way	\N	FHJDKLC	SD	64130	US	1	INIVYZISZE@dell.com	9000374026	4	6083872692193837	2011/08	user7061	password	81	100000	F
7062	LMJNVW	WQVVZOVDUD	1985119786 Dell Way	\N	NXNYAIO	VA	94339	US	1	WQVVZOVDUD@dell.com	1985119786	3	6431226416490973	2012/06	user7062	password	87	60000	M
7063	HZSEVJ	ZRIONLIQZF	1260324545 Dell Way	\N	EXFMLDL	ND	68398	US	1	ZRIONLIQZF@dell.com	1260324545	3	1603760991245508	2012/12	user7063	password	88	40000	M
7064	RLUBKL	JYZVHPUMTS	6026412922 Dell Way	\N	SGEVRSM	OH	32164	US	1	JYZVHPUMTS@dell.com	6026412922	4	2867616571485996	2010/12	user7064	password	27	40000	F
7065	XGUJQT	IMAYHNRZGY	3773258334 Dell Way	\N	DCPWOHC	CT	97621	US	1	IMAYHNRZGY@dell.com	3773258334	4	9247439658269288	2010/11	user7065	password	39	40000	F
7066	CSUVAH	WYOJQOQORS	4160658734 Dell Way	\N	ENHLQKL	WI	16818	US	1	WYOJQOQORS@dell.com	4160658734	2	9598446257878096	2011/09	user7066	password	25	80000	F
7067	XOMEKL	SUBHKQYDUM	8598928486 Dell Way	\N	KGDVSCX	AR	52220	US	1	SUBHKQYDUM@dell.com	8598928486	4	2888738984242081	2012/05	user7067	password	66	100000	M
7068	DAJPTE	QAPHZSCLCJ	4120319476 Dell Way	\N	PXBRVCD	NV	81509	US	1	QAPHZSCLCJ@dell.com	4120319476	4	2839190009050071	2008/06	user7068	password	30	20000	F
7069	OSFSJF	HREATQDDFB	3498170257 Dell Way	\N	EXWHANB	LA	20042	US	1	HREATQDDFB@dell.com	3498170257	2	6002207499463112	2010/07	user7069	password	18	100000	F
7070	FSQKAH	PABFDELEII	2801597135 Dell Way	\N	AQJNRSQ	WV	18727	US	1	PABFDELEII@dell.com	2801597135	3	6569862914737315	2009/05	user7070	password	81	60000	F
7071	MVCTLC	VQGZCKIKLY	2710705169 Dell Way	\N	TZQMPPO	SD	10049	US	1	VQGZCKIKLY@dell.com	2710705169	1	4597274979576469	2008/06	user7071	password	54	60000	F
7072	PHSSDJ	YCLJKVUJPU	9640509434 Dell Way	\N	ZBKOQFO	SD	30344	US	1	YCLJKVUJPU@dell.com	9640509434	5	7054440321400762	2010/05	user7072	password	87	20000	M
7073	RUVATY	LCJGXSWRRX	2457167551 Dell Way	\N	BGOGUJM	PA	31432	US	1	LCJGXSWRRX@dell.com	2457167551	2	6839324974920601	2008/04	user7073	password	44	80000	F
7074	FUUDFW	MMUEJLWGNC	1487716890 Dell Way	\N	UUWEHQK	MI	86303	US	1	MMUEJLWGNC@dell.com	1487716890	3	2088407569564879	2010/04	user7074	password	30	80000	F
7075	YTJVGV	PLEBHLPKGJ	8913372206 Dell Way	\N	HKQXVCT	UT	66897	US	1	PLEBHLPKGJ@dell.com	8913372206	2	9674679499585182	2008/12	user7075	password	24	100000	M
7076	LVXHLJ	LMQXCBELIO	8006748762 Dell Way	\N	CFKEZHV	UT	61561	US	1	LMQXCBELIO@dell.com	8006748762	5	5407532772049308	2012/11	user7076	password	29	40000	M
7077	COELAR	CYTDCFLRIR	4591483910 Dell Way	\N	BMRIINX	CA	50728	US	1	CYTDCFLRIR@dell.com	4591483910	5	4282967864070088	2010/03	user7077	password	25	80000	M
7078	HCVYET	SIWXUNFLOS	5380809135 Dell Way	\N	DXBRVDD	HI	18052	US	1	SIWXUNFLOS@dell.com	5380809135	4	4049322241917253	2010/06	user7078	password	29	100000	M
7079	ZUSTMA	PKUDQGSJKP	9683147158 Dell Way	\N	KBLNEQQ	NV	49193	US	1	PKUDQGSJKP@dell.com	9683147158	2	8786694458220155	2008/02	user7079	password	45	20000	M
7080	CWKCMV	XPLDHVNXFP	3697243865 Dell Way	\N	JTTZJLL	KY	71508	US	1	XPLDHVNXFP@dell.com	3697243865	3	8157209829427303	2011/07	user7080	password	69	80000	F
7081	CWXYTN	JXVELSKABD	7342928899 Dell Way	\N	UBNFNWX	SC	39353	US	1	JXVELSKABD@dell.com	7342928899	3	9030391511972996	2010/03	user7081	password	41	60000	F
7082	FLWTVU	OAFHLGIPAK	2718336124 Dell Way	\N	CGXZESH	UT	27611	US	1	OAFHLGIPAK@dell.com	2718336124	2	4988743762485683	2010/10	user7082	password	58	80000	F
7083	KMCFAD	KHOQQDRBGY	3746043581 Dell Way	\N	YFCRNZW	OH	33963	US	1	KHOQQDRBGY@dell.com	3746043581	2	1706889849156141	2012/12	user7083	password	43	40000	F
7084	LMMOWT	DNKGFLMDKR	6060284181 Dell Way	\N	GBEFYWM	IA	18286	US	1	DNKGFLMDKR@dell.com	6060284181	1	1405251175630837	2012/05	user7084	password	53	40000	M
7085	YYSSBG	DHLOUOZMUB	7177422542 Dell Way	\N	RAZONFQ	AZ	37747	US	1	DHLOUOZMUB@dell.com	7177422542	5	7161466785240919	2008/05	user7085	password	56	20000	F
7086	GVINYQ	YNKNMXINOI	7276313141 Dell Way	\N	MCWSTXA	MI	90596	US	1	YNKNMXINOI@dell.com	7276313141	4	3082852315623313	2009/09	user7086	password	54	60000	M
7087	VZMLYZ	WLMTTZICMK	9863686646 Dell Way	\N	YEEWFPT	VA	27739	US	1	WLMTTZICMK@dell.com	9863686646	1	9200774648692460	2010/08	user7087	password	50	40000	M
7088	YTNXPZ	KJSJRVWCTA	9625801403 Dell Way	\N	GQFWJDB	LA	31576	US	1	KJSJRVWCTA@dell.com	9625801403	5	8665285578928889	2010/02	user7088	password	51	40000	M
7089	ZGNYQW	RAONWQGXXX	3945215496 Dell Way	\N	DTGGUQM	PA	51455	US	1	RAONWQGXXX@dell.com	3945215496	1	6439238124527038	2011/06	user7089	password	54	80000	M
7090	ASKWKK	KXHBEEYCHR	1211887341 Dell Way	\N	INMYAFK	KY	43114	US	1	KXHBEEYCHR@dell.com	1211887341	1	8764434529002757	2010/11	user7090	password	63	60000	M
7091	AKALVY	SWDXVFEMOS	4628995965 Dell Way	\N	YNSEYBO	WI	25690	US	1	SWDXVFEMOS@dell.com	4628995965	3	1522163482382893	2008/12	user7091	password	66	20000	F
7092	SMFQFB	UCWZHJOZIB	1119810324 Dell Way	\N	SNZUBYY	MI	46544	US	1	UCWZHJOZIB@dell.com	1119810324	3	4630450191907585	2011/07	user7092	password	76	40000	M
7093	AAEBUG	YUOIINRJGE	1836109715 Dell Way	\N	JBFHZQR	AK	20158	US	1	YUOIINRJGE@dell.com	1836109715	4	6576133940368891	2012/01	user7093	password	61	100000	F
7094	UZWBXR	PGZDXJJBSK	6751198378 Dell Way	\N	GZKXRKA	RI	19938	US	1	PGZDXJJBSK@dell.com	6751198378	4	2608114844188094	2009/07	user7094	password	37	20000	M
7095	DBLVQR	UTPDDRWOXW	7158871978 Dell Way	\N	ZVNKVHN	MO	97372	US	1	UTPDDRWOXW@dell.com	7158871978	4	5737531120423228	2012/09	user7095	password	21	20000	M
7096	MXLESF	UWJLSYJOXE	9073717783 Dell Way	\N	CHAKUMJ	MO	29130	US	1	UWJLSYJOXE@dell.com	9073717783	3	9588198605924846	2012/07	user7096	password	73	60000	F
7097	FQDLKZ	UVSSEGQJJY	1159359140 Dell Way	\N	JTSWDFB	AK	68991	US	1	UVSSEGQJJY@dell.com	1159359140	5	2701757583767175	2011/05	user7097	password	63	100000	F
7098	TKKTFG	LYLSOUBMDU	3486899740 Dell Way	\N	FZXLBXC	AZ	89368	US	1	LYLSOUBMDU@dell.com	3486899740	5	3518761232495308	2012/11	user7098	password	39	80000	F
7099	SKMZWK	KOZEPLIKRI	4408070669 Dell Way	\N	HCJFELC	MN	35608	US	1	KOZEPLIKRI@dell.com	4408070669	2	2088210775051266	2011/01	user7099	password	45	40000	F
7100	VJHGTW	FYLRGVIODK	8030625694 Dell Way	\N	YJPJLBR	TN	47064	US	1	FYLRGVIODK@dell.com	8030625694	3	4957265206612647	2008/11	user7100	password	82	100000	F
7101	EGAALZ	MCGIKVMVTV	3900588182 Dell Way	\N	KDHMUCW	NE	64762	US	1	MCGIKVMVTV@dell.com	3900588182	4	5617637932300568	2009/09	user7101	password	75	40000	M
7102	VLKUXN	BGYWSTQNEU	1252160517 Dell Way	\N	URPXOEN	UT	90512	US	1	BGYWSTQNEU@dell.com	1252160517	1	6662968223448843	2012/06	user7102	password	62	80000	M
7103	ALUOMB	MJTGZHLUCC	1316828262 Dell Way	\N	JAQNNNK	ND	61374	US	1	MJTGZHLUCC@dell.com	1316828262	2	1242347437422722	2011/01	user7103	password	84	80000	F
7104	SFXTSH	NYHVKBYNKY	3172350359 Dell Way	\N	DYMQIAF	LA	46329	US	1	NYHVKBYNKY@dell.com	3172350359	1	4639014711603522	2008/09	user7104	password	79	100000	M
7105	TQPBDO	IZYKXLUWPS	2636048374 Dell Way	\N	IGBJLKU	OH	47864	US	1	IZYKXLUWPS@dell.com	2636048374	5	1828417671844363	2008/09	user7105	password	89	80000	F
7106	OVMDEL	BOJNIFCBOI	1344967635 Dell Way	\N	CYUNSMY	VA	38394	US	1	BOJNIFCBOI@dell.com	1344967635	5	1155787351541221	2008/09	user7106	password	42	60000	M
7107	VSRGUF	QHOVKQKSSI	3916267890 Dell Way	\N	NGBZFYH	IA	86207	US	1	QHOVKQKSSI@dell.com	3916267890	2	5895885027479381	2011/11	user7107	password	23	60000	M
7108	TTIZJP	NFZDPSWYGD	3665163781 Dell Way	\N	ZFIXNOT	TX	82959	US	1	NFZDPSWYGD@dell.com	3665163781	3	6853594775311649	2009/01	user7108	password	32	20000	M
7109	NCCCPH	CTXVQVBTUH	1817718792 Dell Way	\N	BSVQLRL	PA	28157	US	1	CTXVQVBTUH@dell.com	1817718792	1	2832923999987542	2009/03	user7109	password	86	80000	F
7110	BXYIZS	GVIBWBWEDP	1558490617 Dell Way	\N	ZUBRFUW	IN	93203	US	1	GVIBWBWEDP@dell.com	1558490617	3	2456853628158569	2008/05	user7110	password	53	20000	F
7111	KKHDQC	LSZNPDREDL	2080311992 Dell Way	\N	GURAQZY	OH	61671	US	1	LSZNPDREDL@dell.com	2080311992	4	9660025828983636	2011/10	user7111	password	36	20000	F
7112	NDUQPN	QCCTUHXFNR	4662828930 Dell Way	\N	XOHWNZL	NM	72874	US	1	QCCTUHXFNR@dell.com	4662828930	2	5089224161114544	2011/04	user7112	password	62	20000	F
7113	KVAXMC	AGXIDCWUAL	3064844433 Dell Way	\N	CWYBIPU	OR	86147	US	1	AGXIDCWUAL@dell.com	3064844433	2	2089321758598089	2012/07	user7113	password	57	40000	F
7114	OEXRFD	OOGRKARVCO	4276116270 Dell Way	\N	UEWKYPG	FL	98227	US	1	OOGRKARVCO@dell.com	4276116270	1	6054031122010202	2012/04	user7114	password	89	60000	F
7115	WCQZRE	GIPGALJOFO	5964016275 Dell Way	\N	KQNAWSZ	HI	74661	US	1	GIPGALJOFO@dell.com	5964016275	1	9879078239202500	2010/08	user7115	password	48	60000	M
7116	BKJGQS	VXSGGGMURD	7383943043 Dell Way	\N	IRZARFS	HI	42486	US	1	VXSGGGMURD@dell.com	7383943043	4	9578028717078268	2008/02	user7116	password	66	20000	M
7117	ALETGC	LNISZDJDLB	6749647738 Dell Way	\N	CLSIEYR	VA	71248	US	1	LNISZDJDLB@dell.com	6749647738	1	8561232842504979	2009/03	user7117	password	47	40000	M
7118	PBXRNK	AFKDONPPPB	7880361602 Dell Way	\N	IYGGQDY	ID	23534	US	1	AFKDONPPPB@dell.com	7880361602	3	4221504080574960	2008/11	user7118	password	90	80000	M
7119	WKMHLR	RPGEEWUGES	2100408782 Dell Way	\N	MKJPIQT	CO	25974	US	1	RPGEEWUGES@dell.com	2100408782	2	1640188696328550	2008/01	user7119	password	20	100000	F
7120	NGWEYL	LCQHXWMQJW	8519572302 Dell Way	\N	ZZFPSIT	TX	64039	US	1	LCQHXWMQJW@dell.com	8519572302	5	6584332179278136	2012/12	user7120	password	22	40000	F
7121	YODJZG	AHDWTTFQSE	4668196429 Dell Way	\N	WIXEBUU	VT	76527	US	1	AHDWTTFQSE@dell.com	4668196429	4	7245420803315938	2010/02	user7121	password	84	40000	M
7122	BUSHUZ	KQTEWJXBFF	2699333780 Dell Way	\N	ZKHTFEM	NH	95947	US	1	KQTEWJXBFF@dell.com	2699333780	1	1963414005935192	2008/06	user7122	password	77	20000	F
7123	NLANWR	GAOQXPWCPG	6575856260 Dell Way	\N	JIMOVBN	AL	23645	US	1	GAOQXPWCPG@dell.com	6575856260	1	6630166387185455	2010/04	user7123	password	81	100000	M
7124	XMOOTO	CJMSFPHMZQ	8316616549 Dell Way	\N	YNMABNE	NV	66663	US	1	CJMSFPHMZQ@dell.com	8316616549	1	9080200979951770	2011/01	user7124	password	61	60000	M
7125	DDHSGR	FZXUHJUXII	4856809295 Dell Way	\N	KJJXOAN	MA	20785	US	1	FZXUHJUXII@dell.com	4856809295	1	2695284026209265	2008/08	user7125	password	72	20000	M
7126	AXBSDA	PYHZSFIAPR	7253436572 Dell Way	\N	JNGKAQN	MN	72258	US	1	PYHZSFIAPR@dell.com	7253436572	3	4029914297163487	2010/09	user7126	password	27	60000	M
7127	EESFTQ	MSISAIISSV	6644892628 Dell Way	\N	ZCWPPIH	IN	82590	US	1	MSISAIISSV@dell.com	6644892628	4	5303148020058871	2011/03	user7127	password	22	100000	F
7128	TDDJQW	SIWBRPTMOV	9295227746 Dell Way	\N	IELQMTL	CA	53040	US	1	SIWBRPTMOV@dell.com	9295227746	5	7132100142072887	2012/10	user7128	password	21	80000	M
7129	ECOAUX	XVONPBCLJG	8107206098 Dell Way	\N	XZSQLVC	LA	69100	US	1	XVONPBCLJG@dell.com	8107206098	2	4970289581920952	2012/01	user7129	password	44	20000	F
7130	YBZVZV	KMKLOWVVTV	5128140172 Dell Way	\N	OJGJMPA	ID	96037	US	1	KMKLOWVVTV@dell.com	5128140172	1	1250647156033664	2012/02	user7130	password	32	80000	F
7131	EPDAAQ	KMFHHAACPJ	9427805138 Dell Way	\N	IYWYYDX	ME	30293	US	1	KMFHHAACPJ@dell.com	9427805138	2	4200593935325742	2008/01	user7131	password	57	40000	M
7132	RIQITC	NAJOALDKUB	9703179634 Dell Way	\N	GTAKQLP	NE	71823	US	1	NAJOALDKUB@dell.com	9703179634	4	7197110556066037	2010/01	user7132	password	39	20000	F
7133	XNDZAE	JPFUSPPUWI	6580572233 Dell Way	\N	UGZGWOY	TX	34892	US	1	JPFUSPPUWI@dell.com	6580572233	2	3917787474580109	2012/07	user7133	password	69	100000	F
7134	VVCZER	FZJUODRXYY	1160614460 Dell Way	\N	WEVKDRS	OR	12218	US	1	FZJUODRXYY@dell.com	1160614460	4	6111972381360829	2011/06	user7134	password	63	60000	F
7135	SOMJTL	TOAWGXVEUZ	3554068486 Dell Way	\N	AEDRWWS	VA	55226	US	1	TOAWGXVEUZ@dell.com	3554068486	4	9792655302211644	2012/03	user7135	password	37	80000	M
7136	TZMFSA	FPGDKLXKMC	8649804509 Dell Way	\N	NEZJWWW	DE	54300	US	1	FPGDKLXKMC@dell.com	8649804509	1	7050380119122565	2008/09	user7136	password	47	100000	M
7137	WBJXGY	EKJQHTCJHG	4297742422 Dell Way	\N	IQDFNHS	MA	41078	US	1	EKJQHTCJHG@dell.com	4297742422	3	1198216281365603	2011/05	user7137	password	67	80000	F
7138	BORATB	JJJDLSKSBB	5246258702 Dell Way	\N	VGPCYYL	KS	50709	US	1	JJJDLSKSBB@dell.com	5246258702	1	8305210170801730	2008/09	user7138	password	34	40000	F
7139	XFBZOK	ISWBDOCEJJ	9855684645 Dell Way	\N	TMISYQE	MD	74342	US	1	ISWBDOCEJJ@dell.com	9855684645	3	5088645751122385	2009/10	user7139	password	73	20000	M
7140	UCNFLG	BNJPQOZZHL	1933220500 Dell Way	\N	HAJYFUQ	FL	39728	US	1	BNJPQOZZHL@dell.com	1933220500	2	1731781867798417	2012/07	user7140	password	20	80000	M
7141	OWCVXP	ENFSMFAYNB	5445040225 Dell Way	\N	HLGCCKK	GA	82734	US	1	ENFSMFAYNB@dell.com	5445040225	1	3922813372686505	2010/09	user7141	password	87	20000	M
7142	AYMQCZ	VVLBWJOXRA	7187945799 Dell Way	\N	DTDOEIJ	NV	44298	US	1	VVLBWJOXRA@dell.com	7187945799	1	1915350199211388	2011/04	user7142	password	67	80000	F
7143	DHJDDE	PFAYUYQUBK	7368841398 Dell Way	\N	XQOFZFP	NY	47724	US	1	PFAYUYQUBK@dell.com	7368841398	2	7557265047449619	2009/12	user7143	password	88	60000	F
7144	IRLNGQ	NFKMVFOFDE	2251193445 Dell Way	\N	UIEZYVK	NV	23807	US	1	NFKMVFOFDE@dell.com	2251193445	1	2313469008076936	2008/07	user7144	password	50	60000	F
7145	XYMNMS	YYNEMTHQNQ	9517417624 Dell Way	\N	VMOQXFU	AR	33143	US	1	YYNEMTHQNQ@dell.com	9517417624	1	8504713246133179	2009/07	user7145	password	23	40000	M
7146	OUZGTX	UXKNEBAUWN	7126137922 Dell Way	\N	JNLPHMW	IA	68003	US	1	UXKNEBAUWN@dell.com	7126137922	4	3042710413224995	2011/11	user7146	password	71	40000	M
7147	SPMQKK	AXOBYJYMTL	3462689812 Dell Way	\N	XITKEAB	UT	67735	US	1	AXOBYJYMTL@dell.com	3462689812	4	5991492816247047	2008/12	user7147	password	37	80000	M
7148	TJYDJW	SLUCKHVVEE	7963728556 Dell Way	\N	PPJPQGF	VT	89618	US	1	SLUCKHVVEE@dell.com	7963728556	5	8632219716906548	2008/08	user7148	password	47	80000	M
7149	JXJFQV	ASFHOBLTQB	1972859597 Dell Way	\N	DFRJLPG	GA	54885	US	1	ASFHOBLTQB@dell.com	1972859597	2	2276484535075724	2010/01	user7149	password	28	100000	M
7150	NCOJCH	PJVQVPGWSM	7836473748 Dell Way	\N	NBXDICQ	MI	41575	US	1	PJVQVPGWSM@dell.com	7836473748	5	4472654871642590	2012/10	user7150	password	42	60000	M
7151	XUZFJJ	AZEPGAISOK	5234399729 Dell Way	\N	QRSTIEC	AZ	21655	US	1	AZEPGAISOK@dell.com	5234399729	5	9651056505274028	2012/05	user7151	password	81	80000	F
7152	WXNFYN	KOTLWMZGDR	3028070970 Dell Way	\N	ZWZDYBG	MD	12652	US	1	KOTLWMZGDR@dell.com	3028070970	2	4748907828237862	2008/12	user7152	password	60	100000	M
7153	CEUPPI	JAEWALZRKV	2713239399 Dell Way	\N	RNTTUEU	AL	43284	US	1	JAEWALZRKV@dell.com	2713239399	1	3714924412779510	2011/02	user7153	password	28	100000	F
7154	YMVGVW	LRWWQNHLFV	1249119109 Dell Way	\N	FZPJTQS	WA	77547	US	1	LRWWQNHLFV@dell.com	1249119109	4	8506556476932020	2008/07	user7154	password	25	20000	F
7155	YJWUUN	QREEYPKUUJ	6351978522 Dell Way	\N	JECAXAT	VT	74574	US	1	QREEYPKUUJ@dell.com	6351978522	1	3494079825934023	2011/03	user7155	password	40	80000	M
7156	DLJRCA	VGZLRTGADK	2184448019 Dell Way	\N	CEHDXFW	MT	36702	US	1	VGZLRTGADK@dell.com	2184448019	2	5360838694032282	2010/11	user7156	password	20	60000	F
7157	JGJKCQ	KNHETIIELM	4988926555 Dell Way	\N	LOKRKXY	ND	19472	US	1	KNHETIIELM@dell.com	4988926555	5	9602448226884008	2010/07	user7157	password	35	100000	M
7158	QGXGRL	OWEWEJHQUW	9875352969 Dell Way	\N	AMHYKVA	UT	82660	US	1	OWEWEJHQUW@dell.com	9875352969	2	4382889357395470	2009/03	user7158	password	32	100000	F
7159	CCDNQZ	SNDBUUWQVI	9317079338 Dell Way	\N	XTTTTPO	PA	95425	US	1	SNDBUUWQVI@dell.com	9317079338	5	2259286508429795	2008/10	user7159	password	61	40000	M
7160	STPSMC	WOWQKNLTLE	2736524439 Dell Way	\N	MEYCTSB	NV	72118	US	1	WOWQKNLTLE@dell.com	2736524439	4	5710402851924301	2011/01	user7160	password	51	60000	M
7161	BGHDCV	ASGNEZZJME	3166113527 Dell Way	\N	IPXAQOS	SD	41471	US	1	ASGNEZZJME@dell.com	3166113527	4	4295532885938883	2011/02	user7161	password	28	80000	F
7162	KWLGWE	MKJLKSYOBN	7818098977 Dell Way	\N	MBDBUZK	AL	61857	US	1	MKJLKSYOBN@dell.com	7818098977	4	7397230183240027	2012/06	user7162	password	23	40000	F
7163	NOFSBQ	BNAULPWYBY	4004611657 Dell Way	\N	CCSBNTQ	ID	54017	US	1	BNAULPWYBY@dell.com	4004611657	1	9640559324063362	2010/06	user7163	password	39	100000	F
7164	NQCDSP	ENBTJZVHBY	3109766405 Dell Way	\N	ADLUTSH	AZ	87795	US	1	ENBTJZVHBY@dell.com	3109766405	3	4226333213504404	2010/06	user7164	password	48	20000	F
7165	NEVDII	ECSEXAGWBJ	2841215495 Dell Way	\N	HVCZCEV	KY	70601	US	1	ECSEXAGWBJ@dell.com	2841215495	5	1923285652883351	2011/12	user7165	password	31	20000	F
7166	ZHLILN	BQLBWHDGOZ	3731603067 Dell Way	\N	IOBNKKF	NH	36990	US	1	BQLBWHDGOZ@dell.com	3731603067	2	2971032245550304	2010/05	user7166	password	40	60000	M
7167	TVDHWT	SYQZBWOAFC	1250771199 Dell Way	\N	CSNNYCV	HI	39786	US	1	SYQZBWOAFC@dell.com	1250771199	4	7345326236914844	2009/03	user7167	password	44	20000	F
7168	MJWFBU	WBWSPWXSYQ	4294833432 Dell Way	\N	FLOIGUR	IN	55568	US	1	WBWSPWXSYQ@dell.com	4294833432	4	7358792569022626	2011/09	user7168	password	70	40000	F
7169	PLDKHF	GZVCXNBNTN	1752352759 Dell Way	\N	CCUWTBJ	CO	73343	US	1	GZVCXNBNTN@dell.com	1752352759	5	4875608437694609	2012/01	user7169	password	55	40000	F
7170	RUUWAT	RCRFDEZQHB	6623824563 Dell Way	\N	LDUMNXF	NH	78526	US	1	RCRFDEZQHB@dell.com	6623824563	3	8310846774373204	2008/10	user7170	password	39	100000	M
7171	BRPVJR	NOVSNMZPXD	9024623978 Dell Way	\N	KKQIPGC	HI	68367	US	1	NOVSNMZPXD@dell.com	9024623978	2	4999425123445690	2008/02	user7171	password	19	40000	M
7172	PCEHQT	CIHPHXNKHX	4409622180 Dell Way	\N	BPMHRSY	NE	16506	US	1	CIHPHXNKHX@dell.com	4409622180	4	3137444480787963	2009/01	user7172	password	23	100000	F
7173	GGUAJC	IYJFLUMJVC	8906918530 Dell Way	\N	WDUOBJQ	ME	21845	US	1	IYJFLUMJVC@dell.com	8906918530	5	2520660828333348	2012/10	user7173	password	41	40000	F
7174	CGLEOK	OUWJHFEJCH	8437289803 Dell Way	\N	EQJNHUR	DE	64607	US	1	OUWJHFEJCH@dell.com	8437289803	1	4757198406383395	2008/05	user7174	password	53	40000	M
7175	YKEIZY	FIFKNPMUTD	9671312539 Dell Way	\N	EHLYYPO	PA	75042	US	1	FIFKNPMUTD@dell.com	9671312539	5	1596485340036451	2010/02	user7175	password	65	40000	M
7176	VSNTXW	ZIJOVEHZIO	8065655227 Dell Way	\N	KGNZVGS	RI	25109	US	1	ZIJOVEHZIO@dell.com	8065655227	2	3767466783523560	2010/08	user7176	password	80	40000	F
7177	KAGGZO	QNJUVIDKTK	6718666829 Dell Way	\N	XSFELZI	HI	28445	US	1	QNJUVIDKTK@dell.com	6718666829	4	8362664005719126	2010/12	user7177	password	28	100000	M
7178	JDXYTL	IOGQRQJBOC	3269304801 Dell Way	\N	GSOFAUL	NY	52219	US	1	IOGQRQJBOC@dell.com	3269304801	1	4624470714014024	2009/01	user7178	password	43	80000	F
7179	GSZSAN	YRFPBGDENW	4548187428 Dell Way	\N	STWNEOZ	ME	74166	US	1	YRFPBGDENW@dell.com	4548187428	5	7938628436066211	2011/08	user7179	password	89	20000	F
7180	YSIMRA	RGBXKFKGYD	2542735836 Dell Way	\N	DMIRMSK	UT	59043	US	1	RGBXKFKGYD@dell.com	2542735836	4	2236776178237051	2008/08	user7180	password	50	20000	F
7181	UOZUFG	VDQBNXARBM	4594566116 Dell Way	\N	ZSZSDVG	IN	49077	US	1	VDQBNXARBM@dell.com	4594566116	3	1385040877386927	2012/07	user7181	password	43	80000	F
7182	IKHOFL	FHZCHQDUQW	1563264429 Dell Way	\N	TIZPPHA	AK	76659	US	1	FHZCHQDUQW@dell.com	1563264429	5	3485421705525368	2010/06	user7182	password	44	80000	M
7183	RHBCNJ	BPQSTLIQFR	9314261866 Dell Way	\N	PUHXUHQ	UT	22547	US	1	BPQSTLIQFR@dell.com	9314261866	2	6410756903700531	2009/01	user7183	password	50	100000	F
7184	NBVWDL	NVEYEUDVKY	2411136758 Dell Way	\N	DISKZPO	VA	88587	US	1	NVEYEUDVKY@dell.com	2411136758	1	9072430653963240	2011/02	user7184	password	34	20000	F
7185	BZIMNE	RMIMQEXOHF	6765987898 Dell Way	\N	HSEWHBT	ME	32353	US	1	RMIMQEXOHF@dell.com	6765987898	1	4547414486762136	2012/02	user7185	password	62	100000	F
7186	YKRDCD	LOTQLHYRPQ	5946799607 Dell Way	\N	VLXXFJE	TN	45045	US	1	LOTQLHYRPQ@dell.com	5946799607	4	5984018442686648	2008/08	user7186	password	70	20000	F
7187	KFDNRR	HHDPFVEWQQ	1817746758 Dell Way	\N	UOVDSRN	ID	43924	US	1	HHDPFVEWQQ@dell.com	1817746758	3	9999110273551196	2012/07	user7187	password	20	20000	M
7188	ESKWAS	ZPXUUULLPA	3819072015 Dell Way	\N	GTSYHZI	LA	46397	US	1	ZPXUUULLPA@dell.com	3819072015	1	9291834345553072	2009/05	user7188	password	65	60000	F
7189	BJCTJS	RDNMPYBPFU	6849343536 Dell Way	\N	IDCILLS	RI	65627	US	1	RDNMPYBPFU@dell.com	6849343536	1	9873358093202116	2009/08	user7189	password	23	40000	M
7190	ECIXUM	KGBJIROCAS	3119054321 Dell Way	\N	EJEQBYG	OR	14632	US	1	KGBJIROCAS@dell.com	3119054321	1	7062135809566826	2009/05	user7190	password	65	60000	F
7191	ZKHLVN	NFVFTYFMDO	3741952907 Dell Way	\N	QTQPAJQ	IA	46255	US	1	NFVFTYFMDO@dell.com	3741952907	3	8115125345531852	2012/01	user7191	password	38	100000	F
7192	OJHCWN	XCGWHTZWKT	1780786966 Dell Way	\N	NZTXPAH	VT	61663	US	1	XCGWHTZWKT@dell.com	1780786966	5	6733852654229850	2009/10	user7192	password	26	100000	F
7193	KAAXYC	EUKYUHIOUH	5918087238 Dell Way	\N	ISXIZUX	CA	68717	US	1	EUKYUHIOUH@dell.com	5918087238	3	4917994074989110	2011/05	user7193	password	60	20000	F
7194	PZJSEE	DCYKLNFSVX	5345331192 Dell Way	\N	PEXKCZB	NM	49553	US	1	DCYKLNFSVX@dell.com	5345331192	2	8448775873519481	2008/05	user7194	password	35	80000	F
7195	PKNTNQ	SYBFETBBJF	3042182588 Dell Way	\N	ZTIYUYK	IL	30120	US	1	SYBFETBBJF@dell.com	3042182588	2	6225627346429974	2010/01	user7195	password	85	20000	F
7196	LUYBNX	DSBWUCGACA	1652324149 Dell Way	\N	IBVGLCM	NY	50806	US	1	DSBWUCGACA@dell.com	1652324149	1	5376316343434155	2012/03	user7196	password	84	60000	M
7197	WNNTQG	VNAYUBAUJB	6678887439 Dell Way	\N	PQNRDED	GA	38925	US	1	VNAYUBAUJB@dell.com	6678887439	2	5624957571737469	2010/08	user7197	password	55	60000	F
7198	AEVGZJ	HYDIYXRAMI	5765621006 Dell Way	\N	NELSIRA	WV	87254	US	1	HYDIYXRAMI@dell.com	5765621006	3	5586858879774809	2008/12	user7198	password	67	20000	F
7199	NHCWOA	ZWZWOZJXMO	4255282127 Dell Way	\N	IEXZFWW	OR	45015	US	1	ZWZWOZJXMO@dell.com	4255282127	4	3895990331191570	2008/10	user7199	password	50	60000	F
7200	OKRPJO	OGDOQAAFJF	7302016691 Dell Way	\N	CJKZFDJ	ND	92269	US	1	OGDOQAAFJF@dell.com	7302016691	4	7594529182650150	2008/02	user7200	password	80	80000	M
7201	NHYCWE	GKVGLAQQDZ	8726077552 Dell Way	\N	BDEFMTD	GA	42017	US	1	GKVGLAQQDZ@dell.com	8726077552	2	5615613908041269	2011/01	user7201	password	22	40000	F
7202	ZJEEPO	ZWZZMQCLRG	3235817995 Dell Way	\N	QXSJAYT	VA	33499	US	1	ZWZZMQCLRG@dell.com	3235817995	3	3588337424211204	2009/11	user7202	password	61	40000	F
7203	TMUHLR	HLDXOPPUFM	9788345956 Dell Way	\N	NPNLIKR	NH	99425	US	1	HLDXOPPUFM@dell.com	9788345956	5	8507775272708387	2010/03	user7203	password	20	40000	M
7204	VQCMXO	PUCFKWLWJB	6609947623 Dell Way	\N	KUJUMZU	MI	89149	US	1	PUCFKWLWJB@dell.com	6609947623	1	1787994623649865	2011/05	user7204	password	73	60000	M
7205	WYWKOR	MUBIFYSGIM	6129984709 Dell Way	\N	QDYPXKM	NC	47439	US	1	MUBIFYSGIM@dell.com	6129984709	1	7814668478444219	2009/08	user7205	password	70	40000	M
7206	PQEGDY	HLEGEKOQBR	2440182031 Dell Way	\N	PQPZDDK	OH	38871	US	1	HLEGEKOQBR@dell.com	2440182031	1	9878441780339928	2012/03	user7206	password	62	60000	M
7207	USZTAL	XGPIUGJMVA	5704274574 Dell Way	\N	CVDFFVN	LA	87215	US	1	XGPIUGJMVA@dell.com	5704274574	2	1840620038099587	2008/09	user7207	password	87	100000	F
7208	YRLJPR	YXMEHZAHBV	2914335526 Dell Way	\N	LHAGVKD	KS	68032	US	1	YXMEHZAHBV@dell.com	2914335526	3	4248615405056626	2008/05	user7208	password	75	20000	F
7209	FLQXKO	KPWJPDLKOS	8359840511 Dell Way	\N	KVNVYWL	DE	37969	US	1	KPWJPDLKOS@dell.com	8359840511	2	7243687681388111	2011/06	user7209	password	72	100000	M
7210	KTGYDW	VNLYYVNRGJ	1218318880 Dell Way	\N	EBIANMI	KY	84311	US	1	VNLYYVNRGJ@dell.com	1218318880	5	3225956297013908	2011/10	user7210	password	26	20000	M
7211	JDRFYE	RXDMLUTUYU	7134475820 Dell Way	\N	DZIPHQL	KS	62952	US	1	RXDMLUTUYU@dell.com	7134475820	1	4266449727118015	2011/04	user7211	password	82	20000	F
7212	OKISBG	WORQHLPCOO	1137017148 Dell Way	\N	KEWBPFQ	IN	36898	US	1	WORQHLPCOO@dell.com	1137017148	1	6144044514279813	2012/04	user7212	password	89	60000	M
7213	IETOAI	FRQRGSGVDL	7776550164 Dell Way	\N	RFBWWIE	UT	48967	US	1	FRQRGSGVDL@dell.com	7776550164	4	7365492303855718	2011/03	user7213	password	46	20000	F
7214	DPKMVB	CNIVTDZEVE	7287978399 Dell Way	\N	FSBOXYZ	NV	73034	US	1	CNIVTDZEVE@dell.com	7287978399	2	9271746473386884	2008/06	user7214	password	40	40000	F
7215	SSWUVJ	DRCHQHCVMV	4724275799 Dell Way	\N	WBSUBJM	OR	76266	US	1	DRCHQHCVMV@dell.com	4724275799	5	2431637267582118	2011/01	user7215	password	31	60000	M
7216	AGQKJH	MQXTTSGOPH	5642751652 Dell Way	\N	GKJQWCJ	IN	93013	US	1	MQXTTSGOPH@dell.com	5642751652	1	9986481561791152	2011/06	user7216	password	75	80000	M
7217	KDBRPR	PJLHPZXXGH	3456687577 Dell Way	\N	GWEJFLH	OR	52488	US	1	PJLHPZXXGH@dell.com	3456687577	3	9371963114477696	2008/02	user7217	password	63	60000	F
7218	REXJTG	UBWUYUAFBW	3157733732 Dell Way	\N	JKBVRUI	WI	30788	US	1	UBWUYUAFBW@dell.com	3157733732	1	4560345299076289	2012/06	user7218	password	67	60000	M
7219	OYJVSK	RNJMNONJYX	8912820840 Dell Way	\N	LUPGCNM	KY	58034	US	1	RNJMNONJYX@dell.com	8912820840	2	1163270605728030	2010/10	user7219	password	65	20000	M
7220	AYKLQX	UCLJQUINGD	2728251903 Dell Way	\N	DNFQZOE	UT	78654	US	1	UCLJQUINGD@dell.com	2728251903	3	5687707830686123	2012/07	user7220	password	33	100000	M
7221	QIEODH	ZNXUVLAYON	1006913154 Dell Way	\N	EENSJKM	ND	84309	US	1	ZNXUVLAYON@dell.com	1006913154	3	4494285889901221	2009/04	user7221	password	84	100000	M
7222	BJTIIG	GCBRDAFREK	8249635650 Dell Way	\N	FXUPJIK	MA	77618	US	1	GCBRDAFREK@dell.com	8249635650	3	1344399690162390	2011/05	user7222	password	65	80000	M
7223	KDDQJF	SBJSGAXRFU	6500866281 Dell Way	\N	MVEVGOO	AR	21624	US	1	SBJSGAXRFU@dell.com	6500866281	4	5861942728515715	2009/07	user7223	password	41	80000	M
7224	LHARAB	ATIBQAHLMC	8564426913 Dell Way	\N	QIJEXKH	MS	23480	US	1	ATIBQAHLMC@dell.com	8564426913	4	7168651861604304	2008/06	user7224	password	42	60000	M
7225	JGTKHM	TIDTQPGTFP	3822429252 Dell Way	\N	CKMMRZQ	MT	75910	US	1	TIDTQPGTFP@dell.com	3822429252	4	2423983525484800	2011/04	user7225	password	82	20000	M
7226	QLVDEE	GYUWFNBUPL	2015116451 Dell Way	\N	GCDFSRY	AL	41853	US	1	GYUWFNBUPL@dell.com	2015116451	4	6731528465636075	2012/09	user7226	password	30	80000	F
7227	ZTIEAH	YWMMYHBJNE	2604409816 Dell Way	\N	NTWESXO	SD	62299	US	1	YWMMYHBJNE@dell.com	2604409816	5	3523187342565507	2009/06	user7227	password	48	40000	F
7228	TNFALB	MXZTZJHDXA	8013021858 Dell Way	\N	ACSXQOM	SC	41972	US	1	MXZTZJHDXA@dell.com	8013021858	1	8180464925244451	2008/07	user7228	password	90	100000	F
7229	EYMGLK	GEJPMNNMOP	9226143237 Dell Way	\N	FMFTZAD	OR	24566	US	1	GEJPMNNMOP@dell.com	9226143237	5	7022589219268412	2012/11	user7229	password	68	20000	M
7230	EJGOPK	YFWLSJAHPM	4134913245 Dell Way	\N	NJLNMER	MA	20191	US	1	YFWLSJAHPM@dell.com	4134913245	2	9848688907455654	2008/05	user7230	password	75	20000	M
7231	ATILRN	IDGRDOGPBQ	3624793891 Dell Way	\N	AOCFGLI	NH	76448	US	1	IDGRDOGPBQ@dell.com	3624793891	4	2027427522465586	2008/10	user7231	password	79	20000	M
7232	EOFRWJ	XOMLVBNLCB	8352583731 Dell Way	\N	NHIZPXS	UT	58980	US	1	XOMLVBNLCB@dell.com	8352583731	5	4296274047344923	2011/01	user7232	password	85	100000	M
7233	DMMNKA	ZWVAJGCLTJ	6260357649 Dell Way	\N	TSYRKVF	IA	81024	US	1	ZWVAJGCLTJ@dell.com	6260357649	5	8658690651413054	2010/09	user7233	password	51	80000	F
7234	XEPYDL	TEVZGGTQAL	1677736772 Dell Way	\N	PRWLXDF	MS	10856	US	1	TEVZGGTQAL@dell.com	1677736772	1	7399768060073257	2010/09	user7234	password	83	60000	M
7235	MJZYDD	TDKAWABIQT	1372482301 Dell Way	\N	FBQIHDI	MA	22901	US	1	TDKAWABIQT@dell.com	1372482301	5	8335350203793497	2012/05	user7235	password	65	60000	M
7236	QJWTDZ	DEWEFEVYJX	7099417240 Dell Way	\N	PSFSAPW	AZ	53616	US	1	DEWEFEVYJX@dell.com	7099417240	1	8600659588351847	2009/06	user7236	password	60	100000	M
7237	LSZLWD	HBILWHVUWN	8998442676 Dell Way	\N	ZPOOLQB	CT	66295	US	1	HBILWHVUWN@dell.com	8998442676	3	1609044532291591	2010/05	user7237	password	82	100000	F
7238	WJZZRA	ICXPYRMMQB	4007075308 Dell Way	\N	AFMQGQG	DC	16504	US	1	ICXPYRMMQB@dell.com	4007075308	4	5298367904499173	2009/07	user7238	password	61	20000	M
7239	OBOPKR	MAQDMCUNDA	2807379374 Dell Way	\N	ATGQAKS	LA	12986	US	1	MAQDMCUNDA@dell.com	2807379374	3	6229230106342584	2011/09	user7239	password	54	40000	M
7240	BYDTKD	JOQMJEPJEJ	6895842643 Dell Way	\N	QVKBOTB	PA	42192	US	1	JOQMJEPJEJ@dell.com	6895842643	3	1242357705254107	2008/11	user7240	password	73	40000	M
7241	XZGBJU	RVDVLNAUDV	4262450939 Dell Way	\N	FEKZGEI	VT	74075	US	1	RVDVLNAUDV@dell.com	4262450939	1	6557513948995621	2008/04	user7241	password	51	20000	F
7242	SBPNTL	QOWEORHKWM	3600323520 Dell Way	\N	UWSYFQR	ND	71352	US	1	QOWEORHKWM@dell.com	3600323520	4	9616008947603404	2011/09	user7242	password	32	60000	M
7243	UYNFPB	CTQTBAQNVM	5511703672 Dell Way	\N	GURWLGO	PA	93565	US	1	CTQTBAQNVM@dell.com	5511703672	3	6752575399354101	2011/12	user7243	password	48	60000	M
7244	YSMAVG	QOHRFVMSBH	2850758812 Dell Way	\N	KXTQMMO	WV	98250	US	1	QOHRFVMSBH@dell.com	2850758812	4	9311815105378628	2011/03	user7244	password	77	60000	M
7245	IOSOFH	WWMRJETQPR	7960750097 Dell Way	\N	JFDWUCW	WY	77927	US	1	WWMRJETQPR@dell.com	7960750097	4	9323142979294064	2010/03	user7245	password	77	100000	M
7246	NMYVIV	HAEMTVBKFH	3678260593 Dell Way	\N	NCCQYBJ	OK	72095	US	1	HAEMTVBKFH@dell.com	3678260593	2	8841732138302178	2008/03	user7246	password	63	80000	M
7247	PLZKTA	PGTLHEQPSS	3748973069 Dell Way	\N	RIRTRJL	WY	69845	US	1	PGTLHEQPSS@dell.com	3748973069	1	8790457186754794	2012/10	user7247	password	56	60000	F
7248	NXYNNF	HYNLOCDHUM	8641170047 Dell Way	\N	YNDIYDZ	IA	31794	US	1	HYNLOCDHUM@dell.com	8641170047	1	9942110343836248	2009/09	user7248	password	32	100000	M
7249	ELCJSA	WEPYIXSUVG	3825480621 Dell Way	\N	YEECDLI	WY	65641	US	1	WEPYIXSUVG@dell.com	3825480621	2	3737248656339943	2010/04	user7249	password	83	80000	M
7250	ZALAWP	PVYMOSIURM	4016361623 Dell Way	\N	ZTQKBQA	LA	98796	US	1	PVYMOSIURM@dell.com	4016361623	5	3343125404324383	2009/07	user7250	password	88	40000	M
7251	KGMAWH	YJWQSQHEQA	7130279877 Dell Way	\N	VBCLBLK	MD	40669	US	1	YJWQSQHEQA@dell.com	7130279877	4	9073074354790152	2011/11	user7251	password	53	20000	F
7252	YBZGZI	CQATYFKZAL	7907866461 Dell Way	\N	BMMNXXW	NE	58324	US	1	CQATYFKZAL@dell.com	7907866461	2	4648518515750766	2009/04	user7252	password	56	20000	F
7253	NLIVOZ	WIXCSXDDYP	5161491283 Dell Way	\N	QMNNJBB	CT	36870	US	1	WIXCSXDDYP@dell.com	5161491283	2	6168562360573561	2012/07	user7253	password	84	60000	F
7254	GIPFFX	CIPZLTYBJL	5587986032 Dell Way	\N	OWUQYYY	MD	37071	US	1	CIPZLTYBJL@dell.com	5587986032	2	8870090291835369	2010/11	user7254	password	83	80000	F
7255	MVKJYT	ZYESXGBIUY	3008083979 Dell Way	\N	DLWBJGJ	VA	68104	US	1	ZYESXGBIUY@dell.com	3008083979	2	5633503760211170	2008/12	user7255	password	70	60000	M
7256	DZTWYR	BROHTXCRAO	9830966856 Dell Way	\N	OBXVKVM	NM	20600	US	1	BROHTXCRAO@dell.com	9830966856	4	1653865711763501	2011/05	user7256	password	81	100000	F
7257	QSHHTZ	WBSTDJURYV	6497002777 Dell Way	\N	PTGKFXN	GA	68779	US	1	WBSTDJURYV@dell.com	6497002777	5	1076358312275260	2010/09	user7257	password	42	20000	F
7258	QKEPGG	HAJRVBPRRJ	5272305784 Dell Way	\N	XCPVQUM	IA	73796	US	1	HAJRVBPRRJ@dell.com	5272305784	4	5036208837293089	2012/10	user7258	password	82	60000	F
7259	CAMIIN	RAITQZKZXM	5953903840 Dell Way	\N	PSDKEJC	NV	17400	US	1	RAITQZKZXM@dell.com	5953903840	3	9115012054797264	2010/12	user7259	password	26	60000	M
7260	PVHDNH	LGXLRXJEMB	6638095818 Dell Way	\N	HXGQZXS	NC	45322	US	1	LGXLRXJEMB@dell.com	6638095818	5	3808809582144022	2011/06	user7260	password	37	40000	F
7261	OMVVYB	TKSRTWDVEA	7229780498 Dell Way	\N	BUAZNOJ	DC	58797	US	1	TKSRTWDVEA@dell.com	7229780498	5	1316201149020344	2012/04	user7261	password	43	60000	M
7262	EJRGCB	ZUUWYQAZRV	2195188217 Dell Way	\N	ZRJOBNC	PA	47315	US	1	ZUUWYQAZRV@dell.com	2195188217	4	7058179773390294	2010/03	user7262	password	48	80000	M
7263	CXSEWM	ZTKPTJHOJY	5766670978 Dell Way	\N	YXALATW	CT	52548	US	1	ZTKPTJHOJY@dell.com	5766670978	4	7269390351604671	2012/04	user7263	password	38	20000	F
7264	ZFBLEU	VTOFADOZBL	9379057796 Dell Way	\N	ZNLTJPG	VA	29673	US	1	VTOFADOZBL@dell.com	9379057796	5	5498627974651754	2009/11	user7264	password	68	20000	F
7265	TQFOMZ	CRAGFZHRZU	5150118578 Dell Way	\N	DTDTZBY	WA	88304	US	1	CRAGFZHRZU@dell.com	5150118578	1	7635483521968127	2008/04	user7265	password	76	100000	M
7266	ALLAOC	AUIACAAWEU	7032693398 Dell Way	\N	AXUBWSY	KS	85752	US	1	AUIACAAWEU@dell.com	7032693398	3	2466121234465390	2010/05	user7266	password	26	60000	M
7267	ONJQOE	ZOGZPCDJDA	8868638956 Dell Way	\N	EFXWDFS	SC	71663	US	1	ZOGZPCDJDA@dell.com	8868638956	2	1485224900301545	2012/10	user7267	password	81	60000	F
7268	GEVKDK	QDATGKXHOC	2264975209 Dell Way	\N	ELFKDAC	AK	36775	US	1	QDATGKXHOC@dell.com	2264975209	5	1665394818410277	2008/07	user7268	password	44	40000	M
7269	FRVQIZ	QCFAZNOBSZ	7145092376 Dell Way	\N	HCDIEDP	KS	22041	US	1	QCFAZNOBSZ@dell.com	7145092376	2	6975799134932459	2008/08	user7269	password	44	40000	F
7270	FWPEMR	KNQXBSPBZS	2103406369 Dell Way	\N	EHXIXFL	NH	59646	US	1	KNQXBSPBZS@dell.com	2103406369	4	2379217540845275	2010/11	user7270	password	49	80000	M
7271	AWGRHU	IEWAUXAMCI	3591069480 Dell Way	\N	JLGPXVD	AK	52795	US	1	IEWAUXAMCI@dell.com	3591069480	3	4387380389496684	2011/03	user7271	password	28	80000	F
7272	KKIETN	AUHYUUBDEM	1308232553 Dell Way	\N	JTJEWJR	DE	88879	US	1	AUHYUUBDEM@dell.com	1308232553	5	1677850779145956	2008/08	user7272	password	28	60000	F
7273	MUTAVN	IUIDVLHIUA	1107918256 Dell Way	\N	RZXBQBY	NY	95672	US	1	IUIDVLHIUA@dell.com	1107918256	5	6062292950227857	2008/06	user7273	password	60	80000	F
7274	JRBXAV	FDRRKZLLRL	9224786341 Dell Way	\N	ISBKRSJ	NY	62174	US	1	FDRRKZLLRL@dell.com	9224786341	5	1267689451109617	2010/06	user7274	password	37	100000	F
7275	ITEEYH	WPSVBDNMLG	8985625305 Dell Way	\N	OWXHFPW	CT	48288	US	1	WPSVBDNMLG@dell.com	8985625305	4	9312379810959102	2008/06	user7275	password	25	60000	F
7276	HREPNU	HJWKWIWCXS	9427820251 Dell Way	\N	AEXPAAA	VT	69107	US	1	HJWKWIWCXS@dell.com	9427820251	1	2183221508283168	2008/07	user7276	password	43	40000	F
7277	NXTIEC	EOYMLBKDBO	9019763594 Dell Way	\N	BQPCQMT	NE	59974	US	1	EOYMLBKDBO@dell.com	9019763594	4	1996343821287155	2009/12	user7277	password	42	80000	M
7278	BBZDFO	CSADCEERFV	4599414074 Dell Way	\N	GILTCAH	WV	68815	US	1	CSADCEERFV@dell.com	4599414074	2	6252435531001539	2011/12	user7278	password	47	80000	F
7279	KYHZAA	ZEDDJUJEAR	9021270932 Dell Way	\N	QTTRBTH	MN	95890	US	1	ZEDDJUJEAR@dell.com	9021270932	1	9382965456228704	2009/12	user7279	password	89	80000	M
7280	GRZGQD	KUMEDQFVGZ	2792484682 Dell Way	\N	OXBIFMG	CO	71705	US	1	KUMEDQFVGZ@dell.com	2792484682	3	7016537682153285	2008/02	user7280	password	61	60000	M
7281	OSKRCF	EGIVMDCLSZ	4091605506 Dell Way	\N	MAFZHIR	MS	77332	US	1	EGIVMDCLSZ@dell.com	4091605506	4	8713923638220877	2012/02	user7281	password	64	60000	M
7282	BEXGJE	PEQSGCLGPL	4751648379 Dell Way	\N	MOTVGGO	NE	92383	US	1	PEQSGCLGPL@dell.com	4751648379	3	1215577901806682	2008/01	user7282	password	78	20000	F
7283	SJOXYT	NQZPCGENST	5224212985 Dell Way	\N	HOANCPL	MT	20215	US	1	NQZPCGENST@dell.com	5224212985	3	2202780310530215	2009/09	user7283	password	42	20000	F
7284	XXYQLP	QBRXGFQANE	8535696745 Dell Way	\N	ABHPMUS	WI	41979	US	1	QBRXGFQANE@dell.com	8535696745	2	1241190718021243	2008/04	user7284	password	21	20000	F
7285	ASRQJS	HGYNXYBBYC	5469944812 Dell Way	\N	IOOCGNM	CA	80045	US	1	HGYNXYBBYC@dell.com	5469944812	2	1625393518246710	2010/05	user7285	password	38	60000	F
7286	YELRMS	PAPOBQNDZC	1558714699 Dell Way	\N	SCIFOLZ	AR	72523	US	1	PAPOBQNDZC@dell.com	1558714699	4	1366781370714306	2009/02	user7286	password	25	40000	F
7287	OYVGOV	VDWMRALTSN	3200569410 Dell Way	\N	CXCNXDF	WV	76728	US	1	VDWMRALTSN@dell.com	3200569410	2	9117801221087576	2009/08	user7287	password	35	100000	M
7288	BDCXZG	TLXUWQMKSK	3550007261 Dell Way	\N	NGHQLGJ	NY	62456	US	1	TLXUWQMKSK@dell.com	3550007261	1	2680393294431269	2010/12	user7288	password	71	60000	F
7289	VMBCGM	ZAJQMUJWHP	2783606541 Dell Way	\N	EXALHSA	NE	78173	US	1	ZAJQMUJWHP@dell.com	2783606541	1	7249401142820717	2012/09	user7289	password	74	80000	F
7290	VWJHVJ	RMWLVSSKXQ	6550109388 Dell Way	\N	LIYEINX	MT	65092	US	1	RMWLVSSKXQ@dell.com	6550109388	3	3664962079841644	2009/03	user7290	password	50	20000	F
7291	VMYFDK	BPFUHQRXBZ	3348151449 Dell Way	\N	VGIJEVZ	RI	37185	US	1	BPFUHQRXBZ@dell.com	3348151449	1	5818862357176841	2011/05	user7291	password	63	60000	M
7292	OTAYVP	EPWUHUWHQC	3597696518 Dell Way	\N	PZGLYAT	GA	28034	US	1	EPWUHUWHQC@dell.com	3597696518	5	6066691592801363	2012/06	user7292	password	48	60000	F
7293	KKAZOQ	WJXRFFHIVH	4369663602 Dell Way	\N	OGGPALV	IN	43930	US	1	WJXRFFHIVH@dell.com	4369663602	2	8494943530298770	2011/09	user7293	password	20	40000	F
7294	BFRRCA	PTGUBOPIDW	3144781671 Dell Way	\N	OTXAOFK	WA	46948	US	1	PTGUBOPIDW@dell.com	3144781671	4	1851740845479071	2009/12	user7294	password	31	40000	F
7295	WAFWPZ	DKARAIVWXO	5239947321 Dell Way	\N	UYCZIBJ	NE	78748	US	1	DKARAIVWXO@dell.com	5239947321	5	7241507686674596	2011/03	user7295	password	78	60000	F
7296	BKUANE	AFEJABHPVF	2782687515 Dell Way	\N	SVOTEDN	NV	99759	US	1	AFEJABHPVF@dell.com	2782687515	2	2585989960003644	2008/11	user7296	password	43	20000	F
7297	DCTIDZ	MMAOTPKYHF	8476221279 Dell Way	\N	NAKRNBR	OR	43822	US	1	MMAOTPKYHF@dell.com	8476221279	4	2922512505203485	2008/11	user7297	password	51	40000	M
7298	FQBFDN	FRHUCFBITC	4237766950 Dell Way	\N	SKQUBID	VA	19100	US	1	FRHUCFBITC@dell.com	4237766950	1	9438436619006098	2012/05	user7298	password	81	20000	F
7299	XGDLLV	SFYYHGRJYC	4403342944 Dell Way	\N	ZSDIWAL	HI	18992	US	1	SFYYHGRJYC@dell.com	4403342944	1	5440426809247583	2009/01	user7299	password	55	20000	F
7300	RPTMIY	LGGRYQQAPI	7944004224 Dell Way	\N	DYFEKLH	RI	53300	US	1	LGGRYQQAPI@dell.com	7944004224	1	6022607170045376	2009/03	user7300	password	81	100000	M
7301	PLCOWI	UNGLDHAMLZ	2581574461 Dell Way	\N	SPJDXDQ	NV	24367	US	1	UNGLDHAMLZ@dell.com	2581574461	5	4044834147673100	2008/11	user7301	password	26	80000	F
7302	FFFOAT	VLXCMJNMBD	5327536659 Dell Way	\N	VFAZVRD	AK	66065	US	1	VLXCMJNMBD@dell.com	5327536659	1	5656501250807196	2010/09	user7302	password	80	100000	M
7303	BJYUEJ	RGWBUIDXEI	7730617368 Dell Way	\N	YDEPHEF	RI	28846	US	1	RGWBUIDXEI@dell.com	7730617368	2	9144936643540860	2011/03	user7303	password	77	80000	M
7304	TMSDDY	ZFTIIQMRPQ	1979786574 Dell Way	\N	VEXZKRF	DE	15242	US	1	ZFTIIQMRPQ@dell.com	1979786574	4	3123746502213180	2012/06	user7304	password	74	80000	M
7305	MVBLUG	EDOVPGKFBP	2186651772 Dell Way	\N	DBAVGEX	MA	94699	US	1	EDOVPGKFBP@dell.com	2186651772	2	4378506435081363	2012/12	user7305	password	37	40000	M
7306	IUPOYS	DUIJEOLTRM	3175363506 Dell Way	\N	TNTYLDW	ND	49367	US	1	DUIJEOLTRM@dell.com	3175363506	3	4739622930064798	2010/10	user7306	password	32	100000	M
7307	UJONNI	VWNJHGBUAO	5893424716 Dell Way	\N	OYZRUOD	AR	11047	US	1	VWNJHGBUAO@dell.com	5893424716	3	8515245463699103	2011/05	user7307	password	50	60000	M
7308	ABGJWD	WFLDGFDVUC	3067384582 Dell Way	\N	VMXJPYK	DC	54167	US	1	WFLDGFDVUC@dell.com	3067384582	5	8872094627004118	2011/06	user7308	password	64	80000	F
7309	XBIAYN	MBUSFPMHLY	5265361197 Dell Way	\N	EVOCFRP	MI	61616	US	1	MBUSFPMHLY@dell.com	5265361197	1	1011857685633003	2008/10	user7309	password	52	20000	M
7310	UBVINX	CFCSRKEQPZ	4847056251 Dell Way	\N	ERFWHQL	PA	79720	US	1	CFCSRKEQPZ@dell.com	4847056251	5	6443246212322266	2012/11	user7310	password	54	80000	M
7311	IALGCR	JVITZZIZDA	2762650442 Dell Way	\N	EZHVKBP	TX	94377	US	1	JVITZZIZDA@dell.com	2762650442	4	8409894621931017	2011/06	user7311	password	73	20000	F
7312	FGOWPK	FJJERIISNI	8533170536 Dell Way	\N	AITBXPA	CT	39235	US	1	FJJERIISNI@dell.com	8533170536	5	7797848706133664	2010/11	user7312	password	32	100000	F
7313	TRSDXC	NCUWKMJTMS	2192637671 Dell Way	\N	MOQBPTJ	ME	60237	US	1	NCUWKMJTMS@dell.com	2192637671	1	4638451288454235	2009/10	user7313	password	55	20000	M
7314	GFKISM	COXPYQCQCQ	9790649990 Dell Way	\N	HDFANQO	NV	69999	US	1	COXPYQCQCQ@dell.com	9790649990	5	5396422039717436	2010/01	user7314	password	90	80000	F
7315	KBZWEO	TTNKVEMMLQ	5589135149 Dell Way	\N	SLEJAVA	WY	83608	US	1	TTNKVEMMLQ@dell.com	5589135149	3	8936750473920257	2010/03	user7315	password	29	100000	F
7316	DTLSNF	GXAKKMVBFH	7730378953 Dell Way	\N	FOHBOHW	CA	80007	US	1	GXAKKMVBFH@dell.com	7730378953	3	1004630666226148	2012/06	user7316	password	38	20000	F
7317	SUTXAR	YKBLGCQNIE	8806894693 Dell Way	\N	UJTCGVW	WY	46934	US	1	YKBLGCQNIE@dell.com	8806894693	5	8890314466319979	2008/12	user7317	password	25	100000	M
7318	VUTMTD	OEJRUWZZRJ	8598015215 Dell Way	\N	STPOQPZ	MS	54694	US	1	OEJRUWZZRJ@dell.com	8598015215	4	5009817421901971	2012/07	user7318	password	30	80000	F
7319	XHBBVG	KNBHNAZWTT	1272822700 Dell Way	\N	MIJCHWP	CT	57207	US	1	KNBHNAZWTT@dell.com	1272822700	1	1512561777606606	2008/11	user7319	password	46	20000	F
7320	MDZSOM	UWZUVWOOIW	4421391516 Dell Way	\N	YKEUAHI	AL	42323	US	1	UWZUVWOOIW@dell.com	4421391516	2	2907362366095185	2011/05	user7320	password	43	40000	F
7321	IYBUTX	TNSPCGYZFJ	9980844924 Dell Way	\N	DZJLIKU	OH	67515	US	1	TNSPCGYZFJ@dell.com	9980844924	3	9803808899596334	2009/09	user7321	password	51	80000	M
7322	NLKKFY	CVAJTAODDO	5537849816 Dell Way	\N	MOXXJPN	LA	14777	US	1	CVAJTAODDO@dell.com	5537849816	4	7855639761779458	2012/05	user7322	password	49	60000	M
7323	VWZTZV	UJOUYRYNEN	8173751993 Dell Way	\N	KBXZPGA	CA	95003	US	1	UJOUYRYNEN@dell.com	8173751993	1	3683885190170258	2009/07	user7323	password	24	20000	F
7324	CVJXQT	MLRDJFIXPJ	3558842885 Dell Way	\N	UOYBPAZ	MD	16569	US	1	MLRDJFIXPJ@dell.com	3558842885	4	6352514616679401	2009/09	user7324	password	90	60000	M
7325	JJDCVO	UZYZHWPRQE	3726523353 Dell Way	\N	PRUQRES	WI	83530	US	1	UZYZHWPRQE@dell.com	3726523353	2	5579811383970082	2009/10	user7325	password	19	80000	F
7326	EUASOA	QOINDZDHPV	6268935500 Dell Way	\N	CFNGYLB	IA	81597	US	1	QOINDZDHPV@dell.com	6268935500	3	6397700589150191	2011/03	user7326	password	74	80000	M
7327	UMNUDC	CQFCUNRPPX	9708580668 Dell Way	\N	CWVOYCJ	MT	64694	US	1	CQFCUNRPPX@dell.com	9708580668	1	8158043774310500	2011/11	user7327	password	72	60000	F
7328	HINJLD	POXCGNSDQP	5181029377 Dell Way	\N	ZFNBOBR	NC	27758	US	1	POXCGNSDQP@dell.com	5181029377	2	1861805386375636	2009/10	user7328	password	52	60000	F
7329	ZWPCLE	AOKNHNDWNI	7685747884 Dell Way	\N	KOXLGLQ	OK	73704	US	1	AOKNHNDWNI@dell.com	7685747884	5	5703349845018238	2009/06	user7329	password	67	20000	F
7330	HHSLHG	VVNJYKWHUL	8665630217 Dell Way	\N	EFSQWKI	NJ	39887	US	1	VVNJYKWHUL@dell.com	8665630217	5	7767962250858546	2010/01	user7330	password	19	100000	F
7331	THPZCK	NMIXJQRVVX	1078633764 Dell Way	\N	NLUYUKG	NJ	29969	US	1	NMIXJQRVVX@dell.com	1078633764	1	3085733150597662	2008/12	user7331	password	56	80000	F
7332	CTJNHV	VEFMWAHUNT	4681701108 Dell Way	\N	OLNYSDE	OK	35839	US	1	VEFMWAHUNT@dell.com	4681701108	4	3353780106641352	2012/07	user7332	password	54	20000	F
7333	WOOSKT	XWQXEKLXZX	1910092864 Dell Way	\N	KYQOCJV	MT	19706	US	1	XWQXEKLXZX@dell.com	1910092864	3	6712853162083775	2011/06	user7333	password	85	60000	F
7334	MELGBH	XZMHLJHIUF	1427790490 Dell Way	\N	YJIHFVK	IL	35683	US	1	XZMHLJHIUF@dell.com	1427790490	5	8032137639354915	2012/05	user7334	password	78	60000	M
7335	GSPOPP	BXAKEIFKHO	6507146841 Dell Way	\N	SPTOABV	AR	96425	US	1	BXAKEIFKHO@dell.com	6507146841	1	3979035105556250	2010/06	user7335	password	81	80000	F
7336	MGVBHS	BSXJYHRNAG	6656702604 Dell Way	\N	HOHIKIH	AK	41888	US	1	BSXJYHRNAG@dell.com	6656702604	3	8588077278807760	2010/02	user7336	password	21	100000	F
7337	WASPBK	MLJUDWUKDJ	2694733406 Dell Way	\N	RMTZUTI	MD	27636	US	1	MLJUDWUKDJ@dell.com	2694733406	5	3961556922178716	2009/11	user7337	password	70	20000	M
7338	KRYVEK	EZNBUXEDOR	2651036365 Dell Way	\N	XOLRXVW	CA	77004	US	1	EZNBUXEDOR@dell.com	2651036365	2	6528902741614730	2012/06	user7338	password	54	40000	F
7339	LDHVIG	JJAGOEVFCK	8632838334 Dell Way	\N	QTHMPJG	RI	73955	US	1	JJAGOEVFCK@dell.com	8632838334	4	2256381906569004	2009/01	user7339	password	36	80000	F
7340	OQMUAV	VHKACPCMGV	1166718371 Dell Way	\N	UTKEZEW	SD	88021	US	1	VHKACPCMGV@dell.com	1166718371	1	8810661504510791	2009/12	user7340	password	19	100000	M
7341	MPPILW	SLZIOMOJGH	7282567855 Dell Way	\N	ULGZICV	KS	32035	US	1	SLZIOMOJGH@dell.com	7282567855	3	2841419197153300	2011/05	user7341	password	76	40000	F
7342	KNMHGX	HOLTDVALPL	3033070201 Dell Way	\N	SOTUKCA	CA	70964	US	1	HOLTDVALPL@dell.com	3033070201	5	1801228181924671	2008/01	user7342	password	26	60000	M
7343	OTUMAJ	YTNUTYJFQY	8174338143 Dell Way	\N	YKIALKS	NV	29078	US	1	YTNUTYJFQY@dell.com	8174338143	4	2980906420852989	2012/02	user7343	password	73	60000	M
7344	OZWYYQ	LSJJBPZANK	2507358823 Dell Way	\N	IOVTHMY	AZ	25223	US	1	LSJJBPZANK@dell.com	2507358823	5	3683187229093164	2012/06	user7344	password	29	60000	F
7345	ALJQWC	AFEPFEDQMS	4734465700 Dell Way	\N	MFZYEBD	KY	14573	US	1	AFEPFEDQMS@dell.com	4734465700	2	5660945201758296	2010/10	user7345	password	88	80000	F
7346	IGBLHH	PXNTBDGTPM	4600110179 Dell Way	\N	TORVRAW	CA	34799	US	1	PXNTBDGTPM@dell.com	4600110179	4	1394019031431526	2009/04	user7346	password	35	80000	M
7347	HDUOSS	CMTFTNVFGK	2777102226 Dell Way	\N	WCBWZDD	MA	82381	US	1	CMTFTNVFGK@dell.com	2777102226	4	1621588255744427	2010/06	user7347	password	60	80000	M
7348	JHIBJV	VPOILUPVRR	9105428345 Dell Way	\N	WNRARBV	VA	82005	US	1	VPOILUPVRR@dell.com	9105428345	2	3309085820801556	2010/01	user7348	password	80	100000	F
7349	EYSZTI	OCUIRPZJMN	2247070303 Dell Way	\N	ANFCICW	IA	45995	US	1	OCUIRPZJMN@dell.com	2247070303	4	4980962527450174	2012/08	user7349	password	75	20000	M
7350	NEHVSJ	PBBFAKRNLE	6932051962 Dell Way	\N	TNNVKTF	NC	54309	US	1	PBBFAKRNLE@dell.com	6932051962	3	1779201047495007	2010/09	user7350	password	63	100000	M
7351	XUOHJQ	IPQTGEELXR	3835958528 Dell Way	\N	ZSBTYPF	NH	21683	US	1	IPQTGEELXR@dell.com	3835958528	1	8412281905300916	2012/12	user7351	password	67	100000	M
7352	GEDWMS	NGZRKLPCKI	7435272997 Dell Way	\N	EDGTJWX	NY	91572	US	1	NGZRKLPCKI@dell.com	7435272997	4	9050066126976164	2009/06	user7352	password	66	80000	M
7353	UNDNAJ	NSTYIVIQZL	6037943110 Dell Way	\N	XTVTQMR	LA	18680	US	1	NSTYIVIQZL@dell.com	6037943110	4	6112930055707694	2009/05	user7353	password	32	20000	M
7354	IOZRBR	KZAGIQGUNZ	7583956643 Dell Way	\N	PHQBYZE	MT	75532	US	1	KZAGIQGUNZ@dell.com	7583956643	4	2206638982519507	2012/10	user7354	password	22	40000	F
7355	AXJSIJ	SORJULXUBE	3084654957 Dell Way	\N	KCDJHRC	AK	45693	US	1	SORJULXUBE@dell.com	3084654957	5	2427307394333184	2009/03	user7355	password	52	40000	F
7356	WBKFUY	XDTJANKFXN	6210196447 Dell Way	\N	JHUAJUK	NH	76197	US	1	XDTJANKFXN@dell.com	6210196447	5	9141654973383994	2008/03	user7356	password	89	100000	F
7357	JDBHBF	BKGOVLLJVS	6404466570 Dell Way	\N	EVCYGSS	TN	64079	US	1	BKGOVLLJVS@dell.com	6404466570	5	8477506694849581	2010/10	user7357	password	26	100000	M
7358	EGZJHJ	PVFBHOWASS	3251530053 Dell Way	\N	DRZVJVK	WY	74296	US	1	PVFBHOWASS@dell.com	3251530053	3	5624746674671770	2009/06	user7358	password	50	60000	M
7359	KXAUNW	AODPLEHEHZ	2767770272 Dell Way	\N	DCJZNJR	PA	92082	US	1	AODPLEHEHZ@dell.com	2767770272	1	4643062470946461	2011/08	user7359	password	28	20000	M
7360	DWCAWR	DLCHTHOTKR	7977386012 Dell Way	\N	CKELBYJ	ID	14726	US	1	DLCHTHOTKR@dell.com	7977386012	5	7412945882882924	2012/12	user7360	password	38	20000	M
7361	JBRAFC	DMVKBOVSRF	6258022308 Dell Way	\N	XDHVMNW	IL	49711	US	1	DMVKBOVSRF@dell.com	6258022308	1	4574624399188906	2012/04	user7361	password	32	40000	F
7362	WGNYJA	UTCJOVATSE	4713157121 Dell Way	\N	ANROKYA	WV	20790	US	1	UTCJOVATSE@dell.com	4713157121	5	4357279349118471	2011/01	user7362	password	68	60000	F
7363	FLRGFL	IOADPUVTVJ	8507013856 Dell Way	\N	KJTIKSL	SD	59514	US	1	IOADPUVTVJ@dell.com	8507013856	3	6548017944209278	2010/11	user7363	password	85	80000	F
7364	PZNAHC	ALSUGLQPWZ	2997415186 Dell Way	\N	IFKBRFP	MS	66808	US	1	ALSUGLQPWZ@dell.com	2997415186	1	5727346286643297	2008/10	user7364	password	79	80000	M
7365	JUBMVM	EQSQGIMGRR	1064838144 Dell Way	\N	QTIWIVM	ND	87377	US	1	EQSQGIMGRR@dell.com	1064838144	4	6599889724981040	2012/06	user7365	password	44	40000	F
7366	KSBWWS	PMYYZFPRVI	3898463474 Dell Way	\N	ARRVEGS	DE	96146	US	1	PMYYZFPRVI@dell.com	3898463474	1	4768072245176882	2011/04	user7366	password	66	20000	M
7367	TYVLOI	JMHOCYKLYC	7732115189 Dell Way	\N	DUGJNLI	SD	51864	US	1	JMHOCYKLYC@dell.com	7732115189	3	7449584371875972	2010/08	user7367	password	66	20000	M
7368	MPCVZP	DORCYDBBGV	9475282312 Dell Way	\N	IPITYEF	OH	70686	US	1	DORCYDBBGV@dell.com	9475282312	1	3394973686430603	2011/04	user7368	password	77	20000	M
7369	XYVMBJ	EDIHEJNASD	5155425056 Dell Way	\N	JLCNRUF	NJ	89139	US	1	EDIHEJNASD@dell.com	5155425056	2	2218576535116881	2009/05	user7369	password	89	20000	F
7370	URIEVL	MDPWQQOUZA	6924989529 Dell Way	\N	WMRQSIN	DC	59644	US	1	MDPWQQOUZA@dell.com	6924989529	3	9052221294492484	2011/08	user7370	password	30	60000	F
7371	MPDYBG	OXXEMRDMOQ	9425666135 Dell Way	\N	EFIMSMB	MA	92782	US	1	OXXEMRDMOQ@dell.com	9425666135	1	5793788061477244	2008/06	user7371	password	77	60000	F
7372	YNCFBA	CFMUJZIZDN	3443849029 Dell Way	\N	IQGVRQT	NJ	68922	US	1	CFMUJZIZDN@dell.com	3443849029	4	1931585748679936	2008/04	user7372	password	28	20000	M
7373	GGWGIC	TCLSLLWZTN	6648139178 Dell Way	\N	GPFWIVN	NE	57823	US	1	TCLSLLWZTN@dell.com	6648139178	4	8493733237963171	2011/09	user7373	password	65	20000	M
7374	NHHPAJ	ATVLQUFEAU	5775089833 Dell Way	\N	JXCEKRS	AR	43304	US	1	ATVLQUFEAU@dell.com	5775089833	5	1763862931635230	2008/10	user7374	password	20	80000	F
7375	HHDRHW	NTNHYRITAF	9938385321 Dell Way	\N	WEQNXSX	ME	56197	US	1	NTNHYRITAF@dell.com	9938385321	3	4047052644658834	2008/04	user7375	password	49	40000	M
7376	OAWLNP	YVOQDHQJDV	6092484251 Dell Way	\N	ARTSPEF	NE	77521	US	1	YVOQDHQJDV@dell.com	6092484251	4	1277286529075354	2008/12	user7376	password	60	60000	M
7377	LZMAYH	OPLWGUACVR	7765809329 Dell Way	\N	VNHZTWS	KS	50994	US	1	OPLWGUACVR@dell.com	7765809329	2	4502677792683244	2009/11	user7377	password	42	80000	M
7378	UUVCJK	NGQHGSCYOQ	9104898408 Dell Way	\N	FNKBGSN	WY	12523	US	1	NGQHGSCYOQ@dell.com	9104898408	2	9157809059135616	2009/02	user7378	password	75	20000	M
7379	PDGAQM	RXTKARYRWM	7285198893 Dell Way	\N	BYSTLSU	KY	12144	US	1	RXTKARYRWM@dell.com	7285198893	3	2058763133361935	2010/08	user7379	password	18	20000	M
7380	GDJTUH	MFHEDZBQAZ	2472871357 Dell Way	\N	IULAPUB	IL	42316	US	1	MFHEDZBQAZ@dell.com	2472871357	4	9800730109214784	2008/11	user7380	password	70	60000	M
7381	BETIRY	QWCPXSQXBL	4949454630 Dell Way	\N	IBACDHL	IL	14277	US	1	QWCPXSQXBL@dell.com	4949454630	3	9102484852075578	2008/11	user7381	password	81	40000	F
7382	QOTPFP	SVNKLKMXTO	2173863385 Dell Way	\N	XWREHYF	PA	44629	US	1	SVNKLKMXTO@dell.com	2173863385	5	3378949151374400	2008/02	user7382	password	42	80000	M
7383	CFWSYS	FJEQVBKJYG	6394401178 Dell Way	\N	ADOYJHI	MO	26701	US	1	FJEQVBKJYG@dell.com	6394401178	3	3718274026643485	2012/02	user7383	password	89	20000	F
7384	WSHOYQ	SPLTZUSFVV	5747088820 Dell Way	\N	TTEBCRF	OH	23691	US	1	SPLTZUSFVV@dell.com	5747088820	4	3445081227459013	2010/08	user7384	password	63	40000	F
7385	XYHNQX	YKWTDCOYVH	3040186328 Dell Way	\N	DWKUCCY	NJ	74242	US	1	YKWTDCOYVH@dell.com	3040186328	1	4204730932600796	2012/06	user7385	password	70	80000	F
7386	AGBXEM	UXPWMORUSO	3955621759 Dell Way	\N	ENQGLHZ	NY	45983	US	1	UXPWMORUSO@dell.com	3955621759	3	9049739823676648	2008/04	user7386	password	41	20000	M
7387	KZRWTP	MQBBHWTWAG	1708218242 Dell Way	\N	NHSUGJE	NE	91824	US	1	MQBBHWTWAG@dell.com	1708218242	4	2522798234596848	2009/09	user7387	password	66	80000	M
7388	JRLZDB	BFJXYFXETE	4095166445 Dell Way	\N	WNLGSAE	RI	66554	US	1	BFJXYFXETE@dell.com	4095166445	1	3858072533272207	2008/12	user7388	password	90	40000	M
7389	KITMJY	VGXBECUJZH	7642839568 Dell Way	\N	UFAUKUK	PA	96123	US	1	VGXBECUJZH@dell.com	7642839568	4	9259729116689416	2011/02	user7389	password	57	20000	F
7390	HQVGLC	EMHGHQFOLL	3060844409 Dell Way	\N	OFVJQPI	MA	41333	US	1	EMHGHQFOLL@dell.com	3060844409	1	5322706554085016	2011/03	user7390	password	87	20000	M
7391	UIHXNU	ETBVYQGKFM	6827431624 Dell Way	\N	GOCVXME	CO	62671	US	1	ETBVYQGKFM@dell.com	6827431624	5	8486896865535528	2010/12	user7391	password	68	40000	F
7392	AHUUMO	WHNNOXTADI	1325626142 Dell Way	\N	DYFQDIF	RI	27163	US	1	WHNNOXTADI@dell.com	1325626142	2	2324699002318084	2011/10	user7392	password	50	80000	F
7393	GNNUKV	IXKFRKJZOH	8251197463 Dell Way	\N	EEKMJER	MD	59832	US	1	IXKFRKJZOH@dell.com	8251197463	1	3749561563134193	2009/11	user7393	password	43	60000	F
7394	WHUSPS	CVJMEIBMMF	9423419056 Dell Way	\N	XYPBQZQ	ME	22399	US	1	CVJMEIBMMF@dell.com	9423419056	4	1065495231654495	2009/03	user7394	password	47	20000	F
7395	FWCXYX	HLBQMNDSKC	4904125218 Dell Way	\N	HMSHDDL	AZ	82087	US	1	HLBQMNDSKC@dell.com	4904125218	2	9773367524612696	2012/06	user7395	password	50	20000	F
7396	NZHLGS	MWFAZXLCFY	7124028847 Dell Way	\N	UMBXXCS	KY	50671	US	1	MWFAZXLCFY@dell.com	7124028847	1	9556756590958686	2008/03	user7396	password	40	80000	F
7397	PBLIOI	NPILAKQYFD	5483190160 Dell Way	\N	ZCBCUKO	MO	63256	US	1	NPILAKQYFD@dell.com	5483190160	4	8433271045796574	2012/04	user7397	password	19	40000	F
7398	MSXVGM	DRMOILTMLW	3992001892 Dell Way	\N	NNRXBDN	ND	78539	US	1	DRMOILTMLW@dell.com	3992001892	2	1241069511510431	2009/10	user7398	password	44	100000	F
7399	HQSTUK	GJTSDFDZSQ	6272204714 Dell Way	\N	QQSUDHO	MN	67895	US	1	GJTSDFDZSQ@dell.com	6272204714	5	4641569389961660	2012/08	user7399	password	82	40000	F
7400	PZCAGM	TYPYBPQSGG	7699605579 Dell Way	\N	KAKSPWI	DE	71077	US	1	TYPYBPQSGG@dell.com	7699605579	1	4016031149774790	2011/05	user7400	password	64	40000	F
7401	TFPFZO	VXPKNIQUTR	1620557336 Dell Way	\N	FLGBULT	MT	61233	US	1	VXPKNIQUTR@dell.com	1620557336	1	9350223747547716	2011/05	user7401	password	38	60000	M
7402	WROKNL	AYZIOUCGZN	5000942687 Dell Way	\N	NAHYUVN	TN	96404	US	1	AYZIOUCGZN@dell.com	5000942687	3	3946596130263060	2011/01	user7402	password	85	60000	M
7403	MAFYAD	XJSSLYRZMS	4331427305 Dell Way	\N	GKMCYIB	MA	89674	US	1	XJSSLYRZMS@dell.com	4331427305	1	9107434717938304	2009/09	user7403	password	62	80000	M
7404	VSSZPC	RHOQZNCSUN	3809448052 Dell Way	\N	FWLNXVK	IL	92597	US	1	RHOQZNCSUN@dell.com	3809448052	3	6436275104992092	2012/05	user7404	password	39	80000	F
7405	ASQCKY	QAXEDQYRVV	5041149592 Dell Way	\N	CISYTAV	AZ	62209	US	1	QAXEDQYRVV@dell.com	5041149592	5	9257828784175218	2011/09	user7405	password	87	80000	F
7406	PWVNNW	LRZBQQWLTF	7267220825 Dell Way	\N	ERZFNAU	WV	10577	US	1	LRZBQQWLTF@dell.com	7267220825	4	7554360118694604	2011/06	user7406	password	29	40000	F
7407	ZTWVEO	VGEMCQFIVX	1342888453 Dell Way	\N	HAKHVKI	MT	19462	US	1	VGEMCQFIVX@dell.com	1342888453	1	6228224269580097	2008/05	user7407	password	85	20000	F
7408	UAHIVN	NIQENYALGB	9315453232 Dell Way	\N	WOWGWJI	VA	57635	US	1	NIQENYALGB@dell.com	9315453232	1	9193686676677316	2012/04	user7408	password	20	80000	F
7409	IZDWML	NRZMRKSSGG	4548657824 Dell Way	\N	PMCYVZM	OR	16395	US	1	NRZMRKSSGG@dell.com	4548657824	3	4017196452245116	2010/03	user7409	password	62	80000	F
7410	TQREEJ	DQANITTPIG	1725045721 Dell Way	\N	RHBRTUT	DC	45452	US	1	DQANITTPIG@dell.com	1725045721	3	6578834317158908	2011/05	user7410	password	77	60000	M
7411	MPDWSU	WGCPZSYGKF	1926821135 Dell Way	\N	HBZCUDM	VA	72992	US	1	WGCPZSYGKF@dell.com	1926821135	3	1426299873739481	2012/01	user7411	password	20	60000	M
7412	EGIYDO	BTOTRUDWBF	7282829689 Dell Way	\N	VEAYQXQ	PA	52925	US	1	BTOTRUDWBF@dell.com	7282829689	4	5382091801613569	2011/01	user7412	password	24	100000	F
7413	KWMZXF	NRWHUTJAOO	8825627157 Dell Way	\N	ANEXEYJ	UT	63789	US	1	NRWHUTJAOO@dell.com	8825627157	4	7096298812422902	2012/07	user7413	password	19	40000	F
7414	MIHSWY	OETIOTXCTK	5311505695 Dell Way	\N	HQPFAMU	VT	16952	US	1	OETIOTXCTK@dell.com	5311505695	5	6319563368801028	2010/03	user7414	password	87	100000	M
7415	FRLEGP	XODQLFJWMA	6485811037 Dell Way	\N	MSBYMYA	WV	83808	US	1	XODQLFJWMA@dell.com	6485811037	3	1453604774083942	2010/06	user7415	password	63	80000	F
7416	BYKQVZ	UMLZVIMWUE	7760411618 Dell Way	\N	XSRWTRS	LA	22405	US	1	UMLZVIMWUE@dell.com	7760411618	5	6414837113581598	2009/09	user7416	password	72	60000	M
7417	EBNDVZ	OVVXISRMQK	6216880662 Dell Way	\N	EMDVFNZ	WI	48078	US	1	OVVXISRMQK@dell.com	6216880662	2	2244786331430077	2009/09	user7417	password	76	60000	M
7418	IQPIFL	DCTVTFLEKY	4309096339 Dell Way	\N	HGEUFCF	SD	48591	US	1	DCTVTFLEKY@dell.com	4309096339	1	2468466168269515	2008/08	user7418	password	87	60000	F
7419	OULZYN	SUHYGLJFTP	1442591678 Dell Way	\N	JOVLUQX	DC	79706	US	1	SUHYGLJFTP@dell.com	1442591678	2	4599818799179047	2012/10	user7419	password	65	60000	M
7420	CNOQGJ	XFPJOUCEDR	8339374858 Dell Way	\N	APLQMPK	MT	92945	US	1	XFPJOUCEDR@dell.com	8339374858	3	7707152532413603	2010/01	user7420	password	45	60000	M
7421	YEWHCC	XLQROVVFVK	9230248349 Dell Way	\N	QLXGWKE	OH	94624	US	1	XLQROVVFVK@dell.com	9230248349	1	1161078440491110	2009/09	user7421	password	64	40000	M
7422	NOZPLL	FDZBYFWJWI	6487690503 Dell Way	\N	GCFQHXP	FL	14149	US	1	FDZBYFWJWI@dell.com	6487690503	3	7850681555923075	2009/09	user7422	password	66	80000	F
7423	QIRCOV	CPTHMCDUIG	7221252851 Dell Way	\N	ZZNWOSY	FL	26576	US	1	CPTHMCDUIG@dell.com	7221252851	3	9074670440983028	2009/03	user7423	password	29	20000	M
7424	VCBQER	KMDMPYVWYV	2562269060 Dell Way	\N	JVKCTOH	MI	10141	US	1	KMDMPYVWYV@dell.com	2562269060	4	2589811533689499	2009/10	user7424	password	67	20000	M
7425	TVBLFO	OSENOALJKG	5542003347 Dell Way	\N	TMAIULI	WI	30555	US	1	OSENOALJKG@dell.com	5542003347	2	1176691457629203	2008/06	user7425	password	84	100000	F
7426	ZJMNYF	RLTRXCCDWP	8515155940 Dell Way	\N	DEJPNHV	AL	60636	US	1	RLTRXCCDWP@dell.com	8515155940	2	9976648034527900	2011/02	user7426	password	36	80000	M
7427	SGLYXX	RPUURYQGCV	5158032457 Dell Way	\N	PRJXMJM	KS	62576	US	1	RPUURYQGCV@dell.com	5158032457	1	7612261543050409	2011/10	user7427	password	36	60000	F
7428	SJXPBM	KVEIMLKHAB	4134769713 Dell Way	\N	RYOAKWP	UT	92379	US	1	KVEIMLKHAB@dell.com	4134769713	3	7205052224919201	2010/01	user7428	password	68	40000	F
7429	PXLCHG	HQSSAATCRR	1866851895 Dell Way	\N	QSBMIYK	NY	55863	US	1	HQSSAATCRR@dell.com	1866851895	2	5768655532505364	2011/07	user7429	password	85	40000	F
7430	JMUPTK	IMLJFNAWET	9132553538 Dell Way	\N	YQBWBTJ	DC	10848	US	1	IMLJFNAWET@dell.com	9132553538	5	6283467872068287	2012/05	user7430	password	23	20000	M
7431	WUPHCB	SLGGMDKFBB	6517596857 Dell Way	\N	HXDAHHA	GA	30611	US	1	SLGGMDKFBB@dell.com	6517596857	1	6162650838959963	2011/03	user7431	password	48	60000	M
7432	AVBCON	JUZMFENHML	5386798877 Dell Way	\N	KMTRNYX	CT	96977	US	1	JUZMFENHML@dell.com	5386798877	5	2418716039974242	2012/05	user7432	password	26	100000	F
7433	EATRJO	RVUWJBIVMV	6696437146 Dell Way	\N	ODINBLM	ND	33896	US	1	RVUWJBIVMV@dell.com	6696437146	3	6709687472321094	2011/05	user7433	password	79	100000	F
7434	PPTEHO	YDYZLTMGIP	9368762384 Dell Way	\N	PVRAHFH	WA	70927	US	1	YDYZLTMGIP@dell.com	9368762384	4	1434188744984567	2011/08	user7434	password	49	40000	F
7435	ENNSMQ	RMBKYISOXN	2522118365 Dell Way	\N	FYVLGTD	DE	49091	US	1	RMBKYISOXN@dell.com	2522118365	5	1427923645358532	2010/04	user7435	password	38	80000	M
7436	UMHKDT	MORUHFSULQ	8810008260 Dell Way	\N	QXWKABV	DE	98115	US	1	MORUHFSULQ@dell.com	8810008260	4	3472699518781155	2008/07	user7436	password	24	100000	F
7437	JIEDUS	VPZAIUMZLJ	2409952139 Dell Way	\N	WVJXQOW	MS	38344	US	1	VPZAIUMZLJ@dell.com	2409952139	4	8598885470535607	2009/07	user7437	password	80	80000	M
7438	ATRTPH	TQQNCPYLLT	5762910169 Dell Way	\N	VIKJFXR	MA	59002	US	1	TQQNCPYLLT@dell.com	5762910169	4	1978593284729868	2009/04	user7438	password	90	60000	F
7439	REPZXG	PLIEKUQEPZ	2037963545 Dell Way	\N	OZFMRPA	FL	29091	US	1	PLIEKUQEPZ@dell.com	2037963545	3	5322006233502180	2008/01	user7439	password	55	100000	F
7440	DUBJKN	ROXMFBCEPB	6690825005 Dell Way	\N	JBSYCXD	GA	54919	US	1	ROXMFBCEPB@dell.com	6690825005	2	5510614691302181	2008/02	user7440	password	66	40000	M
7441	TQHGIW	DUBEWFUYPW	6114367946 Dell Way	\N	QNYOREB	IN	51923	US	1	DUBEWFUYPW@dell.com	6114367946	3	6197918006684632	2009/09	user7441	password	52	100000	F
7442	TFRPJM	RNJWIHLFYZ	4259321153 Dell Way	\N	ENQIOYU	DC	45062	US	1	RNJWIHLFYZ@dell.com	4259321153	2	2041395079810172	2012/05	user7442	password	53	60000	M
7443	EFXQWL	ASUHEZGDDT	3097225385 Dell Way	\N	UMISGLD	NJ	85376	US	1	ASUHEZGDDT@dell.com	3097225385	3	2719082068186253	2011/01	user7443	password	73	100000	F
7444	RNCDNV	XVAWBEAUYM	6437167945 Dell Way	\N	DRTOUJK	AL	82695	US	1	XVAWBEAUYM@dell.com	6437167945	4	8651278442237527	2009/08	user7444	password	24	20000	F
7445	FDRABN	BYPFYJDLNV	2897392758 Dell Way	\N	FCQOMRJ	CA	45618	US	1	BYPFYJDLNV@dell.com	2897392758	3	1153987325262278	2009/06	user7445	password	30	60000	M
7446	WNSJOQ	YUPIYAVTFY	5038496053 Dell Way	\N	JUKADNL	KY	96967	US	1	YUPIYAVTFY@dell.com	5038496053	4	5124306746758521	2011/02	user7446	password	25	60000	M
7447	UWGKVA	ZEYAARGYBA	3478065755 Dell Way	\N	ICEWONV	WY	25086	US	1	ZEYAARGYBA@dell.com	3478065755	4	3876383785624057	2009/02	user7447	password	90	20000	M
7448	GPTGPX	FQXXWVYXEB	1649055039 Dell Way	\N	BAPPWPT	CT	28598	US	1	FQXXWVYXEB@dell.com	1649055039	3	3617530494928360	2008/09	user7448	password	34	40000	F
7449	ZOWXTM	VQJQPHVRIW	4498428079 Dell Way	\N	HYSXRWC	PA	42260	US	1	VQJQPHVRIW@dell.com	4498428079	5	1365624248981475	2011/02	user7449	password	41	80000	M
7450	EMMRHD	BYTIUKRRSP	6765284615 Dell Way	\N	KPHGSAP	CA	87357	US	1	BYTIUKRRSP@dell.com	6765284615	4	9957301973365248	2012/04	user7450	password	69	20000	M
7451	EVCHXB	AFWLXNENXT	7076221514 Dell Way	\N	UDLVTOR	MD	32760	US	1	AFWLXNENXT@dell.com	7076221514	2	6041661515831948	2009/07	user7451	password	44	60000	F
7452	MVGNWL	KIJXMWVGQZ	1545329017 Dell Way	\N	SLSGDDN	SD	52420	US	1	KIJXMWVGQZ@dell.com	1545329017	1	9765194083563984	2010/09	user7452	password	40	100000	M
7453	OLLAVU	JSGFONWNFI	8304833886 Dell Way	\N	GLLJYHV	AK	52008	US	1	JSGFONWNFI@dell.com	8304833886	3	2859540813136846	2008/04	user7453	password	75	80000	M
7454	GROABH	HGVUCJZLPL	8560958850 Dell Way	\N	XZKEVKQ	NJ	86290	US	1	HGVUCJZLPL@dell.com	8560958850	4	2585991531610489	2011/06	user7454	password	85	100000	F
7455	MXDUEK	QZNZZYPLVP	3330291549 Dell Way	\N	VAKGQAC	MO	79188	US	1	QZNZZYPLVP@dell.com	3330291549	1	2722907568793744	2008/12	user7455	password	39	80000	M
7456	LMBVCB	ICAHSLCHHC	7024921559 Dell Way	\N	RNTSPFM	TX	38996	US	1	ICAHSLCHHC@dell.com	7024921559	1	3716835570521653	2012/09	user7456	password	31	40000	F
7457	GFIIOL	IVEUYLBBDP	6737324224 Dell Way	\N	UWEAIBI	AK	17456	US	1	IVEUYLBBDP@dell.com	6737324224	5	8335762748494745	2012/05	user7457	password	20	20000	M
7458	JKDUSY	YNXKPYOETK	3772932186 Dell Way	\N	JTTKCTM	OK	72655	US	1	YNXKPYOETK@dell.com	3772932186	3	1445511103607714	2009/08	user7458	password	63	80000	F
7459	TMTSLG	PWWNKBGULA	1170896934 Dell Way	\N	OVCHIVZ	NM	43425	US	1	PWWNKBGULA@dell.com	1170896934	5	9945387806277724	2011/08	user7459	password	18	40000	F
7460	TCPARL	WFWYMRJMFE	7979216461 Dell Way	\N	PMNKLDU	MN	20519	US	1	WFWYMRJMFE@dell.com	7979216461	1	8040941755753011	2011/06	user7460	password	86	60000	M
7461	ONFZKK	VIXNRJSWYE	4775335851 Dell Way	\N	JJPNDBQ	VT	24529	US	1	VIXNRJSWYE@dell.com	4775335851	4	6774217942729593	2009/03	user7461	password	32	100000	M
7462	LXEWTM	TGECYABCKK	6165517935 Dell Way	\N	SYOUOMY	WY	24744	US	1	TGECYABCKK@dell.com	6165517935	2	4458202488254756	2011/03	user7462	password	28	40000	F
7463	HBWUUC	YWAZYDKIVI	9164757124 Dell Way	\N	XPXJOXN	CT	32293	US	1	YWAZYDKIVI@dell.com	9164757124	5	5435358515474946	2008/02	user7463	password	63	40000	F
7464	MDYPCV	QCTUMCPVZF	4498834778 Dell Way	\N	TIUQWXX	RI	81063	US	1	QCTUMCPVZF@dell.com	4498834778	5	8967674696817995	2008/02	user7464	password	20	60000	F
7465	YCJTTL	NNYPDUOJNX	7271420620 Dell Way	\N	DETABNV	MN	40595	US	1	NNYPDUOJNX@dell.com	7271420620	3	5416714966762811	2011/12	user7465	password	74	80000	F
7466	DLVPZJ	OOMIDVWAYA	2464152237 Dell Way	\N	UZCIUPR	MS	15277	US	1	OOMIDVWAYA@dell.com	2464152237	2	1452242907602340	2012/11	user7466	password	28	20000	F
7467	ZRIIFW	VNARJBQKWP	2919203413 Dell Way	\N	NEKCWWE	AK	19153	US	1	VNARJBQKWP@dell.com	2919203413	5	1033179373946040	2009/01	user7467	password	44	40000	M
7468	RSWONK	OEUPUFLKSQ	8088606730 Dell Way	\N	UVMRZNU	GA	50712	US	1	OEUPUFLKSQ@dell.com	8088606730	3	5229053693357855	2008/12	user7468	password	28	100000	M
7469	AJDLYI	FODKAODQIY	6139548499 Dell Way	\N	DAYQUDC	NH	73296	US	1	FODKAODQIY@dell.com	6139548499	4	6611168581526727	2011/07	user7469	password	35	80000	M
7470	KEXSJL	WULKXCTWGT	3336487133 Dell Way	\N	UXOYAEQ	NE	90577	US	1	WULKXCTWGT@dell.com	3336487133	2	5116515528876335	2010/01	user7470	password	47	100000	F
7471	HQPSMJ	EXHHQDOKYL	5186885252 Dell Way	\N	YWLCNAA	RI	38953	US	1	EXHHQDOKYL@dell.com	5186885252	2	4260345920454711	2012/03	user7471	password	60	20000	M
7472	EWHOBE	WJUAXEYJDV	5689721578 Dell Way	\N	VGIVGDE	OR	45490	US	1	WJUAXEYJDV@dell.com	5689721578	3	6129494946915657	2008/09	user7472	password	44	40000	M
7473	QVRVRB	QSYVQIZMDF	9061480707 Dell Way	\N	VYMYDFI	NM	84361	US	1	QSYVQIZMDF@dell.com	9061480707	4	6169491834007204	2009/01	user7473	password	32	100000	M
7474	XTNYJG	XFWFEJIKEH	5626130681 Dell Way	\N	XCKCLAY	KS	79619	US	1	XFWFEJIKEH@dell.com	5626130681	3	8064940217416734	2011/07	user7474	password	64	80000	F
7475	EOQKLV	HQZQZJUGGX	3315398106 Dell Way	\N	RJISHQM	SD	29950	US	1	HQZQZJUGGX@dell.com	3315398106	3	7510295246727765	2012/02	user7475	password	88	20000	M
7476	PMDKTU	JJTTEAZBRI	9741645151 Dell Way	\N	KJQAWLG	CO	98838	US	1	JJTTEAZBRI@dell.com	9741645151	5	2115428901743143	2012/01	user7476	password	77	60000	M
7477	YYGSHQ	MBVMAWEJHO	6203293451 Dell Way	\N	AHKMONL	MT	54942	US	1	MBVMAWEJHO@dell.com	6203293451	3	6006258586421609	2009/12	user7477	password	23	40000	M
7478	IBFZNG	UAHREQYSRG	7077461075 Dell Way	\N	DDUQPID	DC	79374	US	1	UAHREQYSRG@dell.com	7077461075	3	7822146330494434	2011/11	user7478	password	67	20000	M
7479	XBLEWL	LOPCNITTLW	4477675878 Dell Way	\N	OBLWEPQ	TX	22870	US	1	LOPCNITTLW@dell.com	4477675878	4	1104581898543983	2008/09	user7479	password	85	100000	M
7480	JCQUOF	KQSSJLEGZF	4873819949 Dell Way	\N	RWKHMGK	TX	88627	US	1	KQSSJLEGZF@dell.com	4873819949	5	6188545249402524	2009/11	user7480	password	43	80000	M
7481	AMNFWE	XPNITTIYLE	1706973215 Dell Way	\N	JSQQDNN	ND	49419	US	1	XPNITTIYLE@dell.com	1706973215	5	3858815941028297	2010/08	user7481	password	40	60000	F
7482	VQZANO	OWHHEGTJPM	3533303603 Dell Way	\N	AGPNTEZ	SD	18441	US	1	OWHHEGTJPM@dell.com	3533303603	2	7437165991403163	2010/09	user7482	password	77	60000	F
7483	ULVIZR	QHWWAGMMGS	1766042138 Dell Way	\N	CULHTHJ	AK	57512	US	1	QHWWAGMMGS@dell.com	1766042138	4	2906727868597954	2012/01	user7483	password	56	80000	F
7484	JALBQT	XNTDZGKSJE	2529314715 Dell Way	\N	EQXLAXY	CA	57396	US	1	XNTDZGKSJE@dell.com	2529314715	5	6065217480063439	2011/09	user7484	password	20	20000	M
7485	MCIFAW	ZEVGONPTRG	6844272083 Dell Way	\N	QCGOBIC	IA	40129	US	1	ZEVGONPTRG@dell.com	6844272083	5	1161401495803147	2011/12	user7485	password	70	20000	F
7486	BKCXJG	TPVHFOZLFC	4384504084 Dell Way	\N	RTEAVKJ	MS	40311	US	1	TPVHFOZLFC@dell.com	4384504084	1	3911045415326953	2008/05	user7486	password	47	20000	M
7487	MCCTVS	PDXDCIIEAC	4490633404 Dell Way	\N	IBYSKLB	RI	65590	US	1	PDXDCIIEAC@dell.com	4490633404	5	9705094831995668	2011/01	user7487	password	69	40000	F
7488	UBZNQC	KUETDIUFRV	2761413847 Dell Way	\N	EKGPMAF	TX	90529	US	1	KUETDIUFRV@dell.com	2761413847	4	9473626937251540	2012/12	user7488	password	23	80000	M
7489	BFQDQK	HJOQDTIZYS	1455914721 Dell Way	\N	FOEFUBC	WV	71872	US	1	HJOQDTIZYS@dell.com	1455914721	5	6631606108974666	2008/07	user7489	password	63	20000	M
7490	GHKRPU	FGXZOXXHCL	8420466381 Dell Way	\N	MHGNKFF	MN	17152	US	1	FGXZOXXHCL@dell.com	8420466381	3	6906548990868033	2010/10	user7490	password	50	80000	F
7491	WJQQOW	ONLLKSNWEV	1394957687 Dell Way	\N	CSGIXSK	OK	37845	US	1	ONLLKSNWEV@dell.com	1394957687	1	1558023891877383	2010/11	user7491	password	25	40000	F
7492	TZTPNG	BYRTMNYIQQ	6967367074 Dell Way	\N	OYNHIGP	MA	47066	US	1	BYRTMNYIQQ@dell.com	6967367074	5	3333663094788790	2011/03	user7492	password	51	60000	F
7493	FDRLEQ	CXCQWKHMZF	9597438434 Dell Way	\N	AHOHXYS	NC	81720	US	1	CXCQWKHMZF@dell.com	9597438434	2	9973450967110694	2010/10	user7493	password	29	80000	M
7494	VBCLDA	OUWZBJZHKG	6249737438 Dell Way	\N	WSDUKRP	KY	10271	US	1	OUWZBJZHKG@dell.com	6249737438	4	8422251680400223	2011/05	user7494	password	73	60000	F
7495	WAOWPJ	TOKDNSOUOG	4983915216 Dell Way	\N	YJQPYZQ	NC	76883	US	1	TOKDNSOUOG@dell.com	4983915216	2	1899040888994932	2009/11	user7495	password	54	20000	M
7496	BYMKSA	VWOOKJDQHM	2110514080 Dell Way	\N	HXLHNZA	WI	32050	US	1	VWOOKJDQHM@dell.com	2110514080	1	1885115324985236	2011/03	user7496	password	89	80000	F
7497	LBXMXT	BLEKOUSACP	7975260089 Dell Way	\N	MJDLKCR	MT	31992	US	1	BLEKOUSACP@dell.com	7975260089	1	5323268740903586	2011/10	user7497	password	66	40000	M
7498	OSUITG	MEUHWVJLHT	4422823971 Dell Way	\N	PSERKRX	DE	85546	US	1	MEUHWVJLHT@dell.com	4422823971	5	6998197901993991	2008/02	user7498	password	59	80000	M
7499	JYOPKT	JRPFBBMUQE	2456244863 Dell Way	\N	ZHPRFTM	NE	69482	US	1	JRPFBBMUQE@dell.com	2456244863	4	8106910740956665	2011/03	user7499	password	62	20000	F
7500	ESOYCG	NHHPTCGYBN	7392975742 Dell Way	\N	NSSGFIX	LA	93948	US	1	NHHPTCGYBN@dell.com	7392975742	1	2525283380877226	2009/03	user7500	password	42	60000	M
7501	XLZDZG	KOZMUYOILG	5274468139 Dell Way	\N	BSMJQVH	KY	94627	US	1	KOZMUYOILG@dell.com	5274468139	4	2227545967791229	2012/03	user7501	password	20	80000	M
7502	ZVPGGE	GSZEHHQOJI	9415828094 Dell Way	\N	ATZWBIU	MT	99436	US	1	GSZEHHQOJI@dell.com	9415828094	2	2591846303548664	2012/01	user7502	password	76	100000	M
7503	KFCOLV	NPCVFQEORX	1355676627 Dell Way	\N	ONYWIMW	IA	80824	US	1	NPCVFQEORX@dell.com	1355676627	2	8290682224556805	2012/03	user7503	password	66	40000	F
7504	TUUOIK	QDQHIFYFTM	3079073238 Dell Way	\N	EPUQMAK	MT	32663	US	1	QDQHIFYFTM@dell.com	3079073238	2	4817657233215869	2012/08	user7504	password	75	80000	F
7505	PESZVV	QDDVCJOONE	1514638008 Dell Way	\N	IEQJPEQ	SD	56421	US	1	QDDVCJOONE@dell.com	1514638008	4	1962254646234214	2012/05	user7505	password	53	60000	M
7506	FLJABN	EWPNLDBQMF	1486320561 Dell Way	\N	HWULNPY	ND	37287	US	1	EWPNLDBQMF@dell.com	1486320561	3	6758663540240378	2010/11	user7506	password	30	80000	F
7507	NTJAYG	QLRUMIGSPD	1236299148 Dell Way	\N	MAQCYFK	AK	65071	US	1	QLRUMIGSPD@dell.com	1236299148	3	5216184047982097	2008/04	user7507	password	73	80000	F
7508	DTZJKL	BEXJLQYOCZ	5313419011 Dell Way	\N	FEXKOYA	NH	54709	US	1	BEXJLQYOCZ@dell.com	5313419011	4	8170358298812062	2009/07	user7508	password	80	40000	F
7509	WTRHUV	FEGVCVXBAC	3062503766 Dell Way	\N	ZKRYLGL	VT	14461	US	1	FEGVCVXBAC@dell.com	3062503766	1	6078829732723535	2008/07	user7509	password	79	100000	F
7510	NFBIKF	PFIKDKLGKW	8061110178 Dell Way	\N	XIHETEF	WY	40874	US	1	PFIKDKLGKW@dell.com	8061110178	1	8759517486672849	2011/01	user7510	password	26	20000	F
7511	EMQJCW	SNACYGNUEV	5363102390 Dell Way	\N	CJPHOPQ	KY	71915	US	1	SNACYGNUEV@dell.com	5363102390	5	7390814075246454	2011/02	user7511	password	87	80000	M
7512	PDRMVF	NYDULYYHAH	8948951691 Dell Way	\N	WIWMYFE	ME	27639	US	1	NYDULYYHAH@dell.com	8948951691	1	3832989147398621	2012/10	user7512	password	84	60000	M
7513	PXTUKS	YEDWDLXLIF	1166126663 Dell Way	\N	HUDNZOS	TX	62500	US	1	YEDWDLXLIF@dell.com	1166126663	4	4311551968567073	2012/02	user7513	password	39	60000	F
7514	BILUHP	YDTJBERHMM	9414898868 Dell Way	\N	KZLZRHO	OH	99039	US	1	YDTJBERHMM@dell.com	9414898868	4	1936207655817270	2009/03	user7514	password	27	40000	M
7515	OBUEZX	XJZCAGOMRN	4008334098 Dell Way	\N	YQFGFXF	DC	57219	US	1	XJZCAGOMRN@dell.com	4008334098	2	7223045195452870	2010/08	user7515	password	32	20000	M
7516	ZESWCB	WFCCTPTHNK	6283066106 Dell Way	\N	MTPJZTX	KS	21057	US	1	WFCCTPTHNK@dell.com	6283066106	4	8104845046065749	2011/10	user7516	password	56	80000	M
7517	GQCIMH	KOAZIIMSUG	9693580200 Dell Way	\N	HEGBBOE	NM	42285	US	1	KOAZIIMSUG@dell.com	9693580200	3	2433711604215205	2010/02	user7517	password	28	80000	M
7518	GBGNLU	OKDWXVQEDU	5687589075 Dell Way	\N	LEWAJMJ	KS	91680	US	1	OKDWXVQEDU@dell.com	5687589075	5	1581898414529860	2011/07	user7518	password	79	100000	M
7519	CLAXZL	AWJVNNYIYD	6773339410 Dell Way	\N	EYMRIUO	TN	65217	US	1	AWJVNNYIYD@dell.com	6773339410	3	2340211491100490	2010/06	user7519	password	70	60000	M
7520	TMWEMS	NIGBGOAKTZ	5079671750 Dell Way	\N	WKHRZDH	NJ	68100	US	1	NIGBGOAKTZ@dell.com	5079671750	1	1588424610439688	2008/09	user7520	password	85	100000	F
7521	UCQMPY	SRFHRPAQMK	7942516000 Dell Way	\N	YEJBMAS	WA	19296	US	1	SRFHRPAQMK@dell.com	7942516000	1	8002783795353026	2011/01	user7521	password	85	60000	F
7522	OYSMRJ	RYAHYRTJPY	6511530752 Dell Way	\N	SRKTJIV	CT	49005	US	1	RYAHYRTJPY@dell.com	6511530752	5	5082865787670016	2010/04	user7522	password	58	20000	F
7523	GOXQFV	RNUIGDYEWP	8115329847 Dell Way	\N	OPYXLCI	AR	91462	US	1	RNUIGDYEWP@dell.com	8115329847	3	2727445183321833	2009/08	user7523	password	49	80000	F
7524	IGLEYY	ZGFCFJZUYO	9208537430 Dell Way	\N	TWZVEBS	WV	65428	US	1	ZGFCFJZUYO@dell.com	9208537430	2	3431186295114458	2009/12	user7524	password	52	80000	F
7525	XWDWVK	BXPKWJJLCF	4244454619 Dell Way	\N	LXKMQKC	ND	74277	US	1	BXPKWJJLCF@dell.com	4244454619	5	6938725432381035	2012/07	user7525	password	80	80000	F
7526	ZPFJRD	ZCAILLLRXJ	8618046916 Dell Way	\N	CJAMLOE	SD	50797	US	1	ZCAILLLRXJ@dell.com	8618046916	4	1171403096988797	2011/05	user7526	password	49	80000	F
7527	RBRUAU	VJGGVXEEZN	2986478827 Dell Way	\N	EMZTRUF	MS	51244	US	1	VJGGVXEEZN@dell.com	2986478827	2	8838041473180056	2011/11	user7527	password	83	40000	M
7528	PCAJXK	PEFNJKNWOZ	9911117125 Dell Way	\N	WIQRNDD	OR	40246	US	1	PEFNJKNWOZ@dell.com	9911117125	2	3149663975462317	2012/09	user7528	password	33	60000	M
7529	FVTPLY	VYHFLDUKAC	7676487180 Dell Way	\N	BRPEUJN	RI	78106	US	1	VYHFLDUKAC@dell.com	7676487180	4	5201690744142980	2012/02	user7529	password	38	20000	M
7530	AUKYPJ	FUUJOFKRGB	8686569946 Dell Way	\N	HKWQXQK	NV	36526	US	1	FUUJOFKRGB@dell.com	8686569946	4	4913372658193112	2008/10	user7530	password	48	20000	M
7531	VCEEIZ	YSOECFKEMV	4310919641 Dell Way	\N	ACTQMKY	KY	99731	US	1	YSOECFKEMV@dell.com	4310919641	3	8080230196006597	2011/08	user7531	password	44	60000	M
7532	OTCNSV	BXXGHCSDCV	1177020271 Dell Way	\N	WTHGRQG	AL	20758	US	1	BXXGHCSDCV@dell.com	1177020271	5	7859100398141892	2009/05	user7532	password	55	100000	F
7533	QLXLMU	JTCLMFOHBH	1981759079 Dell Way	\N	PHYFOZJ	ND	81141	US	1	JTCLMFOHBH@dell.com	1981759079	5	2837678559124470	2011/11	user7533	password	46	40000	F
7534	HRVCBO	FMALAIMHXU	2914718596 Dell Way	\N	GDIFMXA	NE	85715	US	1	FMALAIMHXU@dell.com	2914718596	2	7402208514045925	2010/06	user7534	password	19	100000	F
7535	VZEKFR	LQSTDAQXGU	7375071989 Dell Way	\N	GMGEMVZ	NY	14297	US	1	LQSTDAQXGU@dell.com	7375071989	2	5582489297259599	2011/03	user7535	password	65	60000	F
7536	VZJNKZ	FDDFUAMOHY	2749333626 Dell Way	\N	ULKQLCR	DC	42373	US	1	FDDFUAMOHY@dell.com	2749333626	5	5843525499571115	2012/06	user7536	password	70	80000	F
7537	CFVCLY	FQTGCHNACZ	4620286040 Dell Way	\N	LTKNKOW	NJ	51549	US	1	FQTGCHNACZ@dell.com	4620286040	3	9253330627456308	2008/02	user7537	password	42	40000	F
7538	EHUCML	WSNDGOGGZZ	6520685526 Dell Way	\N	RMJGJZS	RI	50653	US	1	WSNDGOGGZZ@dell.com	6520685526	5	6423416888341308	2012/02	user7538	password	88	20000	F
7539	TFWEBP	SFWHLCHKTU	8457661742 Dell Way	\N	UZDURXF	IN	80492	US	1	SFWHLCHKTU@dell.com	8457661742	2	8810882979538293	2011/05	user7539	password	35	60000	M
7540	CSQSKW	OSHRZSKTMK	4875200641 Dell Way	\N	WGCUMJO	IN	66197	US	1	OSHRZSKTMK@dell.com	4875200641	1	9852695218287408	2011/08	user7540	password	59	80000	F
7541	FMTBBL	JSKBCENNBU	6112087867 Dell Way	\N	PVGYJOP	SD	69468	US	1	JSKBCENNBU@dell.com	6112087867	3	3620695174671710	2008/04	user7541	password	63	40000	M
7542	KKUVTN	GVQKJDLDSH	9178604900 Dell Way	\N	KRRYGMQ	TN	96328	US	1	GVQKJDLDSH@dell.com	9178604900	5	3037137394770980	2010/04	user7542	password	89	100000	M
7543	UTMHAH	XLQBXUTEEL	5539448576 Dell Way	\N	VDSITNH	NV	53880	US	1	XLQBXUTEEL@dell.com	5539448576	1	8114318608306349	2010/02	user7543	password	54	40000	M
7544	ZOXHMJ	YNGSHLXTHA	3247576531 Dell Way	\N	LPUZWLL	MA	68355	US	1	YNGSHLXTHA@dell.com	3247576531	5	7949587761890144	2011/02	user7544	password	66	80000	M
7545	OAFXYT	ERAPPUXQFM	3521306451 Dell Way	\N	KFJWRTN	VT	66028	US	1	ERAPPUXQFM@dell.com	3521306451	4	7872604582924397	2012/05	user7545	password	52	60000	F
7546	RKJKPB	LFQFCGLPRQ	1843986109 Dell Way	\N	YNHSBFI	KS	88066	US	1	LFQFCGLPRQ@dell.com	1843986109	2	3356904197018594	2010/10	user7546	password	67	40000	F
7547	BQUCCZ	TICATRSKQG	1490360102 Dell Way	\N	SIHYRPU	PA	88480	US	1	TICATRSKQG@dell.com	1490360102	2	6769467348232866	2011/07	user7547	password	78	80000	F
7548	QXHPRP	RRJJJUZQMH	1212701010 Dell Way	\N	XKYNFSJ	ID	11225	US	1	RRJJJUZQMH@dell.com	1212701010	1	6112559169065208	2012/10	user7548	password	73	60000	M
7549	BCIRTA	ACKUCAHJXS	6387801842 Dell Way	\N	ILYAVFA	TN	28187	US	1	ACKUCAHJXS@dell.com	6387801842	4	9890112339984628	2009/03	user7549	password	66	60000	F
7550	ABAACD	LXFLFOJXXU	3205550369 Dell Way	\N	WXPBYLG	NC	22080	US	1	LXFLFOJXXU@dell.com	3205550369	5	3708326119929552	2012/04	user7550	password	57	100000	F
7551	OYNRJK	WVPLENJZJG	5120594351 Dell Way	\N	PLFARTE	WA	69141	US	1	WVPLENJZJG@dell.com	5120594351	5	9850784521549940	2008/10	user7551	password	46	60000	M
7552	XGCHDY	XPCKYCUFRF	8258307337 Dell Way	\N	KRXEWVV	IN	71904	US	1	XPCKYCUFRF@dell.com	8258307337	2	5166574622504413	2008/11	user7552	password	31	20000	F
7553	HJGFGV	IRTLLZCRKU	6093099541 Dell Way	\N	OOQKJYC	FL	32157	US	1	IRTLLZCRKU@dell.com	6093099541	2	2065144276246428	2011/06	user7553	password	35	20000	M
7554	MHBHQT	BBFBDWLXLZ	8613601934 Dell Way	\N	OWJMYOS	MT	92951	US	1	BBFBDWLXLZ@dell.com	8613601934	2	4375499226152897	2008/05	user7554	password	32	60000	M
7555	GWGAXH	FZKBKINJWJ	6212670784 Dell Way	\N	TJIHBVF	WA	20863	US	1	FZKBKINJWJ@dell.com	6212670784	1	5109411765355617	2011/07	user7555	password	23	20000	F
7556	HBIPGH	ZHRIVBEEUN	9078793318 Dell Way	\N	MBPIHNL	TX	57073	US	1	ZHRIVBEEUN@dell.com	9078793318	4	1693901461549103	2012/09	user7556	password	53	40000	M
7557	VWYCVG	UDBVIGQWSS	6145029329 Dell Way	\N	LBZZMWM	MA	53738	US	1	UDBVIGQWSS@dell.com	6145029329	2	2416910272091627	2008/08	user7557	password	81	100000	F
7558	VZICTM	EPUKGQDYCE	5043166043 Dell Way	\N	YBQUOAH	DC	44359	US	1	EPUKGQDYCE@dell.com	5043166043	1	1066958012059330	2009/01	user7558	password	53	20000	F
7559	VGUHLK	CVQTZPVDOX	3031838451 Dell Way	\N	UJMVRQF	CO	83648	US	1	CVQTZPVDOX@dell.com	3031838451	3	8958320082165302	2011/08	user7559	password	85	60000	M
7560	SVHDXD	URCKMGZKBI	3037399832 Dell Way	\N	XXZNCCI	KY	58736	US	1	URCKMGZKBI@dell.com	3037399832	1	2193759706337005	2008/07	user7560	password	89	100000	F
7561	GAIKVZ	MFMTEXUNUS	3700918659 Dell Way	\N	NIUQQDE	UT	27625	US	1	MFMTEXUNUS@dell.com	3700918659	1	8005774106364698	2009/11	user7561	password	31	60000	M
7562	MYTMKY	YEDVZRPREX	6233723594 Dell Way	\N	MVOPZLU	IL	53429	US	1	YEDVZRPREX@dell.com	6233723594	3	4555367634631694	2011/02	user7562	password	41	40000	F
7563	BSLARQ	EMPVCGAASV	9148327253 Dell Way	\N	OIVADCN	OH	68570	US	1	EMPVCGAASV@dell.com	9148327253	3	7779811973683537	2009/09	user7563	password	75	40000	F
7564	GICWNP	LJRSKRKFGS	5870602793 Dell Way	\N	BHVDUNU	OH	10129	US	1	LJRSKRKFGS@dell.com	5870602793	5	7501588846556843	2009/03	user7564	password	30	60000	M
7565	GLCWWL	NPVEZBLSDS	8179425506 Dell Way	\N	NGMBBEB	NE	19229	US	1	NPVEZBLSDS@dell.com	8179425506	5	3981502817478031	2012/06	user7565	password	83	40000	M
7566	ZCULPJ	HUJJFBMXPS	1080457666 Dell Way	\N	KRTOTJR	NC	33879	US	1	HUJJFBMXPS@dell.com	1080457666	3	7740356662310661	2012/09	user7566	password	66	100000	M
7567	MIKWPE	FZJGLHWERN	3686125073 Dell Way	\N	YGGHYUO	WI	37262	US	1	FZJGLHWERN@dell.com	3686125073	5	1334184438455849	2012/09	user7567	password	80	60000	F
7568	GHRLMR	VTCCPGUDEA	5734876387 Dell Way	\N	KMZEAXM	KS	78644	US	1	VTCCPGUDEA@dell.com	5734876387	2	5587143353186548	2009/09	user7568	password	60	80000	F
7569	HBMYWG	AYVHTZMUJY	9282749410 Dell Way	\N	TOZQAHK	ND	61791	US	1	AYVHTZMUJY@dell.com	9282749410	5	3656602095346898	2010/07	user7569	password	39	80000	M
7570	USMATL	WBEVNYFMRT	6449787847 Dell Way	\N	LITTTII	NY	32622	US	1	WBEVNYFMRT@dell.com	6449787847	1	8303818896412850	2012/12	user7570	password	49	80000	M
7571	XSLJPN	OKAMQNEJYN	5475378410 Dell Way	\N	CRGLZYR	NH	19818	US	1	OKAMQNEJYN@dell.com	5475378410	3	1685767193324864	2012/03	user7571	password	74	100000	M
7572	FFMTTX	TGNHKWFYZX	3827256432 Dell Way	\N	FLXDDNG	NJ	12106	US	1	TGNHKWFYZX@dell.com	3827256432	3	2958679403178394	2008/05	user7572	password	27	40000	M
7573	QBINVO	BCZYIXYGCJ	9207074780 Dell Way	\N	DFMRMCS	RI	68621	US	1	BCZYIXYGCJ@dell.com	9207074780	5	1302441027015447	2008/03	user7573	password	62	80000	F
7574	YEBMGD	MFMJDSMNWR	8391867419 Dell Way	\N	ANEDFYU	CT	82166	US	1	MFMJDSMNWR@dell.com	8391867419	1	9838807096239180	2010/10	user7574	password	33	40000	F
7575	GWHKIM	WSQOEELWFY	7607271129 Dell Way	\N	AIEYDIT	WI	54132	US	1	WSQOEELWFY@dell.com	7607271129	2	3879373149480671	2012/10	user7575	password	42	40000	M
7576	QPYCMR	TBVXMRCLSL	7802418855 Dell Way	\N	QQOYKNL	CT	89316	US	1	TBVXMRCLSL@dell.com	7802418855	1	6716697597410530	2008/04	user7576	password	36	80000	M
7577	FVJWOL	SMXJPJBAZS	6459810106 Dell Way	\N	PYCCJGZ	CT	38364	US	1	SMXJPJBAZS@dell.com	6459810106	2	6389590117149056	2012/12	user7577	password	54	20000	M
7578	WYIHQU	FAJOCKOVZM	1687371996 Dell Way	\N	YCWEBZM	NV	28194	US	1	FAJOCKOVZM@dell.com	1687371996	3	2247732696123421	2010/08	user7578	password	83	60000	M
7579	FTFAYG	KNJUBEUOCW	7673915914 Dell Way	\N	KGYKSPP	SD	21275	US	1	KNJUBEUOCW@dell.com	7673915914	2	7617618476040662	2011/10	user7579	password	40	100000	M
7580	NWMUGA	DBCHWQJSBQ	2103721365 Dell Way	\N	RMJGBEK	SD	58446	US	1	DBCHWQJSBQ@dell.com	2103721365	3	4166117734275758	2010/04	user7580	password	83	100000	F
7581	KSKKVM	MDIDNBFDSR	5946716668 Dell Way	\N	MZTRJOF	MS	99777	US	1	MDIDNBFDSR@dell.com	5946716668	5	3680873710662127	2010/11	user7581	password	51	100000	M
7582	XGLJTO	SWBTCFMTSM	4080398705 Dell Way	\N	MJVBOIB	CO	33972	US	1	SWBTCFMTSM@dell.com	4080398705	3	2213932612910866	2012/05	user7582	password	70	80000	M
7583	DBKSTH	UNJZZDSLQB	1458302998 Dell Way	\N	HRQQSTX	AZ	36373	US	1	UNJZZDSLQB@dell.com	1458302998	5	7312733717728407	2011/07	user7583	password	44	100000	M
7584	UQJBKW	LKWPCIFEQX	5534886294 Dell Way	\N	UHQNFSU	IA	61664	US	1	LKWPCIFEQX@dell.com	5534886294	1	2244817629456520	2012/12	user7584	password	73	80000	M
7585	DSZADK	WTNEYRVWLC	9130479951 Dell Way	\N	MYHETOT	ID	60218	US	1	WTNEYRVWLC@dell.com	9130479951	1	5510891130659730	2011/10	user7585	password	23	80000	F
7586	BUQMQJ	ZVIQRECTRA	6821217142 Dell Way	\N	BWUPQBD	MT	25317	US	1	ZVIQRECTRA@dell.com	6821217142	1	9412407125812024	2011/12	user7586	password	47	100000	M
7587	AHKKGG	SXXWAROASK	9803638436 Dell Way	\N	VHAWLOB	CA	77256	US	1	SXXWAROASK@dell.com	9803638436	5	7494115009438247	2009/08	user7587	password	53	60000	M
7588	XUEDMC	BJCSYDLIYT	4503966501 Dell Way	\N	JVFXWHR	TX	20263	US	1	BJCSYDLIYT@dell.com	4503966501	2	7668996474705637	2012/08	user7588	password	65	80000	F
7589	VXYXZI	ASGDDOCXYY	3064082581 Dell Way	\N	CWVJNRM	VT	90997	US	1	ASGDDOCXYY@dell.com	3064082581	4	5913956888485700	2012/07	user7589	password	90	80000	F
7590	YQLGQD	MUHBXEZVGV	7812228447 Dell Way	\N	QQJICGF	KY	13319	US	1	MUHBXEZVGV@dell.com	7812228447	2	6252304911613465	2011/12	user7590	password	21	80000	M
7591	MXFQKA	XLXBKTIGKY	5309974535 Dell Way	\N	PSBWXKX	NY	64854	US	1	XLXBKTIGKY@dell.com	5309974535	3	5891306404490024	2010/02	user7591	password	26	20000	F
7592	IQKINV	GOGAWNKVCC	4605961644 Dell Way	\N	WZAGWSW	KY	21119	US	1	GOGAWNKVCC@dell.com	4605961644	5	2930195177439600	2010/11	user7592	password	33	100000	F
7593	PEALLP	SLMFVHIYDI	1200720022 Dell Way	\N	ZKERGNV	NM	45337	US	1	SLMFVHIYDI@dell.com	1200720022	1	3400748675223440	2009/12	user7593	password	73	100000	F
7594	THQJAB	VGXCPWFXVQ	3235929181 Dell Way	\N	BNWPINZ	KY	69557	US	1	VGXCPWFXVQ@dell.com	3235929181	3	6931581029202790	2008/06	user7594	password	79	80000	M
7595	LDTNYA	KAPHGMCWOQ	6020082511 Dell Way	\N	TDYGDHX	LA	90555	US	1	KAPHGMCWOQ@dell.com	6020082511	2	4055544199887663	2009/02	user7595	password	24	100000	F
7596	WJFWUG	MBMYEJMUCQ	3519490671 Dell Way	\N	TITBGDY	SC	54373	US	1	MBMYEJMUCQ@dell.com	3519490671	1	6819727515336127	2009/01	user7596	password	85	40000	F
7597	DCEKOG	WNKGAEJQYS	6749555768 Dell Way	\N	JZYMXTZ	FL	93204	US	1	WNKGAEJQYS@dell.com	6749555768	3	9717358235269786	2010/10	user7597	password	45	80000	M
7598	OCLVZZ	FGZKPPIHZI	8620207624 Dell Way	\N	FMFYMKW	CT	98589	US	1	FGZKPPIHZI@dell.com	8620207624	4	8015558331273497	2009/05	user7598	password	67	80000	F
7599	DPLCVR	CFHROORWUE	3474440804 Dell Way	\N	CTQNQTM	MN	50184	US	1	CFHROORWUE@dell.com	3474440804	4	8535313076805324	2012/06	user7599	password	41	20000	F
7600	UFXMHD	TYSIQOCURV	5390801650 Dell Way	\N	LELFRXQ	WA	65017	US	1	TYSIQOCURV@dell.com	5390801650	5	1853289934340864	2012/12	user7600	password	31	60000	F
7601	CBLGUK	YDBNFVEBHI	2263446836 Dell Way	\N	NMZLDYB	NJ	84579	US	1	YDBNFVEBHI@dell.com	2263446836	3	8264425573404879	2009/01	user7601	password	89	60000	F
7602	LRWVPZ	WCFSGGZPUM	2394206697 Dell Way	\N	PFPNGGJ	MD	69587	US	1	WCFSGGZPUM@dell.com	2394206697	4	7118552656378598	2008/02	user7602	password	73	60000	M
7603	QKKQGM	VZTCZIXLXC	6571487465 Dell Way	\N	BLJHUTY	WA	54307	US	1	VZTCZIXLXC@dell.com	6571487465	1	6768090641591699	2009/08	user7603	password	50	20000	F
7604	WQHIMG	CPFKMRIPST	8621713365 Dell Way	\N	YZOSXMF	NC	60157	US	1	CPFKMRIPST@dell.com	8621713365	5	2690245982725173	2009/11	user7604	password	33	20000	M
7605	MMATOP	ZZCQIRICQH	8887303384 Dell Way	\N	QIFDOTR	MA	69976	US	1	ZZCQIRICQH@dell.com	8887303384	4	6239716776646674	2008/10	user7605	password	27	60000	F
7606	EIWUHW	WXEOGHEOYM	7942220203 Dell Way	\N	TBANTLE	NJ	19523	US	1	WXEOGHEOYM@dell.com	7942220203	4	9365160931833088	2012/04	user7606	password	35	20000	M
7607	CVXZSV	EGBLKQJXKL	4615787615 Dell Way	\N	YXFJCVM	UT	58108	US	1	EGBLKQJXKL@dell.com	4615787615	4	8425528979394586	2011/11	user7607	password	50	80000	M
7608	JSKEXQ	GIBWSYHEXE	5967162527 Dell Way	\N	JGHETDS	DC	93256	US	1	GIBWSYHEXE@dell.com	5967162527	4	7889229936990888	2012/07	user7608	password	50	40000	F
7609	VODMUM	NRFMYJJDTQ	3348577371 Dell Way	\N	KYJORNM	HI	36126	US	1	NRFMYJJDTQ@dell.com	3348577371	2	8312727602198721	2011/07	user7609	password	22	60000	F
7610	FAXROP	XAOHKSABDZ	1336850973 Dell Way	\N	KRQYEWF	MI	18242	US	1	XAOHKSABDZ@dell.com	1336850973	1	6968718576710672	2008/09	user7610	password	74	40000	M
7611	RZGHWH	WDRODTRDDJ	4585379487 Dell Way	\N	UCOQIAT	KY	24169	US	1	WDRODTRDDJ@dell.com	4585379487	3	8726457005832345	2008/09	user7611	password	60	100000	M
7612	WDODAR	VOVOGZSPTU	2522639883 Dell Way	\N	DJCDDMI	MT	91888	US	1	VOVOGZSPTU@dell.com	2522639883	4	6819277926813812	2011/07	user7612	password	43	60000	M
7613	XTSPOG	LDNKVCDQGN	7984562028 Dell Way	\N	TKRFSED	VA	87832	US	1	LDNKVCDQGN@dell.com	7984562028	4	4756684604100883	2008/03	user7613	password	26	20000	M
7614	VQNCCQ	PMMSQDYEWJ	3678434484 Dell Way	\N	VCBAFYW	AK	63473	US	1	PMMSQDYEWJ@dell.com	3678434484	1	8415015935432167	2010/03	user7614	password	75	40000	M
7615	IJXYYK	LRBOQFLZBO	4861394087 Dell Way	\N	BCUAZUP	ID	92805	US	1	LRBOQFLZBO@dell.com	4861394087	4	1848451635800302	2009/12	user7615	password	84	60000	F
7616	VMGFYX	GMNMYNOMOQ	1641098790 Dell Way	\N	HOPBEWZ	NH	59828	US	1	GMNMYNOMOQ@dell.com	1641098790	5	5430178407113999	2012/05	user7616	password	75	80000	M
7617	BZTYGG	MSEZHROXYD	4926580756 Dell Way	\N	NAHKZXY	AR	73935	US	1	MSEZHROXYD@dell.com	4926580756	1	1480711408890783	2009/10	user7617	password	82	40000	M
7618	QFBWSU	BRBSGZRJNR	3734005383 Dell Way	\N	QXQOVSG	IL	75554	US	1	BRBSGZRJNR@dell.com	3734005383	3	5945932118222118	2008/10	user7618	password	44	100000	M
7619	LRRFTJ	HLQHDZUUQS	4786082453 Dell Way	\N	LEODKVW	OK	39383	US	1	HLQHDZUUQS@dell.com	4786082453	5	1833443100564181	2011/09	user7619	password	23	40000	F
7620	TLDDTO	TASSVMINYN	3755975248 Dell Way	\N	BCXXYQF	MA	57764	US	1	TASSVMINYN@dell.com	3755975248	1	3143802728503942	2009/05	user7620	password	63	20000	M
7621	THOIAP	ATLNCYLPAN	9305938100 Dell Way	\N	NXMEDWR	ME	12127	US	1	ATLNCYLPAN@dell.com	9305938100	5	4662931022234261	2010/12	user7621	password	35	40000	F
7622	VPGKQZ	VDCUPSUCFS	9037276252 Dell Way	\N	PJVMBGM	WV	14815	US	1	VDCUPSUCFS@dell.com	9037276252	3	9977851688396188	2008/10	user7622	password	33	100000	F
7623	LJBLEE	OZTGUWLNMV	6667190100 Dell Way	\N	IYWPKVQ	IN	43152	US	1	OZTGUWLNMV@dell.com	6667190100	3	2631426014937460	2012/05	user7623	password	61	40000	M
7624	QTYVHX	OOSLZFXVNV	1709292341 Dell Way	\N	RCGNTOX	LA	10878	US	1	OOSLZFXVNV@dell.com	1709292341	2	4512082690373063	2011/07	user7624	password	26	40000	F
7625	BDPYSD	RDDWBYKWQM	1952819167 Dell Way	\N	DEGSBPS	CT	84885	US	1	RDDWBYKWQM@dell.com	1952819167	5	4205378153827041	2009/02	user7625	password	64	40000	F
7626	GFZJXC	MTDLDABQEF	7083564325 Dell Way	\N	WWGMPKI	NY	28398	US	1	MTDLDABQEF@dell.com	7083564325	5	4005079212598503	2009/03	user7626	password	61	60000	F
7627	OXHRKB	UVEVXVZDRV	3823473235 Dell Way	\N	JEKUMCZ	DE	11749	US	1	UVEVXVZDRV@dell.com	3823473235	3	2868563906755298	2012/01	user7627	password	63	60000	M
7628	YDJZYF	DTCYSFQOPV	3836499224 Dell Way	\N	ZJHCJMC	NV	95572	US	1	DTCYSFQOPV@dell.com	3836499224	3	9841300854925068	2012/01	user7628	password	85	100000	F
7629	HVCMZV	OYOUPDJKCT	1977461354 Dell Way	\N	SECEHTD	NJ	40506	US	1	OYOUPDJKCT@dell.com	1977461354	3	4432984706945717	2008/06	user7629	password	58	40000	F
7630	QUGMJF	BEUEOFGHXL	8979739675 Dell Way	\N	KCTEFJN	KS	93381	US	1	BEUEOFGHXL@dell.com	8979739675	2	4148216134868562	2010/09	user7630	password	62	20000	F
7631	WOWCPA	XUOCBWAMGC	9145423053 Dell Way	\N	GKIQYQO	SD	11029	US	1	XUOCBWAMGC@dell.com	9145423053	2	7236041529104114	2010/04	user7631	password	30	40000	M
7632	AMNAJH	PLILMVROBC	3198273645 Dell Way	\N	XSAOGVO	DE	17774	US	1	PLILMVROBC@dell.com	3198273645	4	4752990984357894	2010/01	user7632	password	40	60000	M
7633	VLXCBJ	KMVGEKIGHA	6719985838 Dell Way	\N	HVHDKLF	NM	22210	US	1	KMVGEKIGHA@dell.com	6719985838	1	2932768078055233	2012/06	user7633	password	74	80000	M
7634	RWZBHM	XNQIWXPWEL	9597619534 Dell Way	\N	EIVPNMT	DE	58163	US	1	XNQIWXPWEL@dell.com	9597619534	1	1176824390422552	2011/11	user7634	password	88	60000	M
7635	YMBKJP	ARLYHHCTLK	6571853327 Dell Way	\N	PBYBUDP	PA	31872	US	1	ARLYHHCTLK@dell.com	6571853327	3	2183036645408720	2010/11	user7635	password	82	60000	F
7636	YYSNZK	YXRGAKSLZT	9056809749 Dell Way	\N	KBONRIT	IL	82809	US	1	YXRGAKSLZT@dell.com	9056809749	5	7308398697990925	2011/05	user7636	password	22	80000	F
7637	UGIEFG	WLGHESHXCJ	3973591625 Dell Way	\N	MQAVJHQ	IL	24221	US	1	WLGHESHXCJ@dell.com	3973591625	1	6022037514951081	2009/10	user7637	password	84	20000	F
7638	GJFMGR	TNVLUTNDGD	2527025890 Dell Way	\N	EBNLSVP	AL	88331	US	1	TNVLUTNDGD@dell.com	2527025890	3	6907793041318656	2008/08	user7638	password	68	40000	M
7639	XUEPNS	KZNENRKRVM	5790842195 Dell Way	\N	FHEAWFW	AR	65243	US	1	KZNENRKRVM@dell.com	5790842195	1	2869809465948492	2009/06	user7639	password	30	20000	F
7640	JSUBDT	OIGFSXBFCI	4569007153 Dell Way	\N	JDFOZGE	MT	44478	US	1	OIGFSXBFCI@dell.com	4569007153	4	8434858791995794	2010/11	user7640	password	22	100000	M
7641	VZTPOB	VTUTVZWDJZ	8098042314 Dell Way	\N	IYZPDNZ	NC	32848	US	1	VTUTVZWDJZ@dell.com	8098042314	1	2236886597238481	2012/01	user7641	password	72	80000	M
7642	MGNOCH	JWCJSFSSOR	6139753235 Dell Way	\N	RDUECIL	VA	48274	US	1	JWCJSFSSOR@dell.com	6139753235	4	4905709767248482	2009/06	user7642	password	48	100000	M
7643	YJUGSQ	IBIOUACLSG	5042616772 Dell Way	\N	GXIPIFA	VA	95725	US	1	IBIOUACLSG@dell.com	5042616772	2	4349827066063881	2012/01	user7643	password	22	100000	F
7644	VBDMJF	UYAVBLOHSL	2473812095 Dell Way	\N	QITVIQU	RI	87775	US	1	UYAVBLOHSL@dell.com	2473812095	4	9011795811355116	2009/06	user7644	password	39	20000	F
7645	LNWQIU	QEVCSDVDTD	3888348063 Dell Way	\N	XPLOJFL	NC	87894	US	1	QEVCSDVDTD@dell.com	3888348063	4	3819841227028519	2011/10	user7645	password	76	20000	F
7646	RRRLIV	HKOKGSEJPT	2959631273 Dell Way	\N	VECBPQX	WA	46405	US	1	HKOKGSEJPT@dell.com	2959631273	3	2954003055579960	2008/07	user7646	password	58	80000	F
7647	FDOALZ	PWFHAPWTKB	2120969716 Dell Way	\N	WLRNIPX	ND	21470	US	1	PWFHAPWTKB@dell.com	2120969716	3	7384710251819343	2011/04	user7647	password	88	100000	F
7648	OYVNNR	TURIRLTSHE	8182705273 Dell Way	\N	JUNYRBC	SD	68056	US	1	TURIRLTSHE@dell.com	8182705273	3	9140462630894036	2011/05	user7648	password	40	40000	F
7649	DVUVPP	MYGXRYFVIZ	9676614239 Dell Way	\N	JHRKJMB	DE	98549	US	1	MYGXRYFVIZ@dell.com	9676614239	5	4254707992542535	2009/03	user7649	password	66	60000	F
7650	MFRBSQ	HQHGVDOVMW	3981059242 Dell Way	\N	MWFZYKZ	VT	40899	US	1	HQHGVDOVMW@dell.com	3981059242	1	6337580399587751	2012/07	user7650	password	67	60000	M
7651	JNMZUD	HAYKPTWLGT	1167934292 Dell Way	\N	RGRCFPL	NC	77989	US	1	HAYKPTWLGT@dell.com	1167934292	3	3953837134875357	2011/01	user7651	password	26	20000	M
7652	PBISII	RSYLOKSIBZ	6902315740 Dell Way	\N	ZEEOPSI	NH	34474	US	1	RSYLOKSIBZ@dell.com	6902315740	2	3492697134613991	2011/05	user7652	password	75	40000	F
7653	CCTLUM	KGBUYJWXIA	4374469241 Dell Way	\N	CXPVGFC	VA	56038	US	1	KGBUYJWXIA@dell.com	4374469241	4	8977264440618456	2008/01	user7653	password	41	40000	F
7654	BSYOCE	PXDYTBHUDF	9965468826 Dell Way	\N	KZLPCJC	MN	11981	US	1	PXDYTBHUDF@dell.com	9965468826	4	1615835931617766	2009/11	user7654	password	34	40000	M
7655	EYSJNQ	MMJOUESZOR	8893686602 Dell Way	\N	LETUGFV	ID	84418	US	1	MMJOUESZOR@dell.com	8893686602	3	7442873966880143	2008/12	user7655	password	41	40000	M
7656	BPLRCX	AQRFIRTACX	5664254662 Dell Way	\N	TWEZRLU	ND	11209	US	1	AQRFIRTACX@dell.com	5664254662	4	9790767517406494	2012/12	user7656	password	82	100000	M
7657	HNQFOH	XUPONQRLKO	1505310174 Dell Way	\N	QJFBEUC	OH	51932	US	1	XUPONQRLKO@dell.com	1505310174	3	4561356940306723	2012/05	user7657	password	86	40000	M
7658	OLNWJH	MXVCOHMCXW	9996702408 Dell Way	\N	IZADBSP	CO	32819	US	1	MXVCOHMCXW@dell.com	9996702408	1	7000294857192785	2012/04	user7658	password	63	60000	M
7659	DJCLVA	HXPOKRMGAL	9322686806 Dell Way	\N	HENAUQG	RI	70578	US	1	HXPOKRMGAL@dell.com	9322686806	4	9640658519696444	2010/03	user7659	password	69	80000	M
7660	UDKVKH	KZSCLYDXGH	7067260572 Dell Way	\N	KGBBNVS	ME	58572	US	1	KZSCLYDXGH@dell.com	7067260572	5	7799080204684288	2009/08	user7660	password	42	20000	M
7661	SZEAKE	TMPRPNYWXE	1633808316 Dell Way	\N	YYRURCI	KY	16014	US	1	TMPRPNYWXE@dell.com	1633808316	4	7472379732877017	2009/11	user7661	password	54	20000	M
7662	RDHVWT	LOJYMGWREV	2995253829 Dell Way	\N	IZNLHWN	KY	61766	US	1	LOJYMGWREV@dell.com	2995253829	4	5330984923988581	2011/11	user7662	password	45	60000	F
7663	RGXLRM	UQZBMQGIZF	7535289268 Dell Way	\N	VKMRXVG	CT	62803	US	1	UQZBMQGIZF@dell.com	7535289268	5	5135255301836878	2008/04	user7663	password	53	80000	F
7664	KFEWAV	VBHMHQLNLW	8893852035 Dell Way	\N	ZDTVJXK	CA	77879	US	1	VBHMHQLNLW@dell.com	8893852035	1	1099255525972694	2009/12	user7664	password	55	80000	F
7665	RPFNLH	VXOLJCXFCA	6889473645 Dell Way	\N	ZXJXILQ	GA	68659	US	1	VXOLJCXFCA@dell.com	6889473645	3	6627780989743770	2008/04	user7665	password	77	100000	M
7666	AJJHEH	WPRYMXAMWY	6361870455 Dell Way	\N	WTHIKMZ	AZ	13651	US	1	WPRYMXAMWY@dell.com	6361870455	2	4202846215572208	2010/02	user7666	password	38	60000	F
7667	RSPZPF	QOSNOFKNBE	6881930440 Dell Way	\N	UKOGJQH	WI	88162	US	1	QOSNOFKNBE@dell.com	6881930440	2	9578442410100252	2012/10	user7667	password	47	80000	M
7668	AOCGFQ	YSFEDSFHNQ	3918976430 Dell Way	\N	WTZNBYJ	OK	37926	US	1	YSFEDSFHNQ@dell.com	3918976430	4	1972569127101451	2011/04	user7668	password	63	80000	M
7669	TZAJXT	PBWIHEVXAP	3393333310 Dell Way	\N	XNRWXJE	HI	13747	US	1	PBWIHEVXAP@dell.com	3393333310	5	3727295716293156	2012/09	user7669	password	27	80000	M
7670	EAOXPQ	UXYYTWZJTN	7714380146 Dell Way	\N	APKKTQL	AL	62657	US	1	UXYYTWZJTN@dell.com	7714380146	5	3382582496851683	2012/07	user7670	password	84	20000	M
7671	MZDCTB	ASVWSEQFEF	2089598679 Dell Way	\N	QPZHAAW	RI	93331	US	1	ASVWSEQFEF@dell.com	2089598679	4	5214719540905208	2008/09	user7671	password	19	60000	M
7672	EPKFQD	AMVFDBKISZ	7552017163 Dell Way	\N	IZZIVUG	WI	48504	US	1	AMVFDBKISZ@dell.com	7552017163	5	2135469114407897	2011/06	user7672	password	75	100000	F
7673	FDRJDE	FJHGTQYSZX	1319687832 Dell Way	\N	SHTMORX	IL	68955	US	1	FJHGTQYSZX@dell.com	1319687832	1	2168420974165201	2012/12	user7673	password	32	20000	F
7674	XJFBPO	JVHAUZZSSH	9111080883 Dell Way	\N	LEVDCCU	CT	22826	US	1	JVHAUZZSSH@dell.com	9111080883	5	1618370707146823	2008/12	user7674	password	26	100000	F
7675	IBYWLU	DLODLGWSSA	8711040397 Dell Way	\N	NVDQPGU	MO	29076	US	1	DLODLGWSSA@dell.com	8711040397	3	2797243470326066	2012/08	user7675	password	59	40000	M
7676	NDCHHO	WLZDHRVIFQ	1963209424 Dell Way	\N	LWFSQSX	MS	37014	US	1	WLZDHRVIFQ@dell.com	1963209424	3	8957713303621859	2011/09	user7676	password	57	20000	M
7677	QMEEJP	EMWVIEBYQX	1626696300 Dell Way	\N	EINXFAE	KY	54498	US	1	EMWVIEBYQX@dell.com	1626696300	1	3169424530118704	2011/03	user7677	password	27	40000	M
7678	HKBXOO	UKWZLVPIZX	6686401065 Dell Way	\N	WWDXBMK	CT	55367	US	1	UKWZLVPIZX@dell.com	6686401065	4	7446313204243780	2011/12	user7678	password	49	20000	F
7679	MYZBTK	YSVTIETGBQ	1872586747 Dell Way	\N	KYSWIVJ	WV	61575	US	1	YSVTIETGBQ@dell.com	1872586747	4	6006549044512213	2010/10	user7679	password	88	20000	M
7680	YBMIAF	ETNIMTJDDI	7996889368 Dell Way	\N	VAQQKPF	MO	39508	US	1	ETNIMTJDDI@dell.com	7996889368	1	1957338467240333	2011/01	user7680	password	79	80000	F
7681	IACNEW	ANJUWMXFHX	8999403347 Dell Way	\N	WYILEUU	WI	82765	US	1	ANJUWMXFHX@dell.com	8999403347	4	8548180718906225	2011/05	user7681	password	87	20000	F
7682	BPOXQB	HKYUIDCFZA	9879607552 Dell Way	\N	OLFIFED	CA	87111	US	1	HKYUIDCFZA@dell.com	9879607552	5	3018000508192926	2012/11	user7682	password	61	100000	F
7683	DXCEFM	CZUFBAFCOQ	5875903827 Dell Way	\N	HXVLBYI	AR	78804	US	1	CZUFBAFCOQ@dell.com	5875903827	5	6923537859693170	2008/12	user7683	password	27	40000	M
7684	GLBSOB	NUCOZEDPMB	8138186526 Dell Way	\N	LYCJGED	RI	22328	US	1	NUCOZEDPMB@dell.com	8138186526	5	1945023175794631	2012/03	user7684	password	89	20000	M
7685	BXFCKZ	EZYJDOVEZT	7138363716 Dell Way	\N	HJZLMTP	IL	71705	US	1	EZYJDOVEZT@dell.com	7138363716	2	8912714314647020	2011/05	user7685	password	56	80000	F
7686	SVSRZR	QIVEDZEXGO	2791142844 Dell Way	\N	WSBQHII	WV	59358	US	1	QIVEDZEXGO@dell.com	2791142844	4	9389503726270052	2011/05	user7686	password	33	60000	F
7687	XDDPTM	KYQJDNQRKJ	5696814915 Dell Way	\N	SAQBJPP	ND	29452	US	1	KYQJDNQRKJ@dell.com	5696814915	2	6058383169583977	2011/09	user7687	password	70	80000	M
7688	WFPJQO	AARNRJYABZ	9966855545 Dell Way	\N	QCIFSXL	HI	25184	US	1	AARNRJYABZ@dell.com	9966855545	5	8936975180171431	2011/07	user7688	password	70	60000	M
7689	IYLWYL	NMCXLCYKTB	7118487218 Dell Way	\N	TYTQKZU	MA	92113	US	1	NMCXLCYKTB@dell.com	7118487218	1	5458275175187737	2009/09	user7689	password	40	80000	M
7690	TOPFCB	IZMKYXEAQC	2190539446 Dell Way	\N	TGNSBXQ	OR	99373	US	1	IZMKYXEAQC@dell.com	2190539446	1	7144204913638533	2010/11	user7690	password	41	20000	F
7691	XKOZSO	MDMJHMAKGH	5134526730 Dell Way	\N	XZIUQCU	PA	30376	US	1	MDMJHMAKGH@dell.com	5134526730	1	1731008184608072	2011/05	user7691	password	55	80000	M
7692	BRMPDP	CNWPNGVUEV	5672374697 Dell Way	\N	DYLFSEL	FL	43794	US	1	CNWPNGVUEV@dell.com	5672374697	5	7801102573517711	2008/08	user7692	password	56	20000	F
7693	ARLPTY	MILTEFXZJV	7509736475 Dell Way	\N	KOOPASZ	MT	71138	US	1	MILTEFXZJV@dell.com	7509736475	3	3852721119765192	2009/08	user7693	password	62	40000	F
7694	BWBZIJ	KBNQYMZUXO	1372148923 Dell Way	\N	IMOBLCS	FL	68495	US	1	KBNQYMZUXO@dell.com	1372148923	3	3528795858379453	2011/09	user7694	password	60	80000	M
7695	QRWZBX	NSWZSQXHYK	8898701884 Dell Way	\N	WZWYSAP	PA	51910	US	1	NSWZSQXHYK@dell.com	8898701884	3	2382021140772849	2010/02	user7695	password	68	20000	M
7696	OBWLOO	IOHYLOXVKW	4007884166 Dell Way	\N	RJPSYJE	TN	79341	US	1	IOHYLOXVKW@dell.com	4007884166	2	8900273768231274	2008/05	user7696	password	65	60000	F
7697	MAZBJN	IHZXEVHBMR	7047635406 Dell Way	\N	RFPAKLU	OK	75331	US	1	IHZXEVHBMR@dell.com	7047635406	4	1754661689046770	2009/04	user7697	password	54	100000	F
7698	MWSZFA	ZDFULGGCYM	9559357214 Dell Way	\N	SYWDTPW	ME	39851	US	1	ZDFULGGCYM@dell.com	9559357214	4	6904712884686888	2010/07	user7698	password	19	100000	F
7699	TXRTWU	YQFFXHDKZB	8387346087 Dell Way	\N	GDVVAGE	WI	97602	US	1	YQFFXHDKZB@dell.com	8387346087	2	5773968146182597	2012/04	user7699	password	88	60000	F
7700	QICKGT	PLRXOBXQHA	2820541284 Dell Way	\N	MDASHZR	CT	44173	US	1	PLRXOBXQHA@dell.com	2820541284	5	7268280306831003	2008/07	user7700	password	85	80000	M
7701	AFCUVO	LSCMQTUQFY	7583004317 Dell Way	\N	RXGRPJA	SC	38858	US	1	LSCMQTUQFY@dell.com	7583004317	5	8679020911455155	2011/10	user7701	password	69	80000	M
7702	ULUIXN	LKDFFULDLJ	9095221463 Dell Way	\N	JCYSDTB	UT	73129	US	1	LKDFFULDLJ@dell.com	9095221463	3	5182816797867418	2010/03	user7702	password	49	40000	M
7703	FTOSEY	WKDQVHBEQE	1224118633 Dell Way	\N	DJIWKEO	IN	73885	US	1	WKDQVHBEQE@dell.com	1224118633	5	9223177032545210	2010/04	user7703	password	59	80000	F
7704	DKFCGQ	FXLMZQDDTM	3438431553 Dell Way	\N	MPXQEFJ	FL	20919	US	1	FXLMZQDDTM@dell.com	3438431553	4	4814463979564607	2012/04	user7704	password	51	100000	M
7705	RBZHHX	TUWJXADKMS	1589522966 Dell Way	\N	HCXNMBQ	OR	75269	US	1	TUWJXADKMS@dell.com	1589522966	3	1478817161638289	2010/07	user7705	password	75	40000	M
7706	UNXRGR	NQOOTZALHD	2793601064 Dell Way	\N	IUPKLID	MT	92093	US	1	NQOOTZALHD@dell.com	2793601064	1	5241417436394841	2012/03	user7706	password	24	80000	M
7707	ZLAQZQ	FNJFOVMREH	9641188465 Dell Way	\N	GPSOSGM	WA	34303	US	1	FNJFOVMREH@dell.com	9641188465	5	5610737597569824	2008/09	user7707	password	37	20000	F
7708	GRDWXR	GCGBOXFVDU	6279881779 Dell Way	\N	OSNUFLB	DE	43820	US	1	GCGBOXFVDU@dell.com	6279881779	2	1632623685058206	2012/03	user7708	password	34	20000	M
7709	JZUBGX	HHLENHIIWB	7791800161 Dell Way	\N	WRGITKR	KS	66730	US	1	HHLENHIIWB@dell.com	7791800161	1	8814250744413585	2012/04	user7709	password	74	40000	F
7710	PKNMSV	XWIFFQBGMT	4745831732 Dell Way	\N	NUMXMVO	IA	99185	US	1	XWIFFQBGMT@dell.com	4745831732	2	3500046655535698	2008/07	user7710	password	58	80000	M
7711	BGRWDO	FJTVLAIEND	7605149380 Dell Way	\N	QLQMZWL	MD	16247	US	1	FJTVLAIEND@dell.com	7605149380	3	6716781957075000	2009/05	user7711	password	62	40000	M
7712	HGTVLC	PHNQQRDTIP	9393196122 Dell Way	\N	JVOFGZH	WY	60180	US	1	PHNQQRDTIP@dell.com	9393196122	2	9285305329132826	2010/08	user7712	password	55	100000	M
7713	GRIJHQ	WXGOBAXQKS	6907321894 Dell Way	\N	FQZEXZT	TX	35186	US	1	WXGOBAXQKS@dell.com	6907321894	2	9395822679623962	2008/03	user7713	password	78	60000	M
7714	EUEURC	BGECEVMXAC	1739429323 Dell Way	\N	WFAWYWD	NH	31517	US	1	BGECEVMXAC@dell.com	1739429323	4	5142641309183091	2012/03	user7714	password	44	20000	M
7715	OXRQYX	VACQMZRPWW	2150070473 Dell Way	\N	PSVLWKR	WI	27173	US	1	VACQMZRPWW@dell.com	2150070473	5	4582155258394778	2010/12	user7715	password	46	20000	M
7716	BRUZMU	BDHAUWWRLP	5326958253 Dell Way	\N	MXLXOKC	NY	33299	US	1	BDHAUWWRLP@dell.com	5326958253	1	2799574636854231	2012/03	user7716	password	20	100000	M
7717	UXJPZM	XAHUWYGMKD	8010778513 Dell Way	\N	XHRIJJP	UT	58759	US	1	XAHUWYGMKD@dell.com	8010778513	4	7645363237708808	2012/09	user7717	password	62	80000	M
7718	ZFPLDP	TXMREYBHWJ	6801160619 Dell Way	\N	ZETJTQX	NC	42477	US	1	TXMREYBHWJ@dell.com	6801160619	2	1385251627769321	2009/12	user7718	password	65	40000	F
7719	GRIVKF	HCKGESCNRH	3854039421 Dell Way	\N	HBAXYOH	NH	91804	US	1	HCKGESCNRH@dell.com	3854039421	5	8780230963137002	2012/01	user7719	password	21	20000	M
7720	JAEOIH	ZOLRQZIYGK	3631837402 Dell Way	\N	YEJNLYL	RI	82129	US	1	ZOLRQZIYGK@dell.com	3631837402	4	8942773286253215	2009/12	user7720	password	65	80000	M
7721	VGHCFV	OXMNGKUQJY	6513443151 Dell Way	\N	ZWKYIES	NH	92198	US	1	OXMNGKUQJY@dell.com	6513443151	5	8596337975468487	2009/08	user7721	password	76	20000	M
7722	BFCXTA	KHGUBWEAWB	4391925271 Dell Way	\N	LUJQNYN	CT	90170	US	1	KHGUBWEAWB@dell.com	4391925271	2	5600100547540933	2008/06	user7722	password	46	40000	M
7723	NEMNOT	TJVQNWMOHG	3440917969 Dell Way	\N	XXUWLXT	SD	36738	US	1	TJVQNWMOHG@dell.com	3440917969	5	8098028987180442	2011/03	user7723	password	54	20000	F
7724	ZRYSLH	OBVKNJRUHP	6188612849 Dell Way	\N	PEAMYVU	FL	84460	US	1	OBVKNJRUHP@dell.com	6188612849	5	1620267288759350	2008/01	user7724	password	52	20000	M
7725	KTDSHE	ORSXJNFYCJ	7185336815 Dell Way	\N	YPHUKMQ	WV	41842	US	1	ORSXJNFYCJ@dell.com	7185336815	1	4430186232551932	2008/01	user7725	password	24	60000	M
7726	FHDKVV	DTERZCUJBK	8914912150 Dell Way	\N	QWUDMTM	DC	81406	US	1	DTERZCUJBK@dell.com	8914912150	2	8843192106578500	2012/11	user7726	password	69	20000	F
7727	VPAQTU	VKTXECZPTV	8015118574 Dell Way	\N	JXHCKLX	ID	76734	US	1	VKTXECZPTV@dell.com	8015118574	2	6622908585239202	2010/06	user7727	password	76	40000	F
7728	VYTPUE	IRJLQYELHB	5855110760 Dell Way	\N	TKLEISX	CA	94471	US	1	IRJLQYELHB@dell.com	5855110760	3	4198180969804525	2009/11	user7728	password	45	20000	M
7729	DTQHCH	QNYOSKVTEG	2848812236 Dell Way	\N	FIOXGRW	RI	30858	US	1	QNYOSKVTEG@dell.com	2848812236	1	2139380508568138	2010/04	user7729	password	89	80000	F
7730	PZDXPR	WEJHADLGIT	8449665017 Dell Way	\N	VGAMCUS	IN	92719	US	1	WEJHADLGIT@dell.com	8449665017	5	2883275521453470	2012/07	user7730	password	36	60000	M
7731	KIDBFH	LMIOYOXSJD	6681892582 Dell Way	\N	SVGNONK	LA	46742	US	1	LMIOYOXSJD@dell.com	6681892582	1	9809034890495242	2012/08	user7731	password	56	40000	M
7732	RJDZUQ	HJOWHGFKZB	6143283341 Dell Way	\N	QMPEXZP	NC	24764	US	1	HJOWHGFKZB@dell.com	6143283341	3	7903993054293097	2008/09	user7732	password	69	80000	F
7733	WTWMAG	BWNICYHEPU	7194089060 Dell Way	\N	UTRTJFX	WA	68196	US	1	BWNICYHEPU@dell.com	7194089060	1	4229159725364298	2009/10	user7733	password	49	40000	M
7734	HTPOUL	BDOZLTOFNI	2236843610 Dell Way	\N	XGRDEQU	UT	67554	US	1	BDOZLTOFNI@dell.com	2236843610	2	4894965374376625	2010/07	user7734	password	89	100000	F
7735	OLBAME	PMPIBVVJTC	7850125642 Dell Way	\N	BWGRQDI	SC	46849	US	1	PMPIBVVJTC@dell.com	7850125642	2	9334464830812068	2011/03	user7735	password	31	40000	M
7736	GHDKWQ	AERWABPCDM	8503558785 Dell Way	\N	JVDMDXX	VT	33288	US	1	AERWABPCDM@dell.com	8503558785	4	5396213699132204	2008/12	user7736	password	28	40000	F
7737	HRDXSI	OOIQDKTPTO	4422144467 Dell Way	\N	SGSQEPX	AK	32977	US	1	OOIQDKTPTO@dell.com	4422144467	1	2672716166824102	2010/04	user7737	password	48	100000	M
7738	NSQWHE	EXIOQYIFRP	9853264890 Dell Way	\N	YHUOFUU	NE	82113	US	1	EXIOQYIFRP@dell.com	9853264890	1	1650099534075707	2010/11	user7738	password	18	100000	M
7739	QUWVYU	DNLCWQTMPB	9054099322 Dell Way	\N	GDGAXVV	VT	92166	US	1	DNLCWQTMPB@dell.com	9054099322	2	8306470570154489	2012/03	user7739	password	48	60000	F
7740	HJZBMN	NPJEIVTJCW	2478109053 Dell Way	\N	QCULYRJ	SD	99252	US	1	NPJEIVTJCW@dell.com	2478109053	4	3164110872894525	2010/04	user7740	password	38	100000	M
7741	GYDULS	DQAZJKBFAE	9272588657 Dell Way	\N	AMCRVYR	WY	68799	US	1	DQAZJKBFAE@dell.com	9272588657	3	9270643268246204	2008/06	user7741	password	57	60000	F
7742	RGWJKM	KKVUMBVQBH	3249776689 Dell Way	\N	TTCRKCI	KY	68627	US	1	KKVUMBVQBH@dell.com	3249776689	3	1804575121961534	2011/12	user7742	password	52	60000	F
7743	IVQUFA	QZMRVCTCWM	1379859419 Dell Way	\N	FOXHWGY	CT	80561	US	1	QZMRVCTCWM@dell.com	1379859419	5	8035140531603248	2010/05	user7743	password	19	100000	F
7744	QQKRHK	DZFGSICFNQ	9201770833 Dell Way	\N	CVNIUQD	TN	60229	US	1	DZFGSICFNQ@dell.com	9201770833	2	9337339010555298	2012/03	user7744	password	26	60000	M
7745	MFDXJC	CPUKSZYJCT	1001877315 Dell Way	\N	WLONOJB	MO	74757	US	1	CPUKSZYJCT@dell.com	1001877315	3	9234850584529340	2008/12	user7745	password	73	80000	F
7746	XMOZPE	UAWUYFWSCI	3452926751 Dell Way	\N	GPXQRJJ	NY	79818	US	1	UAWUYFWSCI@dell.com	3452926751	4	7813992058858276	2008/05	user7746	password	88	100000	M
7747	NXMRSM	OMLTJEVRKL	5075901859 Dell Way	\N	OBDXKUS	OH	61670	US	1	OMLTJEVRKL@dell.com	5075901859	4	9724448935594412	2010/08	user7747	password	81	100000	M
7748	JQGWES	HYBLUTWFHX	7032941540 Dell Way	\N	IFIDXAS	LA	76766	US	1	HYBLUTWFHX@dell.com	7032941540	4	4456501590553671	2010/09	user7748	password	86	100000	F
7749	ETNXAM	YMGRIMZGUE	7629825272 Dell Way	\N	PYCPQLJ	IN	29485	US	1	YMGRIMZGUE@dell.com	7629825272	5	9424270272254944	2011/09	user7749	password	38	100000	F
7750	VSMHRY	NJHZIOUNDS	2857152616 Dell Way	\N	PTJBCQH	TN	53413	US	1	NJHZIOUNDS@dell.com	2857152616	3	2828898046165705	2010/05	user7750	password	66	40000	F
7751	DPTCCC	JCLXXZBPPU	3562966643 Dell Way	\N	YQWPXSC	CT	28731	US	1	JCLXXZBPPU@dell.com	3562966643	4	5917471935972572	2012/12	user7751	password	62	20000	M
7752	JEQMOS	YMPXNFNIDE	6931930935 Dell Way	\N	FTBXVFC	CT	83720	US	1	YMPXNFNIDE@dell.com	6931930935	1	7699321010150016	2009/02	user7752	password	36	80000	F
7753	WCWPAJ	EYXKLFOPKH	5074168615 Dell Way	\N	RHDXKGS	AZ	38407	US	1	EYXKLFOPKH@dell.com	5074168615	2	5178630640730262	2011/12	user7753	password	75	60000	F
7754	RECAJB	XTNDHDNPVV	7910126109 Dell Way	\N	TSFZKHH	TX	66711	US	1	XTNDHDNPVV@dell.com	7910126109	3	6401941610034556	2010/02	user7754	password	67	40000	F
7755	UHRVFL	IITLVJGQCZ	4391734867 Dell Way	\N	WBJDJFU	DC	81708	US	1	IITLVJGQCZ@dell.com	4391734867	4	9525631722062828	2008/12	user7755	password	37	100000	F
7756	YRKKZS	ELONSEPSAR	1349011618 Dell Way	\N	BEBHYEC	KY	90740	US	1	ELONSEPSAR@dell.com	1349011618	2	8531950265634806	2009/03	user7756	password	21	40000	M
7757	LRWEVI	SIBXYTYPVC	6161890030 Dell Way	\N	QCBVFKT	IA	80517	US	1	SIBXYTYPVC@dell.com	6161890030	3	9975344929378480	2011/10	user7757	password	81	20000	M
7758	TGICYR	DVPXTFSWWV	1970142302 Dell Way	\N	YSAILHC	AK	85128	US	1	DVPXTFSWWV@dell.com	1970142302	4	6952235714998097	2012/09	user7758	password	30	80000	M
7759	NUXEYS	UVMAOJWJHO	2733282747 Dell Way	\N	KPZSSAN	TN	67285	US	1	UVMAOJWJHO@dell.com	2733282747	5	4052246046718210	2009/07	user7759	password	38	100000	F
7760	EBHXVD	KVRTSBAGMQ	3153802594 Dell Way	\N	GEJGSEX	VA	99403	US	1	KVRTSBAGMQ@dell.com	3153802594	2	5724004053045065	2010/02	user7760	password	80	80000	F
7761	DPZGZV	YTNZTULKAP	5130409991 Dell Way	\N	THHYFFY	MI	49659	US	1	YTNZTULKAP@dell.com	5130409991	5	5944070065859706	2009/08	user7761	password	69	60000	F
7762	RSGNQZ	APSUBDVRWD	2332860654 Dell Way	\N	ZVIETUP	GA	77268	US	1	APSUBDVRWD@dell.com	2332860654	3	4623946534935385	2012/12	user7762	password	65	60000	M
7763	XAIWBY	PWZSSQPWPK	2208576044 Dell Way	\N	FUEZJJT	MT	90717	US	1	PWZSSQPWPK@dell.com	2208576044	2	8943148518912495	2011/11	user7763	password	60	80000	M
7764	XNZVDW	VVOMKLCVQW	2056740886 Dell Way	\N	ZPGIITG	MO	20280	US	1	VVOMKLCVQW@dell.com	2056740886	2	1111737831030040	2011/12	user7764	password	87	80000	F
7765	YLPVHK	KTVVWQLSQB	8343033462 Dell Way	\N	YYKRFWU	IN	21751	US	1	KTVVWQLSQB@dell.com	8343033462	1	1644019640982151	2011/08	user7765	password	57	80000	F
7766	DNIOXC	KSYBEQRFPQ	7022924725 Dell Way	\N	PHVMBDP	VA	21980	US	1	KSYBEQRFPQ@dell.com	7022924725	4	7666785601060838	2009/05	user7766	password	75	40000	M
7767	DYUFIN	DJRUBWJRMQ	5344925173 Dell Way	\N	MYSPOPT	HI	33534	US	1	DJRUBWJRMQ@dell.com	5344925173	3	6645167223643512	2009/10	user7767	password	55	60000	M
7768	IPBVTK	MNLJXDWOPV	7755330664 Dell Way	\N	GFJWYPD	ME	11519	US	1	MNLJXDWOPV@dell.com	7755330664	4	8300069327466191	2009/02	user7768	password	56	60000	M
7769	OKMZXA	LHXODLDYSJ	7617578138 Dell Way	\N	IOHXRTY	MI	49903	US	1	LHXODLDYSJ@dell.com	7617578138	4	5957550240680576	2009/04	user7769	password	37	100000	M
7770	TVOTGW	QVZCZYUIHJ	4256048392 Dell Way	\N	QEBJCMV	TX	26949	US	1	QVZCZYUIHJ@dell.com	4256048392	1	5192373806145042	2011/12	user7770	password	28	40000	M
7771	SCAOTW	OVVNQDUZUZ	2582427165 Dell Way	\N	ADCNYYS	KS	12963	US	1	OVVNQDUZUZ@dell.com	2582427165	5	9827742288354784	2009/04	user7771	password	72	20000	F
7772	UPEQDA	MQQPLQKKRN	4788944370 Dell Way	\N	MEMKXVL	AZ	78753	US	1	MQQPLQKKRN@dell.com	4788944370	2	1699024296365678	2008/05	user7772	password	54	100000	F
7773	RPDRBU	HRGYBQPPDU	7826888258 Dell Way	\N	CNRXZTR	MD	21461	US	1	HRGYBQPPDU@dell.com	7826888258	3	5895914540160448	2009/07	user7773	password	58	100000	F
7774	SOFNWX	TUYKKONERB	3179914829 Dell Way	\N	VPAOGKS	AK	99260	US	1	TUYKKONERB@dell.com	3179914829	2	5727318194694818	2011/03	user7774	password	66	60000	M
7775	WZQTTL	SDVGQZYSVN	6916258683 Dell Way	\N	SKUDCUD	KS	15670	US	1	SDVGQZYSVN@dell.com	6916258683	1	3236299045849591	2009/08	user7775	password	18	20000	M
7776	QYJCQM	XXDXWVSJOC	3114446344 Dell Way	\N	DREYVNZ	MO	68004	US	1	XXDXWVSJOC@dell.com	3114446344	4	3365119908004999	2009/12	user7776	password	82	100000	M
7777	GZPTWN	WUJSMSGPWY	2928556712 Dell Way	\N	UUTHTFY	WY	12358	US	1	WUJSMSGPWY@dell.com	2928556712	2	1125104913022369	2008/02	user7777	password	86	40000	F
7778	NBZAYT	JQGCWVYUQS	8412226521 Dell Way	\N	OYMUXLV	CO	72732	US	1	JQGCWVYUQS@dell.com	8412226521	1	8422700799535961	2011/07	user7778	password	85	40000	M
7779	XIORSE	XUBTTWKLKI	9150389163 Dell Way	\N	YEFJZIC	SD	56993	US	1	XUBTTWKLKI@dell.com	9150389163	3	1515855588950216	2012/11	user7779	password	66	80000	F
7780	FKXJIS	KCLGMXRVVW	9500206568 Dell Way	\N	BFWJHRX	GA	33835	US	1	KCLGMXRVVW@dell.com	9500206568	1	2350267365109175	2011/10	user7780	password	44	100000	F
7781	HENZPP	LWCJNXFKZK	3986755969 Dell Way	\N	GISXFYE	DE	96933	US	1	LWCJNXFKZK@dell.com	3986755969	4	7710749793797732	2011/07	user7781	password	86	100000	M
7782	LYJBKF	EUTCZDBKJJ	7733845922 Dell Way	\N	CHPAMTA	SC	57329	US	1	EUTCZDBKJJ@dell.com	7733845922	3	1890997359063476	2011/06	user7782	password	80	20000	F
7783	FFVKJP	DMOHNYQXBX	9058087046 Dell Way	\N	NCKHCEU	TX	70909	US	1	DMOHNYQXBX@dell.com	9058087046	3	2197137797717005	2011/09	user7783	password	57	100000	M
7784	JJGYMS	NUGMKENIRQ	7462133807 Dell Way	\N	SYSXTOP	NM	18890	US	1	NUGMKENIRQ@dell.com	7462133807	2	7907442852854729	2009/04	user7784	password	64	80000	M
7785	XPEQCY	WPJACRSTKQ	9062837867 Dell Way	\N	LIJAXAD	NJ	45473	US	1	WPJACRSTKQ@dell.com	9062837867	5	7474382127635182	2010/07	user7785	password	47	60000	F
7786	OBFNYV	WYYORRZHDH	8317973206 Dell Way	\N	RDESHVC	FL	72422	US	1	WYYORRZHDH@dell.com	8317973206	4	2904922486282885	2009/02	user7786	password	41	80000	F
7787	OHDJEC	HTTYSBBATF	9166613917 Dell Way	\N	FLNANRS	KY	45468	US	1	HTTYSBBATF@dell.com	9166613917	3	5916996242012829	2009/05	user7787	password	73	80000	M
7788	XDVZKO	TJHULHORMZ	7984895753 Dell Way	\N	EMNVEWF	CA	49571	US	1	TJHULHORMZ@dell.com	7984895753	2	8069296326022596	2010/02	user7788	password	49	60000	F
7789	GKRVDA	DYMLMDXMHK	2088382381 Dell Way	\N	ADPXJRI	CT	11391	US	1	DYMLMDXMHK@dell.com	2088382381	4	2075855149887502	2010/01	user7789	password	44	100000	F
7790	ARQBUP	NGCQEPYOPB	9917053126 Dell Way	\N	EMKWVNW	WI	25933	US	1	NGCQEPYOPB@dell.com	9917053126	3	3298622150439769	2009/05	user7790	password	72	40000	F
7791	KLVZZB	BQFROUGPYT	9649195911 Dell Way	\N	AUPNROS	NV	15808	US	1	BQFROUGPYT@dell.com	9649195911	1	4619369789492339	2011/05	user7791	password	47	20000	M
7792	FBUHDL	MVZGBPFVPZ	5098149131 Dell Way	\N	LDRZVIB	SC	39063	US	1	MVZGBPFVPZ@dell.com	5098149131	3	7429745144676418	2012/08	user7792	password	57	20000	M
7793	JJUUVQ	TCRIHNYHZB	3518120427 Dell Way	\N	YYWGARO	MN	24735	US	1	TCRIHNYHZB@dell.com	3518120427	2	7734425577335060	2012/05	user7793	password	47	20000	M
7794	FYPVSS	NAZBZGAAFZ	5385386061 Dell Way	\N	XLZOALT	IL	79198	US	1	NAZBZGAAFZ@dell.com	5385386061	1	2660322911106050	2012/04	user7794	password	88	20000	F
7795	OYYHLZ	HMYONZTMWE	8588780847 Dell Way	\N	LLEXEMR	NY	62635	US	1	HMYONZTMWE@dell.com	8588780847	3	8856160436291248	2012/09	user7795	password	25	40000	M
7796	BRBAYN	YMAYFNUKYG	5583558501 Dell Way	\N	PWLBNCQ	KY	70867	US	1	YMAYFNUKYG@dell.com	5583558501	1	4098502878565341	2011/07	user7796	password	86	80000	F
7797	ZRCNQP	OOUBJEAQUW	2673805076 Dell Way	\N	BVJELSV	WV	87233	US	1	OOUBJEAQUW@dell.com	2673805076	3	4471368190832436	2008/03	user7797	password	59	20000	M
7798	RPOHED	BFNGFDABEW	4401216086 Dell Way	\N	LJIDEHZ	MA	88612	US	1	BFNGFDABEW@dell.com	4401216086	3	2101769802626222	2012/08	user7798	password	21	80000	F
7799	QXJTZP	GGUKHWPDHY	7634581050 Dell Way	\N	LLDTKMP	SC	10060	US	1	GGUKHWPDHY@dell.com	7634581050	4	6467269492801279	2011/05	user7799	password	78	60000	F
7800	FEGULN	PVULKXTJJE	6167793790 Dell Way	\N	MDPZTKZ	MN	23371	US	1	PVULKXTJJE@dell.com	6167793790	2	5761665821541101	2010/08	user7800	password	77	80000	M
7801	CKHPZC	JLNHFWRJIU	1516277299 Dell Way	\N	ZHNJHZN	TX	31329	US	1	JLNHFWRJIU@dell.com	1516277299	2	9123295043129476	2012/11	user7801	password	71	100000	F
7802	ANGCXR	QFWNWGVQFD	3488774676 Dell Way	\N	EPKDDGJ	FL	55663	US	1	QFWNWGVQFD@dell.com	3488774676	1	4241613288875669	2008/01	user7802	password	62	20000	M
7803	VDMNUR	KHNQDEWHIM	8391449707 Dell Way	\N	SMQYVVL	CO	88714	US	1	KHNQDEWHIM@dell.com	8391449707	1	9033555164933206	2010/02	user7803	password	50	40000	F
7804	XUBOFI	CVMGSTPFLB	4464385290 Dell Way	\N	VKXQWAM	NY	21499	US	1	CVMGSTPFLB@dell.com	4464385290	1	3481410189531744	2012/05	user7804	password	58	80000	F
7805	QIJZKF	LRYEHDQIYA	6624504436 Dell Way	\N	FOWFAOJ	ME	68427	US	1	LRYEHDQIYA@dell.com	6624504436	2	1273417157586664	2008/01	user7805	password	33	100000	F
7806	PUTUFL	SKSVAAUAGI	2135777874 Dell Way	\N	XMJLVUC	MI	13383	US	1	SKSVAAUAGI@dell.com	2135777874	4	1364132546819746	2009/06	user7806	password	44	100000	F
7807	CSLNLV	FHVGBWNJUZ	6350338448 Dell Way	\N	TFUNIGO	MI	89790	US	1	FHVGBWNJUZ@dell.com	6350338448	4	3948375495150685	2012/09	user7807	password	57	20000	F
7808	ZPWUVE	QCFNPPHPIN	8699158647 Dell Way	\N	KVVQKHN	WY	17191	US	1	QCFNPPHPIN@dell.com	8699158647	5	8069166343659163	2009/01	user7808	password	33	40000	M
7809	BEKFUN	LICAPRJDBF	2275502695 Dell Way	\N	ZSPHGPJ	CA	59534	US	1	LICAPRJDBF@dell.com	2275502695	3	6058467851951719	2009/11	user7809	password	29	60000	F
7810	PRVCCD	EDTWNXYSWQ	1256811471 Dell Way	\N	IDWXNZM	NV	51485	US	1	EDTWNXYSWQ@dell.com	1256811471	1	3885387533809990	2008/06	user7810	password	43	80000	F
7811	EWEIBI	BYVZWNVNWZ	2201585411 Dell Way	\N	JTMJGDV	ID	23459	US	1	BYVZWNVNWZ@dell.com	2201585411	3	6194492813199759	2010/03	user7811	password	66	80000	F
7812	WZDEAC	ZAYNVLJVVD	2888812040 Dell Way	\N	IEJMZQQ	CO	17615	US	1	ZAYNVLJVVD@dell.com	2888812040	3	3832039557397366	2012/03	user7812	password	48	80000	F
7813	OXGQWG	PKCAUXVYGA	3972385892 Dell Way	\N	HTZYJCA	NE	73292	US	1	PKCAUXVYGA@dell.com	3972385892	3	9530891709960998	2011/03	user7813	password	29	40000	F
7814	KYYQNJ	TODRJBXKJR	2220013143 Dell Way	\N	JHAMIPE	NM	16041	US	1	TODRJBXKJR@dell.com	2220013143	2	3172161946538836	2009/09	user7814	password	40	80000	M
7815	GIEPCS	TTCVQMFIWM	3342373044 Dell Way	\N	IJVYNLA	NY	85944	US	1	TTCVQMFIWM@dell.com	3342373044	5	5856067412532867	2010/08	user7815	password	31	100000	M
7816	JLBCEV	EAMRFUNSCW	4137475497 Dell Way	\N	NBKZCCV	KY	13521	US	1	EAMRFUNSCW@dell.com	4137475497	5	7249279190320522	2010/09	user7816	password	68	100000	F
7817	TZIODJ	AVOVIGXFTZ	4869843532 Dell Way	\N	QTBSOKT	VA	38429	US	1	AVOVIGXFTZ@dell.com	4869843532	3	1387734733056277	2008/04	user7817	password	32	100000	F
7818	OLLXMG	LHPSFUMFLF	1315669535 Dell Way	\N	GDTRWQZ	IL	16624	US	1	LHPSFUMFLF@dell.com	1315669535	3	4528880887664855	2009/04	user7818	password	67	80000	M
7819	DRGJDO	ZWTUIZFOGI	4750393738 Dell Way	\N	HXEYXMA	WA	89627	US	1	ZWTUIZFOGI@dell.com	4750393738	1	2596414801198989	2008/12	user7819	password	85	40000	M
7820	EPTSOP	MJYLOMRXUP	6569155280 Dell Way	\N	CTMOTLL	DE	64786	US	1	MJYLOMRXUP@dell.com	6569155280	2	6059364761691541	2010/06	user7820	password	31	80000	F
7821	YLROXA	MJPZAMTQOM	7501108404 Dell Way	\N	DDGOOLE	FL	73330	US	1	MJPZAMTQOM@dell.com	7501108404	4	2822155127767473	2012/06	user7821	password	40	100000	M
7822	ZLUAYD	PXECRUREXU	7707192757 Dell Way	\N	KLJVPOO	KY	36930	US	1	PXECRUREXU@dell.com	7707192757	2	7744117182213814	2008/02	user7822	password	63	20000	M
7823	KBMORJ	SUAMLEKGPW	3185609176 Dell Way	\N	QLMFZVM	OR	15604	US	1	SUAMLEKGPW@dell.com	3185609176	4	2625283148605376	2012/10	user7823	password	71	40000	M
7824	FVNOOH	PBTULZKHQV	8474483375 Dell Way	\N	UVVPIOQ	ND	39318	US	1	PBTULZKHQV@dell.com	8474483375	3	2216502177529037	2010/09	user7824	password	90	80000	M
7825	NICUXD	OSONCWDYQZ	7945102911 Dell Way	\N	TGHIXVQ	OK	32025	US	1	OSONCWDYQZ@dell.com	7945102911	2	9553901446517558	2011/01	user7825	password	53	40000	F
7826	OCHSQZ	GDCDHBUGUA	6011911073 Dell Way	\N	OCXJTQP	MT	92626	US	1	GDCDHBUGUA@dell.com	6011911073	2	9525270889513196	2008/07	user7826	password	39	80000	M
7827	OIGOOK	QSSRNZMONP	9724674752 Dell Way	\N	MWJCMWA	AR	24035	US	1	QSSRNZMONP@dell.com	9724674752	1	7467481910251082	2009/09	user7827	password	44	100000	F
7828	QKPBAH	TSVTFJGVVD	9148913919 Dell Way	\N	EXQAYRE	VT	79386	US	1	TSVTFJGVVD@dell.com	9148913919	1	5289032517932356	2009/01	user7828	password	53	100000	F
7829	CYLKRE	FLJOREJVIH	4565030275 Dell Way	\N	MJGDOEX	MN	40391	US	1	FLJOREJVIH@dell.com	4565030275	4	4161462869495154	2012/08	user7829	password	72	100000	M
7830	EJGIOR	SDJWMFFURP	8943310130 Dell Way	\N	AVDFTPN	CT	38422	US	1	SDJWMFFURP@dell.com	8943310130	1	9403938721399756	2011/12	user7830	password	53	100000	F
7831	SEXKWA	TTNZZHQOIL	5668517991 Dell Way	\N	RNEGBIP	WI	40030	US	1	TTNZZHQOIL@dell.com	5668517991	3	3898695095907897	2008/05	user7831	password	66	80000	M
7832	ODLPXE	CWDKMSTYJH	1773676958 Dell Way	\N	DQJLFHT	OR	89969	US	1	CWDKMSTYJH@dell.com	1773676958	4	3633924240246415	2011/06	user7832	password	80	40000	M
7833	HXNMAJ	QLWIEURMXI	3802593290 Dell Way	\N	VIODCHA	FL	14331	US	1	QLWIEURMXI@dell.com	3802593290	5	5751085810363293	2008/04	user7833	password	28	60000	F
7834	QYEAOQ	WWUQOHOXCW	4000760918 Dell Way	\N	LFZTGDU	ND	17231	US	1	WWUQOHOXCW@dell.com	4000760918	4	4030283147003502	2010/03	user7834	password	55	20000	F
7835	SDSIZP	CQDKEBMBNS	6150316646 Dell Way	\N	AGYEBNG	MD	30903	US	1	CQDKEBMBNS@dell.com	6150316646	5	4796512159984559	2008/12	user7835	password	58	80000	F
7836	GCCVFS	ZPXABYNUYU	8970902077 Dell Way	\N	SCWGIHM	VT	24229	US	1	ZPXABYNUYU@dell.com	8970902077	5	2380302708130330	2010/10	user7836	password	37	80000	M
7837	JNBCMQ	ANSYBMXVFZ	3793292751 Dell Way	\N	SLIZXGE	SC	29807	US	1	ANSYBMXVFZ@dell.com	3793292751	2	9853040975984188	2010/12	user7837	password	79	100000	F
7838	XBXOBK	GALTXHZWAK	6780914354 Dell Way	\N	FAILEDR	MO	42313	US	1	GALTXHZWAK@dell.com	6780914354	1	3500884263310581	2010/01	user7838	password	69	40000	F
7839	PXEAEE	MYBUXYVHEV	4534475946 Dell Way	\N	QPATGNC	VT	61773	US	1	MYBUXYVHEV@dell.com	4534475946	2	6479408173356206	2008/10	user7839	password	69	80000	M
7840	WTWBFU	DARCVZGRPW	4342233065 Dell Way	\N	RJDEMAT	UT	47681	US	1	DARCVZGRPW@dell.com	4342233065	5	2605454889126122	2008/09	user7840	password	80	100000	F
7841	SAQMER	DGNDNESJWC	2202498795 Dell Way	\N	NBONULY	FL	45787	US	1	DGNDNESJWC@dell.com	2202498795	2	1663891658186912	2012/03	user7841	password	53	80000	F
7842	DEKUIQ	HLDMENIHAJ	7643077253 Dell Way	\N	VOEGNJR	NV	65080	US	1	HLDMENIHAJ@dell.com	7643077253	4	8463556555099786	2009/05	user7842	password	22	40000	M
7843	LEVCMH	GYMTGTUQPJ	6503045856 Dell Way	\N	VWWENNU	IA	24865	US	1	GYMTGTUQPJ@dell.com	6503045856	3	5504771951586009	2011/11	user7843	password	19	20000	F
7844	WFMEMK	QGRJAIZKDV	5055940398 Dell Way	\N	GHIUCPY	OH	15189	US	1	QGRJAIZKDV@dell.com	5055940398	2	9110443699639292	2010/07	user7844	password	84	40000	M
7845	JMFUCL	MMMULWXGDF	2127807836 Dell Way	\N	PXHEWAF	IN	43875	US	1	MMMULWXGDF@dell.com	2127807836	4	8936208864673973	2008/02	user7845	password	62	60000	M
7846	VFRGRE	TMQPKWSPMP	2636411051 Dell Way	\N	XQMYWTH	WY	58320	US	1	TMQPKWSPMP@dell.com	2636411051	1	6657540614251048	2011/06	user7846	password	32	80000	M
7847	WWIBPU	RFENXUANSQ	9201805132 Dell Way	\N	ZQNTYMH	CT	55470	US	1	RFENXUANSQ@dell.com	9201805132	5	9464742828160524	2008/07	user7847	password	60	100000	F
7848	XAASRF	XFCRFQKWPB	3673568316 Dell Way	\N	JJZWQDJ	NC	13296	US	1	XFCRFQKWPB@dell.com	3673568316	4	6141188904643059	2012/08	user7848	password	89	80000	M
7849	ZNIFKO	ICUYMQOOAX	3364861334 Dell Way	\N	NWNRFBR	MT	75022	US	1	ICUYMQOOAX@dell.com	3364861334	2	4214928096160293	2009/03	user7849	password	19	40000	M
7850	JLCXTE	RSRIGFIDTE	8314000159 Dell Way	\N	RKKTCXL	LA	36898	US	1	RSRIGFIDTE@dell.com	8314000159	3	5372560261748731	2012/11	user7850	password	30	20000	F
7851	GCALTS	CCZHKCBPTL	7142504967 Dell Way	\N	ZMNXYXF	RI	54315	US	1	CCZHKCBPTL@dell.com	7142504967	3	3946738077793270	2012/10	user7851	password	61	20000	M
7852	QOQJQS	IYDLZSFKSR	6997293477 Dell Way	\N	YPQWUKI	MO	10489	US	1	IYDLZSFKSR@dell.com	6997293477	2	8002560882829130	2009/06	user7852	password	64	100000	M
7853	GGQZPO	CANUFYNXXC	7625356338 Dell Way	\N	OTXYBKY	OR	76850	US	1	CANUFYNXXC@dell.com	7625356338	1	2789265063591301	2009/11	user7853	password	32	80000	F
7854	VPTJRT	XMZVZWSCKL	4233389296 Dell Way	\N	AJNKIGE	AR	33992	US	1	XMZVZWSCKL@dell.com	4233389296	3	2572890545707196	2010/01	user7854	password	42	40000	M
7855	CTIWQU	VMUREWCQXL	8579719067 Dell Way	\N	DITKMUR	TN	29434	US	1	VMUREWCQXL@dell.com	8579719067	2	3364321561064571	2008/10	user7855	password	83	40000	M
7856	FDDAYP	UQURSKODOW	2441106731 Dell Way	\N	XYIRPEX	MN	60059	US	1	UQURSKODOW@dell.com	2441106731	4	3846069312654436	2008/11	user7856	password	77	40000	F
7857	ZHZOBP	JSITHLHDIG	5800477821 Dell Way	\N	MAWRXHF	AZ	94457	US	1	JSITHLHDIG@dell.com	5800477821	1	8653795754071326	2009/05	user7857	password	82	40000	M
7858	WXTMGM	UZUGHXONKO	4992714550 Dell Way	\N	JBMRHOP	SD	71914	US	1	UZUGHXONKO@dell.com	4992714550	1	1858737031463533	2009/06	user7858	password	75	40000	F
7859	ORPAMP	USWSGJDVSF	7009397914 Dell Way	\N	IJMWZIO	ME	54635	US	1	USWSGJDVSF@dell.com	7009397914	4	9929689314682038	2010/12	user7859	password	45	100000	M
7860	ZACPVU	LOBVRXOWGX	2662259390 Dell Way	\N	JDXSSHF	LA	15021	US	1	LOBVRXOWGX@dell.com	2662259390	5	1088107473216950	2010/10	user7860	password	65	60000	M
7861	TDROOF	QKXOYUUVEX	1963514232 Dell Way	\N	TWPBBZC	HI	81811	US	1	QKXOYUUVEX@dell.com	1963514232	4	6528431234415621	2011/05	user7861	password	51	60000	F
7862	DBAISK	GGIAAEEYXA	9576266183 Dell Way	\N	OYBOBHI	DE	17707	US	1	GGIAAEEYXA@dell.com	9576266183	5	4780622720252723	2010/06	user7862	password	82	60000	F
7863	XWFICL	RDMWHLUIZT	2620034694 Dell Way	\N	JNURWYT	SD	89193	US	1	RDMWHLUIZT@dell.com	2620034694	2	3753619313705713	2008/10	user7863	password	76	100000	M
7864	ZHTLZW	XVEIPMIIWW	3506400201 Dell Way	\N	DNSCHNZ	MN	78971	US	1	XVEIPMIIWW@dell.com	3506400201	3	5781473360955716	2008/06	user7864	password	30	20000	M
7865	XNTUKP	YTFKBNHXRU	5185942304 Dell Way	\N	QTBESOY	AK	15541	US	1	YTFKBNHXRU@dell.com	5185942304	1	6011425090953708	2011/02	user7865	password	43	60000	M
7866	DJBSHV	XSWLZUCUKW	1203923535 Dell Way	\N	WPPKNPM	WY	69979	US	1	XSWLZUCUKW@dell.com	1203923535	4	8375164658762515	2009/03	user7866	password	52	60000	M
7867	OFVJCO	FOOAQILMFA	2214011545 Dell Way	\N	BPOQCNI	CO	23280	US	1	FOOAQILMFA@dell.com	2214011545	3	3950111052021384	2011/12	user7867	password	80	20000	F
7868	RMHGSV	UTMDEYJEAY	7529769140 Dell Way	\N	SRBGZDK	CO	65392	US	1	UTMDEYJEAY@dell.com	7529769140	4	6269469532184303	2010/11	user7868	password	73	40000	F
7869	BNCWIV	ILAHUEHTXZ	2326031054 Dell Way	\N	UEYYOBO	IL	81683	US	1	ILAHUEHTXZ@dell.com	2326031054	5	7058613721281291	2012/02	user7869	password	21	100000	M
7870	DVZZEL	ZLGETACSVG	2864898483 Dell Way	\N	RTVTICN	MO	97229	US	1	ZLGETACSVG@dell.com	2864898483	2	2007519333157688	2009/05	user7870	password	74	60000	F
7871	TKIEJT	LOMLQFGXWA	8950634245 Dell Way	\N	SQJUDVU	LA	29456	US	1	LOMLQFGXWA@dell.com	8950634245	4	5955842800904066	2011/01	user7871	password	69	60000	F
7872	APUUAI	HMZMTWJUOZ	7639423619 Dell Way	\N	DJDZDME	AL	20078	US	1	HMZMTWJUOZ@dell.com	7639423619	4	2207271443214267	2010/02	user7872	password	57	60000	M
7873	IGSRNF	QZYNJTCIWM	2921026297 Dell Way	\N	MVPZAQC	RI	39413	US	1	QZYNJTCIWM@dell.com	2921026297	2	4799430353101343	2011/09	user7873	password	26	20000	M
7874	VTKBKK	AYTTACQNOM	5521280989 Dell Way	\N	CNMTPGC	TN	52494	US	1	AYTTACQNOM@dell.com	5521280989	3	2332607843447476	2011/09	user7874	password	22	60000	F
7875	MNWWNV	QHVTXIHJLV	7601482817 Dell Way	\N	WFLCHHP	SC	87983	US	1	QHVTXIHJLV@dell.com	7601482817	3	5925327514298261	2011/11	user7875	password	90	40000	F
7876	WDYRUF	NNCWVMIRIN	8370877654 Dell Way	\N	DLVKAPH	PA	11241	US	1	NNCWVMIRIN@dell.com	8370877654	3	9009017281699928	2012/10	user7876	password	38	80000	M
7877	FJTLWH	OSDABUIOYU	8948034925 Dell Way	\N	JIUZPOZ	ME	19544	US	1	OSDABUIOYU@dell.com	8948034925	2	9334477860480548	2008/12	user7877	password	83	40000	F
7878	RVDYJW	CJXXSMVMWE	8747903089 Dell Way	\N	HVTVVEY	OH	48589	US	1	CJXXSMVMWE@dell.com	8747903089	5	4128429520875216	2011/04	user7878	password	63	60000	F
7879	TJLQMU	NJMAEZWJGR	1675266357 Dell Way	\N	CBNHAFS	UT	17477	US	1	NJMAEZWJGR@dell.com	1675266357	4	4110870724543929	2011/01	user7879	password	48	60000	F
7880	WBXRPH	EPMDMVJDXL	3616881249 Dell Way	\N	QFMWYIY	AK	97415	US	1	EPMDMVJDXL@dell.com	3616881249	4	1225992609281092	2011/02	user7880	password	51	60000	F
7881	JFWQKM	CNYXXCVJTB	2408526579 Dell Way	\N	VPZEOAD	TN	75332	US	1	CNYXXCVJTB@dell.com	2408526579	3	9016586056444796	2011/02	user7881	password	27	100000	F
7882	ZQTLTG	JQDLMNFNIU	2352496934 Dell Way	\N	NMINQEG	RI	74312	US	1	JQDLMNFNIU@dell.com	2352496934	2	8523966825567187	2009/05	user7882	password	31	40000	F
7883	YSTECK	IOWVTKENXQ	6198773824 Dell Way	\N	WLGASAT	TX	48342	US	1	IOWVTKENXQ@dell.com	6198773824	1	8223154699895532	2011/05	user7883	password	76	80000	F
7884	OWFYFT	UBMEFACWWO	4369037901 Dell Way	\N	CXGDQCO	GA	32598	US	1	UBMEFACWWO@dell.com	4369037901	5	6879286264069379	2008/08	user7884	password	73	80000	M
7885	YRTSLU	EQZETVBHYY	6157083583 Dell Way	\N	OCORQUX	AL	78435	US	1	EQZETVBHYY@dell.com	6157083583	2	4840466508176178	2009/12	user7885	password	88	40000	M
7886	SZBMES	LJLHKTFIIH	8951189521 Dell Way	\N	XZYSXZL	MO	26686	US	1	LJLHKTFIIH@dell.com	8951189521	5	2109150961041450	2012/02	user7886	password	70	60000	F
7887	UAHMMQ	YTASZJAHHZ	5625369491 Dell Way	\N	FZXFLJK	KS	26759	US	1	YTASZJAHHZ@dell.com	5625369491	1	3661995250731707	2009/09	user7887	password	47	20000	M
7888	RNGILZ	JDZTEGAEMA	9235945789 Dell Way	\N	BRLLCUQ	NH	96140	US	1	JDZTEGAEMA@dell.com	9235945789	5	7107273062225432	2009/11	user7888	password	49	20000	F
7889	RIURRY	QKCXLHJLIB	3992744906 Dell Way	\N	XTESJTR	IN	62722	US	1	QKCXLHJLIB@dell.com	3992744906	4	4924702447373420	2011/08	user7889	password	75	60000	M
7890	PBQOSA	QPMYZYGBWA	9869545475 Dell Way	\N	FOKZFSO	NC	38975	US	1	QPMYZYGBWA@dell.com	9869545475	2	9467084044590592	2011/09	user7890	password	82	40000	M
7891	NXMOOC	AMCYTDVTJJ	2237861450 Dell Way	\N	EIOWWCF	TX	44817	US	1	AMCYTDVTJJ@dell.com	2237861450	4	1887451118323952	2008/12	user7891	password	82	60000	M
7892	JBLMCY	OBRSWLBFQJ	4173568584 Dell Way	\N	UMFWRBG	TN	71861	US	1	OBRSWLBFQJ@dell.com	4173568584	5	7083865667227656	2009/05	user7892	password	59	80000	F
7893	ACNZRO	QJKCKQSTKF	4624188755 Dell Way	\N	ZHXBNSS	UT	60945	US	1	QJKCKQSTKF@dell.com	4624188755	1	9405186799354852	2012/09	user7893	password	44	20000	M
7894	WZMLQV	WSGMLZXQZE	7770935907 Dell Way	\N	NASGTPV	DC	73843	US	1	WSGMLZXQZE@dell.com	7770935907	1	5009577544406057	2008/02	user7894	password	38	20000	F
7895	TLSPIK	WVWVSMVXAV	4189090116 Dell Way	\N	PHOFCSX	TN	83542	US	1	WVWVSMVXAV@dell.com	4189090116	5	9386980111245068	2011/12	user7895	password	19	40000	F
7896	SASDWN	ZSGMNDMJTT	4272153897 Dell Way	\N	XYWPWRL	HI	68438	US	1	ZSGMNDMJTT@dell.com	4272153897	5	6479629283770919	2009/03	user7896	password	19	20000	F
7897	TGCGFV	NRIRERKYPJ	7632876322 Dell Way	\N	UFFMQLD	AK	36667	US	1	NRIRERKYPJ@dell.com	7632876322	2	5904994324781001	2011/06	user7897	password	76	60000	M
7898	XTYTGQ	BXUTITJRNO	2877757324 Dell Way	\N	XAFJDFR	UT	62988	US	1	BXUTITJRNO@dell.com	2877757324	4	1618147576693445	2008/02	user7898	password	74	100000	M
7899	SRCISA	DMJWVBKJZK	5014898669 Dell Way	\N	PINUZKJ	GA	11044	US	1	DMJWVBKJZK@dell.com	5014898669	2	2059430223889649	2009/02	user7899	password	88	100000	M
7900	CGNCKZ	MGVNQFMAUV	1626956579 Dell Way	\N	OPUYYAY	MD	30567	US	1	MGVNQFMAUV@dell.com	1626956579	4	4321299665141851	2008/07	user7900	password	30	20000	M
7901	RGFRSM	NFCSRDNMRC	9253665090 Dell Way	\N	HQBIPMO	NV	18662	US	1	NFCSRDNMRC@dell.com	9253665090	4	6984720882959665	2008/10	user7901	password	54	80000	F
7902	SLTFZZ	HSRLFEDIMT	6335297123 Dell Way	\N	JUIVIZY	IA	71402	US	1	HSRLFEDIMT@dell.com	6335297123	2	5499220675788820	2008/02	user7902	password	58	100000	M
7903	IANHIF	YTLCXTOQDJ	2431781985 Dell Way	\N	ZYSZWYR	MN	35387	US	1	YTLCXTOQDJ@dell.com	2431781985	3	4490519423037768	2011/05	user7903	password	87	20000	F
7904	MIRSGL	EJIXYZAHYZ	6497167494 Dell Way	\N	ZYWYPIF	PA	89678	US	1	EJIXYZAHYZ@dell.com	6497167494	3	3319933281745762	2010/06	user7904	password	64	20000	M
7905	ITBTYL	CVJBWRAVRZ	2435231465 Dell Way	\N	RPOAVIX	MI	80639	US	1	CVJBWRAVRZ@dell.com	2435231465	1	3539450191892684	2011/01	user7905	password	24	20000	M
7906	EXTPZP	ZBLQBHHAZX	9824250697 Dell Way	\N	PZSXXES	AR	24701	US	1	ZBLQBHHAZX@dell.com	9824250697	5	2924357814714312	2008/12	user7906	password	20	40000	M
7907	UVVJUW	UKYBSZBPPA	8923026431 Dell Way	\N	IMYNFZR	DE	83766	US	1	UKYBSZBPPA@dell.com	8923026431	2	8045077051501722	2012/06	user7907	password	64	80000	F
7908	LBCIVN	HXFGZVVAEI	5567989287 Dell Way	\N	YRNXJSS	HI	95844	US	1	HXFGZVVAEI@dell.com	5567989287	1	4897432642057538	2008/11	user7908	password	71	60000	M
7909	VYSIFQ	OMPKHPPQOH	3453420915 Dell Way	\N	ELQXEWV	NY	11007	US	1	OMPKHPPQOH@dell.com	3453420915	5	8606950026471169	2008/05	user7909	password	70	100000	F
7910	LEOCTA	SEIHTYVBDH	4569310570 Dell Way	\N	RALOWDO	CT	95955	US	1	SEIHTYVBDH@dell.com	4569310570	1	4307559408247471	2008/12	user7910	password	69	60000	F
7911	GQXGIC	OQVNMWRUOR	7323756226 Dell Way	\N	GCOJQRI	AR	85230	US	1	OQVNMWRUOR@dell.com	7323756226	1	8389772551599891	2010/09	user7911	password	90	80000	F
7912	XXSZMJ	VAWSRQGJXJ	3382071095 Dell Way	\N	XGAPPBL	IN	29680	US	1	VAWSRQGJXJ@dell.com	3382071095	4	9545906745363028	2009/05	user7912	password	42	20000	F
7913	BDTLZU	HRLYYVVISC	5892968200 Dell Way	\N	IISJUAP	AR	74504	US	1	HRLYYVVISC@dell.com	5892968200	2	1792199430521577	2012/06	user7913	password	45	100000	M
7914	DJOXRG	JPFELNXNVF	1269110288 Dell Way	\N	FFAFUBY	KY	40515	US	1	JPFELNXNVF@dell.com	1269110288	2	8125616366043688	2010/02	user7914	password	46	60000	M
7915	YLEFUU	KYFYVTTBYZ	3149124905 Dell Way	\N	BEUCDDL	DC	42408	US	1	KYFYVTTBYZ@dell.com	3149124905	3	5665809530299157	2011/02	user7915	password	20	60000	M
7916	FUIAFH	FDDYXEXXGC	7224763066 Dell Way	\N	RJFVUJE	AR	94591	US	1	FDDYXEXXGC@dell.com	7224763066	4	1299368179403245	2011/04	user7916	password	59	100000	F
7917	XZHEEK	HDIMBFTDXC	7603090299 Dell Way	\N	JSXTXYS	NE	65486	US	1	HDIMBFTDXC@dell.com	7603090299	2	8878705656155945	2009/04	user7917	password	86	20000	F
7918	FJKQRO	ZEPEXTCZDV	4006388193 Dell Way	\N	XXSVPHL	KS	64780	US	1	ZEPEXTCZDV@dell.com	4006388193	4	8928506985306741	2009/10	user7918	password	26	60000	F
7919	NCXCBB	RGYLJYPEVM	7003680261 Dell Way	\N	XRBEDKU	MO	13384	US	1	RGYLJYPEVM@dell.com	7003680261	4	8816203090827913	2011/03	user7919	password	23	40000	F
7920	YKKACR	ZNAXDFTPCL	9868840612 Dell Way	\N	RGPCBBD	OK	83854	US	1	ZNAXDFTPCL@dell.com	9868840612	3	1415648670867085	2008/10	user7920	password	45	20000	F
7921	UAHLZV	MXYRROTCGA	6759874708 Dell Way	\N	SIBULUP	ME	36342	US	1	MXYRROTCGA@dell.com	6759874708	3	1966304069384932	2008/06	user7921	password	41	80000	M
7922	QGNMSL	KKCZDFFEXN	4961007990 Dell Way	\N	GRYBHJI	WA	85620	US	1	KKCZDFFEXN@dell.com	4961007990	5	4045940018258989	2011/09	user7922	password	81	40000	M
7923	KWSVHC	YGGEMKBZRT	5357743927 Dell Way	\N	YSBHAZD	MO	91499	US	1	YGGEMKBZRT@dell.com	5357743927	2	6803400339093060	2009/08	user7923	password	63	80000	F
7924	IPTKOZ	RSLBTLSNKK	1797371349 Dell Way	\N	ORLNVYL	KS	24147	US	1	RSLBTLSNKK@dell.com	1797371349	4	7973977683577687	2011/06	user7924	password	35	20000	F
7925	ZMOZDG	LEAWXOGIDY	6792415620 Dell Way	\N	URUSDCW	GA	80488	US	1	LEAWXOGIDY@dell.com	6792415620	5	2944076878950000	2012/12	user7925	password	35	100000	F
7926	VVOCGT	CDQRKZVIUM	3129351606 Dell Way	\N	DMPGJVA	WY	76896	US	1	CDQRKZVIUM@dell.com	3129351606	5	7438005711417646	2010/09	user7926	password	29	40000	M
7927	SJWLMZ	CEJCZSWMWJ	4199283776 Dell Way	\N	CCSXCSQ	KY	62045	US	1	CEJCZSWMWJ@dell.com	4199283776	5	3927677671890706	2010/02	user7927	password	84	40000	F
7928	TRZTUD	DWDWSPSBRU	4332227785 Dell Way	\N	UOXMFGB	NE	17983	US	1	DWDWSPSBRU@dell.com	4332227785	1	2934923727530986	2009/04	user7928	password	70	20000	M
7929	SUSWXP	ZTIPLJGGEV	7404739697 Dell Way	\N	DQBKRQM	AL	72628	US	1	ZTIPLJGGEV@dell.com	7404739697	2	9902430259156972	2010/05	user7929	password	87	20000	F
7930	RZAHZU	POFZUMDQQT	9861660640 Dell Way	\N	RAKHNLZ	HI	78431	US	1	POFZUMDQQT@dell.com	9861660640	4	2004101980943232	2012/10	user7930	password	35	80000	M
7931	HWSBMH	GLBTOSJHKJ	1242137018 Dell Way	\N	SRXERDX	NY	81208	US	1	GLBTOSJHKJ@dell.com	1242137018	4	6211036829277874	2009/03	user7931	password	43	60000	F
7932	BPOJWZ	KPODYWNIOF	7406722717 Dell Way	\N	FSWIQOD	NV	23538	US	1	KPODYWNIOF@dell.com	7406722717	5	4275427130982280	2008/06	user7932	password	51	20000	F
7933	AMXAXM	PAKLOSATYS	7237160999 Dell Way	\N	QHJEKAI	CT	96461	US	1	PAKLOSATYS@dell.com	7237160999	1	4864039131440222	2008/04	user7933	password	52	20000	M
7934	JFSWUT	HFHAFAYYRG	7587236302 Dell Way	\N	IVQIEUH	TX	96557	US	1	HFHAFAYYRG@dell.com	7587236302	1	3547274153679609	2009/03	user7934	password	24	60000	F
7935	ULEOSK	VTPWRONYWJ	6354984134 Dell Way	\N	OFNJNKI	IA	46267	US	1	VTPWRONYWJ@dell.com	6354984134	3	6362842135597021	2011/01	user7935	password	90	60000	M
7936	EAGOVZ	ESRTFPPPEV	5422141138 Dell Way	\N	CNJMVPX	ME	16155	US	1	ESRTFPPPEV@dell.com	5422141138	1	2098034503869712	2010/08	user7936	password	63	80000	M
7937	WFLVJE	NCJCSYGOBU	7257433843 Dell Way	\N	XOQNLBO	WA	23425	US	1	NCJCSYGOBU@dell.com	7257433843	3	7647590820677579	2009/01	user7937	password	43	20000	F
7938	UAQYNT	IQMHXAJRXX	2996888392 Dell Way	\N	HLJIZHM	OH	75126	US	1	IQMHXAJRXX@dell.com	2996888392	1	8117798380553723	2010/03	user7938	password	22	40000	F
7939	SITLRJ	XZGYIYWGGH	4731767083 Dell Way	\N	POHXBZQ	ID	99429	US	1	XZGYIYWGGH@dell.com	4731767083	5	2726296007633209	2010/03	user7939	password	47	20000	M
7940	EQFNOE	UMNSJTYQJN	1841236791 Dell Way	\N	YGOXWWX	IL	72144	US	1	UMNSJTYQJN@dell.com	1841236791	4	9152164170052856	2010/12	user7940	password	51	80000	M
7941	REDWZQ	KSZDRQMEOT	2822021293 Dell Way	\N	TLQPJXH	MN	71138	US	1	KSZDRQMEOT@dell.com	2822021293	5	6603854926768691	2011/08	user7941	password	32	40000	M
7942	IFUYPM	XSDOFHCZBO	8196712842 Dell Way	\N	PRXMZJE	DE	40151	US	1	XSDOFHCZBO@dell.com	8196712842	5	9579950599465520	2012/02	user7942	password	73	40000	F
7943	NGYZER	DSXLVWMKLE	9731607986 Dell Way	\N	HYDRCHA	VT	20810	US	1	DSXLVWMKLE@dell.com	9731607986	5	3525212498381734	2011/03	user7943	password	64	40000	F
7944	PGRGJK	EUGAHQLLYK	3365265111 Dell Way	\N	OPNWQKZ	NH	39885	US	1	EUGAHQLLYK@dell.com	3365265111	2	6042154740542174	2012/07	user7944	password	21	60000	M
7945	STEDYZ	JYGZKSXUHN	6509258469 Dell Way	\N	HDDSDTB	MA	14647	US	1	JYGZKSXUHN@dell.com	6509258469	2	6615207862574608	2011/10	user7945	password	50	40000	M
7946	QNMQWL	XWVPUPWHXA	8484888905 Dell Way	\N	LQDERNF	IL	84249	US	1	XWVPUPWHXA@dell.com	8484888905	5	6543574630282820	2009/05	user7946	password	30	100000	M
7947	RNTCKP	XAJNXRKXCB	1353513610 Dell Way	\N	BGSPLAL	IL	97274	US	1	XAJNXRKXCB@dell.com	1353513610	3	3809626243542880	2009/06	user7947	password	30	100000	F
7948	XYKNVL	XJIOTGQVIX	8483347427 Dell Way	\N	NYJOJQN	MA	27033	US	1	XJIOTGQVIX@dell.com	8483347427	4	6945504493545742	2008/06	user7948	password	66	100000	F
7949	CLGNIP	WXJDOELLSK	3515305520 Dell Way	\N	UGTLUDQ	NJ	75229	US	1	WXJDOELLSK@dell.com	3515305520	4	2726502370089292	2012/07	user7949	password	62	20000	M
7950	WOIMLG	VOUAAGTKBZ	2589955853 Dell Way	\N	DMUGCKZ	MA	12023	US	1	VOUAAGTKBZ@dell.com	2589955853	2	6079176789615304	2011/05	user7950	password	58	80000	M
7951	WCICYW	XYXDRHFRLR	5051617851 Dell Way	\N	MSTWRDX	TX	51185	US	1	XYXDRHFRLR@dell.com	5051617851	4	8228115617297591	2012/04	user7951	password	69	100000	F
7952	AZHXXG	VBYCGPOXBG	1669000419 Dell Way	\N	RYYVVUH	ID	48025	US	1	VBYCGPOXBG@dell.com	1669000419	2	7272664289455862	2011/02	user7952	password	23	100000	F
7953	JSAQOB	ORHEFFGLWE	3576850030 Dell Way	\N	JRAEYHP	AL	59925	US	1	ORHEFFGLWE@dell.com	3576850030	5	7323565672151745	2009/08	user7953	password	79	80000	F
7954	WJXXYO	FCTLIFHNPZ	1709306326 Dell Way	\N	OTYVJZJ	NM	82231	US	1	FCTLIFHNPZ@dell.com	1709306326	5	4861566210165620	2012/09	user7954	password	75	80000	F
7955	RSAFXC	ZILFQZUQNO	8207049719 Dell Way	\N	PIXOSOJ	SC	59137	US	1	ZILFQZUQNO@dell.com	8207049719	4	3455293294042349	2010/06	user7955	password	44	40000	F
7956	JMCMML	YRCXMSLBHU	3970276930 Dell Way	\N	YWNNGHB	AL	11955	US	1	YRCXMSLBHU@dell.com	3970276930	4	5608762972056866	2011/11	user7956	password	69	20000	F
7957	UOWGMO	IKABVBIQAF	9725032085 Dell Way	\N	DOLLPML	WA	19661	US	1	IKABVBIQAF@dell.com	9725032085	4	9913730045314880	2011/09	user7957	password	44	60000	F
7958	FSSTBC	UCYWLOXRRL	7244550195 Dell Way	\N	CDBPPZS	ND	64385	US	1	UCYWLOXRRL@dell.com	7244550195	2	3614190373569727	2008/09	user7958	password	55	40000	F
7959	FBMIVP	GSAVPSNBUQ	9793594272 Dell Way	\N	CKFCCUR	SC	99554	US	1	GSAVPSNBUQ@dell.com	9793594272	5	7210729778278620	2010/02	user7959	password	25	80000	F
7960	PBAEIT	FDIXRKSHMC	9836724386 Dell Way	\N	NOFHGAH	IA	88496	US	1	FDIXRKSHMC@dell.com	9836724386	4	1117632643319666	2008/06	user7960	password	32	80000	M
7961	FVVYBZ	HYQSQYETLT	8780361360 Dell Way	\N	ZTAZBGW	AL	10513	US	1	HYQSQYETLT@dell.com	8780361360	1	5198952640406788	2008/10	user7961	password	89	40000	M
7962	VGRUOQ	KGGJLAVFZO	9737903231 Dell Way	\N	FZPMVQN	NY	78468	US	1	KGGJLAVFZO@dell.com	9737903231	4	5991467729210854	2012/01	user7962	password	31	80000	F
7963	WOWMZC	TINUDTUSZT	3449409956 Dell Way	\N	IMOYZGS	WI	98601	US	1	TINUDTUSZT@dell.com	3449409956	5	1226184010040015	2010/08	user7963	password	41	40000	F
7964	EVEGPM	UJPODINWQZ	7091462207 Dell Way	\N	LPYRHXQ	NE	80079	US	1	UJPODINWQZ@dell.com	7091462207	1	4872981993481517	2012/05	user7964	password	63	20000	F
7965	ULUHGE	XUHFHEVGPK	3711603314 Dell Way	\N	FHSCYHW	NH	40704	US	1	XUHFHEVGPK@dell.com	3711603314	3	7438951655291022	2012/10	user7965	password	84	80000	F
7966	SZLWWF	EBMIXTYIZF	4668589984 Dell Way	\N	BBDJYTR	HI	41818	US	1	EBMIXTYIZF@dell.com	4668589984	1	2067499658092856	2009/11	user7966	password	41	20000	M
7967	TXTZBU	LKSFJBEPCG	9670313072 Dell Way	\N	TLEMDJV	NC	58367	US	1	LKSFJBEPCG@dell.com	9670313072	5	4680963178165257	2009/11	user7967	password	37	20000	M
7968	AZWULH	NRQOWFQCYC	6081566155 Dell Way	\N	GLFQHTE	IA	66451	US	1	NRQOWFQCYC@dell.com	6081566155	3	5708932091947645	2012/07	user7968	password	41	100000	M
7969	EQALER	BSNHJPGLVR	6371714250 Dell Way	\N	RMZLQFB	FL	78469	US	1	BSNHJPGLVR@dell.com	6371714250	1	3922018751502037	2012/11	user7969	password	82	20000	F
7970	XNQPPJ	CXTSDFOVXA	2166342195 Dell Way	\N	VIQBKVU	AK	85062	US	1	CXTSDFOVXA@dell.com	2166342195	5	7137161269318313	2008/01	user7970	password	30	100000	M
7971	VMEFPB	YHFDWBAXWJ	8728588146 Dell Way	\N	NXUISUE	TX	72835	US	1	YHFDWBAXWJ@dell.com	8728588146	5	7386567065492273	2008/10	user7971	password	36	100000	F
7972	LBWMZE	SDAUDXQNLO	5231732394 Dell Way	\N	HUHBYDT	SD	11502	US	1	SDAUDXQNLO@dell.com	5231732394	5	8127101044170559	2011/09	user7972	password	21	20000	M
7973	XQSBJV	CDZAUMLJUF	6508008199 Dell Way	\N	QVEUPZV	AZ	85318	US	1	CDZAUMLJUF@dell.com	6508008199	4	5772234999109060	2011/12	user7973	password	37	60000	M
7974	ZQYVTC	UTWHEGBKXX	9491090448 Dell Way	\N	PSMONOK	CT	40997	US	1	UTWHEGBKXX@dell.com	9491090448	4	3638941467273980	2009/05	user7974	password	82	20000	F
7975	VZTYUM	VBRBCBYZQR	6971671860 Dell Way	\N	MFEAQHJ	NE	18689	US	1	VBRBCBYZQR@dell.com	6971671860	4	5159174336586148	2010/12	user7975	password	52	40000	M
7976	FITREV	IFYKEXBVKG	8817814369 Dell Way	\N	ALXIUMK	MN	34254	US	1	IFYKEXBVKG@dell.com	8817814369	1	3203175193630159	2009/05	user7976	password	33	60000	M
7977	ZFXUOD	SYIQZDAGEL	2414121700 Dell Way	\N	EMGQWSX	OR	74767	US	1	SYIQZDAGEL@dell.com	2414121700	1	2154880960937589	2009/08	user7977	password	81	40000	M
7978	UDJXVI	FMIJNONZTA	7992571988 Dell Way	\N	FJWYHQQ	MI	72365	US	1	FMIJNONZTA@dell.com	7992571988	5	3755129162687808	2011/03	user7978	password	27	60000	F
7979	NJDVPQ	DYDSMCMMIW	9885018766 Dell Way	\N	JGDZXPR	NY	47246	US	1	DYDSMCMMIW@dell.com	9885018766	2	6247827885672451	2008/10	user7979	password	82	80000	F
7980	AMSRQR	UJEXVRGRAM	4522035089 Dell Way	\N	UAKKSCV	OH	47840	US	1	UJEXVRGRAM@dell.com	4522035089	5	2733025087509304	2009/06	user7980	password	41	40000	M
7981	AZNSUW	WRSNXJOKEO	5668208833 Dell Way	\N	VOGXJYI	PA	78841	US	1	WRSNXJOKEO@dell.com	5668208833	1	2847358324564993	2012/05	user7981	password	26	100000	F
7982	QOCNKU	FYSOMCSBYH	3096335390 Dell Way	\N	HVQGEKA	NY	49522	US	1	FYSOMCSBYH@dell.com	3096335390	3	8037180598825217	2009/05	user7982	password	25	100000	M
7983	ENIYSH	QHTTAUSHCO	6223445101 Dell Way	\N	YJSJJKU	NJ	92444	US	1	QHTTAUSHCO@dell.com	6223445101	5	3686960619408637	2011/12	user7983	password	35	100000	F
7984	PVEWML	PGLJYTLMSU	8227942874 Dell Way	\N	FBEPWUN	MN	77600	US	1	PGLJYTLMSU@dell.com	8227942874	1	7240727256052197	2008/12	user7984	password	28	80000	M
7985	HMHTBN	FLMZXYRRDT	2046582639 Dell Way	\N	WTQRGCK	AR	29393	US	1	FLMZXYRRDT@dell.com	2046582639	1	2871824940666556	2009/09	user7985	password	19	60000	F
7986	HHFVNQ	HMNGEFKYCD	1614131371 Dell Way	\N	OUJQFKW	IN	55175	US	1	HMNGEFKYCD@dell.com	1614131371	3	2800208782311529	2008/02	user7986	password	44	40000	F
7987	PFYGNL	TUPZENCICW	8391541242 Dell Way	\N	SSBDPJQ	NV	94369	US	1	TUPZENCICW@dell.com	8391541242	4	1562827485147863	2008/02	user7987	password	53	80000	F
7988	LAXWTR	LTWZVEBSWU	2214742015 Dell Way	\N	TZJDQAB	MI	77855	US	1	LTWZVEBSWU@dell.com	2214742015	4	9015168894547970	2011/05	user7988	password	36	20000	F
7989	DXEVJX	RITWKMTEGT	2677697498 Dell Way	\N	NJJOLUH	NE	47755	US	1	RITWKMTEGT@dell.com	2677697498	2	8334342896007002	2010/04	user7989	password	33	60000	F
7990	JKOHCX	BYHNRMULZD	8277187331 Dell Way	\N	UOPOVEZ	AL	44587	US	1	BYHNRMULZD@dell.com	8277187331	3	6883695643860847	2008/01	user7990	password	79	40000	F
7991	KSOITN	PHFCBQCFKQ	1282021893 Dell Way	\N	VZLZZMJ	RI	94716	US	1	PHFCBQCFKQ@dell.com	1282021893	4	9941737474873664	2012/03	user7991	password	51	40000	M
7992	APRNFY	SHAIJGTZBS	8568344719 Dell Way	\N	LBRXLLW	MN	32542	US	1	SHAIJGTZBS@dell.com	8568344719	2	5029837015084923	2009/08	user7992	password	42	40000	F
7993	ZVKYNR	ZWBFPAHHLI	2138760960 Dell Way	\N	ZJULFGR	AR	62452	US	1	ZWBFPAHHLI@dell.com	2138760960	2	2832064284943044	2010/08	user7993	password	48	60000	F
7994	VKANKW	OPLPXTAGTJ	1318046902 Dell Way	\N	AEPGVQV	WV	96593	US	1	OPLPXTAGTJ@dell.com	1318046902	3	6475301790982485	2010/11	user7994	password	23	40000	F
7995	BUSYII	KYFEYLXILB	1918080017 Dell Way	\N	XRXNNWM	ND	37677	US	1	KYFEYLXILB@dell.com	1918080017	1	2890750376973301	2008/04	user7995	password	56	40000	F
7996	FFKNPI	TTHEQPPSNH	9927922782 Dell Way	\N	PBUMOJU	NV	42742	US	1	TTHEQPPSNH@dell.com	9927922782	5	6769654218573124	2010/01	user7996	password	69	80000	F
7997	DHWLAQ	TEHJUZWCPX	3251848180 Dell Way	\N	WBMGVCP	TN	94414	US	1	TEHJUZWCPX@dell.com	3251848180	2	1174491249956190	2012/02	user7997	password	39	20000	F
7998	ENKUGP	BPJAMLQKIR	9352807888 Dell Way	\N	WONZEIX	ME	70997	US	1	BPJAMLQKIR@dell.com	9352807888	2	7920549986883999	2009/06	user7998	password	28	40000	M
7999	NEGCGW	MHIXXSGOPV	8716893518 Dell Way	\N	COZKMLC	MA	83378	US	1	MHIXXSGOPV@dell.com	8716893518	4	3483669833280146	2008/01	user7999	password	37	60000	F
8000	NQLJDS	SBQKHFACHO	6605818496 Dell Way	\N	CSANUKJ	NM	12015	US	1	SBQKHFACHO@dell.com	6605818496	4	1277671463787555	2012/03	user8000	password	34	40000	M
8001	RTYKLZ	AWHGWKNKMF	9094764851 Dell Way	\N	LAZWJQW	WY	34834	US	1	AWHGWKNKMF@dell.com	9094764851	5	5071015951689333	2008/04	user8001	password	38	80000	F
8002	FEMFFJ	NLFXZQKECK	5912567110 Dell Way	\N	EYUVUUC	OH	69945	US	1	NLFXZQKECK@dell.com	5912567110	5	9460393764544280	2012/08	user8002	password	88	20000	M
8003	LHAUUM	ARLRBQTMVR	7029232137 Dell Way	\N	HQLBSDS	IL	97331	US	1	ARLRBQTMVR@dell.com	7029232137	1	6228405591100455	2011/02	user8003	password	45	20000	F
8004	KXFWXW	IOYZILUZSK	2285989990 Dell Way	\N	LUDPNLO	FL	57390	US	1	IOYZILUZSK@dell.com	2285989990	5	7085875509306789	2010/11	user8004	password	25	100000	M
8005	HUSEDH	DCQOXPHIBB	1809738051 Dell Way	\N	LQPXETK	KY	63201	US	1	DCQOXPHIBB@dell.com	1809738051	5	5566626457497478	2008/10	user8005	password	41	60000	M
8006	BRSJVV	ZKSORAPTMG	2910313269 Dell Way	\N	IJLCUTS	UT	66372	US	1	ZKSORAPTMG@dell.com	2910313269	1	4720600393600762	2010/07	user8006	password	18	60000	F
8007	TYBOXL	HMCHCWUIFE	6016493238 Dell Way	\N	TIYNAVD	IA	89438	US	1	HMCHCWUIFE@dell.com	6016493238	4	4943763938732445	2010/05	user8007	password	66	40000	F
8008	SWFDDR	GLTDGBJKVR	5343588506 Dell Way	\N	IISEMZB	AL	77599	US	1	GLTDGBJKVR@dell.com	5343588506	3	2001467389520257	2008/11	user8008	password	47	100000	M
8009	PAXGHJ	AKPBTZWLIF	1006277014 Dell Way	\N	EMRDOSX	AL	39031	US	1	AKPBTZWLIF@dell.com	1006277014	1	2976541142445057	2010/01	user8009	password	89	100000	F
8010	XGIGGT	VINVFYEKDR	4408624415 Dell Way	\N	CGFVDGE	DC	47329	US	1	VINVFYEKDR@dell.com	4408624415	3	5135079524945468	2009/07	user8010	password	55	40000	M
8011	WMBPIK	CEPBIAEZDK	3874873312 Dell Way	\N	FZOLDSW	MS	33884	US	1	CEPBIAEZDK@dell.com	3874873312	5	8315581133123488	2012/02	user8011	password	62	80000	M
8012	RHYBJC	RKKRPKUAQT	4318283927 Dell Way	\N	OBXHYKO	IA	32902	US	1	RKKRPKUAQT@dell.com	4318283927	1	4259518530219793	2012/10	user8012	password	88	80000	F
8013	WSKZKV	KBLUWLKQAM	5837743268 Dell Way	\N	NHKXWRE	HI	76866	US	1	KBLUWLKQAM@dell.com	5837743268	2	5611281935125590	2010/11	user8013	password	58	40000	M
8014	ZJZVTB	GNYRYORLCZ	7946626942 Dell Way	\N	WAVNEBG	OK	34671	US	1	GNYRYORLCZ@dell.com	7946626942	2	2309236570261419	2009/08	user8014	password	72	40000	M
8015	TDRUJF	SBEHTQJTMJ	1653664617 Dell Way	\N	PZOQGHY	AL	55234	US	1	SBEHTQJTMJ@dell.com	1653664617	2	1932165755424648	2012/09	user8015	password	22	60000	M
8016	TIEZBG	DIAUSTGCIG	5738234416 Dell Way	\N	QZNXYNK	WY	90464	US	1	DIAUSTGCIG@dell.com	5738234416	5	6098123788367957	2010/05	user8016	password	45	40000	M
8017	OHUVLC	VFVPMXYSNY	3088917293 Dell Way	\N	GLWUWWR	MD	70658	US	1	VFVPMXYSNY@dell.com	3088917293	5	1395243891514837	2011/04	user8017	password	73	20000	M
8018	NZBQVH	LLTJJMWHSI	7668060241 Dell Way	\N	EMFAEPS	MD	62011	US	1	LLTJJMWHSI@dell.com	7668060241	1	8977577575948090	2010/03	user8018	password	54	20000	F
8019	ORAVDL	PMUCJCVSHI	9655040402 Dell Way	\N	XHMMZWB	OR	89030	US	1	PMUCJCVSHI@dell.com	9655040402	2	1489271419122815	2010/04	user8019	password	34	20000	M
8020	GVCRLP	MNYOIQVQOD	9307409468 Dell Way	\N	DBDZDWW	CA	18094	US	1	MNYOIQVQOD@dell.com	9307409468	3	4195782773196697	2008/07	user8020	password	39	40000	F
8021	KBVZNI	XCROYHDCKE	5590184320 Dell Way	\N	FKHBHJE	GA	93208	US	1	XCROYHDCKE@dell.com	5590184320	2	5245379394385964	2012/09	user8021	password	80	20000	M
8022	REHACK	RRIZUKJYQU	1260256358 Dell Way	\N	GRBQVGO	KY	63811	US	1	RRIZUKJYQU@dell.com	1260256358	1	3950563746038824	2012/05	user8022	password	25	60000	M
8023	KOPUFG	DEBOOAEJGW	6205101876 Dell Way	\N	KWSQLBG	MN	28991	US	1	DEBOOAEJGW@dell.com	6205101876	2	6136872547212989	2011/11	user8023	password	25	20000	F
8024	SXSZBX	APLAUVHQFE	2531470486 Dell Way	\N	IWPKCBP	OH	48891	US	1	APLAUVHQFE@dell.com	2531470486	2	4124417346902192	2009/06	user8024	password	78	100000	F
8025	NYKLZA	XAUSHLXLUU	9260214458 Dell Way	\N	BEWDTOO	WA	95609	US	1	XAUSHLXLUU@dell.com	9260214458	2	4835554515942931	2011/03	user8025	password	76	40000	F
8026	FSCGPD	BHKMFWGZYL	8218430265 Dell Way	\N	WBFLQDJ	ND	40141	US	1	BHKMFWGZYL@dell.com	8218430265	2	5619033561088145	2011/07	user8026	password	65	100000	F
8027	TCWXDE	HQJEXICIFE	5575066908 Dell Way	\N	NQVRZKZ	SC	73332	US	1	HQJEXICIFE@dell.com	5575066908	3	3581809195689857	2008/03	user8027	password	59	100000	F
8028	LULQCC	AHZJKIOPVE	8240753620 Dell Way	\N	KMEVMYN	AK	42037	US	1	AHZJKIOPVE@dell.com	8240753620	1	6331719169393182	2009/01	user8028	password	84	100000	M
8029	JMZLMG	LVRTJGPNRC	6193808912 Dell Way	\N	RMPQZPZ	SC	76535	US	1	LVRTJGPNRC@dell.com	6193808912	1	8294593652244658	2010/01	user8029	password	67	100000	F
8030	RIYXTT	ONDVCQMEIY	9061973814 Dell Way	\N	TYXIYSC	MS	89304	US	1	ONDVCQMEIY@dell.com	9061973814	5	8981078508310021	2010/11	user8030	password	44	40000	F
8031	HEYBSL	ENNVASDYMB	4014390119 Dell Way	\N	WVAOXNL	SD	55526	US	1	ENNVASDYMB@dell.com	4014390119	2	4269372299779207	2011/08	user8031	password	57	100000	M
8032	MBNXGB	LBBEEZQGVM	6794489797 Dell Way	\N	GKKUWFH	FL	62452	US	1	LBBEEZQGVM@dell.com	6794489797	5	2867947727907449	2008/11	user8032	password	90	80000	M
8033	MOEOAF	PEKPVRKHYV	7127036676 Dell Way	\N	SSRXZWM	NJ	78258	US	1	PEKPVRKHYV@dell.com	7127036676	5	6730102129746229	2011/06	user8033	password	59	20000	F
8034	TSBYHF	JWBAHJYDBQ	1710351746 Dell Way	\N	VYPRLGL	CO	13506	US	1	JWBAHJYDBQ@dell.com	1710351746	4	5505136970896274	2011/12	user8034	password	56	40000	M
8035	PIYURV	WRDGQGHGBG	6692055845 Dell Way	\N	WTRCFUD	IL	60740	US	1	WRDGQGHGBG@dell.com	6692055845	5	5557513920590282	2008/04	user8035	password	29	80000	M
8036	COIYKA	CRQJYWLFTE	7715819952 Dell Way	\N	XVJRYRG	NH	62709	US	1	CRQJYWLFTE@dell.com	7715819952	4	9038852012250572	2012/06	user8036	password	56	20000	F
8037	WZLWBC	MKBJVHCAEX	5840923463 Dell Way	\N	KVWBCMQ	TN	30907	US	1	MKBJVHCAEX@dell.com	5840923463	4	7556644614785910	2008/10	user8037	password	74	100000	M
8038	GUUJGF	KPASSBWQLS	9553660198 Dell Way	\N	NNUZDQF	OH	41489	US	1	KPASSBWQLS@dell.com	9553660198	4	1935255580581724	2011/09	user8038	password	78	100000	F
8039	PHSVSI	VKAXHRIZEW	8554493901 Dell Way	\N	UEAKKST	KY	51327	US	1	VKAXHRIZEW@dell.com	8554493901	1	2259135118685663	2011/01	user8039	password	61	40000	F
8040	ICBQYL	RVTIESNAMR	3997222796 Dell Way	\N	AWCTPLF	MI	53895	US	1	RVTIESNAMR@dell.com	3997222796	1	5569726102054120	2012/05	user8040	password	78	40000	F
8041	WWLIOG	BXLUKMHCNE	6412763602 Dell Way	\N	EGTPLFC	RI	40074	US	1	BXLUKMHCNE@dell.com	6412763602	4	7627423433586956	2010/12	user8041	password	35	40000	M
8042	RQJYSG	JNRWUTJYYP	9910627001 Dell Way	\N	SOBXQVG	IA	55519	US	1	JNRWUTJYYP@dell.com	9910627001	4	4983387600630522	2009/12	user8042	password	36	100000	M
8043	QVIWFW	OBQIKOGAHV	8353995550 Dell Way	\N	BEMWLSJ	MI	46081	US	1	OBQIKOGAHV@dell.com	8353995550	4	4524683230556548	2008/07	user8043	password	19	80000	F
8044	JOPFCQ	VKBKRCRMDW	5209951524 Dell Way	\N	YAIRKTB	GA	47414	US	1	VKBKRCRMDW@dell.com	5209951524	2	9694850415457040	2010/12	user8044	password	43	100000	M
8045	YBQOXB	QITSAGWXEW	4115336393 Dell Way	\N	FWGZYLJ	MD	75862	US	1	QITSAGWXEW@dell.com	4115336393	5	7312047524843366	2011/10	user8045	password	35	80000	M
8046	XETYVB	RNCYJZCGEZ	4456837323 Dell Way	\N	MDYYNIR	UT	31329	US	1	RNCYJZCGEZ@dell.com	4456837323	3	9970124038867652	2011/03	user8046	password	78	60000	F
8047	OLEQDS	SBBSEIWEVA	6937715010 Dell Way	\N	CTNLLKR	TN	96626	US	1	SBBSEIWEVA@dell.com	6937715010	3	2224614807870239	2010/12	user8047	password	54	20000	F
8048	RSOJLQ	LDVTAZOACI	1650601966 Dell Way	\N	ONUZEQY	TN	16492	US	1	LDVTAZOACI@dell.com	1650601966	2	1313370542600750	2010/05	user8048	password	51	40000	F
8049	APNRAR	MURMJSOSHB	2899719482 Dell Way	\N	MGFCEAE	IA	41476	US	1	MURMJSOSHB@dell.com	2899719482	5	7526584490668029	2011/01	user8049	password	77	80000	M
8050	IIRZVM	RHVJVOQWAW	2650044220 Dell Way	\N	BDBCIHL	MT	21364	US	1	RHVJVOQWAW@dell.com	2650044220	1	2611709767021239	2012/11	user8050	password	78	40000	F
8051	NIAZZI	VIDKZZKVBO	5603063717 Dell Way	\N	XEWFQKI	SD	62904	US	1	VIDKZZKVBO@dell.com	5603063717	5	5171444671694190	2009/02	user8051	password	67	100000	F
8052	SWKAST	ECSENOFBMK	4420717879 Dell Way	\N	YRAIAWX	MT	69854	US	1	ECSENOFBMK@dell.com	4420717879	5	8183888622559608	2008/09	user8052	password	35	80000	M
8053	RUGKZI	DDVSIXETVV	1894224391 Dell Way	\N	UEVQBJH	MN	28125	US	1	DDVSIXETVV@dell.com	1894224391	3	9208817428443582	2009/04	user8053	password	52	20000	F
8054	TKBBOE	XGNUKGQGBU	5916045164 Dell Way	\N	CRWLZHQ	AZ	83257	US	1	XGNUKGQGBU@dell.com	5916045164	3	1902914593927562	2008/06	user8054	password	31	80000	M
8055	GVKKSQ	XNBEDIFXKX	9895262654 Dell Way	\N	UVWBMYX	AK	43367	US	1	XNBEDIFXKX@dell.com	9895262654	1	8147558977361769	2008/10	user8055	password	64	60000	M
8056	AVIRTW	TYZBDXMBRI	1354596992 Dell Way	\N	YTUWQVG	NM	87030	US	1	TYZBDXMBRI@dell.com	1354596992	5	6842456047423185	2011/03	user8056	password	37	80000	F
8057	PKULDT	LFXJSYBAWV	2318310743 Dell Way	\N	VTMQZCM	AK	92997	US	1	LFXJSYBAWV@dell.com	2318310743	4	2399917283561080	2010/05	user8057	password	33	20000	M
8058	ALYTXE	QGWPHXLDTE	7907782944 Dell Way	\N	PJERWEP	AL	88172	US	1	QGWPHXLDTE@dell.com	7907782944	3	3448974265251309	2012/06	user8058	password	23	20000	M
8059	ATUEKA	BZIZLLSPBC	1753385799 Dell Way	\N	TTZYJAV	CO	50184	US	1	BZIZLLSPBC@dell.com	1753385799	1	8941969872452320	2008/02	user8059	password	74	20000	M
8060	OJHPLG	YLSKDILGCE	6315456542 Dell Way	\N	GANGVQS	WA	74860	US	1	YLSKDILGCE@dell.com	6315456542	1	8386578145436943	2009/03	user8060	password	67	100000	M
8061	YMBFKM	YUQGGWIKDJ	1709354149 Dell Way	\N	XKFNCDG	OH	27977	US	1	YUQGGWIKDJ@dell.com	1709354149	1	5035209919791669	2011/12	user8061	password	22	80000	F
8062	CYWPWR	FDXCLIFUGP	7989594615 Dell Way	\N	AUSDAKI	CO	50204	US	1	FDXCLIFUGP@dell.com	7989594615	5	4659111535642296	2012/08	user8062	password	80	100000	M
8063	TNKKSN	IUZRAUXQUR	6145040011 Dell Way	\N	IXRSGUE	AL	69400	US	1	IUZRAUXQUR@dell.com	6145040011	5	3248917045537382	2010/10	user8063	password	75	20000	F
8064	FPBSXV	SOWMLMHDUE	5501009235 Dell Way	\N	UNLPRLG	IA	38405	US	1	SOWMLMHDUE@dell.com	5501009235	4	2053119518328458	2009/11	user8064	password	49	60000	F
8065	MFJIXY	EJKQQNLVHY	2400423827 Dell Way	\N	GXQSDWB	NM	60059	US	1	EJKQQNLVHY@dell.com	2400423827	5	4647034118417651	2010/05	user8065	password	79	20000	M
8066	EKMDOW	NFNAQJHPQF	1533990163 Dell Way	\N	FIICJZR	NC	91110	US	1	NFNAQJHPQF@dell.com	1533990163	1	3752620019018650	2012/03	user8066	password	84	20000	M
8067	KFEHSJ	USAEAPUFVD	7498790305 Dell Way	\N	OYMNPAK	NM	24884	US	1	USAEAPUFVD@dell.com	7498790305	3	4308978116605431	2011/08	user8067	password	88	20000	M
8068	DIOMDG	NHGCBMYEAW	3255130479 Dell Way	\N	RNMSYCW	NV	68556	US	1	NHGCBMYEAW@dell.com	3255130479	2	3541805577930063	2009/05	user8068	password	26	40000	M
8069	RVUXIC	ELDRJIRGAF	7876259184 Dell Way	\N	SSDVPUM	TX	18993	US	1	ELDRJIRGAF@dell.com	7876259184	1	4940585391130299	2012/05	user8069	password	25	60000	F
8070	XMOZQZ	DIJLZQMEJE	6852578955 Dell Way	\N	IEUCRRF	ME	76633	US	1	DIJLZQMEJE@dell.com	6852578955	2	2324788328260183	2011/11	user8070	password	45	80000	F
8071	YQZXTH	HFGXRLGWTL	2900387398 Dell Way	\N	RWCIBNB	OK	85745	US	1	HFGXRLGWTL@dell.com	2900387398	3	7311441286932678	2010/02	user8071	password	20	60000	M
8072	AKMHSR	OPJZWFSHWP	5283015036 Dell Way	\N	KEQYGJU	MN	85601	US	1	OPJZWFSHWP@dell.com	5283015036	1	9608205525670202	2010/07	user8072	password	68	60000	M
8073	EURWJH	FIDKBLHQVL	5245192570 Dell Way	\N	HUSROEN	AL	28289	US	1	FIDKBLHQVL@dell.com	5245192570	3	7804354592692108	2008/01	user8073	password	71	40000	M
8074	KFERLN	VWPGDGCPOW	4653073329 Dell Way	\N	HFKLTLQ	GA	96412	US	1	VWPGDGCPOW@dell.com	4653073329	2	9961594211868944	2008/09	user8074	password	78	60000	M
8075	AFKOAG	DHJKJYYFGE	1212167875 Dell Way	\N	QRXBIDA	OR	55690	US	1	DHJKJYYFGE@dell.com	1212167875	5	3174933695234358	2012/05	user8075	password	32	100000	M
8076	PKQVOX	EYHDXNJBDB	8564455315 Dell Way	\N	ZFKCGDP	ID	99921	US	1	EYHDXNJBDB@dell.com	8564455315	1	4662838360294700	2008/12	user8076	password	19	80000	F
8077	RLZPQX	WUUJDWMFVS	2121526074 Dell Way	\N	PXYSNES	KY	36783	US	1	WUUJDWMFVS@dell.com	2121526074	2	3526793668977916	2008/01	user8077	password	67	100000	F
8078	QKCOGW	JQAFDFAVUY	5658711319 Dell Way	\N	TNLYGUG	LA	25650	US	1	JQAFDFAVUY@dell.com	5658711319	3	2606177610345185	2009/04	user8078	password	63	100000	M
8079	SKZOTP	OYSTZOOXHC	5381265794 Dell Way	\N	IGIDMRI	WY	25888	US	1	OYSTZOOXHC@dell.com	5381265794	1	5517605064436794	2008/01	user8079	password	34	100000	F
8080	FJEVYD	OSCCHAJJJP	1140746064 Dell Way	\N	RMCIUBN	IL	33471	US	1	OSCCHAJJJP@dell.com	1140746064	3	3651401501614600	2009/03	user8080	password	71	60000	M
8081	XHOBVG	DXOEHXNXOA	6480288696 Dell Way	\N	ZXVBKCI	MI	56350	US	1	DXOEHXNXOA@dell.com	6480288696	4	7651194100268186	2009/02	user8081	password	43	40000	F
8082	XHFELD	SPKPDIEEHC	4119044831 Dell Way	\N	ZJNCRYP	ID	66283	US	1	SPKPDIEEHC@dell.com	4119044831	4	7846733428072185	2011/11	user8082	password	30	60000	F
8083	KTPNMF	YCIGHMOJMX	2817196720 Dell Way	\N	WOOVEVL	MT	50148	US	1	YCIGHMOJMX@dell.com	2817196720	2	3694860605057329	2009/10	user8083	password	50	80000	M
8084	AHAFGD	ONKBBTNZQB	2128674328 Dell Way	\N	OLGJWTV	CA	96677	US	1	ONKBBTNZQB@dell.com	2128674328	3	7877408959902824	2010/03	user8084	password	41	60000	M
8085	JVUMJH	WKJQYIGZWR	7488344056 Dell Way	\N	GGOZCQY	GA	17606	US	1	WKJQYIGZWR@dell.com	7488344056	4	3782699434086680	2008/05	user8085	password	79	60000	F
8086	QXOXTZ	HJXQQXNHDU	8937446678 Dell Way	\N	WDWMCBO	SD	87165	US	1	HJXQQXNHDU@dell.com	8937446678	5	3118401303887367	2011/04	user8086	password	49	40000	F
8087	AGYZOH	XEYVRGZLCC	5330647183 Dell Way	\N	IOFKDAG	AL	90420	US	1	XEYVRGZLCC@dell.com	5330647183	4	2514349108561873	2012/02	user8087	password	42	100000	F
8088	GXXOUB	MQTSPFURNJ	9784893768 Dell Way	\N	XXNXDOV	NM	37699	US	1	MQTSPFURNJ@dell.com	9784893768	3	4596793338656426	2009/06	user8088	password	72	60000	F
8089	QDESPU	LIJRDBENYB	3811329597 Dell Way	\N	BWFPRWX	NM	44857	US	1	LIJRDBENYB@dell.com	3811329597	5	8597444851882757	2008/07	user8089	password	32	80000	M
8090	JLGEXO	NOSOSFMUGI	1781868973 Dell Way	\N	AWAWUQG	CO	61598	US	1	NOSOSFMUGI@dell.com	1781868973	1	1672530533745885	2009/11	user8090	password	68	80000	F
8091	YVEMIS	FXLKKGRTGO	1210208002 Dell Way	\N	TCJJILY	MI	64686	US	1	FXLKKGRTGO@dell.com	1210208002	4	5323799432720989	2011/05	user8091	password	74	80000	F
8092	ZDORJL	DTVJLOQAIS	9091617857 Dell Way	\N	JRBVQNK	NV	30133	US	1	DTVJLOQAIS@dell.com	9091617857	2	6498043168336154	2011/01	user8092	password	77	80000	F
8093	JINUMH	QVTFMUNEDF	6349650118 Dell Way	\N	GYWTJNZ	ID	91534	US	1	QVTFMUNEDF@dell.com	6349650118	5	9493253632914276	2010/08	user8093	password	27	80000	M
8094	ROKZFG	SKSNYXQDDP	4369500427 Dell Way	\N	AXZNXGL	MO	27475	US	1	SKSNYXQDDP@dell.com	4369500427	5	8037223979365081	2010/09	user8094	password	69	20000	F
8095	CDLIWV	AJUXAXBQXZ	8371391234 Dell Way	\N	PLWVWIA	IA	31707	US	1	AJUXAXBQXZ@dell.com	8371391234	4	9172629579901696	2010/12	user8095	password	28	80000	F
8096	OYYKYH	EWICXYAWOM	2948434018 Dell Way	\N	SKIBLPI	IA	41664	US	1	EWICXYAWOM@dell.com	2948434018	4	3506176207214594	2009/05	user8096	password	43	100000	F
8097	HJGPNC	XQZWQWKDPU	7234742086 Dell Way	\N	MQGBYMK	DE	32422	US	1	XQZWQWKDPU@dell.com	7234742086	3	6600330629851670	2008/06	user8097	password	85	40000	M
8098	EXIGVZ	GRQCCTRXFI	5353378339 Dell Way	\N	DHHPRLW	MA	98523	US	1	GRQCCTRXFI@dell.com	5353378339	3	5026723033282906	2010/09	user8098	password	36	60000	M
8099	PVLOBD	FDFYVCEDGL	3666763623 Dell Way	\N	KWDWSNW	GA	93120	US	1	FDFYVCEDGL@dell.com	3666763623	4	6931561231147499	2010/03	user8099	password	39	20000	M
8100	TSAWXE	CWZFACLLNH	6815281904 Dell Way	\N	OJABGFZ	MT	84409	US	1	CWZFACLLNH@dell.com	6815281904	1	9951932358555496	2012/03	user8100	password	88	80000	M
8101	ZOWDQS	DVTFHETPTD	6901330841 Dell Way	\N	PUJVUWR	ME	96765	US	1	DVTFHETPTD@dell.com	6901330841	2	2770072651095688	2011/01	user8101	password	28	80000	M
8102	AUGTXC	MCKQWZJZPE	4412623840 Dell Way	\N	ILYFCJE	OR	77560	US	1	MCKQWZJZPE@dell.com	4412623840	2	8242128403391690	2010/12	user8102	password	48	60000	M
8103	RHQTTT	DKQDUPSYYD	8506716198 Dell Way	\N	XEGHIZA	OK	41085	US	1	DKQDUPSYYD@dell.com	8506716198	2	4007639372721315	2009/10	user8103	password	24	100000	F
8104	TRVNVG	DYASRYRVWV	7318021898 Dell Way	\N	BDDAEWJ	WY	20077	US	1	DYASRYRVWV@dell.com	7318021898	2	9122649163007736	2011/02	user8104	password	89	60000	M
8105	VBQBEP	BXGAOCWJDZ	4558729431 Dell Way	\N	NDDJNDM	HI	42721	US	1	BXGAOCWJDZ@dell.com	4558729431	1	5635623283684254	2009/07	user8105	password	42	20000	M
8106	ZFTPHQ	WHEYDOBCBF	3153853259 Dell Way	\N	GLSJYYS	KY	96534	US	1	WHEYDOBCBF@dell.com	3153853259	4	5600157393608243	2010/11	user8106	password	25	60000	F
8107	WEKMAR	RYUGAXHFDT	4236490558 Dell Way	\N	YMRXFAW	MN	76044	US	1	RYUGAXHFDT@dell.com	4236490558	1	6641082076821477	2010/08	user8107	password	72	40000	M
8108	DVUVMS	PTSNAYQUWD	8747121909 Dell Way	\N	MTJNPVG	WI	86641	US	1	PTSNAYQUWD@dell.com	8747121909	3	5129923962987960	2011/09	user8108	password	34	80000	M
8109	ZOASEU	KRUIIPFLBY	9393927975 Dell Way	\N	VOOQUNM	NV	94236	US	1	KRUIIPFLBY@dell.com	9393927975	2	7028642654884607	2008/01	user8109	password	33	20000	M
8110	GWTAGL	VPTKVFMUAB	5034013809 Dell Way	\N	IQWVCNU	AL	80125	US	1	VPTKVFMUAB@dell.com	5034013809	1	8162405155133457	2011/05	user8110	password	45	100000	F
8111	DYLOTB	HEWMRQMSZD	6858571681 Dell Way	\N	OUFBPGW	AL	50500	US	1	HEWMRQMSZD@dell.com	6858571681	4	8067366757430137	2008/08	user8111	password	88	20000	M
8112	KSHMZM	JMDZZWYCLT	8279170581 Dell Way	\N	INIOJJA	AK	16565	US	1	JMDZZWYCLT@dell.com	8279170581	1	7135277570690960	2011/03	user8112	password	34	20000	M
8113	NRWAAI	EAHAYJMSSZ	2722773814 Dell Way	\N	BGILHJN	CO	44502	US	1	EAHAYJMSSZ@dell.com	2722773814	5	6101001727394760	2010/01	user8113	password	50	100000	M
8114	HZUQDU	YETHQLAPNG	3148371502 Dell Way	\N	YYOHMRR	NV	58515	US	1	YETHQLAPNG@dell.com	3148371502	1	6548075360246003	2011/01	user8114	password	44	100000	M
8115	DQDYOH	RWYDWOQDMP	5452859799 Dell Way	\N	RUBILSW	NY	81001	US	1	RWYDWOQDMP@dell.com	5452859799	2	8283428538125009	2012/05	user8115	password	76	20000	M
8116	XYNFPJ	DTFRJIEZZY	4224541187 Dell Way	\N	BIJTFBO	OK	48477	US	1	DTFRJIEZZY@dell.com	4224541187	3	7974207804538310	2008/08	user8116	password	71	20000	M
8117	GHDPLW	UDGDHGDFHL	8895343520 Dell Way	\N	PARRPKC	WI	96587	US	1	UDGDHGDFHL@dell.com	8895343520	1	5933969310950488	2011/03	user8117	password	23	100000	F
8118	FLXBGA	IJHOMNVYDW	5596533050 Dell Way	\N	PVLAXKZ	SC	55272	US	1	IJHOMNVYDW@dell.com	5596533050	3	7084496644325555	2010/04	user8118	password	28	80000	M
8119	AWZBFI	JTVXPTBMJW	5663072566 Dell Way	\N	YJUIIPV	TX	99713	US	1	JTVXPTBMJW@dell.com	5663072566	3	3423550205305219	2011/03	user8119	password	90	80000	F
8120	ZTHICB	DZQXADHXBR	5707539610 Dell Way	\N	RKAGGWG	PA	37268	US	1	DZQXADHXBR@dell.com	5707539610	3	5784524570684881	2010/02	user8120	password	63	60000	M
8121	XUYZYY	QVZTCWUUOF	5369593763 Dell Way	\N	UULQBEY	NE	64100	US	1	QVZTCWUUOF@dell.com	5369593763	1	7341690762434155	2008/07	user8121	password	58	20000	F
8122	NAHLQD	LJGHEAVJVQ	3526760292 Dell Way	\N	UMSZKHO	VT	44539	US	1	LJGHEAVJVQ@dell.com	3526760292	1	9701036934740842	2012/01	user8122	password	43	40000	F
8123	QURUFA	AMEBIOWZII	3935451237 Dell Way	\N	RHTZWQJ	DE	70114	US	1	AMEBIOWZII@dell.com	3935451237	5	7431010665372015	2011/04	user8123	password	73	40000	F
8124	LCHLDU	QFDEBDNKVV	2649555593 Dell Way	\N	DUSUDWM	MO	87169	US	1	QFDEBDNKVV@dell.com	2649555593	1	2648680141661316	2012/06	user8124	password	38	40000	M
8125	PVSKMX	NRYQFJMANG	6635454429 Dell Way	\N	SHKPUWL	WI	11997	US	1	NRYQFJMANG@dell.com	6635454429	5	5370960625819862	2012/04	user8125	password	21	60000	F
8126	TXPQKH	PBMZOMMUFU	6239973702 Dell Way	\N	FUOBGNC	TX	48575	US	1	PBMZOMMUFU@dell.com	6239973702	4	7390560262836517	2011/04	user8126	password	78	40000	F
8127	LBPSRR	EQFRCZWXFR	2090173649 Dell Way	\N	LGXZJTK	WI	57916	US	1	EQFRCZWXFR@dell.com	2090173649	3	8290370296221227	2012/12	user8127	password	89	40000	F
8128	OCRGGH	LXKLUHQLTX	4848735737 Dell Way	\N	ITGCEFQ	IL	81759	US	1	LXKLUHQLTX@dell.com	4848735737	2	7928988300263882	2010/08	user8128	password	75	100000	M
8129	LFYTRV	ECPMTBGQJZ	7163875698 Dell Way	\N	XLDDBKX	MS	68192	US	1	ECPMTBGQJZ@dell.com	7163875698	5	3243833957705647	2010/11	user8129	password	85	100000	F
8130	WRTSWW	IIPJOGSODE	9990864270 Dell Way	\N	RGGCETT	TX	70699	US	1	IIPJOGSODE@dell.com	9990864270	2	6091668444685639	2012/04	user8130	password	67	80000	M
8131	LMUIUC	XERDXFHBXO	4034376445 Dell Way	\N	IASCTOU	PA	90516	US	1	XERDXFHBXO@dell.com	4034376445	4	2326183613389730	2008/06	user8131	password	24	60000	M
8132	WTTZRX	RVUWDWURFU	9835667117 Dell Way	\N	JINYCHV	ME	96183	US	1	RVUWDWURFU@dell.com	9835667117	3	4850936376955360	2008/11	user8132	password	46	100000	M
8133	DYIBPE	WLHTGYZAIH	2787729620 Dell Way	\N	NGJVCUU	AZ	28321	US	1	WLHTGYZAIH@dell.com	2787729620	1	1806342152878642	2010/01	user8133	password	72	80000	M
8134	CUPGRB	NLHLKHTRVA	1930716838 Dell Way	\N	AQCVKEA	NH	36477	US	1	NLHLKHTRVA@dell.com	1930716838	1	4285976091399789	2012/12	user8134	password	44	100000	M
8135	YEKZRW	GDGOXYJYZA	8737894292 Dell Way	\N	AUKFUAM	VA	28055	US	1	GDGOXYJYZA@dell.com	8737894292	4	2143760027829557	2009/09	user8135	password	80	20000	M
8136	HENDKR	KZPIIOHIPC	1831741356 Dell Way	\N	TUWTHUZ	DC	58063	US	1	KZPIIOHIPC@dell.com	1831741356	2	2885027988813817	2012/07	user8136	password	21	40000	M
8137	PJCHTC	XBKLJTALNV	8794844622 Dell Way	\N	IHCDGFR	KY	63239	US	1	XBKLJTALNV@dell.com	8794844622	2	2097427830100059	2012/07	user8137	password	77	60000	M
8138	XUQZRS	KDBEDNSYWA	9876636439 Dell Way	\N	BZGHQPW	MS	90540	US	1	KDBEDNSYWA@dell.com	9876636439	3	4788884866982699	2011/12	user8138	password	40	80000	M
8139	YSKQDN	SIRGBQCBRC	2844913725 Dell Way	\N	HYSXVGU	SC	69389	US	1	SIRGBQCBRC@dell.com	2844913725	3	6400870004668832	2010/04	user8139	password	42	60000	F
8140	TCEHUM	ZANPCOHEWF	4641828855 Dell Way	\N	XTBDNVU	OR	49770	US	1	ZANPCOHEWF@dell.com	4641828855	2	7776811114046723	2011/09	user8140	password	74	60000	M
8141	YTOKSO	YIRNPWJVUC	9204282739 Dell Way	\N	WYQSTJE	DC	64747	US	1	YIRNPWJVUC@dell.com	9204282739	5	3663579547777772	2011/05	user8141	password	22	80000	F
8142	QBWEZE	WMUTWPNZML	8818430589 Dell Way	\N	PFEZJIO	ID	28557	US	1	WMUTWPNZML@dell.com	8818430589	5	6091470434796066	2012/08	user8142	password	68	60000	M
8143	OTQSPD	NIZDWYPIOU	6548271358 Dell Way	\N	NNEVCLB	WI	44707	US	1	NIZDWYPIOU@dell.com	6548271358	5	9720839977264404	2009/06	user8143	password	61	100000	F
8144	FOUICC	IFZGUHUPVI	5797501454 Dell Way	\N	TRKESIO	KS	29740	US	1	IFZGUHUPVI@dell.com	5797501454	4	6846559814643115	2008/06	user8144	password	77	40000	F
8145	PRDSZI	RGDZBTUJMM	9688703219 Dell Way	\N	TRECFNI	PA	23937	US	1	RGDZBTUJMM@dell.com	9688703219	5	6806607707869262	2011/03	user8145	password	69	40000	M
8146	WBYFTE	ISGBNPOAJF	5515703122 Dell Way	\N	EMLSUFW	PA	17427	US	1	ISGBNPOAJF@dell.com	5515703122	3	3891146018635482	2009/11	user8146	password	35	20000	M
8147	EGSJPL	PRZFFZOLDB	5112746824 Dell Way	\N	WWVBSOD	GA	19074	US	1	PRZFFZOLDB@dell.com	5112746824	3	9963150756433608	2011/06	user8147	password	87	100000	M
8148	RFJCVA	BAGAPREQNA	2221300255 Dell Way	\N	MPTBSYD	DE	42973	US	1	BAGAPREQNA@dell.com	2221300255	5	8721425680443645	2008/09	user8148	password	62	80000	M
8149	ZVUZXV	GXKXCBLCNA	1018627002 Dell Way	\N	VOSUSXD	TN	79219	US	1	GXKXCBLCNA@dell.com	1018627002	5	5632558629382402	2011/09	user8149	password	53	60000	M
8150	HPKCVI	MTKOENBEIQ	1668507425 Dell Way	\N	XCIUGEO	ID	17679	US	1	MTKOENBEIQ@dell.com	1668507425	5	7843897876329721	2010/06	user8150	password	38	100000	F
8151	RXXZKQ	KYUXAYFQWI	9769518563 Dell Way	\N	ZQPDFWF	ID	76003	US	1	KYUXAYFQWI@dell.com	9769518563	5	2805210808757692	2009/08	user8151	password	36	100000	M
8152	DYZTIY	OFYMLPIUOZ	2585488495 Dell Way	\N	KREGXLZ	UT	34858	US	1	OFYMLPIUOZ@dell.com	2585488495	1	9417185212951154	2010/01	user8152	password	54	60000	M
8153	MIHKWN	JJYYSTMRDE	5659798951 Dell Way	\N	WJCHJYP	MT	17282	US	1	JJYYSTMRDE@dell.com	5659798951	5	2201007043477148	2008/07	user8153	password	26	60000	M
8154	KXTYGC	XFVQSNTWJD	2247426236 Dell Way	\N	ZRMYGAA	RI	98165	US	1	XFVQSNTWJD@dell.com	2247426236	4	5634928989689798	2009/04	user8154	password	46	80000	F
8155	DPMGMR	BDJPXGYAFQ	1352882528 Dell Way	\N	NDWOEQN	IN	50166	US	1	BDJPXGYAFQ@dell.com	1352882528	3	7731809694319964	2010/03	user8155	password	88	60000	M
8156	LUHCWK	MLHTKIZAWD	7594334223 Dell Way	\N	XKHNXPZ	WI	22071	US	1	MLHTKIZAWD@dell.com	7594334223	2	4106750822160393	2011/12	user8156	password	28	20000	M
8157	LGQVTB	DMMLMMHPJS	9696505941 Dell Way	\N	XXPMXOQ	NJ	95442	US	1	DMMLMMHPJS@dell.com	9696505941	2	8992857626173646	2008/06	user8157	password	64	60000	M
8158	GKLINY	UZKGHAQZXO	9930943276 Dell Way	\N	PKLEABC	WY	44912	US	1	UZKGHAQZXO@dell.com	9930943276	1	8545907525811345	2011/08	user8158	password	56	100000	F
8159	ZFOXZN	HGVHWUFLJP	2499086957 Dell Way	\N	WNQYQPI	NJ	73516	US	1	HGVHWUFLJP@dell.com	2499086957	2	4187921138945967	2011/02	user8159	password	46	80000	F
8160	YOHMWO	HELCJWMZTZ	3434284108 Dell Way	\N	PRQFAGX	DE	55505	US	1	HELCJWMZTZ@dell.com	3434284108	5	6670128535479308	2011/07	user8160	password	87	80000	F
8161	GCYUKC	FMMCYMVYBM	9718354508 Dell Way	\N	PHMVFQI	MN	56819	US	1	FMMCYMVYBM@dell.com	9718354508	1	1510678573511540	2012/09	user8161	password	29	20000	M
8162	CYGFET	SGREBQGOFN	3295473354 Dell Way	\N	ABSRKEF	LA	37539	US	1	SGREBQGOFN@dell.com	3295473354	2	1427458730526268	2010/06	user8162	password	82	60000	F
8163	DTOWLU	OQWFWKKKLM	6738629048 Dell Way	\N	CCWHHFP	ND	53749	US	1	OQWFWKKKLM@dell.com	6738629048	5	9303208257071676	2010/06	user8163	password	40	80000	F
8164	WNSRCI	NHFYSPJESM	6742058625 Dell Way	\N	AZUFOJS	GA	38802	US	1	NHFYSPJESM@dell.com	6742058625	4	8318283865228296	2012/05	user8164	password	21	100000	M
8165	TMABAH	GZZWIEOVEN	1721877060 Dell Way	\N	PKCYDHG	PA	12388	US	1	GZZWIEOVEN@dell.com	1721877060	4	4776803577318788	2008/07	user8165	password	42	100000	F
8166	JYAQFZ	QBIUPDZDTJ	9670914830 Dell Way	\N	FSMNYGO	AR	95634	US	1	QBIUPDZDTJ@dell.com	9670914830	1	5257780747022480	2009/01	user8166	password	53	80000	M
8167	NHFNYH	WTXASATBGL	3091419148 Dell Way	\N	OTKVHLT	ID	65669	US	1	WTXASATBGL@dell.com	3091419148	3	7024983849376441	2011/03	user8167	password	66	40000	M
8168	WTMDPF	BPXBJZHUNB	9401964146 Dell Way	\N	FIJQCQG	KY	28263	US	1	BPXBJZHUNB@dell.com	9401964146	1	4885058006737381	2011/04	user8168	password	88	60000	F
8169	LQQQRG	NSPNAKBCPK	7500121493 Dell Way	\N	LGMCNVH	MI	89946	US	1	NSPNAKBCPK@dell.com	7500121493	1	2582422827370465	2011/07	user8169	password	33	20000	F
8170	WTVDHO	SUPDWRTGDZ	6824278616 Dell Way	\N	TGNPNYM	IA	10351	US	1	SUPDWRTGDZ@dell.com	6824278616	5	5794722907710821	2012/01	user8170	password	68	80000	M
8171	NVCCOX	RSTJLZNLTT	4835169652 Dell Way	\N	YIHXUNX	MI	50337	US	1	RSTJLZNLTT@dell.com	4835169652	2	5444092198740691	2008/01	user8171	password	39	80000	M
8172	JTLGKD	AUPZIASBYB	8170468323 Dell Way	\N	IWVWTGH	DE	60978	US	1	AUPZIASBYB@dell.com	8170468323	2	6349888830445707	2008/12	user8172	password	52	60000	M
8173	XSCBSX	RSFRLGQMPM	7601932754 Dell Way	\N	HLFOTKD	ND	70986	US	1	RSFRLGQMPM@dell.com	7601932754	4	6496994122862816	2009/02	user8173	password	38	20000	M
8174	JEOGVG	LNRSDEIQMT	5795936963 Dell Way	\N	WBNGEBX	VT	72953	US	1	LNRSDEIQMT@dell.com	5795936963	1	8178359642624856	2012/03	user8174	password	63	20000	F
8175	ELGKXT	CPXHXOTRKU	7679062088 Dell Way	\N	EQZGOXY	CA	12749	US	1	CPXHXOTRKU@dell.com	7679062088	5	3410711334086955	2009/02	user8175	password	67	60000	M
8176	YYKSBA	PIYDCPOXUE	1781877032 Dell Way	\N	WATUZVV	OK	76026	US	1	PIYDCPOXUE@dell.com	1781877032	1	8401301645673812	2011/08	user8176	password	43	80000	M
8177	TKPUAY	SEAISXCWUD	9918819218 Dell Way	\N	PPDLKVE	MO	92278	US	1	SEAISXCWUD@dell.com	9918819218	2	5640282859094441	2009/12	user8177	password	22	20000	F
8178	RXJPQN	PYFNBCIFSX	6307859893 Dell Way	\N	IDHEIUB	IN	14057	US	1	PYFNBCIFSX@dell.com	6307859893	4	1084286871831864	2011/10	user8178	password	45	40000	M
8179	TXHHNF	NBHPJMIGVL	4594104583 Dell Way	\N	OZUIBBK	NM	74053	US	1	NBHPJMIGVL@dell.com	4594104583	2	5155806320253760	2011/08	user8179	password	26	60000	F
8180	JVAPIB	XYKJHRETFE	7724406315 Dell Way	\N	NOFOYVH	LA	21029	US	1	XYKJHRETFE@dell.com	7724406315	1	7440562711562962	2012/08	user8180	password	33	40000	F
8181	FVVGTT	RCAIHTOLHC	3924253081 Dell Way	\N	QVBMDKP	UT	58713	US	1	RCAIHTOLHC@dell.com	3924253081	4	2815983985085040	2010/12	user8181	password	67	80000	M
8182	MAOGRR	HZYBNKIQBE	8651039708 Dell Way	\N	SNICDFQ	MN	93765	US	1	HZYBNKIQBE@dell.com	8651039708	5	9171405034139752	2010/09	user8182	password	71	20000	M
8183	HHKYPK	XRYHZOIEHW	5770917715 Dell Way	\N	MJZRALQ	UT	51002	US	1	XRYHZOIEHW@dell.com	5770917715	3	2801800924818963	2009/06	user8183	password	87	60000	M
8184	JMIUJZ	SQZHZDOVQY	9420918546 Dell Way	\N	VIZHYVT	MO	32808	US	1	SQZHZDOVQY@dell.com	9420918546	4	7208737831562758	2012/04	user8184	password	48	40000	M
8185	TADSTU	RBTVPPMOKU	3721705179 Dell Way	\N	NSTJLGP	LA	99579	US	1	RBTVPPMOKU@dell.com	3721705179	2	3571884561330080	2011/07	user8185	password	22	60000	M
8186	FDHZVI	TQYICMTXZL	2709884014 Dell Way	\N	RJWXYGX	ID	53916	US	1	TQYICMTXZL@dell.com	2709884014	5	9938030917663128	2009/06	user8186	password	56	60000	M
8187	VLKDEB	BNEOHBNSSW	3843681995 Dell Way	\N	PQVVNCI	OK	18164	US	1	BNEOHBNSSW@dell.com	3843681995	5	5710139886476100	2012/06	user8187	password	25	80000	M
8188	NUAOWO	SKVUYONVDD	4660286569 Dell Way	\N	RZRUIKW	NJ	42928	US	1	SKVUYONVDD@dell.com	4660286569	3	8048053314443678	2010/02	user8188	password	64	20000	M
8189	RPVFIF	BCEPQATTST	9689198317 Dell Way	\N	KMBVJRE	SC	23306	US	1	BCEPQATTST@dell.com	9689198317	2	3525020380970091	2010/05	user8189	password	33	40000	M
8190	AMHGNK	LDALXTEQER	8146407911 Dell Way	\N	RZBJEVN	DC	23112	US	1	LDALXTEQER@dell.com	8146407911	4	5375333246774972	2008/01	user8190	password	49	20000	F
8191	SHACSE	CEBWJRAAJA	5883247565 Dell Way	\N	BTFXGJB	AR	17997	US	1	CEBWJRAAJA@dell.com	5883247565	1	1838435378856957	2012/02	user8191	password	60	80000	F
8192	PTCTWH	USQMTRWTTQ	5500672266 Dell Way	\N	ZQWISYK	IA	98728	US	1	USQMTRWTTQ@dell.com	5500672266	2	1735948088578879	2008/11	user8192	password	52	80000	M
8193	OLNWGG	NTZFPTYFSP	1850372009 Dell Way	\N	CBHALOA	WI	79517	US	1	NTZFPTYFSP@dell.com	1850372009	1	7069769317749888	2010/09	user8193	password	43	20000	F
8194	WAJDND	CSSWRYOGBQ	5876107574 Dell Way	\N	OCBCCAW	FL	13463	US	1	CSSWRYOGBQ@dell.com	5876107574	4	7691472057718784	2012/11	user8194	password	82	80000	M
8195	GWLJZE	CVVBKBDAQF	8944303364 Dell Way	\N	CSHCPMD	CT	31519	US	1	CVVBKBDAQF@dell.com	8944303364	1	2151327151339501	2011/10	user8195	password	19	20000	M
8196	LKQQNL	LOWNRXDXZW	1334393587 Dell Way	\N	ECLRFOX	CO	61433	US	1	LOWNRXDXZW@dell.com	1334393587	5	4082114895805717	2008/11	user8196	password	90	60000	F
8197	QDVCPJ	YCBWGYVCDX	1036405212 Dell Way	\N	NUDCSGR	PA	20904	US	1	YCBWGYVCDX@dell.com	1036405212	5	1177422300912439	2012/05	user8197	password	41	80000	F
8198	DSBNQE	PMKNINRGAM	7955929782 Dell Way	\N	JDEQUYT	SC	77982	US	1	PMKNINRGAM@dell.com	7955929782	4	1855117604136467	2008/05	user8198	password	60	40000	F
8199	QTTVIG	GWOTNUUAEX	9837509347 Dell Way	\N	EVRDOMX	KY	34169	US	1	GWOTNUUAEX@dell.com	9837509347	3	7030573070049287	2010/09	user8199	password	74	40000	F
8200	NATTGP	IADCUDHRID	8183285083 Dell Way	\N	JLRWIAD	KS	52652	US	1	IADCUDHRID@dell.com	8183285083	5	2290892913471907	2010/02	user8200	password	58	20000	F
8201	HVKXDK	AGEEOWMRGY	1070482409 Dell Way	\N	JCHKGQW	AL	56177	US	1	AGEEOWMRGY@dell.com	1070482409	4	6488031529821456	2010/09	user8201	password	71	100000	M
8202	DTQNUX	SZLPLCVKLY	5123932125 Dell Way	\N	SWEISFW	OK	83405	US	1	SZLPLCVKLY@dell.com	5123932125	2	5432550418656320	2008/02	user8202	password	90	40000	M
8203	QWSNOR	YEDBZONYGJ	6731118938 Dell Way	\N	CPBILUD	VT	16380	US	1	YEDBZONYGJ@dell.com	6731118938	1	2987991811241954	2011/06	user8203	password	27	40000	F
8204	WUWNSA	RUZFHYMQAB	8071607992 Dell Way	\N	SJNMNKO	DC	56481	US	1	RUZFHYMQAB@dell.com	8071607992	4	9452214774675668	2012/01	user8204	password	33	80000	M
8205	BHOBZI	BEQZRGATZK	2145098911 Dell Way	\N	GLXRABE	SD	84010	US	1	BEQZRGATZK@dell.com	2145098911	4	8768591408152134	2009/07	user8205	password	67	60000	M
8206	GMUONY	ENQLNJKXPW	5873986714 Dell Way	\N	VHXWMSR	NH	48534	US	1	ENQLNJKXPW@dell.com	5873986714	5	9400542235933244	2009/05	user8206	password	72	60000	M
8207	NAJMEW	CQKLAIBXDJ	8441532756 Dell Way	\N	UZVMRKX	GA	42796	US	1	CQKLAIBXDJ@dell.com	8441532756	3	7435443162452430	2010/11	user8207	password	57	20000	M
8208	XOCTRS	ECTMEQPNKO	8709930185 Dell Way	\N	JWGUTLD	NE	87681	US	1	ECTMEQPNKO@dell.com	8709930185	1	7701255272608251	2009/03	user8208	password	64	40000	M
8209	TBLLFO	ERTVHGFWQB	2167827371 Dell Way	\N	CKVNOKK	MD	59664	US	1	ERTVHGFWQB@dell.com	2167827371	4	8030091562308372	2011/01	user8209	password	59	60000	F
8210	AYIODA	HYHOEDEFFO	8048203287 Dell Way	\N	BTCLDNA	ID	36877	US	1	HYHOEDEFFO@dell.com	8048203287	1	4417498834896833	2009/07	user8210	password	55	40000	F
8211	WXPWFO	DTSHYYNNZG	8282466559 Dell Way	\N	QLJDLQL	HI	68531	US	1	DTSHYYNNZG@dell.com	8282466559	3	2625954086426645	2009/12	user8211	password	66	20000	M
8212	HABVEV	OLTMYGMFXX	1210495279 Dell Way	\N	OAJFLPV	ID	23645	US	1	OLTMYGMFXX@dell.com	1210495279	3	1726114640943706	2011/09	user8212	password	85	100000	M
8213	ZUYUJK	OVJVIOSGDS	4713053751 Dell Way	\N	PIEEELI	GA	10676	US	1	OVJVIOSGDS@dell.com	4713053751	5	7781530653592200	2009/11	user8213	password	56	40000	M
8214	MCZXRV	HMEWEKZXAI	3272309700 Dell Way	\N	BENMNSM	WA	64351	US	1	HMEWEKZXAI@dell.com	3272309700	2	5046724391635508	2011/07	user8214	password	24	40000	M
8215	CEJXLV	BHZMHWMPYR	8975498507 Dell Way	\N	DLEVYCL	FL	42818	US	1	BHZMHWMPYR@dell.com	8975498507	5	9514007141347976	2012/03	user8215	password	64	20000	F
8216	ZZVUBC	UNJRZZPQCA	3074135827 Dell Way	\N	VYYXJDH	IA	18976	US	1	UNJRZZPQCA@dell.com	3074135827	2	3950313462410122	2012/04	user8216	password	70	100000	F
8217	OQHQLV	ACUZRLCSGA	3084201898 Dell Way	\N	REKUMQX	OH	88140	US	1	ACUZRLCSGA@dell.com	3084201898	3	2376202092505991	2012/06	user8217	password	47	60000	F
8218	SDMNDP	IDHTGZAGQF	3837218563 Dell Way	\N	RLSHJKE	NH	97300	US	1	IDHTGZAGQF@dell.com	3837218563	3	4515028786845505	2011/01	user8218	password	51	60000	F
8219	YYIOGL	VASUBZLHQX	7567902793 Dell Way	\N	ZXGJBWI	MA	45300	US	1	VASUBZLHQX@dell.com	7567902793	1	4788142402190715	2008/07	user8219	password	60	20000	F
8220	XRTJNT	BHVATCQQBO	6224472072 Dell Way	\N	XLQTTAE	MS	21966	US	1	BHVATCQQBO@dell.com	6224472072	4	7063933254219592	2008/10	user8220	password	29	20000	M
8221	XKAQLI	LMBOCSPRQA	1988719985 Dell Way	\N	HKUHOHL	CT	96274	US	1	LMBOCSPRQA@dell.com	1988719985	2	8058400392532349	2009/05	user8221	password	39	20000	M
8222	IVFQGR	RVUKKLALSL	3143419172 Dell Way	\N	FAZMMDL	NE	48090	US	1	RVUKKLALSL@dell.com	3143419172	5	7980524729471654	2010/01	user8222	password	56	100000	M
8223	TMCKEX	FOHRPTKAYK	4093998963 Dell Way	\N	ALXDXMO	DC	38031	US	1	FOHRPTKAYK@dell.com	4093998963	4	3823666803073138	2012/07	user8223	password	27	80000	M
8224	FBECGS	KXIDHJBSJN	7205820019 Dell Way	\N	PNKBCOJ	MI	30489	US	1	KXIDHJBSJN@dell.com	7205820019	2	7734086784999818	2012/12	user8224	password	72	20000	M
8225	XCFQMD	YQKISDSFSG	2438892965 Dell Way	\N	QUIEETK	TX	17544	US	1	YQKISDSFSG@dell.com	2438892965	4	1144249104429036	2012/09	user8225	password	90	100000	M
8226	FLHIKX	TSPWKVPQLJ	8628844311 Dell Way	\N	ZQOTAKV	FL	15605	US	1	TSPWKVPQLJ@dell.com	8628844311	1	7682893259450794	2012/11	user8226	password	56	20000	F
8227	VJSSDL	IAWDPNOZME	7537575512 Dell Way	\N	NGFXBKZ	VT	55072	US	1	IAWDPNOZME@dell.com	7537575512	4	4617101868614555	2009/10	user8227	password	71	20000	F
8228	MUHXCH	TFXHUWUYKA	5241758814 Dell Way	\N	EICOHZB	AL	77651	US	1	TFXHUWUYKA@dell.com	5241758814	2	5930079026613385	2009/05	user8228	password	70	80000	F
8229	APGIJL	FQFCKEMKIU	8137073711 Dell Way	\N	MXCMZDG	MI	48343	US	1	FQFCKEMKIU@dell.com	8137073711	4	8013701685238630	2010/04	user8229	password	84	60000	M
8230	DWGPBX	VDHZQSILFF	9043171592 Dell Way	\N	OSFRYQC	OR	36027	US	1	VDHZQSILFF@dell.com	9043171592	2	6544090075418354	2012/10	user8230	password	56	100000	M
8231	UOSRJV	ZIMRRXXWMP	6532104817 Dell Way	\N	BDOSGHZ	DE	57516	US	1	ZIMRRXXWMP@dell.com	6532104817	5	3804356641601771	2008/12	user8231	password	86	100000	F
8232	QPVMPE	YHVWESITUM	4709123975 Dell Way	\N	HMTOMXC	CO	89101	US	1	YHVWESITUM@dell.com	4709123975	2	8223941148724408	2009/03	user8232	password	38	100000	M
8233	CMJHLQ	DIUVQOQDWC	5281420739 Dell Way	\N	WLPUNSR	WA	97251	US	1	DIUVQOQDWC@dell.com	5281420739	2	2311186544597149	2011/04	user8233	password	85	100000	M
8234	HDFYGN	SCEHSHDVEO	3347394823 Dell Way	\N	LZBDQAC	CT	37364	US	1	SCEHSHDVEO@dell.com	3347394823	5	6340141808614135	2008/09	user8234	password	44	60000	M
8235	OKDCDF	GKXNNSSCDR	1608281703 Dell Way	\N	EHIEKLM	NY	37836	US	1	GKXNNSSCDR@dell.com	1608281703	5	1318329058587551	2010/05	user8235	password	83	100000	M
8236	ACWFIH	DWVWOXAGBH	4154928400 Dell Way	\N	OFSASKI	PA	32075	US	1	DWVWOXAGBH@dell.com	4154928400	1	6267083309125156	2009/03	user8236	password	42	40000	F
8237	FMPMQL	HMAEMGGUVL	7481429661 Dell Way	\N	NVDXDXD	MO	19607	US	1	HMAEMGGUVL@dell.com	7481429661	4	3657853593118489	2008/01	user8237	password	58	40000	M
8238	DSDPAP	PFCVLXQWKM	4153161591 Dell Way	\N	AHPYKCB	DC	84025	US	1	PFCVLXQWKM@dell.com	4153161591	1	8453874547500164	2012/06	user8238	password	42	20000	F
8239	LQEBGK	EBVBSSLFTT	5842024988 Dell Way	\N	UREXTHS	CA	54750	US	1	EBVBSSLFTT@dell.com	5842024988	1	9466560510918500	2012/01	user8239	password	26	40000	M
8240	HKYSOA	NQTFCYZVTQ	7589920305 Dell Way	\N	ZQKHIMU	UT	54117	US	1	NQTFCYZVTQ@dell.com	7589920305	4	5985906784888357	2012/01	user8240	password	37	20000	F
8241	FWAGJQ	ZPTYOORFOI	2146423390 Dell Way	\N	PVRCQOO	LA	36223	US	1	ZPTYOORFOI@dell.com	2146423390	2	4287289514672011	2009/05	user8241	password	78	80000	F
8242	WVPNVE	GTTULYITNE	6528111422 Dell Way	\N	KQVYEEG	KS	44508	US	1	GTTULYITNE@dell.com	6528111422	4	7719481121748687	2010/04	user8242	password	88	40000	F
8243	OVZSBT	LWEKFYYKJO	5565393772 Dell Way	\N	FITJOBT	DE	79351	US	1	LWEKFYYKJO@dell.com	5565393772	4	1766204324085265	2010/12	user8243	password	35	20000	M
8244	FTVYFR	DPWBNHKBMT	7474589617 Dell Way	\N	UWHWPLQ	CT	17141	US	1	DPWBNHKBMT@dell.com	7474589617	3	1042389128357172	2012/08	user8244	password	72	20000	F
8245	ODNGHD	CIQKTSWMNS	3986855354 Dell Way	\N	UJIGALI	OK	13005	US	1	CIQKTSWMNS@dell.com	3986855354	4	6728377569932491	2008/11	user8245	password	89	80000	M
8246	NWGQZP	HJJZFWMYRW	4439236194 Dell Way	\N	GXWSFOT	ND	33135	US	1	HJJZFWMYRW@dell.com	4439236194	4	2037595814559608	2009/04	user8246	password	25	100000	F
8247	JNDZUN	ITTFFRWBYU	8858852305 Dell Way	\N	YRANKOT	SC	28401	US	1	ITTFFRWBYU@dell.com	8858852305	1	5390962684061378	2012/01	user8247	password	64	40000	M
8248	UIHHRB	BWHSTJRNHI	7991479470 Dell Way	\N	NUTCNOH	MD	72821	US	1	BWHSTJRNHI@dell.com	7991479470	2	7490051953122020	2010/09	user8248	password	36	40000	F
8249	ONTPOQ	WGJFYXMHKG	1036267359 Dell Way	\N	BMUPUFH	ND	62534	US	1	WGJFYXMHKG@dell.com	1036267359	5	3870766380801797	2009/03	user8249	password	45	100000	M
8250	CKGSHN	CMLZZSKGUX	2245543741 Dell Way	\N	AJRGQGV	NM	31559	US	1	CMLZZSKGUX@dell.com	2245543741	5	4872517254669219	2010/09	user8250	password	26	80000	F
8251	JJJWLW	HLVAVBUTCE	4202772266 Dell Way	\N	LJURELY	IN	39547	US	1	HLVAVBUTCE@dell.com	4202772266	5	1208490860182791	2010/06	user8251	password	26	100000	M
8252	MSGIZS	EAOGVHJZSS	6125726070 Dell Way	\N	UKWFIEO	NY	99028	US	1	EAOGVHJZSS@dell.com	6125726070	1	4964845862705261	2011/12	user8252	password	36	20000	M
8253	NNRFRS	TXOAGOTYID	4746952921 Dell Way	\N	VOMZCEZ	NV	38578	US	1	TXOAGOTYID@dell.com	4746952921	2	3841646790038794	2011/07	user8253	password	18	20000	F
8254	SJRKDP	ZEWNXVVBQK	3819382368 Dell Way	\N	NQMRPDZ	AK	53751	US	1	ZEWNXVVBQK@dell.com	3819382368	4	1013565913308411	2009/11	user8254	password	19	20000	F
8255	SLJHKN	EYKZUMPEZF	3457615370 Dell Way	\N	QRVURVH	WY	55571	US	1	EYKZUMPEZF@dell.com	3457615370	2	4190226166509092	2009/04	user8255	password	60	20000	M
8256	YHELMD	WLXIBBIGSZ	8002407967 Dell Way	\N	CMRXTQL	AR	95084	US	1	WLXIBBIGSZ@dell.com	8002407967	2	3435129959601909	2009/05	user8256	password	20	40000	M
8257	FTCIPO	GYPHGWAGYN	7981993766 Dell Way	\N	XWHOHIN	AR	69659	US	1	GYPHGWAGYN@dell.com	7981993766	3	9983810328878464	2012/09	user8257	password	64	20000	F
8258	TJBHQA	WYHSYNQMLN	7642347521 Dell Way	\N	TAUCNVT	IL	32984	US	1	WYHSYNQMLN@dell.com	7642347521	1	9711048983968796	2009/02	user8258	password	49	20000	M
8259	MKDNGB	UZAIQMTDGU	9847666763 Dell Way	\N	XIHTBPA	SC	72406	US	1	UZAIQMTDGU@dell.com	9847666763	1	8528647971805186	2010/04	user8259	password	44	100000	M
8260	NKYOFX	PNOBHRHBPP	5228396438 Dell Way	\N	JJRYJLQ	LA	64649	US	1	PNOBHRHBPP@dell.com	5228396438	4	8966750189661981	2012/09	user8260	password	58	40000	F
8261	NXHKMU	ZOBQWDGMMQ	1796655279 Dell Way	\N	DKZPBJF	MT	22115	US	1	ZOBQWDGMMQ@dell.com	1796655279	2	8299711994361133	2011/09	user8261	password	83	20000	M
8262	EOCZNR	BEOELARBEC	4348797416 Dell Way	\N	BUDLZRO	AZ	11013	US	1	BEOELARBEC@dell.com	4348797416	4	7271802864503116	2009/11	user8262	password	39	60000	F
8263	JLZBME	PQPPHRUJTO	8916774340 Dell Way	\N	NEOESPE	CA	39595	US	1	PQPPHRUJTO@dell.com	8916774340	2	2776520928833633	2008/10	user8263	password	64	60000	F
8264	PPSUEJ	JURBOBUDOY	8309173800 Dell Way	\N	RTRHXTP	SC	20711	US	1	JURBOBUDOY@dell.com	8309173800	5	9414605300873520	2010/07	user8264	password	30	20000	F
8265	XVGGFB	XGPYBTNZKG	5074787539 Dell Way	\N	QSEKIYN	CT	92765	US	1	XGPYBTNZKG@dell.com	5074787539	3	4846392760984600	2011/08	user8265	password	56	60000	F
8266	UURVRY	LQZEEYOLPH	9045652288 Dell Way	\N	PZPONSM	WV	34864	US	1	LQZEEYOLPH@dell.com	9045652288	3	9149309277068824	2010/02	user8266	password	44	40000	M
8267	AAOZLF	YQKWEVMMKM	9386980957 Dell Way	\N	BYZTLYA	KS	57657	US	1	YQKWEVMMKM@dell.com	9386980957	4	6785350178834052	2009/12	user8267	password	56	40000	M
8268	CHKIFA	TCFOPRZBSY	2211749537 Dell Way	\N	AMJZNRM	MI	46398	US	1	TCFOPRZBSY@dell.com	2211749537	4	4062870687339455	2011/01	user8268	password	39	80000	F
8269	SCPTVS	ZKHQJIJHJW	1417321132 Dell Way	\N	QIJHVUS	WI	58052	US	1	ZKHQJIJHJW@dell.com	1417321132	4	6420564048923553	2009/05	user8269	password	88	20000	F
8270	OUIGTS	OKBXUJGQZP	9497096044 Dell Way	\N	AHKVZJI	AR	97206	US	1	OKBXUJGQZP@dell.com	9497096044	2	4193810616154224	2012/06	user8270	password	79	60000	F
8271	ETAWHL	YEFHLWHAWP	1990089609 Dell Way	\N	LROUAPT	WV	10042	US	1	YEFHLWHAWP@dell.com	1990089609	5	5022304726764560	2012/05	user8271	password	68	20000	F
8272	SAKDYP	JGAFOBCDNU	7927894067 Dell Way	\N	SHVIBUI	DC	70668	US	1	JGAFOBCDNU@dell.com	7927894067	1	1286155370529741	2010/03	user8272	password	27	20000	F
8273	NIEDRL	EXAFADSVWA	2116171794 Dell Way	\N	QEBKMFC	ID	39562	US	1	EXAFADSVWA@dell.com	2116171794	4	6025535517837853	2009/11	user8273	password	75	80000	F
8274	ZXXLBV	LHVOAQLAGP	2772005874 Dell Way	\N	CRCIUJQ	VA	17508	US	1	LHVOAQLAGP@dell.com	2772005874	1	9903460428584368	2012/12	user8274	password	33	100000	M
8275	CKWXVE	TKEJVFQLHI	9512993501 Dell Way	\N	NPCWGZY	MI	21466	US	1	TKEJVFQLHI@dell.com	9512993501	3	1532287291716784	2008/05	user8275	password	82	40000	M
8276	UFQYYA	CIWHYHPHUE	5690157215 Dell Way	\N	JRKIQWM	NE	34761	US	1	CIWHYHPHUE@dell.com	5690157215	4	6962554533500225	2010/01	user8276	password	50	20000	F
8277	BDDCGM	YNKGDRBIBS	5766840586 Dell Way	\N	TJJPVYW	LA	71780	US	1	YNKGDRBIBS@dell.com	5766840586	4	7284285567700864	2012/12	user8277	password	83	20000	F
8278	BDINCW	YIZQJHRCAB	8044444565 Dell Way	\N	LQWKMGC	AK	11890	US	1	YIZQJHRCAB@dell.com	8044444565	5	9830811389256270	2011/01	user8278	password	22	80000	F
8279	JGGGEO	FUYNLANMMD	6633113296 Dell Way	\N	JWQQYRQ	OR	68316	US	1	FUYNLANMMD@dell.com	6633113296	3	7151835777331144	2011/02	user8279	password	80	20000	F
8280	CHORNJ	PAVQOHCRRZ	3803970131 Dell Way	\N	IHYZYRQ	NE	18807	US	1	PAVQOHCRRZ@dell.com	3803970131	2	3316844772547483	2008/05	user8280	password	66	40000	M
8281	GYDPNE	KESSGKKGSS	2714603194 Dell Way	\N	ESRVIGY	NM	54996	US	1	KESSGKKGSS@dell.com	2714603194	5	8554142615757883	2012/01	user8281	password	53	20000	M
8282	QRNUCS	NUYXFEQXJI	2189395396 Dell Way	\N	OERUDHH	IN	19030	US	1	NUYXFEQXJI@dell.com	2189395396	1	2506704142317176	2011/03	user8282	password	30	40000	M
8283	SBAKOV	ILANCYWKMB	6645038770 Dell Way	\N	BHEJOML	OH	67494	US	1	ILANCYWKMB@dell.com	6645038770	2	8925349836703391	2011/07	user8283	password	76	60000	M
8284	VXEQFQ	QTSOQDBSEI	8829370541 Dell Way	\N	WOXJAPZ	NM	93511	US	1	QTSOQDBSEI@dell.com	8829370541	3	5441484136041254	2011/12	user8284	password	25	60000	M
8285	HDAXUU	QILTKDYTZM	7135962984 Dell Way	\N	QIMGICE	GA	57735	US	1	QILTKDYTZM@dell.com	7135962984	5	5038618169259280	2011/05	user8285	password	36	20000	F
8286	HZGCPP	NJZQHTQTKZ	3818559525 Dell Way	\N	FQHIVNW	MT	44084	US	1	NJZQHTQTKZ@dell.com	3818559525	2	7673058684449644	2010/05	user8286	password	34	100000	F
8287	MYZBLI	BCPVSJFRPW	6511533284 Dell Way	\N	ZXRMUFW	CA	56454	US	1	BCPVSJFRPW@dell.com	6511533284	4	9077427835669368	2012/07	user8287	password	37	40000	F
8288	GJXOLZ	EGSNMKCIKA	6567173937 Dell Way	\N	ZWUFTWS	LA	58645	US	1	EGSNMKCIKA@dell.com	6567173937	1	1510472039226442	2012/07	user8288	password	55	20000	M
8289	KRIKVP	DIBNKKXKJU	7172368141 Dell Way	\N	FPNCIXQ	WA	18300	US	1	DIBNKKXKJU@dell.com	7172368141	5	6408584540709854	2008/12	user8289	password	53	80000	M
8290	VAKLES	NRDXPOHJUW	5495373721 Dell Way	\N	XWEUMDX	DE	93173	US	1	NRDXPOHJUW@dell.com	5495373721	2	8589851937256754	2012/12	user8290	password	49	100000	F
8291	VHEOUW	SSLGZVAWTX	9468289324 Dell Way	\N	BOJELOC	WI	94074	US	1	SSLGZVAWTX@dell.com	9468289324	5	9335716374684126	2009/10	user8291	password	87	20000	F
8292	DTWALO	LSOHTKAQMP	4877868244 Dell Way	\N	AQAOTZN	NY	93339	US	1	LSOHTKAQMP@dell.com	4877868244	1	7277353545185179	2009/03	user8292	password	72	60000	M
8293	PNLDZD	RGWCHMOXNF	5814532085 Dell Way	\N	YBYXPQV	AK	71806	US	1	RGWCHMOXNF@dell.com	5814532085	2	9366123094689102	2009/11	user8293	password	85	100000	F
8294	JAKMSR	JVZVJWIPUK	8227620297 Dell Way	\N	OSZEOAW	AZ	45976	US	1	JVZVJWIPUK@dell.com	8227620297	2	3775426045991480	2011/03	user8294	password	71	20000	F
8295	DOZVXU	UTDQCTLNHD	3044850992 Dell Way	\N	NMRNJTX	DE	20517	US	1	UTDQCTLNHD@dell.com	3044850992	5	4151937695685774	2012/12	user8295	password	62	20000	M
8296	OXKISE	MIGGUTNYHA	8539854798 Dell Way	\N	PUJJSNM	WA	46487	US	1	MIGGUTNYHA@dell.com	8539854798	5	4221616456750780	2010/01	user8296	password	81	20000	M
8297	HJPLVY	RCTLPRTQHN	3494812726 Dell Way	\N	ZQGNDEX	WV	17706	US	1	RCTLPRTQHN@dell.com	3494812726	3	1810148261953145	2008/06	user8297	password	18	60000	M
8298	PWPOOR	HAHZTXGGXW	8804840247 Dell Way	\N	NKARIZU	NJ	45173	US	1	HAHZTXGGXW@dell.com	8804840247	4	8308990970719606	2012/03	user8298	password	60	60000	F
8299	FBPWJP	EIICOPALDL	6559165820 Dell Way	\N	LVTKPJU	MN	22663	US	1	EIICOPALDL@dell.com	6559165820	2	3906912516802549	2009/10	user8299	password	44	40000	M
8300	ZHFOLN	XOBNOMQZYM	6324198745 Dell Way	\N	TJBDENG	RI	86446	US	1	XOBNOMQZYM@dell.com	6324198745	5	6992272705305368	2012/05	user8300	password	56	100000	M
8301	TMCHKR	JYFWPFUBYD	2222198837 Dell Way	\N	CBHQIBM	WA	12639	US	1	JYFWPFUBYD@dell.com	2222198837	5	4569699431769550	2011/10	user8301	password	21	60000	F
8302	DRSUBQ	AXFFRGEUJG	6077993436 Dell Way	\N	CZODLNE	NE	45940	US	1	AXFFRGEUJG@dell.com	6077993436	2	2901412907987833	2011/08	user8302	password	55	80000	F
8303	FOKVOH	BUYHYTQEVQ	8720340311 Dell Way	\N	TYBGDQQ	OH	89425	US	1	BUYHYTQEVQ@dell.com	8720340311	2	5896166030783207	2009/01	user8303	password	83	60000	M
8304	HKEOLY	NTWGKABATA	2165959812 Dell Way	\N	BAESRWP	MT	23098	US	1	NTWGKABATA@dell.com	2165959812	5	2722868148703128	2008/06	user8304	password	75	40000	M
8305	YWIWJC	TQMTSMNSOO	1582581334 Dell Way	\N	WGFSVTW	WV	66168	US	1	TQMTSMNSOO@dell.com	1582581334	1	1825383422896266	2012/04	user8305	password	89	80000	F
8306	IROKKF	XEXJSPYGMF	9228419544 Dell Way	\N	MFBFCAV	DE	11698	US	1	XEXJSPYGMF@dell.com	9228419544	1	3984292440582067	2012/10	user8306	password	55	40000	F
8307	CPWHMA	EWSUVZHALM	4793176015 Dell Way	\N	BQPBLTC	LA	78521	US	1	EWSUVZHALM@dell.com	4793176015	2	6045841767918319	2012/06	user8307	password	19	20000	F
8308	WIOXML	QGGPOHABIR	7400602688 Dell Way	\N	QKDKMMD	VT	76941	US	1	QGGPOHABIR@dell.com	7400602688	5	2861442239489406	2011/11	user8308	password	38	80000	F
8309	WNRHDY	OTMVTNELEO	9840866249 Dell Way	\N	OOBASYU	MD	82881	US	1	OTMVTNELEO@dell.com	9840866249	1	7177307291422040	2009/10	user8309	password	81	20000	F
8310	NKKMZE	YVXLZJPOXE	1521379615 Dell Way	\N	PYWOSGJ	OH	45606	US	1	YVXLZJPOXE@dell.com	1521379615	5	2337078440468758	2012/01	user8310	password	48	60000	F
8311	VYMZWH	XIHGYVECLC	7879664127 Dell Way	\N	ZZUFJMQ	ME	49373	US	1	XIHGYVECLC@dell.com	7879664127	2	5526766560040415	2008/10	user8311	password	89	20000	M
8312	LAQTXZ	AEXVJAGLZG	7023535971 Dell Way	\N	GFPSVAE	NH	41819	US	1	AEXVJAGLZG@dell.com	7023535971	4	2482198621612042	2011/10	user8312	password	84	20000	M
8313	NVSMVX	KRGLYSLEYQ	3565814169 Dell Way	\N	TRLTVBD	MT	83644	US	1	KRGLYSLEYQ@dell.com	3565814169	1	6503288286738098	2008/04	user8313	password	48	80000	F
8314	DFYBQQ	IBOAMSZDMQ	1530893427 Dell Way	\N	PGMQJZL	NM	24028	US	1	IBOAMSZDMQ@dell.com	1530893427	5	4826192600652576	2010/07	user8314	password	56	80000	M
8315	MRLCZN	RZAJYDWPSC	6815198408 Dell Way	\N	BILBUCF	TX	94913	US	1	RZAJYDWPSC@dell.com	6815198408	2	5637029993347824	2008/12	user8315	password	40	80000	M
8316	TUOGLO	GVNJRDCUFL	8114077699 Dell Way	\N	FGGIMCH	CT	46289	US	1	GVNJRDCUFL@dell.com	8114077699	2	4049304153770208	2008/12	user8316	password	86	100000	M
8317	NCECJA	PTSSVMXHSE	4011245334 Dell Way	\N	NARPHUZ	CA	18623	US	1	PTSSVMXHSE@dell.com	4011245334	2	1602194430306553	2009/01	user8317	password	77	80000	F
8318	AWNAMG	SFCEDJXIXX	9345065239 Dell Way	\N	ZMFTMIW	SD	56936	US	1	SFCEDJXIXX@dell.com	9345065239	1	6148955550976098	2011/11	user8318	password	71	80000	M
8319	GUFMML	PROZOWWMVI	2166425934 Dell Way	\N	SPVAMQO	MD	73835	US	1	PROZOWWMVI@dell.com	2166425934	1	6225764113944024	2012/11	user8319	password	41	20000	M
8320	OPEZEV	NDKKZXFIPV	1573754813 Dell Way	\N	DQHUFSM	KY	84616	US	1	NDKKZXFIPV@dell.com	1573754813	1	7444751370698214	2009/04	user8320	password	45	100000	M
8321	NXBJKF	UUFRANHWRY	4642111217 Dell Way	\N	ELEWYMR	AK	72215	US	1	UUFRANHWRY@dell.com	4642111217	2	9819611657876522	2011/04	user8321	password	80	40000	F
8322	XSQCML	IEMWMINKMZ	7691589592 Dell Way	\N	OJYBBYT	MI	40272	US	1	IEMWMINKMZ@dell.com	7691589592	2	6893940638750792	2011/07	user8322	password	81	60000	F
8323	MQSYYW	KUJSITFIIO	2834655068 Dell Way	\N	GKPFEBO	VT	36405	US	1	KUJSITFIIO@dell.com	2834655068	3	8585275392979384	2008/01	user8323	password	24	60000	M
8324	UMPRWK	APTUVBDJIO	2715050703 Dell Way	\N	ZOSBCQJ	IN	23538	US	1	APTUVBDJIO@dell.com	2715050703	2	2644904676824808	2009/12	user8324	password	79	20000	F
8325	LTHWUX	PPSRTCZHCN	9627003925 Dell Way	\N	ZDQQMYU	NY	36597	US	1	PPSRTCZHCN@dell.com	9627003925	5	3073903967626393	2012/01	user8325	password	65	40000	M
8326	YCPWSF	OJYRIFTWFX	9559652680 Dell Way	\N	MVJLPBS	ND	10519	US	1	OJYRIFTWFX@dell.com	9559652680	2	1338494576513767	2011/08	user8326	password	79	60000	M
8327	LLKQAU	ORCULZZIMU	8093797965 Dell Way	\N	RXKTQZT	NE	39326	US	1	ORCULZZIMU@dell.com	8093797965	1	9485819857101888	2011/10	user8327	password	66	20000	F
8328	CSEWGW	ZBHYAPLVHI	5079308696 Dell Way	\N	FBZEUON	NE	75472	US	1	ZBHYAPLVHI@dell.com	5079308696	2	5325571496970952	2008/04	user8328	password	66	40000	M
8329	WBFSBH	AZHPLCXTIY	5327877220 Dell Way	\N	SNTHAIA	MO	57075	US	1	AZHPLCXTIY@dell.com	5327877220	3	8097025677561761	2008/10	user8329	password	72	20000	M
8330	ZSXGTX	OJIQGCZFVM	6188023404 Dell Way	\N	YCNGCZU	NE	62782	US	1	OJIQGCZFVM@dell.com	6188023404	4	4535851156804711	2009/09	user8330	password	37	40000	F
8331	EOECCN	LTUNSZJFYL	7244994583 Dell Way	\N	SFOSZDH	ND	88838	US	1	LTUNSZJFYL@dell.com	7244994583	5	6467832698021085	2012/03	user8331	password	22	20000	M
8332	GGWURQ	OFIOOONAHS	2884289094 Dell Way	\N	PZSSHGP	WY	24729	US	1	OFIOOONAHS@dell.com	2884289094	5	4331711912527681	2009/02	user8332	password	28	60000	F
8333	AHAQWF	ZLTNYUVQJU	2277310571 Dell Way	\N	ICCPRCU	VA	14287	US	1	ZLTNYUVQJU@dell.com	2277310571	1	2341684866230935	2009/09	user8333	password	53	40000	M
8334	NXWSXH	MKFGFWQAFS	4783847422 Dell Way	\N	DVKFPIH	OR	53275	US	1	MKFGFWQAFS@dell.com	4783847422	1	2541777755133807	2012/04	user8334	password	29	60000	F
8335	ADCIQN	OWTKNUQGXL	6429022403 Dell Way	\N	QDBYKUL	SD	82653	US	1	OWTKNUQGXL@dell.com	6429022403	4	2015922710765153	2011/02	user8335	password	42	80000	F
8336	LCXZRU	SCHMSNJEEN	9449143339 Dell Way	\N	FDXAOSV	DC	50919	US	1	SCHMSNJEEN@dell.com	9449143339	5	6414822759572417	2009/09	user8336	password	82	80000	M
8337	URMOKO	WWGJGLNTRR	5110670287 Dell Way	\N	RRFKNJW	MI	34400	US	1	WWGJGLNTRR@dell.com	5110670287	4	9791746175847948	2009/06	user8337	password	75	20000	F
8338	GRNUNJ	BXQMLKECCV	9027778843 Dell Way	\N	HMJQIUX	SC	56118	US	1	BXQMLKECCV@dell.com	9027778843	1	9535008816979826	2011/04	user8338	password	22	100000	M
8339	OTLYUI	PHUALWCHDP	9131174996 Dell Way	\N	QUYLSTY	NH	88324	US	1	PHUALWCHDP@dell.com	9131174996	2	2117273293435573	2012/03	user8339	password	21	60000	M
8340	MNUVCB	QDNMFVQVML	5318479924 Dell Way	\N	TYDMWTJ	SC	13018	US	1	QDNMFVQVML@dell.com	5318479924	4	3318462349940091	2010/04	user8340	password	34	20000	M
8341	ZWXBMB	PZHLPCXBWW	3018170002 Dell Way	\N	EISYRNZ	DE	34498	US	1	PZHLPCXBWW@dell.com	3018170002	4	6172008064575494	2010/09	user8341	password	46	60000	M
8342	HNCJCB	QORSLSPHXX	4600201265 Dell Way	\N	AVPOUUV	AL	53506	US	1	QORSLSPHXX@dell.com	4600201265	3	2946441983804107	2011/12	user8342	password	78	20000	F
8343	XLNZBB	RUNKKVHHWD	4550212818 Dell Way	\N	XLYSGZE	NV	51169	US	1	RUNKKVHHWD@dell.com	4550212818	3	4391064722090960	2009/07	user8343	password	76	20000	M
8344	IDBKUW	YFGUMORQMC	4626884513 Dell Way	\N	PEIOIZA	OR	48976	US	1	YFGUMORQMC@dell.com	4626884513	5	9666439175140114	2009/02	user8344	password	86	60000	F
8345	ZYAWXF	CRSQIJCKYG	2191489182 Dell Way	\N	TNPTOIE	WI	35818	US	1	CRSQIJCKYG@dell.com	2191489182	1	4355571142397821	2008/09	user8345	password	60	20000	M
8346	PXNVZE	NQNXTXVARJ	6605639932 Dell Way	\N	QKXZOVG	OH	98827	US	1	NQNXTXVARJ@dell.com	6605639932	4	7093318886589260	2009/10	user8346	password	40	100000	M
8347	VQSAEJ	NBDLXDCGTM	6878922305 Dell Way	\N	DSBZZTZ	NH	56260	US	1	NBDLXDCGTM@dell.com	6878922305	5	4025183756370097	2012/08	user8347	password	22	100000	F
8348	UVLEJN	HVKKYREKVX	1701842522 Dell Way	\N	MVXFUMT	MI	37868	US	1	HVKKYREKVX@dell.com	1701842522	3	9452790246810764	2008/03	user8348	password	33	100000	F
8349	QCKEJG	OUEGZPBXBX	5892886363 Dell Way	\N	UHRHADP	CO	57782	US	1	OUEGZPBXBX@dell.com	5892886363	2	7736882619094104	2011/03	user8349	password	76	60000	F
8350	FORMDL	QJLFLIHIDO	4719967274 Dell Way	\N	ALPDBSR	NE	97255	US	1	QJLFLIHIDO@dell.com	4719967274	2	2403352828696370	2009/09	user8350	password	49	60000	F
8351	CXLONU	ZTGIAPMPPX	1434236697 Dell Way	\N	FTYXKNX	SD	87102	US	1	ZTGIAPMPPX@dell.com	1434236697	1	6312462731730193	2010/06	user8351	password	82	60000	F
8352	IDXDCR	JLRZXHPUMI	7445334026 Dell Way	\N	TKTGHOD	LA	63363	US	1	JLRZXHPUMI@dell.com	7445334026	5	1587865265086293	2010/05	user8352	password	50	100000	M
8353	IAQZKC	RJZZYULHNW	3009785434 Dell Way	\N	AUEOYNE	NV	43823	US	1	RJZZYULHNW@dell.com	3009785434	2	8130329007282854	2011/02	user8353	password	42	20000	F
8354	ZAPBRY	BQXVCEJZEE	8842597603 Dell Way	\N	ETDSXTC	CT	11470	US	1	BQXVCEJZEE@dell.com	8842597603	4	2558335840236395	2009/10	user8354	password	43	20000	M
8355	YGMWHD	UDGYNGDSKW	8003198594 Dell Way	\N	VCTPEXP	AR	71063	US	1	UDGYNGDSKW@dell.com	8003198594	2	5237862101290375	2008/06	user8355	password	37	20000	M
8356	TYZXSD	DRQJUIURDW	5183183912 Dell Way	\N	LTBIJDZ	CT	44032	US	1	DRQJUIURDW@dell.com	5183183912	2	8372641810681672	2011/04	user8356	password	54	60000	F
8357	MJZPNQ	GWLOQCSNNL	9126789672 Dell Way	\N	PVUSVYC	IN	26869	US	1	GWLOQCSNNL@dell.com	9126789672	1	5584533911664039	2010/07	user8357	password	74	100000	M
8358	TMJKSG	WHXYALMMAI	9089712361 Dell Way	\N	HSDFULK	OH	52043	US	1	WHXYALMMAI@dell.com	9089712361	1	9792927504517140	2011/01	user8358	password	80	60000	F
8359	GWFMSN	KRNVDZVLGO	5385293106 Dell Way	\N	PLJBWBN	PA	24582	US	1	KRNVDZVLGO@dell.com	5385293106	3	2497563689481467	2009/11	user8359	password	66	60000	M
8360	XBLKMC	XHGXCSERHQ	4452297424 Dell Way	\N	AJMBWFF	KY	67621	US	1	XHGXCSERHQ@dell.com	4452297424	4	5507816070225090	2008/04	user8360	password	33	100000	F
8361	QIUTGC	ZEFRIWZYWI	7975197413 Dell Way	\N	KXEQDNH	MT	29962	US	1	ZEFRIWZYWI@dell.com	7975197413	3	5399497670121491	2012/07	user8361	password	78	80000	M
8362	QJCSJG	XAPUANQJYO	8077899884 Dell Way	\N	OORBWFH	NJ	79306	US	1	XAPUANQJYO@dell.com	8077899884	4	3438723851460964	2011/03	user8362	password	25	40000	M
8363	FZZLWA	ARAOHJMWXB	8012893141 Dell Way	\N	NZXTHNN	CA	23625	US	1	ARAOHJMWXB@dell.com	8012893141	4	4589842670597136	2012/12	user8363	password	19	20000	M
8364	ZOUAOL	ADTKQPIRDI	7230843546 Dell Way	\N	PWQDJSH	DC	45482	US	1	ADTKQPIRDI@dell.com	7230843546	1	4014610878191888	2011/02	user8364	password	35	80000	M
8365	ASGMTJ	FDZUMRXUHU	8619902258 Dell Way	\N	KKDDSHN	MD	38481	US	1	FDZUMRXUHU@dell.com	8619902258	1	4912881432566792	2008/10	user8365	password	24	20000	M
8366	IPGRUK	RPWINRPHCA	5241405479 Dell Way	\N	LFSSSDA	ND	30654	US	1	RPWINRPHCA@dell.com	5241405479	4	1409285465255379	2010/10	user8366	password	59	100000	F
8367	VOEFGT	COHUEPWEAC	3552601033 Dell Way	\N	XTUAUJG	IA	12483	US	1	COHUEPWEAC@dell.com	3552601033	5	8191476097330452	2012/09	user8367	password	29	80000	F
8368	IXNCAB	JUFZRKZTHS	7756682589 Dell Way	\N	OHMYNTY	SD	58909	US	1	JUFZRKZTHS@dell.com	7756682589	4	3180245831143111	2012/05	user8368	password	55	40000	F
8369	AIGBSB	HRSRQMZJAG	4389148380 Dell Way	\N	WYUPXPD	NM	32396	US	1	HRSRQMZJAG@dell.com	4389148380	3	6300837149377913	2012/10	user8369	password	79	100000	F
8370	CZVDHN	WYEIXNJEKH	4304885417 Dell Way	\N	YZFNCWU	MO	46404	US	1	WYEIXNJEKH@dell.com	4304885417	2	2799331071320921	2009/04	user8370	password	41	40000	F
8371	ELNRIM	VRKJAOTINS	9838672495 Dell Way	\N	NAVJVIU	DE	73506	US	1	VRKJAOTINS@dell.com	9838672495	2	9866347607690842	2009/09	user8371	password	35	60000	F
8372	TDMGZD	QIEFCMSVAS	7133526515 Dell Way	\N	RKNZESS	DE	18273	US	1	QIEFCMSVAS@dell.com	7133526515	3	7962465533521027	2012/12	user8372	password	84	80000	F
8373	JYBNOK	RUMDMIEFZO	3815676963 Dell Way	\N	TZTLRXO	KY	42779	US	1	RUMDMIEFZO@dell.com	3815676963	2	3729805924464017	2009/12	user8373	password	46	60000	M
8374	LCMWTG	JXSRBXQQQQ	9241078288 Dell Way	\N	JCHGQQP	WI	92730	US	1	JXSRBXQQQQ@dell.com	9241078288	1	8947801455855370	2009/10	user8374	password	75	80000	M
8375	GPPNYN	FQODHEUXNW	6773574468 Dell Way	\N	FUNVKMT	IN	67707	US	1	FQODHEUXNW@dell.com	6773574468	4	4666413703002036	2010/05	user8375	password	37	80000	M
8376	WEXKKN	YOVDISRFXM	3227332069 Dell Way	\N	STWFNEV	DC	80513	US	1	YOVDISRFXM@dell.com	3227332069	3	2320832811761647	2010/03	user8376	password	26	40000	F
8377	AUVOTJ	JXSCOXZAQT	9905134789 Dell Way	\N	XWGBRJV	WA	95253	US	1	JXSCOXZAQT@dell.com	9905134789	3	2767583062406629	2008/11	user8377	password	64	20000	M
8378	MSKWBH	OEWMDWDXUZ	6802742510 Dell Way	\N	DVRNRPL	NV	14100	US	1	OEWMDWDXUZ@dell.com	6802742510	4	9050677498802544	2009/11	user8378	password	56	80000	M
8379	XPRFEV	BQZYTWSTZN	9426080650 Dell Way	\N	KMFZXWB	ND	66053	US	1	BQZYTWSTZN@dell.com	9426080650	5	5623462885618210	2010/08	user8379	password	25	40000	F
8380	TPJOQZ	NOTKGMJUXV	9948286934 Dell Way	\N	ZXTWYIM	UT	24216	US	1	NOTKGMJUXV@dell.com	9948286934	2	7714636817574502	2008/09	user8380	password	86	100000	F
8381	HKZGYN	AIUNSPKNPH	5500987337 Dell Way	\N	HLGPYCT	WA	50439	US	1	AIUNSPKNPH@dell.com	5500987337	1	2617990415077656	2010/11	user8381	password	54	80000	F
8382	MZGZAP	UNHKYVZGCL	3018949913 Dell Way	\N	MRJPLIB	WI	39675	US	1	UNHKYVZGCL@dell.com	3018949913	2	2799278885591775	2011/02	user8382	password	53	20000	F
8383	TECIZP	PJOKJUNVHF	1320451490 Dell Way	\N	FWQNXPV	DC	95973	US	1	PJOKJUNVHF@dell.com	1320451490	5	1416655798442661	2010/01	user8383	password	26	40000	F
8384	FPFVEP	JPZECULHZI	5667548083 Dell Way	\N	YNGNIJM	MA	32103	US	1	JPZECULHZI@dell.com	5667548083	5	3745974146295339	2011/02	user8384	password	58	100000	M
8385	URXKAN	JEQEPXEYWR	1764000520 Dell Way	\N	EJANVJU	LA	34624	US	1	JEQEPXEYWR@dell.com	1764000520	1	4876422253437340	2011/11	user8385	password	30	60000	M
8386	CUNPES	FIIDMGZEKJ	3189310369 Dell Way	\N	EYFOSOV	SD	61992	US	1	FIIDMGZEKJ@dell.com	3189310369	3	4846345185302198	2010/11	user8386	password	86	60000	M
8387	MCVEHE	MLRTLVDUZC	6195657080 Dell Way	\N	ZNVOIQD	NE	15977	US	1	MLRTLVDUZC@dell.com	6195657080	5	9303163384553046	2010/06	user8387	password	60	100000	M
8388	KDWOQI	FKTBONAQNO	1668802145 Dell Way	\N	LCXCGMD	TN	51574	US	1	FKTBONAQNO@dell.com	1668802145	2	9482158293947578	2011/04	user8388	password	55	20000	F
8389	JQDSWN	LXBYYSMMEP	3441569935 Dell Way	\N	KGVWKQI	MO	99078	US	1	LXBYYSMMEP@dell.com	3441569935	1	3760976797435433	2011/03	user8389	password	74	20000	M
8390	XWRKHP	MGNESAIHKP	1703748131 Dell Way	\N	DHZUQLU	VA	62725	US	1	MGNESAIHKP@dell.com	1703748131	4	7990394554566593	2012/11	user8390	password	61	80000	M
8391	HDZWQF	KUYLDGWSKD	5489922341 Dell Way	\N	RETDYQS	AK	38609	US	1	KUYLDGWSKD@dell.com	5489922341	5	2409358667675406	2008/08	user8391	password	80	40000	M
8392	VGKBQE	ABHHXZRBRV	9256096047 Dell Way	\N	UVULNUT	AL	70381	US	1	ABHHXZRBRV@dell.com	9256096047	1	3629967872984707	2011/07	user8392	password	22	80000	M
8393	LRJQSL	YZIYRKQMEL	1289798740 Dell Way	\N	HQZBKAT	IN	21919	US	1	YZIYRKQMEL@dell.com	1289798740	1	6745112408418209	2008/09	user8393	password	46	60000	F
8394	TFBFDB	OCSYSFCDMT	8778264409 Dell Way	\N	CODCHLF	KS	55043	US	1	OCSYSFCDMT@dell.com	8778264409	3	2685387265868485	2009/12	user8394	password	58	20000	F
8395	QFIRTK	KRCPUFCNIQ	7889141608 Dell Way	\N	QKXCQGP	MS	68645	US	1	KRCPUFCNIQ@dell.com	7889141608	4	6672262811101974	2009/10	user8395	password	77	100000	M
8396	DQTOAK	QQFWSTFJKP	8051552373 Dell Way	\N	GMGNBTD	SD	56392	US	1	QQFWSTFJKP@dell.com	8051552373	1	3524049651809037	2010/01	user8396	password	36	80000	M
8397	ZHTKXK	PUDJZMTPTF	4726258987 Dell Way	\N	WGGQKBD	FL	28387	US	1	PUDJZMTPTF@dell.com	4726258987	4	3578222985845059	2011/07	user8397	password	18	80000	M
8398	TBRDRM	GAMTTBMZYS	8186050080 Dell Way	\N	GOCHRHN	CA	15151	US	1	GAMTTBMZYS@dell.com	8186050080	4	6034896867349744	2012/06	user8398	password	42	60000	F
8399	ASENZE	ZSYBFYZXEN	9291953033 Dell Way	\N	AMFHZHJ	SC	16486	US	1	ZSYBFYZXEN@dell.com	9291953033	3	5477787231560797	2009/02	user8399	password	89	40000	M
8400	DUVITO	HVTFURKIRW	4758349878 Dell Way	\N	OZWWIQX	ID	31234	US	1	HVTFURKIRW@dell.com	4758349878	3	4471294509712607	2010/10	user8400	password	35	60000	M
8401	CXJQEE	KKZBUISRWS	8027496441 Dell Way	\N	NSBEQIK	AR	85195	US	1	KKZBUISRWS@dell.com	8027496441	3	6729564120527357	2008/12	user8401	password	34	20000	M
8402	PTBTDL	TEGBXXXQKP	5078234283 Dell Way	\N	ROGZYHV	OR	74591	US	1	TEGBXXXQKP@dell.com	5078234283	4	7397169250994921	2011/11	user8402	password	60	40000	M
8403	QATCUY	IVWFTMPJDE	3595931432 Dell Way	\N	PDDWYWP	MD	67158	US	1	IVWFTMPJDE@dell.com	3595931432	1	5594992066733540	2012/05	user8403	password	27	60000	F
8404	XPDWYZ	SDSETBIYQL	1652245594 Dell Way	\N	BMKYBUO	LA	87695	US	1	SDSETBIYQL@dell.com	1652245594	2	2806859583593905	2009/10	user8404	password	59	20000	F
8405	SZHRRK	JWEKFCBRDO	9153003927 Dell Way	\N	BCQVQZS	OK	30676	US	1	JWEKFCBRDO@dell.com	9153003927	5	9881703488994392	2010/01	user8405	password	43	20000	M
8406	QVRBFN	FQTIRKMGLO	1615809335 Dell Way	\N	WHEWZXC	VA	84266	US	1	FQTIRKMGLO@dell.com	1615809335	2	8712967816274614	2010/07	user8406	password	80	20000	F
8407	NCPBIF	URXEDDQRZX	5166620844 Dell Way	\N	WVXUYUP	WY	24063	US	1	URXEDDQRZX@dell.com	5166620844	3	7264657162129880	2009/06	user8407	password	23	100000	M
8408	RXXWRO	UWSXMKXKGT	9482079759 Dell Way	\N	HBRCQRG	CO	16443	US	1	UWSXMKXKGT@dell.com	9482079759	3	5810765690170229	2008/04	user8408	password	25	80000	F
8409	AOWPIS	HGFRDQYWXZ	8189255245 Dell Way	\N	NAQFGTG	GA	25722	US	1	HGFRDQYWXZ@dell.com	8189255245	2	4958519797306508	2012/11	user8409	password	61	100000	F
8410	LNUEUA	KMDAKAYJOY	4358971370 Dell Way	\N	ATFTZKY	SC	64823	US	1	KMDAKAYJOY@dell.com	4358971370	4	5565226139035076	2012/08	user8410	password	88	60000	F
8411	TPXTZJ	XZUXXELWEE	5938660171 Dell Way	\N	BYELWZB	HI	71610	US	1	XZUXXELWEE@dell.com	5938660171	2	3760456750635058	2010/08	user8411	password	49	40000	F
8412	JAFSYE	MVCQHYVMZT	6744802386 Dell Way	\N	RKPQLVI	AK	13841	US	1	MVCQHYVMZT@dell.com	6744802386	3	7038265624549241	2008/10	user8412	password	83	60000	M
8413	CDSHQO	JHVICIHWZS	1126326546 Dell Way	\N	MQEHZEI	NH	71108	US	1	JHVICIHWZS@dell.com	1126326546	4	5067842198535800	2012/02	user8413	password	35	100000	F
8414	YGWNQE	JYHRGDRYPH	4513968513 Dell Way	\N	CXHGGWY	ID	59398	US	1	JYHRGDRYPH@dell.com	4513968513	1	6779209340922535	2011/02	user8414	password	82	60000	F
8415	TCBXMA	FDGIVEYDHW	5118968434 Dell Way	\N	KNCGMJV	TX	57296	US	1	FDGIVEYDHW@dell.com	5118968434	3	7184722069650889	2009/02	user8415	password	26	20000	F
8416	EAREFV	LOQPMTWJEK	1172925569 Dell Way	\N	LLWUGTI	OH	31370	US	1	LOQPMTWJEK@dell.com	1172925569	1	3966302667744458	2008/02	user8416	password	56	40000	F
8417	FNIAYX	ROKLKTPVEA	1154710134 Dell Way	\N	SZGLIZR	KY	99915	US	1	ROKLKTPVEA@dell.com	1154710134	3	2086494731251150	2010/10	user8417	password	36	80000	F
8418	PUGMLU	WXFQMAVNTV	8745186636 Dell Way	\N	UEDTWMT	VA	97244	US	1	WXFQMAVNTV@dell.com	8745186636	3	7938801283482463	2008/03	user8418	password	23	80000	M
8419	IELCBI	HRVIMIBHCG	6993657332 Dell Way	\N	LVDYOAX	MI	52090	US	1	HRVIMIBHCG@dell.com	6993657332	3	6973507023882122	2011/03	user8419	password	64	20000	F
8420	BENKME	FURNWZPDLL	4817199836 Dell Way	\N	GJAHGLT	VT	10684	US	1	FURNWZPDLL@dell.com	4817199836	4	3311666407622397	2008/09	user8420	password	68	20000	M
8421	FNJJSE	BGBBWEMILV	1549075979 Dell Way	\N	ITBUMZU	WA	66576	US	1	BGBBWEMILV@dell.com	1549075979	5	4146426359657198	2011/02	user8421	password	35	100000	M
8422	PIKUJQ	VLMZXULSDE	7496046183 Dell Way	\N	UYRTTPJ	SD	62343	US	1	VLMZXULSDE@dell.com	7496046183	3	7360709397122265	2012/07	user8422	password	44	60000	M
8423	TIFJDQ	WDNROGVTAT	3720026992 Dell Way	\N	KTNADIP	TX	88928	US	1	WDNROGVTAT@dell.com	3720026992	5	4445477288216353	2011/05	user8423	password	33	60000	M
8424	LUWBRZ	PJOVEIVYSP	1330085729 Dell Way	\N	LTSUIOQ	NM	43117	US	1	PJOVEIVYSP@dell.com	1330085729	2	7640739344060422	2009/09	user8424	password	50	80000	M
8425	HTEHIN	VESDAQWPCQ	9777827376 Dell Way	\N	IXYWOPG	NE	91625	US	1	VESDAQWPCQ@dell.com	9777827376	5	6603163063526154	2010/07	user8425	password	27	80000	F
8426	HZOVVT	NZTEWIHMQE	6040946430 Dell Way	\N	LNSATHY	OK	20480	US	1	NZTEWIHMQE@dell.com	6040946430	1	6563962008804083	2011/11	user8426	password	80	100000	M
8427	LVQEJQ	XNMGVYWZJK	7564401676 Dell Way	\N	SKDZIWC	VA	10015	US	1	XNMGVYWZJK@dell.com	7564401676	3	8600015778560192	2010/07	user8427	password	66	20000	F
8428	IETYCG	KICIFBRPUC	5096843214 Dell Way	\N	TTKPWHP	NH	89010	US	1	KICIFBRPUC@dell.com	5096843214	1	5022490276955068	2008/03	user8428	password	78	60000	F
8429	OJNVUV	XCBZURTWLN	9280185855 Dell Way	\N	HAKPQAM	CO	27841	US	1	XCBZURTWLN@dell.com	9280185855	2	4744121443014592	2011/09	user8429	password	78	40000	F
8430	IDVEBY	GATXUQIHYJ	3808009034 Dell Way	\N	SNASZDX	VT	42069	US	1	GATXUQIHYJ@dell.com	3808009034	4	1266122856643050	2008/12	user8430	password	24	60000	F
8431	XQFWXG	PUAGDIENAR	1639837947 Dell Way	\N	OSRRQPB	WA	31967	US	1	PUAGDIENAR@dell.com	1639837947	1	3089208698365837	2008/07	user8431	password	45	20000	F
8432	OYBVNW	VTAEXOEPCX	3870397463 Dell Way	\N	GUNVVLC	VT	56310	US	1	VTAEXOEPCX@dell.com	3870397463	1	1420468709431588	2011/02	user8432	password	34	40000	F
8433	HCPEXJ	ECHTGXWEDQ	7373805810 Dell Way	\N	SZMDCKR	MD	50387	US	1	ECHTGXWEDQ@dell.com	7373805810	1	6236554858740420	2012/05	user8433	password	65	40000	F
8434	GJJPOL	XHSUDWYUOY	7170167347 Dell Way	\N	GSARJKC	CA	54329	US	1	XHSUDWYUOY@dell.com	7170167347	1	8642281973734499	2009/03	user8434	password	38	60000	M
8435	QEEBCM	UWQRULFSSY	5171208017 Dell Way	\N	SJIDLLP	DC	50426	US	1	UWQRULFSSY@dell.com	5171208017	3	7243825320620090	2011/01	user8435	password	41	40000	F
8436	NMIAGE	QXYCDRUCKD	9829508564 Dell Way	\N	KNPVDTH	NH	29425	US	1	QXYCDRUCKD@dell.com	9829508564	2	3390183780808002	2009/09	user8436	password	54	100000	F
8437	UVLZMI	YOLPINAMYN	3538664325 Dell Way	\N	BURUBGA	AR	64123	US	1	YOLPINAMYN@dell.com	3538664325	2	4003656225278974	2011/03	user8437	password	56	60000	M
8438	ZOLHNA	TDIHDUFRWA	5586922397 Dell Way	\N	IRCORDE	WI	54171	US	1	TDIHDUFRWA@dell.com	5586922397	4	6926925820764155	2008/04	user8438	password	65	20000	M
8439	CHKCBN	LIQGOHCOPT	9448656308 Dell Way	\N	QELUJKH	UT	21522	US	1	LIQGOHCOPT@dell.com	9448656308	5	5072701334487647	2010/11	user8439	password	42	80000	F
8440	TUGGGO	WMDEOSUIJY	7557175868 Dell Way	\N	TDIDKEH	LA	18697	US	1	WMDEOSUIJY@dell.com	7557175868	5	1045350915752351	2008/08	user8440	password	33	100000	F
8441	LBRAXD	DCSVWAFVUI	4831864336 Dell Way	\N	DYTIFCK	WA	13854	US	1	DCSVWAFVUI@dell.com	4831864336	1	7037081500515342	2011/10	user8441	password	24	20000	M
8442	TCTWGV	OCSPHNJQQH	2735863095 Dell Way	\N	JZNMKLN	SD	48964	US	1	OCSPHNJQQH@dell.com	2735863095	3	3115876477677375	2009/07	user8442	password	23	20000	M
8443	VXXRMA	JBIWLYNTIM	4081752663 Dell Way	\N	GUWRIRC	MT	22346	US	1	JBIWLYNTIM@dell.com	4081752663	5	7037842774298043	2010/11	user8443	password	40	40000	M
8444	FYFGHH	OETMRMVESP	5883853287 Dell Way	\N	BKYTNLW	TX	32990	US	1	OETMRMVESP@dell.com	5883853287	2	1813126054592430	2012/07	user8444	password	78	20000	F
8445	BITJWX	CJPPETHUUS	5701184116 Dell Way	\N	SOFEKBL	WI	39362	US	1	CJPPETHUUS@dell.com	5701184116	5	8644820089451970	2009/11	user8445	password	39	60000	F
8446	BUBYWK	NLPHTJCLCQ	9011974002 Dell Way	\N	RHBSSAB	HI	83908	US	1	NLPHTJCLCQ@dell.com	9011974002	3	7408655480016024	2008/12	user8446	password	84	40000	M
8447	ZEQKSB	ZAVJCHLTYS	4148913484 Dell Way	\N	UQLVRRQ	NE	31326	US	1	ZAVJCHLTYS@dell.com	4148913484	4	3103996265679598	2009/12	user8447	password	18	40000	F
8448	QQWSQX	NZZULTSEOJ	7592498700 Dell Way	\N	PJBGAQM	LA	45377	US	1	NZZULTSEOJ@dell.com	7592498700	4	4460505625698716	2011/11	user8448	password	58	40000	M
8449	LBEIPD	IKPBDUQNKZ	9775260535 Dell Way	\N	OQAFDJP	UT	99201	US	1	IKPBDUQNKZ@dell.com	9775260535	4	8786018591839821	2010/12	user8449	password	46	100000	F
8450	OGRSPB	HQFCGSMGHD	5212499887 Dell Way	\N	GMGPBDP	AR	78435	US	1	HQFCGSMGHD@dell.com	5212499887	3	7658448608126492	2012/07	user8450	password	75	40000	M
8451	LCJNKA	SMGLYNSBTF	9712683283 Dell Way	\N	IJGMZIF	MI	89244	US	1	SMGLYNSBTF@dell.com	9712683283	2	4640849367715418	2011/09	user8451	password	32	40000	M
8452	OTEOLQ	VXPIPQCUYM	6996039176 Dell Way	\N	BLLJRWG	NJ	25201	US	1	VXPIPQCUYM@dell.com	6996039176	2	8726671741809697	2012/08	user8452	password	64	60000	F
8453	VAULVR	AEHRHCQTEB	1809745469 Dell Way	\N	EOSBUIG	MN	74514	US	1	AEHRHCQTEB@dell.com	1809745469	2	3828489264007658	2011/10	user8453	password	65	60000	M
8454	LZPCAU	KSBMIVQKZE	5238876034 Dell Way	\N	CBZLHLE	MA	79216	US	1	KSBMIVQKZE@dell.com	5238876034	1	5750491575337947	2008/08	user8454	password	39	60000	M
8455	XQRRAK	TNTODDOHGP	1093854726 Dell Way	\N	HRXSVHM	IN	45444	US	1	TNTODDOHGP@dell.com	1093854726	3	1442055253311991	2009/12	user8455	password	69	20000	M
8456	KWQUPD	NDHQROXHWO	9196529403 Dell Way	\N	EOKMBSW	AR	20509	US	1	NDHQROXHWO@dell.com	9196529403	2	1703378313686698	2011/07	user8456	password	67	20000	F
8457	IUZLHD	SYVHVCDKHS	7201501361 Dell Way	\N	UTTMQVP	MT	24535	US	1	SYVHVCDKHS@dell.com	7201501361	1	7327849310822786	2009/02	user8457	password	25	80000	M
8458	CDGFWF	AEADILKAGE	5176288292 Dell Way	\N	USUPIIT	AL	51397	US	1	AEADILKAGE@dell.com	5176288292	3	6425734664779157	2010/02	user8458	password	56	80000	F
8459	UXDZXH	ABQLMRRRLK	8497097478 Dell Way	\N	LBTUVTF	IL	24741	US	1	ABQLMRRRLK@dell.com	8497097478	5	3317733409348875	2009/07	user8459	password	54	20000	F
8460	QCIYCJ	OOWFFNRPZT	5804244636 Dell Way	\N	JTOCZWH	SC	73332	US	1	OOWFFNRPZT@dell.com	5804244636	1	2949939647223800	2008/04	user8460	password	62	80000	F
8461	YPNIDB	EJHRBXQVGJ	2335816134 Dell Way	\N	JJIFQDY	DE	37171	US	1	EJHRBXQVGJ@dell.com	2335816134	1	6439792080316693	2011/11	user8461	password	18	80000	F
8462	NAPPEZ	WWATNVZWFI	3401023044 Dell Way	\N	FLYJJCR	MT	36533	US	1	WWATNVZWFI@dell.com	3401023044	2	2337811421137303	2009/12	user8462	password	61	100000	M
8463	EKEDGA	EZNAYKFHQQ	7932058641 Dell Way	\N	FZAIQNQ	VT	83686	US	1	EZNAYKFHQQ@dell.com	7932058641	1	8182086894754321	2009/01	user8463	password	75	60000	F
8464	YRQZWP	NWOXBWOSCN	9076941785 Dell Way	\N	TKEHACC	SC	36711	US	1	NWOXBWOSCN@dell.com	9076941785	1	3686644391156733	2011/09	user8464	password	68	80000	F
8465	IPGYDC	NAEJOXLCQV	9719728708 Dell Way	\N	HXWJARR	VT	83488	US	1	NAEJOXLCQV@dell.com	9719728708	4	5641181784681976	2011/03	user8465	password	83	100000	M
8466	DXZGKZ	KUOIFQZBYX	9117328808 Dell Way	\N	XHXOZVK	WA	48748	US	1	KUOIFQZBYX@dell.com	9117328808	3	7036171649117023	2012/07	user8466	password	56	100000	F
8467	MFXMQR	BYWSXXQUVY	6592050784 Dell Way	\N	SKXNUVY	OH	49509	US	1	BYWSXXQUVY@dell.com	6592050784	3	1099313985556364	2008/06	user8467	password	53	80000	M
8468	KDGBEE	YWCWNWRLOC	6648220348 Dell Way	\N	ICWEAOQ	NV	14539	US	1	YWCWNWRLOC@dell.com	6648220348	5	5415813136845827	2008/06	user8468	password	27	60000	M
8469	JOTOMQ	QIDNAOCCXE	1636478103 Dell Way	\N	ZBFNRWP	IN	71791	US	1	QIDNAOCCXE@dell.com	1636478103	3	2165270329918712	2008/12	user8469	password	68	60000	F
8470	LDZBUI	EIJTKLQPKR	5664849148 Dell Way	\N	VYJSNRK	NH	20032	US	1	EIJTKLQPKR@dell.com	5664849148	4	1428960344288498	2009/05	user8470	password	57	80000	M
8471	NSHWXQ	FQAQGQBYLA	2269457650 Dell Way	\N	HDOZODC	AZ	95559	US	1	FQAQGQBYLA@dell.com	2269457650	2	3881237578112632	2011/12	user8471	password	78	40000	M
8472	DBOTHE	UYKKZIWAQA	9950237738 Dell Way	\N	OQOSSPR	TX	90111	US	1	UYKKZIWAQA@dell.com	9950237738	3	8418037464842201	2012/10	user8472	password	52	100000	M
8473	ARCEMA	PWAXSAOTPE	6504290318 Dell Way	\N	HIWXASU	WY	34046	US	1	PWAXSAOTPE@dell.com	6504290318	5	1178375289775431	2008/10	user8473	password	79	20000	F
8474	YGXYWU	ZTNAIGQMNY	4351833438 Dell Way	\N	JKYCFYJ	SD	78516	US	1	ZTNAIGQMNY@dell.com	4351833438	5	5730570838321001	2009/12	user8474	password	89	20000	F
8475	XDCRCW	ECEKSRYRAJ	8587397686 Dell Way	\N	PCOOLJI	TN	34353	US	1	ECEKSRYRAJ@dell.com	8587397686	1	3396890749223530	2012/03	user8475	password	56	80000	F
8476	QKKNON	SZGJXXJGNM	7456710846 Dell Way	\N	VCYEKUL	IA	83382	US	1	SZGJXXJGNM@dell.com	7456710846	1	1143854266498237	2009/10	user8476	password	42	100000	F
8477	TKSGCS	NMPKWWYJRA	9041851233 Dell Way	\N	HWKBHQW	AK	73900	US	1	NMPKWWYJRA@dell.com	9041851233	2	5341723529156298	2009/02	user8477	password	64	100000	M
8478	JGRBTE	REANCJEDRA	4393065788 Dell Way	\N	NSIEPIX	MS	64889	US	1	REANCJEDRA@dell.com	4393065788	4	7906651961617173	2008/09	user8478	password	42	40000	M
8479	ALRECW	FPYOUCGVPY	8835110975 Dell Way	\N	DUOMRBC	AZ	79977	US	1	FPYOUCGVPY@dell.com	8835110975	1	5271880600135774	2009/06	user8479	password	48	40000	M
8480	CKZYPP	XEKZKFPJJK	3050120610 Dell Way	\N	XWCZYET	TN	31958	US	1	XEKZKFPJJK@dell.com	3050120610	1	7387645359616727	2011/04	user8480	password	62	80000	M
8481	PRGFPL	PPVVEFEPDA	8014251265 Dell Way	\N	RCZVVUB	AZ	85298	US	1	PPVVEFEPDA@dell.com	8014251265	4	1832714067772030	2009/06	user8481	password	72	100000	F
8482	AFTLUI	GPNMUCPUTR	5595230343 Dell Way	\N	UPNPQPK	ME	37161	US	1	GPNMUCPUTR@dell.com	5595230343	5	7777440263889731	2009/10	user8482	password	83	40000	F
8483	QSVYZL	LLFOAAHRUW	8616153863 Dell Way	\N	FJNUUYC	IL	79251	US	1	LLFOAAHRUW@dell.com	8616153863	3	6242901350837201	2011/10	user8483	password	61	40000	M
8484	KIMVUX	BIYBQQVMVE	3933209673 Dell Way	\N	AQYZSGT	ND	81899	US	1	BIYBQQVMVE@dell.com	3933209673	2	6530592063907534	2012/08	user8484	password	27	40000	M
8485	QEUOFC	MGSCBFYGGO	8876688329 Dell Way	\N	FFGMZUG	IL	18775	US	1	MGSCBFYGGO@dell.com	8876688329	2	7875593054108322	2008/07	user8485	password	73	80000	M
8486	NEYQQE	JTGPRNVFSB	2073459015 Dell Way	\N	LEAGLHJ	KS	56301	US	1	JTGPRNVFSB@dell.com	2073459015	2	1564995229709893	2012/12	user8486	password	75	60000	F
8487	SATXKN	DZEQUJJWVO	7693970476 Dell Way	\N	WCZELHR	NE	65925	US	1	DZEQUJJWVO@dell.com	7693970476	3	6124321686569602	2010/11	user8487	password	68	40000	M
8488	LDHYHG	DYBNHXJVUL	3899564806 Dell Way	\N	VYXDQMT	MA	91902	US	1	DYBNHXJVUL@dell.com	3899564806	5	7839618172962219	2008/02	user8488	password	65	60000	F
8489	YKOENM	GBUEKQYVMX	8839703202 Dell Way	\N	TPNFIXC	NY	82014	US	1	GBUEKQYVMX@dell.com	8839703202	4	9452912241220476	2010/02	user8489	password	33	60000	M
8490	TQBGXD	ABNRAJDXCS	1681866704 Dell Way	\N	LHBIKTD	IL	46880	US	1	ABNRAJDXCS@dell.com	1681866704	4	5859396423678846	2009/03	user8490	password	23	20000	M
8491	DHUHIV	UAVEDTGWEO	6414232673 Dell Way	\N	XNYQRGB	OR	12679	US	1	UAVEDTGWEO@dell.com	6414232673	1	3476219071540982	2011/01	user8491	password	29	100000	F
8492	YCSTXS	PBWIHSNWQB	4083632715 Dell Way	\N	UHSAILB	WA	50782	US	1	PBWIHSNWQB@dell.com	4083632715	4	5733022289350629	2010/06	user8492	password	83	60000	M
8493	QELIUN	EDVXRRNSMU	8397142859 Dell Way	\N	KNDVPBH	WA	70859	US	1	EDVXRRNSMU@dell.com	8397142859	3	2123548141214996	2011/11	user8493	password	67	40000	F
8494	DRVRWY	MTQDHIQBTD	1521565990 Dell Way	\N	FPSGWQY	OH	16091	US	1	MTQDHIQBTD@dell.com	1521565990	3	9290892693214120	2011/10	user8494	password	88	100000	F
8495	UNITAC	JEJSULLXQA	3388093036 Dell Way	\N	QXWHVPI	VA	99927	US	1	JEJSULLXQA@dell.com	3388093036	4	7866234504152090	2009/07	user8495	password	33	20000	F
8496	NUBQDF	ZVZLGXBHNZ	5514768821 Dell Way	\N	EUUTDST	ME	38924	US	1	ZVZLGXBHNZ@dell.com	5514768821	4	8463602454401554	2011/08	user8496	password	81	40000	F
8497	XWODVK	CHRAJYNIDI	9724623006 Dell Way	\N	DWMVPXD	CO	59953	US	1	CHRAJYNIDI@dell.com	9724623006	5	2970222528558224	2012/01	user8497	password	65	80000	M
8498	FXTQZA	IAJHOSKXVG	1575672969 Dell Way	\N	JQWHUYV	PA	78690	US	1	IAJHOSKXVG@dell.com	1575672969	3	8311058865860105	2011/05	user8498	password	70	100000	F
8499	MPGMXG	WEUOPRKVBA	3028738895 Dell Way	\N	SIVQEOK	IA	24228	US	1	WEUOPRKVBA@dell.com	3028738895	5	5616029960568995	2012/11	user8499	password	73	60000	M
8500	ZXKGTP	AIESSATTSC	8190992566 Dell Way	\N	OJHDUOH	AK	56304	US	1	AIESSATTSC@dell.com	8190992566	5	4861966798081994	2010/05	user8500	password	85	60000	F
8501	IUAYVJ	COBDHVVKJF	2718280024 Dell Way	\N	SNZGUZT	NH	94406	US	1	COBDHVVKJF@dell.com	2718280024	1	3639252243097872	2008/09	user8501	password	58	60000	M
8502	OKIXMW	ZQEVMPERHS	8912027954 Dell Way	\N	ROMQICP	MS	31666	US	1	ZQEVMPERHS@dell.com	8912027954	4	9509315023198724	2010/01	user8502	password	50	100000	F
8503	UXYRXO	WSALXSTPJH	4424982038 Dell Way	\N	CAPFPCL	MO	75654	US	1	WSALXSTPJH@dell.com	4424982038	5	8248471027240158	2012/11	user8503	password	37	80000	M
8504	FHSUEL	VPJOJYXRBX	9369534416 Dell Way	\N	HGNKRZD	AZ	90395	US	1	VPJOJYXRBX@dell.com	9369534416	5	8144981806166471	2008/07	user8504	password	62	60000	M
8505	IFZUBP	DPYCMQDKXK	6369977100 Dell Way	\N	XICXLEU	LA	16314	US	1	DPYCMQDKXK@dell.com	6369977100	3	6350121449213476	2009/12	user8505	password	48	60000	F
8506	KIGZLV	YOIORTMCRU	1197654949 Dell Way	\N	EOGJJPL	WV	25745	US	1	YOIORTMCRU@dell.com	1197654949	1	2435324973892420	2010/09	user8506	password	44	100000	F
8507	PUMLTB	UISNUVEPAT	8134042856 Dell Way	\N	WJDLUCQ	SD	33323	US	1	UISNUVEPAT@dell.com	8134042856	2	9824694963637740	2008/01	user8507	password	19	80000	M
8508	NFQOZY	HNTDRJDLFN	8794987525 Dell Way	\N	ORHQHDX	CA	44491	US	1	HNTDRJDLFN@dell.com	8794987525	2	5182445550803095	2012/12	user8508	password	43	60000	F
8509	ZZFXHS	RKKAOVFBJW	3936389495 Dell Way	\N	JZDMWFW	OR	51590	US	1	RKKAOVFBJW@dell.com	3936389495	4	5125329242553562	2011/01	user8509	password	66	80000	F
8510	WOIOFS	YFGTLHDHRC	6234663402 Dell Way	\N	LDZRZSD	KS	40415	US	1	YFGTLHDHRC@dell.com	6234663402	5	4465354879386723	2009/08	user8510	password	48	20000	F
8511	TRLLQR	SKCANJRPVV	1171766662 Dell Way	\N	PMVHPDQ	DE	21686	US	1	SKCANJRPVV@dell.com	1171766662	3	8015510043129326	2010/07	user8511	password	90	20000	F
8512	LQVCIF	EJSOAIJVXV	7224528809 Dell Way	\N	QFLUVPX	TX	13155	US	1	EJSOAIJVXV@dell.com	7224528809	2	6087822672445328	2011/06	user8512	password	73	20000	F
8513	PFLUKU	NYVVIRTEIZ	8297981793 Dell Way	\N	PCUFARG	OH	96960	US	1	NYVVIRTEIZ@dell.com	8297981793	2	4929669797886163	2010/07	user8513	password	56	20000	M
8514	ZZCTMB	PIJGBNOADR	9158730607 Dell Way	\N	VIRNPJM	MD	78865	US	1	PIJGBNOADR@dell.com	9158730607	5	3429652704391629	2010/02	user8514	password	89	60000	F
8515	CEPDTX	NZZBOAEFWN	3622949093 Dell Way	\N	WJDGVNA	OR	55691	US	1	NZZBOAEFWN@dell.com	3622949093	1	6897024881560356	2009/07	user8515	password	74	40000	M
8516	JNMGAL	GBZGGFCUCL	6452175286 Dell Way	\N	XIHLJAY	NV	25875	US	1	GBZGGFCUCL@dell.com	6452175286	5	7727534839883447	2009/04	user8516	password	52	80000	M
8517	YAUKGW	KNDPQXSBVB	3609736020 Dell Way	\N	JHKJGBO	TN	99191	US	1	KNDPQXSBVB@dell.com	3609736020	2	3534892255440354	2011/12	user8517	password	23	80000	M
8518	WDFTNS	XDIVVKQWTY	6475749271 Dell Way	\N	HDEIRZI	WI	28731	US	1	XDIVVKQWTY@dell.com	6475749271	4	2370276765897870	2011/06	user8518	password	25	60000	M
8519	HICZFF	IABSRXMPEP	2023720399 Dell Way	\N	TNGTWEY	MN	91870	US	1	IABSRXMPEP@dell.com	2023720399	1	4119414737913758	2009/09	user8519	password	84	60000	F
8520	ZNGFVG	GNXEZNJOGX	3336890898 Dell Way	\N	VATAZFX	CA	41463	US	1	GNXEZNJOGX@dell.com	3336890898	2	1504479854367673	2008/10	user8520	password	23	20000	F
8521	IJDOPR	MUQZDFGAAH	4338012987 Dell Way	\N	TBGZYJI	GA	69994	US	1	MUQZDFGAAH@dell.com	4338012987	2	5315725660882890	2010/07	user8521	password	75	80000	M
8522	YIMPUG	GUKLBKMIEN	1872719466 Dell Way	\N	PDMYLSQ	SD	17260	US	1	GUKLBKMIEN@dell.com	1872719466	2	6482478783000261	2012/01	user8522	password	53	100000	F
8523	ZKEGQY	QCABPIFDYI	1192436183 Dell Way	\N	QXUINPK	NH	89477	US	1	QCABPIFDYI@dell.com	1192436183	3	9269277147948744	2010/04	user8523	password	38	60000	M
8524	LTJKJL	KKBTPESYVP	2420487433 Dell Way	\N	TDCJORG	NE	25273	US	1	KKBTPESYVP@dell.com	2420487433	1	5282678964082152	2010/08	user8524	password	31	100000	F
8525	NHRZSC	AMSFEQATKE	2273520824 Dell Way	\N	VTSMZHR	DC	45080	US	1	AMSFEQATKE@dell.com	2273520824	3	9770251858048142	2009/06	user8525	password	39	100000	M
8526	ZVMBWY	TBCKCVUGQO	6812859526 Dell Way	\N	ZDNHURR	WI	33587	US	1	TBCKCVUGQO@dell.com	6812859526	2	7576572501566262	2012/02	user8526	password	53	100000	M
8527	YZVXSX	ZDZUYGLMGP	7048841524 Dell Way	\N	ANKREIY	TN	64666	US	1	ZDZUYGLMGP@dell.com	7048841524	4	7614045291673393	2008/09	user8527	password	68	20000	M
8528	NAJKZN	KULRGXXVXK	9010498158 Dell Way	\N	FPPONLE	GA	29548	US	1	KULRGXXVXK@dell.com	9010498158	2	9132165556773544	2010/06	user8528	password	59	20000	F
8529	YNMLYG	XPMUNISYNH	1958405781 Dell Way	\N	OBVZFAF	CT	45406	US	1	XPMUNISYNH@dell.com	1958405781	4	8864867771044374	2011/10	user8529	password	44	80000	F
8530	VBHCZX	PUKXMJKUXM	9272830567 Dell Way	\N	QWSQCVB	FL	58783	US	1	PUKXMJKUXM@dell.com	9272830567	5	4232465669512749	2009/06	user8530	password	69	20000	M
8531	AFNXUH	IRURCPOOFL	1247555562 Dell Way	\N	HWNDXSR	SD	60956	US	1	IRURCPOOFL@dell.com	1247555562	1	1329600648023188	2011/03	user8531	password	60	80000	F
8532	CQEKZV	EQXTFMYQUV	5334513298 Dell Way	\N	EXSWONL	NH	65879	US	1	EQXTFMYQUV@dell.com	5334513298	2	8416850964538754	2008/01	user8532	password	34	20000	M
8533	KORFTI	DNNQMEKHII	9602952607 Dell Way	\N	ZFXNRND	DC	85547	US	1	DNNQMEKHII@dell.com	9602952607	2	9227700896561148	2008/05	user8533	password	64	60000	M
8534	IURQYE	DPQIZXQIXW	5244670746 Dell Way	\N	FKNSNRO	MS	87671	US	1	DPQIZXQIXW@dell.com	5244670746	4	3062117813155055	2008/03	user8534	password	29	60000	F
8535	VBZZFO	QNONEWLACV	3720495578 Dell Way	\N	OUJFJWB	TN	57619	US	1	QNONEWLACV@dell.com	3720495578	5	7916186728514732	2010/05	user8535	password	76	40000	F
8536	UGPIXC	XLHTWHWRWR	2839200155 Dell Way	\N	BBAXDWL	MI	81575	US	1	XLHTWHWRWR@dell.com	2839200155	5	2327867789193988	2008/03	user8536	password	57	80000	F
8537	DDIGAT	NUPVQHRIIT	2202716419 Dell Way	\N	IGWERIZ	VA	29131	US	1	NUPVQHRIIT@dell.com	2202716419	5	4470130309462547	2011/09	user8537	password	78	100000	M
8538	EBWXPQ	NKHVCPDVYK	6734638264 Dell Way	\N	SDBBDYG	IA	86468	US	1	NKHVCPDVYK@dell.com	6734638264	5	5823062692303211	2010/10	user8538	password	44	80000	M
8539	FOKWBV	EXYUBUSLMW	8657376549 Dell Way	\N	NNZMUFI	ME	23800	US	1	EXYUBUSLMW@dell.com	8657376549	5	9147679688408972	2009/07	user8539	password	71	60000	F
8540	DHDZLA	XFBRYMEUAS	1153172482 Dell Way	\N	TMNYUYC	NM	83563	US	1	XFBRYMEUAS@dell.com	1153172482	5	3989200090989471	2011/04	user8540	password	46	100000	M
8541	NWZOTE	PLCCQWCIQO	9272231949 Dell Way	\N	VPIURZP	OK	82613	US	1	PLCCQWCIQO@dell.com	9272231949	3	1596245014108717	2009/05	user8541	password	62	100000	F
8542	PJYUZK	XBATDJKSFZ	8930402841 Dell Way	\N	BZRAOJV	MO	83596	US	1	XBATDJKSFZ@dell.com	8930402841	4	2364183901809156	2010/08	user8542	password	42	20000	M
8543	HVZRSA	SMEBXWHWXG	8668196320 Dell Way	\N	NYUWTHS	NJ	15389	US	1	SMEBXWHWXG@dell.com	8668196320	1	7111179561354221	2008/03	user8543	password	66	60000	F
8544	QETRXG	VYDSFZQMNO	3509047398 Dell Way	\N	GKHOCXP	WI	12894	US	1	VYDSFZQMNO@dell.com	3509047398	1	2920989127829671	2012/08	user8544	password	35	60000	M
8545	ZGSGBR	KUXKKJXYQH	4814389472 Dell Way	\N	GEKETJF	AR	55019	US	1	KUXKKJXYQH@dell.com	4814389472	5	2190388383343816	2011/07	user8545	password	86	80000	M
8546	QXWHHR	ERBOPAEXHI	3691480229 Dell Way	\N	ILCRRDE	CA	22316	US	1	ERBOPAEXHI@dell.com	3691480229	4	7413274855818600	2009/05	user8546	password	56	100000	F
8547	KEQBJI	DYXECVLLDX	5767853438 Dell Way	\N	NUORYQV	ID	45917	US	1	DYXECVLLDX@dell.com	5767853438	3	8289102273527534	2008/05	user8547	password	27	60000	M
8548	TOYBRW	ZVZUGKXDYS	6033795992 Dell Way	\N	SQQJLXT	WV	46837	US	1	ZVZUGKXDYS@dell.com	6033795992	1	8138791900593788	2011/06	user8548	password	44	60000	F
8549	IMSELN	DFUODYMVQD	6284020008 Dell Way	\N	MZOJTNU	IN	59476	US	1	DFUODYMVQD@dell.com	6284020008	5	1390696000773459	2012/06	user8549	password	23	40000	M
8550	ULJIPP	CDSBQNRTAR	4982078464 Dell Way	\N	IKLWETK	RI	75495	US	1	CDSBQNRTAR@dell.com	4982078464	4	2362179809715599	2010/12	user8550	password	22	40000	F
8551	KPAASE	STVGLPGDXR	2686847875 Dell Way	\N	OUWIEQA	NJ	41564	US	1	STVGLPGDXR@dell.com	2686847875	1	4045463213697076	2009/06	user8551	password	74	80000	F
8552	URTZKN	UQZKXDIORC	7590562446 Dell Way	\N	KZHBAWK	HI	11362	US	1	UQZKXDIORC@dell.com	7590562446	3	5016722857020796	2010/02	user8552	password	53	40000	M
8553	GHFUCW	TMTWVIOXTO	5721477361 Dell Way	\N	EUPBEUC	WA	34407	US	1	TMTWVIOXTO@dell.com	5721477361	3	4680645571090281	2008/09	user8553	password	34	40000	M
8554	LACHUO	BQJJFHDTMX	8327647767 Dell Way	\N	INCDPAK	CT	51076	US	1	BQJJFHDTMX@dell.com	8327647767	1	2610793323256075	2008/05	user8554	password	30	60000	F
8555	GTFVUW	FDBMHVYFEM	9769246155 Dell Way	\N	HHCISFU	MT	42491	US	1	FDBMHVYFEM@dell.com	9769246155	3	7935559004079551	2008/01	user8555	password	33	60000	M
8556	LFNIKR	KXYFWDJILR	7792594790 Dell Way	\N	KUJQPWZ	ND	48723	US	1	KXYFWDJILR@dell.com	7792594790	4	4934534507803619	2012/02	user8556	password	31	60000	F
8557	STTJDR	IJNLTVXKGR	5841082086 Dell Way	\N	UWGRWVC	NH	57477	US	1	IJNLTVXKGR@dell.com	5841082086	3	6762036497704685	2011/12	user8557	password	89	60000	M
8558	TUWKCF	XOYTLJZDEW	4625415693 Dell Way	\N	KVSGYIT	MN	90988	US	1	XOYTLJZDEW@dell.com	4625415693	1	9029960464220496	2009/08	user8558	password	63	20000	F
8559	MNNSLB	RENAERFBCA	8897085438 Dell Way	\N	TIZCCLZ	MO	66058	US	1	RENAERFBCA@dell.com	8897085438	5	3092976946383715	2010/12	user8559	password	64	100000	M
8560	DRYFID	TJIKPJMPDV	8747138358 Dell Way	\N	OFXAFKQ	CA	33618	US	1	TJIKPJMPDV@dell.com	8747138358	3	3287413882091641	2010/07	user8560	password	74	80000	F
8561	SVPWOZ	EZOOMERHSX	1944222087 Dell Way	\N	FTDPJFW	HI	80063	US	1	EZOOMERHSX@dell.com	1944222087	4	4049825948197395	2012/05	user8561	password	60	60000	F
8562	ELTDQT	RFFVXNOUSH	3144485987 Dell Way	\N	XHRDDXX	IA	64392	US	1	RFFVXNOUSH@dell.com	3144485987	1	9588528127875180	2012/09	user8562	password	28	100000	F
8563	XDVQVA	WQXJFSBNQJ	6691030403 Dell Way	\N	ETMBRTR	VT	88100	US	1	WQXJFSBNQJ@dell.com	6691030403	4	6265186212025583	2011/09	user8563	password	73	80000	M
8564	PIQPEH	NONGPBXZFR	7005045124 Dell Way	\N	MHIFZGC	NJ	96936	US	1	NONGPBXZFR@dell.com	7005045124	2	7126392334233970	2010/01	user8564	password	56	20000	F
8565	EPOMDC	ZKSAHRGYEO	2542280966 Dell Way	\N	HJNNLDM	CT	56961	US	1	ZKSAHRGYEO@dell.com	2542280966	3	6268287394661457	2011/07	user8565	password	88	100000	F
8566	NIIQIS	JIZBPYFDFO	9285310052 Dell Way	\N	RTAVGDI	MD	71813	US	1	JIZBPYFDFO@dell.com	9285310052	1	3183100803755224	2012/12	user8566	password	48	60000	F
8567	SBPLLY	KMOIRSOGJI	4181608987 Dell Way	\N	HFOLNYC	MN	15161	US	1	KMOIRSOGJI@dell.com	4181608987	2	1181019130628556	2011/10	user8567	password	40	60000	M
8568	YXHXIT	LRLDGSNOZT	2169910350 Dell Way	\N	CKGBNSC	VA	15424	US	1	LRLDGSNOZT@dell.com	2169910350	4	8486882540863008	2010/02	user8568	password	67	40000	F
8569	YGJSSB	EWHXKVWDYH	1061853600 Dell Way	\N	KZVCCSE	HI	43569	US	1	EWHXKVWDYH@dell.com	1061853600	4	5648203221149743	2011/01	user8569	password	59	80000	F
8570	YJAANW	HKHDHKBPUA	1439614547 Dell Way	\N	LXCECIN	CO	98582	US	1	HKHDHKBPUA@dell.com	1439614547	4	1182041903026402	2011/06	user8570	password	41	60000	M
8571	IPIFWS	MZAXAQSBBP	5288157983 Dell Way	\N	DGSMTVL	SD	64131	US	1	MZAXAQSBBP@dell.com	5288157983	3	1233566316775977	2011/01	user8571	password	77	20000	M
8572	DIMWUL	WSMNKNPARV	2406764841 Dell Way	\N	SDPNPKD	AZ	85023	US	1	WSMNKNPARV@dell.com	2406764841	5	8635423376690597	2012/12	user8572	password	50	20000	F
8573	XYDJVV	VIFJYFBTYE	4700493460 Dell Way	\N	ILUSPWO	OR	76542	US	1	VIFJYFBTYE@dell.com	4700493460	4	7644969686400146	2012/10	user8573	password	22	80000	M
8574	FDOAZX	GJVLKOJOXV	7340586262 Dell Way	\N	JQLFFEZ	NH	89602	US	1	GJVLKOJOXV@dell.com	7340586262	3	7127986861392856	2011/03	user8574	password	48	100000	F
8575	ZZIWGS	SRCGBQEXAU	1780368244 Dell Way	\N	JGZNFPK	VT	15557	US	1	SRCGBQEXAU@dell.com	1780368244	4	3645236481912434	2010/08	user8575	password	66	60000	M
8576	AJWSBO	UIQLMOLHXR	3006660928 Dell Way	\N	GLXWVVY	WA	54366	US	1	UIQLMOLHXR@dell.com	3006660928	3	2304786856751889	2012/11	user8576	password	75	100000	F
8577	RPHGJP	XUCLGJJYQU	3573422426 Dell Way	\N	VMQQKOD	NM	98202	US	1	XUCLGJJYQU@dell.com	3573422426	3	8957356213591994	2008/05	user8577	password	28	80000	F
8578	LAJAXE	DJLMSJCNFP	6040782882 Dell Way	\N	DWASZQR	IL	25343	US	1	DJLMSJCNFP@dell.com	6040782882	2	6280073368921877	2011/02	user8578	password	61	20000	F
8579	ZEADHJ	OTBYWPDLSZ	8572693649 Dell Way	\N	LKZCCGG	NV	66435	US	1	OTBYWPDLSZ@dell.com	8572693649	2	7643846201244742	2010/06	user8579	password	80	60000	M
8580	WOYFDS	HBOWFZPFLA	8387874888 Dell Way	\N	ENCLTTC	NH	20865	US	1	HBOWFZPFLA@dell.com	8387874888	1	6449643942993135	2011/06	user8580	password	36	60000	M
8581	FTCXAE	LXJLMOWMTJ	1895020932 Dell Way	\N	PFDJHTM	CO	79488	US	1	LXJLMOWMTJ@dell.com	1895020932	4	2919136609882116	2009/04	user8581	password	32	60000	F
8582	HLBMXY	VILKEYDOOI	4487387969 Dell Way	\N	RXQKKTE	MT	56292	US	1	VILKEYDOOI@dell.com	4487387969	5	8364574203733356	2010/06	user8582	password	80	100000	M
8583	YJUXFC	IPHGTVVCMS	8052298509 Dell Way	\N	SXDLBRZ	MI	57210	US	1	IPHGTVVCMS@dell.com	8052298509	1	9554557137656958	2011/12	user8583	password	78	60000	F
8584	PLMSUC	ZBVUWXHPQE	8838246662 Dell Way	\N	TCFKBRX	TN	73766	US	1	ZBVUWXHPQE@dell.com	8838246662	3	6777620270382614	2011/01	user8584	password	86	40000	M
8585	LZHNYJ	JTFHAVXEOZ	4752026461 Dell Way	\N	KYABWWU	PA	40555	US	1	JTFHAVXEOZ@dell.com	4752026461	3	4480914139188826	2009/09	user8585	password	83	80000	M
8586	EISOSL	TZLPXQDXAC	5636735566 Dell Way	\N	YCZUWSD	IL	23918	US	1	TZLPXQDXAC@dell.com	5636735566	4	9060373303014786	2010/06	user8586	password	63	60000	M
8587	IDMTXL	FMJVPGWSEZ	4864556110 Dell Way	\N	RYVJCCN	NH	77927	US	1	FMJVPGWSEZ@dell.com	4864556110	1	2756681039463728	2008/08	user8587	password	88	40000	M
8588	LDQXJD	GFTMBLRACP	9271577125 Dell Way	\N	WMRZAHS	MI	35937	US	1	GFTMBLRACP@dell.com	9271577125	3	9024588531814516	2012/11	user8588	password	64	40000	F
8589	HGJKMO	DZQOQRRGNE	4602093421 Dell Way	\N	YMEFFQN	CT	21929	US	1	DZQOQRRGNE@dell.com	4602093421	1	1149010746274143	2008/05	user8589	password	20	40000	M
8590	KSBZVB	QKSHCYUGWH	2869052429 Dell Way	\N	LCNBPQE	AK	69024	US	1	QKSHCYUGWH@dell.com	2869052429	1	1070503448136150	2009/05	user8590	password	61	80000	F
8591	RQXSGI	KOLJIRGQCJ	4954074253 Dell Way	\N	DEYUJZL	ND	11556	US	1	KOLJIRGQCJ@dell.com	4954074253	5	4393248517997563	2008/06	user8591	password	50	80000	F
8592	JLJSWX	DFGUMXXVAC	2242919241 Dell Way	\N	UVLTGAT	NY	84366	US	1	DFGUMXXVAC@dell.com	2242919241	4	3688718488905579	2010/06	user8592	password	48	100000	M
8593	URRSUX	ZPJWNEXPYS	2613721562 Dell Way	\N	BSZBLQW	NH	43069	US	1	ZPJWNEXPYS@dell.com	2613721562	1	8075982985086740	2010/02	user8593	password	64	40000	M
8594	ICPFBE	PXRUVHSOIL	3797197398 Dell Way	\N	NJXEGMN	MI	69800	US	1	PXRUVHSOIL@dell.com	3797197398	1	8232854389119894	2012/05	user8594	password	61	40000	F
8595	EMOJCM	BWHIPVRAIB	8753314316 Dell Way	\N	XNHKATB	KY	79452	US	1	BWHIPVRAIB@dell.com	8753314316	2	2652727955486625	2010/07	user8595	password	67	80000	F
8596	GADSBZ	ZKPVBQECNR	1775225875 Dell Way	\N	KYSDZBX	TX	38618	US	1	ZKPVBQECNR@dell.com	1775225875	2	8750291056465358	2011/12	user8596	password	83	100000	M
8597	ASAARK	QNMGSOUJYS	3663886664 Dell Way	\N	CCSDZOL	AZ	87999	US	1	QNMGSOUJYS@dell.com	3663886664	5	8434779025614262	2008/11	user8597	password	75	40000	M
8598	VGFGWT	SCLHXVFPXI	6082385365 Dell Way	\N	IAHWLJT	PA	28904	US	1	SCLHXVFPXI@dell.com	6082385365	5	1428345020394772	2009/02	user8598	password	60	20000	F
8599	VKHODK	AKHVQXTYFT	8810263623 Dell Way	\N	GCFPVYV	MD	91127	US	1	AKHVQXTYFT@dell.com	8810263623	4	1589509073644876	2010/12	user8599	password	52	40000	F
8600	TVMDVX	LRNIKMOESQ	3705512780 Dell Way	\N	JIMIDWG	AK	66389	US	1	LRNIKMOESQ@dell.com	3705512780	3	6052016812376679	2011/09	user8600	password	84	60000	M
8601	KRJHCB	VLMHZQZQAH	2471952327 Dell Way	\N	CILZOLP	UT	90418	US	1	VLMHZQZQAH@dell.com	2471952327	4	6493185658473522	2008/03	user8601	password	29	60000	M
8602	NUYPPJ	BWJRWZRECA	5880987938 Dell Way	\N	PBPARMY	TN	21151	US	1	BWJRWZRECA@dell.com	5880987938	5	3704982063267380	2011/05	user8602	password	28	40000	F
8603	CVTLWQ	VNMUFRWGGY	7676322425 Dell Way	\N	VHPIFLL	RI	39743	US	1	VNMUFRWGGY@dell.com	7676322425	3	7474085575900973	2012/09	user8603	password	82	100000	M
8604	QLJHGX	UADLXJRVFZ	9205076962 Dell Way	\N	LNFWZZF	OK	50183	US	1	UADLXJRVFZ@dell.com	9205076962	3	2241019223351031	2011/07	user8604	password	64	60000	M
8605	ASGXMG	AYEKPAPPLD	4377784250 Dell Way	\N	VHCUMVG	MD	47427	US	1	AYEKPAPPLD@dell.com	4377784250	2	9877474257256836	2008/08	user8605	password	89	20000	F
8606	FXWMYU	RIKRYZCCUK	4643582073 Dell Way	\N	EPXAVIK	GA	58171	US	1	RIKRYZCCUK@dell.com	4643582073	2	2655269541312009	2009/03	user8606	password	58	80000	F
8607	KCCFTL	PKKPNMKYRZ	9156964251 Dell Way	\N	WRVECAS	MO	32240	US	1	PKKPNMKYRZ@dell.com	9156964251	5	5401960093062371	2010/06	user8607	password	65	100000	M
8608	TBIFRT	PGHCQGTQCL	2778437974 Dell Way	\N	LHNLAZS	VT	89023	US	1	PGHCQGTQCL@dell.com	2778437974	2	4328097304794937	2012/03	user8608	password	88	80000	F
8609	HVYBLF	JOVPHMRSXZ	5275877489 Dell Way	\N	FJZFBXC	ID	33225	US	1	JOVPHMRSXZ@dell.com	5275877489	1	5466094690375030	2010/09	user8609	password	76	80000	M
8610	TVAZEO	VTWHLOELUN	1496637221 Dell Way	\N	KAPHDWO	NH	98536	US	1	VTWHLOELUN@dell.com	1496637221	1	7448920106049628	2012/10	user8610	password	38	80000	M
8611	HPTVKN	RRZGVLBJVC	5720626376 Dell Way	\N	YDFVSVV	PA	87450	US	1	RRZGVLBJVC@dell.com	5720626376	4	6788665527477861	2012/03	user8611	password	35	20000	M
8612	AYFNQW	NXRYYBUAAY	6166786587 Dell Way	\N	GVQBQKY	DE	10314	US	1	NXRYYBUAAY@dell.com	6166786587	5	3050348720047623	2012/01	user8612	password	20	100000	F
8613	FJQCXN	TVMVQNVPUQ	8656239594 Dell Way	\N	FVGQULQ	KY	44823	US	1	TVMVQNVPUQ@dell.com	8656239594	1	5032169908285141	2012/12	user8613	password	50	20000	F
8614	CFFQZB	CUSQPHKFNG	7707283801 Dell Way	\N	MDAXTJH	NH	57323	US	1	CUSQPHKFNG@dell.com	7707283801	3	5496865323279053	2008/08	user8614	password	78	40000	M
8615	AXTCAO	UQDCBIPHVS	7233809507 Dell Way	\N	HTMRACF	RI	61272	US	1	UQDCBIPHVS@dell.com	7233809507	5	2548458903096616	2010/04	user8615	password	88	60000	F
8616	TQEHLV	KNWTCDOVLI	2218085280 Dell Way	\N	ICIKHDZ	WY	19528	US	1	KNWTCDOVLI@dell.com	2218085280	3	4318861009087414	2008/01	user8616	password	57	100000	M
8617	SDENNR	KGUNVQZDYB	1798475849 Dell Way	\N	MIJPHJS	MI	88708	US	1	KGUNVQZDYB@dell.com	1798475849	3	9462757058907300	2011/05	user8617	password	65	40000	M
8618	VWAMGH	HUCXTGWVTE	4392080495 Dell Way	\N	FJMOBXL	DE	50513	US	1	HUCXTGWVTE@dell.com	4392080495	4	8501599205657841	2008/02	user8618	password	42	100000	M
8619	JIGQPB	TNUZJQTOVC	2892149744 Dell Way	\N	AKEYVIJ	GA	19281	US	1	TNUZJQTOVC@dell.com	2892149744	2	3064972651656717	2010/01	user8619	password	34	100000	F
8620	MOAOHN	IHWZAKUCLE	9233101013 Dell Way	\N	GJAPTFR	WI	50355	US	1	IHWZAKUCLE@dell.com	9233101013	3	5701051715761424	2008/05	user8620	password	85	80000	M
8621	YEFLNN	IMNTHQEMXN	7000710633 Dell Way	\N	MMGSEFD	AZ	73457	US	1	IMNTHQEMXN@dell.com	7000710633	2	1891919833607971	2010/11	user8621	password	20	60000	F
8622	GZOTHA	HBIXFUUTGH	1312175111 Dell Way	\N	AYLFCNY	RI	77378	US	1	HBIXFUUTGH@dell.com	1312175111	2	6437902288045735	2008/11	user8622	password	64	40000	M
8623	EBDFJE	NGKHBEOJEN	7206335603 Dell Way	\N	VKPIIJC	LA	75158	US	1	NGKHBEOJEN@dell.com	7206335603	3	6418678053654731	2009/10	user8623	password	50	60000	M
8624	PSEUFL	FMNJBXNOSX	8562246507 Dell Way	\N	DBGNDQG	SD	16068	US	1	FMNJBXNOSX@dell.com	8562246507	1	8424065436236561	2009/08	user8624	password	66	100000	F
8625	WROHWA	VFCSTQLRUM	4962900900 Dell Way	\N	XHPONKQ	LA	59445	US	1	VFCSTQLRUM@dell.com	4962900900	4	2645415956154465	2008/07	user8625	password	55	100000	F
8626	BGCCCI	EVBUGSOSQW	5110247390 Dell Way	\N	IFJSVTH	IA	45569	US	1	EVBUGSOSQW@dell.com	5110247390	2	9485786203760656	2012/04	user8626	password	30	20000	M
8627	HCQPHL	RBRKQKBMSG	9503113982 Dell Way	\N	WLBPSHA	DE	69065	US	1	RBRKQKBMSG@dell.com	9503113982	1	9555726564023644	2008/02	user8627	password	53	40000	F
8628	DZOORQ	FBGQCTIIQT	3768235466 Dell Way	\N	KGLSGPJ	FL	76765	US	1	FBGQCTIIQT@dell.com	3768235466	2	9063075729180128	2011/09	user8628	password	29	100000	M
8629	SMIISK	PIMJQVAKFG	1802202288 Dell Way	\N	VYMLHRF	NH	95840	US	1	PIMJQVAKFG@dell.com	1802202288	2	6777326736133546	2009/04	user8629	password	41	100000	M
8630	RIMBXU	NHKJHUPNQN	3267005938 Dell Way	\N	ACURHJP	LA	78890	US	1	NHKJHUPNQN@dell.com	3267005938	4	1620582062751054	2010/08	user8630	password	79	40000	M
8631	HHVBUC	MEKHTYXGYZ	3295779696 Dell Way	\N	BPHKEQE	MI	33364	US	1	MEKHTYXGYZ@dell.com	3295779696	1	8625752890016884	2008/03	user8631	password	72	40000	M
8632	OMIRYM	BFFZDMXDNM	2312614209 Dell Way	\N	KYRBDDH	MA	23674	US	1	BFFZDMXDNM@dell.com	2312614209	3	4551665658131242	2012/11	user8632	password	84	60000	F
8633	FDHSEN	YEQKCUYPEW	9695899800 Dell Way	\N	HFAKNKO	NV	88283	US	1	YEQKCUYPEW@dell.com	9695899800	3	7669303533155472	2012/12	user8633	password	23	20000	F
8634	JUHWSM	NDOHBDLYLR	9563840900 Dell Way	\N	YWEILVF	MD	42478	US	1	NDOHBDLYLR@dell.com	9563840900	2	4178893703501672	2008/05	user8634	password	51	40000	F
8635	TGXFUA	UBCYNBJEZF	8893367909 Dell Way	\N	IIQEOBN	MS	38222	US	1	UBCYNBJEZF@dell.com	8893367909	3	7106472913175822	2009/11	user8635	password	79	20000	F
8636	TIZTCA	WBOXKSXQBF	4005378643 Dell Way	\N	HFTITGR	NM	80300	US	1	WBOXKSXQBF@dell.com	4005378643	5	7274422171525658	2008/01	user8636	password	82	100000	F
8637	VRMWON	KLYDIPFOXL	1646198173 Dell Way	\N	IFEPXVJ	HI	80364	US	1	KLYDIPFOXL@dell.com	1646198173	2	8636940874159337	2012/04	user8637	password	35	80000	M
8638	TROGBZ	FFIVKXSVGY	5182395095 Dell Way	\N	AVVVFAQ	IL	48995	US	1	FFIVKXSVGY@dell.com	5182395095	2	7707098808605225	2011/01	user8638	password	71	60000	M
8639	HSTGXZ	PTJMLFTJGO	4545262600 Dell Way	\N	EBUFRBQ	DC	34636	US	1	PTJMLFTJGO@dell.com	4545262600	5	3645864529535174	2008/04	user8639	password	89	60000	M
8640	TRXSHQ	CUBHNLNBPP	5121694497 Dell Way	\N	VVHXMLE	UT	38345	US	1	CUBHNLNBPP@dell.com	5121694497	1	6437923381105066	2010/05	user8640	password	61	20000	F
8641	NWJDYD	FGQQUSGKOC	1627619391 Dell Way	\N	SLODPLM	AZ	50188	US	1	FGQQUSGKOC@dell.com	1627619391	3	8746610864531250	2011/09	user8641	password	87	20000	M
8642	IHMLNS	CENVLXJNPV	8579935072 Dell Way	\N	CTLNFNZ	IL	11379	US	1	CENVLXJNPV@dell.com	8579935072	5	7208973383996636	2011/02	user8642	password	34	20000	F
8643	SOYLQC	YLNWVBLQDF	3602278477 Dell Way	\N	BRKPRRP	MS	66270	US	1	YLNWVBLQDF@dell.com	3602278477	2	7587255476042629	2010/05	user8643	password	28	40000	M
8644	CSPERB	SNWUZNYEPP	6505577640 Dell Way	\N	OEHGUUW	AZ	17551	US	1	SNWUZNYEPP@dell.com	6505577640	3	5408569043502212	2011/10	user8644	password	50	100000	M
8645	BAECTR	ZNRMLVCBKG	7038585448 Dell Way	\N	IQACNCE	DC	71620	US	1	ZNRMLVCBKG@dell.com	7038585448	5	5605760276783258	2008/09	user8645	password	20	20000	M
8646	FHMXGZ	OTLJVMUCUL	4886596119 Dell Way	\N	DWZGBCX	OR	10404	US	1	OTLJVMUCUL@dell.com	4886596119	5	7668746509589256	2010/01	user8646	password	54	80000	F
8647	ZOOZDH	KNDXHGRSJO	5823109593 Dell Way	\N	RPQUNJU	WV	28628	US	1	KNDXHGRSJO@dell.com	5823109593	3	3081209508702159	2008/02	user8647	password	56	20000	M
8648	CAUKLI	NIPUZIEOAU	9555786771 Dell Way	\N	EUINPHS	CT	73798	US	1	NIPUZIEOAU@dell.com	9555786771	1	8306506830267609	2010/03	user8648	password	53	60000	F
8649	HZQPMY	FHXNLLOFPJ	3939589588 Dell Way	\N	NDYUVCN	SC	33832	US	1	FHXNLLOFPJ@dell.com	3939589588	2	5080773643683642	2012/11	user8649	password	65	20000	M
8650	GSHFXP	CLAOZGEJUH	2121728811 Dell Way	\N	IPDKCYR	ME	30250	US	1	CLAOZGEJUH@dell.com	2121728811	2	1644657118245959	2011/04	user8650	password	82	20000	F
8651	EGYUIJ	UXJBCSVKAK	8060623742 Dell Way	\N	OLNMCYS	IA	24355	US	1	UXJBCSVKAK@dell.com	8060623742	1	5425501992460341	2011/01	user8651	password	56	100000	F
8652	LQQVLN	FMQYIAZSOK	8190056357 Dell Way	\N	FBNDTTH	NC	79217	US	1	FMQYIAZSOK@dell.com	8190056357	2	8354925095103682	2009/01	user8652	password	25	80000	M
8653	SQCGVP	WTXXSQLDWM	1070947634 Dell Way	\N	RZFKHTE	CO	96692	US	1	WTXXSQLDWM@dell.com	1070947634	3	1140339524950832	2008/03	user8653	password	68	100000	M
8654	UCQKZK	IWDYHHUTYU	7581288529 Dell Way	\N	ZJCTOES	ND	65034	US	1	IWDYHHUTYU@dell.com	7581288529	4	8343538376037032	2010/07	user8654	password	64	40000	M
8655	HQOSYK	VXSDRLBLLL	2414352278 Dell Way	\N	OFZSXOI	NM	30382	US	1	VXSDRLBLLL@dell.com	2414352278	1	7560843214858324	2011/04	user8655	password	41	20000	M
8656	WUXHQU	ZTLLVXWGLC	7827279906 Dell Way	\N	GEZUNQA	NY	74311	US	1	ZTLLVXWGLC@dell.com	7827279906	3	1193119723815470	2008/07	user8656	password	88	100000	F
8657	WGZQFS	CQOANVMPBQ	9869791098 Dell Way	\N	PWEGXWZ	NV	40427	US	1	CQOANVMPBQ@dell.com	9869791098	4	9110166535247118	2012/09	user8657	password	36	100000	M
8658	FLDYOU	NOIIAYJRNG	9675434021 Dell Way	\N	WUDSTUB	OR	55262	US	1	NOIIAYJRNG@dell.com	9675434021	4	2665436835959554	2009/07	user8658	password	25	60000	M
8659	GKNAXC	IFDHPUUVRP	4872903505 Dell Way	\N	ZKITLBG	ME	78657	US	1	IFDHPUUVRP@dell.com	4872903505	4	3368760101497173	2010/01	user8659	password	34	80000	F
8660	TUJVDP	YKFTFBKVAV	3254613864 Dell Way	\N	DTHFASZ	MI	40334	US	1	YKFTFBKVAV@dell.com	3254613864	5	4737976715900004	2010/09	user8660	password	83	40000	M
8661	HARWYC	CSIDDDEYHY	6969177636 Dell Way	\N	FMYXMJG	OR	41056	US	1	CSIDDDEYHY@dell.com	6969177636	2	1834614681079983	2010/05	user8661	password	64	100000	F
8662	ISKLVC	TYFWDEDBJQ	8210736080 Dell Way	\N	ZHDJNWS	FL	17387	US	1	TYFWDEDBJQ@dell.com	8210736080	4	5456453959457577	2010/07	user8662	password	85	80000	F
8663	IFCLYB	QVEUZGEQFL	2981644082 Dell Way	\N	TPZQHES	CO	92714	US	1	QVEUZGEQFL@dell.com	2981644082	3	5443058743607253	2008/04	user8663	password	75	60000	M
8664	WXMYOH	CJHJNXOZRE	5928313190 Dell Way	\N	ZILDBOB	ID	18821	US	1	CJHJNXOZRE@dell.com	5928313190	3	4701582127716392	2009/11	user8664	password	85	40000	M
8665	KDJSGS	ZPFXEFPIEX	8716628113 Dell Way	\N	UHZJJGL	VT	70279	US	1	ZPFXEFPIEX@dell.com	8716628113	2	6137690139003099	2011/06	user8665	password	45	20000	M
8666	SXVLWL	RUPWJYBHSJ	7780837960 Dell Way	\N	GBSNNQE	MA	86702	US	1	RUPWJYBHSJ@dell.com	7780837960	1	3655339956749231	2008/05	user8666	password	81	100000	F
8667	SHDDYX	TVHRWPKFWL	7039413027 Dell Way	\N	XJZNOJJ	IN	55810	US	1	TVHRWPKFWL@dell.com	7039413027	3	8711327909491957	2010/04	user8667	password	25	40000	M
8668	FKMDDI	KUEZEJVQHF	4018100356 Dell Way	\N	QUTZEAM	TX	50671	US	1	KUEZEJVQHF@dell.com	4018100356	2	7545425885822625	2010/08	user8668	password	38	80000	F
8669	UUECEY	GEDQAUXFKS	2242140759 Dell Way	\N	YJWYWSK	FL	18943	US	1	GEDQAUXFKS@dell.com	2242140759	4	7702615093905479	2010/04	user8669	password	75	40000	F
8670	YHGXOK	BEKWCPGUNQ	2790777506 Dell Way	\N	QMNJXSL	AL	39371	US	1	BEKWCPGUNQ@dell.com	2790777506	3	6434821976348758	2012/09	user8670	password	65	100000	M
8671	XVNHXS	STVHAPVQGI	7979069652 Dell Way	\N	DPFVBGE	IA	74702	US	1	STVHAPVQGI@dell.com	7979069652	2	4491680383682251	2010/02	user8671	password	44	40000	M
8672	XPXQIQ	LPQALHHTKW	4104790969 Dell Way	\N	ZGXGLEY	GA	45656	US	1	LPQALHHTKW@dell.com	4104790969	4	5984853510744870	2011/12	user8672	password	58	80000	M
8673	LGXBRN	SSYZZSKWRR	8972641468 Dell Way	\N	TXCYWII	HI	97234	US	1	SSYZZSKWRR@dell.com	8972641468	5	9423593265935780	2010/07	user8673	password	55	100000	M
8674	KYLXQD	WQDOAZGRTE	1198151874 Dell Way	\N	URBDAHC	VA	28106	US	1	WQDOAZGRTE@dell.com	1198151874	2	7635792369954289	2010/03	user8674	password	54	100000	F
8675	YWUCSK	FGLENCYRXP	9339766346 Dell Way	\N	SAQZCNE	CT	86930	US	1	FGLENCYRXP@dell.com	9339766346	4	1542661573272198	2010/08	user8675	password	33	40000	F
8676	ZMEKRL	VWYYUQVKIW	5264113995 Dell Way	\N	AIZONCK	MI	79116	US	1	VWYYUQVKIW@dell.com	5264113995	5	4418906697072089	2011/03	user8676	password	79	80000	M
8677	ACKLXG	KVBARMJONR	7921908412 Dell Way	\N	NBFQMQK	WI	55932	US	1	KVBARMJONR@dell.com	7921908412	4	7817262275144459	2011/04	user8677	password	52	80000	F
8678	WCHCMD	ENVQWJDOXE	6979256619 Dell Way	\N	TNRKXPX	NV	31633	US	1	ENVQWJDOXE@dell.com	6979256619	2	5904927370138467	2008/11	user8678	password	85	100000	F
8679	FCNJGA	EXXNALKFFY	3446181511 Dell Way	\N	WPVMNMS	FL	79049	US	1	EXXNALKFFY@dell.com	3446181511	2	7144443680532277	2008/04	user8679	password	68	60000	F
8680	FTRFYO	DLOOWUUURK	5970738130 Dell Way	\N	QDYCWDW	DC	49082	US	1	DLOOWUUURK@dell.com	5970738130	2	7668921888340265	2009/10	user8680	password	28	60000	M
8681	VRLJUX	YIUTDOKOEO	7920212397 Dell Way	\N	MHKPEOA	OK	91714	US	1	YIUTDOKOEO@dell.com	7920212397	5	7026788825169206	2012/05	user8681	password	32	80000	F
8682	QCVOBE	IUHXEWCSIK	3387365462 Dell Way	\N	DYORYHP	OK	31163	US	1	IUHXEWCSIK@dell.com	3387365462	4	6684267054311932	2010/05	user8682	password	67	20000	F
8683	NRNRZH	ZXLVAEEKHC	1913572892 Dell Way	\N	YZAGOTM	TN	44854	US	1	ZXLVAEEKHC@dell.com	1913572892	2	7757153929211200	2011/05	user8683	password	33	40000	F
8684	SYBZYY	LTYPXJWZIW	9134280700 Dell Way	\N	AOKTAGD	CO	58506	US	1	LTYPXJWZIW@dell.com	9134280700	5	9416735469363632	2008/03	user8684	password	90	100000	F
8685	AVBZGV	YWSHTSPPSD	7566454350 Dell Way	\N	AMEGQHU	NC	25804	US	1	YWSHTSPPSD@dell.com	7566454350	4	4245613518636674	2011/06	user8685	password	54	80000	F
8686	OTOJRL	CZEUOTNSTZ	7212452623 Dell Way	\N	WAQEVEI	NC	82951	US	1	CZEUOTNSTZ@dell.com	7212452623	2	3636428903788328	2008/01	user8686	password	61	80000	M
8687	EDLPFL	TAZNNSHMPI	4431702238 Dell Way	\N	DTDHBRC	RI	94601	US	1	TAZNNSHMPI@dell.com	4431702238	5	9670199896208944	2012/09	user8687	password	71	20000	M
8688	ETBPNB	PAOIIBXQER	3979024368 Dell Way	\N	TLTLOMJ	WA	50976	US	1	PAOIIBXQER@dell.com	3979024368	5	2448635264299810	2008/01	user8688	password	90	40000	M
8689	AWHCLI	QTQSRGXIAJ	2588095443 Dell Way	\N	BLXOVVA	DC	75922	US	1	QTQSRGXIAJ@dell.com	2588095443	2	8076075768563897	2008/06	user8689	password	60	40000	F
8690	WHTFYN	VQECNNDWOO	2035250185 Dell Way	\N	UDJPDNI	KS	74747	US	1	VQECNNDWOO@dell.com	2035250185	3	2497968778479844	2011/09	user8690	password	51	60000	M
8691	FUXSPO	WSBKVYYKSC	2423190899 Dell Way	\N	TIFHQNZ	PA	12003	US	1	WSBKVYYKSC@dell.com	2423190899	3	7368823205120862	2011/01	user8691	password	67	100000	M
8692	PNKDKC	EUYDTIWVCE	3858982237 Dell Way	\N	BJVPJOP	MS	11999	US	1	EUYDTIWVCE@dell.com	3858982237	1	1428792190738022	2012/12	user8692	password	79	60000	F
8693	GSWJXR	HALQWGSBHB	5465305144 Dell Way	\N	WXKLNXL	SD	13665	US	1	HALQWGSBHB@dell.com	5465305144	5	9849659896455706	2009/05	user8693	password	50	60000	F
8694	IYZAGA	LXWRPYZRUW	1293140207 Dell Way	\N	CFKARFB	DC	12232	US	1	LXWRPYZRUW@dell.com	1293140207	3	4754074856638909	2010/02	user8694	password	54	100000	F
8695	MVIMGF	JYVHYMBVPH	8657291037 Dell Way	\N	FPYKQCL	NY	61906	US	1	JYVHYMBVPH@dell.com	8657291037	1	6966821404173971	2009/12	user8695	password	69	100000	M
8696	AIBFRZ	BZXNASCIXS	6098987916 Dell Way	\N	GIJITAX	NJ	25949	US	1	BZXNASCIXS@dell.com	6098987916	5	2344769905321300	2009/10	user8696	password	86	40000	F
8697	ZNVZOU	WCVPFDNXKV	6446448551 Dell Way	\N	GSPHQFL	FL	27531	US	1	WCVPFDNXKV@dell.com	6446448551	3	1062834342010319	2010/10	user8697	password	28	60000	F
8698	ZMVTJX	PYDSMACIHV	4128077988 Dell Way	\N	XOLDAQI	NM	17578	US	1	PYDSMACIHV@dell.com	4128077988	1	8519105707295240	2010/09	user8698	password	25	60000	F
8699	YFOWUN	ZNAAQIIMGX	5066902109 Dell Way	\N	XJXNSOQ	AZ	76132	US	1	ZNAAQIIMGX@dell.com	5066902109	3	5028439952991903	2010/01	user8699	password	65	60000	F
8700	FIATIO	TIEBQQINOS	2649540221 Dell Way	\N	LCKASMT	DC	14837	US	1	TIEBQQINOS@dell.com	2649540221	4	1633041103836149	2012/03	user8700	password	39	20000	M
8701	IVWWOE	AQVRYJFQVH	7161748635 Dell Way	\N	BVAOODP	OR	86791	US	1	AQVRYJFQVH@dell.com	7161748635	3	1428455929737538	2012/08	user8701	password	60	40000	F
8702	LEAQFR	MWQVCHQKJM	5108065619 Dell Way	\N	KXAONTK	GA	39553	US	1	MWQVCHQKJM@dell.com	5108065619	1	9690189758781344	2008/06	user8702	password	48	60000	M
8703	LCVDPS	TKVBBFKNQI	6365517995 Dell Way	\N	OEWHPBQ	AR	34187	US	1	TKVBBFKNQI@dell.com	6365517995	1	7862562254071236	2008/07	user8703	password	48	60000	M
8704	GPGZJR	ULTAVGREVV	2157636834 Dell Way	\N	ACLCTMJ	KY	62924	US	1	ULTAVGREVV@dell.com	2157636834	2	2462212514132261	2010/10	user8704	password	79	100000	F
8705	CUVUPG	NPCUGGPCHS	8095722781 Dell Way	\N	OJLATUQ	UT	23511	US	1	NPCUGGPCHS@dell.com	8095722781	3	9829004795756192	2011/03	user8705	password	48	80000	M
8706	FNOMBE	OVLULNBDBL	5651591261 Dell Way	\N	PCEKTBN	MT	50736	US	1	OVLULNBDBL@dell.com	5651591261	1	6946337818168104	2012/11	user8706	password	65	20000	F
8707	FQMJEI	UZTIBXKNNN	8555974606 Dell Way	\N	RXGSKUE	WA	94536	US	1	UZTIBXKNNN@dell.com	8555974606	5	8626318241003902	2010/01	user8707	password	39	80000	M
8708	UCWCXV	WFXUQKHDCE	9747976853 Dell Way	\N	KUPEZND	SD	46768	US	1	WFXUQKHDCE@dell.com	9747976853	2	5012351862154901	2009/01	user8708	password	26	20000	F
8709	ZEZVAF	SVWCCAEHKZ	3401572243 Dell Way	\N	WPZKSUV	OH	19814	US	1	SVWCCAEHKZ@dell.com	3401572243	5	2097233566921204	2009/12	user8709	password	33	40000	F
8710	FEEKWA	GZCGEKREHG	2479728671 Dell Way	\N	DRZYNRB	RI	66011	US	1	GZCGEKREHG@dell.com	2479728671	1	6523571222554893	2009/07	user8710	password	73	60000	M
8711	YAOYHO	BNSLFWSMAK	4325356963 Dell Way	\N	LYXDZRT	DC	86301	US	1	BNSLFWSMAK@dell.com	4325356963	3	4236605579499155	2008/02	user8711	password	20	20000	F
8712	PAKDCY	WODSGQSRCR	5488157783 Dell Way	\N	PFQHZUD	KY	39756	US	1	WODSGQSRCR@dell.com	5488157783	3	5032592725008726	2010/07	user8712	password	59	20000	M
8713	ZHQXDE	AVLQODSGTY	5189970458 Dell Way	\N	XAXREGA	NV	73599	US	1	AVLQODSGTY@dell.com	5189970458	2	3229745650663972	2008/05	user8713	password	77	100000	M
8714	LXSQYO	CODGHJZGGA	4055900095 Dell Way	\N	DYEKYVC	ME	12986	US	1	CODGHJZGGA@dell.com	4055900095	3	4324584470130503	2008/06	user8714	password	89	80000	F
8715	SGHGJW	KPDTOKAONY	9729140680 Dell Way	\N	TXXOAIP	LA	79693	US	1	KPDTOKAONY@dell.com	9729140680	3	3066774236969650	2012/02	user8715	password	60	80000	F
8716	WXTSHI	WBXGBMUAFS	3102183955 Dell Way	\N	XUSFJBA	KY	61820	US	1	WBXGBMUAFS@dell.com	3102183955	2	7221708139404655	2012/12	user8716	password	22	80000	M
8717	UJDDFF	ALHMGHSYFM	9933637450 Dell Way	\N	RLWSLEH	NY	53360	US	1	ALHMGHSYFM@dell.com	9933637450	3	4770165298599750	2008/02	user8717	password	37	100000	M
8718	KZSQAE	XMKFFILRAW	6486087795 Dell Way	\N	NSHSAZE	AL	51949	US	1	XMKFFILRAW@dell.com	6486087795	1	6520896888338030	2012/12	user8718	password	26	40000	M
8719	VYXAWK	KBPTMHTJUM	7538381638 Dell Way	\N	RMNQROC	IN	65815	US	1	KBPTMHTJUM@dell.com	7538381638	1	5949226566590369	2012/06	user8719	password	51	80000	F
8720	JSGUDI	JXVQRFLEWY	4544197579 Dell Way	\N	RNPFQXV	KY	17308	US	1	JXVQRFLEWY@dell.com	4544197579	1	5974053633864970	2012/11	user8720	password	87	40000	M
8721	FZSOJP	KAGPLLLJCY	5606482616 Dell Way	\N	ZIOWEXY	ND	20690	US	1	KAGPLLLJCY@dell.com	5606482616	3	1026412516832351	2010/08	user8721	password	61	80000	M
8722	HGZXQZ	EFKPRUSPTA	3085954101 Dell Way	\N	EQFCPTF	CO	26001	US	1	EFKPRUSPTA@dell.com	3085954101	3	8308751181233675	2012/04	user8722	password	49	20000	M
8723	KADKFJ	VUAPMQJNVZ	5115933372 Dell Way	\N	SYPMERQ	MA	32484	US	1	VUAPMQJNVZ@dell.com	5115933372	2	5598047953564674	2012/04	user8723	password	19	40000	F
8724	ESONOI	NEVENIZNAX	5931781935 Dell Way	\N	CNBUDLA	NH	67779	US	1	NEVENIZNAX@dell.com	5931781935	3	9729152256157250	2010/10	user8724	password	41	80000	M
8725	WGCFTG	AXUJXIKULX	8931962420 Dell Way	\N	VFBHGRX	SD	24528	US	1	AXUJXIKULX@dell.com	8931962420	2	9788985633756966	2009/02	user8725	password	55	20000	F
8726	PHCWIA	RRXABRLZNR	8415484244 Dell Way	\N	AUYRSTW	NE	21957	US	1	RRXABRLZNR@dell.com	8415484244	4	3088581069838256	2009/11	user8726	password	59	100000	F
8727	RVLRND	POFHZEURFP	7725437775 Dell Way	\N	QWHJTWN	ND	70564	US	1	POFHZEURFP@dell.com	7725437775	5	5846513442695141	2009/11	user8727	password	68	100000	M
8728	DRFHGT	MNTQILWXBS	3692706749 Dell Way	\N	FLLCYAT	OH	91944	US	1	MNTQILWXBS@dell.com	3692706749	1	7843990219756962	2012/12	user8728	password	50	20000	M
8729	RKXKXK	ENTPJQRCVC	3304233956 Dell Way	\N	OYBPSTM	WY	79660	US	1	ENTPJQRCVC@dell.com	3304233956	5	7922298384830356	2011/02	user8729	password	48	40000	M
8730	IUKTYY	MOICFLYHZW	6829439945 Dell Way	\N	JPOCBOW	KS	58893	US	1	MOICFLYHZW@dell.com	6829439945	1	6874072611331940	2008/05	user8730	password	30	40000	F
8731	ODDNPR	VRWGQDGNMV	8664457832 Dell Way	\N	CPXRMFF	CT	33635	US	1	VRWGQDGNMV@dell.com	8664457832	1	6953822405077518	2008/08	user8731	password	79	60000	M
8732	YCHQYZ	MEQQKDDGFS	3552063816 Dell Way	\N	DWFJCIQ	WA	58103	US	1	MEQQKDDGFS@dell.com	3552063816	5	2103012164123356	2008/07	user8732	password	78	20000	M
8733	DSPCET	TUEWXKCQNZ	8487585652 Dell Way	\N	VXBENAS	SC	96503	US	1	TUEWXKCQNZ@dell.com	8487585652	5	5607900822069496	2011/12	user8733	password	30	80000	M
8734	TXWMQQ	RNOBPEPPAM	2298211928 Dell Way	\N	RFZRXUQ	OR	73205	US	1	RNOBPEPPAM@dell.com	2298211928	3	7276941222604365	2009/03	user8734	password	46	20000	F
8735	GOTWFG	LGWQVMQIDW	5384361654 Dell Way	\N	HUTCLNU	NE	91871	US	1	LGWQVMQIDW@dell.com	5384361654	5	1978191967587918	2012/12	user8735	password	33	20000	F
8736	YZRFLY	BBTNSCROJL	8516787159 Dell Way	\N	IMXVGMS	PA	41837	US	1	BBTNSCROJL@dell.com	8516787159	4	3605932962615043	2008/09	user8736	password	74	20000	M
8737	LFEJHF	DVXFMMPYUB	9433338167 Dell Way	\N	VPIHIBQ	DE	72131	US	1	DVXFMMPYUB@dell.com	9433338167	2	4810617096722126	2011/03	user8737	password	29	20000	F
8738	INSNRN	LWZYMXSNTI	1398775698 Dell Way	\N	WARYRVQ	NJ	14386	US	1	LWZYMXSNTI@dell.com	1398775698	2	3395364626776427	2008/06	user8738	password	68	60000	M
8739	KBQXNN	XLZVENOMJP	3767419589 Dell Way	\N	EIHZYXB	WV	30660	US	1	XLZVENOMJP@dell.com	3767419589	1	7338565180078150	2012/09	user8739	password	68	40000	M
8740	JHGWFR	WAWJOJTENB	3571589166 Dell Way	\N	LNAJOZP	TX	24284	US	1	WAWJOJTENB@dell.com	3571589166	5	8640337577555329	2012/03	user8740	password	60	40000	M
8741	VFTNBT	JLISENGGYT	3332266514 Dell Way	\N	GHHGWDK	DE	98711	US	1	JLISENGGYT@dell.com	3332266514	1	3065906676463783	2012/06	user8741	password	74	80000	M
8742	NFTHPE	QIJDOQBHXJ	9412866957 Dell Way	\N	PDGSOLS	SD	61901	US	1	QIJDOQBHXJ@dell.com	9412866957	4	1546123634558171	2011/05	user8742	password	72	40000	M
8743	MNDQDM	AGAQIINSXQ	1089777751 Dell Way	\N	YQFJIAY	ID	70275	US	1	AGAQIINSXQ@dell.com	1089777751	5	1110464196652174	2011/03	user8743	password	59	40000	M
8744	SWWEWD	ENLNADKRCA	6058455010 Dell Way	\N	WLJWKQO	ME	63767	US	1	ENLNADKRCA@dell.com	6058455010	1	8259322968311609	2008/05	user8744	password	57	100000	F
8745	KAENFR	ZSRCCIFDFR	5833103353 Dell Way	\N	NCBDQMS	GA	69127	US	1	ZSRCCIFDFR@dell.com	5833103353	2	1549213078338652	2008/02	user8745	password	42	60000	F
8746	NZJEYB	VBEEGIKXVM	2606735396 Dell Way	\N	ZZCLSID	IA	67761	US	1	VBEEGIKXVM@dell.com	2606735396	2	8242404180578888	2010/10	user8746	password	88	20000	M
8747	IETKAU	PFBXPZTBYS	9391207771 Dell Way	\N	EKKMNRD	OK	97301	US	1	PFBXPZTBYS@dell.com	9391207771	2	7784755984786899	2012/03	user8747	password	56	40000	F
8748	HQLBFQ	DDFCWHBPLM	4615094532 Dell Way	\N	AYARBSQ	AK	94162	US	1	DDFCWHBPLM@dell.com	4615094532	5	2646690604742616	2012/02	user8748	password	62	40000	M
8749	BHASKD	YNAFPQRBQQ	8949722248 Dell Way	\N	BISTZSS	LA	66679	US	1	YNAFPQRBQQ@dell.com	8949722248	2	8031032531522215	2010/07	user8749	password	59	60000	M
8750	PHFTFS	TLHJDJAUKI	6501227905 Dell Way	\N	MEHFXRV	RI	97817	US	1	TLHJDJAUKI@dell.com	6501227905	2	5336555821821094	2008/10	user8750	password	37	80000	F
8751	MNIEGT	MQWWRQHZDL	4911873282 Dell Way	\N	HIIZECY	RI	44036	US	1	MQWWRQHZDL@dell.com	4911873282	5	2833680248819291	2011/09	user8751	password	39	20000	F
8752	PJMJVD	GSUXZUALCJ	5192342030 Dell Way	\N	UBNWAIG	MN	34481	US	1	GSUXZUALCJ@dell.com	5192342030	1	1049145981669425	2011/04	user8752	password	35	40000	M
8753	TTNWZF	RWEMXPOHJQ	4513190916 Dell Way	\N	UGRCNDK	WY	36418	US	1	RWEMXPOHJQ@dell.com	4513190916	4	6584002301096917	2011/02	user8753	password	39	40000	M
8754	VGVAYS	FKPVYWEPRL	3836548287 Dell Way	\N	HUZKEZS	NE	74664	US	1	FKPVYWEPRL@dell.com	3836548287	2	8633069935254753	2011/07	user8754	password	69	60000	M
8755	OLTGRD	WMCTRSLCZF	6472992970 Dell Way	\N	CKKBCZT	MD	26625	US	1	WMCTRSLCZF@dell.com	6472992970	1	7867542600724847	2009/06	user8755	password	61	100000	M
8756	JDNMZA	PTRIETIKVS	7664913859 Dell Way	\N	VWUUQEZ	IA	25603	US	1	PTRIETIKVS@dell.com	7664913859	3	6447711444925517	2009/06	user8756	password	53	80000	M
8757	AEOAUH	RDMLLWHDRE	8528350250 Dell Way	\N	XMVBLBG	GA	66459	US	1	RDMLLWHDRE@dell.com	8528350250	3	1572575370315462	2009/03	user8757	password	63	40000	F
8758	EJFMBI	YNTVUWNYTA	5668558031 Dell Way	\N	TULVARL	UT	27558	US	1	YNTVUWNYTA@dell.com	5668558031	1	4706937204115093	2008/07	user8758	password	77	40000	M
8759	AUZITM	BPHXCGRCAL	8515647409 Dell Way	\N	OVMFHJL	SD	61018	US	1	BPHXCGRCAL@dell.com	8515647409	5	2007922980468720	2011/04	user8759	password	20	80000	F
8760	AZVNAL	UYNAPQABFW	6349380723 Dell Way	\N	OLEXWZM	OH	92721	US	1	UYNAPQABFW@dell.com	6349380723	2	2777220143005252	2011/12	user8760	password	38	80000	M
8761	DDZOXX	BYMSZNXVCI	1642058912 Dell Way	\N	ZZEYMWW	AZ	28724	US	1	BYMSZNXVCI@dell.com	1642058912	4	2735861171502620	2009/05	user8761	password	28	60000	F
8762	DAKACJ	NUIBRDDADC	5335392199 Dell Way	\N	FCPCZRH	AR	42705	US	1	NUIBRDDADC@dell.com	5335392199	2	7334252493921668	2011/11	user8762	password	31	80000	M
8763	PTYYGS	GHKKKLONQQ	8719588874 Dell Way	\N	DSPUAQE	MS	13685	US	1	GHKKKLONQQ@dell.com	8719588874	1	9098025838844480	2008/11	user8763	password	74	80000	M
8764	SOWLVE	WGPHUDYKGQ	6569818997 Dell Way	\N	ABRRFDS	AZ	33799	US	1	WGPHUDYKGQ@dell.com	6569818997	1	2115153166465461	2009/09	user8764	password	72	20000	F
8765	QODVKJ	KREOPOVGPW	4969184708 Dell Way	\N	XHCBZDI	NJ	33700	US	1	KREOPOVGPW@dell.com	4969184708	1	1089348066132515	2008/02	user8765	password	42	100000	M
8766	MQAWAS	APIPKOEHMM	8021762079 Dell Way	\N	JNMNVCU	IL	17979	US	1	APIPKOEHMM@dell.com	8021762079	3	2731778296176344	2008/04	user8766	password	78	60000	M
8767	WLXPLM	XAXLFEYRNL	5592429790 Dell Way	\N	DAHFUOI	NE	13331	US	1	XAXLFEYRNL@dell.com	5592429790	4	3783156134653837	2009/04	user8767	password	32	40000	M
8768	CUEPRE	NDKRCCFNFF	7680097982 Dell Way	\N	VLAKUPL	IL	36668	US	1	NDKRCCFNFF@dell.com	7680097982	4	6126020337920637	2012/11	user8768	password	38	20000	M
8769	LRIQEM	AWOCBCIHXU	7977023482 Dell Way	\N	HHOXTVF	MO	50437	US	1	AWOCBCIHXU@dell.com	7977023482	3	3604484678711742	2008/06	user8769	password	85	60000	F
8770	GCISDE	HFFJOMHIUO	4807439244 Dell Way	\N	WSIRXUD	NY	28742	US	1	HFFJOMHIUO@dell.com	4807439244	4	7135098323691637	2009/03	user8770	password	77	60000	F
8771	DIMHPR	NYGAFOUUKM	8100522506 Dell Way	\N	CCKXGBC	NV	82941	US	1	NYGAFOUUKM@dell.com	8100522506	1	1324992059729993	2011/08	user8771	password	45	80000	M
8772	VBNNOM	TOSIJMTWPV	2481461244 Dell Way	\N	GNBIPSD	MD	75967	US	1	TOSIJMTWPV@dell.com	2481461244	1	4000285849440843	2010/10	user8772	password	36	40000	M
8773	TXJGRY	YZHLSDBOKO	4905243364 Dell Way	\N	QSEJVOC	WY	63014	US	1	YZHLSDBOKO@dell.com	4905243364	3	4161564730573446	2011/11	user8773	password	29	60000	M
8774	NSMMQM	UCFXDUHRKA	4300247211 Dell Way	\N	WUVLWVA	KS	43411	US	1	UCFXDUHRKA@dell.com	4300247211	1	3525775628164411	2010/06	user8774	password	24	20000	F
8775	POUBIW	GGZANRLONF	8862667035 Dell Way	\N	KYCFZLP	KY	48239	US	1	GGZANRLONF@dell.com	8862667035	5	8938537307083608	2012/12	user8775	password	20	60000	F
8776	VPUSWA	SXOJJCXPMW	4756936681 Dell Way	\N	RSVCIEN	FL	12526	US	1	SXOJJCXPMW@dell.com	4756936681	1	9653007665649056	2010/09	user8776	password	50	40000	F
8777	GZEGRB	VBKYYZLURE	7966211062 Dell Way	\N	QUMUIRV	PA	83266	US	1	VBKYYZLURE@dell.com	7966211062	2	5639432062394918	2009/06	user8777	password	77	60000	F
8778	ZSDBOE	MMDMYYECOZ	5998259736 Dell Way	\N	OIHFDBB	WA	33024	US	1	MMDMYYECOZ@dell.com	5998259736	1	7683093519881368	2009/08	user8778	password	33	40000	F
8779	JLVOXI	RKGPOJENXM	8987592604 Dell Way	\N	VDQXEOD	OR	73742	US	1	RKGPOJENXM@dell.com	8987592604	1	3637630416080356	2008/06	user8779	password	61	60000	M
8780	LZVTRF	AGUJLIHXEK	2240636702 Dell Way	\N	OBPDEIV	AZ	50080	US	1	AGUJLIHXEK@dell.com	2240636702	1	9306497999001296	2011/08	user8780	password	78	20000	M
8781	QXHWYO	QHZZOXDZLE	3512740658 Dell Way	\N	PPJXLLJ	NE	65098	US	1	QHZZOXDZLE@dell.com	3512740658	2	3149585885461420	2008/06	user8781	password	80	80000	F
8782	DQHRGP	RFDOJDANSQ	2489420284 Dell Way	\N	WPBIZQY	IA	95156	US	1	RFDOJDANSQ@dell.com	2489420284	2	4676502002403140	2008/02	user8782	password	75	20000	M
8783	CWZRNF	UBPYCCQSZG	7866873485 Dell Way	\N	THFKFLJ	MA	82311	US	1	UBPYCCQSZG@dell.com	7866873485	3	9224784132558852	2010/07	user8783	password	64	80000	F
8784	QHYWCA	LACOQVNWOV	3185125796 Dell Way	\N	BZANIKI	CO	83380	US	1	LACOQVNWOV@dell.com	3185125796	4	4440578283742070	2012/04	user8784	password	76	60000	M
8785	TKQTVQ	VJHQXEFSGF	4007755089 Dell Way	\N	STODCQY	KS	36442	US	1	VJHQXEFSGF@dell.com	4007755089	2	6072961243800819	2008/09	user8785	password	26	100000	F
8786	TPZKLI	RCFWHYCNRW	5947608771 Dell Way	\N	BUYRTHZ	CA	54021	US	1	RCFWHYCNRW@dell.com	5947608771	2	3101269104517996	2011/01	user8786	password	44	60000	M
8787	IVDRNF	XJMVLZMHBH	2988451470 Dell Way	\N	FTAMSCZ	ID	39249	US	1	XJMVLZMHBH@dell.com	2988451470	5	4639611599501223	2010/05	user8787	password	24	100000	F
8788	FPRKMB	XIMXVUYCAR	9795277496 Dell Way	\N	DNJGNQO	OK	62778	US	1	XIMXVUYCAR@dell.com	9795277496	2	9465402161236852	2008/03	user8788	password	26	40000	M
8789	URIWOQ	JLMDJPDBSR	6412008837 Dell Way	\N	KZEBNXR	MT	28026	US	1	JLMDJPDBSR@dell.com	6412008837	3	4887648102827370	2011/11	user8789	password	36	60000	M
8790	PJBFSN	SWXHAYZRJY	4359232831 Dell Way	\N	WLMTCAY	OH	62858	US	1	SWXHAYZRJY@dell.com	4359232831	3	4871910450980067	2011/12	user8790	password	86	40000	F
8791	ALBNDX	KLYJKPSJLD	9183384047 Dell Way	\N	WFFXDXM	MT	39298	US	1	KLYJKPSJLD@dell.com	9183384047	1	3340180929750204	2012/05	user8791	password	59	100000	M
8792	PJYNUJ	LDUBVENZBS	7291601133 Dell Way	\N	FYWCKJL	KS	56556	US	1	LDUBVENZBS@dell.com	7291601133	1	8847892216872425	2009/01	user8792	password	66	100000	F
8793	PKFZWI	TXEXLEZDJX	7852083865 Dell Way	\N	AMIJXRX	NJ	86038	US	1	TXEXLEZDJX@dell.com	7852083865	5	8906612175982446	2010/10	user8793	password	39	20000	F
8794	MZAVTY	ARJEQNNONA	3592623573 Dell Way	\N	XXXOUNK	NC	46636	US	1	ARJEQNNONA@dell.com	3592623573	5	2588964140042662	2010/01	user8794	password	44	20000	F
8795	KXTIXL	SCCGQQTQOR	6978080211 Dell Way	\N	OCLCNZM	SC	96252	US	1	SCCGQQTQOR@dell.com	6978080211	2	9666250871494412	2008/06	user8795	password	88	60000	F
8796	STHEMJ	GSAWMQKDFN	5477993610 Dell Way	\N	PHBOTVN	MI	30014	US	1	GSAWMQKDFN@dell.com	5477993610	3	7047823932021857	2010/11	user8796	password	19	20000	M
8797	HICRPV	RLIIWMNKBU	2587724351 Dell Way	\N	LQOHEZN	NV	50510	US	1	RLIIWMNKBU@dell.com	2587724351	1	3851468364708126	2009/04	user8797	password	86	60000	M
8798	BEGWVS	FEPRRZSMKJ	8297325972 Dell Way	\N	BSNBFFM	MA	39115	US	1	FEPRRZSMKJ@dell.com	8297325972	3	6789907054975629	2011/02	user8798	password	40	100000	F
8799	ORCGWG	VOYVGLGQMY	3740962354 Dell Way	\N	DNDIANR	SD	20599	US	1	VOYVGLGQMY@dell.com	3740962354	3	2818253909237683	2011/05	user8799	password	51	20000	F
8800	OKYVGM	TBSEIIQGME	3280462564 Dell Way	\N	KVEYMZB	SC	60650	US	1	TBSEIIQGME@dell.com	3280462564	3	9407722274772824	2011/07	user8800	password	89	40000	M
8801	XCGJVI	CAQLRWYVHT	5475556664 Dell Way	\N	AFGAHBO	MT	50580	US	1	CAQLRWYVHT@dell.com	5475556664	2	1199966908898204	2010/06	user8801	password	19	40000	M
8802	GTKPWL	FHCCFYKZYP	7827591374 Dell Way	\N	GYWHNKT	AK	66782	US	1	FHCCFYKZYP@dell.com	7827591374	3	2134746401570737	2011/11	user8802	password	69	20000	M
8803	CQMNVU	QYAOIANYGL	9593373345 Dell Way	\N	UNYFGYV	AL	49107	US	1	QYAOIANYGL@dell.com	9593373345	4	3743639119900763	2011/10	user8803	password	86	80000	F
8804	KHHFYF	FMOFZMLLGZ	1750977348 Dell Way	\N	KMGIHHU	IA	16530	US	1	FMOFZMLLGZ@dell.com	1750977348	5	9138448002748192	2008/08	user8804	password	43	60000	M
8805	QQWWWJ	KBJWNVDNFP	1100514466 Dell Way	\N	TOWAIDC	MD	12224	US	1	KBJWNVDNFP@dell.com	1100514466	3	7166140894871206	2009/11	user8805	password	64	20000	F
8806	NWIXGK	GDYCGLHVFV	6021495021 Dell Way	\N	SFDWIOW	KY	98917	US	1	GDYCGLHVFV@dell.com	6021495021	4	8648702436126769	2008/09	user8806	password	43	80000	M
8807	SQVCXZ	AZFMGBRCUW	6669598614 Dell Way	\N	FQFUNOU	AZ	34702	US	1	AZFMGBRCUW@dell.com	6669598614	2	9914707957766952	2012/12	user8807	password	59	80000	M
8808	KUMJUM	PGSRYULUAC	8686256350 Dell Way	\N	AVPPPRW	HI	93116	US	1	PGSRYULUAC@dell.com	8686256350	2	9204550649970772	2010/11	user8808	password	56	100000	M
8809	AFLMVS	FMQAYLAAMV	2019495216 Dell Way	\N	QBLHYRF	RI	88554	US	1	FMQAYLAAMV@dell.com	2019495216	2	7740066107828171	2011/01	user8809	password	47	80000	F
8810	WDCOJO	FJNRJNDFDF	9616763126 Dell Way	\N	RLDIQXF	OR	19579	US	1	FJNRJNDFDF@dell.com	9616763126	2	2338833208661526	2009/01	user8810	password	47	40000	F
8811	MUNBZX	OQHCTNGZER	3150118308 Dell Way	\N	CNHZSBC	NY	47693	US	1	OQHCTNGZER@dell.com	3150118308	1	5078354731202126	2011/03	user8811	password	64	20000	F
8812	EFZBTQ	IWKVCJATLN	9754544846 Dell Way	\N	BKFCNXN	OR	92066	US	1	IWKVCJATLN@dell.com	9754544846	2	2271222028415650	2011/07	user8812	password	28	80000	M
8813	DVMTEI	DAKMAEXNGI	7008872159 Dell Way	\N	SIVPWON	TN	95780	US	1	DAKMAEXNGI@dell.com	7008872159	3	5334045093972236	2012/03	user8813	password	32	100000	F
8814	RRFAUF	LHFQETWMMF	3819619462 Dell Way	\N	ICBWPXV	IL	40152	US	1	LHFQETWMMF@dell.com	3819619462	1	5965448700822890	2010/01	user8814	password	62	40000	M
8815	VFMBQU	HGYADLMITO	2490332604 Dell Way	\N	KQEHMLP	RI	58361	US	1	HGYADLMITO@dell.com	2490332604	2	6007215669844300	2011/07	user8815	password	36	60000	M
8816	TQJNYQ	MYTXLCRZMI	7491691034 Dell Way	\N	ETUQJOE	NC	87879	US	1	MYTXLCRZMI@dell.com	7491691034	2	4333765151910484	2012/11	user8816	password	24	80000	M
8817	MGMCSK	WPWZHWLPAF	2424720789 Dell Way	\N	JQOXVCU	NC	47148	US	1	WPWZHWLPAF@dell.com	2424720789	3	3820342058315873	2009/03	user8817	password	80	80000	F
8818	IVDTST	PRALDPMIZD	7560308470 Dell Way	\N	XXYARMK	TN	99541	US	1	PRALDPMIZD@dell.com	7560308470	1	2992343879770487	2010/10	user8818	password	67	100000	M
8819	VRIPHA	QSDFFLFIJC	9723838292 Dell Way	\N	GJTTTPT	MS	71786	US	1	QSDFFLFIJC@dell.com	9723838292	1	5428417608141899	2011/01	user8819	password	27	60000	M
8820	LBYMRR	PXWBCEKELT	7488914072 Dell Way	\N	YFNOYAF	WA	19162	US	1	PXWBCEKELT@dell.com	7488914072	3	1970189831685275	2012/01	user8820	password	75	40000	F
8821	TUUKJS	HLVLVZXPYD	4067746981 Dell Way	\N	CMCDSAG	ME	63123	US	1	HLVLVZXPYD@dell.com	4067746981	2	6812471364624799	2008/07	user8821	password	74	100000	F
8822	OGTHNE	CZACXPABSM	4413178739 Dell Way	\N	DWFDCQT	ME	91758	US	1	CZACXPABSM@dell.com	4413178739	3	5396300447639078	2008/05	user8822	password	79	80000	M
8823	PAFTCF	TEDJFECSHY	9493683171 Dell Way	\N	XLAOELL	ND	98155	US	1	TEDJFECSHY@dell.com	9493683171	4	4495107333175838	2011/06	user8823	password	22	40000	F
8824	HDNMXS	PGXUIPBHNN	1739894950 Dell Way	\N	HBRSNGS	MO	93660	US	1	PGXUIPBHNN@dell.com	1739894950	2	4133774316869676	2008/08	user8824	password	74	60000	M
8825	HXRZNX	XHGNJNBWVD	1521239805 Dell Way	\N	ONQUFDS	IN	45029	US	1	XHGNJNBWVD@dell.com	1521239805	3	1231354290619492	2012/11	user8825	password	75	20000	M
8826	LDHJAP	QOYEPVZSJM	9216700692 Dell Way	\N	JDSMWAX	VT	52439	US	1	QOYEPVZSJM@dell.com	9216700692	4	4081727593205869	2011/11	user8826	password	26	20000	M
8827	KNZZDO	YHDTGWCTGG	3831738613 Dell Way	\N	MSCNQAZ	NC	76966	US	1	YHDTGWCTGG@dell.com	3831738613	2	6416414336301387	2010/05	user8827	password	60	100000	M
8828	OVBDUI	GNPDQJJWVC	4001342023 Dell Way	\N	ZISZIFT	NM	51615	US	1	GNPDQJJWVC@dell.com	4001342023	1	8626518245786429	2012/11	user8828	password	72	60000	M
8829	UPNDWB	TZRCIOYLOH	6969404920 Dell Way	\N	DNPJGFV	NH	36031	US	1	TZRCIOYLOH@dell.com	6969404920	3	2790500765666365	2010/12	user8829	password	87	40000	M
8830	MIMNBL	FEUUCFIJJW	7230887169 Dell Way	\N	ZSDFNSM	FL	30360	US	1	FEUUCFIJJW@dell.com	7230887169	3	2991469358094036	2011/10	user8830	password	78	20000	F
8831	HQFTWJ	OQMUYWDUVW	1757368582 Dell Way	\N	XAJQNOW	HI	24151	US	1	OQMUYWDUVW@dell.com	1757368582	5	9640719108283520	2012/12	user8831	password	25	40000	M
8832	HYMRNC	DHBZLVVHTW	4123246671 Dell Way	\N	RKKFGPK	KY	52370	US	1	DHBZLVVHTW@dell.com	4123246671	2	5038808756973595	2010/06	user8832	password	22	80000	F
8833	OKYQOG	RORNJZHFRR	2315736082 Dell Way	\N	QXYFHHS	NJ	59433	US	1	RORNJZHFRR@dell.com	2315736082	1	1053337926510721	2009/10	user8833	password	48	80000	F
8834	JKUPBI	HPSGWYYOOV	4272099649 Dell Way	\N	NUCVMSJ	NJ	80022	US	1	HPSGWYYOOV@dell.com	4272099649	5	6314544436056167	2011/08	user8834	password	77	20000	M
8835	PSBYAQ	QHNOFCDAPX	2723444945 Dell Way	\N	CKJVTZP	CT	85274	US	1	QHNOFCDAPX@dell.com	2723444945	5	4842542998958379	2008/01	user8835	password	47	80000	M
8836	LOUCEB	QTHSWHIUKS	4841355920 Dell Way	\N	EGMEVQZ	AL	58501	US	1	QTHSWHIUKS@dell.com	4841355920	1	6327410967554898	2012/08	user8836	password	45	40000	F
8837	EKKGAD	NTAVBVGUZM	1174583723 Dell Way	\N	GDIXDJL	NE	45098	US	1	NTAVBVGUZM@dell.com	1174583723	3	1394748030696064	2009/09	user8837	password	35	60000	F
8838	QVCUIW	VEXQKRQXYT	9958242087 Dell Way	\N	FVXOGMY	ID	90269	US	1	VEXQKRQXYT@dell.com	9958242087	4	6328218203503639	2009/03	user8838	password	68	100000	F
8839	URJQMO	ODYFTVDNBZ	4493610907 Dell Way	\N	KQFXOMU	ND	24283	US	1	ODYFTVDNBZ@dell.com	4493610907	5	4492059878539294	2008/09	user8839	password	49	100000	F
8840	UNVIBY	HHSDLFFKQV	7147077186 Dell Way	\N	QNJDIYH	OK	77997	US	1	HHSDLFFKQV@dell.com	7147077186	4	4961533032823354	2008/08	user8840	password	75	100000	F
8841	QGGOOO	GSAMXKCSBQ	3146848586 Dell Way	\N	CFYBMQU	FL	49128	US	1	GSAMXKCSBQ@dell.com	3146848586	2	1880926795769483	2008/03	user8841	password	39	80000	F
8842	OFADMS	DYPOBIPRKU	8123948773 Dell Way	\N	PLHGGMS	MO	79041	US	1	DYPOBIPRKU@dell.com	8123948773	3	9713314486667516	2008/02	user8842	password	49	80000	F
8843	LTWDWV	TKXBAOMVEX	4130825735 Dell Way	\N	DLEPDRJ	VT	25138	US	1	TKXBAOMVEX@dell.com	4130825735	5	3972537533845753	2011/08	user8843	password	70	40000	F
8844	PJGLDR	IESWROBPRM	9088636581 Dell Way	\N	THPKRNO	AK	55354	US	1	IESWROBPRM@dell.com	9088636581	4	2231108813080936	2011/01	user8844	password	56	40000	F
8845	UQMMYR	EVISWXKIQS	1812270748 Dell Way	\N	YBJLQJY	MT	25870	US	1	EVISWXKIQS@dell.com	1812270748	1	2649186601396650	2011/05	user8845	password	58	60000	M
8846	BWXSBT	BUPYFYPXXR	1149412285 Dell Way	\N	HIHRHUV	MA	93552	US	1	BUPYFYPXXR@dell.com	1149412285	1	3386528131086379	2010/05	user8846	password	35	80000	F
8847	DIJXJE	NIJLYHJPOS	8739794818 Dell Way	\N	WFZRBJP	AR	44598	US	1	NIJLYHJPOS@dell.com	8739794818	4	8150582971051336	2008/03	user8847	password	24	40000	M
8848	LDYPQH	ZCFGLVUDSA	7156871356 Dell Way	\N	DJBNYCX	SD	75676	US	1	ZCFGLVUDSA@dell.com	7156871356	5	9751051453407856	2011/02	user8848	password	58	40000	F
8849	NVXUVA	ABLVWOOWSX	7591084794 Dell Way	\N	YFWACRT	RI	61630	US	1	ABLVWOOWSX@dell.com	7591084794	3	7511316983960570	2009/10	user8849	password	18	80000	M
8850	XPKXPM	JLIYZFQXDV	7331905389 Dell Way	\N	TEXKYSZ	NY	31512	US	1	JLIYZFQXDV@dell.com	7331905389	5	1035793379414826	2011/09	user8850	password	61	80000	F
8851	AOYMXJ	VVJAMGEHZJ	2387647790 Dell Way	\N	FKHXJZD	CA	92780	US	1	VVJAMGEHZJ@dell.com	2387647790	4	6914665258955211	2011/06	user8851	password	89	80000	M
8852	XGWHBS	QCFXGMXQSH	5242471653 Dell Way	\N	YQRXUTV	WA	59471	US	1	QCFXGMXQSH@dell.com	5242471653	4	9741816863417626	2010/06	user8852	password	86	40000	M
8853	VQSOHU	TEBGBRYJQO	3720533255 Dell Way	\N	ANIUIHI	SC	95728	US	1	TEBGBRYJQO@dell.com	3720533255	2	4501736907288432	2009/08	user8853	password	22	20000	F
8854	UQMOJR	QPSIOBYDCL	1797112198 Dell Way	\N	MWUTFOS	MS	83144	US	1	QPSIOBYDCL@dell.com	1797112198	4	4652776484843344	2008/10	user8854	password	63	100000	F
8855	DMVUDK	MLZOJCRVON	4491890002 Dell Way	\N	PITEAGZ	CO	10811	US	1	MLZOJCRVON@dell.com	4491890002	2	8512021276634187	2008/03	user8855	password	38	20000	M
8856	CXUNKF	MZPPQLEEAM	1031306249 Dell Way	\N	XFNEEQE	ND	88955	US	1	MZPPQLEEAM@dell.com	1031306249	3	1459827054757624	2009/09	user8856	password	69	40000	M
8857	MXASJZ	HZPSDTTPRY	7028462121 Dell Way	\N	DVDTARQ	AK	34240	US	1	HZPSDTTPRY@dell.com	7028462121	2	9806963441427798	2009/09	user8857	password	61	100000	M
8858	POYPWX	FPAZJQQITM	4407548128 Dell Way	\N	LMMDCMK	RI	78674	US	1	FPAZJQQITM@dell.com	4407548128	1	4878890120424330	2012/01	user8858	password	90	60000	M
8859	XEMVJC	VIMMZUFLFS	6084523194 Dell Way	\N	XJVJTPD	CT	79600	US	1	VIMMZUFLFS@dell.com	6084523194	1	8254465730860830	2010/09	user8859	password	48	60000	M
8860	XHFADO	MPNGVYMNVV	5939547806 Dell Way	\N	JFOZIST	VT	82643	US	1	MPNGVYMNVV@dell.com	5939547806	3	5415517486166209	2012/12	user8860	password	43	100000	F
8861	OWJCJY	QPTOBHKXRP	5317080511 Dell Way	\N	MQYEJVZ	VT	37010	US	1	QPTOBHKXRP@dell.com	5317080511	5	3106265544425696	2012/10	user8861	password	51	40000	M
8862	VNZTDP	NRRVBOMRBD	9824570643 Dell Way	\N	PFMLFKT	OH	36885	US	1	NRRVBOMRBD@dell.com	9824570643	3	1483089522458613	2010/11	user8862	password	68	40000	F
8863	RANGOF	XKHMWYNAOT	3355424229 Dell Way	\N	MZYXTQF	OK	24656	US	1	XKHMWYNAOT@dell.com	3355424229	1	1610764167737215	2012/05	user8863	password	52	80000	F
8864	ZWZFUJ	MGGKUGZNTY	4287146619 Dell Way	\N	MRSDWKH	CT	61478	US	1	MGGKUGZNTY@dell.com	4287146619	1	9875828302931042	2012/09	user8864	password	48	100000	M
8865	KBJUNQ	BYKHXYBWLS	5671851189 Dell Way	\N	OOPYWSN	HI	81065	US	1	BYKHXYBWLS@dell.com	5671851189	1	5358356146141887	2012/11	user8865	password	21	40000	M
8866	KDLAEK	KMHJNDUFSI	8090279033 Dell Way	\N	URFNELH	OK	53612	US	1	KMHJNDUFSI@dell.com	8090279033	4	4452327955979854	2012/12	user8866	password	41	40000	F
8867	UGHERT	MAHQVNIEHZ	6909075807 Dell Way	\N	JVEUDWH	VT	57216	US	1	MAHQVNIEHZ@dell.com	6909075807	4	5700908448081464	2012/12	user8867	password	65	80000	F
8868	YYXSKY	ZATNJYVIHQ	4689713369 Dell Way	\N	MCTJJRX	AK	47781	US	1	ZATNJYVIHQ@dell.com	4689713369	5	4642418929375708	2008/10	user8868	password	64	20000	M
8869	OTCMSD	GGMEBVMRHO	9363086733 Dell Way	\N	LRXCOYN	WI	92731	US	1	GGMEBVMRHO@dell.com	9363086733	1	7059468528721482	2010/01	user8869	password	44	20000	M
8870	MQMPXS	CCUXOLFDWW	6077169290 Dell Way	\N	BZKZNJX	MI	44141	US	1	CCUXOLFDWW@dell.com	6077169290	1	4700720002874732	2012/02	user8870	password	30	60000	M
8871	RAQKCS	EAHQFKNBLM	6675833166 Dell Way	\N	MLAVILF	UT	51019	US	1	EAHQFKNBLM@dell.com	6675833166	5	6336295575369150	2012/03	user8871	password	43	60000	F
8872	AWJSBJ	ARPKEQWQDH	2269778773 Dell Way	\N	QZQCEMO	SD	38111	US	1	ARPKEQWQDH@dell.com	2269778773	4	5773378906771541	2010/02	user8872	password	73	60000	M
8873	CFAMGR	BQVSNMVVDU	8130344379 Dell Way	\N	LFZYTVG	VT	50124	US	1	BQVSNMVVDU@dell.com	8130344379	3	5925622959621251	2010/11	user8873	password	55	80000	F
8874	NDJFFA	AXNNTJQNVW	4129709106 Dell Way	\N	NTQJANU	SD	94518	US	1	AXNNTJQNVW@dell.com	4129709106	2	8536877341102810	2012/01	user8874	password	87	60000	F
8875	HPJHQH	VDAFUOAQBU	6283958670 Dell Way	\N	HLUVGPT	NE	98749	US	1	VDAFUOAQBU@dell.com	6283958670	3	1237545176874846	2010/11	user8875	password	33	100000	F
8876	PECWZG	WFAKFRMZYX	4650043330 Dell Way	\N	UTDKNSJ	CO	24747	US	1	WFAKFRMZYX@dell.com	4650043330	4	1108066842425614	2011/06	user8876	password	51	20000	M
8877	OBQUXV	VHBNUALRUF	7366050077 Dell Way	\N	VFTNPVS	WY	53631	US	1	VHBNUALRUF@dell.com	7366050077	3	9793517062440516	2008/10	user8877	password	63	80000	M
8878	GNTCJB	DWVEIMZOIE	6293985806 Dell Way	\N	HVTDNTP	IA	39633	US	1	DWVEIMZOIE@dell.com	6293985806	3	2084768469911068	2009/02	user8878	password	88	60000	M
8879	SPATSW	OXFBWTJBAF	9847963110 Dell Way	\N	UETNUZW	LA	46529	US	1	OXFBWTJBAF@dell.com	9847963110	3	5949823953211308	2012/01	user8879	password	34	80000	M
8880	GKJDYG	IADCJECPZH	3519901661 Dell Way	\N	INBIJKS	LA	98738	US	1	IADCJECPZH@dell.com	3519901661	2	1358446678612381	2010/12	user8880	password	67	80000	F
8881	BWHHFI	LHSQKHPRQD	2354038584 Dell Way	\N	SYNDRWC	WI	27376	US	1	LHSQKHPRQD@dell.com	2354038584	3	2334325228352099	2012/03	user8881	password	54	100000	F
8882	UEGCPN	UGXCWOSZHQ	7532689822 Dell Way	\N	NKIJNHP	NY	74896	US	1	UGXCWOSZHQ@dell.com	7532689822	3	9215833114925772	2009/05	user8882	password	88	20000	M
8883	FDDTYJ	RAFGTFNJSY	6424923221 Dell Way	\N	SCLZRDR	MA	66299	US	1	RAFGTFNJSY@dell.com	6424923221	4	9906826642807574	2010/08	user8883	password	56	80000	M
8884	ROSAFS	GLLLYVEWNG	1659818304 Dell Way	\N	INXLFHC	SC	92238	US	1	GLLLYVEWNG@dell.com	1659818304	2	5908809758722783	2010/02	user8884	password	40	40000	M
8885	AHXTNI	EZHADEOKMB	1497188943 Dell Way	\N	HYGPABN	CO	47970	US	1	EZHADEOKMB@dell.com	1497188943	4	6275935680139810	2009/12	user8885	password	39	40000	F
8886	FCTNHT	UIXZWHLYOK	3302692930 Dell Way	\N	FELGROR	OR	31608	US	1	UIXZWHLYOK@dell.com	3302692930	1	2723669462837279	2010/06	user8886	password	49	80000	M
8887	EHWYCE	VBBCMZRXEW	3800738165 Dell Way	\N	ILNWCHD	LA	43160	US	1	VBBCMZRXEW@dell.com	3800738165	5	8526034377049656	2011/08	user8887	password	47	100000	M
8888	GWZLSB	MVNMNLRJUC	4408624390 Dell Way	\N	XRFEUOO	CA	52954	US	1	MVNMNLRJUC@dell.com	4408624390	5	2138113026507199	2011/10	user8888	password	21	20000	M
8889	BMICZE	QMRBDAVGYM	6811277781 Dell Way	\N	MCHBQJN	AL	26875	US	1	QMRBDAVGYM@dell.com	6811277781	5	9474298042710872	2011/11	user8889	password	59	80000	F
8890	XVJBLV	SMZTIGRVSU	6229230248 Dell Way	\N	CTLLHMQ	WA	36309	US	1	SMZTIGRVSU@dell.com	6229230248	4	2434540842659771	2008/05	user8890	password	56	20000	F
8891	WCPSVC	SOKYGFRBIL	4916096340 Dell Way	\N	NTSZKQH	WY	33138	US	1	SOKYGFRBIL@dell.com	4916096340	1	6464813209604473	2012/03	user8891	password	74	100000	F
8892	JOCLGR	VFYBWAJHND	5611712429 Dell Way	\N	AMNQUNX	GA	67956	US	1	VFYBWAJHND@dell.com	5611712429	1	8403785652015359	2009/12	user8892	password	25	80000	M
8893	FCUXYZ	VZWWJEJMEW	9972864879 Dell Way	\N	AVQNSVE	HI	99955	US	1	VZWWJEJMEW@dell.com	9972864879	3	9987996146548540	2008/02	user8893	password	57	40000	F
8894	IFEIBD	EXMIGZNDZI	6285992304 Dell Way	\N	TNAPSGP	OH	79716	US	1	EXMIGZNDZI@dell.com	6285992304	5	9353419302031400	2008/02	user8894	password	29	60000	F
8895	IUJMZH	YIOYVRYELM	2482785949 Dell Way	\N	FAEMPWG	GA	69988	US	1	YIOYVRYELM@dell.com	2482785949	2	8044480783864857	2009/10	user8895	password	26	80000	M
8896	MDPUCY	IAUAYYLLDM	9146265590 Dell Way	\N	PPCLWHD	AK	65566	US	1	IAUAYYLLDM@dell.com	9146265590	2	4799765059258789	2008/12	user8896	password	20	60000	F
8897	QHEPQF	JQEICPMOEB	9880498456 Dell Way	\N	RQXYTYO	NV	34564	US	1	JQEICPMOEB@dell.com	9880498456	4	3382858357857913	2008/03	user8897	password	45	80000	F
8898	OGCTPT	YXWNJLSLCI	8574447419 Dell Way	\N	JBCHPTO	NH	47959	US	1	YXWNJLSLCI@dell.com	8574447419	4	6474678533617408	2009/04	user8898	password	24	80000	F
8899	FOCYMA	VZJGRVIAFJ	8839133094 Dell Way	\N	CNZVCOG	WA	26288	US	1	VZJGRVIAFJ@dell.com	8839133094	1	5011425029020757	2012/12	user8899	password	86	20000	F
8900	ACYBXX	LEPGMPMWSZ	1374213105 Dell Way	\N	VOBKVZP	NY	22263	US	1	LEPGMPMWSZ@dell.com	1374213105	4	1489248959813267	2012/10	user8900	password	55	20000	M
8901	LBVJMZ	ZTMPFIHFEV	5122111983 Dell Way	\N	HPRGEIK	HI	99047	US	1	ZTMPFIHFEV@dell.com	5122111983	2	8080677140038461	2012/03	user8901	password	68	60000	F
8902	NUUMTO	YIUHQZLMHB	3263529141 Dell Way	\N	DOFMYLM	MD	70042	US	1	YIUHQZLMHB@dell.com	3263529141	2	9107272842433304	2012/10	user8902	password	32	60000	M
8903	AYIOWQ	JEHJQTQRWE	9242598442 Dell Way	\N	XJCJVNA	AZ	88811	US	1	JEHJQTQRWE@dell.com	9242598442	1	6985301669221372	2008/06	user8903	password	35	20000	F
8904	ORHFAL	MJBFZSCDPL	3660895825 Dell Way	\N	GZGTZIQ	VA	38313	US	1	MJBFZSCDPL@dell.com	3660895825	1	7932420404627920	2010/02	user8904	password	29	20000	M
8905	LHVWTF	YZFRBJHMPG	2247747402 Dell Way	\N	TJFBZCJ	IL	20304	US	1	YZFRBJHMPG@dell.com	2247747402	5	3196253350935876	2009/11	user8905	password	21	80000	F
8906	XPYCOX	HFZQMMGSFP	4425027623 Dell Way	\N	XHPAQWD	RI	72685	US	1	HFZQMMGSFP@dell.com	4425027623	1	6358305162284524	2010/10	user8906	password	74	40000	F
8907	SKZQSE	QJRCPJIFHP	9824950959 Dell Way	\N	UHGRLAK	SD	20231	US	1	QJRCPJIFHP@dell.com	9824950959	2	9392953260801732	2011/07	user8907	password	44	60000	M
8908	IDRNTB	EWQNEWVURD	1851664389 Dell Way	\N	AJOBTJE	OK	67028	US	1	EWQNEWVURD@dell.com	1851664389	3	2843095443677157	2010/12	user8908	password	31	80000	F
8909	WIVYMR	OAWLVQCZQL	7710030592 Dell Way	\N	NRFXWXO	WI	45879	US	1	OAWLVQCZQL@dell.com	7710030592	3	4257487691473216	2012/03	user8909	password	50	100000	M
8910	HTAYIA	UTWLWVBHJT	2630090484 Dell Way	\N	NHPKVOV	ND	94943	US	1	UTWLWVBHJT@dell.com	2630090484	3	2272189488634467	2011/04	user8910	password	65	100000	F
8911	RWJRRD	OCZKEHUXUB	2284394620 Dell Way	\N	NFWBAKA	FL	91925	US	1	OCZKEHUXUB@dell.com	2284394620	5	2972956533543765	2011/09	user8911	password	37	60000	M
8912	QDHTSJ	SCNZWLTYZY	3951414970 Dell Way	\N	UAZFAEC	DE	99376	US	1	SCNZWLTYZY@dell.com	3951414970	5	7545865147840232	2010/06	user8912	password	41	40000	M
8913	PZHZSK	NRHZLFYKZY	3416088433 Dell Way	\N	JEZOHDO	NJ	20328	US	1	NRHZLFYKZY@dell.com	3416088433	2	5832109498325736	2010/06	user8913	password	25	20000	F
8914	JEDURV	BRGGPRFOBK	3915257208 Dell Way	\N	NPRRDHU	MD	55511	US	1	BRGGPRFOBK@dell.com	3915257208	1	9541053292341532	2010/03	user8914	password	45	100000	F
8915	MPBIQS	OWIGCWHMJW	9114696375 Dell Way	\N	DBALVLY	DE	48737	US	1	OWIGCWHMJW@dell.com	9114696375	3	6696616703178734	2009/05	user8915	password	18	80000	M
8916	CCPURL	CXNZEAIBEJ	6249815616 Dell Way	\N	CPFNOJY	MN	96480	US	1	CXNZEAIBEJ@dell.com	6249815616	4	4206174141261727	2010/07	user8916	password	42	80000	M
8917	YMGJPE	XOIXXKCGNR	2605790601 Dell Way	\N	MAGWZSV	ND	48842	US	1	XOIXXKCGNR@dell.com	2605790601	1	9482835585251452	2010/10	user8917	password	57	60000	F
8918	UVXYTL	HRISTPFKCG	7528444770 Dell Way	\N	RYFJTTU	WI	92527	US	1	HRISTPFKCG@dell.com	7528444770	3	7690940913278610	2009/11	user8918	password	21	20000	M
8919	YALJHC	SAVHFGJLXI	1758219974 Dell Way	\N	RGBLBAI	PA	52049	US	1	SAVHFGJLXI@dell.com	1758219974	1	4195261045824736	2008/02	user8919	password	22	20000	F
8920	NLKPDL	LLQRUCPCTW	1192678135 Dell Way	\N	EEXFNQR	NH	71547	US	1	LLQRUCPCTW@dell.com	1192678135	4	7989377410616726	2008/10	user8920	password	82	60000	F
8921	HFJSQU	JIPMXSFUXK	7976425522 Dell Way	\N	RCYITNZ	RI	34188	US	1	JIPMXSFUXK@dell.com	7976425522	5	1630344381555915	2011/06	user8921	password	40	100000	M
8922	RRHMBP	CNNUTHRDZU	9471670232 Dell Way	\N	BHNPHIW	AR	25584	US	1	CNNUTHRDZU@dell.com	9471670232	4	6625944648869336	2009/08	user8922	password	37	100000	F
8923	OLKENX	SHQZZUYUWG	4719181551 Dell Way	\N	HMNPIOU	IL	34062	US	1	SHQZZUYUWG@dell.com	4719181551	3	9394844842609020	2011/06	user8923	password	38	40000	M
8924	RKKPCS	FCSABMWHUI	5994697561 Dell Way	\N	UKRJEYQ	NH	52824	US	1	FCSABMWHUI@dell.com	5994697561	2	9450051057618112	2012/07	user8924	password	78	60000	M
8925	FCAYID	QIECFMWOGH	6256022947 Dell Way	\N	FQLEGBQ	SC	38924	US	1	QIECFMWOGH@dell.com	6256022947	4	8573793610557915	2010/02	user8925	password	74	80000	F
8926	UONYFW	CIBOFPVMVM	2118697307 Dell Way	\N	XZSYQNH	HI	21959	US	1	CIBOFPVMVM@dell.com	2118697307	4	3409066339489073	2012/04	user8926	password	53	80000	M
8927	AQBWSJ	YHOODAJPYJ	2891248454 Dell Way	\N	HXAVEGY	IN	89414	US	1	YHOODAJPYJ@dell.com	2891248454	2	2414526995271444	2011/11	user8927	password	18	80000	M
8928	BPGKNN	ZBRZLHYVPV	2097987644 Dell Way	\N	VKACIIZ	NC	57853	US	1	ZBRZLHYVPV@dell.com	2097987644	2	4830606854520738	2008/12	user8928	password	86	20000	M
8929	EPBSOD	JOPRMKGIGQ	6698327701 Dell Way	\N	JIZRHNF	ME	77951	US	1	JOPRMKGIGQ@dell.com	6698327701	3	7394333762116731	2010/09	user8929	password	36	80000	F
8930	ILWLVL	BMXLSGSIPA	3601251757 Dell Way	\N	IGIVMSP	CO	33911	US	1	BMXLSGSIPA@dell.com	3601251757	4	9827967979479582	2010/05	user8930	password	39	100000	M
8931	EIRPJE	NVWTNFINNP	8408713523 Dell Way	\N	WJBOYEV	HI	86384	US	1	NVWTNFINNP@dell.com	8408713523	4	3372044956777245	2008/08	user8931	password	26	40000	M
8932	UWIYJD	VCQBLEOAAX	4439442091 Dell Way	\N	CPVHLBD	ID	83276	US	1	VCQBLEOAAX@dell.com	4439442091	2	4910299068782479	2010/08	user8932	password	45	40000	F
8933	RGWVCY	LDJQSKQPNG	7836143371 Dell Way	\N	LURNXYI	IL	38832	US	1	LDJQSKQPNG@dell.com	7836143371	4	9686547277029604	2008/02	user8933	password	51	100000	F
8934	IQLHBP	QSHBIXOPJI	5415387880 Dell Way	\N	GWGFENN	WI	36888	US	1	QSHBIXOPJI@dell.com	5415387880	1	4482398125808686	2012/11	user8934	password	72	40000	M
8935	EOPTFH	BGQYVFHEMD	6587225704 Dell Way	\N	KRIYFHG	OH	42473	US	1	BGQYVFHEMD@dell.com	6587225704	4	3350655203219503	2009/12	user8935	password	75	60000	F
8936	KIRSJY	IHTOPYBTJS	9876133173 Dell Way	\N	CHYJNQS	DC	36547	US	1	IHTOPYBTJS@dell.com	9876133173	3	3013320242054760	2011/01	user8936	password	68	20000	F
8937	JWTHFA	BUQZVJJOMQ	6775828005 Dell Way	\N	MVEDOHK	NC	83161	US	1	BUQZVJJOMQ@dell.com	6775828005	2	8803307541180403	2009/06	user8937	password	35	80000	F
8938	ZZPABJ	QBEAKSMAFI	2612201319 Dell Way	\N	FIWMTKI	MD	76725	US	1	QBEAKSMAFI@dell.com	2612201319	4	3115994461346418	2010/06	user8938	password	62	40000	F
8939	EKMOAN	SBXLOYRWDA	2413486595 Dell Way	\N	TQTEYDX	CT	89039	US	1	SBXLOYRWDA@dell.com	2413486595	3	3807000495027751	2011/12	user8939	password	72	100000	F
8940	FMJTFL	RRZQJWTJQK	4947101884 Dell Way	\N	CUJGSMD	UT	13834	US	1	RRZQJWTJQK@dell.com	4947101884	4	9789314791094512	2008/08	user8940	password	40	60000	F
8941	REHCVZ	BLIYFROQUJ	5491151710 Dell Way	\N	ZABMEYN	NH	62673	US	1	BLIYFROQUJ@dell.com	5491151710	4	2534366287756711	2012/03	user8941	password	36	60000	F
8942	OOEOQQ	WOWODMJMLJ	3173082266 Dell Way	\N	NYOMLDB	WI	92569	US	1	WOWODMJMLJ@dell.com	3173082266	4	1926305308938026	2010/03	user8942	password	50	20000	M
8943	QPLGMZ	CADOJPATDZ	5137892948 Dell Way	\N	HPKLRJJ	VT	22727	US	1	CADOJPATDZ@dell.com	5137892948	3	4352703525684774	2012/06	user8943	password	30	60000	F
8944	PUNPWO	SLYHMSKLAA	7680159371 Dell Way	\N	WLSFVQJ	ID	13794	US	1	SLYHMSKLAA@dell.com	7680159371	1	5564216719008983	2012/09	user8944	password	59	60000	F
8945	CCJRUU	QCGINRJONU	4831806191 Dell Way	\N	GTPWDWX	UT	15218	US	1	QCGINRJONU@dell.com	4831806191	4	7867540471721441	2012/04	user8945	password	35	20000	F
8946	PTEKJH	RSUJBJXWPQ	2586609013 Dell Way	\N	MMUJKRK	SD	50596	US	1	RSUJBJXWPQ@dell.com	2586609013	5	7659855527337641	2010/11	user8946	password	27	20000	M
8947	ILBPCT	KLVTIRJZEV	6573781802 Dell Way	\N	TNFLYAW	CO	85325	US	1	KLVTIRJZEV@dell.com	6573781802	3	7651487823110075	2011/07	user8947	password	47	20000	M
8948	LRBFBM	AVVSEUXZOK	8251381056 Dell Way	\N	FZIFWLB	MO	97256	US	1	AVVSEUXZOK@dell.com	8251381056	2	5704024730715901	2009/04	user8948	password	54	80000	M
8949	OWABXV	WQARNZFYFF	2726953626 Dell Way	\N	GLBSMOR	IN	80360	US	1	WQARNZFYFF@dell.com	2726953626	3	1599691887386143	2011/02	user8949	password	18	40000	F
8950	AIYWEP	WWCWBABHHM	7844943724 Dell Way	\N	JZYXQGS	TX	78338	US	1	WWCWBABHHM@dell.com	7844943724	3	9315100597683340	2011/10	user8950	password	88	80000	F
8951	XQHMND	PJFPKMXWWW	7922396930 Dell Way	\N	VTNCLJV	HI	92524	US	1	PJFPKMXWWW@dell.com	7922396930	5	7349507884588093	2011/10	user8951	password	76	80000	F
8952	CDYFSI	LISYFPUCLO	6737828551 Dell Way	\N	QNZAJFY	CT	28840	US	1	LISYFPUCLO@dell.com	6737828551	5	9972877913154664	2010/06	user8952	password	49	60000	M
8953	KTISEQ	KCWAWYLKPY	8500602848 Dell Way	\N	KPHQOKV	FL	34868	US	1	KCWAWYLKPY@dell.com	8500602848	4	7890205536037684	2009/02	user8953	password	45	80000	M
8954	SJBIUD	FUAEFLTEVJ	9404942990 Dell Way	\N	MMXXHCE	CT	72965	US	1	FUAEFLTEVJ@dell.com	9404942990	3	8591876212973148	2009/01	user8954	password	71	20000	F
8955	UIFYOZ	YSFKLKFVWS	4015661394 Dell Way	\N	STAUYDM	TX	59243	US	1	YSFKLKFVWS@dell.com	4015661394	1	6529690565075726	2008/03	user8955	password	21	100000	M
8956	GUBGTT	MDFWJATBTM	4346705976 Dell Way	\N	BNKFAHT	KY	49774	US	1	MDFWJATBTM@dell.com	4346705976	3	6563663407694549	2010/04	user8956	password	28	80000	F
8957	FXVZKY	EGIFZKYMLL	3037531138 Dell Way	\N	XRMELVP	SC	32167	US	1	EGIFZKYMLL@dell.com	3037531138	2	5644115844741464	2009/11	user8957	password	60	60000	M
8958	KNEISL	RXLBVXNHUE	4333851426 Dell Way	\N	UZPPOKW	SC	66267	US	1	RXLBVXNHUE@dell.com	4333851426	1	5537323520984501	2012/09	user8958	password	39	40000	F
8959	MRZXIX	IJSGWAABVZ	2911842702 Dell Way	\N	RKOCHJS	NM	57579	US	1	IJSGWAABVZ@dell.com	2911842702	3	3343318921513855	2010/12	user8959	password	56	100000	M
8960	NXXKFH	DMEDMGZMXJ	2951806657 Dell Way	\N	BZRLSHY	VT	90389	US	1	DMEDMGZMXJ@dell.com	2951806657	3	8358720881864429	2011/05	user8960	password	48	40000	F
8961	IQNQTZ	UXMBWZYGBY	9217590284 Dell Way	\N	XMRFLOC	NV	10200	US	1	UXMBWZYGBY@dell.com	9217590284	2	4703598184976727	2009/08	user8961	password	70	80000	F
8962	GHAGCX	SDUSCATBXG	7201472536 Dell Way	\N	SDRHFIH	CT	74183	US	1	SDUSCATBXG@dell.com	7201472536	3	4141747250221670	2010/02	user8962	password	63	80000	F
8963	QWMOPP	IISJCTHILK	4435755378 Dell Way	\N	ZSPIZTA	NY	28384	US	1	IISJCTHILK@dell.com	4435755378	1	3853356191422790	2012/09	user8963	password	69	80000	M
8964	EEFUNO	MWQFDYRNYJ	4644110527 Dell Way	\N	DHJWIAC	OH	18944	US	1	MWQFDYRNYJ@dell.com	4644110527	4	8404305778443814	2008/04	user8964	password	49	40000	M
8965	QCAEPW	VVZUMNTVQA	2173879847 Dell Way	\N	ENIFQAI	AL	73118	US	1	VVZUMNTVQA@dell.com	2173879847	1	1197836354840546	2010/06	user8965	password	56	40000	M
8966	NKDKFZ	KZLXTHOTMC	8248737399 Dell Way	\N	BRSCZTU	CO	90244	US	1	KZLXTHOTMC@dell.com	8248737399	4	4080584959592670	2009/11	user8966	password	83	100000	F
8967	BGMARM	LOFTDZFFBW	9293220766 Dell Way	\N	YDWRXZP	OK	67266	US	1	LOFTDZFFBW@dell.com	9293220766	1	5626561201643199	2012/11	user8967	password	75	100000	F
8968	HWVUIK	ABNZGTADRD	1948312838 Dell Way	\N	ZJBYYUP	UT	83632	US	1	ABNZGTADRD@dell.com	1948312838	4	7530551129952074	2012/07	user8968	password	83	20000	F
8969	SYTCYV	QYCJYFBCFK	5209872994 Dell Way	\N	DEJYTFT	UT	90968	US	1	QYCJYFBCFK@dell.com	5209872994	4	5026028131600470	2009/12	user8969	password	81	20000	M
8970	QFVLVT	NESTGUZQYD	5961559011 Dell Way	\N	ZWXFPTC	CA	56671	US	1	NESTGUZQYD@dell.com	5961559011	3	5072709448169917	2010/07	user8970	password	42	20000	M
8971	ENOYAT	QUZLTPJXPG	5800501974 Dell Way	\N	UUWOXYC	MN	45949	US	1	QUZLTPJXPG@dell.com	5800501974	5	9376126971561464	2012/12	user8971	password	66	20000	F
8972	FZMYPH	YAANKYDRTY	8415273792 Dell Way	\N	OHWMKHX	VT	26899	US	1	YAANKYDRTY@dell.com	8415273792	4	2094262827653438	2010/10	user8972	password	58	80000	M
8973	AQKHOL	ICWHGNAEBI	6846058379 Dell Way	\N	AOSILQN	ID	48875	US	1	ICWHGNAEBI@dell.com	6846058379	4	3352516916114837	2009/06	user8973	password	22	40000	F
8974	LORXWU	TEAGEFINGW	6178288964 Dell Way	\N	GPIWDPI	RI	41871	US	1	TEAGEFINGW@dell.com	6178288964	5	8228688620962203	2011/03	user8974	password	83	20000	M
8975	OZQJSU	JZZPINWETL	3458602792 Dell Way	\N	NQODYIM	MT	37316	US	1	JZZPINWETL@dell.com	3458602792	1	5656832403037698	2008/03	user8975	password	37	80000	F
8976	XCYSMY	RBGEXLXJYO	1632960671 Dell Way	\N	XBMGOZO	SD	22205	US	1	RBGEXLXJYO@dell.com	1632960671	5	4364758693147451	2009/09	user8976	password	61	40000	M
8977	OYHMQJ	SUHESRCGPE	3093844783 Dell Way	\N	TVSSJNW	MN	56806	US	1	SUHESRCGPE@dell.com	3093844783	4	3233820898458361	2012/01	user8977	password	23	40000	M
8978	JWPTPK	BTCSWJHBCC	1590320370 Dell Way	\N	TVMHRYV	VT	76254	US	1	BTCSWJHBCC@dell.com	1590320370	4	7978150257840753	2008/02	user8978	password	73	60000	M
8979	JGOTHH	WZDGGEIJYE	3872000754 Dell Way	\N	WGWUBUO	CT	56760	US	1	WZDGGEIJYE@dell.com	3872000754	2	6749100077897311	2008/10	user8979	password	62	60000	F
8980	EEILBH	PHOUQYSVVY	6377545498 Dell Way	\N	RQALEDY	MO	46566	US	1	PHOUQYSVVY@dell.com	6377545498	3	2585413326974958	2009/12	user8980	password	32	40000	F
8981	NVGVKO	KEEIXZDWRT	6378321541 Dell Way	\N	WCYABKK	NV	97719	US	1	KEEIXZDWRT@dell.com	6378321541	5	9710361584089696	2011/03	user8981	password	29	40000	F
8982	KDLYNQ	DVNCZJUTGW	1422638893 Dell Way	\N	RGYCRPC	ID	51351	US	1	DVNCZJUTGW@dell.com	1422638893	1	7205079650506378	2008/05	user8982	password	71	60000	F
8983	ENAUQV	HTVROPXKHD	1897874727 Dell Way	\N	JJVYMCK	MS	24117	US	1	HTVROPXKHD@dell.com	1897874727	4	5747569828294218	2012/04	user8983	password	19	20000	M
8984	AUMWCG	SUUHRFOVOY	4953015024 Dell Way	\N	RNKTXXX	AK	66508	US	1	SUUHRFOVOY@dell.com	4953015024	5	9343572569079698	2010/11	user8984	password	73	60000	M
8985	FITMBO	GIFLXBZVSM	7513513055 Dell Way	\N	GMKEKKU	TN	32773	US	1	GIFLXBZVSM@dell.com	7513513055	2	1928245011251419	2010/10	user8985	password	73	80000	F
8986	NEDBKM	HWJJVFBILO	5372625091 Dell Way	\N	SQYDKUJ	DC	15298	US	1	HWJJVFBILO@dell.com	5372625091	4	8444459625054152	2009/04	user8986	password	86	80000	F
8987	CVXOCT	YLPDNXOBQF	6981047346 Dell Way	\N	ATPUDTV	NJ	42846	US	1	YLPDNXOBQF@dell.com	6981047346	5	7178570737596602	2011/08	user8987	password	30	80000	F
8988	CGOVEZ	KHNIWPYCPR	5389041983 Dell Way	\N	RJVLFLU	UT	37331	US	1	KHNIWPYCPR@dell.com	5389041983	3	9324185977224260	2011/02	user8988	password	44	80000	F
8989	XOPXZX	KHUZGWOYOY	4759357488 Dell Way	\N	TZDEUAM	ID	53522	US	1	KHUZGWOYOY@dell.com	4759357488	5	6805803049355746	2011/09	user8989	password	22	80000	F
8990	QPGOZO	IZUFOSTNLS	8082600330 Dell Way	\N	QQNRDUD	ND	74423	US	1	IZUFOSTNLS@dell.com	8082600330	2	4592103156726808	2012/01	user8990	password	66	60000	M
8991	XBPLKP	GPEYIRKBHB	4969636505 Dell Way	\N	OZFICTB	VA	18155	US	1	GPEYIRKBHB@dell.com	4969636505	4	2080867092125117	2008/03	user8991	password	71	20000	F
8992	JLRYSG	CQOTBPBCEA	3292101779 Dell Way	\N	HMDBNAD	WV	78552	US	1	CQOTBPBCEA@dell.com	3292101779	1	9984856847207994	2012/01	user8992	password	38	40000	M
8993	YHFFKW	UEXKGAOGHA	2619597016 Dell Way	\N	KIOKMNE	OR	63907	US	1	UEXKGAOGHA@dell.com	2619597016	4	7023341285530478	2010/01	user8993	password	32	60000	F
8994	KQTHKX	EVEEJKMKVV	7907425804 Dell Way	\N	ZGHMKBC	NH	78723	US	1	EVEEJKMKVV@dell.com	7907425804	1	8485079681500793	2012/06	user8994	password	32	40000	F
8995	YQOWVJ	AASLMDGICM	3352477579 Dell Way	\N	QPXRSML	MN	59654	US	1	AASLMDGICM@dell.com	3352477579	3	1337094429880380	2010/10	user8995	password	29	60000	F
8996	SHHBHH	UTUXACAMSP	5262431223 Dell Way	\N	KKHWVTL	CA	26793	US	1	UTUXACAMSP@dell.com	5262431223	3	9863703297451140	2011/12	user8996	password	49	40000	F
8997	SKNZFH	TDHWDUPTEZ	9806319216 Dell Way	\N	BBUUMWZ	WI	46173	US	1	TDHWDUPTEZ@dell.com	9806319216	3	4069545750040561	2010/12	user8997	password	58	20000	F
8998	CCOJWR	QSUKHNPGOQ	6794535215 Dell Way	\N	AJCXJBH	KY	70107	US	1	QSUKHNPGOQ@dell.com	6794535215	4	6439337437506766	2009/11	user8998	password	87	40000	M
8999	MQVDHN	YSUMHBAXBK	4229125439 Dell Way	\N	AZUCHDT	WA	91096	US	1	YSUMHBAXBK@dell.com	4229125439	1	7946836921852083	2009/05	user8999	password	71	80000	F
9000	OYIBWA	WIHXJFZUFY	4559489246 Dell Way	\N	PHGSBEQ	ME	35331	US	1	WIHXJFZUFY@dell.com	4559489246	4	7235439536627383	2008/07	user9000	password	72	80000	F
9001	CTIDPR	LNBQMWWLLD	8164445888 Dell Way	\N	REFVUQC	DE	42095	US	1	LNBQMWWLLD@dell.com	8164445888	2	8898746526800097	2010/12	user9001	password	42	80000	M
9002	RTIJEV	KUIHQTSUKW	8912911104 Dell Way	\N	AGQQIVA	CT	20889	US	1	KUIHQTSUKW@dell.com	8912911104	4	1948395651299506	2009/04	user9002	password	78	100000	F
9003	EGFZRA	HYRBRMLNMR	2827448785 Dell Way	\N	EDAZDDC	AK	84552	US	1	HYRBRMLNMR@dell.com	2827448785	2	2196840009652078	2008/02	user9003	password	31	20000	F
9004	KECLMA	CNSPZFBRJF	8329592666 Dell Way	\N	SJIWLIR	NV	61973	US	1	CNSPZFBRJF@dell.com	8329592666	4	7401365621481091	2012/11	user9004	password	25	60000	F
9005	EVOFYC	XNCDPTNULW	7849351783 Dell Way	\N	DIIMZZB	SD	70217	US	1	XNCDPTNULW@dell.com	7849351783	5	5996221663895995	2012/03	user9005	password	63	20000	F
9006	EHAHFO	JIDDWYPSBX	3250944627 Dell Way	\N	BNXAPSS	KY	56970	US	1	JIDDWYPSBX@dell.com	3250944627	2	7676699317991734	2012/04	user9006	password	76	20000	M
9007	VJTJSC	NVYLLRNISB	2970818104 Dell Way	\N	GTQYLZM	OH	27176	US	1	NVYLLRNISB@dell.com	2970818104	3	5185518863610924	2008/08	user9007	password	19	100000	M
9008	UFSWSO	VEZNRIGSOZ	9628813800 Dell Way	\N	INLHADM	HI	73206	US	1	VEZNRIGSOZ@dell.com	9628813800	2	4081146576441825	2012/02	user9008	password	42	80000	F
9009	AQAPME	PZVXFNMFWA	8246659484 Dell Way	\N	QEATRGM	NJ	55005	US	1	PZVXFNMFWA@dell.com	8246659484	3	6357638608198614	2008/05	user9009	password	83	20000	M
9010	XTMCIL	XGRLTWHTMM	2077535578 Dell Way	\N	UGDASTN	MT	39728	US	1	XGRLTWHTMM@dell.com	2077535578	4	7167721264995635	2008/10	user9010	password	67	100000	M
9011	DAYPYE	GJYCRRPDLW	1208260165 Dell Way	\N	HMOAACI	CT	76822	US	1	GJYCRRPDLW@dell.com	1208260165	1	6161165724974126	2011/01	user9011	password	30	100000	F
9012	CLAHRK	FUCXKGJGNV	2856722477 Dell Way	\N	UNVXWYQ	UT	18971	US	1	FUCXKGJGNV@dell.com	2856722477	3	2566743320785463	2009/06	user9012	password	37	60000	M
9013	HUOSZI	UXSAGZOCUB	2335619054 Dell Way	\N	XRXWHUZ	MS	43708	US	1	UXSAGZOCUB@dell.com	2335619054	5	8228158561978490	2010/05	user9013	password	66	80000	F
9014	FKDOFA	HFGGTIAVGR	7323444784 Dell Way	\N	TDZNCLX	ID	40116	US	1	HFGGTIAVGR@dell.com	7323444784	4	7186331206467003	2009/05	user9014	password	77	60000	M
9015	YDZYKF	FQZORUVINY	8001093551 Dell Way	\N	HBBTYIC	NV	98516	US	1	FQZORUVINY@dell.com	8001093551	1	4276836573146284	2010/08	user9015	password	29	60000	M
9016	DMDIRU	IGLCBUQACR	7454663063 Dell Way	\N	BVQJYHJ	OK	35945	US	1	IGLCBUQACR@dell.com	7454663063	2	9014562400989236	2012/10	user9016	password	63	20000	F
9017	UJZORG	AUHVKHXBJT	2293443040 Dell Way	\N	SSSZBKG	SC	73934	US	1	AUHVKHXBJT@dell.com	2293443040	4	5863931502681226	2011/08	user9017	password	79	60000	F
9018	VDRBEL	JZWQXYARQS	1101283665 Dell Way	\N	JPUTWPM	WY	31784	US	1	JZWQXYARQS@dell.com	1101283665	4	9169388469774276	2012/04	user9018	password	85	80000	F
9019	PTPBDO	YUMWUDMNMC	1289960741 Dell Way	\N	HGYWSXD	OK	71258	US	1	YUMWUDMNMC@dell.com	1289960741	3	9887374852318318	2012/04	user9019	password	48	60000	F
9020	ZQEOOY	ALTDXGQZOW	5613741328 Dell Way	\N	YKOVOHN	NE	87882	US	1	ALTDXGQZOW@dell.com	5613741328	3	2236567062325775	2012/02	user9020	password	30	100000	M
9021	IMHHNS	AQQHHQVDOF	9935839142 Dell Way	\N	SKUZYJW	MI	90223	US	1	AQQHHQVDOF@dell.com	9935839142	2	9958733929321172	2008/04	user9021	password	71	60000	M
9022	BVHUVY	KCFBXIQDAA	2500565471 Dell Way	\N	YAYHWKE	UT	80050	US	1	KCFBXIQDAA@dell.com	2500565471	1	1652485778089612	2012/07	user9022	password	79	100000	F
9023	DSFBDI	GEGPUJPVHQ	1335915749 Dell Way	\N	UPNETJZ	VT	47971	US	1	GEGPUJPVHQ@dell.com	1335915749	5	9793864555191250	2012/10	user9023	password	42	20000	F
9024	OBPWIU	CXPMMKUDEJ	4813206601 Dell Way	\N	QJCAIAL	MA	87063	US	1	CXPMMKUDEJ@dell.com	4813206601	2	6619080779608340	2011/04	user9024	password	25	40000	F
9025	SEQNGN	CTANNESWUB	5391786750 Dell Way	\N	ZVKAHUW	OH	14867	US	1	CTANNESWUB@dell.com	5391786750	3	3932369136251509	2010/10	user9025	password	65	40000	M
9026	HVFVXY	VKLACIUEHQ	7879327493 Dell Way	\N	PHXJEPL	NV	14561	US	1	VKLACIUEHQ@dell.com	7879327493	2	8417493001557887	2010/07	user9026	password	74	80000	F
9027	ZNHYJS	KKVSEAZVPH	2564753360 Dell Way	\N	SZMHKDJ	FL	43117	US	1	KKVSEAZVPH@dell.com	2564753360	4	9350892078597100	2012/04	user9027	password	40	100000	M
9028	PWGIGQ	DYVDYQSGIS	2161687590 Dell Way	\N	SQDVZHF	DE	91794	US	1	DYVDYQSGIS@dell.com	2161687590	1	3061388977337628	2010/01	user9028	password	24	20000	M
9029	IIDYMC	UPAKIHTAZJ	6373788758 Dell Way	\N	EVJLANJ	DC	65877	US	1	UPAKIHTAZJ@dell.com	6373788758	3	6881193390116096	2011/08	user9029	password	57	20000	M
9030	RZLTTB	UDJBWKBGOW	4614291278 Dell Way	\N	PAXDJBT	WV	68185	US	1	UDJBWKBGOW@dell.com	4614291278	4	3433723702561110	2012/09	user9030	password	35	80000	M
9031	RKKSEN	CGKMHRAEHB	1539358470 Dell Way	\N	CKKDDKU	ND	15210	US	1	CGKMHRAEHB@dell.com	1539358470	3	7588462893385441	2009/02	user9031	password	45	100000	M
9032	TRRHUY	SGGJHKRINB	9408717013 Dell Way	\N	TQFDLTF	MS	33852	US	1	SGGJHKRINB@dell.com	9408717013	4	4514025192242116	2009/10	user9032	password	83	20000	F
9033	PJFNCM	TMTEDCREVI	8302719140 Dell Way	\N	KZUEEGK	CO	15574	US	1	TMTEDCREVI@dell.com	8302719140	3	8460401615127922	2011/07	user9033	password	38	40000	M
9034	NVZZPL	TUOVMTRVDQ	7652742279 Dell Way	\N	PHVWSYX	MT	43270	US	1	TUOVMTRVDQ@dell.com	7652742279	2	8857917836401612	2008/07	user9034	password	72	60000	F
9035	SNZDHT	SDGLUBOLQV	5077184667 Dell Way	\N	GMOFJBP	CT	35849	US	1	SDGLUBOLQV@dell.com	5077184667	1	8399761684704573	2009/09	user9035	password	32	100000	F
9036	ECMYUP	EFKFUVVQCH	4184586243 Dell Way	\N	EHRGWUN	KY	93708	US	1	EFKFUVVQCH@dell.com	4184586243	3	6481600103899837	2010/06	user9036	password	77	80000	M
9037	HQIXUO	HZJCVZFCEN	1876357761 Dell Way	\N	UKJOYSM	IN	32969	US	1	HZJCVZFCEN@dell.com	1876357761	5	7483422785531730	2012/07	user9037	password	37	40000	F
9038	PCZDKZ	MNUMSXQFRB	3465954085 Dell Way	\N	PGAHSIO	SD	24228	US	1	MNUMSXQFRB@dell.com	3465954085	4	7467944155447186	2010/12	user9038	password	85	20000	F
9039	XHLXUY	SGQQXVHZLN	2630278406 Dell Way	\N	ZSGHHCM	ND	83008	US	1	SGQQXVHZLN@dell.com	2630278406	1	7793479111045600	2008/03	user9039	password	76	20000	M
9040	GXHEQO	VGMRNLCBLV	9699544117 Dell Way	\N	ITCKFRF	MA	78193	US	1	VGMRNLCBLV@dell.com	9699544117	3	9834048140794040	2011/06	user9040	password	53	20000	F
9041	UFBIBH	USVFVXRRFK	2657725778 Dell Way	\N	UPPLVZF	SC	53498	US	1	USVFVXRRFK@dell.com	2657725778	3	9833541157189758	2011/08	user9041	password	47	60000	M
9042	LTVSOO	OUKLLBRWWH	9394947537 Dell Way	\N	MHCMMXY	NY	51249	US	1	OUKLLBRWWH@dell.com	9394947537	2	1400966497603803	2009/10	user9042	password	79	80000	M
9043	RMDGBX	RMITDFPKRW	9209398013 Dell Way	\N	NDJKCBW	AL	46838	US	1	RMITDFPKRW@dell.com	9209398013	2	2867668086662888	2011/02	user9043	password	74	60000	M
9044	XSRUJE	DCHIRSAOGD	6421104442 Dell Way	\N	YQGZNGK	ME	64804	US	1	DCHIRSAOGD@dell.com	6421104442	1	7599902711808682	2009/08	user9044	password	43	40000	F
9045	ABREEU	MNLFNALRYC	5415941467 Dell Way	\N	XYQDIBT	WA	32052	US	1	MNLFNALRYC@dell.com	5415941467	2	8847632348537446	2012/07	user9045	password	32	100000	M
9046	XBUROI	DUVDFMCIJA	2313322178 Dell Way	\N	ZNIAHHH	RI	61552	US	1	DUVDFMCIJA@dell.com	2313322178	4	2243790800217539	2009/06	user9046	password	72	40000	M
9047	OXCWAW	RECEGLOHKC	6481856518 Dell Way	\N	QLJXSDM	UT	79209	US	1	RECEGLOHKC@dell.com	6481856518	2	3378225089050829	2009/06	user9047	password	77	100000	F
9048	YUJULO	XQVJECTHSF	8375679492 Dell Way	\N	QQYUCUO	OH	99968	US	1	XQVJECTHSF@dell.com	8375679492	1	4947698936332017	2011/12	user9048	password	74	60000	M
9049	DJFRGV	NQAPKHIPYY	7783116870 Dell Way	\N	NSAIHSI	CA	79591	US	1	NQAPKHIPYY@dell.com	7783116870	4	7702388510107995	2010/04	user9049	password	53	80000	M
9050	RJYNWO	OMYVUNUSBM	9579244482 Dell Way	\N	SJTLRWF	MI	62849	US	1	OMYVUNUSBM@dell.com	9579244482	5	8926363430917264	2010/08	user9050	password	57	20000	F
9051	LQXAFJ	YADLUVNHOW	4391322235 Dell Way	\N	BZOXFZM	DC	95216	US	1	YADLUVNHOW@dell.com	4391322235	3	6316274511162192	2012/09	user9051	password	62	40000	F
9052	MJOVIP	ZTKUHSJDTJ	2917140434 Dell Way	\N	SRORESQ	NC	36541	US	1	ZTKUHSJDTJ@dell.com	2917140434	3	1156162089668214	2012/10	user9052	password	46	40000	F
9053	ZENODH	ZYORHRLQKC	2941456519 Dell Way	\N	FBGXRUF	VA	30767	US	1	ZYORHRLQKC@dell.com	2941456519	4	1466632187832146	2011/01	user9053	password	36	60000	F
9054	TDIADG	PUOHFFRIKS	6714802092 Dell Way	\N	OIKJNHP	OK	11206	US	1	PUOHFFRIKS@dell.com	6714802092	2	1365284220315516	2012/11	user9054	password	34	80000	F
9055	OREUGZ	JNFOENYXCG	6971298765 Dell Way	\N	ILUPAMQ	NV	84291	US	1	JNFOENYXCG@dell.com	6971298765	3	7558552553877235	2012/03	user9055	password	74	60000	M
9056	YFCXOQ	CDVPCTSIBD	2480202161 Dell Way	\N	DRDPHUL	WI	40822	US	1	CDVPCTSIBD@dell.com	2480202161	5	5715834526345134	2012/04	user9056	password	45	100000	F
9057	MUBDXE	ZMGSFPUISL	2324414893 Dell Way	\N	MISHURQ	WA	56153	US	1	ZMGSFPUISL@dell.com	2324414893	5	8032008658628912	2010/10	user9057	password	37	20000	M
9058	IELNDX	UWDKQLDBXL	7866593853 Dell Way	\N	UFFMVEZ	WV	13317	US	1	UWDKQLDBXL@dell.com	7866593853	3	8113498392980547	2008/07	user9058	password	42	40000	M
9059	TXVRRR	UCIGFKEREJ	8966347573 Dell Way	\N	XREBQDC	MD	68558	US	1	UCIGFKEREJ@dell.com	8966347573	3	2572517022956162	2009/10	user9059	password	81	100000	M
9060	SQKKLM	SRSCVJHEGZ	4054269169 Dell Way	\N	JIPNKAE	IN	50761	US	1	SRSCVJHEGZ@dell.com	4054269169	3	3427474415395409	2009/06	user9060	password	89	100000	F
9061	KHOWAG	PCBYKGFJPN	7455707406 Dell Way	\N	ZDYZHGL	NJ	78067	US	1	PCBYKGFJPN@dell.com	7455707406	5	3144123017787933	2011/09	user9061	password	44	20000	F
9062	YZAEOD	FMOLSXBGXE	4747087203 Dell Way	\N	EXMKJCE	AZ	92029	US	1	FMOLSXBGXE@dell.com	4747087203	4	6738305603154004	2011/11	user9062	password	65	80000	M
9063	RWKUBX	INPGPVEUAB	8837099686 Dell Way	\N	GLKIPMG	AL	31778	US	1	INPGPVEUAB@dell.com	8837099686	5	1914349731057882	2010/07	user9063	password	86	20000	F
9064	IZLFIZ	UPOQTJQUPB	1311136208 Dell Way	\N	FXRRDSY	AK	55792	US	1	UPOQTJQUPB@dell.com	1311136208	3	1170193462632596	2012/09	user9064	password	46	40000	M
9065	VMAVHP	KXJTOEIQJG	5727748039 Dell Way	\N	HBJZZJN	AL	92457	US	1	KXJTOEIQJG@dell.com	5727748039	5	6745498939882965	2012/04	user9065	password	43	80000	M
9066	JOBZZZ	ISNMADWGLX	6128043980 Dell Way	\N	QLXAYYY	MN	95068	US	1	ISNMADWGLX@dell.com	6128043980	2	3081061287317425	2012/02	user9066	password	18	40000	M
9067	BGRBPJ	OBKSYREWHP	9006876476 Dell Way	\N	THNSGAR	SD	44668	US	1	OBKSYREWHP@dell.com	9006876476	4	5684649605304003	2012/01	user9067	password	34	100000	F
9068	XAWGPY	RIWIMSPBMX	5490674839 Dell Way	\N	PFDPWYZ	PA	69807	US	1	RIWIMSPBMX@dell.com	5490674839	4	7021282111760230	2011/08	user9068	password	86	80000	M
9069	UWFTNN	PWZILBVJQA	8012540984 Dell Way	\N	MGWLFQC	OK	33883	US	1	PWZILBVJQA@dell.com	8012540984	3	8914818624965847	2011/01	user9069	password	55	60000	M
9070	SGMGWI	GEUHZDYZQE	6704220128 Dell Way	\N	WBJMECT	WV	56726	US	1	GEUHZDYZQE@dell.com	6704220128	4	6131365879904479	2008/03	user9070	password	54	100000	F
9071	ZDHHJM	BRLEPLVUIW	3886786762 Dell Way	\N	DVBGOAT	GA	73828	US	1	BRLEPLVUIW@dell.com	3886786762	2	9133424426428976	2012/03	user9071	password	43	80000	F
9072	QBSDDK	OHZACTJZXE	7272003917 Dell Way	\N	BDTCXYU	HI	37144	US	1	OHZACTJZXE@dell.com	7272003917	1	5692046408541501	2008/10	user9072	password	81	80000	M
9073	PUAZJI	ZKKTUKRYLV	5274458370 Dell Way	\N	SOSQIYY	AL	96669	US	1	ZKKTUKRYLV@dell.com	5274458370	1	8077212237287314	2009/10	user9073	password	67	100000	M
9074	RXYZXJ	KRDVICHDUV	5672759142 Dell Way	\N	VLEUJET	TX	33784	US	1	KRDVICHDUV@dell.com	5672759142	2	1261872360017150	2008/02	user9074	password	61	100000	F
9075	OWZXHQ	ACYCKCXFYI	8536164774 Dell Way	\N	JSSOLOV	WI	78286	US	1	ACYCKCXFYI@dell.com	8536164774	1	9069202703423800	2010/01	user9075	password	87	100000	M
9076	XWFOXI	MASOXXMFGF	2186086928 Dell Way	\N	XUQMPOG	MI	74712	US	1	MASOXXMFGF@dell.com	2186086928	5	7737779520452023	2008/11	user9076	password	66	20000	M
9077	WOQEBR	WQOUCUAISV	9796357391 Dell Way	\N	YELNKXF	ND	79249	US	1	WQOUCUAISV@dell.com	9796357391	4	6657438191585243	2011/08	user9077	password	44	60000	F
9078	ARGROW	GIZAJHTEFY	9206963816 Dell Way	\N	QTJNZXH	WA	59191	US	1	GIZAJHTEFY@dell.com	9206963816	3	2768052021507174	2009/01	user9078	password	47	40000	M
9079	QZHNFQ	MGZUZEZYUS	9384649422 Dell Way	\N	HHREPQT	MS	28211	US	1	MGZUZEZYUS@dell.com	9384649422	4	3494101044721901	2009/01	user9079	password	19	100000	F
9080	IMGYZM	XTMBSLWLSD	3246543894 Dell Way	\N	DXSUQFZ	ND	99115	US	1	XTMBSLWLSD@dell.com	3246543894	5	1456438959576189	2009/11	user9080	password	23	80000	F
9081	IOIVMB	INUTKGLOJI	5781541028 Dell Way	\N	HDZMDOM	MA	49016	US	1	INUTKGLOJI@dell.com	5781541028	4	3729380148928613	2011/04	user9081	password	65	100000	M
9082	ZTGABU	VVEBGSLPZP	8766783423 Dell Way	\N	PMSDZCO	MS	75527	US	1	VVEBGSLPZP@dell.com	8766783423	1	9814001201651992	2010/01	user9082	password	74	60000	M
9083	ANWVIR	AJYTUOSJDF	8865015824 Dell Way	\N	CHEEVRX	OH	78840	US	1	AJYTUOSJDF@dell.com	8865015824	2	8252474685199560	2011/09	user9083	password	62	80000	F
9084	MNOENY	DGTRZDVEFC	6187314438 Dell Way	\N	IJYAGQU	DC	87501	US	1	DGTRZDVEFC@dell.com	6187314438	4	6130623125936837	2008/06	user9084	password	76	80000	M
9085	JVNHYT	AQTDLXIOGS	6309788045 Dell Way	\N	NGZEADA	NJ	92215	US	1	AQTDLXIOGS@dell.com	6309788045	4	4503147003240883	2009/06	user9085	password	45	80000	F
9086	XAFQAW	JEIHNWOFKV	6683781704 Dell Way	\N	FOWIOMG	DE	34290	US	1	JEIHNWOFKV@dell.com	6683781704	3	7503388646524400	2008/04	user9086	password	18	100000	F
9087	FOJBYN	JFAGUGRPMF	9424103757 Dell Way	\N	MUUYAYF	NY	54943	US	1	JFAGUGRPMF@dell.com	9424103757	4	8110094644594938	2012/07	user9087	password	25	20000	F
9088	LFAZPG	AWAHNQTTCN	7872642494 Dell Way	\N	NBOMGGZ	GA	92634	US	1	AWAHNQTTCN@dell.com	7872642494	1	5408994965720922	2012/04	user9088	password	61	40000	M
9089	QHDXHA	YOOOIHRVVT	1566790771 Dell Way	\N	KHARGFO	AL	41793	US	1	YOOOIHRVVT@dell.com	1566790771	5	6861819685436786	2011/03	user9089	password	31	40000	M
9090	IFUIDJ	WSREKNZDYG	4262500664 Dell Way	\N	DPNJENS	IA	47758	US	1	WSREKNZDYG@dell.com	4262500664	5	6636147436685861	2010/03	user9090	password	27	100000	F
9091	YENIBG	AFQNEUMLXC	5762709330 Dell Way	\N	YHGMZNX	KY	46459	US	1	AFQNEUMLXC@dell.com	5762709330	5	6514431662391872	2011/10	user9091	password	19	60000	M
9092	OXAUXF	LLKFXWDZVK	8017530714 Dell Way	\N	GHKTFTE	OK	67112	US	1	LLKFXWDZVK@dell.com	8017530714	2	4468623084016144	2011/12	user9092	password	41	40000	M
9093	IETOPF	ZUCVYCQIJY	5482790414 Dell Way	\N	TDDMHVC	CA	30320	US	1	ZUCVYCQIJY@dell.com	5482790414	5	2742609881795943	2012/03	user9093	password	22	20000	F
9094	VSZARU	DNSGDBQBUT	5177865880 Dell Way	\N	FHBBKDH	VA	11534	US	1	DNSGDBQBUT@dell.com	5177865880	4	3263596641365439	2010/11	user9094	password	64	40000	M
9095	QJGKNU	DTYFJAZDFH	6259746658 Dell Way	\N	EGRINOI	WV	33131	US	1	DTYFJAZDFH@dell.com	6259746658	3	2114203027449548	2009/11	user9095	password	69	100000	F
9096	ZGSTKM	RPWRPZWWDC	4889258475 Dell Way	\N	NMQBUPI	MA	19460	US	1	RPWRPZWWDC@dell.com	4889258475	4	9613154029473664	2008/06	user9096	password	31	20000	M
9097	XVCKNR	GEGFACJDQV	4880812664 Dell Way	\N	TRQJZAM	MD	65923	US	1	GEGFACJDQV@dell.com	4880812664	3	1706686688587069	2011/08	user9097	password	75	60000	F
9098	XXZPDE	WJFZSIPOCG	8913458460 Dell Way	\N	EMGEYQU	MA	26827	US	1	WJFZSIPOCG@dell.com	8913458460	5	8495393278077246	2011/07	user9098	password	41	60000	F
9099	IEOMAX	RZQAOEDUIP	7258619182 Dell Way	\N	ANORIYW	GA	94469	US	1	RZQAOEDUIP@dell.com	7258619182	5	5079308541491628	2008/06	user9099	password	81	40000	M
9100	LUPJMO	ZMDEQXMGYA	2129770413 Dell Way	\N	UQITMNR	FL	45534	US	1	ZMDEQXMGYA@dell.com	2129770413	2	8497868064325304	2008/07	user9100	password	49	60000	F
9101	AUVPUI	SYYQLEOLYF	5767331904 Dell Way	\N	URSHJWS	MO	17333	US	1	SYYQLEOLYF@dell.com	5767331904	3	6498872394207866	2012/12	user9101	password	86	100000	M
9102	TONBGL	AXXEMIDRCV	9380023370 Dell Way	\N	JKEGCRI	NM	24573	US	1	AXXEMIDRCV@dell.com	9380023370	3	1823437534738332	2012/07	user9102	password	77	80000	F
9103	ISKUSH	RWTAAKDVUN	9428708632 Dell Way	\N	AAQRIHV	ID	89129	US	1	RWTAAKDVUN@dell.com	9428708632	1	5064414695836604	2011/10	user9103	password	60	20000	F
9104	ZWEHNB	BOBLRXGFXG	5112557493 Dell Way	\N	VPPDLWA	MA	10526	US	1	BOBLRXGFXG@dell.com	5112557493	1	8057324742898346	2008/03	user9104	password	37	20000	F
9105	LIQNJE	PVVMBAKIWZ	6004879109 Dell Way	\N	XZLTAUU	MN	94313	US	1	PVVMBAKIWZ@dell.com	6004879109	3	2361009591259062	2012/07	user9105	password	34	40000	M
9106	WUFAJB	WWCWHKTGIT	6345231618 Dell Way	\N	SCTNWFL	MD	74225	US	1	WWCWHKTGIT@dell.com	6345231618	2	3300980231259018	2012/07	user9106	password	26	80000	F
9107	ISRKOO	MLVXECFXUH	8626106505 Dell Way	\N	RHDWTOP	KS	81337	US	1	MLVXECFXUH@dell.com	8626106505	1	3678233847022057	2012/11	user9107	password	61	40000	M
9108	HSCVEN	QBRTHPNPHV	4486606063 Dell Way	\N	TDOHTXC	NE	14267	US	1	QBRTHPNPHV@dell.com	4486606063	3	8963754987809808	2012/11	user9108	password	48	40000	M
9109	NBTASV	RLCHZROULS	2660895571 Dell Way	\N	JSLGVAH	GA	62367	US	1	RLCHZROULS@dell.com	2660895571	1	4992285653017461	2011/06	user9109	password	90	20000	M
9110	TCGOUR	QCRIQMTJVM	8614740393 Dell Way	\N	UCHVKMK	NE	70379	US	1	QCRIQMTJVM@dell.com	8614740393	1	1935388186480850	2012/04	user9110	password	62	60000	F
9111	VDFNUH	FDYSWHOJCQ	9274281672 Dell Way	\N	QXADHPV	DC	81868	US	1	FDYSWHOJCQ@dell.com	9274281672	5	1808487404603511	2010/07	user9111	password	54	40000	M
9112	SXMZDP	YVMFJVHZMF	5798557423 Dell Way	\N	AQNQLQL	LA	67962	US	1	YVMFJVHZMF@dell.com	5798557423	5	2975726094562560	2008/04	user9112	password	85	80000	F
9113	KSIARD	MWNIENVJOL	4527497626 Dell Way	\N	WEXNQHE	DE	25725	US	1	MWNIENVJOL@dell.com	4527497626	1	5106340958736837	2009/12	user9113	password	65	80000	M
9114	ZTHDFE	QOJEJTSUPX	6486327853 Dell Way	\N	SDNZIRD	OH	89311	US	1	QOJEJTSUPX@dell.com	6486327853	1	8228066281415523	2009/09	user9114	password	50	40000	F
9115	TJSYAG	HEPAWKQTCT	6897501422 Dell Way	\N	HCBZGUW	TX	81804	US	1	HEPAWKQTCT@dell.com	6897501422	1	5870652053970844	2008/05	user9115	password	19	100000	M
9116	SUTYBX	NBUYSOAMVC	6918851340 Dell Way	\N	OUIIQED	IN	36661	US	1	NBUYSOAMVC@dell.com	6918851340	3	6810403603594751	2011/04	user9116	password	44	40000	F
9117	CICAWE	UUWIVIEYWY	4640395617 Dell Way	\N	HFPMIXT	WV	37922	US	1	UUWIVIEYWY@dell.com	4640395617	4	6114602148998529	2011/01	user9117	password	62	100000	F
9118	SXFWRA	TAVCETZDAE	5601911629 Dell Way	\N	SMMQGMY	NM	20363	US	1	TAVCETZDAE@dell.com	5601911629	3	2316621890291571	2008/04	user9118	password	54	100000	F
9119	SSWSLW	OOBHNEISXU	9344956119 Dell Way	\N	FOARMRU	WY	18676	US	1	OOBHNEISXU@dell.com	9344956119	1	4510741820558906	2010/12	user9119	password	59	20000	M
9120	LWCIKQ	JSEOAWLUBZ	9976197557 Dell Way	\N	VTMNNMP	MI	61969	US	1	JSEOAWLUBZ@dell.com	9976197557	5	5583911555353553	2010/01	user9120	password	28	20000	M
9121	FIIWRA	AFAXRVZRQS	7217675840 Dell Way	\N	DEFPURE	RI	59419	US	1	AFAXRVZRQS@dell.com	7217675840	2	6172735567670316	2012/05	user9121	password	52	20000	M
9122	UYIUYO	VWGQVXHOBL	6225730079 Dell Way	\N	UQFLVZA	MT	40339	US	1	VWGQVXHOBL@dell.com	6225730079	2	7124734745826573	2008/05	user9122	password	42	100000	F
9123	RQHGLE	MCAKJOLVJC	1778493426 Dell Way	\N	BUYBVMK	MA	83964	US	1	MCAKJOLVJC@dell.com	1778493426	3	3145897952839732	2010/04	user9123	password	60	20000	M
9124	XJJBWL	BHVQTRZVTU	3819531419 Dell Way	\N	UVPGFZB	KS	49053	US	1	BHVQTRZVTU@dell.com	3819531419	4	7444553100969643	2012/11	user9124	password	64	80000	F
9125	ZVCLXJ	HOCZNYTITO	1413155117 Dell Way	\N	XZUXBCI	MA	85914	US	1	HOCZNYTITO@dell.com	1413155117	2	7307417596224696	2011/01	user9125	password	85	80000	M
9126	ADVKLJ	NKWMDEFSCF	2244263493 Dell Way	\N	MZHPIRL	LA	95547	US	1	NKWMDEFSCF@dell.com	2244263493	1	1126481368206441	2008/09	user9126	password	84	20000	M
9127	SMHBZS	YMWDROFXBF	8286626355 Dell Way	\N	EQNVCWU	HI	92763	US	1	YMWDROFXBF@dell.com	8286626355	2	6714479297399522	2011/05	user9127	password	53	60000	M
9128	TNWMMI	IPAWVXXACO	9932456059 Dell Way	\N	OYQLSWJ	NC	23157	US	1	IPAWVXXACO@dell.com	9932456059	2	5685650873929263	2010/09	user9128	password	46	40000	F
9129	GSSPAI	PXEMVFPJTN	5860257517 Dell Way	\N	AEFWOTA	NC	11504	US	1	PXEMVFPJTN@dell.com	5860257517	1	7541002122685314	2012/04	user9129	password	88	20000	M
9130	RTZAIW	EVRJKBCXBH	6855570469 Dell Way	\N	DYWXZKY	MS	46279	US	1	EVRJKBCXBH@dell.com	6855570469	3	6966837271116675	2011/08	user9130	password	64	40000	F
9131	QIRNMN	EVYGYWIGAG	5988171365 Dell Way	\N	CXFMVSX	MS	23689	US	1	EVYGYWIGAG@dell.com	5988171365	1	7741619081702084	2008/05	user9131	password	24	100000	M
9132	UIEHMA	GTZCBGCIIA	2582760077 Dell Way	\N	OVWHSJL	ID	52207	US	1	GTZCBGCIIA@dell.com	2582760077	3	8873912066686899	2009/04	user9132	password	61	20000	M
9133	UJBVPV	USWAVFJWTE	4886642655 Dell Way	\N	SAXCLEO	NM	65350	US	1	USWAVFJWTE@dell.com	4886642655	5	8883281714282931	2008/12	user9133	password	50	100000	F
9134	NPXIKQ	FLLKUHEZAF	5597059735 Dell Way	\N	WDRARHQ	CO	27561	US	1	FLLKUHEZAF@dell.com	5597059735	1	2356487914919853	2012/12	user9134	password	51	60000	M
9135	JUYAAJ	LLETPDUUZX	1933952094 Dell Way	\N	MZOTQRY	DC	81879	US	1	LLETPDUUZX@dell.com	1933952094	1	7541733338963241	2010/07	user9135	password	37	100000	F
9136	FYKPKV	TDLWYFVVSV	6338254690 Dell Way	\N	KLMBKPW	MT	73672	US	1	TDLWYFVVSV@dell.com	6338254690	1	3511610283050686	2012/01	user9136	password	65	20000	M
9137	BQJWKN	HGLNCHFXRR	9699458655 Dell Way	\N	JTBZPPR	GA	69342	US	1	HGLNCHFXRR@dell.com	9699458655	1	7160509400069714	2011/02	user9137	password	66	80000	M
9138	ANEOUL	AINHNKZEUS	2628822562 Dell Way	\N	GTIVLOM	ME	65628	US	1	AINHNKZEUS@dell.com	2628822562	1	7812393420375884	2012/09	user9138	password	58	100000	F
9139	SLADLI	RTWBTBWMHP	7657050888 Dell Way	\N	VDBJQMZ	SD	56504	US	1	RTWBTBWMHP@dell.com	7657050888	4	2923355800099671	2009/07	user9139	password	49	20000	M
9140	LEKUVE	QXXRTJZJFC	6586469422 Dell Way	\N	KOTXOOK	IL	29280	US	1	QXXRTJZJFC@dell.com	6586469422	3	7679987467359752	2008/08	user9140	password	69	60000	M
9141	DHPHXM	FPFPPOUSZI	9618827626 Dell Way	\N	LWXAGEF	VA	76952	US	1	FPFPPOUSZI@dell.com	9618827626	5	3986190929077566	2011/06	user9141	password	24	80000	M
9142	RCQDHG	IWVXRNWAYS	2280336518 Dell Way	\N	XYZBEWV	CT	81978	US	1	IWVXRNWAYS@dell.com	2280336518	4	3097740252036601	2009/07	user9142	password	87	100000	M
9143	PBYVKU	QHLDDMBWJA	7773389516 Dell Way	\N	WLESGHN	MA	17120	US	1	QHLDDMBWJA@dell.com	7773389516	4	6803341154474766	2011/07	user9143	password	39	40000	M
9144	FCYASF	MVJYXGHYCT	2197432576 Dell Way	\N	CVZKIJM	CA	96346	US	1	MVJYXGHYCT@dell.com	2197432576	4	5235921233892441	2010/01	user9144	password	19	80000	F
9145	YRWEDS	OCQUKOXDRS	8902342547 Dell Way	\N	CCBLPDK	OK	94372	US	1	OCQUKOXDRS@dell.com	8902342547	1	1075397725217044	2012/10	user9145	password	30	100000	F
9146	BBOUPR	KKBZHERAHT	2490420443 Dell Way	\N	BTIFDBE	AL	27453	US	1	KKBZHERAHT@dell.com	2490420443	5	9722372620832176	2009/10	user9146	password	47	40000	M
9147	ZEKQPV	SODXGDEAFX	6120841210 Dell Way	\N	JLBKPCP	PA	99813	US	1	SODXGDEAFX@dell.com	6120841210	1	8003445207141341	2012/06	user9147	password	61	100000	M
9148	APFVHU	YFACJBHHKS	2770049986 Dell Way	\N	IUHKKBK	WV	22874	US	1	YFACJBHHKS@dell.com	2770049986	5	6585127496160567	2011/11	user9148	password	37	100000	F
9149	MRUHPZ	ISJJZQTSZO	8633283686 Dell Way	\N	AKYCVXF	AK	84504	US	1	ISJJZQTSZO@dell.com	8633283686	5	7436030226759613	2008/08	user9149	password	32	80000	F
9150	ZXXZFP	IOPYIIYWJI	3052587233 Dell Way	\N	ULDRREN	MT	98518	US	1	IOPYIIYWJI@dell.com	3052587233	4	6527422166429461	2010/03	user9150	password	83	60000	F
9151	UJIKRX	AQFIOCRXWC	8466998734 Dell Way	\N	BOUGBHF	IN	91748	US	1	AQFIOCRXWC@dell.com	8466998734	4	2224698107223958	2011/02	user9151	password	36	60000	M
9152	PYFMYW	SGKUYIRBKF	2304857243 Dell Way	\N	VQHCVPA	NY	38464	US	1	SGKUYIRBKF@dell.com	2304857243	3	5100039573851973	2009/12	user9152	password	88	100000	M
9153	EMUAEB	LZZUQAEVWU	5474033953 Dell Way	\N	DYQSYHB	CO	73433	US	1	LZZUQAEVWU@dell.com	5474033953	3	6722022616304458	2010/06	user9153	password	54	80000	M
9154	HRDJDC	IXSJBOFWSE	2252708621 Dell Way	\N	MKDUMFN	WI	74926	US	1	IXSJBOFWSE@dell.com	2252708621	3	2836806153878569	2011/01	user9154	password	29	100000	M
9155	HHWJQT	CZVQFRIJET	6735800516 Dell Way	\N	MZFSMEL	NJ	65627	US	1	CZVQFRIJET@dell.com	6735800516	2	7222782561089844	2011/03	user9155	password	49	20000	F
9156	HLCBNC	WEHONRSHDR	1145293552 Dell Way	\N	NWESHTI	WA	11733	US	1	WEHONRSHDR@dell.com	1145293552	4	2832625671289861	2010/10	user9156	password	67	80000	F
9157	TUUWRY	DFMUXTYPHV	7675587508 Dell Way	\N	TZDNIBN	KS	80050	US	1	DFMUXTYPHV@dell.com	7675587508	4	6206923527643085	2010/07	user9157	password	78	20000	F
9158	PAZOEE	AZBUXRBTKB	3357900109 Dell Way	\N	WYJXMSR	HI	52626	US	1	AZBUXRBTKB@dell.com	3357900109	4	9959372948855164	2008/10	user9158	password	40	80000	M
9159	HGALGZ	NBXEDQPEMO	7353975107 Dell Way	\N	OKAGBGS	KS	88720	US	1	NBXEDQPEMO@dell.com	7353975107	3	7174776727799327	2008/02	user9159	password	56	40000	F
9160	NTPMGQ	JLTABYMPMW	4743724073 Dell Way	\N	PSYWKHS	CT	72278	US	1	JLTABYMPMW@dell.com	4743724073	1	8110363414511085	2012/06	user9160	password	26	60000	F
9161	SZKJIV	CJXAWMNSCF	4841114617 Dell Way	\N	RYQYRTQ	CA	90118	US	1	CJXAWMNSCF@dell.com	4841114617	1	3861596038099378	2010/06	user9161	password	52	40000	F
9162	XPUSSE	QTACGTEMKD	1459990288 Dell Way	\N	CJVVZXT	MD	95021	US	1	QTACGTEMKD@dell.com	1459990288	5	5000350158661604	2010/03	user9162	password	84	60000	M
9163	SDNWTH	XWNQBZAFCJ	3806431095 Dell Way	\N	AYJXRTW	OK	74564	US	1	XWNQBZAFCJ@dell.com	3806431095	2	9408198668621480	2009/08	user9163	password	73	100000	M
9164	HUOPSL	DIMCIRFSRD	5142996010 Dell Way	\N	BPUVMNN	SC	77877	US	1	DIMCIRFSRD@dell.com	5142996010	1	4700198887381703	2009/12	user9164	password	33	60000	M
9165	UCLFFT	RICJNUBRVR	2270847399 Dell Way	\N	MQDZEYS	NJ	94953	US	1	RICJNUBRVR@dell.com	2270847399	5	8947281283326448	2009/05	user9165	password	63	20000	F
9166	BIRVAA	XKORLFNDRE	1215063353 Dell Way	\N	GRIFKYD	NC	81677	US	1	XKORLFNDRE@dell.com	1215063353	5	2443646183703095	2011/01	user9166	password	63	80000	F
9167	HOJILU	WDFCQIUUPL	1269372453 Dell Way	\N	DUVBYJW	WV	31111	US	1	WDFCQIUUPL@dell.com	1269372453	4	3252460754942149	2011/05	user9167	password	62	100000	M
9168	ZHITDL	ZGCIAXYLAT	1921890895 Dell Way	\N	GCRQYQW	WY	32802	US	1	ZGCIAXYLAT@dell.com	1921890895	4	6325829499401153	2011/08	user9168	password	52	80000	M
9169	ULAGLH	IUHFSTGLAI	6262777563 Dell Way	\N	CQHTMGZ	NE	91442	US	1	IUHFSTGLAI@dell.com	6262777563	2	5558350153733045	2008/12	user9169	password	46	100000	F
9170	LCWSKQ	ZQITWUTEWJ	2243079968 Dell Way	\N	MQWSPLQ	GA	74086	US	1	ZQITWUTEWJ@dell.com	2243079968	2	7213621241506190	2010/02	user9170	password	26	100000	F
9171	ZRPQRF	ZKCTDHQNTG	2673689863 Dell Way	\N	JMWUCBM	HI	39295	US	1	ZKCTDHQNTG@dell.com	2673689863	4	4810991981532425	2009/09	user9171	password	62	40000	F
9172	FYAKYL	NROUIBNPLZ	3631546927 Dell Way	\N	MFCOSIW	VA	16874	US	1	NROUIBNPLZ@dell.com	3631546927	2	8124729740899057	2012/07	user9172	password	30	20000	F
9173	FNKQAC	EVKGIASIMX	6258945139 Dell Way	\N	KAQSXNU	FL	75561	US	1	EVKGIASIMX@dell.com	6258945139	1	3166871850844473	2011/03	user9173	password	68	100000	M
9174	COSETN	PAWPSEBQPC	7599344183 Dell Way	\N	GHZTCEM	NY	32108	US	1	PAWPSEBQPC@dell.com	7599344183	3	4789738547056914	2010/05	user9174	password	26	60000	M
9175	VRRJGS	FWKKXAZAHH	8367595653 Dell Way	\N	ZAKDNBK	ID	55230	US	1	FWKKXAZAHH@dell.com	8367595653	4	8888032220769674	2012/03	user9175	password	77	80000	M
9176	NDEFJA	QTYQTYYBXZ	9153801851 Dell Way	\N	LBMNMTA	IL	50555	US	1	QTYQTYYBXZ@dell.com	9153801851	2	6971649837214500	2011/12	user9176	password	58	40000	F
9177	SLLTBF	RSZPQBNPMP	9692512618 Dell Way	\N	CABWBIH	WI	60963	US	1	RSZPQBNPMP@dell.com	9692512618	4	5945430595427752	2010/11	user9177	password	65	40000	F
9178	DZKIQD	IFTJTJWILW	8611603441 Dell Way	\N	JIXSPWH	NE	59962	US	1	IFTJTJWILW@dell.com	8611603441	1	5150060211308301	2010/05	user9178	password	76	80000	F
9179	FYZIHF	CQYLMGXJQF	2581521454 Dell Way	\N	HJVERKS	MT	56568	US	1	CQYLMGXJQF@dell.com	2581521454	1	8817620277870447	2012/08	user9179	password	32	20000	M
9180	ENWJQN	HBZOZJFFQO	8554350746 Dell Way	\N	BUGLNTZ	OH	80261	US	1	HBZOZJFFQO@dell.com	8554350746	4	4788778521586210	2008/11	user9180	password	19	20000	F
9181	XOAKVC	KKBTPGKEIF	4247438707 Dell Way	\N	KTSETKY	NE	16393	US	1	KKBTPGKEIF@dell.com	4247438707	4	9422995456028732	2009/10	user9181	password	41	40000	F
9182	IRFKCP	MVETGIBLTV	5952619841 Dell Way	\N	DXOOVDP	FL	75165	US	1	MVETGIBLTV@dell.com	5952619841	3	5777422776911408	2012/11	user9182	password	83	40000	M
9183	CQPRCL	WVRFXCYSGV	6565667344 Dell Way	\N	GUQJKVC	WI	47585	US	1	WVRFXCYSGV@dell.com	6565667344	5	3372158196289092	2010/01	user9183	password	75	80000	M
9184	KHTVDP	MIMPGFWCLQ	3360346590 Dell Way	\N	TVBPXAZ	MT	85893	US	1	MIMPGFWCLQ@dell.com	3360346590	1	8991068014409394	2008/08	user9184	password	58	60000	M
9185	IGBYTK	LJRQFTCWMX	6884370592 Dell Way	\N	XBUXBIT	KS	40793	US	1	LJRQFTCWMX@dell.com	6884370592	2	9734648077283056	2009/10	user9185	password	82	60000	F
9186	YMVIXE	ZNKSPGFMEG	9244924873 Dell Way	\N	HCIPWQY	MT	10167	US	1	ZNKSPGFMEG@dell.com	9244924873	4	8244481903500856	2011/04	user9186	password	81	80000	M
9187	RBPWBD	HUTOZFSGNV	9891370182 Dell Way	\N	ODREBFE	WY	92857	US	1	HUTOZFSGNV@dell.com	9891370182	4	2623291419818997	2012/07	user9187	password	83	60000	M
9188	NLQQSK	JGJPYPDTDG	7638933010 Dell Way	\N	LIIQNHO	MS	17815	US	1	JGJPYPDTDG@dell.com	7638933010	2	6425321244169027	2011/11	user9188	password	31	20000	F
9189	UUAFEG	OUFEYZHELQ	5450425011 Dell Way	\N	MBDUQQX	LA	98431	US	1	OUFEYZHELQ@dell.com	5450425011	1	8942150565329940	2011/02	user9189	password	33	60000	M
9190	GRDNGY	SKWSSBDIOF	9676459455 Dell Way	\N	MJWCGFC	OR	29536	US	1	SKWSSBDIOF@dell.com	9676459455	3	4390053571201861	2008/11	user9190	password	42	60000	M
9191	MXVLQF	HIXIMGXSSG	4242381314 Dell Way	\N	OVMTXFZ	UT	66875	US	1	HIXIMGXSSG@dell.com	4242381314	1	5715806530788541	2011/06	user9191	password	24	20000	F
9192	XPZDXI	AGUHDNAJBV	2996103758 Dell Way	\N	WVSBVPS	FL	65245	US	1	AGUHDNAJBV@dell.com	2996103758	5	1465987782925367	2009/01	user9192	password	46	40000	M
9193	JIORJU	MQYZQHBMDX	4873454506 Dell Way	\N	EFSTXWJ	CT	78370	US	1	MQYZQHBMDX@dell.com	4873454506	3	8355495797935874	2012/08	user9193	password	53	20000	M
9194	BWJWJA	UIRCKDGHIL	5146945102 Dell Way	\N	ZCJWMMQ	VA	94265	US	1	UIRCKDGHIL@dell.com	5146945102	4	6416875705588610	2012/11	user9194	password	61	100000	M
9195	ZWDZQM	QSWUZECKEE	8174546572 Dell Way	\N	UBQGROF	DC	33007	US	1	QSWUZECKEE@dell.com	8174546572	1	2460790394339710	2009/01	user9195	password	86	40000	M
9196	BJONAH	KUGOXRSBLT	7079182153 Dell Way	\N	SSKGXON	OH	68570	US	1	KUGOXRSBLT@dell.com	7079182153	1	7568706973921508	2011/06	user9196	password	65	80000	M
9197	FFVNPP	UDMLVOWOHP	9408921176 Dell Way	\N	ZNMOBEF	OK	32826	US	1	UDMLVOWOHP@dell.com	9408921176	2	7393617666792125	2010/01	user9197	password	55	100000	F
9198	IIUYCX	KOTZLIGAHT	6547233603 Dell Way	\N	MWVQBNX	WY	87580	US	1	KOTZLIGAHT@dell.com	6547233603	3	8794943273533137	2008/05	user9198	password	22	60000	M
9199	WKVUUK	NTVVZVDTIZ	8471479875 Dell Way	\N	OZBCXBZ	MS	67968	US	1	NTVVZVDTIZ@dell.com	8471479875	4	1429039025213569	2012/02	user9199	password	75	80000	F
9200	QNHAAB	VWBRAUAAJZ	8258601885 Dell Way	\N	BMWCLJT	ID	11338	US	1	VWBRAUAAJZ@dell.com	8258601885	1	2052918243687600	2010/12	user9200	password	62	40000	F
9201	XGMYBJ	ZTJUTJETKQ	2243812060 Dell Way	\N	QNCAHJA	CA	57189	US	1	ZTJUTJETKQ@dell.com	2243812060	4	4992138781119138	2011/11	user9201	password	82	80000	F
9202	JPFSOY	BJSKNMVECJ	6226398917 Dell Way	\N	GCQPDTD	ID	48226	US	1	BJSKNMVECJ@dell.com	6226398917	1	3904419684316963	2010/08	user9202	password	50	100000	F
9203	RNVPPE	IASVVXXFDA	4011944733 Dell Way	\N	WTEPXLA	MO	50272	US	1	IASVVXXFDA@dell.com	4011944733	5	1978435294236988	2011/10	user9203	password	44	60000	F
9204	EBXJKX	CFTZCYDDUX	3550152922 Dell Way	\N	HJUSKHE	OR	29983	US	1	CFTZCYDDUX@dell.com	3550152922	3	9928929340094328	2011/12	user9204	password	39	100000	F
9205	FFKCHP	WHSUKVPHDZ	6311367757 Dell Way	\N	CWJJBCP	KS	65012	US	1	WHSUKVPHDZ@dell.com	6311367757	5	6099090242758394	2012/10	user9205	password	59	20000	M
9206	ZEHOAO	GVYCKGGKJC	1350245338 Dell Way	\N	TSDWIMM	VT	48670	US	1	GVYCKGGKJC@dell.com	1350245338	4	2959875463042408	2011/11	user9206	password	32	60000	F
9207	MDCAKX	ZNIFTTOVMH	1914086107 Dell Way	\N	ZJPLVNW	UT	38638	US	1	ZNIFTTOVMH@dell.com	1914086107	3	2756709353532642	2009/01	user9207	password	36	80000	F
9208	IUPGTC	PZWINSVVRE	5052979269 Dell Way	\N	KDAYAXG	CT	43942	US	1	PZWINSVVRE@dell.com	5052979269	3	4990800073835999	2011/03	user9208	password	65	20000	M
9209	GHTJXS	FFGYBBPGMT	9761712974 Dell Way	\N	GKUDRXN	CO	40640	US	1	FFGYBBPGMT@dell.com	9761712974	5	5923285280354322	2011/11	user9209	password	57	100000	F
9210	HGBAMG	GKIHAOTUVE	4150506724 Dell Way	\N	OZVMNYU	MO	76381	US	1	GKIHAOTUVE@dell.com	4150506724	1	6316711836960167	2012/12	user9210	password	72	20000	F
9211	UFSBLD	JTDYMXTRLS	7584313214 Dell Way	\N	MXGKSSD	AZ	82977	US	1	JTDYMXTRLS@dell.com	7584313214	5	8147583318408579	2010/02	user9211	password	20	40000	F
9212	TIUWSN	AQAXKRJDEH	7073254228 Dell Way	\N	JOABSCW	ME	15051	US	1	AQAXKRJDEH@dell.com	7073254228	5	2911745866760611	2011/03	user9212	password	59	60000	F
9213	JIEWIV	XFFPPJTWSH	3209673406 Dell Way	\N	XUZZRKA	KS	39457	US	1	XFFPPJTWSH@dell.com	3209673406	1	5462788306176663	2012/06	user9213	password	89	20000	M
9214	EBDAYJ	FNYOGVHOSB	8185454525 Dell Way	\N	ORSZSBH	WV	17995	US	1	FNYOGVHOSB@dell.com	8185454525	4	6222315924707801	2011/12	user9214	password	46	100000	M
9215	NZYWEM	VTSQBHICVA	5895535233 Dell Way	\N	VVTWDSZ	VT	53773	US	1	VTSQBHICVA@dell.com	5895535233	4	4818603906314820	2012/08	user9215	password	47	60000	M
9216	IIVUDP	NTQVCTRDOM	5531641931 Dell Way	\N	WLPPKNC	WI	30428	US	1	NTQVCTRDOM@dell.com	5531641931	5	9022569578606636	2012/05	user9216	password	56	40000	M
9217	IBUYPO	OKRHCUWORI	8278122173 Dell Way	\N	EGSRIRX	TX	59153	US	1	OKRHCUWORI@dell.com	8278122173	4	8917516089044512	2009/01	user9217	password	56	80000	F
9218	IPQWEB	NMDIISZQWG	5014064511 Dell Way	\N	JOPAMLO	IL	28123	US	1	NMDIISZQWG@dell.com	5014064511	4	2898818524554372	2012/04	user9218	password	38	40000	M
9219	YEBZSN	DAVVAMSGVH	7498463322 Dell Way	\N	WWTIKBN	UT	70072	US	1	DAVVAMSGVH@dell.com	7498463322	5	9603833977598698	2012/02	user9219	password	79	100000	F
9220	XXAKBB	GXBSQIOXFK	4033157297 Dell Way	\N	RNVSASJ	OR	58976	US	1	GXBSQIOXFK@dell.com	4033157297	4	7246615358628333	2008/09	user9220	password	19	20000	M
9221	BLQCSO	EKEMYCSJTF	2079603847 Dell Way	\N	EMFWWZL	FL	74262	US	1	EKEMYCSJTF@dell.com	2079603847	2	4447822783607990	2008/06	user9221	password	89	20000	M
9222	QHPELZ	JYYLQHFVMR	2290519126 Dell Way	\N	BJNBUST	VT	16087	US	1	JYYLQHFVMR@dell.com	2290519126	1	5467498621437699	2008/03	user9222	password	46	80000	M
9223	ZYYYHX	XTNFZJSQLB	4996460494 Dell Way	\N	ENWWGUY	MD	84586	US	1	XTNFZJSQLB@dell.com	4996460494	3	1593996857758611	2012/04	user9223	password	60	80000	F
9224	OTNLRH	ZWGJOXVQCI	2315115289 Dell Way	\N	MYOGXZC	LA	54833	US	1	ZWGJOXVQCI@dell.com	2315115289	1	7904314734973014	2011/12	user9224	password	88	40000	M
9225	MSKTRG	ABVXWLAEXZ	9875013858 Dell Way	\N	TEWSGFF	MA	46643	US	1	ABVXWLAEXZ@dell.com	9875013858	1	4503243089187890	2012/05	user9225	password	27	60000	F
9226	NFUUFV	PDSADWYCQC	9884831313 Dell Way	\N	ZIJEOTP	ND	87171	US	1	PDSADWYCQC@dell.com	9884831313	3	3225833766162395	2008/12	user9226	password	43	80000	F
9227	DLJZAM	SBQPASFDRO	3932888923 Dell Way	\N	MWCFMRC	MN	24921	US	1	SBQPASFDRO@dell.com	3932888923	3	2012510555330664	2011/03	user9227	password	36	100000	M
9228	QVRCNT	SCULHXDVKA	8973014702 Dell Way	\N	YPMPRYU	AK	57298	US	1	SCULHXDVKA@dell.com	8973014702	4	7710269481409342	2008/07	user9228	password	46	80000	F
9229	CWVVPY	PBGNEBXFAN	9105600296 Dell Way	\N	RQEQKFE	IL	90146	US	1	PBGNEBXFAN@dell.com	9105600296	3	4627913362812251	2009/03	user9229	password	71	40000	F
9230	PFRNVS	TIXVGCVTTM	4872708035 Dell Way	\N	YKWDODA	MI	62401	US	1	TIXVGCVTTM@dell.com	4872708035	4	7964581536594779	2008/02	user9230	password	78	80000	F
9231	MGEFAM	CVSERMYDKI	5413298901 Dell Way	\N	ZOWDOIS	AK	16848	US	1	CVSERMYDKI@dell.com	5413298901	1	2793936637695879	2009/11	user9231	password	57	100000	F
9232	RAEECZ	XGQKFTUNTI	1096800667 Dell Way	\N	KWXTPXV	AZ	16881	US	1	XGQKFTUNTI@dell.com	1096800667	2	9826044169254602	2010/03	user9232	password	28	40000	F
9233	HKIHIP	XSURNHKWSG	7651975281 Dell Way	\N	ULVRGXT	ID	37391	US	1	XSURNHKWSG@dell.com	7651975281	5	5635823447722942	2012/01	user9233	password	71	20000	F
9234	BLVQJN	KABSKXLQRW	2927739778 Dell Way	\N	MJDKDKS	TX	30648	US	1	KABSKXLQRW@dell.com	2927739778	4	3534053960349411	2012/12	user9234	password	73	20000	F
9235	OQSCBT	DUDBFUTCHC	2426278863 Dell Way	\N	GRGQJCW	NE	85499	US	1	DUDBFUTCHC@dell.com	2426278863	3	7810301012359560	2012/07	user9235	password	27	60000	F
9236	WOGPSA	TUFNOHVROM	6267332084 Dell Way	\N	XEWZBLV	HI	98247	US	1	TUFNOHVROM@dell.com	6267332084	1	5699586605187506	2011/08	user9236	password	69	60000	F
9237	YEXYXS	ELGLGXZSUE	5688469812 Dell Way	\N	OUGAQMZ	GA	64216	US	1	ELGLGXZSUE@dell.com	5688469812	5	2938256129156798	2009/06	user9237	password	47	20000	M
9238	ICOAGZ	HSFFSYAXNU	4798630690 Dell Way	\N	DNLPNQF	AR	59658	US	1	HSFFSYAXNU@dell.com	4798630690	2	1342885134741664	2012/06	user9238	password	68	20000	M
9239	GEUFMM	LRFJSCWNFK	2366617302 Dell Way	\N	YVYOAZC	MN	34244	US	1	LRFJSCWNFK@dell.com	2366617302	2	7304375237785280	2012/06	user9239	password	34	20000	M
9240	AHCMSU	SCNUZAAKYV	3786839176 Dell Way	\N	IMWIPIP	PA	65711	US	1	SCNUZAAKYV@dell.com	3786839176	4	1500679989811033	2010/09	user9240	password	67	60000	M
9241	UBSPTU	CNUCOEAJNN	3381260486 Dell Way	\N	GWDPMXF	SC	54684	US	1	CNUCOEAJNN@dell.com	3381260486	2	2573760788422078	2012/11	user9241	password	28	80000	M
9242	WIRQKF	LNTQODDBJA	7928636314 Dell Way	\N	FZMCEHP	MI	64853	US	1	LNTQODDBJA@dell.com	7928636314	2	5353299176320434	2012/02	user9242	password	47	80000	F
9243	BKWGWJ	AMYDQZMQFM	5625230905 Dell Way	\N	DHQKXBA	NV	51199	US	1	AMYDQZMQFM@dell.com	5625230905	3	6208587637171150	2012/05	user9243	password	20	100000	M
9244	XGQHGC	FKSFXJKJMS	1907433290 Dell Way	\N	ZXPBYGN	MN	84614	US	1	FKSFXJKJMS@dell.com	1907433290	2	2574844836723059	2008/05	user9244	password	86	20000	M
9245	OHXQNH	JSESCNFUND	6830467834 Dell Way	\N	KPBQCNM	GA	90860	US	1	JSESCNFUND@dell.com	6830467834	2	3403315016999841	2010/05	user9245	password	83	20000	M
9246	UUECDX	GWZUBUIEFX	9417337281 Dell Way	\N	GVAUIFR	WI	60970	US	1	GWZUBUIEFX@dell.com	9417337281	3	9374096761457624	2012/09	user9246	password	61	80000	F
9247	USQRZM	RTOLBSRZZM	7495146033 Dell Way	\N	ZTVFKUU	KY	38447	US	1	RTOLBSRZZM@dell.com	7495146033	1	1028596090618520	2009/10	user9247	password	52	20000	M
9248	CTMOKF	CWHVNHUAHO	9308007743 Dell Way	\N	VNYPHHX	AL	52381	US	1	CWHVNHUAHO@dell.com	9308007743	2	3440865105018020	2009/06	user9248	password	74	60000	F
9249	GBPMEM	UZABUAJIWW	3838970423 Dell Way	\N	HMEOKFB	KS	59167	US	1	UZABUAJIWW@dell.com	3838970423	4	9868555350694806	2008/03	user9249	password	31	40000	F
9250	UVLHPK	HRFIANEXVR	8369536906 Dell Way	\N	CJBHLJV	OR	18365	US	1	HRFIANEXVR@dell.com	8369536906	5	3701526267454028	2012/03	user9250	password	59	80000	M
9251	ZBPKIG	PRHDVFYNHI	4034967096 Dell Way	\N	OPTYKMA	IA	40120	US	1	PRHDVFYNHI@dell.com	4034967096	2	5581512818112970	2012/01	user9251	password	54	100000	F
9252	CHKJXC	RAYWZLEIAT	4724636866 Dell Way	\N	BYEOZLX	KS	69542	US	1	RAYWZLEIAT@dell.com	4724636866	2	7180536059197039	2012/02	user9252	password	74	20000	F
9253	EJHHAI	FXIQCQQWSO	8374975835 Dell Way	\N	BHOMEWD	NH	18524	US	1	FXIQCQQWSO@dell.com	8374975835	3	2852451252751052	2010/07	user9253	password	62	80000	M
9254	XBYGGV	PWYFMUYBWF	8195764052 Dell Way	\N	QIKMLZP	ID	54956	US	1	PWYFMUYBWF@dell.com	8195764052	5	1174475860781967	2010/08	user9254	password	84	40000	M
9255	VPYREU	QKHKIJHNZP	4775860822 Dell Way	\N	XMBXCIK	VA	26185	US	1	QKHKIJHNZP@dell.com	4775860822	2	8393171187024564	2009/08	user9255	password	55	20000	F
9256	LWJGMT	OXBYEPXTNK	2082406051 Dell Way	\N	UKNDVKH	HI	72346	US	1	OXBYEPXTNK@dell.com	2082406051	3	3861120323184878	2011/09	user9256	password	56	20000	M
9257	XIARWY	TVCISVVDQG	1482169956 Dell Way	\N	QTBBBHT	FL	86644	US	1	TVCISVVDQG@dell.com	1482169956	5	6187398575711996	2010/11	user9257	password	28	60000	F
9258	EDCCWX	FFQBBUSHLL	1774140217 Dell Way	\N	JMNRFSN	ID	57364	US	1	FFQBBUSHLL@dell.com	1774140217	5	4810153904370964	2009/05	user9258	password	65	60000	F
9259	TNJRTO	IUPDMXOYHB	2160069962 Dell Way	\N	MYGELOS	NC	45503	US	1	IUPDMXOYHB@dell.com	2160069962	4	7556008709128947	2011/03	user9259	password	32	60000	M
9260	OFLDOG	SRSQGRXHDW	3005942645 Dell Way	\N	OIHCAVM	DE	64567	US	1	SRSQGRXHDW@dell.com	3005942645	5	8131046196445824	2010/06	user9260	password	55	100000	M
9261	ZCGFVY	YMEPKMTGAC	8107176091 Dell Way	\N	ODCKQGZ	TX	28506	US	1	YMEPKMTGAC@dell.com	8107176091	2	7183958754874767	2009/04	user9261	password	46	40000	F
9262	RMEPLQ	UBAHUHIWVL	2362552942 Dell Way	\N	ZFCGFYM	AK	29422	US	1	UBAHUHIWVL@dell.com	2362552942	2	5311545429751277	2010/08	user9262	password	79	40000	F
9263	AVMRPN	SWIZEFVQFB	4051717986 Dell Way	\N	SLHQYHW	AZ	64930	US	1	SWIZEFVQFB@dell.com	4051717986	4	2749627542216331	2008/10	user9263	password	37	40000	M
9264	TWGHPD	PPHVLYAMQM	8815410757 Dell Way	\N	THKBDMR	MO	19256	US	1	PPHVLYAMQM@dell.com	8815410757	4	9377475200686604	2008/11	user9264	password	59	100000	M
9265	VEIYUY	FPJEQWUCPC	1250527579 Dell Way	\N	NRGZJSC	HI	44654	US	1	FPJEQWUCPC@dell.com	1250527579	2	3277992497198284	2010/03	user9265	password	18	60000	F
9266	IIEHOU	QTKMNNCQAU	2988541291 Dell Way	\N	WADPCJZ	DC	73446	US	1	QTKMNNCQAU@dell.com	2988541291	4	9434197442140432	2009/02	user9266	password	42	60000	F
9267	NWBHMU	RZIFCYFWVF	9984101792 Dell Way	\N	AKIJJMB	NE	29031	US	1	RZIFCYFWVF@dell.com	9984101792	5	4217723431531340	2009/05	user9267	password	79	100000	F
9268	XDSRVR	AAUYFQTLQE	8465634093 Dell Way	\N	UANGBCM	AZ	91595	US	1	AAUYFQTLQE@dell.com	8465634093	2	3506217957474291	2011/03	user9268	password	54	60000	F
9269	FGEXGE	RFKIZWZDQZ	9574346291 Dell Way	\N	RXATJCR	GA	53652	US	1	RFKIZWZDQZ@dell.com	9574346291	5	7494127188343555	2010/06	user9269	password	24	80000	M
9270	HOZMGE	WOETNIKNZH	8480608451 Dell Way	\N	NTRQLWC	MA	78769	US	1	WOETNIKNZH@dell.com	8480608451	5	2946692405734211	2012/06	user9270	password	85	20000	F
9271	XQHCNW	GGKPQXOYLI	5302633216 Dell Way	\N	PBTMEDG	WY	95990	US	1	GGKPQXOYLI@dell.com	5302633216	5	5034714348148555	2010/02	user9271	password	54	40000	M
9272	UJHRQO	BFFZUDKCTL	4326226166 Dell Way	\N	VGQZNQX	WY	57948	US	1	BFFZUDKCTL@dell.com	4326226166	2	6742015240713955	2012/09	user9272	password	46	80000	F
9273	RJSFKY	KJSOUUIFQO	6687313276 Dell Way	\N	VPCLNBZ	VA	51575	US	1	KJSOUUIFQO@dell.com	6687313276	4	2361052494030446	2008/06	user9273	password	34	80000	M
9274	YYFWIP	OXJJFPAULP	5845132867 Dell Way	\N	WXDYXBK	MT	83370	US	1	OXJJFPAULP@dell.com	5845132867	3	3412474069278687	2011/03	user9274	password	22	80000	F
9275	HNNWCK	FLQVLKGBHD	3899236403 Dell Way	\N	FFAGPNB	CT	16709	US	1	FLQVLKGBHD@dell.com	3899236403	5	3878090701531619	2009/07	user9275	password	53	80000	F
9276	ANFLTQ	BOCMUDTYIY	8902819725 Dell Way	\N	YPNMQQO	WI	57921	US	1	BOCMUDTYIY@dell.com	8902819725	2	1885744374245405	2009/01	user9276	password	32	40000	M
9277	KUHAWW	DIRHCQQBOF	8673804714 Dell Way	\N	OBVFPUT	MO	23251	US	1	DIRHCQQBOF@dell.com	8673804714	5	2478239597287029	2008/03	user9277	password	70	60000	F
9278	AMXXPG	OWIEMJTRYV	6728347533 Dell Way	\N	NELIYXM	RI	79436	US	1	OWIEMJTRYV@dell.com	6728347533	5	1053356031421571	2009/04	user9278	password	21	40000	M
9279	YGJFVG	OATYUKWPYB	7493244221 Dell Way	\N	AHZYTTS	MA	63879	US	1	OATYUKWPYB@dell.com	7493244221	4	8921886513940991	2011/02	user9279	password	64	80000	F
9280	AXFGLG	ZJAKGQJIRQ	5807412828 Dell Way	\N	HQJBITR	AR	54512	US	1	ZJAKGQJIRQ@dell.com	5807412828	5	6392557235434652	2008/07	user9280	password	88	20000	F
9281	ELXKLH	LVNCEVUVDK	1451925908 Dell Way	\N	FESYVUL	MA	63033	US	1	LVNCEVUVDK@dell.com	1451925908	3	2098523872904479	2008/09	user9281	password	59	20000	F
9282	MQPTCL	HEQDYLGIQL	5801304009 Dell Way	\N	BPHVBRK	CA	30743	US	1	HEQDYLGIQL@dell.com	5801304009	1	9762515415903182	2008/04	user9282	password	29	60000	M
9283	TIAFPE	VSDGZMXLNM	6384229483 Dell Way	\N	SINKTQQ	IL	76888	US	1	VSDGZMXLNM@dell.com	6384229483	2	1502963765058666	2011/12	user9283	password	90	60000	F
9284	ASWENO	IUOUSZIESR	2367948465 Dell Way	\N	SCKJSSC	IN	18148	US	1	IUOUSZIESR@dell.com	2367948465	1	1420404663309454	2008/07	user9284	password	40	20000	F
9285	EIVTRQ	HLIHUNZLGB	7161603925 Dell Way	\N	VPTORBQ	TN	22476	US	1	HLIHUNZLGB@dell.com	7161603925	5	7469330597668887	2012/02	user9285	password	18	20000	F
9286	VYCMFO	UMIHLUNNQD	2853846345 Dell Way	\N	HEVJUQM	MO	65936	US	1	UMIHLUNNQD@dell.com	2853846345	3	7676156367640943	2009/08	user9286	password	32	20000	M
9287	INUWIH	FQTZEGPHOU	1975891143 Dell Way	\N	CXPTJBJ	NE	60244	US	1	FQTZEGPHOU@dell.com	1975891143	5	2985752032604068	2009/11	user9287	password	76	80000	F
9288	PMSXSJ	RSNYIUMCXJ	5732424408 Dell Way	\N	RQTTAIH	CT	23180	US	1	RSNYIUMCXJ@dell.com	5732424408	3	1106855929829180	2009/01	user9288	password	47	100000	M
9289	DWGMNY	ZMHUZJSIBJ	6415124172 Dell Way	\N	CUJLCMP	NJ	93330	US	1	ZMHUZJSIBJ@dell.com	6415124172	5	9726649302523584	2008/11	user9289	password	54	20000	M
9290	TPHSPU	ZKTICCKLEE	2910604113 Dell Way	\N	VQHIFXG	SD	86286	US	1	ZKTICCKLEE@dell.com	2910604113	5	7727207329589874	2011/12	user9290	password	55	60000	M
9291	UEEPEP	INRKXDPBYF	8498888292 Dell Way	\N	IHLGNGC	OR	18061	US	1	INRKXDPBYF@dell.com	8498888292	3	1520528722088784	2009/12	user9291	password	64	20000	F
9292	VSGKBT	CLQGBSEHBM	2063844578 Dell Way	\N	SHZZKSB	HI	24123	US	1	CLQGBSEHBM@dell.com	2063844578	3	1681032993830740	2011/09	user9292	password	30	60000	F
9293	LZMECY	VIAONHQZZY	9133222757 Dell Way	\N	YYIRAOV	DC	21017	US	1	VIAONHQZZY@dell.com	9133222757	5	8530868736095727	2008/06	user9293	password	38	60000	F
9294	USOTOX	TCKATKARJZ	5827106587 Dell Way	\N	AAZPWDS	PA	11870	US	1	TCKATKARJZ@dell.com	5827106587	5	5526865621563048	2012/05	user9294	password	89	60000	F
9295	OIPLBS	WCLGCDQBEQ	7122359775 Dell Way	\N	ATMELGE	WV	18357	US	1	WCLGCDQBEQ@dell.com	7122359775	4	4938563969451934	2011/05	user9295	password	53	40000	M
9296	BRUUNW	FUYJKZNBAH	4092558097 Dell Way	\N	OESVJRX	AL	53343	US	1	FUYJKZNBAH@dell.com	4092558097	4	8813847901765258	2012/11	user9296	password	60	100000	M
9297	JRCFXX	DHIDVJDCYI	8502866561 Dell Way	\N	UTRMRSZ	AK	45106	US	1	DHIDVJDCYI@dell.com	8502866561	5	3694478013087064	2010/09	user9297	password	82	80000	F
9298	ZZIXDP	FGKPKMOSHI	7851213777 Dell Way	\N	JTZBSZM	ND	82220	US	1	FGKPKMOSHI@dell.com	7851213777	5	5785738618113101	2011/09	user9298	password	86	80000	M
9299	GNVVTC	FJMSYEZGOT	5699701290 Dell Way	\N	FQLECAZ	TX	98497	US	1	FJMSYEZGOT@dell.com	5699701290	3	7491039634682239	2010/02	user9299	password	49	80000	M
9300	HOKJUU	VMTALZOFFE	4322494145 Dell Way	\N	QKHRJDQ	VA	64678	US	1	VMTALZOFFE@dell.com	4322494145	2	7544536431785674	2012/01	user9300	password	45	20000	M
9301	ULJPGW	JGIIUNNZEY	7418780731 Dell Way	\N	GVHJMFZ	TN	60950	US	1	JGIIUNNZEY@dell.com	7418780731	4	6709987301379443	2008/09	user9301	password	35	100000	F
9302	QNKMWQ	UELHSLLQRH	4177168297 Dell Way	\N	YBTDBPS	RI	30285	US	1	UELHSLLQRH@dell.com	4177168297	5	9477461699862034	2010/10	user9302	password	24	40000	F
9303	MSDCMI	OUAZGRRNQT	1148057325 Dell Way	\N	GUUWMOB	TX	49672	US	1	OUAZGRRNQT@dell.com	1148057325	3	2857337432913482	2008/09	user9303	password	52	60000	F
9304	PRWXGQ	YFXQXKGQRB	7076685552 Dell Way	\N	LNOAPKM	NJ	85832	US	1	YFXQXKGQRB@dell.com	7076685552	4	5600889305584133	2008/04	user9304	password	82	80000	M
9305	TRFKQL	HHISNZKPLY	8841561906 Dell Way	\N	DLONYEJ	NH	90797	US	1	HHISNZKPLY@dell.com	8841561906	4	2751556205563247	2011/07	user9305	password	30	60000	F
9306	JXVVEC	DXQDHFOFJA	1304072585 Dell Way	\N	UWYYFNV	CA	35247	US	1	DXQDHFOFJA@dell.com	1304072585	5	8164100713562221	2009/05	user9306	password	90	60000	F
9307	VKKYOH	PRPUFVEFPA	7545323023 Dell Way	\N	DNGQJIY	MD	27564	US	1	PRPUFVEFPA@dell.com	7545323023	4	5829089620150626	2011/03	user9307	password	73	60000	M
9308	EMDMBU	BWZWAELBHZ	4316837814 Dell Way	\N	HYIQXSV	NJ	39441	US	1	BWZWAELBHZ@dell.com	4316837814	2	5635575305670500	2008/11	user9308	password	25	40000	F
9309	FTLAVH	ZRIEDJMCQL	1009252279 Dell Way	\N	LHIECYM	MO	33516	US	1	ZRIEDJMCQL@dell.com	1009252279	4	2279022516682744	2008/12	user9309	password	54	40000	M
9310	YINFIF	NMIXZLNKWV	1384926309 Dell Way	\N	SAYQNKX	MT	12864	US	1	NMIXZLNKWV@dell.com	1384926309	4	9552967363037170	2010/12	user9310	password	64	60000	F
9311	DSPIFC	RDCCQMZMEZ	8196983690 Dell Way	\N	KVNVSAW	RI	66771	US	1	RDCCQMZMEZ@dell.com	8196983690	2	6179319447837771	2010/10	user9311	password	80	60000	F
9312	MYSPPV	RSMDRZIRJE	4705067922 Dell Way	\N	EEXFARV	TN	98496	US	1	RSMDRZIRJE@dell.com	4705067922	2	8020249062217773	2009/11	user9312	password	37	80000	M
9313	ZIKVZC	IDUHMMRQRV	9507071535 Dell Way	\N	NWWESSE	CO	97247	US	1	IDUHMMRQRV@dell.com	9507071535	2	8407648519147188	2009/02	user9313	password	62	40000	F
9314	ZBLCJP	XRBJIRAEFW	5838607895 Dell Way	\N	BJPTOSS	MS	16878	US	1	XRBJIRAEFW@dell.com	5838607895	4	2846265751868486	2008/12	user9314	password	66	20000	M
9315	CGJSDB	TMJLNOQJPA	9423332856 Dell Way	\N	ZIORBBT	NH	78612	US	1	TMJLNOQJPA@dell.com	9423332856	4	7196363049559296	2010/11	user9315	password	66	80000	F
9316	AKGBES	LPFZFPPGOY	3722549849 Dell Way	\N	UFZWYOP	VA	36915	US	1	LPFZFPPGOY@dell.com	3722549849	3	2567503659985959	2012/03	user9316	password	39	20000	M
9317	NBUGNJ	MNPCCVRAQW	1303701560 Dell Way	\N	ZMVOCSW	MD	29567	US	1	MNPCCVRAQW@dell.com	1303701560	2	4762947578914464	2009/05	user9317	password	20	100000	F
9318	UCZEPM	TROPIPGFPS	4887725413 Dell Way	\N	BDVUAFA	AR	64250	US	1	TROPIPGFPS@dell.com	4887725413	2	9797753372695298	2010/03	user9318	password	48	40000	F
9319	KLXWFP	LUYABEQTGT	4634310184 Dell Way	\N	PBUVBVL	MS	26093	US	1	LUYABEQTGT@dell.com	4634310184	5	4573861675336957	2012/03	user9319	password	70	40000	M
9320	QCWGNR	FOSKEMQXBS	1766266174 Dell Way	\N	SXTNIGR	OR	28522	US	1	FOSKEMQXBS@dell.com	1766266174	3	4833266583271325	2012/10	user9320	password	24	60000	M
9321	YSJPYX	IIBUZZWRRU	3736301547 Dell Way	\N	KFCRWVW	WV	44256	US	1	IIBUZZWRRU@dell.com	3736301547	4	2374892231542617	2009/03	user9321	password	18	40000	M
9322	JYXHGF	JBEIYVASGF	2490784909 Dell Way	\N	UYCQVBA	CT	86549	US	1	JBEIYVASGF@dell.com	2490784909	3	1808914638590067	2008/11	user9322	password	21	60000	M
9323	YVBDEC	INBENTLTOJ	8832661167 Dell Way	\N	WEEYFIU	LA	83881	US	1	INBENTLTOJ@dell.com	8832661167	3	6932560064829887	2012/01	user9323	password	49	100000	M
9324	MZBPIP	QMDJXWYHTD	3435338803 Dell Way	\N	MRIULRP	IN	30382	US	1	QMDJXWYHTD@dell.com	3435338803	2	3757888439111412	2011/01	user9324	password	33	20000	F
9325	HTJWJW	ZTUWRBPUOG	4037736666 Dell Way	\N	DISUYAA	GA	31474	US	1	ZTUWRBPUOG@dell.com	4037736666	5	3860514986328781	2010/02	user9325	password	46	100000	M
9326	USGQRA	KNRMDMAJPI	6718792155 Dell Way	\N	BKHCLMI	RI	47303	US	1	KNRMDMAJPI@dell.com	6718792155	2	5686145146377385	2008/02	user9326	password	46	80000	M
9327	QLNRVB	IHEVIOLQQV	4247360676 Dell Way	\N	YSHLABV	NV	44178	US	1	IHEVIOLQQV@dell.com	4247360676	4	5767511943355203	2011/06	user9327	password	45	40000	M
9328	XBSYKA	CGIRRZHNXZ	7821669756 Dell Way	\N	UJZWEQF	NC	39000	US	1	CGIRRZHNXZ@dell.com	7821669756	2	8112249145749957	2008/09	user9328	password	67	20000	M
9329	KYELBK	UTBTAORAJA	7813438350 Dell Way	\N	ZFFQLTZ	FL	16138	US	1	UTBTAORAJA@dell.com	7813438350	2	7916576097253711	2010/05	user9329	password	56	100000	F
9330	RHJBBD	DVDSNDBODG	4384745714 Dell Way	\N	UUSOTXP	MS	29887	US	1	DVDSNDBODG@dell.com	4384745714	5	6082781712058932	2012/10	user9330	password	81	60000	F
9331	GRDJUZ	NMMQOBUVVO	2799265658 Dell Way	\N	NJHKZUQ	KY	76582	US	1	NMMQOBUVVO@dell.com	2799265658	2	5801000781357289	2008/10	user9331	password	62	40000	F
9332	TRHTET	GVHHPDCDQL	5545256472 Dell Way	\N	LBLGRTZ	VA	10946	US	1	GVHHPDCDQL@dell.com	5545256472	5	8530123014934362	2008/04	user9332	password	41	100000	M
9333	PQDJWY	RDOUGRKSDM	7750843751 Dell Way	\N	DJEXIBX	TN	99940	US	1	RDOUGRKSDM@dell.com	7750843751	5	3450879564043134	2008/11	user9333	password	34	80000	F
9334	JAIIRM	WLSOWKRIOA	8206609740 Dell Way	\N	MLJNJEN	CT	21355	US	1	WLSOWKRIOA@dell.com	8206609740	1	9635967398993672	2008/11	user9334	password	48	40000	M
9335	TSNFOZ	XDVIUEXVRJ	4779079741 Dell Way	\N	EESISWL	MT	13531	US	1	XDVIUEXVRJ@dell.com	4779079741	3	9032233414240182	2012/12	user9335	password	73	60000	M
9336	HUFGRI	CACHXYYGCD	7923515022 Dell Way	\N	ZKVVWJW	IN	90143	US	1	CACHXYYGCD@dell.com	7923515022	1	8393343535717578	2010/09	user9336	password	51	100000	F
9337	RCEZEF	CMCAKJCNJN	4751931335 Dell Way	\N	JFKSCSP	TX	85492	US	1	CMCAKJCNJN@dell.com	4751931335	2	5924536090809852	2012/03	user9337	password	20	60000	F
9338	FNMKQY	NRIXUWGIFM	8273764027 Dell Way	\N	SXOKNKG	WA	81084	US	1	NRIXUWGIFM@dell.com	8273764027	5	9865240605548024	2012/05	user9338	password	37	20000	M
9339	SLNRYE	AVZWCHBPZZ	3859819300 Dell Way	\N	DKNORLI	MS	32896	US	1	AVZWCHBPZZ@dell.com	3859819300	2	6442741454113275	2010/05	user9339	password	53	40000	M
9340	AZTFZP	EVSLXHLXLW	7562734775 Dell Way	\N	LZOWHBD	NJ	43990	US	1	EVSLXHLXLW@dell.com	7562734775	2	7743327020201833	2009/07	user9340	password	59	40000	F
9341	ILMYPH	RBFYNDKJOJ	1962217799 Dell Way	\N	YKRZOHJ	IL	54136	US	1	RBFYNDKJOJ@dell.com	1962217799	3	1035240655764937	2011/09	user9341	password	53	100000	F
9342	YYTGPU	MOHPYRDHPO	7639748104 Dell Way	\N	YPDGYKT	AR	89681	US	1	MOHPYRDHPO@dell.com	7639748104	4	6441731434781105	2009/09	user9342	password	72	20000	M
9343	MLGHXU	PNTGRAWGZL	3198450599 Dell Way	\N	JFJTYLQ	OH	22672	US	1	PNTGRAWGZL@dell.com	3198450599	5	8687631548382343	2012/02	user9343	password	54	60000	M
9344	TUMOJZ	HPRHMXHXGN	7311330390 Dell Way	\N	HAMSREW	VT	17821	US	1	HPRHMXHXGN@dell.com	7311330390	5	2787387064658105	2009/05	user9344	password	73	100000	F
9345	FNNFUD	WCPUJNBWUB	8034688214 Dell Way	\N	IMSMIQP	AR	57496	US	1	WCPUJNBWUB@dell.com	8034688214	2	9234980889596046	2010/03	user9345	password	23	80000	M
9346	PZMTWO	IQYVSUQTDD	6051734782 Dell Way	\N	MQLDFMQ	WY	76854	US	1	IQYVSUQTDD@dell.com	6051734782	3	9501621307805180	2011/04	user9346	password	65	40000	F
9347	DZDSIU	QDMKUGOXSE	5826352689 Dell Way	\N	JVJWMJP	AR	90819	US	1	QDMKUGOXSE@dell.com	5826352689	4	2693684034049511	2008/12	user9347	password	51	40000	M
9348	PAFJQJ	WBECPBVTKR	6336536228 Dell Way	\N	DGDNVFK	MA	90257	US	1	WBECPBVTKR@dell.com	6336536228	3	8429627030156554	2008/11	user9348	password	71	80000	M
9349	YANIWO	MYDOUXYLAE	5437410346 Dell Way	\N	ONAUYKR	NC	97633	US	1	MYDOUXYLAE@dell.com	5437410346	3	8660450075753034	2009/03	user9349	password	71	20000	F
9350	GNDUAC	YOWVMHWRWK	9588125612 Dell Way	\N	SQIDIWC	SC	51433	US	1	YOWVMHWRWK@dell.com	9588125612	1	7261874596588314	2011/03	user9350	password	87	100000	M
9351	CTTERI	BNVIJMFUFV	2302865594 Dell Way	\N	DIDZLYL	MD	99046	US	1	BNVIJMFUFV@dell.com	2302865594	1	2905266353860497	2008/01	user9351	password	87	20000	M
9352	SJLAKZ	VTIIYDOUGX	1726101477 Dell Way	\N	YFIWRTW	SD	84857	US	1	VTIIYDOUGX@dell.com	1726101477	5	8759682027623058	2008/02	user9352	password	64	80000	F
9353	CUWBQP	KZNNNHTLFZ	2849257336 Dell Way	\N	UCRNZMI	AR	45620	US	1	KZNNNHTLFZ@dell.com	2849257336	1	5490488911978901	2012/11	user9353	password	88	100000	M
9354	VZHLJG	YXUGRFMQZO	7112524781 Dell Way	\N	HNOUWPE	AZ	71486	US	1	YXUGRFMQZO@dell.com	7112524781	5	5795915371738375	2011/10	user9354	password	30	60000	M
9355	MXFSWC	NCTTOKTDSG	5499071913 Dell Way	\N	RNDHREZ	LA	17197	US	1	NCTTOKTDSG@dell.com	5499071913	1	9156291347928346	2011/06	user9355	password	70	20000	F
9356	XWFAKI	TEXEXBXETK	5219292254 Dell Way	\N	HACMZLO	MS	50047	US	1	TEXEXBXETK@dell.com	5219292254	1	9290940771810712	2008/04	user9356	password	39	20000	F
9357	NCPWWT	TBQUYVOIDO	2997701994 Dell Way	\N	KPOWEBH	NM	30738	US	1	TBQUYVOIDO@dell.com	2997701994	5	5878912717103959	2010/12	user9357	password	70	20000	F
9358	HXWBQY	SLWNAFROPH	9774205300 Dell Way	\N	DMLFUCL	WY	93458	US	1	SLWNAFROPH@dell.com	9774205300	3	8644808702636511	2011/07	user9358	password	81	20000	F
9359	TBCRTO	OGOTXDJFGV	5653827536 Dell Way	\N	QMPTXPR	UT	18774	US	1	OGOTXDJFGV@dell.com	5653827536	3	6833513315301389	2009/07	user9359	password	24	20000	M
9360	EVJSJQ	GCOJLTQHJC	2808988461 Dell Way	\N	WDZLUWO	IN	49522	US	1	GCOJLTQHJC@dell.com	2808988461	4	1115870079956948	2009/10	user9360	password	64	60000	M
9361	ZEAQLC	EVOXMVHPRK	9086671109 Dell Way	\N	ODFLSNX	VA	28927	US	1	EVOXMVHPRK@dell.com	9086671109	1	1377079343423247	2010/08	user9361	password	68	60000	M
9362	RDHUID	IFPENEVYTZ	9096014341 Dell Way	\N	DFRQCPW	WY	79631	US	1	IFPENEVYTZ@dell.com	9096014341	3	4901236563455314	2010/01	user9362	password	38	40000	F
9363	PBNSKT	IOGNKEHKHM	8755609696 Dell Way	\N	BYPRUPL	OH	20730	US	1	IOGNKEHKHM@dell.com	8755609696	2	2561969931703061	2008/07	user9363	password	45	80000	M
9364	XLAQUP	WIZAPJICLH	6169160916 Dell Way	\N	RCBHNUK	MA	16322	US	1	WIZAPJICLH@dell.com	6169160916	3	6741188001353294	2012/04	user9364	password	37	100000	M
9365	HLMWIU	WIKFRMRYET	5594619834 Dell Way	\N	AMGUWQW	MI	24595	US	1	WIKFRMRYET@dell.com	5594619834	2	4757730062119663	2011/03	user9365	password	27	20000	M
9366	QYALVJ	VBAISZNLZZ	9269377944 Dell Way	\N	SUWIRIN	DE	73476	US	1	VBAISZNLZZ@dell.com	9269377944	5	9412972166668624	2008/01	user9366	password	63	80000	M
9367	QCVZYW	ZHOYUZYURT	6535419943 Dell Way	\N	RAKZNOR	MI	57534	US	1	ZHOYUZYURT@dell.com	6535419943	3	6052533766254783	2009/02	user9367	password	58	100000	F
9368	JVFFVM	TTHTSCLLTM	5578168409 Dell Way	\N	VSZKKLY	AL	94258	US	1	TTHTSCLLTM@dell.com	5578168409	2	1916729776654392	2008/02	user9368	password	45	60000	M
9369	PQTCKN	JEFMPRFBNY	5880635273 Dell Way	\N	BYJNXKL	MD	68319	US	1	JEFMPRFBNY@dell.com	5880635273	3	7874448777642102	2012/11	user9369	password	69	60000	M
9370	LPYZYC	FKSWQTKPVI	7730709921 Dell Way	\N	YIFIUQZ	KS	17688	US	1	FKSWQTKPVI@dell.com	7730709921	2	9752405227161944	2010/09	user9370	password	54	100000	F
9371	LWGOCR	GZIAJXVSWE	6584441462 Dell Way	\N	YEYOEGQ	VT	53355	US	1	GZIAJXVSWE@dell.com	6584441462	2	2910278115887195	2008/04	user9371	password	56	60000	F
9372	UCGLJF	UJORFHNJFS	3222552603 Dell Way	\N	HUWOKUA	AR	24317	US	1	UJORFHNJFS@dell.com	3222552603	1	4897195216268301	2011/09	user9372	password	60	60000	M
9373	VAFAUO	PLTWZDCRKW	9519665579 Dell Way	\N	OZHJAIN	IA	53202	US	1	PLTWZDCRKW@dell.com	9519665579	1	2922019029036164	2010/07	user9373	password	22	40000	M
9374	GKJVZV	OWVRYMCUBB	1561147072 Dell Way	\N	BKBJYIW	UT	41130	US	1	OWVRYMCUBB@dell.com	1561147072	3	9262867167126388	2008/10	user9374	password	54	40000	F
9375	WEDSTZ	NLXAOSBPTM	3477449493 Dell Way	\N	RDKAZHJ	AL	73962	US	1	NLXAOSBPTM@dell.com	3477449493	1	5329434913117439	2011/07	user9375	password	64	80000	M
9376	UJMTWX	RWLKYBDLTG	4267243535 Dell Way	\N	WTGEDHW	MD	48914	US	1	RWLKYBDLTG@dell.com	4267243535	1	9674012773670256	2008/10	user9376	password	67	80000	F
9377	EOBCGY	OQXPTIJAFD	9531933710 Dell Way	\N	HJGOGRZ	NJ	85034	US	1	OQXPTIJAFD@dell.com	9531933710	4	6958695731591434	2011/05	user9377	password	79	80000	M
9378	XWEVKU	SAOBKPGNWQ	9363229456 Dell Way	\N	ULXLKNG	LA	22930	US	1	SAOBKPGNWQ@dell.com	9363229456	5	5933850199915469	2011/10	user9378	password	54	80000	M
9379	RMCMFC	BGMRNAODUZ	3208560805 Dell Way	\N	AFKOMUS	ME	79907	US	1	BGMRNAODUZ@dell.com	3208560805	1	6133584112860263	2011/11	user9379	password	35	60000	F
9380	IXOLZU	XRIYFLSFMY	7722148092 Dell Way	\N	QBLKTWE	WY	14310	US	1	XRIYFLSFMY@dell.com	7722148092	4	9177386875730008	2012/02	user9380	password	37	40000	F
9381	VSBQQT	YOYKHEWGUY	5358517552 Dell Way	\N	RERNJQO	CO	44402	US	1	YOYKHEWGUY@dell.com	5358517552	1	5887196920812131	2011/05	user9381	password	63	60000	F
9382	SEULDJ	KNQOKXJIOO	6137055306 Dell Way	\N	ZCXQRAA	DC	20905	US	1	KNQOKXJIOO@dell.com	6137055306	5	5728244369849563	2008/06	user9382	password	66	100000	M
9383	LIUUSH	LHSIQAXEAZ	7796061525 Dell Way	\N	CRQCRUF	ID	72965	US	1	LHSIQAXEAZ@dell.com	7796061525	3	2425289405044168	2010/05	user9383	password	76	100000	M
9384	PQKWCS	OKIPINPHPG	6579501780 Dell Way	\N	YSYTYFM	OH	70356	US	1	OKIPINPHPG@dell.com	6579501780	1	1227651957888156	2010/12	user9384	password	70	20000	M
9385	DWSVLD	EALRQTHXSZ	7725099989 Dell Way	\N	VLXBXPS	NC	74462	US	1	EALRQTHXSZ@dell.com	7725099989	5	7077780124731363	2010/12	user9385	password	38	60000	M
9386	ZKHCOH	NGXGNUZMQL	4650124086 Dell Way	\N	KRJAKXS	DE	87048	US	1	NGXGNUZMQL@dell.com	4650124086	4	8421931914985181	2011/03	user9386	password	66	80000	M
9387	YTEGHK	DOYYNKPYVH	8613987220 Dell Way	\N	HVSEOWA	WV	53002	US	1	DOYYNKPYVH@dell.com	8613987220	4	7155529761686922	2010/04	user9387	password	39	60000	F
9388	MRIXVW	VUKGJIBRPX	4341776453 Dell Way	\N	JTMFULR	NJ	19849	US	1	VUKGJIBRPX@dell.com	4341776453	1	4841915437486023	2011/07	user9388	password	54	20000	F
9389	VBCSXW	CDGKFXADGT	6298375363 Dell Way	\N	PMNBEEE	MT	36058	US	1	CDGKFXADGT@dell.com	6298375363	1	8836387522518636	2008/05	user9389	password	27	100000	F
9390	FQHCTL	JDQGDTNXJZ	7850487531 Dell Way	\N	LKDPORX	DE	86819	US	1	JDQGDTNXJZ@dell.com	7850487531	2	2808076987974346	2012/02	user9390	password	61	20000	M
9391	XFNIOR	YVVSITCIEM	2479755774 Dell Way	\N	LUBCRGZ	MI	53167	US	1	YVVSITCIEM@dell.com	2479755774	2	6793357549235225	2011/06	user9391	password	50	80000	M
9392	ZZGQYB	MQKFSTKFEE	6715414830 Dell Way	\N	HHVNGHZ	ME	63708	US	1	MQKFSTKFEE@dell.com	6715414830	1	1401218901854008	2008/11	user9392	password	70	20000	M
9393	YRTAEK	LJCETIJYPR	7062213547 Dell Way	\N	TDXACIQ	OR	58183	US	1	LJCETIJYPR@dell.com	7062213547	5	4445939235854894	2009/11	user9393	password	32	40000	M
9394	YJSJVC	LAVUJTKBNN	3047245613 Dell Way	\N	ZOPIEJV	TX	25203	US	1	LAVUJTKBNN@dell.com	3047245613	2	1275974966585636	2010/08	user9394	password	60	40000	M
9395	HTVJEV	FZFZJGNWFB	1236538791 Dell Way	\N	MNGVJCZ	NH	42602	US	1	FZFZJGNWFB@dell.com	1236538791	1	9652537034358830	2011/05	user9395	password	86	100000	F
9396	THIPNI	UMRBZNGBAU	7734254150 Dell Way	\N	IVDLVTU	TX	78628	US	1	UMRBZNGBAU@dell.com	7734254150	3	2564021293539554	2011/05	user9396	password	41	60000	M
9397	QAEYVQ	QWQEDSEXAA	7382682384 Dell Way	\N	ALVUFSN	WV	24882	US	1	QWQEDSEXAA@dell.com	7382682384	4	5834808647166938	2008/02	user9397	password	32	80000	F
9398	JQZZGV	QLYIPWIPXU	8601359657 Dell Way	\N	LRADFZH	VT	67079	US	1	QLYIPWIPXU@dell.com	8601359657	5	7717710570432246	2008/08	user9398	password	83	40000	F
9399	WKNSAY	RJNNSDKMOB	8568626703 Dell Way	\N	MSGLAEC	TX	17971	US	1	RJNNSDKMOB@dell.com	8568626703	5	7251106424257160	2011/04	user9399	password	86	60000	M
9400	LHSJZB	WMTZWGOYTH	2133145893 Dell Way	\N	EFHIHDL	DC	14175	US	1	WMTZWGOYTH@dell.com	2133145893	5	4013440911192447	2008/06	user9400	password	18	60000	M
9401	SWTUSF	OSCUHAOOFT	4473061050 Dell Way	\N	WOBAZEB	CO	15004	US	1	OSCUHAOOFT@dell.com	4473061050	1	5753537571523339	2009/08	user9401	password	40	20000	M
9402	BXGGLZ	IGGJUVONRC	3981946450 Dell Way	\N	ORCTTEU	CT	41011	US	1	IGGJUVONRC@dell.com	3981946450	3	1004382964223623	2011/08	user9402	password	55	80000	M
9403	TYYSHE	ZQZUFMMHBE	9222537195 Dell Way	\N	KUXOPBX	WA	61336	US	1	ZQZUFMMHBE@dell.com	9222537195	3	2854875642806291	2010/03	user9403	password	71	20000	F
9404	RWLWWC	VRHIDPJIZE	1662884656 Dell Way	\N	GOUHMSW	MA	34468	US	1	VRHIDPJIZE@dell.com	1662884656	5	5655446057207883	2012/12	user9404	password	68	60000	M
9405	EJSGFJ	ONNDXWDBCR	4064695565 Dell Way	\N	WKDOHNV	KY	38284	US	1	ONNDXWDBCR@dell.com	4064695565	1	3557531805243343	2008/08	user9405	password	28	20000	F
9406	WLFFZT	TDQPGSSXOD	2475952553 Dell Way	\N	BCKOYTW	IL	92027	US	1	TDQPGSSXOD@dell.com	2475952553	2	5982283485122026	2009/07	user9406	password	58	20000	M
9407	UJYNDB	DTHWMFLPGO	3172814896 Dell Way	\N	AVMUSTR	UT	16278	US	1	DTHWMFLPGO@dell.com	3172814896	1	6194625544827432	2012/04	user9407	password	56	60000	M
9408	LCVNGP	VCBANRHBRD	9526497254 Dell Way	\N	OMVHDSJ	MD	88942	US	1	VCBANRHBRD@dell.com	9526497254	1	2844385783188045	2010/10	user9408	password	84	100000	M
9409	TLCIGE	KHSBOUTRIF	3654377026 Dell Way	\N	NQJFZUC	WI	97229	US	1	KHSBOUTRIF@dell.com	3654377026	3	7641735394950957	2009/05	user9409	password	61	100000	M
9410	RHBWSI	OUXINORTCH	6581532233 Dell Way	\N	DHHXKFW	NY	67894	US	1	OUXINORTCH@dell.com	6581532233	5	9912508680485190	2009/11	user9410	password	75	100000	F
9411	VTVDHQ	BQDQIXSPBA	7843025257 Dell Way	\N	XZKDWBU	MN	96857	US	1	BQDQIXSPBA@dell.com	7843025257	4	8311741944868118	2010/07	user9411	password	87	40000	F
9412	UNPKOG	OEOMXENXCM	2250229765 Dell Way	\N	HFIJZUI	OR	53437	US	1	OEOMXENXCM@dell.com	2250229765	2	1371094731613993	2008/08	user9412	password	42	100000	F
9413	YITFWY	UJVZXSBKAG	1519929818 Dell Way	\N	SJGNSZA	TN	34933	US	1	UJVZXSBKAG@dell.com	1519929818	5	9404771010857076	2009/10	user9413	password	26	40000	F
9414	WOAUIK	QHHJIRJPKS	1419797767 Dell Way	\N	VYLVYGC	WY	27403	US	1	QHHJIRJPKS@dell.com	1419797767	2	1191887345165014	2008/09	user9414	password	29	20000	F
9415	EVPOLW	WUFNEVXXRV	8212005934 Dell Way	\N	IMUPPUU	NV	25314	US	1	WUFNEVXXRV@dell.com	8212005934	5	9176656547933818	2012/11	user9415	password	31	20000	M
9416	USDRPY	WCCSAZJVIV	5125977658 Dell Way	\N	PXLJRCO	MO	92365	US	1	WCCSAZJVIV@dell.com	5125977658	3	7792015249375255	2011/08	user9416	password	48	60000	F
9417	OCXMZA	ORAOAVXWLU	1921033930 Dell Way	\N	IVMLJZJ	TN	48287	US	1	ORAOAVXWLU@dell.com	1921033930	3	1279490512795746	2010/11	user9417	password	44	20000	F
9418	HOAHCR	HRSCOPOJYJ	3530152444 Dell Way	\N	WJTVSOG	SD	14419	US	1	HRSCOPOJYJ@dell.com	3530152444	2	9647100531961770	2011/05	user9418	password	89	100000	M
9419	ZEBRMT	KOIZDRYMOH	8430840620 Dell Way	\N	GJAVQVW	VA	25545	US	1	KOIZDRYMOH@dell.com	8430840620	3	6234641991090030	2012/06	user9419	password	56	80000	M
9420	PLCJVR	RVVJUIXBOH	7008416363 Dell Way	\N	CJXXGUC	AZ	39639	US	1	RVVJUIXBOH@dell.com	7008416363	5	8084817448165268	2009/08	user9420	password	49	80000	F
9421	ODYGVU	BEOJCQXJSH	2247851995 Dell Way	\N	GPNASPJ	LA	51537	US	1	BEOJCQXJSH@dell.com	2247851995	3	1995166092645377	2010/05	user9421	password	33	20000	M
9422	DJIYKN	MTPCRYUZEK	7052275124 Dell Way	\N	NECCNMO	NY	13902	US	1	MTPCRYUZEK@dell.com	7052275124	2	4675742790568620	2012/05	user9422	password	85	20000	M
9423	GZCTLW	IOOGJNKTAP	8227171173 Dell Way	\N	WDDJSUK	LA	14541	US	1	IOOGJNKTAP@dell.com	8227171173	2	4735001278575510	2011/04	user9423	password	27	100000	F
9424	GSSDBG	RHPFSJGHGJ	7316425967 Dell Way	\N	LPBGZLH	SC	72927	US	1	RHPFSJGHGJ@dell.com	7316425967	3	9887949314434082	2012/06	user9424	password	35	20000	F
9425	YFGFWN	VCGFIOLSZB	9260959852 Dell Way	\N	UFBGNVY	GA	42430	US	1	VCGFIOLSZB@dell.com	9260959852	1	8644097992684693	2008/02	user9425	password	21	20000	F
9426	HIEVDH	CJPQUIPVCV	9420547663 Dell Way	\N	XIISGNC	FL	59781	US	1	CJPQUIPVCV@dell.com	9420547663	2	6995915136765689	2012/06	user9426	password	89	40000	M
9427	EDYLFH	BVCJLYMGVU	3799900457 Dell Way	\N	ONBCQGQ	ND	62580	US	1	BVCJLYMGVU@dell.com	3799900457	3	1369078594725579	2009/11	user9427	password	78	60000	M
9428	TXEBZA	DILBUSWPHK	5827916459 Dell Way	\N	RJAXAPM	KS	21824	US	1	DILBUSWPHK@dell.com	5827916459	4	9726070259697736	2009/01	user9428	password	86	20000	M
9429	CEYDHH	OJCHFSOPJY	3857853463 Dell Way	\N	QHYFUHJ	IN	91514	US	1	OJCHFSOPJY@dell.com	3857853463	4	9879296051338316	2009/10	user9429	password	89	40000	M
9430	YMGFBP	IIVAXLJWBQ	9857617432 Dell Way	\N	UHLCQTZ	WA	46662	US	1	IIVAXLJWBQ@dell.com	9857617432	1	2811432205140590	2012/07	user9430	password	29	100000	F
9431	KCCAKL	VLJGUFILAP	3036778733 Dell Way	\N	WCFQCDA	CA	40909	US	1	VLJGUFILAP@dell.com	3036778733	1	9100765895564110	2009/12	user9431	password	86	100000	F
9432	BVMNRX	WYSCGECVBF	4962283724 Dell Way	\N	BRIFRKO	VT	51922	US	1	WYSCGECVBF@dell.com	4962283724	2	4692370763979852	2009/02	user9432	password	51	60000	M
9433	YYPVUN	OXUSZPTFRK	8259478708 Dell Way	\N	NWCYKZK	TN	36653	US	1	OXUSZPTFRK@dell.com	8259478708	2	4645059807226062	2009/08	user9433	password	43	40000	M
9434	YBKMPH	HHHWAMOLZK	2962195393 Dell Way	\N	NYUNIQV	CT	86624	US	1	HHHWAMOLZK@dell.com	2962195393	2	5568712683860213	2010/08	user9434	password	25	60000	M
9435	NAGUHN	BEOOSZOCNM	8996096988 Dell Way	\N	XAUNWXJ	AZ	38799	US	1	BEOOSZOCNM@dell.com	8996096988	4	9338882575742900	2012/02	user9435	password	60	60000	F
9436	VHLJJP	XXHXMKLYIL	9058931875 Dell Way	\N	SVHQFJZ	CO	10154	US	1	XXHXMKLYIL@dell.com	9058931875	1	2343567127361893	2010/08	user9436	password	40	40000	M
9437	TQGIOE	QMQBXOJJHF	2620088070 Dell Way	\N	RYKAXNA	SD	66051	US	1	QMQBXOJJHF@dell.com	2620088070	2	2966501571238041	2010/08	user9437	password	25	40000	F
9438	JOUOFG	EGDTQMBVDA	6540540603 Dell Way	\N	GEYUFTK	MA	12860	US	1	EGDTQMBVDA@dell.com	6540540603	5	6536974761635066	2011/02	user9438	password	79	20000	M
9439	QQWWUD	ZOUMQPQQWU	9452886248 Dell Way	\N	OQZHAJI	NM	30408	US	1	ZOUMQPQQWU@dell.com	9452886248	2	3867081323172897	2011/06	user9439	password	89	60000	F
9440	WHXZGL	UTBJJSGEGW	1440450848 Dell Way	\N	DNXNWOS	SC	92214	US	1	UTBJJSGEGW@dell.com	1440450848	3	4325919589959085	2008/12	user9440	password	51	100000	F
9441	IWNURH	WAQOHUUDYI	8904530769 Dell Way	\N	BLFPEZN	HI	61431	US	1	WAQOHUUDYI@dell.com	8904530769	2	5980690621770919	2009/02	user9441	password	76	80000	F
9442	IMRPIS	GXZASDZAEK	4135448778 Dell Way	\N	GUPFHUU	DE	13980	US	1	GXZASDZAEK@dell.com	4135448778	3	2564488949254155	2008/03	user9442	password	31	60000	M
9443	WBZOIW	NIPRHQVSWP	3751411067 Dell Way	\N	HBXCWBD	HI	59166	US	1	NIPRHQVSWP@dell.com	3751411067	2	7439599052537233	2010/11	user9443	password	44	40000	M
9444	IXFFKO	UCWLXPHNWJ	7649525787 Dell Way	\N	LZFMCLA	MD	82155	US	1	UCWLXPHNWJ@dell.com	7649525787	5	6847698600962759	2008/03	user9444	password	59	60000	F
9445	UROJMQ	GXOVEBSNMR	6590534657 Dell Way	\N	TZUEZFZ	OR	18095	US	1	GXOVEBSNMR@dell.com	6590534657	5	3919539518654347	2008/04	user9445	password	50	100000	M
9446	ZJKQQI	ELMGEATWTS	3343797959 Dell Way	\N	QXSVWLY	MS	35764	US	1	ELMGEATWTS@dell.com	3343797959	4	6051330074667931	2011/09	user9446	password	54	80000	F
9447	XIRFMD	STISMELEVJ	2841980420 Dell Way	\N	XRGJPTQ	UT	50694	US	1	STISMELEVJ@dell.com	2841980420	3	2304962658789009	2011/04	user9447	password	33	80000	M
9448	WVCAOV	IGIMSNICKZ	7137796190 Dell Way	\N	ITPCKMN	NJ	13569	US	1	IGIMSNICKZ@dell.com	7137796190	2	3883034943137318	2012/12	user9448	password	85	80000	M
9449	AUIWCP	EPHRYKCXSW	4078142041 Dell Way	\N	NUHZIXA	AL	29167	US	1	EPHRYKCXSW@dell.com	4078142041	5	2383498799055815	2009/09	user9449	password	86	40000	F
9450	GEPWIE	EADODAGZOB	5662999455 Dell Way	\N	GNKDOLJ	VA	40119	US	1	EADODAGZOB@dell.com	5662999455	1	1117742152884602	2010/06	user9450	password	52	80000	M
9451	BPZGTA	JHDKOCYQJM	8332664545 Dell Way	\N	BNBMXYU	MD	21121	US	1	JHDKOCYQJM@dell.com	8332664545	5	6338785591535271	2009/07	user9451	password	34	40000	F
9452	FPXFYF	IJULHKVULI	5577029430 Dell Way	\N	VXFUSQX	MT	54140	US	1	IJULHKVULI@dell.com	5577029430	5	1654401730280369	2011/03	user9452	password	35	100000	M
9453	DDSJMB	DXJNTDZBZX	5420708243 Dell Way	\N	HUPYSDK	GA	95955	US	1	DXJNTDZBZX@dell.com	5420708243	5	2136206256691366	2011/11	user9453	password	82	100000	F
9454	PFMRJK	AXDEWFDTNY	6136581204 Dell Way	\N	JLQMWVL	LA	78249	US	1	AXDEWFDTNY@dell.com	6136581204	1	6702374957501889	2010/12	user9454	password	65	20000	F
9455	DSOOTL	SXHYBBMZKX	8258962626 Dell Way	\N	PXUKIDE	VT	30711	US	1	SXHYBBMZKX@dell.com	8258962626	2	2722597568295896	2010/06	user9455	password	45	80000	F
9456	YEWJXU	QVVRHUCFKZ	6120620975 Dell Way	\N	AUIDZFJ	SC	62943	US	1	QVVRHUCFKZ@dell.com	6120620975	2	1122273397166281	2012/11	user9456	password	29	100000	F
9457	BFYVWU	QOCLRHVQHQ	8009111390 Dell Way	\N	YLQEVKT	MD	69129	US	1	QOCLRHVQHQ@dell.com	8009111390	2	5632104719989002	2012/03	user9457	password	58	100000	F
9458	MUIGLX	IWOQSEYJDK	6058466846 Dell Way	\N	ZIFKBQB	TX	97448	US	1	IWOQSEYJDK@dell.com	6058466846	4	2747368225362152	2008/10	user9458	password	65	60000	M
9459	ZWZWEW	KVPOTYSEYA	2576626456 Dell Way	\N	KICAJYZ	WA	75042	US	1	KVPOTYSEYA@dell.com	2576626456	1	5385643301997334	2012/08	user9459	password	21	80000	F
9460	BQRXAN	MPHLHLJIVR	5832674782 Dell Way	\N	KVBIVZB	WY	10993	US	1	MPHLHLJIVR@dell.com	5832674782	5	6799691325984896	2010/08	user9460	password	27	80000	F
9461	UNGHAW	OMEAWMVNWQ	2885373377 Dell Way	\N	PFLOGLO	RI	32231	US	1	OMEAWMVNWQ@dell.com	2885373377	2	8519104399718345	2009/12	user9461	password	22	20000	M
9462	ILOEAA	IAWVWKRNZW	5540710740 Dell Way	\N	ZODKCXR	KS	33728	US	1	IAWVWKRNZW@dell.com	5540710740	4	3222663981840014	2010/10	user9462	password	73	100000	F
9463	IBHIKI	FFEPXSPURD	3892402461 Dell Way	\N	XCGVTOB	ID	29041	US	1	FFEPXSPURD@dell.com	3892402461	5	1101929457858204	2008/09	user9463	password	37	40000	M
9464	OTFWYL	BOJTEDLHBN	3918532252 Dell Way	\N	OWHCYOI	IA	47098	US	1	BOJTEDLHBN@dell.com	3918532252	2	2262937904335558	2010/09	user9464	password	86	20000	F
9465	DAKPBZ	YUDBGLCTZZ	2671566031 Dell Way	\N	BCXQKDB	OK	53473	US	1	YUDBGLCTZZ@dell.com	2671566031	2	2944814662449062	2008/06	user9465	password	67	40000	F
9466	CWMBUH	FVNQYHPXJR	6854180938 Dell Way	\N	UZBYAUL	HI	18466	US	1	FVNQYHPXJR@dell.com	6854180938	2	5791976120322943	2009/08	user9466	password	89	60000	F
9467	MMGTSB	HIAPYYYQTY	2091454596 Dell Way	\N	SRZMDFP	RI	59388	US	1	HIAPYYYQTY@dell.com	2091454596	1	2443996325135231	2008/07	user9467	password	63	60000	F
9468	WISXQB	YFAWEQPDIH	1181603651 Dell Way	\N	CVKIKEW	NC	33717	US	1	YFAWEQPDIH@dell.com	1181603651	4	8152671904768796	2011/03	user9468	password	78	60000	M
9469	OKDPJJ	PFOGVROCUK	7394414236 Dell Way	\N	MCVQYJX	WV	99048	US	1	PFOGVROCUK@dell.com	7394414236	4	2652437786571681	2010/02	user9469	password	69	20000	M
9470	WSWGIC	UOXMDAGONJ	9017685506 Dell Way	\N	JDISBHS	RI	93174	US	1	UOXMDAGONJ@dell.com	9017685506	2	1319677731953561	2010/05	user9470	password	59	60000	F
9471	LSKOMZ	LZCMFRZPAD	2626591785 Dell Way	\N	XTEFLZD	KS	35611	US	1	LZCMFRZPAD@dell.com	2626591785	5	7174088468775154	2011/05	user9471	password	75	20000	F
9472	FSOEEN	HRTYQIZTGS	8933310222 Dell Way	\N	YMDXQMF	SD	46810	US	1	HRTYQIZTGS@dell.com	8933310222	3	8155064435210080	2011/09	user9472	password	81	100000	F
9473	LBQZJH	SIYBHRIZQV	8473127955 Dell Way	\N	DNLQSGA	NH	81786	US	1	SIYBHRIZQV@dell.com	8473127955	2	5804694857914001	2011/02	user9473	password	90	20000	F
9474	QCPYVX	WXFOFFEAIS	1406484321 Dell Way	\N	MZLSABN	TN	39222	US	1	WXFOFFEAIS@dell.com	1406484321	3	5313782765064389	2008/09	user9474	password	68	80000	M
9475	HQQENN	JCTOHTXZFW	3483449833 Dell Way	\N	LYWMLSU	MS	32291	US	1	JCTOHTXZFW@dell.com	3483449833	3	9348300603684040	2012/03	user9475	password	70	40000	M
9476	ILKVUM	OJTIHTOEEN	9280899486 Dell Way	\N	AQYTLLZ	OK	99849	US	1	OJTIHTOEEN@dell.com	9280899486	4	3063074045814574	2011/12	user9476	password	25	100000	F
9477	NVEZKO	TSVMHZRUAI	4956865268 Dell Way	\N	TTTFTMF	NY	23567	US	1	TSVMHZRUAI@dell.com	4956865268	2	1800492858514189	2010/04	user9477	password	51	20000	F
9478	QAMEUF	ZHMZYHZGBT	7385977448 Dell Way	\N	AGNMMEQ	VT	53693	US	1	ZHMZYHZGBT@dell.com	7385977448	3	7876062687952072	2008/06	user9478	password	80	80000	M
9479	IZIOZP	BYOIYVKSVQ	6625705152 Dell Way	\N	FHDJXAW	NJ	53217	US	1	BYOIYVKSVQ@dell.com	6625705152	4	9794400108512492	2010/07	user9479	password	55	100000	M
9480	VJNLKM	ZTKUDCPUHW	4484221202 Dell Way	\N	XRUYNKK	DE	26520	US	1	ZTKUDCPUHW@dell.com	4484221202	4	7850648941937835	2012/06	user9480	password	40	80000	M
9481	VDGHDZ	RXDUNXCKVT	5733736389 Dell Way	\N	ETHPELT	NC	18017	US	1	RXDUNXCKVT@dell.com	5733736389	3	5952403064817191	2012/02	user9481	password	45	80000	F
9482	QYLQQJ	TLWRNGMHLG	6881251070 Dell Way	\N	OAKAUYC	IN	44960	US	1	TLWRNGMHLG@dell.com	6881251070	1	5991600997280330	2008/10	user9482	password	81	80000	M
9483	IHKRAV	NSIUEPFKEF	7363781653 Dell Way	\N	VEZTHHD	WA	49266	US	1	NSIUEPFKEF@dell.com	7363781653	5	3101057520136237	2010/08	user9483	password	89	100000	M
9484	JOYECQ	NWUCBFHHBM	3246611552 Dell Way	\N	HUTPYSA	NY	70128	US	1	NWUCBFHHBM@dell.com	3246611552	2	3683883446734399	2009/02	user9484	password	32	60000	M
9485	DUUTHQ	OKSURZVDGQ	6003583082 Dell Way	\N	XVPPWGG	CO	55273	US	1	OKSURZVDGQ@dell.com	6003583082	2	6742379384115339	2011/12	user9485	password	41	100000	M
9486	CQZSFJ	KZBKUERLBN	4874092859 Dell Way	\N	ARJHYMU	MO	81568	US	1	KZBKUERLBN@dell.com	4874092859	2	7481890460476280	2011/02	user9486	password	48	100000	M
9487	KPZTAY	UKTZBFBOFS	9124321650 Dell Way	\N	YNQKIDE	OR	41983	US	1	UKTZBFBOFS@dell.com	9124321650	3	5344223188702017	2009/05	user9487	password	36	80000	M
9488	FLYEGJ	YFLDHZJZYW	6194070528 Dell Way	\N	QIETMYC	MD	48706	US	1	YFLDHZJZYW@dell.com	6194070528	4	8092583616729827	2012/06	user9488	password	71	20000	M
9489	RFDBEJ	MHQMRPKNFS	8835531902 Dell Way	\N	SYFQBPC	NM	38979	US	1	MHQMRPKNFS@dell.com	8835531902	3	7681841297075153	2011/07	user9489	password	63	40000	M
9490	TIXCVF	SHWIRKNKCM	3498828178 Dell Way	\N	PTOFVEN	OK	67625	US	1	SHWIRKNKCM@dell.com	3498828178	2	2395351028069854	2012/08	user9490	password	83	80000	M
9491	UTTZLA	WTSGHCIUSC	3686316453 Dell Way	\N	IYYNMRD	OR	97819	US	1	WTSGHCIUSC@dell.com	3686316453	4	6209485670085997	2008/04	user9491	password	55	100000	F
9492	GZMHWF	ZCNCLHVNPT	7284126026 Dell Way	\N	MDFDGYD	ND	63960	US	1	ZCNCLHVNPT@dell.com	7284126026	4	8951326414942742	2009/10	user9492	password	84	60000	M
9493	JTPPTR	CWDKRRALDD	1871967392 Dell Way	\N	RHKPKYF	CO	73542	US	1	CWDKRRALDD@dell.com	1871967392	2	5138532106298954	2008/10	user9493	password	33	40000	M
9494	VZHNCE	QMVHMHLQYS	2118489193 Dell Way	\N	AODYTFR	TX	58353	US	1	QMVHMHLQYS@dell.com	2118489193	5	3920712440274656	2009/03	user9494	password	81	20000	F
9495	EQHIHT	EOGLZWJSWY	9108751372 Dell Way	\N	VVSBMOO	NJ	47216	US	1	EOGLZWJSWY@dell.com	9108751372	5	6829682123381645	2011/02	user9495	password	80	100000	M
9496	DGAXLP	DWPAGHWFCS	5549197526 Dell Way	\N	XDFLSVW	NJ	79778	US	1	DWPAGHWFCS@dell.com	5549197526	2	8920765157788993	2009/04	user9496	password	64	60000	M
9497	RKAHNX	WNEDKJGDGK	8136344996 Dell Way	\N	ISDDOTX	AZ	22583	US	1	WNEDKJGDGK@dell.com	8136344996	3	5214642850682140	2010/11	user9497	password	22	20000	F
9498	CJVZGJ	DKTNQWTBFL	5747586244 Dell Way	\N	EIAXGBB	AR	53283	US	1	DKTNQWTBFL@dell.com	5747586244	3	4522255479358137	2010/07	user9498	password	68	80000	M
9499	NQFWUP	QHGNBHSMLB	4942986492 Dell Way	\N	NJIOLJB	WV	85776	US	1	QHGNBHSMLB@dell.com	4942986492	3	4811987345106900	2008/03	user9499	password	46	80000	M
9500	PNQEEY	KRZSKMEMZN	4986232322 Dell Way	\N	VOZEPYA	AL	53732	US	1	KRZSKMEMZN@dell.com	4986232322	1	7300378147047014	2012/10	user9500	password	58	60000	F
9501	FPMDAE	CSPPWCOKXC	5443618445 Dell Way	\N	JBSICTU	NC	90255	US	1	CSPPWCOKXC@dell.com	5443618445	2	7228937476407737	2008/10	user9501	password	18	40000	F
9502	MKJRNB	GCYIRIGUSI	8231861167 Dell Way	\N	MAKFVYC	IN	37599	US	1	GCYIRIGUSI@dell.com	8231861167	2	1744446445722133	2012/08	user9502	password	50	40000	M
9503	VZNXGP	VPGEVBXDNX	8920472201 Dell Way	\N	OTSMWAU	NV	44708	US	1	VPGEVBXDNX@dell.com	8920472201	3	9964156463276596	2009/10	user9503	password	90	20000	M
9504	MBZCWO	JBKKYNXWCR	9887383095 Dell Way	\N	PONPJEZ	IA	67765	US	1	JBKKYNXWCR@dell.com	9887383095	3	4811016724910587	2012/09	user9504	password	31	60000	M
9505	EORTXS	DHRRFNUWCI	6553731271 Dell Way	\N	JSSOSZF	OH	59804	US	1	DHRRFNUWCI@dell.com	6553731271	4	3561028609517962	2011/02	user9505	password	22	100000	M
9506	SSQLWY	CODQIATRKL	2744584930 Dell Way	\N	JYEJEWX	RI	56808	US	1	CODQIATRKL@dell.com	2744584930	3	7013808714691550	2009/07	user9506	password	45	100000	F
9507	AKDYNR	CEZDXROJBN	6133355496 Dell Way	\N	NKRJILX	MS	99838	US	1	CEZDXROJBN@dell.com	6133355496	4	5842678244225681	2012/09	user9507	password	76	100000	F
9508	XXSPAW	PDUGSEHFSS	8341655192 Dell Way	\N	WBAHZNH	NC	35115	US	1	PDUGSEHFSS@dell.com	8341655192	3	1158409039024263	2011/06	user9508	password	30	60000	F
9509	WDKTSO	NZGRHLJZHL	8223969098 Dell Way	\N	ZPLNWZU	NY	53153	US	1	NZGRHLJZHL@dell.com	8223969098	2	9538091316353532	2012/10	user9509	password	42	100000	M
9510	TPRHCQ	OUXAEXHQWX	5059234210 Dell Way	\N	BJTAEKN	WV	72646	US	1	OUXAEXHQWX@dell.com	5059234210	5	5618556836154312	2011/10	user9510	password	51	60000	F
9511	DVMTKH	RKLOSBLPCV	9639009619 Dell Way	\N	IDZTQZL	CA	92382	US	1	RKLOSBLPCV@dell.com	9639009619	5	7428191961254925	2010/05	user9511	password	25	60000	F
9512	PIQWZB	IOTJAJMVRP	4841840825 Dell Way	\N	VLGUXIS	TX	26926	US	1	IOTJAJMVRP@dell.com	4841840825	2	6291388167068363	2010/10	user9512	password	78	20000	F
9513	LZDNHR	GRRPENHTJT	1869400547 Dell Way	\N	ADQIWMN	IL	77105	US	1	GRRPENHTJT@dell.com	1869400547	5	6025506935548038	2012/12	user9513	password	67	40000	M
9514	UXFMDX	ETBSBVBUVF	2883160597 Dell Way	\N	LDBXQJQ	OR	25914	US	1	ETBSBVBUVF@dell.com	2883160597	4	1989277495536953	2012/01	user9514	password	20	80000	M
9515	GEBDIV	EAWZCRVHCY	1011707624 Dell Way	\N	JAPSRIX	UT	97799	US	1	EAWZCRVHCY@dell.com	1011707624	4	1160733797587454	2008/06	user9515	password	87	40000	M
9516	AKZVPA	SPCKKKNJTN	3170730024 Dell Way	\N	YLEGJBF	LA	83146	US	1	SPCKKKNJTN@dell.com	3170730024	2	3424669784493744	2008/08	user9516	password	83	40000	F
9517	WBRXUH	ZESKSBDFZP	5729571166 Dell Way	\N	KFYLLHG	OH	71332	US	1	ZESKSBDFZP@dell.com	5729571166	5	4072147245518863	2010/02	user9517	password	48	40000	F
9518	CFXJFC	CPUDSACHKI	6157739588 Dell Way	\N	GVUOCMG	NJ	40882	US	1	CPUDSACHKI@dell.com	6157739588	1	4848701598122716	2012/05	user9518	password	59	20000	M
9519	MMTPOI	JRBKUJUCPQ	2093523397 Dell Way	\N	XETJKJS	WV	47751	US	1	JRBKUJUCPQ@dell.com	2093523397	5	8012497972697020	2011/01	user9519	password	42	20000	M
9520	CTBLDT	MNNVIQLYNP	3254940830 Dell Way	\N	RWZBOYM	OH	91084	US	1	MNNVIQLYNP@dell.com	3254940830	2	9510032078251244	2010/07	user9520	password	51	80000	F
9521	NCLHPY	VKGMWFZLXW	3026901691 Dell Way	\N	LYLJLDH	NY	56362	US	1	VKGMWFZLXW@dell.com	3026901691	2	1573675348423421	2011/12	user9521	password	44	40000	F
9522	UNQTIB	AUXGUIDRUC	8426528982 Dell Way	\N	CENGLFT	NV	51650	US	1	AUXGUIDRUC@dell.com	8426528982	2	4672500477638096	2008/07	user9522	password	51	100000	F
9523	CTLDTG	BABJDSEGVI	8469544494 Dell Way	\N	TBTYVKK	NV	78226	US	1	BABJDSEGVI@dell.com	8469544494	5	4022280985955149	2009/11	user9523	password	49	40000	M
9524	WNICOJ	DYMWCTRLMT	7081951894 Dell Way	\N	ELPPWGI	OK	17227	US	1	DYMWCTRLMT@dell.com	7081951894	5	9231399918440730	2008/05	user9524	password	53	100000	M
9525	VCMEGK	RCNKUYXODJ	4158223771 Dell Way	\N	DSGJBYL	OR	94933	US	1	RCNKUYXODJ@dell.com	4158223771	5	3923002853989601	2012/10	user9525	password	34	80000	M
9526	SWDDOG	RZAQWOTGRL	7251461163 Dell Way	\N	MBNLMGJ	TN	16922	US	1	RZAQWOTGRL@dell.com	7251461163	4	8990888277068735	2012/05	user9526	password	75	80000	F
9527	XTUEKT	EAPTUWLGIM	9690323248 Dell Way	\N	TTYADUC	SD	51169	US	1	EAPTUWLGIM@dell.com	9690323248	4	8305940758436919	2011/05	user9527	password	20	80000	F
9528	UVOOAP	DUJZFQIRJB	7302590068 Dell Way	\N	QJFLLAX	ME	78218	US	1	DUJZFQIRJB@dell.com	7302590068	1	2194639739114791	2011/11	user9528	password	37	60000	M
9529	VCSKGM	UGRKOJUQAE	7631387189 Dell Way	\N	VLQVJBP	AR	31782	US	1	UGRKOJUQAE@dell.com	7631387189	4	1834272150415927	2008/04	user9529	password	74	100000	F
9530	MGQZAW	RLLAFBBKXN	5004600156 Dell Way	\N	BTWCIXJ	CA	73046	US	1	RLLAFBBKXN@dell.com	5004600156	1	1217464752029627	2009/11	user9530	password	49	80000	F
9531	BREYIP	JJVLLGIYHC	5220621088 Dell Way	\N	VKKTTNL	GA	63142	US	1	JJVLLGIYHC@dell.com	5220621088	3	5504930373746902	2012/02	user9531	password	65	100000	M
9532	VXDLHM	GTYNBWUDSF	2529367077 Dell Way	\N	OLYCXER	LA	61975	US	1	GTYNBWUDSF@dell.com	2529367077	2	7357873195782305	2012/03	user9532	password	55	80000	F
9533	QBLDIF	BVGYQKQVZC	3115174920 Dell Way	\N	UBAYTJN	VT	67040	US	1	BVGYQKQVZC@dell.com	3115174920	4	8857537126168610	2011/05	user9533	password	20	40000	F
9534	MNTROP	YNFJEBJGWL	2293671841 Dell Way	\N	HUEQICH	ND	83083	US	1	YNFJEBJGWL@dell.com	2293671841	2	2574582537636161	2008/09	user9534	password	61	80000	F
9535	JIUYHH	DRLFASBLZW	7222444967 Dell Way	\N	QQESXTN	AR	15678	US	1	DRLFASBLZW@dell.com	7222444967	2	7762128140311689	2009/11	user9535	password	87	80000	F
9536	SONASE	MXEEZQEVGV	6254790284 Dell Way	\N	AYSUMTV	DE	97257	US	1	MXEEZQEVGV@dell.com	6254790284	3	8654535025358201	2010/02	user9536	password	23	40000	M
9537	PHJTTH	YYGPCCVXCU	2760773461 Dell Way	\N	QWHJSLI	IL	90682	US	1	YYGPCCVXCU@dell.com	2760773461	5	9912208738271148	2009/01	user9537	password	65	100000	F
9538	AQCHOA	ODDQZBTURP	4367013710 Dell Way	\N	BBIMKPJ	NH	47612	US	1	ODDQZBTURP@dell.com	4367013710	5	5489655449055135	2008/09	user9538	password	80	20000	F
9539	YJXZXB	COADIUVYWW	7764303122 Dell Way	\N	GIGVSWG	CA	73731	US	1	COADIUVYWW@dell.com	7764303122	1	4820654978975654	2011/02	user9539	password	73	60000	M
9540	RNLSQZ	SUHNPFJMMS	7378196666 Dell Way	\N	SHKOONH	IN	66222	US	1	SUHNPFJMMS@dell.com	7378196666	5	8064965664874763	2010/06	user9540	password	39	20000	M
9541	SVPSNK	ABZGKLSDEA	5085487408 Dell Way	\N	NTOBAWR	OR	78794	US	1	ABZGKLSDEA@dell.com	5085487408	2	3019270529970527	2011/04	user9541	password	33	60000	F
9542	VFRFFT	EMEQEHUEVO	6252535707 Dell Way	\N	TWPPNIJ	WY	57842	US	1	EMEQEHUEVO@dell.com	6252535707	4	8753019441384823	2011/03	user9542	password	18	80000	F
9543	SVQLZC	PQGWLLSZEO	3548571944 Dell Way	\N	OUCXDBK	OK	82549	US	1	PQGWLLSZEO@dell.com	3548571944	3	1168533338699489	2009/02	user9543	password	49	100000	M
9544	BLYDAO	KXAWPZBEOV	2386925723 Dell Way	\N	GLZIWSD	DC	29085	US	1	KXAWPZBEOV@dell.com	2386925723	3	4048302474431694	2010/06	user9544	password	38	80000	M
9545	FUXUFU	UBKUDPIYVU	2591957254 Dell Way	\N	YEQQIUV	MN	30952	US	1	UBKUDPIYVU@dell.com	2591957254	1	6982052847743035	2010/09	user9545	password	56	80000	F
9546	KMRFGT	QBWFJVBETG	5407356601 Dell Way	\N	UKOPFAV	MD	15246	US	1	QBWFJVBETG@dell.com	5407356601	5	7679398684762419	2008/07	user9546	password	33	60000	F
9547	XRHQHI	NNSJPWCVQN	2763199239 Dell Way	\N	JGSKBDL	ND	99040	US	1	NNSJPWCVQN@dell.com	2763199239	3	5739776376634837	2010/01	user9547	password	56	40000	M
9548	UYZDMM	VVBRYXILHO	8201318840 Dell Way	\N	ERQHDFH	KS	79545	US	1	VVBRYXILHO@dell.com	8201318840	4	8045445888768882	2009/01	user9548	password	50	20000	M
9549	KGLXBH	ZSFWBQEPUV	9999442754 Dell Way	\N	GBZLIIF	DC	14574	US	1	ZSFWBQEPUV@dell.com	9999442754	3	1866848438046872	2010/08	user9549	password	24	100000	M
9550	OTYVSR	APSQTILPON	1264610413 Dell Way	\N	OAVWFZY	HI	51485	US	1	APSQTILPON@dell.com	1264610413	4	1639756420627236	2008/07	user9550	password	86	80000	F
9551	WMANNQ	FDJOPZCCOC	5070269044 Dell Way	\N	YLIXJOJ	MA	31933	US	1	FDJOPZCCOC@dell.com	5070269044	3	8032214111648501	2009/03	user9551	password	23	40000	M
9552	CTESZI	CNXBQZPTXA	7111749086 Dell Way	\N	CVJRFTX	NY	33703	US	1	CNXBQZPTXA@dell.com	7111749086	1	4887241257820279	2011/04	user9552	password	24	100000	F
9553	GOBOQP	LRFLHZJHBF	2117447251 Dell Way	\N	RSKLPCR	IL	23778	US	1	LRFLHZJHBF@dell.com	2117447251	1	5148457210045308	2009/11	user9553	password	56	60000	F
9554	PZCELU	KWBJFJKLAC	5928335180 Dell Way	\N	VLSYDZC	ID	12855	US	1	KWBJFJKLAC@dell.com	5928335180	3	9246936425566674	2008/12	user9554	password	44	80000	M
9555	LWJFGG	HPMQAXRDTC	8183599296 Dell Way	\N	WRGWTNW	IN	10857	US	1	HPMQAXRDTC@dell.com	8183599296	2	9419498584698888	2008/01	user9555	password	80	80000	M
9556	FVELCU	YTUVKYONUF	3239996152 Dell Way	\N	UQZHNGI	KS	68482	US	1	YTUVKYONUF@dell.com	3239996152	3	7349368208553643	2008/01	user9556	password	62	40000	M
9557	UUAOST	JNDHCRCHLS	9061113316 Dell Way	\N	HTGOBOE	IN	13597	US	1	JNDHCRCHLS@dell.com	9061113316	3	2105969320517033	2010/09	user9557	password	20	40000	M
9558	BVGUFU	YMWPOEBHLU	3187177736 Dell Way	\N	NZVCEDD	AZ	58778	US	1	YMWPOEBHLU@dell.com	3187177736	3	3503003946039826	2009/11	user9558	password	76	40000	M
9559	BCXVBJ	RRYWSFHMTH	3452486982 Dell Way	\N	IVLLYNZ	FL	17105	US	1	RRYWSFHMTH@dell.com	3452486982	3	9495320798829200	2008/10	user9559	password	65	20000	M
9560	OYYYQP	WMICUUVBCR	1063322466 Dell Way	\N	MOPZOUB	TN	31087	US	1	WMICUUVBCR@dell.com	1063322466	5	1076945204753428	2011/01	user9560	password	83	40000	M
9561	VDPLAC	TCWOYXRPJF	2984564585 Dell Way	\N	FJUZLQF	MI	57914	US	1	TCWOYXRPJF@dell.com	2984564585	1	6057213294785470	2008/04	user9561	password	57	100000	F
9562	DKMFDP	BSNZJDJPIS	1908656185 Dell Way	\N	JIDANPO	OR	70580	US	1	BSNZJDJPIS@dell.com	1908656185	5	9773731420747936	2011/10	user9562	password	48	80000	F
9563	WZJMBB	ZBKDKALDKU	5431902107 Dell Way	\N	GKHVYBN	AR	90947	US	1	ZBKDKALDKU@dell.com	5431902107	4	7410225096158684	2012/06	user9563	password	85	80000	F
9564	HGNIGO	TJYUVBEPIP	5955812802 Dell Way	\N	XENYSOV	FL	32505	US	1	TJYUVBEPIP@dell.com	5955812802	1	7318394628819079	2010/11	user9564	password	28	80000	F
9565	RCKFWU	EQPFVFOKCT	4935287571 Dell Way	\N	XBLMXQT	MI	74677	US	1	EQPFVFOKCT@dell.com	4935287571	5	6518264974933118	2010/08	user9565	password	73	40000	M
9566	ELPYPG	OVBTKLWDJX	5741209066 Dell Way	\N	OWUFPGX	AL	24137	US	1	OVBTKLWDJX@dell.com	5741209066	4	8390864248387516	2009/11	user9566	password	60	60000	F
9567	FKXLYT	MSDYOHIMWE	5728674524 Dell Way	\N	HBTOZTS	MS	42890	US	1	MSDYOHIMWE@dell.com	5728674524	4	2873886155430227	2008/03	user9567	password	54	40000	M
9568	KTPDGH	HEWPMJLQRN	7488761915 Dell Way	\N	KFMDXZN	MI	79090	US	1	HEWPMJLQRN@dell.com	7488761915	3	1155651774257421	2009/11	user9568	password	66	80000	M
9569	GUVOBZ	LQMUCDMPNR	8489378554 Dell Way	\N	BRPBEBV	VA	63196	US	1	LQMUCDMPNR@dell.com	8489378554	1	4925729264039546	2010/09	user9569	password	19	80000	M
9570	VIOVTF	IOHLAXYRZP	4206268332 Dell Way	\N	HAUIVRX	NV	81347	US	1	IOHLAXYRZP@dell.com	4206268332	1	5784049220383168	2009/12	user9570	password	20	40000	F
9571	PAZVJN	DUNATFAJNA	2206957855 Dell Way	\N	DVWVTNP	CO	71848	US	1	DUNATFAJNA@dell.com	2206957855	3	6463563648052514	2008/09	user9571	password	79	80000	M
9572	VQCITW	WUPCUYPVCL	5456021843 Dell Way	\N	RXFFMHX	NJ	81291	US	1	WUPCUYPVCL@dell.com	5456021843	5	5372775970026851	2009/08	user9572	password	33	20000	F
9573	HNYEJT	TMNSCJUNAR	3730141917 Dell Way	\N	SFEADUV	NJ	63731	US	1	TMNSCJUNAR@dell.com	3730141917	5	2668117045890540	2010/02	user9573	password	46	100000	M
9574	IZZCSM	QLOZFCZXUF	6791385103 Dell Way	\N	BVIWQYL	WI	91711	US	1	QLOZFCZXUF@dell.com	6791385103	3	1146331701427698	2008/04	user9574	password	63	40000	F
9575	QMZCCK	RBQTBNOHPK	5581167353 Dell Way	\N	QLAPXZM	ND	50990	US	1	RBQTBNOHPK@dell.com	5581167353	3	7653761347290129	2008/12	user9575	password	90	80000	F
9576	ZWNKNO	AHQOVXEFNQ	4915425914 Dell Way	\N	GCNGPCS	CO	72449	US	1	AHQOVXEFNQ@dell.com	4915425914	2	6988090952858329	2010/01	user9576	password	25	60000	M
9577	PUKEVS	UKNSOTFEAI	2499046992 Dell Way	\N	SGYUYBN	MA	37318	US	1	UKNSOTFEAI@dell.com	2499046992	5	3867440781090409	2009/03	user9577	password	32	100000	F
9578	PBVHWF	VOUPUYPDQV	7689523131 Dell Way	\N	BLUDYEL	CT	97475	US	1	VOUPUYPDQV@dell.com	7689523131	2	2653434327803552	2012/04	user9578	password	32	60000	F
9579	AWFGST	AHOZWRPSTB	8498383354 Dell Way	\N	NWARHDQ	AL	58968	US	1	AHOZWRPSTB@dell.com	8498383354	5	8333739214576782	2008/07	user9579	password	28	20000	F
9580	IHCCIK	RHHIXZCZNZ	5677004043 Dell Way	\N	AEGEVHS	NY	35040	US	1	RHHIXZCZNZ@dell.com	5677004043	4	8353086134884507	2011/09	user9580	password	33	20000	F
9581	IDJSUR	ZDPZFOMEOR	8412709738 Dell Way	\N	LSNSLEA	WI	89165	US	1	ZDPZFOMEOR@dell.com	8412709738	4	6662103755865247	2008/08	user9581	password	67	40000	M
9582	BBNTBR	IAWWNBLEME	4572867887 Dell Way	\N	SFPXFOT	AL	24833	US	1	IAWWNBLEME@dell.com	4572867887	1	8164611774962396	2008/06	user9582	password	57	20000	M
9583	CWOTFP	PBCQNHDRAI	8072132569 Dell Way	\N	HXOVROZ	AR	68630	US	1	PBCQNHDRAI@dell.com	8072132569	1	1816866185516119	2009/04	user9583	password	61	60000	F
9584	EDJTTL	WKYDNQDWXB	7388297932 Dell Way	\N	KTSZSTQ	MS	89532	US	1	WKYDNQDWXB@dell.com	7388297932	5	2451744292397052	2009/04	user9584	password	41	60000	F
9585	RFECBO	BFCRJYPKII	9128680558 Dell Way	\N	CHBWXOT	NM	45750	US	1	BFCRJYPKII@dell.com	9128680558	5	6874270834960044	2009/05	user9585	password	22	100000	M
9586	FASUBY	WTHUJSDRVL	4005773887 Dell Way	\N	SRJHKZR	KS	93595	US	1	WTHUJSDRVL@dell.com	4005773887	3	4062464709859341	2009/06	user9586	password	88	80000	F
9587	RKNPGH	XBQQFILQBD	3239889698 Dell Way	\N	ZIOZAWX	KY	47470	US	1	XBQQFILQBD@dell.com	3239889698	4	8796823451761157	2009/05	user9587	password	41	100000	M
9588	WNZDKB	UAGDMWEPWN	3587076077 Dell Way	\N	DVNATWK	AK	66070	US	1	UAGDMWEPWN@dell.com	3587076077	2	9781470385845752	2011/02	user9588	password	70	60000	M
9589	SQATLB	ZONWSDTGGP	3182411689 Dell Way	\N	THIQSIG	WY	60092	US	1	ZONWSDTGGP@dell.com	3182411689	3	7098156912717969	2012/01	user9589	password	40	80000	M
9590	IKDKKR	YHKBAQIPKP	5481377368 Dell Way	\N	YBHGIHV	ND	89598	US	1	YHKBAQIPKP@dell.com	5481377368	3	9639227385167032	2012/03	user9590	password	66	20000	M
9591	UOAMMI	XOIOXYZNWA	9453593199 Dell Way	\N	VDJCYXZ	MI	49912	US	1	XOIOXYZNWA@dell.com	9453593199	2	6707679143175483	2011/05	user9591	password	35	60000	M
9592	HXKPUY	XJVWIISJDV	7317224846 Dell Way	\N	SGUQFFB	DE	51367	US	1	XJVWIISJDV@dell.com	7317224846	4	8554499026853592	2012/03	user9592	password	73	40000	F
9593	EUXCSG	YOOHHYLCQS	4543919882 Dell Way	\N	WGXCICO	AL	86933	US	1	YOOHHYLCQS@dell.com	4543919882	5	1320013992954045	2008/03	user9593	password	26	40000	M
9594	AKSGJH	VROTCRKUNQ	7277187076 Dell Way	\N	SQZUEAR	NE	98730	US	1	VROTCRKUNQ@dell.com	7277187076	4	2634440013207495	2012/01	user9594	password	31	100000	F
9595	XBVEXN	TQPKAKYRDO	8606976458 Dell Way	\N	RYTRPIR	IN	15063	US	1	TQPKAKYRDO@dell.com	8606976458	1	1892247679177671	2008/12	user9595	password	59	100000	F
9596	KCXXVO	NGPYEHCTYA	9620801233 Dell Way	\N	MQQUHYW	CT	17381	US	1	NGPYEHCTYA@dell.com	9620801233	1	1222872185986489	2010/02	user9596	password	20	100000	F
9597	YVAMIH	CHLJJEHKQY	1928533935 Dell Way	\N	BLFZIJC	ID	56016	US	1	CHLJJEHKQY@dell.com	1928533935	4	6352410727180541	2008/09	user9597	password	75	20000	M
9598	VOWCQD	NANSHXJGYU	9192311738 Dell Way	\N	LYCUAJI	CT	25129	US	1	NANSHXJGYU@dell.com	9192311738	2	8899531215429307	2011/05	user9598	password	47	60000	M
9599	HPOLDO	YVWVECUZNS	5559570043 Dell Way	\N	CITLRWQ	ND	19772	US	1	YVWVECUZNS@dell.com	5559570043	2	4982417776715011	2012/10	user9599	password	42	20000	F
9600	XQMLOI	HKMJELXXOG	1347692705 Dell Way	\N	QAXMQMP	DC	75838	US	1	HKMJELXXOG@dell.com	1347692705	1	5528978598769755	2009/04	user9600	password	81	40000	M
9601	JSLRZW	EJAQGYEMOE	1943610070 Dell Way	\N	KBUWRYP	OH	99708	US	1	EJAQGYEMOE@dell.com	1943610070	1	3233142467215657	2012/05	user9601	password	27	40000	F
9602	OAAKFJ	LVQKZDZENA	2425662123 Dell Way	\N	ZKRXZJX	CA	51482	US	1	LVQKZDZENA@dell.com	2425662123	1	8252584835980088	2009/05	user9602	password	80	100000	F
9603	WHQGSL	WDLZCPNDPX	5116209723 Dell Way	\N	UMXEKZQ	ND	16347	US	1	WDLZCPNDPX@dell.com	5116209723	5	5383690787944943	2009/09	user9603	password	85	20000	M
9604	OLSAHV	MHYBUBRSWE	2448134051 Dell Way	\N	PBOPSDR	DC	99025	US	1	MHYBUBRSWE@dell.com	2448134051	3	7275166057050229	2008/08	user9604	password	67	80000	F
9605	KRJGDR	EFMFWEBAUD	4756712075 Dell Way	\N	PKVTBZS	HI	49343	US	1	EFMFWEBAUD@dell.com	4756712075	2	1739990894217044	2008/12	user9605	password	29	60000	M
9606	NSTEXY	RCVVEVQHLA	6428870871 Dell Way	\N	CEBCWHN	IN	64824	US	1	RCVVEVQHLA@dell.com	6428870871	2	6113544897641987	2011/11	user9606	password	31	40000	M
9607	YMNXDQ	SZUNPCZPFD	2453085727 Dell Way	\N	RHAZUIP	MD	74001	US	1	SZUNPCZPFD@dell.com	2453085727	1	6433378750924022	2009/06	user9607	password	34	40000	M
9608	TEBJWB	DKQFJGLNYS	2278307410 Dell Way	\N	NYNVNXN	NY	16166	US	1	DKQFJGLNYS@dell.com	2278307410	1	5655815347097815	2009/04	user9608	password	50	20000	F
9609	NLJOPT	FVDLGQKYEI	9570521708 Dell Way	\N	LZVJNNL	NV	58777	US	1	FVDLGQKYEI@dell.com	9570521708	1	8738803561776877	2009/02	user9609	password	43	100000	M
9610	SLEMRA	QCGGMFKVRK	6003628705 Dell Way	\N	QBXEMPS	MI	65611	US	1	QCGGMFKVRK@dell.com	6003628705	5	7756026483606548	2012/09	user9610	password	42	80000	F
9611	NCWOSZ	VZMAKHSUXU	7036960658 Dell Way	\N	SBGHTSX	KS	57983	US	1	VZMAKHSUXU@dell.com	7036960658	2	3488988343626261	2008/11	user9611	password	53	60000	M
9612	IBRHXQ	TXABQVYKNA	2599243731 Dell Way	\N	RVUJTCX	ME	40228	US	1	TXABQVYKNA@dell.com	2599243731	3	2625415503047406	2011/12	user9612	password	26	100000	F
9613	UHYKBV	LCMGBXTCOP	5566761393 Dell Way	\N	WYIZVTI	AK	27012	US	1	LCMGBXTCOP@dell.com	5566761393	4	2369553055614233	2011/09	user9613	password	31	60000	M
9614	CVBYGE	LMGIGIXVFV	3425869184 Dell Way	\N	EFRYNSD	AL	42887	US	1	LMGIGIXVFV@dell.com	3425869184	4	1334487305954098	2010/01	user9614	password	19	60000	M
9615	BNDGZP	MIVUFQABVF	8556900903 Dell Way	\N	TTTLWUU	CT	51636	US	1	MIVUFQABVF@dell.com	8556900903	3	5819302247837186	2012/03	user9615	password	48	100000	M
9616	NERDQZ	YLFPLHLRAE	3059063145 Dell Way	\N	LMBFHES	CO	79704	US	1	YLFPLHLRAE@dell.com	3059063145	5	9512068587355316	2011/11	user9616	password	65	20000	F
9617	IIRIGC	OWOVHGWMRI	4701394465 Dell Way	\N	NXPRPSM	TN	70775	US	1	OWOVHGWMRI@dell.com	4701394465	3	6054389695636929	2008/09	user9617	password	62	40000	M
9618	HSGKHC	ZCKFZWXHKV	8703134326 Dell Way	\N	XCKQOGH	WI	76696	US	1	ZCKFZWXHKV@dell.com	8703134326	1	4687157195061445	2010/05	user9618	password	46	80000	F
9619	QDKTCN	DIMAFULASN	8583194912 Dell Way	\N	LIBRQAL	MO	13191	US	1	DIMAFULASN@dell.com	8583194912	5	5052796141710133	2009/09	user9619	password	60	100000	M
9620	ZPXNTF	AULUFLNSWV	3523061961 Dell Way	\N	UOLUAXV	TX	86764	US	1	AULUFLNSWV@dell.com	3523061961	1	5776111189275981	2012/12	user9620	password	43	100000	M
9621	GJIMKC	XEIJSBGNVV	3417919611 Dell Way	\N	ZQVXMRT	OR	76934	US	1	XEIJSBGNVV@dell.com	3417919611	4	7194973556324840	2011/06	user9621	password	35	100000	M
9622	OJGRGL	AQDBWQXRPN	6264237057 Dell Way	\N	MMZDGTX	MS	41735	US	1	AQDBWQXRPN@dell.com	6264237057	1	8468311307020486	2012/12	user9622	password	68	40000	F
9623	YBQJBG	MDCDAUTOGG	5426242307 Dell Way	\N	OKMIIZR	VA	20212	US	1	MDCDAUTOGG@dell.com	5426242307	4	1954686437267810	2008/02	user9623	password	51	20000	F
9624	BMGIZJ	KCKEWZLCOW	8277697793 Dell Way	\N	PWEPNCS	AK	83645	US	1	KCKEWZLCOW@dell.com	8277697793	1	9413344708736988	2009/04	user9624	password	26	40000	M
9625	JQTTBW	EGSDSVSPKO	6526883189 Dell Way	\N	UACWSCR	MT	36745	US	1	EGSDSVSPKO@dell.com	6526883189	4	6449153178371490	2011/02	user9625	password	46	20000	M
9626	DVVZZB	SDTNVJYKDY	5262550657 Dell Way	\N	MZROREW	ID	95757	US	1	SDTNVJYKDY@dell.com	5262550657	1	1581374030094593	2012/02	user9626	password	77	20000	M
9627	QAXSSB	MGWVFGYDSX	9959848990 Dell Way	\N	UHOZEVY	NM	85796	US	1	MGWVFGYDSX@dell.com	9959848990	3	9392587436828764	2012/07	user9627	password	80	60000	M
9628	TDFUPM	RKRYJVQGQY	4993356126 Dell Way	\N	VPCRNTN	MT	32433	US	1	RKRYJVQGQY@dell.com	4993356126	2	7807373477611692	2009/10	user9628	password	37	20000	M
9629	MWOZOY	QMILDOBBKR	9381925748 Dell Way	\N	EBFYPSE	AL	14773	US	1	QMILDOBBKR@dell.com	9381925748	2	8563274845946581	2008/05	user9629	password	74	80000	F
9630	IRUHHG	PTJEVLOMQQ	3624839602 Dell Way	\N	ROFKSFL	NV	58801	US	1	PTJEVLOMQQ@dell.com	3624839602	5	9316407680045814	2008/07	user9630	password	30	40000	F
9631	ZQNFGG	PKCAYPROGF	5158979289 Dell Way	\N	URYZDON	MD	48380	US	1	PKCAYPROGF@dell.com	5158979289	3	9750721977557988	2011/11	user9631	password	31	60000	M
9632	SVTZKD	BLCQCRXHLO	2816613289 Dell Way	\N	FLRUZCF	MI	60619	US	1	BLCQCRXHLO@dell.com	2816613289	1	4714691650588066	2009/08	user9632	password	84	20000	F
9633	RBXUCI	XTLOQTZFZL	9601222055 Dell Way	\N	XUKZAVO	GA	91615	US	1	XTLOQTZFZL@dell.com	9601222055	3	6157143354415894	2012/09	user9633	password	21	60000	M
9634	YIVHFO	SUEMUKLFHF	9393633657 Dell Way	\N	PGFLUKJ	PA	10707	US	1	SUEMUKLFHF@dell.com	9393633657	4	7096630920190365	2012/02	user9634	password	46	100000	F
9635	FFSTYN	XKHIVNPADW	4158977413 Dell Way	\N	GOQRYKR	UT	13169	US	1	XKHIVNPADW@dell.com	4158977413	5	2781308185774833	2011/10	user9635	password	68	100000	M
9636	KRYYPI	FXDSNEVJLK	6733146583 Dell Way	\N	ZCJKUFL	CT	15695	US	1	FXDSNEVJLK@dell.com	6733146583	5	8612848497461528	2009/10	user9636	password	79	80000	F
9637	TRCCXZ	GQMKMVWXVY	4208386875 Dell Way	\N	GGSLRVN	KS	73100	US	1	GQMKMVWXVY@dell.com	4208386875	4	5508262540679426	2008/05	user9637	password	89	100000	F
9638	BBZBHQ	OSCKOZGMFM	3319730238 Dell Way	\N	FREBENT	MT	24075	US	1	OSCKOZGMFM@dell.com	3319730238	4	6076879490166903	2009/09	user9638	password	65	40000	M
9639	QJAGXS	JHHIOUNAZF	4874017451 Dell Way	\N	FBJSUXW	AZ	65306	US	1	JHHIOUNAZF@dell.com	4874017451	2	3711407320108265	2008/08	user9639	password	20	80000	M
9640	BZWUIE	BRSVFTVKYW	6151572888 Dell Way	\N	TRRRNTH	WI	14730	US	1	BRSVFTVKYW@dell.com	6151572888	1	6868938481900842	2011/10	user9640	password	62	80000	M
9641	MLCQNT	IJYBFJACDR	3000445278 Dell Way	\N	TUFNBDO	NJ	27171	US	1	IJYBFJACDR@dell.com	3000445278	2	9601696177385748	2012/11	user9641	password	69	40000	F
9642	UXXOGG	NILWINZAHU	5506791680 Dell Way	\N	FUVJJLO	NH	72112	US	1	NILWINZAHU@dell.com	5506791680	3	6371211646124721	2009/09	user9642	password	88	20000	M
9643	WOWCCE	OYNBYNJTSE	3831906394 Dell Way	\N	OCNAQDS	CT	59872	US	1	OYNBYNJTSE@dell.com	3831906394	2	3438406106084585	2009/05	user9643	password	83	20000	M
9644	UFAZTZ	MVXAERTIGV	8286173732 Dell Way	\N	WGLZZPO	IN	92297	US	1	MVXAERTIGV@dell.com	8286173732	3	3349292506929487	2011/09	user9644	password	30	60000	M
9645	EMRDZM	BZRSTZYOWF	7877376048 Dell Way	\N	AVFPJNN	FL	16740	US	1	BZRSTZYOWF@dell.com	7877376048	5	7938347897958011	2012/05	user9645	password	68	20000	M
9646	JGVWIU	NBNNACJFCF	8013720008 Dell Way	\N	LSOYFTA	WV	67160	US	1	NBNNACJFCF@dell.com	8013720008	5	1210182106122374	2010/01	user9646	password	82	100000	F
9647	SRPNFQ	BSQDCWGHHY	3130826871 Dell Way	\N	VFDPFCF	AK	10727	US	1	BSQDCWGHHY@dell.com	3130826871	3	1241798640694469	2008/04	user9647	password	39	100000	M
9648	XIENJX	DNZZUGHSCN	1014468132 Dell Way	\N	WRSZXTZ	CT	28361	US	1	DNZZUGHSCN@dell.com	1014468132	2	5521692679729313	2009/01	user9648	password	53	20000	F
9649	RSUPWH	OWBVDUYQQQ	8212970863 Dell Way	\N	JPNCPQH	NH	89821	US	1	OWBVDUYQQQ@dell.com	8212970863	5	9587135851848872	2009/02	user9649	password	43	100000	M
9650	DOQLDM	MYQHXGYNQO	5561992631 Dell Way	\N	ASDRASO	SD	65814	US	1	MYQHXGYNQO@dell.com	5561992631	1	7332047407981009	2012/01	user9650	password	54	100000	M
9651	DKSQXR	GEPNDCDRDW	8652453266 Dell Way	\N	UUXNISD	TX	83413	US	1	GEPNDCDRDW@dell.com	8652453266	4	8945833447854967	2009/09	user9651	password	54	60000	F
9652	FCAXJF	MXIPBZSXUM	2822977627 Dell Way	\N	UHVNLRI	IN	44348	US	1	MXIPBZSXUM@dell.com	2822977627	4	1651830887421965	2011/02	user9652	password	30	100000	F
9653	EVPJIM	RXORPLLCGT	1422845020 Dell Way	\N	XTEPBMZ	ID	22018	US	1	RXORPLLCGT@dell.com	1422845020	5	3324304641224444	2009/11	user9653	password	54	60000	M
9654	CUAPMX	DDNPOPVHNP	4402975448 Dell Way	\N	MCQZBXD	CT	89014	US	1	DDNPOPVHNP@dell.com	4402975448	2	7843025735113771	2012/09	user9654	password	52	100000	M
9655	MOZKSC	XHRMDZZSMC	9169749067 Dell Way	\N	JLEHPHD	WI	67463	US	1	XHRMDZZSMC@dell.com	9169749067	5	4443925831466913	2009/10	user9655	password	83	100000	F
9656	WGCZDK	RQNQQGDSPP	2968255652 Dell Way	\N	XWEFADV	WA	95454	US	1	RQNQQGDSPP@dell.com	2968255652	2	7801959040574730	2008/02	user9656	password	28	20000	F
9657	GZOQRE	EHVLKOAALX	9840145702 Dell Way	\N	EQYHMWF	OK	25256	US	1	EHVLKOAALX@dell.com	9840145702	5	3985763531643897	2008/11	user9657	password	72	40000	M
9658	HZMMEU	IPFWQFIOJZ	8549569436 Dell Way	\N	MRMIWEN	UT	99921	US	1	IPFWQFIOJZ@dell.com	8549569436	5	8496825447771699	2010/05	user9658	password	66	100000	F
9659	EJNYRC	EOTKWHUWTL	3894956591 Dell Way	\N	ICIMPEM	MI	25691	US	1	EOTKWHUWTL@dell.com	3894956591	1	5650775241665543	2012/11	user9659	password	80	20000	F
9660	JCYMHN	FRKMMGGXOI	1907367018 Dell Way	\N	FBYKOJP	UT	43872	US	1	FRKMMGGXOI@dell.com	1907367018	5	3474397495388985	2012/01	user9660	password	57	40000	F
9661	NUKAZB	KMNRSLGBQH	9829877410 Dell Way	\N	ZBWIQSS	OR	62223	US	1	KMNRSLGBQH@dell.com	9829877410	4	6238322849385441	2010/01	user9661	password	68	20000	M
9662	BBUDMH	REACKBTSAU	4989112310 Dell Way	\N	OJLHBFW	AL	90250	US	1	REACKBTSAU@dell.com	4989112310	3	9179342621006072	2008/08	user9662	password	70	40000	M
9663	NIDUAH	UCSVWKWQYF	1841354355 Dell Way	\N	CGGHCHE	NC	86839	US	1	UCSVWKWQYF@dell.com	1841354355	4	5061746853403747	2012/11	user9663	password	25	40000	F
9664	GCFOXI	GTEQPVPVYV	6993385009 Dell Way	\N	BFYJKMF	MS	23761	US	1	GTEQPVPVYV@dell.com	6993385009	2	1244614976923912	2011/08	user9664	password	35	20000	M
9665	MOQUVK	ZLAUBVSXWY	5363749079 Dell Way	\N	VGIHLVL	CT	22559	US	1	ZLAUBVSXWY@dell.com	5363749079	5	7877133497036994	2011/12	user9665	password	54	20000	F
9666	DZHOYT	OSUJLSGJNM	5093405607 Dell Way	\N	SVYOHCR	PA	98211	US	1	OSUJLSGJNM@dell.com	5093405607	3	9145113463979216	2012/09	user9666	password	47	20000	M
9667	SRPLFI	GOUYVEMIWH	3094158308 Dell Way	\N	GLOJCII	NE	84837	US	1	GOUYVEMIWH@dell.com	3094158308	3	5621244908310473	2011/08	user9667	password	30	40000	F
9668	UUMCBB	XAXBMFYUMJ	1410721716 Dell Way	\N	JVMSDAN	MA	60449	US	1	XAXBMFYUMJ@dell.com	1410721716	1	2768092996440828	2009/05	user9668	password	53	20000	F
9669	ZCFBAF	YBSDZMPIVK	6218706220 Dell Way	\N	UOOVBYJ	CT	95282	US	1	YBSDZMPIVK@dell.com	6218706220	2	3615853250958025	2008/05	user9669	password	49	20000	F
9670	QCMVAN	NEMAUVWFQK	9436232962 Dell Way	\N	TLMSVPQ	MD	94433	US	1	NEMAUVWFQK@dell.com	9436232962	3	3526471372228116	2009/07	user9670	password	71	100000	M
9671	FVRSJV	FJPBFURPOC	9132973693 Dell Way	\N	CGYRXIQ	TN	81568	US	1	FJPBFURPOC@dell.com	9132973693	2	3836874381639063	2011/03	user9671	password	86	100000	F
9672	POJKUS	AVYVMOJPQQ	9505558136 Dell Way	\N	NIOVYKQ	TX	63446	US	1	AVYVMOJPQQ@dell.com	9505558136	3	8094189631287009	2012/05	user9672	password	76	60000	M
9673	EXRXXM	VTZJDOATCI	1610819857 Dell Way	\N	HXHRODH	MO	67550	US	1	VTZJDOATCI@dell.com	1610819857	2	9768093744292856	2012/11	user9673	password	81	20000	M
9674	OXQBTJ	ADMPDGRMOP	5771723879 Dell Way	\N	UGDXNQO	NE	99350	US	1	ADMPDGRMOP@dell.com	5771723879	3	8500330315437169	2009/06	user9674	password	59	100000	F
9675	FZDPAG	CPKIHWWWQC	5185571250 Dell Way	\N	AOQQCFQ	NM	68309	US	1	CPKIHWWWQC@dell.com	5185571250	1	2169109861832112	2008/12	user9675	password	56	40000	M
9676	RVZYXP	IFXECUVFUK	8173143965 Dell Way	\N	VLNABDR	MT	27087	US	1	IFXECUVFUK@dell.com	8173143965	3	2598010300658643	2009/10	user9676	password	29	100000	M
9677	DYNTGT	QLVKGAFRWQ	7071039100 Dell Way	\N	EWRHOFM	KY	78368	US	1	QLVKGAFRWQ@dell.com	7071039100	4	5938947239425034	2012/08	user9677	password	29	100000	M
9678	RSVKJH	GTOGYFDPJZ	8047878853 Dell Way	\N	GROMEWG	TN	58959	US	1	GTOGYFDPJZ@dell.com	8047878853	4	2859636693727225	2012/08	user9678	password	76	80000	F
9679	QASXGM	LNLQQAZQHR	8246636878 Dell Way	\N	ETVBZRP	RI	39759	US	1	LNLQQAZQHR@dell.com	8246636878	4	9688682428561152	2011/04	user9679	password	40	40000	F
9680	ADPMOC	XFTXFJEWOY	6971270346 Dell Way	\N	SPYJFRS	AK	46121	US	1	XFTXFJEWOY@dell.com	6971270346	4	7497303145937622	2012/10	user9680	password	22	100000	M
9681	QMNSJT	MHYVMVJKNZ	2403188472 Dell Way	\N	IXEAPEL	ID	79955	US	1	MHYVMVJKNZ@dell.com	2403188472	2	6486089430283756	2009/03	user9681	password	59	100000	M
9682	COCWAJ	UWWQGHEFQB	9540137615 Dell Way	\N	KQQOCXI	IA	23138	US	1	UWWQGHEFQB@dell.com	9540137615	3	4400187308900058	2010/04	user9682	password	24	80000	M
9683	EMXOHU	KXARBGHDQY	2925237243 Dell Way	\N	UEBRNHV	MO	75965	US	1	KXARBGHDQY@dell.com	2925237243	5	1277932417578995	2009/08	user9683	password	84	60000	F
9684	VAJPLH	PDJWLMMJHR	5201588292 Dell Way	\N	KZESURL	AK	68915	US	1	PDJWLMMJHR@dell.com	5201588292	2	3490305962041020	2009/10	user9684	password	45	20000	M
9685	TUGBKJ	KGUXSEEJPD	2351404173 Dell Way	\N	OHYFTZW	GA	34834	US	1	KGUXSEEJPD@dell.com	2351404173	3	1556231849361211	2010/10	user9685	password	81	40000	M
9686	CIYMTE	GQWLVGAZVI	3014823846 Dell Way	\N	YABXXGE	AR	83880	US	1	GQWLVGAZVI@dell.com	3014823846	3	6182538023218513	2008/11	user9686	password	26	40000	F
9687	ARYFYP	CKKIKKETIF	4977562353 Dell Way	\N	UFCBJEW	NH	76982	US	1	CKKIKKETIF@dell.com	4977562353	4	6497156631201506	2010/11	user9687	password	76	60000	M
9688	TUNIWX	TFIDJCMOWR	2634144924 Dell Way	\N	RXBVUQO	HI	40007	US	1	TFIDJCMOWR@dell.com	2634144924	4	3074640946462750	2012/05	user9688	password	77	80000	F
9689	JBAHVG	PZQRLEODWM	4576674260 Dell Way	\N	ERGVGME	ME	33148	US	1	PZQRLEODWM@dell.com	4576674260	3	6581057558301837	2009/02	user9689	password	74	60000	F
9690	UVBBLA	RDMVRQREVJ	7975166346 Dell Way	\N	KQPXVAE	GA	50871	US	1	RDMVRQREVJ@dell.com	7975166346	3	6458353691734374	2010/12	user9690	password	78	40000	M
9691	WKGXBJ	KXBAOFVYQM	6831981778 Dell Way	\N	ONHPRNB	MN	93278	US	1	KXBAOFVYQM@dell.com	6831981778	1	9146471512503924	2010/05	user9691	password	70	40000	M
9692	ZHUIRR	KSGQNFGATU	6826422367 Dell Way	\N	IIMVJYT	AL	96003	US	1	KSGQNFGATU@dell.com	6826422367	3	3830178707838059	2009/11	user9692	password	22	40000	F
9693	WRVOBN	URBZYBTTJC	4848580228 Dell Way	\N	FFLEYMC	NE	99060	US	1	URBZYBTTJC@dell.com	4848580228	5	8683973459526897	2010/04	user9693	password	90	40000	M
9694	UXAIRR	JRQLLJVNPA	3763589084 Dell Way	\N	ZTYMWNL	IL	52637	US	1	JRQLLJVNPA@dell.com	3763589084	4	7722599680069835	2009/02	user9694	password	68	20000	F
9695	RKSJUK	AFVKAIZAIS	7516111000 Dell Way	\N	ZUONGVZ	NC	65010	US	1	AFVKAIZAIS@dell.com	7516111000	5	7572481592185796	2010/12	user9695	password	71	20000	F
9696	LMEVNJ	QXKZWLHOKB	3743628738 Dell Way	\N	DXIZXWO	NJ	72028	US	1	QXKZWLHOKB@dell.com	3743628738	1	6698998529929668	2008/02	user9696	password	90	60000	M
9697	EHDNYA	YYWJFKUHOS	8022503898 Dell Way	\N	PNPLCFD	MA	32135	US	1	YYWJFKUHOS@dell.com	8022503898	3	4387112030293793	2011/11	user9697	password	90	100000	F
9698	CMECKC	ZTHKOPYGFL	7206717415 Dell Way	\N	WRNBVXI	NH	40525	US	1	ZTHKOPYGFL@dell.com	7206717415	2	3245525710750371	2011/04	user9698	password	51	80000	M
9699	QXESWY	AGMPETVQPM	6857110074 Dell Way	\N	DQHBZXK	NV	35031	US	1	AGMPETVQPM@dell.com	6857110074	2	6294180321507156	2008/02	user9699	password	44	80000	F
9700	NLXLLD	YBIRWZGJDX	4918838614 Dell Way	\N	REWOPNW	HI	88044	US	1	YBIRWZGJDX@dell.com	4918838614	2	9910192949231716	2011/01	user9700	password	18	40000	M
9701	XUYBSA	JKWIRGLOXQ	8529259213 Dell Way	\N	LMFZILW	PA	81343	US	1	JKWIRGLOXQ@dell.com	8529259213	3	8825297380331905	2012/11	user9701	password	45	80000	M
9702	IUJIEU	FNLLYAJPLV	9283061870 Dell Way	\N	VLDGHXB	CT	50266	US	1	FNLLYAJPLV@dell.com	9283061870	5	3899565330240876	2009/09	user9702	password	89	80000	M
9703	JZRDEE	PQDPZSBUNM	6471027032 Dell Way	\N	YUUVVXH	PA	88328	US	1	PQDPZSBUNM@dell.com	6471027032	1	6259930591098965	2010/09	user9703	password	24	100000	M
9704	TCVXRM	AHLTIGGVEB	9662087634 Dell Way	\N	PAWNIQJ	VT	71723	US	1	AHLTIGGVEB@dell.com	9662087634	3	4359887575265020	2008/06	user9704	password	20	80000	M
9705	WSGITN	UMVATRFUHG	4276006018 Dell Way	\N	RUOHEMZ	CT	97436	US	1	UMVATRFUHG@dell.com	4276006018	1	4858127593062818	2009/12	user9705	password	89	40000	M
9706	FPKSJW	OKQFQKNWCH	3386665527 Dell Way	\N	KKLWKOV	PA	76507	US	1	OKQFQKNWCH@dell.com	3386665527	1	7333893635310233	2009/05	user9706	password	45	60000	F
9707	UEKRTU	HZKSMHUTRF	3007476362 Dell Way	\N	FNPUJIN	NM	54291	US	1	HZKSMHUTRF@dell.com	3007476362	5	9140144973527640	2010/05	user9707	password	84	40000	M
9708	IAGCIG	NASUVMMBRA	4380887612 Dell Way	\N	QMJZZAM	GA	90106	US	1	NASUVMMBRA@dell.com	4380887612	5	3080439765006304	2009/03	user9708	password	72	80000	F
9709	ASOGGP	ZALLNMDNCP	1021196424 Dell Way	\N	WCPWOVU	WA	66829	US	1	ZALLNMDNCP@dell.com	1021196424	2	8355582739226521	2011/10	user9709	password	20	80000	M
9710	PAUEZV	PLIBPVEFSG	1721507448 Dell Way	\N	VOVQITG	KY	97338	US	1	PLIBPVEFSG@dell.com	1721507448	1	8180701613426209	2008/11	user9710	password	42	80000	M
9711	DWXYMI	GOYBSDTZYI	3883641021 Dell Way	\N	UPROWAN	WA	22606	US	1	GOYBSDTZYI@dell.com	3883641021	1	1135274340864270	2011/10	user9711	password	84	80000	M
9712	VSDEZR	CBKGVKEEFU	1329968818 Dell Way	\N	VTQWHOA	NH	63265	US	1	CBKGVKEEFU@dell.com	1329968818	2	4115069680847228	2012/01	user9712	password	89	80000	M
9713	CYSUAT	EGOOLSTFON	3946557686 Dell Way	\N	VLUKMJZ	MT	67032	US	1	EGOOLSTFON@dell.com	3946557686	3	6981840362306685	2009/03	user9713	password	47	60000	F
9714	DEEXJL	LYXESDTFZF	7124563931 Dell Way	\N	AJSJIFA	NY	70936	US	1	LYXESDTFZF@dell.com	7124563931	5	9204745939932764	2008/05	user9714	password	23	40000	M
9715	GCYSOW	PTOTNUSTUB	3113628635 Dell Way	\N	LEKQECI	TX	14986	US	1	PTOTNUSTUB@dell.com	3113628635	5	4998545312788338	2009/02	user9715	password	19	60000	F
9716	YHVVXP	JQCDIWXKHB	4600957032 Dell Way	\N	VYGXGCY	MO	13515	US	1	JQCDIWXKHB@dell.com	4600957032	4	2793659242801368	2010/05	user9716	password	51	40000	M
9717	HEOWOE	ZSNVQYDSTB	3620773402 Dell Way	\N	YRHBQUC	AK	62928	US	1	ZSNVQYDSTB@dell.com	3620773402	3	9602210964541884	2011/10	user9717	password	62	20000	M
9718	DYOIYH	WTXUXQOYOF	6236770671 Dell Way	\N	GQVASWQ	AK	37116	US	1	WTXUXQOYOF@dell.com	6236770671	4	1983725721016526	2008/10	user9718	password	25	40000	M
9719	RRRYNL	WIIMXHBDNR	3218507375 Dell Way	\N	ZOKVFKD	RI	24847	US	1	WIIMXHBDNR@dell.com	3218507375	5	9856299398932608	2009/04	user9719	password	72	20000	M
9720	LYNWUW	FHTNIWBZWP	9266322045 Dell Way	\N	JRUUVPY	AZ	59485	US	1	FHTNIWBZWP@dell.com	9266322045	3	8713094944600017	2011/06	user9720	password	79	20000	F
9721	JYFFEM	ZRUWSUSIDK	2193706175 Dell Way	\N	DXFSWHH	RI	75085	US	1	ZRUWSUSIDK@dell.com	2193706175	3	2495467513799667	2012/07	user9721	password	59	40000	F
9722	UOQGNI	BJBVBKZMOX	8933171024 Dell Way	\N	SHTZONS	NY	94074	US	1	BJBVBKZMOX@dell.com	8933171024	4	5007280852645636	2010/12	user9722	password	84	40000	M
9723	OMBXNK	ZIMKIYYFQF	8337712207 Dell Way	\N	YQTLJLJ	IA	18773	US	1	ZIMKIYYFQF@dell.com	8337712207	4	1744534179102629	2011/11	user9723	password	62	40000	F
9724	RFXBFG	OPONNTETRU	2036090739 Dell Way	\N	MCEYMKA	IL	18019	US	1	OPONNTETRU@dell.com	2036090739	1	9977761168032886	2011/04	user9724	password	45	40000	M
9725	HLTNAI	BNVUROMMBP	2225290552 Dell Way	\N	QABBAID	DC	43042	US	1	BNVUROMMBP@dell.com	2225290552	5	7235919488593937	2010/04	user9725	password	35	80000	M
9726	ZISHJG	DEYSQKUFBU	7145011960 Dell Way	\N	HCVQGZZ	MA	85803	US	1	DEYSQKUFBU@dell.com	7145011960	5	1942464163992554	2012/09	user9726	password	77	100000	F
9727	OEJUIO	SAFDVLFPSH	3849177758 Dell Way	\N	KIOJIYF	WY	85650	US	1	SAFDVLFPSH@dell.com	3849177758	5	5803665853571147	2008/10	user9727	password	57	80000	M
9728	XMHMFI	RIDCNSUVDC	7331372715 Dell Way	\N	KNLISKE	AL	40217	US	1	RIDCNSUVDC@dell.com	7331372715	1	2234398609492928	2009/11	user9728	password	26	20000	F
9729	KPNTHW	XJKPDFTGQG	6122375245 Dell Way	\N	RYYCCZL	SD	24134	US	1	XJKPDFTGQG@dell.com	6122375245	1	1091478947084397	2011/03	user9729	password	42	20000	M
9730	WWCTTL	DJPJCVZJNX	5182263294 Dell Way	\N	IPAHBWL	NJ	91648	US	1	DJPJCVZJNX@dell.com	5182263294	2	2045661619398743	2012/05	user9730	password	86	80000	F
9731	AKAMOJ	BXMXWVLUDA	7270340197 Dell Way	\N	VKCRWRP	KY	99059	US	1	BXMXWVLUDA@dell.com	7270340197	1	4578994870185852	2011/10	user9731	password	66	80000	F
9732	RDUAFS	NDOIOJLPEW	7723781616 Dell Way	\N	RWTJLCJ	CT	30547	US	1	NDOIOJLPEW@dell.com	7723781616	4	1495666367001831	2010/06	user9732	password	39	20000	M
9733	CDUUQY	JYMSJCXGTT	4162071198 Dell Way	\N	ZDFBMIH	GA	19409	US	1	JYMSJCXGTT@dell.com	4162071198	4	5881005024537445	2011/09	user9733	password	27	80000	M
9734	YNLWWJ	JPTLMAFGZI	4801809447 Dell Way	\N	LBUUJAW	OK	67319	US	1	JPTLMAFGZI@dell.com	4801809447	2	4072522147092968	2010/02	user9734	password	29	60000	M
9735	PJMZSC	TEOTKVTSGV	5686006761 Dell Way	\N	NAEOXWE	KS	32034	US	1	TEOTKVTSGV@dell.com	5686006761	5	4102846150286496	2011/05	user9735	password	88	40000	M
9736	LHLOAQ	CUBYNUEIHF	9818446900 Dell Way	\N	NWDKALQ	NC	40075	US	1	CUBYNUEIHF@dell.com	9818446900	2	7341186674777419	2012/07	user9736	password	49	60000	M
9737	XYUOBO	PZCJELRJYN	9817920889 Dell Way	\N	MINYYCH	WA	38173	US	1	PZCJELRJYN@dell.com	9817920889	5	8467476079706103	2010/04	user9737	password	63	40000	F
9738	KWHZLH	CULNLVLZIU	7589985482 Dell Way	\N	NGTPNRX	MT	60530	US	1	CULNLVLZIU@dell.com	7589985482	5	8690637487452478	2009/03	user9738	password	25	80000	F
9739	KTNSWI	DJUZVTHPGO	4834580509 Dell Way	\N	IWCATPO	MO	58296	US	1	DJUZVTHPGO@dell.com	4834580509	5	7992696690373123	2010/08	user9739	password	81	100000	F
9740	KQFSUP	MTKGBANPIJ	6597728845 Dell Way	\N	SJCIYPV	KY	47646	US	1	MTKGBANPIJ@dell.com	6597728845	5	1169668131042271	2010/10	user9740	password	45	100000	F
9741	PPFECY	PJAPWQYFIH	4139564833 Dell Way	\N	IQFXMPI	CA	50700	US	1	PJAPWQYFIH@dell.com	4139564833	3	3293514566496015	2011/06	user9741	password	67	40000	F
9742	WNEVDN	VSKLRPUZYK	5461246304 Dell Way	\N	FWWUEZG	MT	59073	US	1	VSKLRPUZYK@dell.com	5461246304	2	1123910068534314	2008/08	user9742	password	24	20000	F
9743	GXGUTZ	EFQUZQTJVP	7844514126 Dell Way	\N	GQTFWHT	LA	59374	US	1	EFQUZQTJVP@dell.com	7844514126	3	2277338462416082	2012/08	user9743	password	36	20000	F
9744	MXGMCL	DWKTQTPFAF	9490454110 Dell Way	\N	ZFCGYMU	OK	11513	US	1	DWKTQTPFAF@dell.com	9490454110	3	6589178289752454	2009/09	user9744	password	26	80000	M
9745	JERUHO	EAEYQJYWIE	1564273610 Dell Way	\N	YPCLJVL	KS	44253	US	1	EAEYQJYWIE@dell.com	1564273610	3	1439549994654953	2008/03	user9745	password	63	60000	F
9746	HIRVMS	ZLIIKERODG	9141027617 Dell Way	\N	ROPMAYW	AZ	51335	US	1	ZLIIKERODG@dell.com	9141027617	2	7141623790375889	2010/10	user9746	password	23	80000	F
9747	TPPLPB	UXLYOZCUQQ	5418430059 Dell Way	\N	KCQJZSV	UT	96702	US	1	UXLYOZCUQQ@dell.com	5418430059	2	7712964741047473	2010/03	user9747	password	79	40000	M
9748	LTJMNH	XMWXOQNFBQ	3617435527 Dell Way	\N	WKPPFMO	OK	86742	US	1	XMWXOQNFBQ@dell.com	3617435527	2	1340774508658796	2008/07	user9748	password	78	60000	F
9749	FBWMZI	IWXZKCBAZM	9829028298 Dell Way	\N	QORCCKY	MA	71125	US	1	IWXZKCBAZM@dell.com	9829028298	3	3330315597355366	2012/02	user9749	password	60	20000	F
9750	LNDTVA	QVKTWLSICG	4350128068 Dell Way	\N	AEILCSC	CA	31579	US	1	QVKTWLSICG@dell.com	4350128068	5	4055680925492197	2012/12	user9750	password	54	40000	F
9751	QDGRUC	CNYOGHQMIU	2173326462 Dell Way	\N	VTXOWAU	IA	91932	US	1	CNYOGHQMIU@dell.com	2173326462	2	8486451874487103	2011/08	user9751	password	36	40000	M
9752	NYOPBC	OPIWFUEAQY	7042461337 Dell Way	\N	YEVYZBV	CO	34675	US	1	OPIWFUEAQY@dell.com	7042461337	4	8878801696002484	2012/01	user9752	password	63	60000	M
9753	EABGPQ	OLWJPWAOUF	6248252730 Dell Way	\N	JSELOHS	IA	12657	US	1	OLWJPWAOUF@dell.com	6248252730	1	1540159784723073	2009/08	user9753	password	21	40000	M
9754	CQFSFQ	POGLPUGUEZ	4026949718 Dell Way	\N	YPOGIUH	VA	95526	US	1	POGLPUGUEZ@dell.com	4026949718	1	5965080094058067	2009/06	user9754	password	31	60000	F
9755	KFIBUX	HGMCMGHMFW	3755416364 Dell Way	\N	AMEUTCT	CA	26457	US	1	HGMCMGHMFW@dell.com	3755416364	3	7022438307292760	2010/12	user9755	password	75	100000	F
9756	CYYZGE	MIQTPDZMDL	6297649029 Dell Way	\N	RYETSGX	AK	76427	US	1	MIQTPDZMDL@dell.com	6297649029	3	7137455067597330	2009/05	user9756	password	78	60000	F
9757	TMOXYW	OSMRRYVCPT	9803580035 Dell Way	\N	HJLOGLH	TX	95381	US	1	OSMRRYVCPT@dell.com	9803580035	2	3977054671384394	2012/09	user9757	password	65	60000	F
9758	FMEBAW	OSNNNQCHXL	5215062411 Dell Way	\N	TMSEUPD	PA	82824	US	1	OSNNNQCHXL@dell.com	5215062411	3	5703004338778556	2008/02	user9758	password	70	40000	M
9759	WJPSYH	GLVWNCUZVH	6634914559 Dell Way	\N	SABHEUC	NJ	41217	US	1	GLVWNCUZVH@dell.com	6634914559	4	5082278509624303	2009/01	user9759	password	19	40000	F
9760	QYJXFU	TBIVWHRDAR	8039321211 Dell Way	\N	EIVZKMI	AR	28504	US	1	TBIVWHRDAR@dell.com	8039321211	2	3277218642178923	2012/08	user9760	password	67	60000	M
9761	AITUCV	DXSLPVLGAT	1233328597 Dell Way	\N	CAEOIFU	CT	65651	US	1	DXSLPVLGAT@dell.com	1233328597	5	3016276874579489	2011/05	user9761	password	74	80000	M
9762	NNUIRR	ACGWNNXHQX	5877188572 Dell Way	\N	MFGSZJI	WY	35718	US	1	ACGWNNXHQX@dell.com	5877188572	4	6723148691467941	2009/06	user9762	password	42	100000	M
9763	CEQUFS	BCFOZNFXZK	4729245450 Dell Way	\N	DRJMAIU	NC	13630	US	1	BCFOZNFXZK@dell.com	4729245450	5	5214058581739664	2011/09	user9763	password	49	100000	M
9764	BQCTRE	ZGENLBMVEE	1381600646 Dell Way	\N	ERENLTO	TX	63583	US	1	ZGENLBMVEE@dell.com	1381600646	4	3648138761986047	2010/06	user9764	password	30	60000	F
9765	GHTLHA	PULQHHULMM	3367395821 Dell Way	\N	QAXJPUZ	NJ	44438	US	1	PULQHHULMM@dell.com	3367395821	1	8475519685074688	2010/08	user9765	password	84	80000	M
9766	RDFRSZ	DIGKDSWPJW	5629348796 Dell Way	\N	NTMHSCR	WV	26838	US	1	DIGKDSWPJW@dell.com	5629348796	3	8385039915330709	2010/02	user9766	password	72	20000	F
9767	YTXYWG	FHJYDZHANA	6298741941 Dell Way	\N	MVTPMST	AK	19406	US	1	FHJYDZHANA@dell.com	6298741941	3	2770054831169545	2009/07	user9767	password	47	40000	F
9768	IFDOLK	YJOYRPLRCG	4817030945 Dell Way	\N	KRTDLTF	AL	26438	US	1	YJOYRPLRCG@dell.com	4817030945	2	7283460034057499	2012/08	user9768	password	88	20000	M
9769	CSINRR	CPIRBATILL	7222578968 Dell Way	\N	BOWVUXZ	GA	32782	US	1	CPIRBATILL@dell.com	7222578968	1	9100579171907158	2011/03	user9769	password	74	80000	M
9770	CHPTJF	CBHCVPOGQC	2385181927 Dell Way	\N	CLXALCG	DC	22661	US	1	CBHCVPOGQC@dell.com	2385181927	5	4066521316301078	2012/07	user9770	password	37	20000	M
9771	WUFCWH	JZCZNIPPLB	1672686843 Dell Way	\N	MLNPRRT	TN	51949	US	1	JZCZNIPPLB@dell.com	1672686843	4	1304434189107269	2009/10	user9771	password	82	40000	M
9772	CIKJRJ	LQXUGMFIZQ	1099130467 Dell Way	\N	WPINIDZ	MD	92206	US	1	LQXUGMFIZQ@dell.com	1099130467	4	7216504163574428	2012/12	user9772	password	35	20000	F
9773	QKYAWP	XQWKVEKMAZ	5900979703 Dell Way	\N	UNIYNSW	MT	49636	US	1	XQWKVEKMAZ@dell.com	5900979703	3	4543743003625423	2011/06	user9773	password	65	60000	M
9774	PMRFJI	BUEFFQGFLT	1356152656 Dell Way	\N	NJHFFUQ	RI	29497	US	1	BUEFFQGFLT@dell.com	1356152656	3	6829612256027759	2011/12	user9774	password	52	40000	F
9775	EMVMOQ	QTVGZASTNB	7328629980 Dell Way	\N	BTHVJBB	ME	63918	US	1	QTVGZASTNB@dell.com	7328629980	1	6275583057664335	2008/06	user9775	password	20	40000	M
9776	WULNLF	JSFJKZXMAQ	9813778398 Dell Way	\N	TWAUXLK	NJ	61138	US	1	JSFJKZXMAQ@dell.com	9813778398	4	9887244455050678	2008/02	user9776	password	83	100000	M
9777	JKJOTB	UDMTBYTRRP	7525306158 Dell Way	\N	SMNEWDT	TN	91083	US	1	UDMTBYTRRP@dell.com	7525306158	5	1154174757190048	2011/10	user9777	password	86	100000	F
9778	HOXJIB	VBCTVUKLNW	9770038907 Dell Way	\N	YRTBLOY	DC	48285	US	1	VBCTVUKLNW@dell.com	9770038907	4	2602637584786862	2012/10	user9778	password	42	40000	F
9779	GOQIJS	LDOFNZTKXL	3894216137 Dell Way	\N	DZWSYZD	VT	79490	US	1	LDOFNZTKXL@dell.com	3894216137	5	5803884499706328	2011/01	user9779	password	80	100000	M
9780	MGZFRC	TXQTQBRBFQ	2794720077 Dell Way	\N	XXOXBMR	MA	35501	US	1	TXQTQBRBFQ@dell.com	2794720077	1	3768946541473270	2008/12	user9780	password	83	60000	F
9781	WTWYNT	PGKQXLVNIT	2384716488 Dell Way	\N	CGUOXEW	CA	30360	US	1	PGKQXLVNIT@dell.com	2384716488	1	2713932792656123	2008/09	user9781	password	47	100000	F
9782	HWZAMF	LCDWYRFRTL	1885682842 Dell Way	\N	MIIRELX	KS	62275	US	1	LCDWYRFRTL@dell.com	1885682842	2	3443602026905864	2010/04	user9782	password	70	80000	F
9783	RUQXGT	ACRSHJLTWU	4332838926 Dell Way	\N	COYNLHC	NC	69147	US	1	ACRSHJLTWU@dell.com	4332838926	1	9510643584188076	2008/10	user9783	password	25	80000	M
9784	TRWMSY	DKGNWAJRCX	5474071760 Dell Way	\N	PPJXSXO	AZ	95101	US	1	DKGNWAJRCX@dell.com	5474071760	1	7824986320454628	2011/12	user9784	password	45	40000	M
9785	FUIEYT	LLPLVGNSWD	7123529528 Dell Way	\N	BUWZIYX	SD	18072	US	1	LLPLVGNSWD@dell.com	7123529528	3	1279980187769979	2008/10	user9785	password	65	40000	M
9786	ZMNSXZ	IIUPWNMAPG	9190870348 Dell Way	\N	WOOUMJW	DE	82691	US	1	IIUPWNMAPG@dell.com	9190870348	2	6133740510791541	2010/07	user9786	password	28	60000	M
9787	RHWQPF	KFCXRCNXZB	3226984207 Dell Way	\N	MTNWQSR	ND	92194	US	1	KFCXRCNXZB@dell.com	3226984207	1	4730154392775148	2009/08	user9787	password	45	20000	M
9788	GRNLCT	OAKRNIQOVK	2115284883 Dell Way	\N	CRBUJPS	NJ	74168	US	1	OAKRNIQOVK@dell.com	2115284883	5	4368316572159529	2010/01	user9788	password	40	80000	M
9789	VFUOTU	ZKIIBWDLZV	2521561065 Dell Way	\N	MUECMUU	NH	80326	US	1	ZKIIBWDLZV@dell.com	2521561065	1	8409721992444248	2010/11	user9789	password	57	40000	F
9790	IXVDWF	LEGIISIDFC	7292875492 Dell Way	\N	IHOCBEW	IA	34399	US	1	LEGIISIDFC@dell.com	7292875492	4	2141440323553979	2009/01	user9790	password	31	60000	M
9791	ASUFEZ	MNHFVLKXTR	1210049688 Dell Way	\N	MVTQSZX	MD	73645	US	1	MNHFVLKXTR@dell.com	1210049688	4	7619373654946686	2009/03	user9791	password	65	40000	M
9792	LLDKYQ	SDMDOJWFVS	4668493697 Dell Way	\N	ZLLZJVR	MA	52989	US	1	SDMDOJWFVS@dell.com	4668493697	3	7304443202447147	2008/10	user9792	password	65	60000	F
9793	UXEKQI	WUWGQCCJBN	8213634622 Dell Way	\N	UAXQSGC	CO	86086	US	1	WUWGQCCJBN@dell.com	8213634622	1	6805227661039681	2010/08	user9793	password	82	40000	M
9794	BQFJNZ	GUQIWAJJUK	1153815274 Dell Way	\N	GKCNNFJ	KS	42434	US	1	GUQIWAJJUK@dell.com	1153815274	4	1183155208360403	2012/12	user9794	password	61	100000	M
9795	UIDUPX	KXTKHDFSKQ	4386807545 Dell Way	\N	UYDZILJ	KS	30456	US	1	KXTKHDFSKQ@dell.com	4386807545	2	2941057248041034	2012/03	user9795	password	79	80000	M
9796	ZODXZA	RKIVPAGFVE	3482003691 Dell Way	\N	JVMVEVB	ND	14910	US	1	RKIVPAGFVE@dell.com	3482003691	3	3266520898789167	2008/04	user9796	password	75	20000	M
9797	XAVYRG	HNVITBDXLY	5810093080 Dell Way	\N	KHDFIRH	NJ	29336	US	1	HNVITBDXLY@dell.com	5810093080	4	5661148877814413	2009/11	user9797	password	45	40000	M
9798	FFNLMB	HVUJYSUXCB	5227234363 Dell Way	\N	BIKTPAY	DC	76937	US	1	HVUJYSUXCB@dell.com	5227234363	3	6202388779725880	2012/09	user9798	password	49	20000	M
9799	YNKZVF	UEEMZCOBDX	8337945785 Dell Way	\N	MWNMVRG	IL	22539	US	1	UEEMZCOBDX@dell.com	8337945785	1	8748006551992149	2009/03	user9799	password	75	40000	M
9800	FFOLZT	PLTSAVVYHS	2008392182 Dell Way	\N	LUNCAVG	TX	96736	US	1	PLTSAVVYHS@dell.com	2008392182	1	2638180944602936	2012/04	user9800	password	85	20000	F
9801	NNMGDX	AVYWRWDJIY	8716726630 Dell Way	\N	XLZSRVR	SC	91614	US	1	AVYWRWDJIY@dell.com	8716726630	4	2762500360142439	2011/10	user9801	password	67	40000	F
9802	DOMBPH	ALZWPIFNFQ	4766938253 Dell Way	\N	MYHIQCF	MO	80987	US	1	ALZWPIFNFQ@dell.com	4766938253	2	6244006014429033	2008/07	user9802	password	84	40000	F
9803	JISRID	RFSZKGFATE	8218045167 Dell Way	\N	IBULHGF	OH	56699	US	1	RFSZKGFATE@dell.com	8218045167	5	1674229059368372	2011/01	user9803	password	32	20000	F
9804	XUSALX	TKIZQITVRU	4957039159 Dell Way	\N	PCCVIUJ	CT	61987	US	1	TKIZQITVRU@dell.com	4957039159	5	6700186044443399	2011/12	user9804	password	18	60000	M
9805	SODQIO	YIFHBAZWPB	9303372835 Dell Way	\N	YLKSVNH	IA	42861	US	1	YIFHBAZWPB@dell.com	9303372835	5	3676018417812884	2012/05	user9805	password	18	80000	M
9806	DHHSFQ	XNRXMNNOMZ	2153522292 Dell Way	\N	YEUMMBV	MD	93506	US	1	XNRXMNNOMZ@dell.com	2153522292	2	4087164715863764	2008/12	user9806	password	41	40000	F
9807	QZMGXZ	XVLLIAYIYC	4734836561 Dell Way	\N	CKPDGZB	LA	37054	US	1	XVLLIAYIYC@dell.com	4734836561	3	3491244190372527	2011/10	user9807	password	56	40000	M
9808	APQZNM	LZULXDKZFV	2133412610 Dell Way	\N	OJBOLLW	TX	93578	US	1	LZULXDKZFV@dell.com	2133412610	3	7386163921095432	2011/12	user9808	password	52	80000	M
9809	DRBPCA	KOXNZXTUMC	9090330996 Dell Way	\N	VAOGXKE	AK	98522	US	1	KOXNZXTUMC@dell.com	9090330996	4	9386834341567012	2009/04	user9809	password	52	60000	M
9810	NCCOMR	MAQKTKXVGX	7257721619 Dell Way	\N	KNVUSVT	NH	54310	US	1	MAQKTKXVGX@dell.com	7257721619	5	8426656140014530	2008/06	user9810	password	77	80000	M
9811	XHAOTB	FDUPAQWYAJ	9191619573 Dell Way	\N	UUBPORC	IA	66502	US	1	FDUPAQWYAJ@dell.com	9191619573	3	1816919586621225	2011/02	user9811	password	64	80000	F
9812	RFESKI	NAJDXIDGCY	7354710548 Dell Way	\N	IRMZTTP	NY	24413	US	1	NAJDXIDGCY@dell.com	7354710548	2	3649061035364866	2009/01	user9812	password	69	20000	F
9813	WTREGR	OJPWNVYLEQ	2088855816 Dell Way	\N	YDJRTBV	MO	50899	US	1	OJPWNVYLEQ@dell.com	2088855816	5	5385791569482535	2012/11	user9813	password	71	80000	M
9814	KWVBLF	QHTMFERWCU	3077345903 Dell Way	\N	GUOHPBT	OK	88220	US	1	QHTMFERWCU@dell.com	3077345903	3	7466738464776427	2012/03	user9814	password	41	40000	F
9815	EKOJBV	COBHFXKADE	3082182496 Dell Way	\N	PLTQEMN	MD	12956	US	1	COBHFXKADE@dell.com	3082182496	2	3448377938941121	2010/09	user9815	password	46	80000	F
9816	YCFTFT	VMZSWZWBPH	6463271341 Dell Way	\N	VGLHTVI	WY	28401	US	1	VMZSWZWBPH@dell.com	6463271341	3	9195662056561560	2012/03	user9816	password	20	100000	F
9817	GSNZNA	ZGWZCYOKTV	8195166888 Dell Way	\N	VBORJOX	WY	17236	US	1	ZGWZCYOKTV@dell.com	8195166888	5	3857395547907800	2012/12	user9817	password	64	20000	M
9818	EBEEBK	BANZPXSKTU	9313894215 Dell Way	\N	ZLENIDP	CT	22351	US	1	BANZPXSKTU@dell.com	9313894215	5	1590848983731120	2010/01	user9818	password	69	80000	F
9819	WXEHYE	UXUSQELKEW	9293341659 Dell Way	\N	ORFSHIW	HI	34701	US	1	UXUSQELKEW@dell.com	9293341659	4	3758207839913666	2011/07	user9819	password	48	60000	F
9820	OTITNG	NGXSRHWOWO	6863245883 Dell Way	\N	TPWBLCI	LA	89158	US	1	NGXSRHWOWO@dell.com	6863245883	5	4493456207215786	2008/06	user9820	password	75	80000	F
9821	CJTJXZ	GQRONFKBZA	3788570923 Dell Way	\N	YBLBKVX	AR	83026	US	1	GQRONFKBZA@dell.com	3788570923	1	3515785581432283	2008/09	user9821	password	54	40000	F
9822	GOAGVQ	XJDDUFDUEE	2406276319 Dell Way	\N	GFOBDPW	MI	74710	US	1	XJDDUFDUEE@dell.com	2406276319	3	5130977471824736	2011/09	user9822	password	60	100000	F
9823	PDDGBM	JFGPIBUMHZ	8471864567 Dell Way	\N	BJCQGOJ	MA	18131	US	1	JFGPIBUMHZ@dell.com	8471864567	1	8501967263408006	2010/12	user9823	password	28	20000	F
9824	GGDTQJ	AGRBADJZES	6183708857 Dell Way	\N	CVYQFIT	AR	44797	US	1	AGRBADJZES@dell.com	6183708857	3	4018728672526777	2011/06	user9824	password	49	100000	M
9825	PTIYTO	PVOTEOYXQT	9289954263 Dell Way	\N	WHZFAAP	NJ	51555	US	1	PVOTEOYXQT@dell.com	9289954263	2	9219659290276468	2009/04	user9825	password	62	100000	F
9826	YWVMMQ	BFVPDTFXPN	3370230325 Dell Way	\N	WUOXJDJ	IN	53156	US	1	BFVPDTFXPN@dell.com	3370230325	4	8177512865047903	2012/08	user9826	password	80	100000	F
9827	RHYIID	EXGXDENRBH	6641131123 Dell Way	\N	FYRJHZV	NC	67458	US	1	EXGXDENRBH@dell.com	6641131123	3	3064936965703964	2010/03	user9827	password	68	20000	M
9828	QMWTRU	AOXEBOGJUE	9147280860 Dell Way	\N	BDLAYZR	NE	45788	US	1	AOXEBOGJUE@dell.com	9147280860	1	6564581980463118	2010/03	user9828	password	27	40000	M
9829	ZZKTZY	REAGKKAOLD	1132719239 Dell Way	\N	AMCZERK	AZ	74801	US	1	REAGKKAOLD@dell.com	1132719239	4	9534807856660336	2008/11	user9829	password	67	20000	M
9830	BWWAOA	BULLVAXYBK	4185983213 Dell Way	\N	ABORLQK	MN	38268	US	1	BULLVAXYBK@dell.com	4185983213	3	2798760645091533	2008/09	user9830	password	22	20000	M
9831	XCEYDZ	KPUKNSLXTM	6720225565 Dell Way	\N	MLYDVJL	GA	97834	US	1	KPUKNSLXTM@dell.com	6720225565	2	7325992119964213	2011/04	user9831	password	40	60000	F
9832	MNOLXE	FIRYUPSGBD	3277579311 Dell Way	\N	FEZOQEO	ID	45807	US	1	FIRYUPSGBD@dell.com	3277579311	5	7380285512190313	2010/07	user9832	password	27	20000	F
9833	SMZWSI	ORCDJJFNOK	7911422626 Dell Way	\N	MDARRHB	WI	32054	US	1	ORCDJJFNOK@dell.com	7911422626	3	8141811233945192	2012/07	user9833	password	81	60000	F
9834	WLUFAL	HDVRJIGTVJ	2088518663 Dell Way	\N	UMBCNAI	IN	57454	US	1	HDVRJIGTVJ@dell.com	2088518663	1	1794094386044889	2012/10	user9834	password	28	100000	F
9835	YBGJJK	FATNGNJQIV	4122315614 Dell Way	\N	SKJTSRG	TN	88294	US	1	FATNGNJQIV@dell.com	4122315614	5	6916909312363715	2010/09	user9835	password	83	60000	M
9836	DUDOZE	INKVWBDSUN	3391357481 Dell Way	\N	BNGTUCP	CT	93341	US	1	INKVWBDSUN@dell.com	3391357481	4	6651727831456811	2008/01	user9836	password	46	40000	M
9837	NWVREJ	CAFEDYYRZM	6080767687 Dell Way	\N	XTGAIJY	NH	97573	US	1	CAFEDYYRZM@dell.com	6080767687	4	1047831355594098	2012/02	user9837	password	78	60000	M
9838	RDDAGD	FKHDJYDVWW	4472960316 Dell Way	\N	BWFKVVJ	MA	63676	US	1	FKHDJYDVWW@dell.com	4472960316	2	7188284512609244	2009/10	user9838	password	65	100000	M
9839	UWFYCP	FGYEKTAHVX	6482014710 Dell Way	\N	NFSIPCX	WY	50798	US	1	FGYEKTAHVX@dell.com	6482014710	2	3401779867243022	2009/01	user9839	password	34	20000	M
9840	LZBAEI	ZISTJAOGNT	8451283881 Dell Way	\N	ZVJCTIO	LA	58088	US	1	ZISTJAOGNT@dell.com	8451283881	4	6479034822434188	2008/08	user9840	password	58	60000	M
9841	QNUYMD	QFMRTTEMSZ	3940604921 Dell Way	\N	WVTEKCS	HI	74838	US	1	QFMRTTEMSZ@dell.com	3940604921	2	4400293947663158	2012/10	user9841	password	90	60000	F
9842	ULSXCY	JTRCXEVXAR	8625467624 Dell Way	\N	QFCTYHM	IA	62546	US	1	JTRCXEVXAR@dell.com	8625467624	1	4069884567521513	2012/08	user9842	password	61	80000	F
9843	IOEGXY	YAVDWTDOKJ	8730352931 Dell Way	\N	QDHYPON	MN	71291	US	1	YAVDWTDOKJ@dell.com	8730352931	2	3960797844454646	2010/12	user9843	password	48	80000	F
9844	PBKNZL	JCHCGWMPMQ	5017567228 Dell Way	\N	XKGLYRD	SC	99281	US	1	JCHCGWMPMQ@dell.com	5017567228	2	9364055438432844	2012/01	user9844	password	47	60000	F
9845	VZCGIF	OLMKYCXOZI	4828127298 Dell Way	\N	VKGNNBM	WV	38438	US	1	OLMKYCXOZI@dell.com	4828127298	5	4251750676892698	2012/04	user9845	password	51	80000	F
9846	OXQTLB	FVAHTPHBKR	1489804353 Dell Way	\N	IXFJKES	TN	12724	US	1	FVAHTPHBKR@dell.com	1489804353	4	3931206800974906	2010/04	user9846	password	61	20000	F
9847	FVQHBM	HIFXPHHHPF	1557319401 Dell Way	\N	NZPSRLT	OK	18338	US	1	HIFXPHHHPF@dell.com	1557319401	2	4602787996176630	2011/04	user9847	password	61	100000	F
9848	FEESMM	YJCFRKUWXU	4659800251 Dell Way	\N	MQLXJEA	ME	46060	US	1	YJCFRKUWXU@dell.com	4659800251	1	7297351299319417	2008/12	user9848	password	77	40000	F
9849	ZYQMWA	PBSZWOXQBO	4264661246 Dell Way	\N	CZXGZIR	MA	47652	US	1	PBSZWOXQBO@dell.com	4264661246	2	4541029710322619	2008/08	user9849	password	57	20000	M
9850	EQLFFN	XFJMDANRDN	7387127286 Dell Way	\N	OKMXBWI	ME	32473	US	1	XFJMDANRDN@dell.com	7387127286	3	8828583798836918	2009/10	user9850	password	49	60000	F
9851	WQPJOV	TAYUOPXBEH	5556971506 Dell Way	\N	NCIKKTQ	CO	42243	US	1	TAYUOPXBEH@dell.com	5556971506	2	2040755159221589	2012/10	user9851	password	55	80000	F
9852	DEZYXA	XRONOPRWDT	5008921811 Dell Way	\N	FNEZDGI	NV	66539	US	1	XRONOPRWDT@dell.com	5008921811	3	4882586627732963	2012/05	user9852	password	82	20000	M
9853	WALWXD	LKSACODWUQ	4161973645 Dell Way	\N	ATUHBLX	MT	12193	US	1	LKSACODWUQ@dell.com	4161973645	3	4676935753319413	2009/07	user9853	password	87	20000	M
9854	KZMNKX	FKZUOWOFWH	8729319027 Dell Way	\N	ZEJLCXL	MI	43225	US	1	FKZUOWOFWH@dell.com	8729319027	4	9252132618799808	2012/10	user9854	password	53	40000	M
9855	YTDVYO	VSCRHHOPHS	2226929072 Dell Way	\N	YSUWEGF	AL	91974	US	1	VSCRHHOPHS@dell.com	2226929072	5	7104101681150497	2011/01	user9855	password	48	60000	M
9856	OKTCGM	FXTNMIVEHO	8415081683 Dell Way	\N	ZDSGJTD	MO	62447	US	1	FXTNMIVEHO@dell.com	8415081683	1	6724895811174066	2009/09	user9856	password	48	80000	F
9857	EXIQDG	JQSRMXZAXC	7053123222 Dell Way	\N	SDLLHYA	CO	12992	US	1	JQSRMXZAXC@dell.com	7053123222	2	7392285216599704	2008/02	user9857	password	76	40000	F
9858	DWEKFV	CXHAWHXZZB	1757128453 Dell Way	\N	KLIIMLJ	DE	80643	US	1	CXHAWHXZZB@dell.com	1757128453	2	9377247045282276	2012/07	user9858	password	89	20000	F
9859	EKPZNN	GNJOLIOMTA	9856238952 Dell Way	\N	VCMGMRB	ND	92134	US	1	GNJOLIOMTA@dell.com	9856238952	3	4754323019646108	2012/06	user9859	password	75	20000	M
9860	JCJWJX	GXJPMWJMRL	9598119212 Dell Way	\N	ZYXQAMN	WY	92418	US	1	GXJPMWJMRL@dell.com	9598119212	5	4390116129536182	2011/02	user9860	password	35	20000	F
9861	QAOOGM	XWYTFLLRKK	4329469304 Dell Way	\N	PALCOLZ	MT	45106	US	1	XWYTFLLRKK@dell.com	4329469304	2	5327491091098637	2011/05	user9861	password	67	40000	F
9862	GURTSN	SMTDXLNIAO	1555954525 Dell Way	\N	TCDECQP	MN	92664	US	1	SMTDXLNIAO@dell.com	1555954525	1	3749297130852938	2011/04	user9862	password	68	100000	F
9863	JSVWKH	QOFBBNCQHE	6775675329 Dell Way	\N	TMHKBTI	CT	85995	US	1	QOFBBNCQHE@dell.com	6775675329	5	2569979070685804	2009/11	user9863	password	39	80000	M
9864	COZKFN	PGPCIFKNZX	6340674642 Dell Way	\N	VKZOTCK	MA	96608	US	1	PGPCIFKNZX@dell.com	6340674642	4	8350123484153301	2012/06	user9864	password	46	100000	M
9865	JJEXYL	MBUSMHSJDD	2897764676 Dell Way	\N	ISWLCHK	OK	10041	US	1	MBUSMHSJDD@dell.com	2897764676	3	4810867321677506	2011/08	user9865	password	48	100000	M
9866	PWYBJA	VCMDVWGYFY	5641644926 Dell Way	\N	VQBCAUC	IA	43428	US	1	VCMDVWGYFY@dell.com	5641644926	5	9658594275359064	2012/10	user9866	password	86	60000	M
9867	WPBWLD	JOYFVXKUSB	9639398895 Dell Way	\N	WUCQXIZ	ME	24506	US	1	JOYFVXKUSB@dell.com	9639398895	2	9767109017353506	2012/11	user9867	password	66	80000	F
9868	SQXWZM	UFHSQCKRYF	3079827026 Dell Way	\N	UOCCONG	MT	87788	US	1	UFHSQCKRYF@dell.com	3079827026	3	7769490292761476	2012/03	user9868	password	35	60000	M
9869	DLUQGA	YYQAJIYOCN	8217128882 Dell Way	\N	RFCELPB	NY	11319	US	1	YYQAJIYOCN@dell.com	8217128882	3	2695659447461366	2008/03	user9869	password	90	20000	M
9870	UVWUTV	LTETSTWGKB	2091313365 Dell Way	\N	IPNXQFY	MI	80196	US	1	LTETSTWGKB@dell.com	2091313365	3	9605052517727018	2008/08	user9870	password	60	100000	F
9871	MSFHDZ	MXSFTYPVGE	3497106682 Dell Way	\N	IEVOCGI	HI	76619	US	1	MXSFTYPVGE@dell.com	3497106682	2	4617201973684132	2012/03	user9871	password	81	40000	M
9872	CPBBBZ	UHSSWOZBWD	3590197728 Dell Way	\N	WLGDTMX	AL	84553	US	1	UHSSWOZBWD@dell.com	3590197728	5	1679610823746770	2008/03	user9872	password	19	40000	M
9873	CIXBCE	UVAIUCFYZQ	6283559264 Dell Way	\N	FDKRAKN	IL	36625	US	1	UVAIUCFYZQ@dell.com	6283559264	3	5527673435863108	2011/09	user9873	password	41	80000	F
9874	FTDJOZ	KXUMCSMTXP	4134877836 Dell Way	\N	DPPOCWV	OH	39138	US	1	KXUMCSMTXP@dell.com	4134877836	2	1306282394565641	2011/01	user9874	password	23	100000	M
9875	FGIFRF	ZDIRPBPEFF	9951686634 Dell Way	\N	TTHQPAY	WI	37203	US	1	ZDIRPBPEFF@dell.com	9951686634	4	3758975178003311	2008/06	user9875	password	23	40000	M
9876	KNKPMO	YEEATIFYCZ	8869443431 Dell Way	\N	GTOGSNO	OH	22416	US	1	YEEATIFYCZ@dell.com	8869443431	4	6732404173351825	2012/01	user9876	password	46	40000	M
9877	UZBIXF	NXZWCYYCFS	9503509365 Dell Way	\N	QMKEADI	VT	90229	US	1	NXZWCYYCFS@dell.com	9503509365	5	9678292707540096	2009/03	user9877	password	57	20000	F
9878	PMBUZZ	TVCSUEXMVJ	8815722338 Dell Way	\N	XZKAHHX	IA	24036	US	1	TVCSUEXMVJ@dell.com	8815722338	3	4276808808092028	2010/09	user9878	password	57	100000	F
9879	PUDPOZ	RGTWEFRNDR	7575091783 Dell Way	\N	XDZFAFJ	VA	82945	US	1	RGTWEFRNDR@dell.com	7575091783	2	5647262863814831	2009/04	user9879	password	68	100000	F
9880	VMQUDX	OABTROWJMA	9177468725 Dell Way	\N	JSAPBYK	SC	32216	US	1	OABTROWJMA@dell.com	9177468725	1	5921000105328858	2010/12	user9880	password	64	60000	F
9881	HGOEUO	GNGUKQHKZZ	2683015736 Dell Way	\N	LOBKYVQ	UT	90656	US	1	GNGUKQHKZZ@dell.com	2683015736	3	8529014453757555	2012/11	user9881	password	36	20000	F
9882	VHXJNL	QIWHPHHPTV	2834331702 Dell Way	\N	QDUMURJ	WI	22784	US	1	QIWHPHHPTV@dell.com	2834331702	4	1432121201884001	2010/11	user9882	password	31	40000	F
9883	CQROHZ	LPPSWELRVO	4189073755 Dell Way	\N	MHJEQHH	TX	17403	US	1	LPPSWELRVO@dell.com	4189073755	2	9640832729171964	2010/07	user9883	password	26	80000	F
9884	UFNTQC	JJYNUQIJCQ	1639428386 Dell Way	\N	SHHAPDC	WA	49003	US	1	JJYNUQIJCQ@dell.com	1639428386	3	1001755229197442	2008/02	user9884	password	33	100000	F
9885	SSZUCJ	SPDJYNMOGT	4633760716 Dell Way	\N	VHIZKGK	MN	76870	US	1	SPDJYNMOGT@dell.com	4633760716	4	8908468482550234	2011/08	user9885	password	34	40000	F
9886	FDLOWA	SFZGRONKKU	6574334144 Dell Way	\N	TJFZTRT	DE	37923	US	1	SFZGRONKKU@dell.com	6574334144	4	9361527753993870	2012/02	user9886	password	38	20000	F
9887	SQCTJI	SQZGEKQYDA	1382122038 Dell Way	\N	DDUUWYC	MS	75225	US	1	SQZGEKQYDA@dell.com	1382122038	2	8554279467090965	2009/06	user9887	password	24	20000	F
9888	ETLNMC	MTGXKFBKJE	7146271610 Dell Way	\N	EEBDGOV	IN	92125	US	1	MTGXKFBKJE@dell.com	7146271610	4	4038809084799141	2011/08	user9888	password	48	100000	F
9889	WMXZZQ	FWALXKUCPY	9769427393 Dell Way	\N	ESFSONQ	IA	23807	US	1	FWALXKUCPY@dell.com	9769427393	1	8260515503585339	2009/12	user9889	password	34	40000	F
9890	CGKTMG	TXEESHTQLM	4022643712 Dell Way	\N	WEAJUGN	RI	34233	US	1	TXEESHTQLM@dell.com	4022643712	1	3104542166460305	2010/06	user9890	password	66	80000	M
9891	BKDIDB	MITUBJFNGJ	3932122100 Dell Way	\N	OPEVDYC	MO	17510	US	1	MITUBJFNGJ@dell.com	3932122100	1	5565416894387454	2012/09	user9891	password	30	20000	F
9892	HJFJWO	CQPMWDSFSH	8929254961 Dell Way	\N	JNLHPXJ	WA	94691	US	1	CQPMWDSFSH@dell.com	8929254961	5	6685847872868181	2008/12	user9892	password	70	40000	F
9893	YSFMUW	CGSFYYYGHL	2722222775 Dell Way	\N	SPBQYAO	TN	93742	US	1	CGSFYYYGHL@dell.com	2722222775	5	9187871844507756	2012/03	user9893	password	37	100000	M
9894	MJTJLA	BRZZPGHBYW	9553298179 Dell Way	\N	COVCDQB	IN	58312	US	1	BRZZPGHBYW@dell.com	9553298179	2	8047077589668334	2009/01	user9894	password	71	80000	F
9895	MBWMDN	MCDSKEQGHF	1372073800 Dell Way	\N	BKISLQG	MA	85504	US	1	MCDSKEQGHF@dell.com	1372073800	3	9241811134852470	2011/04	user9895	password	42	40000	F
9896	FTMSFP	WYZAOGHTHS	5030968752 Dell Way	\N	BADSHNN	KS	19021	US	1	WYZAOGHTHS@dell.com	5030968752	1	4537294474430382	2011/05	user9896	password	71	100000	F
9897	FSJUOH	TPVZXPHPRI	7441223063 Dell Way	\N	SJPFXYI	KY	13364	US	1	TPVZXPHPRI@dell.com	7441223063	1	4649058046285063	2010/02	user9897	password	56	80000	M
9898	XLKEFZ	AFXQMMHVFR	8261508193 Dell Way	\N	LKOJTYK	MN	15567	US	1	AFXQMMHVFR@dell.com	8261508193	5	2669138757977634	2009/07	user9898	password	19	40000	F
9899	LKFLKL	IBYUITZAEK	7784129114 Dell Way	\N	POENYQO	PA	58173	US	1	IBYUITZAEK@dell.com	7784129114	1	1978277022950351	2011/04	user9899	password	27	40000	M
9900	JQDUYE	STNLTNQECE	6290259547 Dell Way	\N	IPCYEWM	WA	95763	US	1	STNLTNQECE@dell.com	6290259547	4	3466219385620207	2011/12	user9900	password	90	20000	M
9901	DWMIOG	VAZJQDMULC	1027636584 Dell Way	\N	XKGUWFS	MO	92479	US	1	VAZJQDMULC@dell.com	1027636584	1	8515805768780411	2012/04	user9901	password	45	20000	F
9902	WLRCHR	CQHFCCREAC	4694605660 Dell Way	\N	LUZRNLO	MT	66897	US	1	CQHFCCREAC@dell.com	4694605660	3	8985038563609124	2011/08	user9902	password	90	80000	F
9903	QUJHWA	PCDRUIRWUM	8335799926 Dell Way	\N	WLZHAMY	ME	10236	US	1	PCDRUIRWUM@dell.com	8335799926	2	6851593432482333	2012/11	user9903	password	72	60000	M
9904	DTNDJQ	HAKPSHKEDV	3765270917 Dell Way	\N	ELVRJGR	DE	53037	US	1	HAKPSHKEDV@dell.com	3765270917	5	4269546090159565	2008/06	user9904	password	20	20000	F
9905	OINEQO	PFHXPMALQL	4374349145 Dell Way	\N	HHVNYZA	IA	98197	US	1	PFHXPMALQL@dell.com	4374349145	2	4709702628664673	2010/06	user9905	password	61	100000	M
9906	DDLSTR	ZQHLRSBDZJ	4134796984 Dell Way	\N	YNHYNOY	VT	86722	US	1	ZQHLRSBDZJ@dell.com	4134796984	2	4076975372619927	2012/04	user9906	password	30	20000	F
9907	PUEHTV	OENHGQHQPV	6912680378 Dell Way	\N	XOJMMGI	TN	61589	US	1	OENHGQHQPV@dell.com	6912680378	4	8664631383959205	2012/11	user9907	password	38	60000	M
9908	MSKHHO	VPVLWLBRJQ	7396963919 Dell Way	\N	AVDHDYW	SC	77330	US	1	VPVLWLBRJQ@dell.com	7396963919	4	6541116243228317	2012/01	user9908	password	36	60000	M
9909	QUCFPR	BBONCFWTGS	2529316471 Dell Way	\N	WOVUKQO	CO	33544	US	1	BBONCFWTGS@dell.com	2529316471	1	3930620914325118	2010/07	user9909	password	26	20000	F
9910	FHYWIZ	LVCRSVXKRL	5095583993 Dell Way	\N	GMWWAZD	GA	17683	US	1	LVCRSVXKRL@dell.com	5095583993	4	6936341112013907	2010/09	user9910	password	18	80000	M
9911	YRIYCD	ATWWRGNDMA	7363815189 Dell Way	\N	ZIAZMGB	WA	88442	US	1	ATWWRGNDMA@dell.com	7363815189	3	6117155205458403	2011/04	user9911	password	58	80000	M
9912	WPAAPT	WLKCZNOZNX	7213534761 Dell Way	\N	AMKGNID	HI	82886	US	1	WLKCZNOZNX@dell.com	7213534761	5	1728830109350383	2009/08	user9912	password	18	20000	F
9913	ACUTZG	EBFSQEGOES	2390930906 Dell Way	\N	YLGGOMB	IA	48258	US	1	EBFSQEGOES@dell.com	2390930906	3	1262335837353020	2008/08	user9913	password	33	20000	M
9914	AYRGDT	LVKPBYUUXG	9632295031 Dell Way	\N	AEUNGAY	MD	57029	US	1	LVKPBYUUXG@dell.com	9632295031	3	1991780030075460	2008/09	user9914	password	77	20000	M
9915	MKUFVQ	PLSOGNMMNQ	9559336067 Dell Way	\N	HBWIZHV	WA	84993	US	1	PLSOGNMMNQ@dell.com	9559336067	1	6108098768629134	2011/04	user9915	password	36	40000	M
9916	BMNSCZ	KQGYDTMTAN	3815666431 Dell Way	\N	QIMXEKT	CT	56318	US	1	KQGYDTMTAN@dell.com	3815666431	5	8127351176925004	2010/02	user9916	password	52	80000	M
9917	AIRZTI	GRLZDFAQVJ	8555417209 Dell Way	\N	DTONMRB	SD	61466	US	1	GRLZDFAQVJ@dell.com	8555417209	2	7379095550160856	2009/12	user9917	password	40	40000	F
9918	ZIAIOS	TOVYPMUYPO	4971209726 Dell Way	\N	MDAEEVT	AK	28267	US	1	TOVYPMUYPO@dell.com	4971209726	2	2637834918685257	2011/08	user9918	password	52	80000	M
9919	NBOFVD	AUSNPQCDDG	4370445847 Dell Way	\N	DHKZALF	MN	78284	US	1	AUSNPQCDDG@dell.com	4370445847	2	4740494974888861	2012/12	user9919	password	46	40000	F
9920	YOVBPQ	UCFLFIOLMV	5113627342 Dell Way	\N	WMWHRIB	AL	59571	US	1	UCFLFIOLMV@dell.com	5113627342	5	5601909035351128	2012/03	user9920	password	56	100000	M
9921	JWKARN	FCSNQEAMAM	7723142793 Dell Way	\N	JHDRIEG	SC	14103	US	1	FCSNQEAMAM@dell.com	7723142793	4	3560910982079804	2009/06	user9921	password	24	80000	F
9922	MRZZWB	SKSWKFWXOE	5700053690 Dell Way	\N	AFNEMIG	GA	97292	US	1	SKSWKFWXOE@dell.com	5700053690	3	4849069932475686	2011/02	user9922	password	73	20000	M
9923	TBSVUC	OQNTNLHRLN	9325352876 Dell Way	\N	FQZNWEM	MD	70802	US	1	OQNTNLHRLN@dell.com	9325352876	1	8437743918504567	2011/02	user9923	password	64	60000	F
9924	IHYLVP	ZOCKVUVJZM	1078376716 Dell Way	\N	INJNAUE	WI	80591	US	1	ZOCKVUVJZM@dell.com	1078376716	4	8954478002153338	2011/01	user9924	password	22	100000	F
9925	ALEPKT	RUPMQYLDGZ	9369135605 Dell Way	\N	MTZGYYB	WI	61549	US	1	RUPMQYLDGZ@dell.com	9369135605	4	6881707808468491	2012/08	user9925	password	19	100000	F
9926	FOLYGF	NSVMEYTDLN	3803190400 Dell Way	\N	DSLCTKR	OH	12694	US	1	NSVMEYTDLN@dell.com	3803190400	4	6657009482383729	2009/08	user9926	password	65	60000	F
9927	CMMHAF	DMJCFNOTRG	3473934965 Dell Way	\N	FTAQKSQ	OR	43618	US	1	DMJCFNOTRG@dell.com	3473934965	1	1341932585928589	2012/08	user9927	password	38	20000	F
9928	UHBZLO	JNUXBNOITI	5025076098 Dell Way	\N	IJTAZMK	ID	58075	US	1	JNUXBNOITI@dell.com	5025076098	2	2069693130906671	2011/03	user9928	password	31	60000	M
9929	GMYVVM	QSOEHWXQFG	5472097968 Dell Way	\N	JGGVQNJ	CA	74279	US	1	QSOEHWXQFG@dell.com	5472097968	5	9334414698649200	2011/04	user9929	password	49	100000	M
9930	JTQWJJ	KNQGLGLRQR	1551278458 Dell Way	\N	XMIKWKD	KY	31312	US	1	KNQGLGLRQR@dell.com	1551278458	1	5933060176204891	2010/12	user9930	password	42	100000	M
9931	YSCHDQ	YJBFVSVNQH	1376295731 Dell Way	\N	VBDGEMM	IA	55628	US	1	YJBFVSVNQH@dell.com	1376295731	4	5148614068981260	2009/08	user9931	password	30	40000	F
9932	GQMWOV	YURQPEGXAI	5376769163 Dell Way	\N	AGMNTTA	SC	53449	US	1	YURQPEGXAI@dell.com	5376769163	1	1939114667475223	2011/07	user9932	password	51	100000	F
9933	YUSTSM	LJCPQZPYAW	7913137869 Dell Way	\N	LNPEOKR	AL	62252	US	1	LJCPQZPYAW@dell.com	7913137869	4	1751424078363925	2009/08	user9933	password	33	20000	F
9934	YXCKIM	MYCLNBLKMZ	1688435689 Dell Way	\N	ARNKIOZ	CA	31912	US	1	MYCLNBLKMZ@dell.com	1688435689	2	8616573021281511	2009/06	user9934	password	35	40000	F
9935	JQSVDR	YOFZAPLAPD	2579348328 Dell Way	\N	NALCZOI	AZ	87476	US	1	YOFZAPLAPD@dell.com	2579348328	2	3969742994755507	2010/08	user9935	password	70	80000	F
9936	LPICNX	HMYWYYMBMM	3116152196 Dell Way	\N	NOLBXNX	AZ	90312	US	1	HMYWYYMBMM@dell.com	3116152196	3	5326233998406679	2012/04	user9936	password	69	40000	M
9937	AMJYUW	XQVVDWIPJX	9433116289 Dell Way	\N	AKUOIWL	ND	40693	US	1	XQVVDWIPJX@dell.com	9433116289	3	6390053665731103	2011/11	user9937	password	51	80000	F
9938	VQDSNU	NJXJRNTOOD	2238660036 Dell Way	\N	ICMFOAO	MS	57890	US	1	NJXJRNTOOD@dell.com	2238660036	1	4808378168847412	2010/10	user9938	password	76	60000	F
9939	YCYTPH	RZZESOSWWV	3984825755 Dell Way	\N	JCKJQWX	PA	11393	US	1	RZZESOSWWV@dell.com	3984825755	2	8421406340319664	2008/10	user9939	password	36	20000	M
9940	FVMNNM	MSFALBXGKZ	4319855220 Dell Way	\N	QUPNSJO	AL	74550	US	1	MSFALBXGKZ@dell.com	4319855220	1	5352590121794492	2011/04	user9940	password	44	100000	F
9941	WIQIVI	NWUPTAATRU	9407008103 Dell Way	\N	JFNTTOL	CT	73401	US	1	NWUPTAATRU@dell.com	9407008103	4	9596490370109678	2009/07	user9941	password	21	20000	M
9942	RMTAZP	UPJVPDMKMS	1957164299 Dell Way	\N	XFLLROD	NH	38942	US	1	UPJVPDMKMS@dell.com	1957164299	5	9121149489656092	2008/01	user9942	password	78	100000	M
9943	OVNEQC	OLSRYCDQAJ	8905007184 Dell Way	\N	CMARQQZ	OR	56116	US	1	OLSRYCDQAJ@dell.com	8905007184	5	6014686916954816	2011/09	user9943	password	23	40000	M
9944	PLESZQ	LQONUEODGA	8595429783 Dell Way	\N	EXQUXJH	PA	33250	US	1	LQONUEODGA@dell.com	8595429783	3	9767993027344348	2012/09	user9944	password	56	60000	F
9945	SGEIRV	WFQBTTHUXF	1351422463 Dell Way	\N	LRCUZWB	SD	39336	US	1	WFQBTTHUXF@dell.com	1351422463	4	1611111283302307	2010/04	user9945	password	37	40000	M
9946	LPEHMJ	XOCRVXOBIG	4667459751 Dell Way	\N	DDGAFBI	IA	82607	US	1	XOCRVXOBIG@dell.com	4667459751	5	1661381512880325	2011/02	user9946	password	59	20000	M
9947	TKFCHT	FYPCNQKUUO	9796722779 Dell Way	\N	AUTCDZX	ND	80967	US	1	FYPCNQKUUO@dell.com	9796722779	2	8923371594399215	2010/05	user9947	password	60	40000	M
9948	UJANOZ	CRNTCHNQII	1248797622 Dell Way	\N	JLMJIBD	KS	33545	US	1	CRNTCHNQII@dell.com	1248797622	5	6391361422836781	2011/02	user9948	password	42	60000	M
9949	JYCIAT	WUWDIMMRWY	1376024174 Dell Way	\N	DFGEJOL	MA	49839	US	1	WUWDIMMRWY@dell.com	1376024174	1	6362305035814644	2009/05	user9949	password	27	80000	F
9950	FBJZYD	VCLIOCEMGK	4313044228 Dell Way	\N	TLTIWDU	VT	23828	US	1	VCLIOCEMGK@dell.com	4313044228	2	6044570078141988	2010/01	user9950	password	83	80000	F
9951	GSAKOC	VWRYBEELXP	1490834434 Dell Way	\N	FGMIAKM	MA	70998	US	1	VWRYBEELXP@dell.com	1490834434	5	7263247087132186	2012/08	user9951	password	75	40000	F
9952	VPWXLS	PJTTOFREKX	4894483750 Dell Way	\N	RTYBFIT	IL	28773	US	1	PJTTOFREKX@dell.com	4894483750	2	8254722745157779	2009/06	user9952	password	26	20000	F
9953	ZYLRNV	LHKQYPAWGT	2321366562 Dell Way	\N	UHZDBGI	MO	54482	US	1	LHKQYPAWGT@dell.com	2321366562	4	9291596492286772	2009/09	user9953	password	86	40000	M
9954	KXFFIM	QZLFAHLUCT	5048168937 Dell Way	\N	TGUAPGN	OR	96750	US	1	QZLFAHLUCT@dell.com	5048168937	5	7247592814266682	2009/03	user9954	password	45	80000	F
9955	PALBQL	NVLUHFXAZD	7768921974 Dell Way	\N	VASCOLB	AK	49747	US	1	NVLUHFXAZD@dell.com	7768921974	2	6819237303920091	2008/03	user9955	password	72	80000	F
9956	FTVQGR	CBYIZZIDUI	4706204160 Dell Way	\N	WXXIYXT	OH	37324	US	1	CBYIZZIDUI@dell.com	4706204160	5	5371137102600187	2008/07	user9956	password	67	40000	F
9957	MAODCQ	CKQBSTWBQT	6884111998 Dell Way	\N	YYRWSKE	CT	29354	US	1	CKQBSTWBQT@dell.com	6884111998	2	7652580676600338	2009/08	user9957	password	20	100000	M
9958	PZTFBE	VDWPZYFSXE	7870883304 Dell Way	\N	KTWVYZA	NE	35402	US	1	VDWPZYFSXE@dell.com	7870883304	5	9428567619528622	2011/09	user9958	password	61	40000	M
9959	JPUNLX	KBXIGQGLBA	5686385991 Dell Way	\N	HWYHWNP	NM	50006	US	1	KBXIGQGLBA@dell.com	5686385991	3	2715953887440264	2008/10	user9959	password	84	60000	F
9960	SZWQJY	OSFEYQFYYB	1393617580 Dell Way	\N	WGYKVPW	KY	12916	US	1	OSFEYQFYYB@dell.com	1393617580	3	8681598966941238	2012/12	user9960	password	38	80000	M
9961	EIHCWZ	HAXXGWWITC	7677419206 Dell Way	\N	GDXWAGX	AR	75104	US	1	HAXXGWWITC@dell.com	7677419206	1	6840827158652247	2008/09	user9961	password	58	20000	M
9962	VHVUOW	SMCOJKHLRL	1039403092 Dell Way	\N	JNLQKNJ	DC	55685	US	1	SMCOJKHLRL@dell.com	1039403092	1	2697346083354205	2010/05	user9962	password	31	40000	M
9963	AEFXWS	ZLBKTNBFXP	8622947018 Dell Way	\N	QNADWER	UT	40339	US	1	ZLBKTNBFXP@dell.com	8622947018	3	7349050111137331	2008/10	user9963	password	43	20000	M
9964	PYWHXH	JIAWJFTZWH	2473444897 Dell Way	\N	ZAEDRAL	MT	52297	US	1	JIAWJFTZWH@dell.com	2473444897	3	3494609884917736	2010/08	user9964	password	36	20000	M
9965	CKLJTT	KQDQKCMRBN	6607327540 Dell Way	\N	VFFWQSI	SD	34722	US	1	KQDQKCMRBN@dell.com	6607327540	2	8893153861165048	2012/06	user9965	password	48	100000	M
9966	WJOQTF	UKPXWHZKCE	5224105931 Dell Way	\N	PZVIIQP	WI	96115	US	1	UKPXWHZKCE@dell.com	5224105931	5	4477243083529174	2012/10	user9966	password	32	80000	F
9967	UKXZEH	OBEVAPYEEY	9668173789 Dell Way	\N	ZNHQCGO	ND	16413	US	1	OBEVAPYEEY@dell.com	9668173789	3	8882628474850208	2008/03	user9967	password	20	100000	M
9968	YXUGMV	LIWAHBFFBS	7190526654 Dell Way	\N	NRVTGJV	HI	84530	US	1	LIWAHBFFBS@dell.com	7190526654	2	1260208066087216	2011/04	user9968	password	63	80000	F
9969	KYSGJB	CKIEQOFJBX	4700003505 Dell Way	\N	EUEOPJJ	IL	78289	US	1	CKIEQOFJBX@dell.com	4700003505	1	1770844256505370	2008/09	user9969	password	41	60000	M
9970	BRZCTK	KYBYEKZBOU	4879785307 Dell Way	\N	FDJPNRI	VT	70185	US	1	KYBYEKZBOU@dell.com	4879785307	5	4145211373455823	2011/05	user9970	password	88	100000	F
9971	YXUJHT	KGXUGYJAEM	1839895083 Dell Way	\N	KTZBCXT	MT	87585	US	1	KGXUGYJAEM@dell.com	1839895083	2	3162374989129603	2008/02	user9971	password	38	20000	M
9972	CJHVUO	SOURYVVKGP	4859742685 Dell Way	\N	KIRIBFE	DE	54168	US	1	SOURYVVKGP@dell.com	4859742685	2	6222341460175813	2011/03	user9972	password	59	80000	M
9973	WPJKIY	FZWBVHHKSP	4292349422 Dell Way	\N	CARHFVU	NM	15395	US	1	FZWBVHHKSP@dell.com	4292349422	2	3584577403031290	2012/02	user9973	password	82	80000	M
9974	GECEKC	BLXISIAIKB	2822065085 Dell Way	\N	ASHWMXX	TX	34713	US	1	BLXISIAIKB@dell.com	2822065085	4	4780413914471865	2008/07	user9974	password	31	40000	M
9975	HNEJOP	HXHPYQAAQT	9094038601 Dell Way	\N	HNFFKCM	NJ	89621	US	1	HXHPYQAAQT@dell.com	9094038601	4	5164432451128960	2008/01	user9975	password	34	40000	M
9976	JSDZZB	HPZXPZOJHB	1139693724 Dell Way	\N	OMMRZCO	UT	81704	US	1	HPZXPZOJHB@dell.com	1139693724	5	8577317622490228	2009/04	user9976	password	47	80000	F
9977	OPZPWP	PTFPIOWJDJ	6109578241 Dell Way	\N	VUIYJES	LA	21219	US	1	PTFPIOWJDJ@dell.com	6109578241	4	4772721833549440	2012/03	user9977	password	49	60000	M
9978	KDRASL	FIUTEDXOZR	6246091695 Dell Way	\N	WXBBQKE	GA	11102	US	1	FIUTEDXOZR@dell.com	6246091695	1	3209034776780754	2008/09	user9978	password	23	60000	M
9979	TLOFQW	ZKBDIPCALA	7364106657 Dell Way	\N	BMQLRVM	IA	11219	US	1	ZKBDIPCALA@dell.com	7364106657	2	7495956274680794	2011/09	user9979	password	58	60000	F
9980	DTUASF	BWNRYNDYOQ	2377220724 Dell Way	\N	PAHKMNL	FL	79961	US	1	BWNRYNDYOQ@dell.com	2377220724	5	5130390365608037	2011/06	user9980	password	60	100000	F
9981	JVZOXV	BOTORSDIHD	4183541737 Dell Way	\N	PSPDDUX	IL	76935	US	1	BOTORSDIHD@dell.com	4183541737	1	3120320353191346	2012/11	user9981	password	52	40000	M
9982	LVPGXE	AMWSPEATTS	2085518449 Dell Way	\N	JWWDTDX	CO	24228	US	1	AMWSPEATTS@dell.com	2085518449	1	1016021010465919	2010/05	user9982	password	68	20000	F
9983	HHBLIO	HBDLBXEUGB	9615026324 Dell Way	\N	QJVUGYY	MA	98509	US	1	HBDLBXEUGB@dell.com	9615026324	5	3899070546496660	2011/01	user9983	password	54	100000	F
9984	OIQCQR	GBTDGNJHET	4144317028 Dell Way	\N	CZABYKA	UT	45719	US	1	GBTDGNJHET@dell.com	4144317028	3	4763722133822739	2012/06	user9984	password	71	60000	M
9985	JNKBUM	UYSIIZNCCM	4078439942 Dell Way	\N	CDKNEHY	MT	81932	US	1	UYSIIZNCCM@dell.com	4078439942	2	3153999032918364	2008/10	user9985	password	19	60000	F
9986	LNDXIB	PQJPDLSQOW	3941000996 Dell Way	\N	ACAHAOC	LA	94144	US	1	PQJPDLSQOW@dell.com	3941000996	3	7577805479522795	2009/11	user9986	password	22	80000	F
9987	ERTGHK	QWNCOEQKET	7019880590 Dell Way	\N	LLUAODY	UT	62472	US	1	QWNCOEQKET@dell.com	7019880590	2	5369383465964347	2011/01	user9987	password	84	100000	M
9988	QDYAUV	OWJSMUXGGJ	3031813151 Dell Way	\N	AGXEETT	TN	99164	US	1	OWJSMUXGGJ@dell.com	3031813151	3	9960846504196526	2008/06	user9988	password	67	80000	M
9989	QUKLJG	VCTPZZVIAB	9879784808 Dell Way	\N	GEGAXBZ	DC	67973	US	1	VCTPZZVIAB@dell.com	9879784808	2	2141014740802347	2011/01	user9989	password	73	40000	M
9990	ESFKNI	EDHEYQEAWJ	1770153214 Dell Way	\N	GWHIWKY	TX	71853	US	1	EDHEYQEAWJ@dell.com	1770153214	3	7582185082603247	2012/10	user9990	password	60	20000	M
9991	ULBCPE	KUCAYDXIJU	4836344682 Dell Way	\N	PRQAQMS	OK	98115	US	1	KUCAYDXIJU@dell.com	4836344682	3	7935644034296275	2008/07	user9991	password	38	100000	F
9992	IXQMIK	PJISGRCAGT	8850244405 Dell Way	\N	QGKDYCC	MA	70995	US	1	PJISGRCAGT@dell.com	8850244405	2	3333927040919662	2008/03	user9992	password	38	60000	F
9993	XZKHOT	QHZHJANCRU	5914920476 Dell Way	\N	MUTPXDH	RI	56464	US	1	QHZHJANCRU@dell.com	5914920476	5	7317808314692230	2012/05	user9993	password	75	80000	F
9994	FZXYQF	YXOZLRQGEL	3983537721 Dell Way	\N	ZUICBCQ	NH	10924	US	1	YXOZLRQGEL@dell.com	3983537721	3	4679468500427902	2008/02	user9994	password	74	40000	F
9995	RGTXFQ	LECCVIGGHA	1630160989 Dell Way	\N	OKCQARR	LA	19859	US	1	LECCVIGGHA@dell.com	1630160989	3	3191287819296121	2012/10	user9995	password	44	60000	F
9996	CKHTWM	VYHDFNLGCV	4328007983 Dell Way	\N	ITWAKGD	MN	75540	US	1	VYHDFNLGCV@dell.com	4328007983	2	5879402471706272	2011/11	user9996	password	63	100000	F
9997	XPCJLB	ROHEZNGVWA	2874240475 Dell Way	\N	SWKYZWR	LA	24757	US	1	ROHEZNGVWA@dell.com	2874240475	1	9985649213660508	2012/12	user9997	password	36	80000	M
9998	JDZKUO	SZOFGJBGBY	7007159631 Dell Way	\N	QAYNRHR	VA	45833	US	1	SZOFGJBGBY@dell.com	7007159631	4	4145712514873594	2012/06	user9998	password	83	40000	M
9999	WSKLKJ	ZPQIRWKPNL	6307108376 Dell Way	\N	OACVSZG	LA	74402	US	1	ZPQIRWKPNL@dell.com	6307108376	2	2631467383820563	2010/07	user9999	password	74	40000	F
10000	EUQOTG	ECXBNNOYCP	9593894142 Dell Way	\N	BYHBEQU	PA	93129	US	1	ECXBNNOYCP@dell.com	9593894142	2	5289698296692223	2011/08	user10000	password	70	100000	F
10001	QQGWSL	NNTHRFAVRX	6739733410 Dell Way	\N	KQLKYDL	\N	0	UK	2	NNTHRFAVRX@dell.com	6739733410	5	3180290846154094	2010/06	user10001	password	62	100000	F
10002	GEYYPM	LIUCOUYFSI	1635345615 Dell Way	\N	WETVIES	\N	0	UK	2	LIUCOUYFSI@dell.com	1635345615	5	5082264172378928	2010/07	user10002	password	45	80000	M
10003	OOTDBF	MVIBQGGJPD	6409226552 Dell Way	\N	NIYVNQU	\N	0	Germany	2	MVIBQGGJPD@dell.com	6409226552	2	1973200108390301	2008/08	user10003	password	69	100000	F
10004	GSIIYV	DGWUMDDCGQ	5717251424 Dell Way	\N	KEMYVHN	\N	0	France	2	DGWUMDDCGQ@dell.com	5717251424	4	6244009170215577	2008/05	user10004	password	58	40000	M
10005	HPXFLB	LHVYKYAQPL	5610700704 Dell Way	\N	VBJQJXB	\N	0	South Africa	2	LHVYKYAQPL@dell.com	5610700704	4	1152014677878469	2012/03	user10005	password	41	60000	F
10006	YJRJKD	QGBBFCRUNM	8593107757 Dell Way	\N	WXDFUFC	\N	0	Chile	2	QGBBFCRUNM@dell.com	8593107757	1	2281865046359598	2008/06	user10006	password	61	60000	F
10007	YESJIJ	QJKVMBQZOM	8979118647 Dell Way	\N	XSRRXUZ	\N	0	Russia	2	QJKVMBQZOM@dell.com	8979118647	1	8134640486445279	2009/09	user10007	password	40	80000	M
10008	MKBUTR	EDNQFDQUPN	3615621776 Dell Way	\N	MHFKBED	\N	0	UK	2	EDNQFDQUPN@dell.com	3615621776	5	3379513563588262	2012/04	user10008	password	86	80000	M
10009	ISOBJS	FWJKZAEPOR	2570195918 Dell Way	\N	WTBYYFX	\N	0	Chile	2	FWJKZAEPOR@dell.com	2570195918	1	3070291752927005	2010/02	user10009	password	82	20000	F
10010	PSMZLR	VVBVVGLJYH	3739616435 Dell Way	\N	DAGCFDI	\N	0	France	2	VVBVVGLJYH@dell.com	3739616435	3	8460021168924869	2009/06	user10010	password	90	100000	F
10011	SHZDYV	YARUGCEEKH	3510558329 Dell Way	\N	EQKKUSV	\N	0	Australia	2	YARUGCEEKH@dell.com	3510558329	4	5356388117186725	2011/08	user10011	password	39	80000	F
10012	OTMNOL	NGGUIKZSSE	1269110020 Dell Way	\N	JCODVKF	\N	0	Canada	2	NGGUIKZSSE@dell.com	1269110020	4	8462025763932616	2011/01	user10012	password	60	20000	M
10013	INCXZQ	DFLMQKFIOO	6754738194 Dell Way	\N	LDSGNYJ	\N	0	Germany	2	DFLMQKFIOO@dell.com	6754738194	1	2882433429360390	2011/10	user10013	password	35	40000	F
10014	TIATZD	YKPOUVXJJI	2327655676 Dell Way	\N	MBPZZYN	\N	0	Japan	2	YKPOUVXJJI@dell.com	2327655676	4	3530884771142155	2012/12	user10014	password	55	20000	M
10015	WALVEK	FUZAPWJYEV	1573272367 Dell Way	\N	AUVASIR	\N	0	South Africa	2	FUZAPWJYEV@dell.com	1573272367	5	8194627977907658	2008/06	user10015	password	78	80000	F
10016	WECAPI	UOIKLSJQOJ	9961822467 Dell Way	\N	KJKDSBA	\N	0	Russia	2	UOIKLSJQOJ@dell.com	9961822467	4	8113483418710531	2010/08	user10016	password	56	80000	F
10017	SWMIEH	WNRIGBYUKI	3267488778 Dell Way	\N	EVLWWLQ	\N	0	South Africa	2	WNRIGBYUKI@dell.com	3267488778	3	3864263771567494	2012/12	user10017	password	22	40000	M
10018	XWZCDW	QVEXWCRHLV	7673123736 Dell Way	\N	CWSZIIW	\N	0	Germany	2	QVEXWCRHLV@dell.com	7673123736	1	5132363616488874	2011/03	user10018	password	77	40000	F
10019	RIGUFX	QJUNMMUXHX	9547578394 Dell Way	\N	UZXCITR	\N	0	Australia	2	QJUNMMUXHX@dell.com	9547578394	1	7757308084983379	2008/12	user10019	password	26	40000	M
10020	LPLRNB	AHONUJKBHE	2210785543 Dell Way	\N	BFHKZZL	\N	0	UK	2	AHONUJKBHE@dell.com	2210785543	1	1946008443366736	2008/04	user10020	password	51	80000	M
10021	BDKPFL	XUYRDJSLOU	8473228257 Dell Way	\N	QVEPVQN	\N	0	UK	2	XUYRDJSLOU@dell.com	8473228257	4	1429330241866409	2008/01	user10021	password	73	100000	F
10022	XISCTP	XSHACAMQUC	8568280099 Dell Way	\N	LZSGPFF	\N	0	France	2	XSHACAMQUC@dell.com	8568280099	2	6248648855369539	2012/01	user10022	password	53	20000	M
10023	UUBOKY	HRZJRLZLOL	2754182037 Dell Way	\N	LHSBMYM	\N	0	China	2	HRZJRLZLOL@dell.com	2754182037	1	3223434450570494	2009/07	user10023	password	39	20000	F
10024	BFYLEF	CDPTPOFEAR	3475831425 Dell Way	\N	LSSXQFG	\N	0	South Africa	2	CDPTPOFEAR@dell.com	3475831425	3	1678142335265875	2012/10	user10024	password	35	20000	M
10025	MDIQIL	UYFJNLONCZ	6848648400 Dell Way	\N	GUXXZDT	\N	0	Chile	2	UYFJNLONCZ@dell.com	6848648400	5	1979567454662174	2010/01	user10025	password	40	40000	M
10026	LREUCY	SIIFTWTWVZ	5150419577 Dell Way	\N	RTXRWQY	\N	0	Germany	2	SIIFTWTWVZ@dell.com	5150419577	1	9863915279973300	2010/05	user10026	password	40	20000	M
10027	ZGOCFG	KOMEKFBGFS	4177900753 Dell Way	\N	ZCJWTIK	\N	0	Canada	2	KOMEKFBGFS@dell.com	4177900753	2	7521882192697377	2011/09	user10027	password	75	60000	M
10028	BAUGHF	UUJFZLMFDM	2507730757 Dell Way	\N	HNJAVTF	\N	0	Canada	2	UUJFZLMFDM@dell.com	2507730757	5	8917216498870403	2012/09	user10028	password	44	60000	M
10029	KJASOV	MYAMJMRNZZ	2670183289 Dell Way	\N	AIAWCGA	\N	0	Chile	2	MYAMJMRNZZ@dell.com	2670183289	5	2187381065450608	2012/04	user10029	password	69	80000	M
10030	BTJPOV	NPIXCZKBZL	2923534292 Dell Way	\N	JZHLFIS	\N	0	China	2	NPIXCZKBZL@dell.com	2923534292	5	3924742170143873	2010/07	user10030	password	21	20000	M
10031	UNEJJS	YRQARBBQML	4587131812 Dell Way	\N	PTWUBOF	\N	0	Chile	2	YRQARBBQML@dell.com	4587131812	3	7873797914478929	2012/07	user10031	password	84	60000	F
10032	KSSULQ	LBRCCTSPEI	8613195780 Dell Way	\N	IBDKQIS	\N	0	Australia	2	LBRCCTSPEI@dell.com	8613195780	3	9555175118613988	2010/05	user10032	password	52	80000	M
10033	EMOPDA	RUCUOVJSDS	3562563633 Dell Way	\N	UGDKOVK	\N	0	France	2	RUCUOVJSDS@dell.com	3562563633	2	8508224144577981	2011/11	user10033	password	61	60000	F
10034	CAPFAH	ADBOYLHBDB	3208933695 Dell Way	\N	IGLXCWI	\N	0	China	2	ADBOYLHBDB@dell.com	3208933695	1	1242399002891033	2008/10	user10034	password	52	20000	M
10035	MSBNZB	QBPOMXQQYY	3826260293 Dell Way	\N	WKVZHEI	\N	0	Germany	2	QBPOMXQQYY@dell.com	3826260293	2	6497259695082904	2008/11	user10035	password	69	100000	F
10036	KYVKZM	LPAYMQOLPL	2021417723 Dell Way	\N	WLKDPTR	\N	0	UK	2	LPAYMQOLPL@dell.com	2021417723	2	9807209601160140	2012/12	user10036	password	82	40000	F
10037	VDUVPF	KQEXHSJWDF	3807314330 Dell Way	\N	HOJXHAU	\N	0	France	2	KQEXHSJWDF@dell.com	3807314330	4	4344325587153435	2009/08	user10037	password	66	80000	F
10038	ULIKRS	AVQHOAESGL	9431120990 Dell Way	\N	GPJOQEZ	\N	0	UK	2	AVQHOAESGL@dell.com	9431120990	2	3115890454500913	2011/01	user10038	password	84	20000	M
10039	JKEBDF	WUMLURDACJ	3146343668 Dell Way	\N	QLYGPXF	\N	0	Germany	2	WUMLURDACJ@dell.com	3146343668	3	2354483730625361	2009/05	user10039	password	35	20000	M
10040	QFTTLQ	OYCIPFJSPA	9129135796 Dell Way	\N	ENGTKMI	\N	0	Japan	2	OYCIPFJSPA@dell.com	9129135796	3	9091335818637164	2009/09	user10040	password	86	100000	F
10041	ETDPJR	NLADRJVGJZ	5730947961 Dell Way	\N	UQTFCBW	\N	0	Australia	2	NLADRJVGJZ@dell.com	5730947961	4	3317539137788117	2009/09	user10041	password	34	60000	M
10042	YSLIJZ	UJCMTXTDWN	4048859753 Dell Way	\N	TQSWRPW	\N	0	Chile	2	UJCMTXTDWN@dell.com	4048859753	1	4966281573753804	2008/05	user10042	password	19	100000	F
10043	SIQCIL	LKXFIQIFEB	9032069937 Dell Way	\N	VWXNLUS	\N	0	Russia	2	LKXFIQIFEB@dell.com	9032069937	1	8502696065697820	2009/03	user10043	password	70	60000	M
10044	BEAKQL	UORDFZJJBE	6363390961 Dell Way	\N	GYSSTLN	\N	0	Japan	2	UORDFZJJBE@dell.com	6363390961	2	8776914604473860	2011/01	user10044	password	47	80000	F
10045	PSNFEI	TVLZUVIVAP	2338562636 Dell Way	\N	USHNDUD	\N	0	Russia	2	TVLZUVIVAP@dell.com	2338562636	1	5687204761430622	2009/06	user10045	password	33	40000	F
10046	XWFCEZ	XQYRMHNMWH	9875332320 Dell Way	\N	EDVIYZB	\N	0	Australia	2	XQYRMHNMWH@dell.com	9875332320	3	3821505235973746	2010/10	user10046	password	66	60000	M
10047	NQUSPR	JNJVUWHREM	4715014173 Dell Way	\N	UZUTYVV	\N	0	UK	2	JNJVUWHREM@dell.com	4715014173	1	4139300560113043	2009/10	user10047	password	73	100000	F
10048	JSBZJL	NTHIQPZUBT	5590163264 Dell Way	\N	UWNTSJR	\N	0	Canada	2	NTHIQPZUBT@dell.com	5590163264	1	3901471483986825	2009/10	user10048	password	35	80000	F
10049	YTDIFQ	BMYRCXMERH	7631881897 Dell Way	\N	AFATOSW	\N	0	Australia	2	BMYRCXMERH@dell.com	7631881897	1	4475568006280810	2010/05	user10049	password	22	80000	F
10050	VVRAMT	NLLQIXUAEV	6385936927 Dell Way	\N	FFOTXKV	\N	0	Japan	2	NLLQIXUAEV@dell.com	6385936927	2	2458525989670306	2008/04	user10050	password	80	40000	F
10051	RADETR	PEHYCBYHXE	9804240555 Dell Way	\N	MLYJWTA	\N	0	France	2	PEHYCBYHXE@dell.com	9804240555	1	5386042096186429	2009/01	user10051	password	80	40000	M
10052	WMWQDL	VLKYNJFKNS	3324043716 Dell Way	\N	WMBTGCF	\N	0	Chile	2	VLKYNJFKNS@dell.com	3324043716	4	5306127820163965	2009/07	user10052	password	78	20000	F
10053	IWCMIX	XTVLCBWPTS	4597893572 Dell Way	\N	CVMIXRO	\N	0	Canada	2	XTVLCBWPTS@dell.com	4597893572	1	5055893732700497	2012/11	user10053	password	51	40000	F
10054	IMRRKP	KFAMHWCAPE	2017872509 Dell Way	\N	WBNTTCX	\N	0	Canada	2	KFAMHWCAPE@dell.com	2017872509	2	1948662749025970	2012/10	user10054	password	54	20000	F
10055	ZWVJLG	PLSWIVXXAT	8353687536 Dell Way	\N	ZNNSPLW	\N	0	Russia	2	PLSWIVXXAT@dell.com	8353687536	5	7273557737469674	2011/06	user10055	password	81	80000	F
10056	SQVEWK	PPHYKFWKZV	4202817306 Dell Way	\N	XNNNYKG	\N	0	Russia	2	PPHYKFWKZV@dell.com	4202817306	5	4718861056491733	2012/10	user10056	password	33	40000	M
10057	VCRSNH	HVGRACCAXA	7282172787 Dell Way	\N	NLNMVTG	\N	0	Canada	2	HVGRACCAXA@dell.com	7282172787	4	1025425476487725	2010/11	user10057	password	38	20000	M
10058	JSKWAS	RGJSJLSGMF	6243641837 Dell Way	\N	RZSNTYS	\N	0	France	2	RGJSJLSGMF@dell.com	6243641837	4	9632304616272450	2010/12	user10058	password	90	20000	F
10059	SOFTGX	AQQJCIQOOI	3091990710 Dell Way	\N	OGVIENT	\N	0	Russia	2	AQQJCIQOOI@dell.com	3091990710	4	2953869292978197	2009/09	user10059	password	45	60000	F
10060	YTFFRF	VHPYQGMEOB	8537606805 Dell Way	\N	LKJQYDK	\N	0	Canada	2	VHPYQGMEOB@dell.com	8537606805	4	4470193764660508	2010/12	user10060	password	86	100000	M
10061	SEDJKY	RAXHGKMULY	6243925950 Dell Way	\N	FUOEXZI	\N	0	Russia	2	RAXHGKMULY@dell.com	6243925950	4	3723552077542990	2010/08	user10061	password	39	60000	F
10062	MQTXOK	XMSDWEYHCD	4557584681 Dell Way	\N	CRIZQRT	\N	0	Chile	2	XMSDWEYHCD@dell.com	4557584681	1	8010454925708474	2008/05	user10062	password	38	60000	M
10063	XDSMOP	YGTUKRBNVD	9169301503 Dell Way	\N	EDDVVWA	\N	0	Chile	2	YGTUKRBNVD@dell.com	9169301503	4	3394477863330394	2009/01	user10063	password	68	20000	M
10064	VULKKJ	QDDBUFPQJU	4513530052 Dell Way	\N	UMPPJPU	\N	0	Chile	2	QDDBUFPQJU@dell.com	4513530052	1	5550156751181931	2010/10	user10064	password	59	60000	M
10065	JWZTFQ	WJSRPHIYBC	6178471337 Dell Way	\N	LQSUGNB	\N	0	Japan	2	WJSRPHIYBC@dell.com	6178471337	3	1792271003592759	2009/02	user10065	password	55	100000	F
10066	JXFPOC	ZGTONCNPEY	3820577870 Dell Way	\N	FWSMJTC	\N	0	UK	2	ZGTONCNPEY@dell.com	3820577870	1	3611886825412512	2010/09	user10066	password	34	100000	F
10067	DDRRFR	YZFMBTBGRH	1082003695 Dell Way	\N	DKTNEVL	\N	0	France	2	YZFMBTBGRH@dell.com	1082003695	4	9186739193741232	2011/12	user10067	password	77	80000	F
10068	YLUECT	DIFFBGLTNO	3338888825 Dell Way	\N	DGBHCNT	\N	0	Canada	2	DIFFBGLTNO@dell.com	3338888825	4	8262083166744561	2009/06	user10068	password	60	40000	F
10069	ADPDWT	LBYNHJGVXJ	1807350868 Dell Way	\N	CZQEMKH	\N	0	Russia	2	LBYNHJGVXJ@dell.com	1807350868	1	9729195745661856	2010/09	user10069	password	40	20000	M
10070	LPVHJH	JHURQAMOJP	2663877332 Dell Way	\N	NAUALCT	\N	0	Germany	2	JHURQAMOJP@dell.com	2663877332	4	1893308870028704	2012/01	user10070	password	26	60000	F
10071	TKTCRC	JLUZLHOUWB	5841661297 Dell Way	\N	VQBGSVT	\N	0	UK	2	JLUZLHOUWB@dell.com	5841661297	5	8032445598859341	2010/12	user10071	password	43	20000	M
10072	TUUKXD	WRDHYRCUTY	8111738101 Dell Way	\N	LVEEQYC	\N	0	Canada	2	WRDHYRCUTY@dell.com	8111738101	5	7625508227385581	2011/03	user10072	password	73	60000	M
10073	NHKKLG	BOOAGRUZPG	4528128825 Dell Way	\N	UULLSNQ	\N	0	France	2	BOOAGRUZPG@dell.com	4528128825	2	3414150215219706	2011/02	user10073	password	72	60000	M
10074	AZBLGD	AVDGNYGCEB	5243405644 Dell Way	\N	XPMPDCC	\N	0	Germany	2	AVDGNYGCEB@dell.com	5243405644	2	2288729942403733	2010/02	user10074	password	71	40000	F
10075	TGPZKP	VNWILCLQDI	4357417721 Dell Way	\N	GQXJTAX	\N	0	Chile	2	VNWILCLQDI@dell.com	4357417721	1	8271048333030195	2010/10	user10075	password	19	80000	M
10076	HFNRVI	FRQQUBHXKN	8937147076 Dell Way	\N	OHXIIVN	\N	0	Japan	2	FRQQUBHXKN@dell.com	8937147076	2	2528125386685133	2011/05	user10076	password	76	20000	M
10077	ASJVBO	NRFHTMFDAT	9575928618 Dell Way	\N	LYBTUPL	\N	0	Japan	2	NRFHTMFDAT@dell.com	9575928618	4	3966543852817267	2009/05	user10077	password	56	100000	F
10078	GIGHXU	ZCBSPGWPAI	2245944387 Dell Way	\N	OCCISNZ	\N	0	Japan	2	ZCBSPGWPAI@dell.com	2245944387	2	9764142272062600	2010/11	user10078	password	88	100000	F
10079	HGJFAI	HBBWIYMJGA	6776416847 Dell Way	\N	LIJDWIU	\N	0	Australia	2	HBBWIYMJGA@dell.com	6776416847	4	5965994568075985	2010/09	user10079	password	56	60000	F
10080	TXFUGN	WHKEFWNLXZ	6699945194 Dell Way	\N	UGCROWR	\N	0	Chile	2	WHKEFWNLXZ@dell.com	6699945194	2	7171842810232193	2009/09	user10080	password	35	40000	M
10081	DPHJDD	RNHWJVIGUC	6871525665 Dell Way	\N	MXUBTLG	\N	0	France	2	RNHWJVIGUC@dell.com	6871525665	5	7790595149621368	2009/03	user10081	password	27	100000	F
10082	TESWHJ	JPGTLOAFRM	7761809133 Dell Way	\N	DLOWXUH	\N	0	Germany	2	JPGTLOAFRM@dell.com	7761809133	1	9487596791237594	2012/03	user10082	password	79	40000	M
10083	AZUIJE	YQXJFXPXKS	9132548442 Dell Way	\N	JYPGTWU	\N	0	Germany	2	YQXJFXPXKS@dell.com	9132548442	4	5108677317854017	2008/07	user10083	password	71	100000	M
10084	TUXCYV	TWFYUUVFME	9754201967 Dell Way	\N	EBLYYGL	\N	0	South Africa	2	TWFYUUVFME@dell.com	9754201967	5	9189001498743892	2010/08	user10084	password	84	20000	F
10085	RBMQXF	NCEHWAMJFQ	9352626667 Dell Way	\N	KQPJWAE	\N	0	South Africa	2	NCEHWAMJFQ@dell.com	9352626667	1	4557246199343354	2010/12	user10085	password	57	100000	M
10086	PKINQV	PVDMVPVAGG	8901255636 Dell Way	\N	RVPNWUJ	\N	0	Russia	2	PVDMVPVAGG@dell.com	8901255636	4	4201388108078390	2012/04	user10086	password	38	60000	M
10087	SXLISB	DVNZLJASQR	4158152063 Dell Way	\N	OGFKAPF	\N	0	UK	2	DVNZLJASQR@dell.com	4158152063	3	8032491980120540	2011/11	user10087	password	42	60000	M
10088	FAWYBA	UPAFZAYPRM	6717190796 Dell Way	\N	WWWWLCU	\N	0	South Africa	2	UPAFZAYPRM@dell.com	6717190796	3	5239448581822217	2010/11	user10088	password	22	20000	F
10089	CXCEXW	UYBTYAJPMF	5006037916 Dell Way	\N	MJCYLWS	\N	0	Australia	2	UYBTYAJPMF@dell.com	5006037916	1	5953192958608270	2009/04	user10089	password	59	60000	F
10090	MONKKH	IMBGNKVZPI	2476778124 Dell Way	\N	ISGUPZW	\N	0	Australia	2	IMBGNKVZPI@dell.com	2476778124	2	4408753018826246	2010/12	user10090	password	81	80000	F
10091	LIVWPD	JRJWBFVRNE	2890650204 Dell Way	\N	JTYYSVZ	\N	0	South Africa	2	JRJWBFVRNE@dell.com	2890650204	2	3752314754296094	2008/03	user10091	password	24	80000	M
10092	KLNAOX	RYTTDPKQUU	1900685158 Dell Way	\N	KTTCOTZ	\N	0	Russia	2	RYTTDPKQUU@dell.com	1900685158	2	9542154934257270	2009/05	user10092	password	58	20000	M
10093	ZNUOLM	MEFPUQGPLQ	1341591656 Dell Way	\N	IETXYTR	\N	0	Australia	2	MEFPUQGPLQ@dell.com	1341591656	4	4208298417273909	2010/03	user10093	password	44	40000	F
10094	XASIME	NSUHIBWUSF	4186313154 Dell Way	\N	YMCWFTX	\N	0	Chile	2	NSUHIBWUSF@dell.com	4186313154	2	7072445282246918	2010/08	user10094	password	82	80000	M
10095	XKVKPI	CKQLLMFDSE	2973819278 Dell Way	\N	QUBVNYC	\N	0	South Africa	2	CKQLLMFDSE@dell.com	2973819278	4	4631033144891262	2012/08	user10095	password	24	40000	M
10096	MEYBNA	LDMXQRBIWR	4239000649 Dell Way	\N	DXNQWPN	\N	0	Australia	2	LDMXQRBIWR@dell.com	4239000649	5	9259736299980432	2008/01	user10096	password	37	60000	F
10097	LMOZNA	DAXURYCOQG	4034690435 Dell Way	\N	LDWHTKJ	\N	0	Australia	2	DAXURYCOQG@dell.com	4034690435	2	1910733405034989	2009/07	user10097	password	66	100000	F
10098	DKARLD	RIXJHAYYGJ	4189842694 Dell Way	\N	BDRUNBX	\N	0	South Africa	2	RIXJHAYYGJ@dell.com	4189842694	5	3050081475637853	2012/08	user10098	password	23	100000	M
10099	MYMYCE	HAOOAMNHWP	3473827165 Dell Way	\N	KNJYPHV	\N	0	UK	2	HAOOAMNHWP@dell.com	3473827165	1	8800260539166630	2012/02	user10099	password	77	80000	M
10100	UFOWKV	WYKXLXEHMP	4379210984 Dell Way	\N	VWNKDIJ	\N	0	France	2	WYKXLXEHMP@dell.com	4379210984	2	4143868730869144	2010/01	user10100	password	24	20000	M
10101	IRSSMP	RWMCURKGGG	3288615390 Dell Way	\N	DURHCAS	\N	0	France	2	RWMCURKGGG@dell.com	3288615390	1	9811987663153560	2009/02	user10101	password	24	20000	F
10102	TVDGLV	CXYXPIDVPH	3638252370 Dell Way	\N	PGOSHGF	\N	0	Germany	2	CXYXPIDVPH@dell.com	3638252370	1	8562310294248165	2010/04	user10102	password	88	100000	F
10103	VAGGVJ	DTGTCKORRE	3543113188 Dell Way	\N	YGXGMCU	\N	0	Russia	2	DTGTCKORRE@dell.com	3543113188	4	2791193337179720	2010/07	user10103	password	22	60000	F
10104	BVQXFU	QMNTWCLOHJ	9932375559 Dell Way	\N	UEPHHJB	\N	0	Germany	2	QMNTWCLOHJ@dell.com	9932375559	2	2109899335075169	2010/04	user10104	password	69	100000	F
10105	OPGTJX	FWQCZBQGLL	1078569755 Dell Way	\N	LBSSLTH	\N	0	France	2	FWQCZBQGLL@dell.com	1078569755	3	1075021381955593	2009/02	user10105	password	89	80000	M
10106	OYLYVQ	VMTUOKBZVM	9047117867 Dell Way	\N	BOFMIMY	\N	0	China	2	VMTUOKBZVM@dell.com	9047117867	5	6731725109275431	2008/11	user10106	password	41	80000	F
10107	GCKCTF	PNADXBDTNE	6026961002 Dell Way	\N	HSRPFQY	\N	0	Australia	2	PNADXBDTNE@dell.com	6026961002	3	1996745985001325	2010/11	user10107	password	75	100000	F
10108	XJGQPW	DPZBQDUEIC	2732246190 Dell Way	\N	XZSCPQF	\N	0	Canada	2	DPZBQDUEIC@dell.com	2732246190	2	6812821795232595	2008/02	user10108	password	61	40000	M
10109	YNQOJU	DIVUMPZURW	5672703804 Dell Way	\N	TJZJAFO	\N	0	Chile	2	DIVUMPZURW@dell.com	5672703804	2	3548251475207508	2011/10	user10109	password	56	80000	M
10110	AGHJAL	SVGELFYDCS	8783237271 Dell Way	\N	NBCNHRT	\N	0	Russia	2	SVGELFYDCS@dell.com	8783237271	1	4752150702755898	2011/07	user10110	password	20	60000	M
10111	HSYIER	EKWPPUTRNH	5935694625 Dell Way	\N	TQUAHNV	\N	0	Canada	2	EKWPPUTRNH@dell.com	5935694625	2	8412646643817426	2008/04	user10111	password	35	80000	M
10112	YPWCGA	NCQCXKULRN	6236592912 Dell Way	\N	BMOJAJN	\N	0	Germany	2	NCQCXKULRN@dell.com	6236592912	2	6738944484386594	2012/08	user10112	password	38	60000	M
10113	WHRDHE	FYGDIAOAOQ	8782142456 Dell Way	\N	MCZMLNA	\N	0	Australia	2	FYGDIAOAOQ@dell.com	8782142456	4	8818608785048128	2010/12	user10113	password	37	100000	M
10114	ORYWVE	UCIDCXEQNQ	8498664345 Dell Way	\N	TNDEBEF	\N	0	UK	2	UCIDCXEQNQ@dell.com	8498664345	1	4323902602307499	2011/05	user10114	password	44	80000	M
10115	APTWUO	YCRAAWROMK	8655448267 Dell Way	\N	BPPDTUB	\N	0	Japan	2	YCRAAWROMK@dell.com	8655448267	3	4533984720706940	2008/10	user10115	password	19	20000	M
10116	PURJJP	MBQMXIBJSC	7278119118 Dell Way	\N	ZIGTCHJ	\N	0	UK	2	MBQMXIBJSC@dell.com	7278119118	4	2315578255336731	2010/10	user10116	password	33	40000	F
10117	AYTJOG	KETHMURFXR	5555194362 Dell Way	\N	ODKRLTP	\N	0	Canada	2	KETHMURFXR@dell.com	5555194362	4	6434540746733547	2009/12	user10117	password	83	80000	M
10118	WKJKQU	PJCBETHBKV	8882054197 Dell Way	\N	FVMQPCT	\N	0	Australia	2	PJCBETHBKV@dell.com	8882054197	2	4273187201470137	2012/04	user10118	password	18	100000	F
10119	KFNAAC	KCEOVLQGHV	6261610412 Dell Way	\N	CUMRXFT	\N	0	Russia	2	KCEOVLQGHV@dell.com	6261610412	1	6768435376696289	2012/02	user10119	password	53	100000	M
10120	SLOSNY	USNQDDXLZZ	5996990640 Dell Way	\N	GLRERLY	\N	0	Chile	2	USNQDDXLZZ@dell.com	5996990640	3	1760621150955557	2011/01	user10120	password	20	40000	M
10121	MTNASI	SFYWIWHIVO	3222345544 Dell Way	\N	TMSKXRR	\N	0	France	2	SFYWIWHIVO@dell.com	3222345544	4	2421808199491352	2009/10	user10121	password	44	20000	F
10122	DQGVYZ	AXVJTDRPRL	3114843563 Dell Way	\N	CKVABMM	\N	0	China	2	AXVJTDRPRL@dell.com	3114843563	4	6717701875139028	2008/12	user10122	password	73	40000	F
10123	KNYIMY	GIIZLAPDLR	8028708820 Dell Way	\N	OHRPUDX	\N	0	Australia	2	GIIZLAPDLR@dell.com	8028708820	3	1076460378710180	2011/04	user10123	password	37	100000	M
10124	UVBGUH	PCHBCWFNOT	8567666024 Dell Way	\N	UGJOKHO	\N	0	Canada	2	PCHBCWFNOT@dell.com	8567666024	3	9521665547974408	2008/11	user10124	password	79	100000	M
10125	RXXLFM	NMNQJTDXMY	6984292588 Dell Way	\N	EWNODCS	\N	0	UK	2	NMNQJTDXMY@dell.com	6984292588	4	2152544459328055	2010/07	user10125	password	90	20000	F
10126	XAPCMD	OATYTWWGVA	9573938260 Dell Way	\N	CIOFKHF	\N	0	Australia	2	OATYTWWGVA@dell.com	9573938260	2	6331757990177721	2010/04	user10126	password	70	80000	F
10127	TFHGIW	GCUAZRHURJ	2018868689 Dell Way	\N	DGPONUQ	\N	0	France	2	GCUAZRHURJ@dell.com	2018868689	2	9501714078709484	2010/12	user10127	password	59	80000	M
10128	UYXDUE	FPFEHMYYWB	5176567489 Dell Way	\N	FLPTGGF	\N	0	China	2	FPFEHMYYWB@dell.com	5176567489	1	7971899009309710	2010/09	user10128	password	47	20000	M
10129	IAQDFV	TKZAXYZUAE	3771405611 Dell Way	\N	FPXLWDU	\N	0	China	2	TKZAXYZUAE@dell.com	3771405611	3	7550768678542227	2008/12	user10129	password	77	60000	F
10130	VEMAAG	LZGJYGDYKI	2478032308 Dell Way	\N	OIUKMPS	\N	0	Russia	2	LZGJYGDYKI@dell.com	2478032308	3	8383618688210846	2008/04	user10130	password	45	60000	F
10131	OYDOEO	OLXNRBLCKZ	5992407089 Dell Way	\N	LEJXUCR	\N	0	UK	2	OLXNRBLCKZ@dell.com	5992407089	3	1824740753043443	2012/11	user10131	password	59	100000	F
10132	NAASPP	DNCVONXZMI	4601885022 Dell Way	\N	EWFYZXW	\N	0	Germany	2	DNCVONXZMI@dell.com	4601885022	5	4198343658354133	2009/07	user10132	password	37	80000	F
10133	ISTXHX	LJSAXPZKYD	9386657843 Dell Way	\N	GEBGCYU	\N	0	France	2	LJSAXPZKYD@dell.com	9386657843	1	7743720630183817	2010/05	user10133	password	51	60000	M
10134	EHQLEB	VWBSMBCLEJ	5491548091 Dell Way	\N	QGPSFJE	\N	0	Canada	2	VWBSMBCLEJ@dell.com	5491548091	5	6635525713209063	2012/05	user10134	password	29	80000	M
10135	LFZQHV	MJNZKQLPAB	8591200602 Dell Way	\N	WPTBZXF	\N	0	France	2	MJNZKQLPAB@dell.com	8591200602	5	4384110403712839	2009/01	user10135	password	89	80000	F
10136	FTBMOO	VCOFTZUTBR	8168687290 Dell Way	\N	JUSISYV	\N	0	Germany	2	VCOFTZUTBR@dell.com	8168687290	1	8042043758090586	2012/03	user10136	password	57	40000	F
10137	HHWWWR	YKXSKSLLJU	2289117672 Dell Way	\N	GCDZBYO	\N	0	South Africa	2	YKXSKSLLJU@dell.com	2289117672	2	6777330616954715	2009/11	user10137	password	82	80000	F
10138	EOZBGY	MDQWWCIGXP	5089185717 Dell Way	\N	IBPJZDF	\N	0	Canada	2	MDQWWCIGXP@dell.com	5089185717	5	5042902151588351	2009/10	user10138	password	28	60000	M
10139	RMZXKM	BBJYEREBHN	9951185623 Dell Way	\N	CWXCZDG	\N	0	France	2	BBJYEREBHN@dell.com	9951185623	4	7931391815189273	2011/10	user10139	password	35	80000	M
10140	SRLDDN	FNLJEQLMDO	6098545796 Dell Way	\N	IBQIEWU	\N	0	Canada	2	FNLJEQLMDO@dell.com	6098545796	3	9260164564941080	2009/10	user10140	password	62	100000	M
10141	HIQLVV	YHFDXRPBFY	6896148943 Dell Way	\N	CWHGTCL	\N	0	China	2	YHFDXRPBFY@dell.com	6896148943	2	7248618901707233	2010/12	user10141	password	61	100000	F
10142	XPSTLR	ARUYIKZNJB	2044077443 Dell Way	\N	KRIDTTL	\N	0	France	2	ARUYIKZNJB@dell.com	2044077443	1	8876663849689067	2008/09	user10142	password	79	40000	M
10143	LBKXSL	PMJXXILHKV	5903141781 Dell Way	\N	YSZSMKD	\N	0	Japan	2	PMJXXILHKV@dell.com	5903141781	1	7150446451734752	2009/11	user10143	password	19	100000	F
10144	BIFTTU	GDSELDLWZK	2962988598 Dell Way	\N	PYCBJFR	\N	0	UK	2	GDSELDLWZK@dell.com	2962988598	2	2661317951977253	2008/05	user10144	password	25	40000	F
10145	KOFEIM	HBQTECQEMF	3898981832 Dell Way	\N	DOHMUYK	\N	0	UK	2	HBQTECQEMF@dell.com	3898981832	3	1484882939606905	2011/09	user10145	password	48	20000	F
10146	ZJHIVP	JMJOOZSAEV	3876787956 Dell Way	\N	OLIJKSI	\N	0	Russia	2	JMJOOZSAEV@dell.com	3876787956	2	4997829695232213	2008/10	user10146	password	61	20000	M
10147	YLCUAM	HJAVJSVNNK	5555397888 Dell Way	\N	ZWTKPCD	\N	0	UK	2	HJAVJSVNNK@dell.com	5555397888	3	9273519292008132	2009/03	user10147	password	21	20000	F
10148	MFYMRF	WRAFJWTXHT	9058227925 Dell Way	\N	UBEJEHG	\N	0	Japan	2	WRAFJWTXHT@dell.com	9058227925	1	9964757571462544	2008/03	user10148	password	24	40000	M
10149	HEFYJC	QKHZHBXPVR	5395655665 Dell Way	\N	QZBVHHN	\N	0	Canada	2	QKHZHBXPVR@dell.com	5395655665	3	3309400976169854	2011/08	user10149	password	53	60000	M
10150	QQVASL	LALTCJIXBZ	8358887409 Dell Way	\N	WCUEKII	\N	0	South Africa	2	LALTCJIXBZ@dell.com	8358887409	3	6402427504770458	2010/01	user10150	password	20	40000	M
10151	RDTJPF	KBYMLGJMFG	4017353374 Dell Way	\N	OAKYITV	\N	0	Canada	2	KBYMLGJMFG@dell.com	4017353374	3	6133136368356646	2010/06	user10151	password	81	20000	F
10152	AXNQCX	SAJDGTPMAE	4551610878 Dell Way	\N	NLDWEZA	\N	0	Germany	2	SAJDGTPMAE@dell.com	4551610878	3	9382084748707712	2012/06	user10152	password	22	100000	F
10153	YMDAJV	BTYINOVOTI	7961254629 Dell Way	\N	ZWEEVFS	\N	0	Chile	2	BTYINOVOTI@dell.com	7961254629	4	1785297000315040	2009/09	user10153	password	23	80000	M
10154	OVRYQT	SPBFEWUXFT	3608987357 Dell Way	\N	UJYQPRW	\N	0	China	2	SPBFEWUXFT@dell.com	3608987357	5	6228095464874060	2012/01	user10154	password	39	80000	M
10155	DINTBF	JCLOZFMEZG	7179738324 Dell Way	\N	OYWDPTM	\N	0	South Africa	2	JCLOZFMEZG@dell.com	7179738324	1	8808631554245950	2011/05	user10155	password	54	40000	F
10156	VUGWZQ	ZLEYQQDQXR	4165079685 Dell Way	\N	OUUENHA	\N	0	Chile	2	ZLEYQQDQXR@dell.com	4165079685	5	9138823721557856	2011/05	user10156	password	30	20000	F
10157	YLCYBC	JFBAVERTVG	4056399883 Dell Way	\N	NQKAYLF	\N	0	Chile	2	JFBAVERTVG@dell.com	4056399883	1	9846837298944592	2011/04	user10157	password	30	100000	F
10158	PCFQEP	VFQRJHKFNY	3729343511 Dell Way	\N	VYYTJEB	\N	0	Russia	2	VFQRJHKFNY@dell.com	3729343511	1	5047834767494351	2011/03	user10158	password	49	100000	M
10159	NCKSRG	XIYHPJMDHI	2592086646 Dell Way	\N	BGCLKDD	\N	0	Russia	2	XIYHPJMDHI@dell.com	2592086646	3	3992895328439772	2009/01	user10159	password	32	20000	M
10160	HOFZVD	HULXEYBLHC	3138321772 Dell Way	\N	SJNDNRV	\N	0	Russia	2	HULXEYBLHC@dell.com	3138321772	1	1651594693772494	2009/05	user10160	password	34	80000	M
10161	UAQQDY	KPVONWAUZS	8597267993 Dell Way	\N	ENVRERK	\N	0	France	2	KPVONWAUZS@dell.com	8597267993	3	6954802865628154	2009/09	user10161	password	50	100000	F
10162	LOCPMN	EIBSFCMEUR	2970905884 Dell Way	\N	SQJWHTH	\N	0	Canada	2	EIBSFCMEUR@dell.com	2970905884	5	4230778086464852	2012/05	user10162	password	36	40000	M
10163	UNLHAQ	PCJVEVAZNS	8577527341 Dell Way	\N	PWPWPWA	\N	0	South Africa	2	PCJVEVAZNS@dell.com	8577527341	2	7654870729893447	2009/08	user10163	password	27	20000	F
10164	QNSQEI	TNDXJDWWWL	7284530558 Dell Way	\N	SLIIIIE	\N	0	Canada	2	TNDXJDWWWL@dell.com	7284530558	5	4631218837574124	2009/01	user10164	password	53	80000	M
10165	ALIEUB	SXYBBVYXGR	1489341315 Dell Way	\N	JPZRXDV	\N	0	Japan	2	SXYBBVYXGR@dell.com	1489341315	2	9382251427043230	2008/09	user10165	password	67	80000	M
10166	DBYXDQ	VCSXXQVDHE	9193210722 Dell Way	\N	THVQLRG	\N	0	Germany	2	VCSXXQVDHE@dell.com	9193210722	1	6351599304471166	2011/11	user10166	password	43	40000	M
10167	LIXOZT	QSQNJMRRQK	5472946271 Dell Way	\N	YLBKDIX	\N	0	Australia	2	QSQNJMRRQK@dell.com	5472946271	3	7111224857158960	2009/11	user10167	password	22	40000	F
10168	KHVJAM	BRAKDRCTCA	8634719535 Dell Way	\N	FDLJMIK	\N	0	UK	2	BRAKDRCTCA@dell.com	8634719535	1	3883632669225335	2011/02	user10168	password	67	100000	M
10169	YVXZIZ	RIKUAMOCNU	6475792656 Dell Way	\N	GYDSHNR	\N	0	Canada	2	RIKUAMOCNU@dell.com	6475792656	5	8727430333383382	2011/09	user10169	password	80	40000	M
10170	RFPAFG	IPBICQLQKS	1880309476 Dell Way	\N	POKXCCB	\N	0	Japan	2	IPBICQLQKS@dell.com	1880309476	5	4960966001264751	2011/10	user10170	password	71	60000	F
10171	YALDHU	TIDVZPLJHB	8817738433 Dell Way	\N	XSYAUZS	\N	0	UK	2	TIDVZPLJHB@dell.com	8817738433	1	7111725436989219	2011/11	user10171	password	24	20000	M
10172	CNXKIR	SLMSAYBIZZ	8403998359 Dell Way	\N	AXZVXRS	\N	0	Russia	2	SLMSAYBIZZ@dell.com	8403998359	3	4433130065910518	2011/06	user10172	password	50	60000	M
10173	ZKZHBS	SOKTNMBMMC	1411284092 Dell Way	\N	KMXIEQB	\N	0	UK	2	SOKTNMBMMC@dell.com	1411284092	3	6989946354180575	2010/11	user10173	password	28	20000	M
10174	ODDPVW	EGPRSREFTP	4785845211 Dell Way	\N	RRXVIZV	\N	0	China	2	EGPRSREFTP@dell.com	4785845211	3	9042753570247442	2009/08	user10174	password	20	20000	F
10175	DIUZEY	GUPYMTEGIV	9486163615 Dell Way	\N	XFRFFMO	\N	0	Japan	2	GUPYMTEGIV@dell.com	9486163615	3	9427894753869624	2010/07	user10175	password	27	80000	M
10176	LNQQLW	LAVYUZEDVC	4229946434 Dell Way	\N	JMIOYXE	\N	0	South Africa	2	LAVYUZEDVC@dell.com	4229946434	1	5083723139017821	2012/03	user10176	password	31	60000	M
10177	RDIDAU	EWSYVWCRZL	3307666684 Dell Way	\N	DHZCEDZ	\N	0	Germany	2	EWSYVWCRZL@dell.com	3307666684	3	4517810765653849	2010/08	user10177	password	83	20000	F
10178	BMLBGP	XYOTVQKVBO	1357700140 Dell Way	\N	CBQGFPU	\N	0	France	2	XYOTVQKVBO@dell.com	1357700140	1	9436407967936248	2011/02	user10178	password	25	100000	F
10179	PJFVZD	UNXQDHLEWO	8306822119 Dell Way	\N	GMVLCQX	\N	0	Canada	2	UNXQDHLEWO@dell.com	8306822119	5	8078229821287096	2012/12	user10179	password	72	20000	M
10180	DGICKD	PHUTPGYLUE	3866084752 Dell Way	\N	XPPAGMD	\N	0	Australia	2	PHUTPGYLUE@dell.com	3866084752	5	9547994325403124	2009/09	user10180	password	18	80000	M
10181	GCXRGN	YAGNGEZBJX	9861608232 Dell Way	\N	RYXXLBY	\N	0	Russia	2	YAGNGEZBJX@dell.com	9861608232	5	1100467301905155	2011/11	user10181	password	73	60000	F
10182	WJVCWU	DCIKHHLQED	8756748022 Dell Way	\N	PCABDZV	\N	0	Canada	2	DCIKHHLQED@dell.com	8756748022	5	8074196348898114	2011/08	user10182	password	35	100000	F
10183	PTOLNR	OVBWDMMIPC	8257119818 Dell Way	\N	KQEOPZR	\N	0	France	2	OVBWDMMIPC@dell.com	8257119818	3	2940673394594341	2009/09	user10183	password	28	100000	F
10184	XKTKBI	GCEKPRSFUD	8419453294 Dell Way	\N	VYRLXJX	\N	0	Russia	2	GCEKPRSFUD@dell.com	8419453294	1	2042999049182981	2010/03	user10184	password	88	100000	F
10185	JPOKYU	NCFCUXIOAE	6443884624 Dell Way	\N	NSPKBMD	\N	0	South Africa	2	NCFCUXIOAE@dell.com	6443884624	2	4887534297537059	2012/03	user10185	password	37	100000	M
10186	WNZUIM	XNPSLXHMBU	6187376962 Dell Way	\N	FRFHEIE	\N	0	Russia	2	XNPSLXHMBU@dell.com	6187376962	4	6667177129071206	2011/11	user10186	password	62	40000	M
10187	DIOMUM	AKEMHLYJFE	3005966048 Dell Way	\N	BKLGTQA	\N	0	China	2	AKEMHLYJFE@dell.com	3005966048	4	1938490689266473	2008/04	user10187	password	51	100000	F
10188	UKWPXX	ZBJHNIRSMS	6335146240 Dell Way	\N	DYYWOYF	\N	0	Russia	2	ZBJHNIRSMS@dell.com	6335146240	2	8934484786819668	2012/10	user10188	password	72	40000	M
10189	EDDBAC	CKJQTAJGTM	8797612742 Dell Way	\N	ERJTQON	\N	0	Chile	2	CKJQTAJGTM@dell.com	8797612742	2	1717374604195356	2011/02	user10189	password	41	20000	F
10190	LHIMJL	XTCQULWNXA	7101970024 Dell Way	\N	FHUVWHB	\N	0	Russia	2	XTCQULWNXA@dell.com	7101970024	1	4126516355667263	2012/06	user10190	password	55	20000	M
10191	ULKEXH	XZXRKUEIVJ	5027533818 Dell Way	\N	QPFMWHF	\N	0	Germany	2	XZXRKUEIVJ@dell.com	5027533818	3	4279917010571808	2012/01	user10191	password	52	100000	M
10192	XGAVOX	UMPFGTOBDE	4511029898 Dell Way	\N	RJQORVC	\N	0	Canada	2	UMPFGTOBDE@dell.com	4511029898	3	1298848853446543	2010/12	user10192	password	82	40000	M
10193	DHRSFL	EURLOFNSJE	3558330391 Dell Way	\N	BATSVVV	\N	0	Chile	2	EURLOFNSJE@dell.com	3558330391	5	7131373615469784	2009/10	user10193	password	89	20000	M
10194	HSPMEU	GVGVBTNKYP	9993039340 Dell Way	\N	KRHGNDM	\N	0	Russia	2	GVGVBTNKYP@dell.com	9993039340	1	1055499330163002	2011/02	user10194	password	22	80000	F
10195	UGXYBE	UHZVBMGACR	6145838396 Dell Way	\N	SJXFNKA	\N	0	Germany	2	UHZVBMGACR@dell.com	6145838396	1	3373916660901159	2011/01	user10195	password	84	20000	M
10196	EAUGFP	OEKQRRQTIJ	6473729488 Dell Way	\N	DFOQQPE	\N	0	Chile	2	OEKQRRQTIJ@dell.com	6473729488	3	9265581147745252	2011/05	user10196	password	21	60000	M
10197	CIUHYI	MJYEAPXIYB	3716773192 Dell Way	\N	ONSFCWK	\N	0	Russia	2	MJYEAPXIYB@dell.com	3716773192	2	4702536763623357	2011/05	user10197	password	87	20000	F
10198	HYTGHF	PFJPVHYUIN	4720993161 Dell Way	\N	HBSKXCD	\N	0	Chile	2	PFJPVHYUIN@dell.com	4720993161	3	8833574912045152	2011/07	user10198	password	21	40000	M
10199	AZBHFQ	NOGIWECESK	5593499283 Dell Way	\N	GKVEMYJ	\N	0	UK	2	NOGIWECESK@dell.com	5593499283	2	7226950575597585	2008/04	user10199	password	85	100000	F
10200	XWPCMC	RSKNXNSPYY	7735387832 Dell Way	\N	ATDNSMK	\N	0	Chile	2	RSKNXNSPYY@dell.com	7735387832	1	3095272887963801	2008/01	user10200	password	21	40000	M
10201	XYBKAS	DLGBYZQWYR	7025165271 Dell Way	\N	QBEINOO	\N	0	Chile	2	DLGBYZQWYR@dell.com	7025165271	4	3998948336578906	2011/10	user10201	password	67	80000	M
10202	PSDQKH	BRIZQZWOQM	2219153687 Dell Way	\N	PUVDJJL	\N	0	Australia	2	BRIZQZWOQM@dell.com	2219153687	4	7487511905375869	2012/06	user10202	password	44	80000	F
10203	BWRMDS	DLSULOJBBY	3434584469 Dell Way	\N	VWCEFNF	\N	0	China	2	DLSULOJBBY@dell.com	3434584469	5	3952437197789550	2011/04	user10203	password	20	80000	F
10204	XKVADZ	MVUXKDZLBV	2354139209 Dell Way	\N	IEAORFX	\N	0	UK	2	MVUXKDZLBV@dell.com	2354139209	2	6882314071524889	2010/04	user10204	password	47	100000	F
10205	VQFYQR	UKPENOQPKY	6962171530 Dell Way	\N	TKNLQKJ	\N	0	Russia	2	UKPENOQPKY@dell.com	6962171530	1	2967495350632816	2012/06	user10205	password	19	20000	F
10206	RIFHZA	SPEFEVVOUP	4936394473 Dell Way	\N	ZHAPSKJ	\N	0	China	2	SPEFEVVOUP@dell.com	4936394473	3	3830095810815692	2012/08	user10206	password	49	20000	F
10207	TJOTJG	IOMMJIBDXA	5962969480 Dell Way	\N	LYQDIZN	\N	0	Russia	2	IOMMJIBDXA@dell.com	5962969480	5	6893978524953128	2008/04	user10207	password	76	60000	M
10208	EZSNGB	BTOLBQOZQA	5553207097 Dell Way	\N	XGDGGRA	\N	0	Russia	2	BTOLBQOZQA@dell.com	5553207097	4	9498407904058696	2011/06	user10208	password	44	80000	M
10209	JMEPOG	ICRKSGKJGI	3528289034 Dell Way	\N	QKOWCPR	\N	0	Germany	2	ICRKSGKJGI@dell.com	3528289034	4	4189206943847239	2011/12	user10209	password	26	60000	F
10210	PPXDVG	GMRZTBIAJZ	2077579160 Dell Way	\N	KYVMNNC	\N	0	South Africa	2	GMRZTBIAJZ@dell.com	2077579160	3	6218576460145414	2008/07	user10210	password	90	60000	F
10211	OIHKPO	XHNQIWQSVB	1570055858 Dell Way	\N	QROEEQZ	\N	0	Chile	2	XHNQIWQSVB@dell.com	1570055858	3	4468751607928425	2011/07	user10211	password	76	80000	F
10212	DCOTQL	AECJASBVTS	5365740850 Dell Way	\N	MHXRYXY	\N	0	UK	2	AECJASBVTS@dell.com	5365740850	2	6516081497538835	2008/02	user10212	password	46	40000	F
10213	MTACFA	GHJGZLCTEP	5886295774 Dell Way	\N	BBGZZFZ	\N	0	France	2	GHJGZLCTEP@dell.com	5886295774	4	5652191146276892	2011/12	user10213	password	70	100000	F
10214	MZORAV	YJCYVESZTT	4287106692 Dell Way	\N	BATAFTM	\N	0	Russia	2	YJCYVESZTT@dell.com	4287106692	1	4930318934377283	2009/09	user10214	password	47	100000	F
10215	JJWKFV	THUPLMPFGQ	2522881990 Dell Way	\N	FARLTEE	\N	0	Canada	2	THUPLMPFGQ@dell.com	2522881990	4	5366400258615613	2012/01	user10215	password	40	20000	F
10216	RZUXVO	EPDQBSVIJB	3350686538 Dell Way	\N	IAMBFQF	\N	0	China	2	EPDQBSVIJB@dell.com	3350686538	4	3417148053180426	2009/12	user10216	password	45	80000	M
10217	JLOEAT	UDJWWEEGFM	4981880375 Dell Way	\N	HROMITW	\N	0	Japan	2	UDJWWEEGFM@dell.com	4981880375	1	8886589900590480	2010/06	user10217	password	57	20000	M
10218	ARBAKV	ETSAYWHEJO	1037684131 Dell Way	\N	WXAERXU	\N	0	Canada	2	ETSAYWHEJO@dell.com	1037684131	4	5880212046205998	2010/03	user10218	password	65	40000	F
10219	IKFTGJ	MYKLVRPEGL	1797656481 Dell Way	\N	CHQTEKW	\N	0	Canada	2	MYKLVRPEGL@dell.com	1797656481	2	6945827439893038	2009/01	user10219	password	19	60000	F
10220	LTDRCQ	QNBMFQQLCS	7485931480 Dell Way	\N	SSMWDIA	\N	0	Chile	2	QNBMFQQLCS@dell.com	7485931480	4	5810155843850226	2011/09	user10220	password	21	20000	F
10221	UHVXXM	KYYPPOARHT	3545636862 Dell Way	\N	KTPOBPU	\N	0	Russia	2	KYYPPOARHT@dell.com	3545636862	2	6037038498092443	2012/05	user10221	password	70	20000	F
10222	ZYBXKM	WICLXCDEVO	2958411115 Dell Way	\N	YLCZAXU	\N	0	China	2	WICLXCDEVO@dell.com	2958411115	2	3731689505744726	2010/01	user10222	password	48	80000	F
10223	JVYUHV	DJHAMKFIZD	3452783500 Dell Way	\N	TCDUZYC	\N	0	Chile	2	DJHAMKFIZD@dell.com	3452783500	3	8115043869242073	2009/11	user10223	password	57	40000	F
10224	JJZQEC	ALDMWJUVNO	8927850401 Dell Way	\N	XRJXPMC	\N	0	South Africa	2	ALDMWJUVNO@dell.com	8927850401	5	2774995212908834	2011/06	user10224	password	60	100000	M
10225	YXKCAK	NEXKNSFBGD	1041646252 Dell Way	\N	SPAHBDE	\N	0	UK	2	NEXKNSFBGD@dell.com	1041646252	2	6989332995843143	2010/12	user10225	password	61	40000	M
10226	NQZOBN	SYXGQDHXGA	8662217232 Dell Way	\N	MHIOKMM	\N	0	China	2	SYXGQDHXGA@dell.com	8662217232	1	8491230892017485	2012/10	user10226	password	21	80000	F
10227	RRUSFN	RDTHGBENCR	8806590225 Dell Way	\N	UKFFWSP	\N	0	Russia	2	RDTHGBENCR@dell.com	8806590225	3	5830040798522533	2011/06	user10227	password	35	100000	F
10228	YRWDFN	HZVOBZBDRW	1715842044 Dell Way	\N	NWBKPRD	\N	0	France	2	HZVOBZBDRW@dell.com	1715842044	4	1658409155905246	2010/11	user10228	password	87	80000	M
10229	QOZWCG	VXUWXWAOTN	7455526282 Dell Way	\N	LUXALBM	\N	0	Germany	2	VXUWXWAOTN@dell.com	7455526282	3	1723495191428810	2011/07	user10229	password	74	60000	F
10230	IKAKRW	IMTFITUBGF	3412950718 Dell Way	\N	WEGIGSW	\N	0	UK	2	IMTFITUBGF@dell.com	3412950718	5	6185937509406359	2011/09	user10230	password	19	100000	F
10231	LYLCUU	OOAXHUZOAW	9538527732 Dell Way	\N	TGEZZAY	\N	0	Chile	2	OOAXHUZOAW@dell.com	9538527732	3	1085942037869244	2011/07	user10231	password	86	80000	M
10232	XEBSYQ	GYONSNBSJU	3066593066 Dell Way	\N	ZOUYOSE	\N	0	Germany	2	GYONSNBSJU@dell.com	3066593066	1	2473730250727385	2011/02	user10232	password	80	80000	F
10233	AUSYLY	XZLPNNIWIH	6268755959 Dell Way	\N	LCGZVKM	\N	0	Australia	2	XZLPNNIWIH@dell.com	6268755959	4	8229910698253662	2011/07	user10233	password	56	80000	M
10234	ILMUJJ	TVZGIIDRQP	7489696317 Dell Way	\N	TWOOGBP	\N	0	South Africa	2	TVZGIIDRQP@dell.com	7489696317	3	6017933848313988	2009/12	user10234	password	38	80000	F
10235	SGBBQV	XQCGYFXOVR	3143128643 Dell Way	\N	KJFRLVN	\N	0	Canada	2	XQCGYFXOVR@dell.com	3143128643	1	4587872588075698	2008/05	user10235	password	30	60000	F
10236	LNDBIB	SKHQQFFLWQ	9447247637 Dell Way	\N	VBHGXVK	\N	0	Canada	2	SKHQQFFLWQ@dell.com	9447247637	5	3915739180520177	2009/12	user10236	password	75	40000	F
10237	HOMPPE	AXVQCABYQW	4039546658 Dell Way	\N	AYDXUNB	\N	0	Russia	2	AXVQCABYQW@dell.com	4039546658	2	1222980488557368	2009/02	user10237	password	48	80000	F
10238	YFBOKB	LFRNFTLVQL	8241560437 Dell Way	\N	TTJOHLG	\N	0	Japan	2	LFRNFTLVQL@dell.com	8241560437	2	9467658221721650	2012/09	user10238	password	66	60000	M
10239	WMFHOQ	MGDRZPNQAH	4314120464 Dell Way	\N	JKVRVCH	\N	0	Japan	2	MGDRZPNQAH@dell.com	4314120464	2	6374892835505307	2008/11	user10239	password	19	80000	M
10240	NXBBNN	HRFHGTXHAH	5205206407 Dell Way	\N	RWYNYGD	\N	0	China	2	HRFHGTXHAH@dell.com	5205206407	4	4398460921831429	2009/09	user10240	password	24	20000	F
10241	ZFHNTP	EZWLSTSTBK	7827892125 Dell Way	\N	PZXOFAW	\N	0	Japan	2	EZWLSTSTBK@dell.com	7827892125	2	1582535158377140	2010/04	user10241	password	33	80000	F
10242	LBVEQA	DMLWGEPHOE	8317741396 Dell Way	\N	HLSNMPF	\N	0	Chile	2	DMLWGEPHOE@dell.com	8317741396	2	7722567531280220	2008/07	user10242	password	54	60000	M
10243	OHCEIG	RUCYYSGNWN	5968463076 Dell Way	\N	ZPBLEHR	\N	0	UK	2	RUCYYSGNWN@dell.com	5968463076	3	2136688505299389	2008/12	user10243	password	60	100000	F
10244	WCREJJ	ZLIXDOLACK	9549797063 Dell Way	\N	QDVUKNU	\N	0	UK	2	ZLIXDOLACK@dell.com	9549797063	5	1043327939230948	2012/06	user10244	password	90	40000	F
10245	CBOLLN	WTLAHWBJHR	2480964113 Dell Way	\N	MCMXQGV	\N	0	Germany	2	WTLAHWBJHR@dell.com	2480964113	5	5180140862707049	2011/11	user10245	password	79	20000	M
10246	XOIICF	BOGIKHSRZF	8033922825 Dell Way	\N	ULCLRYA	\N	0	South Africa	2	BOGIKHSRZF@dell.com	8033922825	3	5524839845485986	2011/04	user10246	password	56	60000	F
10247	CWOFCP	TJYERQWQWQ	6182620170 Dell Way	\N	BYCTWCP	\N	0	Japan	2	TJYERQWQWQ@dell.com	6182620170	1	3427878473419696	2012/08	user10247	password	76	20000	M
10248	RRXUGQ	EFUVWQLSHN	9468040461 Dell Way	\N	QJGNMWE	\N	0	Australia	2	EFUVWQLSHN@dell.com	9468040461	3	9507028452586384	2010/03	user10248	password	22	40000	M
10249	SETZUX	EPSAGETNSK	5482911985 Dell Way	\N	XYXKVBL	\N	0	Russia	2	EPSAGETNSK@dell.com	5482911985	2	3738783114589751	2011/06	user10249	password	59	80000	F
10250	TKDNHH	DAIJFBXXLV	1302382370 Dell Way	\N	WJFRKQK	\N	0	UK	2	DAIJFBXXLV@dell.com	1302382370	4	6901181840337814	2010/04	user10250	password	41	80000	F
10251	STOAAS	BJBGLZDXUA	8355637929 Dell Way	\N	GARRRCP	\N	0	Russia	2	BJBGLZDXUA@dell.com	8355637929	2	2569611708633601	2008/07	user10251	password	76	20000	F
10252	ORIPKJ	YLQJLUHGUN	9901817600 Dell Way	\N	HMEYOTQ	\N	0	China	2	YLQJLUHGUN@dell.com	9901817600	5	5366755563300103	2010/08	user10252	password	62	100000	F
10253	HETSNR	EEBPYIWSVD	5581849066 Dell Way	\N	EABTUSD	\N	0	Russia	2	EEBPYIWSVD@dell.com	5581849066	4	3845774361863732	2008/03	user10253	password	29	40000	M
10254	IAFWRK	ATZYBVRXZW	4076893540 Dell Way	\N	YAPSSSM	\N	0	Chile	2	ATZYBVRXZW@dell.com	4076893540	5	4218565796036273	2010/12	user10254	password	63	20000	F
10255	QIDISD	BSCDOTBNQA	1145268058 Dell Way	\N	OFSHYFN	\N	0	Chile	2	BSCDOTBNQA@dell.com	1145268058	5	8807184707839043	2012/07	user10255	password	88	40000	F
10256	HKMAON	TQRHKTVATK	1868243283 Dell Way	\N	GMRFRFN	\N	0	Russia	2	TQRHKTVATK@dell.com	1868243283	2	7121748655103148	2011/05	user10256	password	86	80000	M
10257	IGRWUK	NLSXEOYYYE	3251302857 Dell Way	\N	KQJCVWU	\N	0	UK	2	NLSXEOYYYE@dell.com	3251302857	3	5824544813949615	2010/06	user10257	password	39	40000	M
10258	NXQIID	TBAYPYXNDH	7215979242 Dell Way	\N	DNKZJFX	\N	0	Japan	2	TBAYPYXNDH@dell.com	7215979242	3	3005546492058784	2008/09	user10258	password	51	100000	F
10259	JMOSPI	TQHIPEWSMZ	3361576345 Dell Way	\N	FWYPBVF	\N	0	Russia	2	TQHIPEWSMZ@dell.com	3361576345	3	8899620943702758	2012/11	user10259	password	72	40000	F
10260	FVZVDS	LKBBPXTBWY	2896345376 Dell Way	\N	XVOZRTT	\N	0	UK	2	LKBBPXTBWY@dell.com	2896345376	4	9185295201372356	2008/05	user10260	password	29	40000	M
10261	ZJLCCW	NDYCAREXQB	5045961449 Dell Way	\N	SEBJYVH	\N	0	Canada	2	NDYCAREXQB@dell.com	5045961449	2	3396388283465058	2012/05	user10261	password	66	60000	F
10262	AVLCSZ	GQBGIFDYHV	7362333181 Dell Way	\N	DJFBENF	\N	0	Japan	2	GQBGIFDYHV@dell.com	7362333181	3	5041581272613257	2008/02	user10262	password	81	40000	F
10263	SVHLUN	CWTKCXJKTM	3127802425 Dell Way	\N	TYOYMTO	\N	0	Canada	2	CWTKCXJKTM@dell.com	3127802425	1	3119388842955232	2009/11	user10263	password	63	60000	M
10264	LVAGID	DCNGZXQTJK	9188156259 Dell Way	\N	RXIERXI	\N	0	UK	2	DCNGZXQTJK@dell.com	9188156259	3	3564865957945585	2011/03	user10264	password	78	40000	M
10265	QKXZOA	BCHBZXUIHM	5588407641 Dell Way	\N	GQQYNYV	\N	0	France	2	BCHBZXUIHM@dell.com	5588407641	1	3122157930396497	2011/12	user10265	password	63	40000	M
10266	BGOPHQ	RORQMLZUXG	2357433766 Dell Way	\N	KNEYMAK	\N	0	UK	2	RORQMLZUXG@dell.com	2357433766	4	7167031065560878	2008/03	user10266	password	20	80000	F
10267	HGWPWN	DOEQZDKXKU	7831977116 Dell Way	\N	KOTXPDW	\N	0	Russia	2	DOEQZDKXKU@dell.com	7831977116	3	8551354032009841	2008/08	user10267	password	57	40000	M
10268	UEMRSP	FWFFAQCKKN	8556434320 Dell Way	\N	ZEKOHHH	\N	0	Australia	2	FWFFAQCKKN@dell.com	8556434320	1	1554401111789047	2010/09	user10268	password	44	40000	F
10269	NUEGKJ	CQPDGROREN	5546389873 Dell Way	\N	VPCDWJE	\N	0	Russia	2	CQPDGROREN@dell.com	5546389873	2	2289363337680697	2008/08	user10269	password	51	80000	F
10270	GUJQEM	HUPNLDFQRA	6195218598 Dell Way	\N	GTDCDIV	\N	0	Japan	2	HUPNLDFQRA@dell.com	6195218598	5	8363017022144050	2008/06	user10270	password	52	40000	M
10271	GRILDP	FSDRWIIOJO	4777708261 Dell Way	\N	INRMVMC	\N	0	France	2	FSDRWIIOJO@dell.com	4777708261	5	6353121445514262	2012/05	user10271	password	83	60000	M
10272	OVCRLI	KOAHWIWGXE	7113779481 Dell Way	\N	TOQPATA	\N	0	France	2	KOAHWIWGXE@dell.com	7113779481	3	3375058426987380	2008/06	user10272	password	74	80000	F
10273	PVTAED	OELLNHRKML	6509895971 Dell Way	\N	YDAYXAJ	\N	0	Germany	2	OELLNHRKML@dell.com	6509895971	4	6799565408844501	2008/05	user10273	password	45	20000	F
10274	FXAKAP	OMBCUSMHEL	4545335074 Dell Way	\N	KEJIFTX	\N	0	South Africa	2	OMBCUSMHEL@dell.com	4545335074	3	9195367072243244	2012/11	user10274	password	22	100000	F
10275	YVNZKB	MLEGEQNIBY	7193637652 Dell Way	\N	NLGSFEN	\N	0	Germany	2	MLEGEQNIBY@dell.com	7193637652	3	4618076419923455	2010/06	user10275	password	33	80000	F
10276	AFLLHX	XLEBCRKEQY	6327725544 Dell Way	\N	QXQVBEL	\N	0	Russia	2	XLEBCRKEQY@dell.com	6327725544	5	4105551845394075	2008/01	user10276	password	22	60000	F
10277	HZMOWJ	AALCSWGJUW	9621761116 Dell Way	\N	HLSIPDC	\N	0	Canada	2	AALCSWGJUW@dell.com	9621761116	3	3438030994962901	2012/06	user10277	password	76	20000	M
10278	UOIQXI	RJLKFSUAPB	9395863512 Dell Way	\N	LHKAKMF	\N	0	China	2	RJLKFSUAPB@dell.com	9395863512	3	4307309459894896	2010/04	user10278	password	48	20000	F
10279	YNSWWK	GHVLZPLORX	6573802715 Dell Way	\N	VBYGODQ	\N	0	France	2	GHVLZPLORX@dell.com	6573802715	1	9311708324123176	2012/06	user10279	password	26	100000	F
10280	QRGMCM	TXYSNKHEHD	1167614254 Dell Way	\N	GFJUJAH	\N	0	UK	2	TXYSNKHEHD@dell.com	1167614254	2	8922454769257457	2010/05	user10280	password	80	100000	M
10281	OBLQNF	NMYBWFFEIL	8109356031 Dell Way	\N	JSGSSOS	\N	0	Russia	2	NMYBWFFEIL@dell.com	8109356031	3	2568893823772669	2008/06	user10281	password	89	20000	M
10282	BOPOTD	BSEXXKBGWL	4998704346 Dell Way	\N	YDERSWK	\N	0	France	2	BSEXXKBGWL@dell.com	4998704346	3	6543552191928030	2012/07	user10282	password	70	100000	M
10283	HLEAPF	SUCQEEWBPV	4938640546 Dell Way	\N	EUMWQWJ	\N	0	Australia	2	SUCQEEWBPV@dell.com	4938640546	5	9657102761790156	2012/09	user10283	password	77	60000	M
10284	GTAWYT	QBJVGGXWBB	3799276416 Dell Way	\N	QOYHKIJ	\N	0	South Africa	2	QBJVGGXWBB@dell.com	3799276416	2	8537817639764399	2008/02	user10284	password	48	100000	F
10285	EAGDTX	FDSLJQHLSY	9090168839 Dell Way	\N	ZQFKZOG	\N	0	Chile	2	FDSLJQHLSY@dell.com	9090168839	1	3721985809970647	2008/06	user10285	password	39	60000	M
10286	HRUAPZ	EILNYTZQRY	6783300216 Dell Way	\N	HXIGMOO	\N	0	China	2	EILNYTZQRY@dell.com	6783300216	5	4646566420793533	2008/02	user10286	password	79	100000	F
10287	NPMCPQ	LAEJUDZLBH	9337729632 Dell Way	\N	JKNVZCF	\N	0	Japan	2	LAEJUDZLBH@dell.com	9337729632	4	7823360340204091	2008/06	user10287	password	58	60000	M
10288	EZCTPN	UTWOWWAYEJ	1038818982 Dell Way	\N	JSFIUKY	\N	0	Japan	2	UTWOWWAYEJ@dell.com	1038818982	4	7880453723948450	2010/04	user10288	password	37	60000	F
10289	GMEVAZ	PXNLUNKYXT	7762148763 Dell Way	\N	QCCKNBC	\N	0	Germany	2	PXNLUNKYXT@dell.com	7762148763	5	9615529703907670	2008/02	user10289	password	45	60000	F
10290	WQFWPU	UDGORQMOKD	5414317319 Dell Way	\N	RMNENQR	\N	0	Chile	2	UDGORQMOKD@dell.com	5414317319	4	3563567077275366	2011/01	user10290	password	71	100000	M
10291	JEUZYO	CECTVPIFTZ	5511085942 Dell Way	\N	RGEEXWL	\N	0	China	2	CECTVPIFTZ@dell.com	5511085942	4	1023470506537705	2010/06	user10291	password	89	60000	M
10292	EEVDTX	IWRDLZIFZA	4556693048 Dell Way	\N	MDFJZRT	\N	0	France	2	IWRDLZIFZA@dell.com	4556693048	4	1061841509770601	2012/09	user10292	password	48	80000	M
10293	PNAILI	EDMQCVVBVI	2371975517 Dell Way	\N	FBRESKR	\N	0	Canada	2	EDMQCVVBVI@dell.com	2371975517	4	9774748573079706	2012/02	user10293	password	68	80000	M
10294	FUARDF	UPWXKSYGAD	6981976090 Dell Way	\N	HRIACZD	\N	0	Chile	2	UPWXKSYGAD@dell.com	6981976090	1	2071335279848426	2011/10	user10294	password	83	60000	F
10295	SLSVRM	KNKVFJCFNK	6471160057 Dell Way	\N	XVKZVNF	\N	0	France	2	KNKVFJCFNK@dell.com	6471160057	2	3189126935321838	2009/03	user10295	password	67	60000	M
10296	DCTVPE	IAAOJCUWMR	3040671108 Dell Way	\N	RWRNKXA	\N	0	Australia	2	IAAOJCUWMR@dell.com	3040671108	2	4559749857056886	2010/12	user10296	password	76	40000	F
10297	XEXNIF	NITWLOSYFK	2734651541 Dell Way	\N	UWYFTYF	\N	0	UK	2	NITWLOSYFK@dell.com	2734651541	3	5096831291448325	2008/05	user10297	password	80	40000	F
10298	ACVIHI	RBFDPYBVJW	8790642422 Dell Way	\N	SHBMFGL	\N	0	France	2	RBFDPYBVJW@dell.com	8790642422	5	5894076782744378	2009/10	user10298	password	72	60000	M
10299	VKCDTU	FYYVXZQGVI	2476769952 Dell Way	\N	NXUTEGE	\N	0	Australia	2	FYYVXZQGVI@dell.com	2476769952	4	3752698599360883	2012/06	user10299	password	82	80000	F
10300	HVKAPQ	ZNLWNCCJKQ	3130157614 Dell Way	\N	GFJLMNM	\N	0	Japan	2	ZNLWNCCJKQ@dell.com	3130157614	4	6073438182473183	2011/08	user10300	password	37	100000	M
10301	BKZRAZ	FMWSOZCYPI	1259296881 Dell Way	\N	EZUQMGH	\N	0	Russia	2	FMWSOZCYPI@dell.com	1259296881	5	4767723419703543	2011/02	user10301	password	46	80000	F
10302	UQWUQB	HMUVLWUAFY	7604346775 Dell Way	\N	ZZPMFWF	\N	0	Chile	2	HMUVLWUAFY@dell.com	7604346775	4	9546529420185836	2012/01	user10302	password	61	20000	M
10303	GWQWYX	ISSUPMVUKV	2656369112 Dell Way	\N	TAIZXOG	\N	0	Japan	2	ISSUPMVUKV@dell.com	2656369112	1	5322551291901618	2009/10	user10303	password	54	20000	F
10304	JRXIOG	BGAQTWKERE	6122109769 Dell Way	\N	EZDBNJS	\N	0	Russia	2	BGAQTWKERE@dell.com	6122109769	1	9393069337587804	2009/09	user10304	password	88	40000	F
10305	QHKENL	LOBEKMIBQM	5239613106 Dell Way	\N	BTOPDHI	\N	0	Russia	2	LOBEKMIBQM@dell.com	5239613106	2	1606076378840953	2008/03	user10305	password	51	40000	M
10306	TQAGCL	VEQFQYHGLJ	5446384594 Dell Way	\N	AAYDHGW	\N	0	Russia	2	VEQFQYHGLJ@dell.com	5446384594	5	9397576634772124	2011/05	user10306	password	30	60000	F
10307	VOJXAE	BQKRPRYAAY	8572582899 Dell Way	\N	BYBIFXC	\N	0	Russia	2	BQKRPRYAAY@dell.com	8572582899	1	4671289803925902	2009/03	user10307	password	87	40000	F
10308	NSYNWA	EGSTYQTYOU	3437740629 Dell Way	\N	XQDDOGV	\N	0	France	2	EGSTYQTYOU@dell.com	3437740629	2	6588041703682393	2010/03	user10308	password	87	60000	M
10309	QMFNMJ	UFCSVWRKQO	7567122488 Dell Way	\N	BURQANA	\N	0	Chile	2	UFCSVWRKQO@dell.com	7567122488	4	8003619844093920	2012/08	user10309	password	39	60000	F
10310	UUTGEO	MGGICXTTMU	1793470613 Dell Way	\N	OEKORLW	\N	0	China	2	MGGICXTTMU@dell.com	1793470613	4	3745572158601135	2011/12	user10310	password	83	100000	M
10311	SRZWFL	CMUFKNZWHN	6340471728 Dell Way	\N	ASCSDYC	\N	0	Chile	2	CMUFKNZWHN@dell.com	6340471728	3	9324333490338176	2010/04	user10311	password	79	40000	M
10312	NGWTSY	FMEPZDMHQN	7513877789 Dell Way	\N	ZSFDRIK	\N	0	Chile	2	FMEPZDMHQN@dell.com	7513877789	2	8206680769100786	2008/02	user10312	password	21	20000	M
10313	HWLZVQ	LZGLCTSTGS	5984538468 Dell Way	\N	LLWDTGK	\N	0	France	2	LZGLCTSTGS@dell.com	5984538468	1	5689389294944704	2011/03	user10313	password	57	60000	M
10314	KVNGMZ	FTKIMCBSVN	2929693155 Dell Way	\N	ERQYXAL	\N	0	France	2	FTKIMCBSVN@dell.com	2929693155	5	2529921703971922	2010/07	user10314	password	59	100000	M
10315	KNEXMJ	QWSDZTVUGA	4125420664 Dell Way	\N	LWYIXKU	\N	0	Canada	2	QWSDZTVUGA@dell.com	4125420664	5	6206459078006447	2012/07	user10315	password	59	80000	M
10316	BYWOIM	KAQKTMEAMP	7490473277 Dell Way	\N	XLYUVTX	\N	0	Canada	2	KAQKTMEAMP@dell.com	7490473277	3	1319779484067112	2009/01	user10316	password	76	40000	F
10317	TBRBOC	BFMVRQVDGS	9285938376 Dell Way	\N	PFNLZLQ	\N	0	Japan	2	BFMVRQVDGS@dell.com	9285938376	4	9549021087586880	2012/06	user10317	password	30	20000	F
10318	GVGUXI	ZKDRBZVISK	2196127409 Dell Way	\N	NFWMQME	\N	0	Germany	2	ZKDRBZVISK@dell.com	2196127409	1	5878007764928043	2011/04	user10318	password	66	100000	M
10319	MBIKKI	UOZVNUDFER	5180343675 Dell Way	\N	LAEBNIQ	\N	0	Japan	2	UOZVNUDFER@dell.com	5180343675	1	3176773091312498	2011/11	user10319	password	21	40000	F
10320	DPSNXM	BXIPRMVWDG	2045965090 Dell Way	\N	XHIKQYB	\N	0	Canada	2	BXIPRMVWDG@dell.com	2045965090	2	8720538728404791	2012/05	user10320	password	28	40000	F
10321	TZZRLB	OUQFGLCJSZ	7475650267 Dell Way	\N	RAJIZLK	\N	0	Australia	2	OUQFGLCJSZ@dell.com	7475650267	2	1290749579668045	2008/05	user10321	password	39	60000	F
10322	GMVSNJ	MEPSQRCIQU	7968122710 Dell Way	\N	IACILNK	\N	0	Canada	2	MEPSQRCIQU@dell.com	7968122710	3	3087874320335686	2008/09	user10322	password	72	40000	M
10323	GDRUNE	YCXPTZXKTG	4345601690 Dell Way	\N	LVOWIYB	\N	0	Canada	2	YCXPTZXKTG@dell.com	4345601690	2	3741755794268102	2008/01	user10323	password	64	20000	F
10324	UTBHYA	KVPEUNOOTZ	2726341580 Dell Way	\N	KIWTGXW	\N	0	Japan	2	KVPEUNOOTZ@dell.com	2726341580	1	7568741415161640	2009/10	user10324	password	76	60000	M
10325	OOXMOH	HELCRAQLZA	8288250848 Dell Way	\N	TWUATQR	\N	0	UK	2	HELCRAQLZA@dell.com	8288250848	2	2621309116482734	2011/03	user10325	password	67	40000	M
10326	GDFULM	ZXPQXFBXGV	8825215153 Dell Way	\N	TAVNRMM	\N	0	France	2	ZXPQXFBXGV@dell.com	8825215153	4	1944874329958111	2008/05	user10326	password	41	80000	M
10327	LZKWMJ	UBARHBPOXJ	1229839135 Dell Way	\N	OSWGFJT	\N	0	Australia	2	UBARHBPOXJ@dell.com	1229839135	5	2132609758060425	2009/02	user10327	password	84	100000	M
10328	XIMKSH	LSYTUOHRXW	7153134490 Dell Way	\N	KUCPDVR	\N	0	Canada	2	LSYTUOHRXW@dell.com	7153134490	4	5799589340109379	2012/09	user10328	password	53	60000	M
10329	VZZNGL	FFFZTMRQJB	1992225280 Dell Way	\N	KMQOHIS	\N	0	UK	2	FFFZTMRQJB@dell.com	1992225280	2	8555656944867224	2012/09	user10329	password	40	60000	M
10330	HKBNWH	SCHLPYCYAM	1185628246 Dell Way	\N	KQBSZUS	\N	0	Australia	2	SCHLPYCYAM@dell.com	1185628246	3	9024395295418800	2011/11	user10330	password	40	40000	F
10331	TJQQRI	SYUHXWGXJQ	6145718686 Dell Way	\N	OKINEAP	\N	0	Chile	2	SYUHXWGXJQ@dell.com	6145718686	3	9656754950527104	2010/10	user10331	password	37	60000	M
10332	QEEHMW	GHEEDKBNAP	2959457721 Dell Way	\N	YJDCKSI	\N	0	UK	2	GHEEDKBNAP@dell.com	2959457721	2	4520939390640706	2008/07	user10332	password	85	60000	F
10333	CSNOPT	WTXZEZMEPL	2289398864 Dell Way	\N	OSNZLWY	\N	0	Japan	2	WTXZEZMEPL@dell.com	2289398864	2	7186333490535618	2011/04	user10333	password	36	100000	F
10334	ZKXODT	IBTMBGRQRF	5177162177 Dell Way	\N	JFEUBDM	\N	0	Chile	2	IBTMBGRQRF@dell.com	5177162177	1	9118233697954566	2011/05	user10334	password	75	20000	F
10335	EYYISG	KLTLRKBJQK	8365473586 Dell Way	\N	OVFQYRV	\N	0	France	2	KLTLRKBJQK@dell.com	8365473586	4	2199581156019121	2009/07	user10335	password	31	60000	M
10336	DNBVTL	HMWZXYINJX	1650451720 Dell Way	\N	IONHFIS	\N	0	Australia	2	HMWZXYINJX@dell.com	1650451720	5	3354554992634803	2010/01	user10336	password	79	40000	F
10337	JIADUH	PRGNPPAYMJ	2943682103 Dell Way	\N	NZRTIJU	\N	0	France	2	PRGNPPAYMJ@dell.com	2943682103	1	1053696713875979	2009/11	user10337	password	40	60000	F
10338	QKJLSZ	CZMRONQBWD	7235956620 Dell Way	\N	BOWJXQU	\N	0	Canada	2	CZMRONQBWD@dell.com	7235956620	5	4359104860574007	2010/02	user10338	password	74	100000	M
10339	EEEWEG	VQYKDOLASM	5269392821 Dell Way	\N	OPWMGRQ	\N	0	UK	2	VQYKDOLASM@dell.com	5269392821	5	5548797122668475	2010/10	user10339	password	41	40000	M
10340	NNVRUR	ITBLINMAAB	2447957495 Dell Way	\N	PXOVOET	\N	0	Australia	2	ITBLINMAAB@dell.com	2447957495	2	6601949866861106	2012/08	user10340	password	88	100000	F
10341	MSUHJC	ALOIYAIZCY	8447265873 Dell Way	\N	WQULVOM	\N	0	UK	2	ALOIYAIZCY@dell.com	8447265873	1	9134092682041228	2010/01	user10341	password	75	60000	M
10342	MIVWKV	HYDGZMGCLC	1766532492 Dell Way	\N	SGNOUZN	\N	0	Japan	2	HYDGZMGCLC@dell.com	1766532492	3	1380274357274174	2008/03	user10342	password	60	80000	M
10343	XMOHHW	GLDGYJIJLB	5785521116 Dell Way	\N	PZPKZCA	\N	0	Australia	2	GLDGYJIJLB@dell.com	5785521116	1	2741308038122952	2011/08	user10343	password	81	60000	M
10344	JZVRWB	CZHBIQLURA	5618406217 Dell Way	\N	TGLSJLU	\N	0	UK	2	CZHBIQLURA@dell.com	5618406217	5	6805976764298976	2008/11	user10344	password	23	80000	F
10345	BNWXOY	WWAFNLZELS	2815316986 Dell Way	\N	LXLVJFS	\N	0	South Africa	2	WWAFNLZELS@dell.com	2815316986	2	1117481722962111	2008/06	user10345	password	68	40000	M
10346	FCKTBH	QBMDMMIYFT	7104329212 Dell Way	\N	VRPEWHA	\N	0	Australia	2	QBMDMMIYFT@dell.com	7104329212	1	2148373607546091	2008/09	user10346	password	44	80000	M
10347	LBSMJI	NWMZIVXNOT	9876756301 Dell Way	\N	EDXBLYD	\N	0	Canada	2	NWMZIVXNOT@dell.com	9876756301	2	3327924475073814	2011/08	user10347	password	83	80000	F
10348	YJOHSC	DECMAZAOSE	7155388287 Dell Way	\N	SQGEOKH	\N	0	Germany	2	DECMAZAOSE@dell.com	7155388287	3	3585417370311916	2009/06	user10348	password	87	60000	F
10349	HZSABW	FEIFDITWNM	5729618059 Dell Way	\N	NTRCEZR	\N	0	South Africa	2	FEIFDITWNM@dell.com	5729618059	5	2622569603845477	2012/11	user10349	password	61	40000	F
10350	OCFQYK	UHPYQJVDVJ	1464253646 Dell Way	\N	XNLCMCY	\N	0	UK	2	UHPYQJVDVJ@dell.com	1464253646	1	9749304413329812	2012/09	user10350	password	44	20000	F
10351	MIXKSS	SIRIRNMNWJ	5589367738 Dell Way	\N	AIMMLKM	\N	0	France	2	SIRIRNMNWJ@dell.com	5589367738	3	4767075494397432	2009/10	user10351	password	58	60000	F
10352	XKSQDK	YVTQIFEFPE	6485694412 Dell Way	\N	NBRYLEK	\N	0	UK	2	YVTQIFEFPE@dell.com	6485694412	5	2660969013348222	2010/05	user10352	password	67	80000	F
10353	CKXGVV	BOMKUQPJUC	3802030919 Dell Way	\N	LMBXQMW	\N	0	Chile	2	BOMKUQPJUC@dell.com	3802030919	1	7056872900575400	2011/09	user10353	password	45	100000	M
10354	UXBPSC	EFMYVCIQET	6268318428 Dell Way	\N	CGRTSNZ	\N	0	Australia	2	EFMYVCIQET@dell.com	6268318428	4	7527854038868100	2009/01	user10354	password	69	20000	M
10355	PFKIIO	NVNIXVYCPB	4975479995 Dell Way	\N	IGUAUUB	\N	0	China	2	NVNIXVYCPB@dell.com	4975479995	4	7072291222866625	2010/06	user10355	password	77	40000	F
10356	ASKIHY	EUHBQFEFHM	4235591930 Dell Way	\N	LCNFWPP	\N	0	China	2	EUHBQFEFHM@dell.com	4235591930	2	8021010809578002	2012/01	user10356	password	23	100000	F
10357	UJLCHP	XORNUVSBHE	3100362396 Dell Way	\N	DVKAKZI	\N	0	Russia	2	XORNUVSBHE@dell.com	3100362396	1	6555022642016411	2009/03	user10357	password	59	60000	M
10358	YWBFLY	UDMPYFQGJU	2870383152 Dell Way	\N	CUVMTDG	\N	0	UK	2	UDMPYFQGJU@dell.com	2870383152	5	3721291960217059	2009/06	user10358	password	69	40000	F
10359	OKOAJJ	DVYBAPIKKK	1023696784 Dell Way	\N	EFXYIDY	\N	0	Germany	2	DVYBAPIKKK@dell.com	1023696784	2	9156917731743308	2010/12	user10359	password	36	80000	F
10360	QJNZSQ	VRSVGAFQLK	5639190051 Dell Way	\N	WIIELHS	\N	0	France	2	VRSVGAFQLK@dell.com	5639190051	4	9038631195202472	2010/11	user10360	password	67	100000	M
10361	AMNTCI	KUDRVJIGTE	6943148608 Dell Way	\N	OCIAJBM	\N	0	South Africa	2	KUDRVJIGTE@dell.com	6943148608	2	4106857008300722	2010/01	user10361	password	40	20000	F
10362	TNWWVG	QZYMIGSCLH	2892882569 Dell Way	\N	ETIOVVL	\N	0	France	2	QZYMIGSCLH@dell.com	2892882569	4	9992854976560920	2009/01	user10362	password	19	40000	M
10363	OFSKMJ	JKVSROUCVZ	7548238341 Dell Way	\N	WENRZYE	\N	0	Canada	2	JKVSROUCVZ@dell.com	7548238341	1	5180849527474493	2012/03	user10363	password	79	80000	M
10364	BJDOSN	ZOFQCZTXZP	6661023190 Dell Way	\N	CMHBLMG	\N	0	Canada	2	ZOFQCZTXZP@dell.com	6661023190	4	9757089416030796	2012/07	user10364	password	64	60000	M
10365	ZSESFD	GKUJKNGKDI	4195176459 Dell Way	\N	WLKHXQM	\N	0	Germany	2	GKUJKNGKDI@dell.com	4195176459	3	4204717353917658	2012/01	user10365	password	85	60000	F
10366	QRUVVB	GPKRDRBHAX	2273896203 Dell Way	\N	SKFQBSE	\N	0	France	2	GPKRDRBHAX@dell.com	2273896203	3	3911006020382047	2009/06	user10366	password	79	40000	F
10367	NCXIDD	XNUBFWIFUA	3804442933 Dell Way	\N	QAQSSUD	\N	0	South Africa	2	XNUBFWIFUA@dell.com	3804442933	3	1550165312830358	2011/04	user10367	password	43	80000	M
10368	LRDOVB	CQCHMKNGKE	5317584590 Dell Way	\N	GBXYWAU	\N	0	Canada	2	CQCHMKNGKE@dell.com	5317584590	5	9171049050521106	2011/03	user10368	password	69	60000	M
10369	KSFFTH	VVPHFDOQHU	4738157932 Dell Way	\N	RETNFOR	\N	0	Japan	2	VVPHFDOQHU@dell.com	4738157932	3	5195202459581197	2011/04	user10369	password	21	40000	M
10370	TLXMTS	HJANMODUJU	6350831128 Dell Way	\N	ZDIERAW	\N	0	Australia	2	HJANMODUJU@dell.com	6350831128	2	7485902315936983	2012/05	user10370	password	89	60000	F
10371	LMPFFX	OGKAVNUEIU	2525287576 Dell Way	\N	IQYZQVC	\N	0	Chile	2	OGKAVNUEIU@dell.com	2525287576	5	2158923670183867	2010/10	user10371	password	70	80000	F
10372	FHLKEZ	QPAMDVQLPZ	8618650584 Dell Way	\N	CNYTJBZ	\N	0	Germany	2	QPAMDVQLPZ@dell.com	8618650584	1	1768286355305463	2011/10	user10372	password	73	100000	F
10373	BILGHC	VHOZCFLSEN	3817711553 Dell Way	\N	GDGPEFD	\N	0	Australia	2	VHOZCFLSEN@dell.com	3817711553	2	6772783723659814	2008/12	user10373	password	55	20000	F
10374	VOGDQC	KECNJNGOAM	4552643000 Dell Way	\N	RHBVMEV	\N	0	South Africa	2	KECNJNGOAM@dell.com	4552643000	3	9348887391388416	2009/12	user10374	password	22	40000	M
10375	QRXGTI	LVWVJCJJOA	1991514483 Dell Way	\N	QQVDUQY	\N	0	Chile	2	LVWVJCJJOA@dell.com	1991514483	5	6144271408207715	2008/12	user10375	password	88	100000	M
10376	QUUKDG	GABPDKZRKP	6011154095 Dell Way	\N	HGTCXRI	\N	0	UK	2	GABPDKZRKP@dell.com	6011154095	5	1735567600466311	2010/11	user10376	password	88	20000	F
10377	UVWXBD	YCSBNRSXHA	4023821651 Dell Way	\N	EBDBTLA	\N	0	Chile	2	YCSBNRSXHA@dell.com	4023821651	1	8030032507609577	2008/02	user10377	password	77	80000	M
10378	QOUSRS	VKTICMGKML	6633014101 Dell Way	\N	LQMECNM	\N	0	France	2	VKTICMGKML@dell.com	6633014101	2	6535944512579591	2011/01	user10378	password	38	60000	M
10379	VJLNBH	YUQAGXLTIX	8519812276 Dell Way	\N	KUCMHOX	\N	0	UK	2	YUQAGXLTIX@dell.com	8519812276	3	6719279127195478	2012/10	user10379	password	33	80000	M
10380	OCEPJD	KADRXPLFMV	8032119785 Dell Way	\N	AOIIDGG	\N	0	UK	2	KADRXPLFMV@dell.com	8032119785	5	8965805213898421	2011/01	user10380	password	57	40000	M
10381	QLGAOR	ASIYITEUPE	6427728501 Dell Way	\N	JYMMETL	\N	0	UK	2	ASIYITEUPE@dell.com	6427728501	2	6008008560165763	2011/11	user10381	password	77	40000	M
10382	GPNVGO	OOMWIRQYWA	3506469527 Dell Way	\N	WJMACYZ	\N	0	Japan	2	OOMWIRQYWA@dell.com	3506469527	3	4339633142109960	2008/05	user10382	password	68	80000	M
10383	HEMNTA	CGWKXNJTNF	8046687965 Dell Way	\N	CAGFZGX	\N	0	Chile	2	CGWKXNJTNF@dell.com	8046687965	2	4523498130030930	2008/12	user10383	password	21	80000	F
10384	GGTZGV	FDGDRPXFUA	4131541369 Dell Way	\N	FBFEHCL	\N	0	Australia	2	FDGDRPXFUA@dell.com	4131541369	5	2994200408458710	2009/11	user10384	password	18	60000	F
10385	GGCNCH	QILIXINSJT	2430977896 Dell Way	\N	UOXBQID	\N	0	UK	2	QILIXINSJT@dell.com	2430977896	2	3641734443139285	2008/05	user10385	password	77	20000	M
10386	CFCENT	MYBKHPCQIW	4913768447 Dell Way	\N	FGYVPCV	\N	0	Russia	2	MYBKHPCQIW@dell.com	4913768447	1	7953586042858661	2011/12	user10386	password	83	40000	F
10387	CNFQGR	PICWYFNGCS	5766093494 Dell Way	\N	MAOCCKV	\N	0	Germany	2	PICWYFNGCS@dell.com	5766093494	4	3985213071107864	2010/07	user10387	password	71	60000	M
10388	GSGMKV	VMSTRFATYN	1326591854 Dell Way	\N	UNPWXLK	\N	0	France	2	VMSTRFATYN@dell.com	1326591854	4	9272160053253176	2010/06	user10388	password	49	20000	M
10389	DKFNFB	AYURDVLCIF	3372577710 Dell Way	\N	PXCNJNZ	\N	0	China	2	AYURDVLCIF@dell.com	3372577710	5	9336536112241448	2011/04	user10389	password	24	60000	F
10390	MRZSSZ	QNQUIBWQHM	8792432390 Dell Way	\N	OJAXWZH	\N	0	Canada	2	QNQUIBWQHM@dell.com	8792432390	2	8918186859227718	2008/04	user10390	password	42	80000	M
10391	APMSPD	FFXOHUFPHU	3020804778 Dell Way	\N	YHSVHZY	\N	0	Canada	2	FFXOHUFPHU@dell.com	3020804778	5	3873374904505909	2010/02	user10391	password	87	40000	F
10392	OVXDYD	JVRRQXGXRE	7945253450 Dell Way	\N	EJZLJYP	\N	0	Germany	2	JVRRQXGXRE@dell.com	7945253450	5	2077777769882232	2012/11	user10392	password	50	20000	F
10393	GZOFDX	AUOQRUOJZS	7340949303 Dell Way	\N	SZEBYUR	\N	0	Russia	2	AUOQRUOJZS@dell.com	7340949303	4	6749555127229542	2010/03	user10393	password	72	100000	F
10394	TNRWLS	RZJJUXSUQK	9341312439 Dell Way	\N	UVMSQDK	\N	0	China	2	RZJJUXSUQK@dell.com	9341312439	1	9039435832761228	2008/10	user10394	password	82	80000	M
10395	KIKVBB	VLKQJDLZNF	4394375942 Dell Way	\N	VAXLEIU	\N	0	Australia	2	VLKQJDLZNF@dell.com	4394375942	4	3217238417826593	2008/07	user10395	password	82	80000	M
10396	FDUGFQ	SQGBTSBHXW	7872886281 Dell Way	\N	HVILECO	\N	0	Germany	2	SQGBTSBHXW@dell.com	7872886281	5	7360309198964388	2009/09	user10396	password	49	40000	M
10397	OBETRW	JYXCQYJOVR	5389711877 Dell Way	\N	JEDNGRB	\N	0	Australia	2	JYXCQYJOVR@dell.com	5389711877	4	3904765907209367	2008/03	user10397	password	60	20000	M
10398	QGMHCW	GAZWZJKUAU	2019002565 Dell Way	\N	YEHFWJF	\N	0	China	2	GAZWZJKUAU@dell.com	2019002565	3	5646844833157957	2009/02	user10398	password	61	20000	M
10399	VNBYKH	YJEYTOTTIR	7025319997 Dell Way	\N	YQXUZDD	\N	0	Canada	2	YJEYTOTTIR@dell.com	7025319997	4	4658822280354798	2011/03	user10399	password	50	60000	F
10400	ZPAJXZ	TBXMQQGZIE	7616804756 Dell Way	\N	QGYPJCS	\N	0	Australia	2	TBXMQQGZIE@dell.com	7616804756	1	8386974031105638	2012/07	user10400	password	45	20000	M
10401	ZBXWAR	YYDOOJOXOE	6709669824 Dell Way	\N	DNUMPNN	\N	0	China	2	YYDOOJOXOE@dell.com	6709669824	2	3758519391063601	2009/09	user10401	password	43	80000	M
10402	KROLIN	JMCYVQVKVY	3595872009 Dell Way	\N	XPLMCYV	\N	0	Russia	2	JMCYVQVKVY@dell.com	3595872009	1	9543744822032752	2012/06	user10402	password	69	80000	M
10403	JGISTR	EVQAMLKHKH	8002685194 Dell Way	\N	XWUAVQT	\N	0	Australia	2	EVQAMLKHKH@dell.com	8002685194	4	1827512832824140	2009/05	user10403	password	74	20000	M
10404	AMMTEQ	PURCGBKQJH	7694245243 Dell Way	\N	MEHHVBK	\N	0	Germany	2	PURCGBKQJH@dell.com	7694245243	3	8711060266941787	2008/04	user10404	password	19	100000	F
10405	NKBRBR	MSTSUDJDLV	1490728642 Dell Way	\N	ISDDTOS	\N	0	Germany	2	MSTSUDJDLV@dell.com	1490728642	3	6895530677400530	2009/08	user10405	password	60	80000	F
10406	ZQUAIG	TBZNFIRQDZ	4931889267 Dell Way	\N	IHDCWWQ	\N	0	UK	2	TBZNFIRQDZ@dell.com	4931889267	2	3122632295824587	2008/11	user10406	password	79	20000	M
10407	MYWUEP	WDDBLURPUA	1166546940 Dell Way	\N	XYDUUTR	\N	0	Chile	2	WDDBLURPUA@dell.com	1166546940	5	3361363155767322	2012/10	user10407	password	47	80000	F
10408	IOBNDX	RHYDBQTWQR	1575003989 Dell Way	\N	UULPNDV	\N	0	Germany	2	RHYDBQTWQR@dell.com	1575003989	1	4654790911823511	2012/06	user10408	password	25	20000	M
10409	QDIUBA	CZEDQXAHOV	3936555963 Dell Way	\N	BALOEGC	\N	0	Chile	2	CZEDQXAHOV@dell.com	3936555963	3	1441907438449561	2012/08	user10409	password	27	80000	F
10410	GZBIAD	IEHYBIFQEG	5171787437 Dell Way	\N	RPVVVYA	\N	0	Canada	2	IEHYBIFQEG@dell.com	5171787437	1	9653357266448440	2008/03	user10410	password	61	40000	F
10411	PKUPOC	TWAUFGLJNC	1067882217 Dell Way	\N	YJXTIYX	\N	0	Russia	2	TWAUFGLJNC@dell.com	1067882217	5	8663719629868866	2009/06	user10411	password	32	80000	F
10412	QMQFPJ	BQEGWPPKRO	1477597531 Dell Way	\N	TPHBNFV	\N	0	Germany	2	BQEGWPPKRO@dell.com	1477597531	4	7675916808657349	2010/11	user10412	password	50	60000	M
10413	YESNNT	DSAAHQKZEE	7810820187 Dell Way	\N	OMGCRBP	\N	0	Russia	2	DSAAHQKZEE@dell.com	7810820187	2	3173270000610500	2011/10	user10413	password	75	20000	M
10414	ZWGMQJ	EQKMHULMZA	1474906002 Dell Way	\N	ZFCQHSJ	\N	0	Australia	2	EQKMHULMZA@dell.com	1474906002	4	7073816829826683	2012/05	user10414	password	78	60000	F
10415	RUWIEB	ZOOGIATIAS	4299454975 Dell Way	\N	NDJUVTV	\N	0	South Africa	2	ZOOGIATIAS@dell.com	4299454975	3	7598612430971117	2011/04	user10415	password	38	20000	F
10416	BAIFCH	TQOCQHKRAY	1363350758 Dell Way	\N	UJSQDON	\N	0	France	2	TQOCQHKRAY@dell.com	1363350758	2	3451151472982019	2009/07	user10416	password	49	40000	M
10417	LSVNZP	ENSUVDLVBG	7051800181 Dell Way	\N	FUWIIKV	\N	0	China	2	ENSUVDLVBG@dell.com	7051800181	1	7693941022735090	2009/07	user10417	password	26	100000	M
10418	VRNUHR	IALDDXYFDE	4859640044 Dell Way	\N	ZAMILIS	\N	0	Canada	2	IALDDXYFDE@dell.com	4859640044	3	3999366254080087	2012/07	user10418	password	30	100000	F
10419	WLEDCM	DOPHMOMQSM	9853999589 Dell Way	\N	RFVCONF	\N	0	UK	2	DOPHMOMQSM@dell.com	9853999589	3	9359520032536240	2010/09	user10419	password	80	100000	M
10420	HDSKPW	ZFDMUQDMCU	6986597679 Dell Way	\N	SXXGLCG	\N	0	France	2	ZFDMUQDMCU@dell.com	6986597679	1	9906601731199772	2009/01	user10420	password	86	100000	F
10421	BSTROT	XSFRJIELDW	5796830323 Dell Way	\N	JADVDJG	\N	0	South Africa	2	XSFRJIELDW@dell.com	5796830323	2	2773609269410372	2010/03	user10421	password	30	100000	F
10422	WQXLJU	DPLMYQYCNI	6776352670 Dell Way	\N	CQDGAKB	\N	0	Germany	2	DPLMYQYCNI@dell.com	6776352670	2	1935915077105164	2012/06	user10422	password	90	20000	F
10423	QZSATW	PFJOVIQIQT	4086060806 Dell Way	\N	ZUAZFCO	\N	0	South Africa	2	PFJOVIQIQT@dell.com	4086060806	4	6895048818551005	2011/08	user10423	password	70	20000	F
10424	RUGLRW	QALMJCVZWU	9885321960 Dell Way	\N	UXUZZIV	\N	0	China	2	QALMJCVZWU@dell.com	9885321960	3	1755766193382442	2011/03	user10424	password	28	100000	M
10425	YDHPAY	QMLZOGZLBT	1068776277 Dell Way	\N	IWSHEOP	\N	0	Canada	2	QMLZOGZLBT@dell.com	1068776277	4	8211901831440628	2008/11	user10425	password	68	20000	M
10426	VIJWHZ	ISZXZYJARR	3508401585 Dell Way	\N	WKZBYPG	\N	0	UK	2	ISZXZYJARR@dell.com	3508401585	1	2361742953304201	2008/09	user10426	password	32	100000	M
10427	OGLVGU	OGRNEBNWSK	7406881165 Dell Way	\N	HSLGHRF	\N	0	Germany	2	OGRNEBNWSK@dell.com	7406881165	2	7186690718866885	2010/07	user10427	password	60	100000	F
10428	WKXDEL	JWYNYMKQWR	5169489152 Dell Way	\N	JHXQZCF	\N	0	Japan	2	JWYNYMKQWR@dell.com	5169489152	5	2084290864877402	2008/06	user10428	password	26	20000	F
10429	NALSMV	PKJNXTETLN	3628170759 Dell Way	\N	BJEALKS	\N	0	UK	2	PKJNXTETLN@dell.com	3628170759	5	9420432140119376	2011/12	user10429	password	20	20000	F
10430	BOFNJU	YSIVMNPXBQ	2729485648 Dell Way	\N	GFQSPJQ	\N	0	UK	2	YSIVMNPXBQ@dell.com	2729485648	3	7115368748549373	2008/08	user10430	password	75	80000	M
10431	JVESQC	LYYXLNVMDC	9965124405 Dell Way	\N	SUUIDLG	\N	0	China	2	LYYXLNVMDC@dell.com	9965124405	5	5274270427413285	2011/09	user10431	password	24	40000	F
10432	XLUNNG	MMEYZZKCBD	6600691663 Dell Way	\N	XWMAHSJ	\N	0	Chile	2	MMEYZZKCBD@dell.com	6600691663	5	8848232761025430	2009/12	user10432	password	27	40000	M
10433	OEJCKV	OOTNNEQPIN	8088691094 Dell Way	\N	LUOSMYZ	\N	0	Canada	2	OOTNNEQPIN@dell.com	8088691094	5	4992399663664401	2011/12	user10433	password	78	60000	M
10434	ZYQKTE	YNSMRJCAWN	1872499098 Dell Way	\N	ULGHJGK	\N	0	Canada	2	YNSMRJCAWN@dell.com	1872499098	5	8932341601233930	2008/09	user10434	password	50	80000	M
10435	JHBDMA	REMJNOJKCE	7321306237 Dell Way	\N	VJLFPWJ	\N	0	Japan	2	REMJNOJKCE@dell.com	7321306237	2	7916447334457190	2009/09	user10435	password	47	20000	F
10436	RCFDCW	IPGWEPGHTC	8823250473 Dell Way	\N	QFHFBQW	\N	0	Russia	2	IPGWEPGHTC@dell.com	8823250473	4	2151470247190445	2010/01	user10436	password	30	80000	M
10437	HVXKSF	ZYCENILHLB	8081506449 Dell Way	\N	MSGNJDH	\N	0	Chile	2	ZYCENILHLB@dell.com	8081506449	3	8003939446061850	2012/07	user10437	password	47	60000	M
10438	FMGYRG	WTKKCVSNXE	4473823606 Dell Way	\N	GDSPHZV	\N	0	Australia	2	WTKKCVSNXE@dell.com	4473823606	4	9172717895824464	2012/01	user10438	password	53	100000	F
10439	YBEQIB	KSMMOEALJH	3855834745 Dell Way	\N	PBWWBSY	\N	0	France	2	KSMMOEALJH@dell.com	3855834745	5	4645967454183847	2009/04	user10439	password	34	60000	F
10440	HTXQUH	IHUXMVIVCY	6123168956 Dell Way	\N	XZUYRSK	\N	0	UK	2	IHUXMVIVCY@dell.com	6123168956	5	3822492967825383	2012/01	user10440	password	81	20000	F
10441	QCYKKH	SFEEANACLX	1598649333 Dell Way	\N	BGWTZGT	\N	0	Germany	2	SFEEANACLX@dell.com	1598649333	1	4948913855478168	2008/12	user10441	password	63	60000	M
10442	SJYCRR	IVVIJVLUTN	1286358153 Dell Way	\N	BPGAWZO	\N	0	UK	2	IVVIJVLUTN@dell.com	1286358153	1	1300144569948315	2012/08	user10442	password	51	60000	F
10443	VLLNDT	JYCSUNNOAO	2445787101 Dell Way	\N	DHPAHEY	\N	0	China	2	JYCSUNNOAO@dell.com	2445787101	5	3360407040454447	2011/06	user10443	password	73	20000	F
10444	FOUIIE	HKWCYKQZZU	7475369419 Dell Way	\N	GOUNSTV	\N	0	South Africa	2	HKWCYKQZZU@dell.com	7475369419	1	7001038977410645	2008/11	user10444	password	74	60000	F
10445	IGKQLS	BHUZSKYREF	6972157353 Dell Way	\N	GZSZSOW	\N	0	France	2	BHUZSKYREF@dell.com	6972157353	3	6361764164175839	2010/04	user10445	password	22	60000	M
10446	IZHTRI	BMHTWGKBLR	9868430963 Dell Way	\N	AEQTSME	\N	0	China	2	BMHTWGKBLR@dell.com	9868430963	4	9112168192397804	2009/10	user10446	password	53	100000	F
10447	MEXENY	QVRNBCOMTP	3472478894 Dell Way	\N	QJIJVNT	\N	0	South Africa	2	QVRNBCOMTP@dell.com	3472478894	4	1984114280901849	2008/02	user10447	password	19	40000	M
10448	FDUSBK	NTXPWMBPCS	4829415501 Dell Way	\N	ZLBVYUQ	\N	0	Chile	2	NTXPWMBPCS@dell.com	4829415501	4	3807921050116420	2010/10	user10448	password	58	20000	M
10449	RYSTJG	MHVITXYWPY	2473146040 Dell Way	\N	HRTGLKL	\N	0	South Africa	2	MHVITXYWPY@dell.com	2473146040	4	4808941273484379	2012/04	user10449	password	60	100000	M
10450	NQTWXF	DSOXPNUFLB	5581247229 Dell Way	\N	WEHIPTE	\N	0	Russia	2	DSOXPNUFLB@dell.com	5581247229	4	7311516585759819	2012/03	user10450	password	64	100000	M
10451	HOPETT	WIRMVLSHNO	6884929191 Dell Way	\N	MVWBOBV	\N	0	Australia	2	WIRMVLSHNO@dell.com	6884929191	3	9040371391456576	2012/02	user10451	password	69	60000	F
10452	GDPAXM	IOZEARMNGY	4231792393 Dell Way	\N	ICAXEVZ	\N	0	South Africa	2	IOZEARMNGY@dell.com	4231792393	5	6856533357407898	2010/07	user10452	password	33	100000	M
10453	JOVGBE	UAIUSVIYTR	4510831301 Dell Way	\N	ATOEPNZ	\N	0	UK	2	UAIUSVIYTR@dell.com	4510831301	4	5269297834020108	2012/11	user10453	password	49	80000	F
10454	ZPLBTG	BCBTXKSQBT	6108625969 Dell Way	\N	KPXZDXY	\N	0	Germany	2	BCBTXKSQBT@dell.com	6108625969	3	5233636997640133	2010/11	user10454	password	35	80000	M
10455	VCXOJZ	QKTNULEVEO	9497541248 Dell Way	\N	LCOOANC	\N	0	Germany	2	QKTNULEVEO@dell.com	9497541248	3	9941926394589246	2012/10	user10455	password	63	80000	M
10456	SOEBNU	MGIHSMDWBO	7875932286 Dell Way	\N	YQDYDFN	\N	0	Australia	2	MGIHSMDWBO@dell.com	7875932286	3	9058449140749872	2010/02	user10456	password	58	20000	M
10457	CIXQDJ	XMQPYUMAIK	4394243307 Dell Way	\N	RMJURWX	\N	0	France	2	XMQPYUMAIK@dell.com	4394243307	4	9932314765639604	2010/05	user10457	password	29	40000	F
10458	MGCPQA	BHQABCBKMS	2769675772 Dell Way	\N	WVNOSKZ	\N	0	Australia	2	BHQABCBKMS@dell.com	2769675772	5	6346700228750706	2010/02	user10458	password	87	20000	M
10459	FCFWDH	ETIGVJQHCN	1237859644 Dell Way	\N	DPBVABY	\N	0	Chile	2	ETIGVJQHCN@dell.com	1237859644	3	7722867435775698	2008/06	user10459	password	72	80000	M
10460	WZOZHT	SPZNZQVBDY	3212681135 Dell Way	\N	RFURGSW	\N	0	Chile	2	SPZNZQVBDY@dell.com	3212681135	4	5022068189457059	2011/05	user10460	password	33	60000	F
10461	FZFMSX	BSKAJGCNFT	9392137726 Dell Way	\N	SALZSHH	\N	0	UK	2	BSKAJGCNFT@dell.com	9392137726	4	7242080250289292	2009/12	user10461	password	26	60000	F
10462	CSPVQR	OARXHUKMOC	1671550718 Dell Way	\N	MZCFHJE	\N	0	Chile	2	OARXHUKMOC@dell.com	1671550718	5	5669351701624692	2008/12	user10462	password	21	20000	F
10463	USXKJL	LBISWSEKVQ	9107614643 Dell Way	\N	JXWRGAW	\N	0	China	2	LBISWSEKVQ@dell.com	9107614643	2	4121661691460759	2012/06	user10463	password	52	100000	F
10464	FWPPHA	RQSNJXXEOH	3088993794 Dell Way	\N	CKZJLVS	\N	0	China	2	RQSNJXXEOH@dell.com	3088993794	1	2985357177909463	2011/07	user10464	password	31	100000	M
10465	BMHINY	ZGMIDKNSSP	7106127499 Dell Way	\N	CRYONQX	\N	0	Russia	2	ZGMIDKNSSP@dell.com	7106127499	1	4661959161516279	2008/04	user10465	password	39	100000	F
10466	UFRHEQ	NRZRBMJTBM	1306621459 Dell Way	\N	KABXQYQ	\N	0	China	2	NRZRBMJTBM@dell.com	1306621459	1	5647556100506336	2009/05	user10466	password	49	80000	F
10467	RIKVZY	MYQOLAHMNS	4071600041 Dell Way	\N	MOQDMHL	\N	0	Germany	2	MYQOLAHMNS@dell.com	4071600041	5	8523496785201133	2011/05	user10467	password	53	100000	F
10468	UGXUFJ	SVYDWFQJYD	7094360027 Dell Way	\N	XOGKWSX	\N	0	Chile	2	SVYDWFQJYD@dell.com	7094360027	4	9019607950467616	2008/03	user10468	password	69	20000	F
10469	YAVDKO	ZIRVOIENLC	2397467865 Dell Way	\N	CSMYLKD	\N	0	Canada	2	ZIRVOIENLC@dell.com	2397467865	1	2614429644308984	2009/09	user10469	password	40	60000	M
10470	IGVTUU	CMQRUVEGXG	4354021148 Dell Way	\N	ZKFKVIM	\N	0	UK	2	CMQRUVEGXG@dell.com	4354021148	4	4207390577532351	2008/12	user10470	password	75	100000	F
10471	AQCVLE	HCVCXAJUGI	9192478161 Dell Way	\N	FMTAUGZ	\N	0	Canada	2	HCVCXAJUGI@dell.com	9192478161	2	3623847629409283	2012/02	user10471	password	25	40000	F
10472	TIZFNH	HJKEJTZQCE	5755959702 Dell Way	\N	CVFXBEB	\N	0	UK	2	HJKEJTZQCE@dell.com	5755959702	2	8847956221085043	2011/06	user10472	password	25	100000	F
10473	LUKYBR	HMWRFVHHAK	7678853048 Dell Way	\N	DFHEKJE	\N	0	UK	2	HMWRFVHHAK@dell.com	7678853048	1	6207496904302389	2009/02	user10473	password	46	60000	M
10474	EVNGNV	TKMYFUGGEJ	7846699967 Dell Way	\N	LMOVWST	\N	0	Japan	2	TKMYFUGGEJ@dell.com	7846699967	2	8345386971253903	2012/09	user10474	password	35	60000	M
10475	CZFPVY	ZIWFCDLHMX	8509868845 Dell Way	\N	UBTQUMG	\N	0	Germany	2	ZIWFCDLHMX@dell.com	8509868845	1	5138605531770736	2010/04	user10475	password	86	60000	F
10476	YRZTPZ	BMFEPRLCOF	2521447905 Dell Way	\N	EHWZUCN	\N	0	Japan	2	BMFEPRLCOF@dell.com	2521447905	5	2792871264275163	2010/12	user10476	password	68	100000	M
10477	JVQZVR	MAVBRHEGNI	8297861110 Dell Way	\N	OJHIMVZ	\N	0	Japan	2	MAVBRHEGNI@dell.com	8297861110	1	2173418927006423	2011/11	user10477	password	89	60000	F
10478	VFGQXS	RTUIAYPOHD	6675742704 Dell Way	\N	YPMLKLC	\N	0	Chile	2	RTUIAYPOHD@dell.com	6675742704	2	9582976122852416	2010/03	user10478	password	57	80000	F
10479	TZQQRH	JLQKKFYRJX	6512366881 Dell Way	\N	GVIRHKX	\N	0	UK	2	JLQKKFYRJX@dell.com	6512366881	5	4811362231150270	2012/05	user10479	password	30	100000	F
10480	DLUVTE	HKORQNIZKP	9915133850 Dell Way	\N	VTGDDDB	\N	0	Russia	2	HKORQNIZKP@dell.com	9915133850	3	5938829666469247	2009/08	user10480	password	44	60000	M
10481	VHPPLW	ZANPOWPZLL	1712450407 Dell Way	\N	SSOVWPO	\N	0	South Africa	2	ZANPOWPZLL@dell.com	1712450407	1	3134324669372290	2011/06	user10481	password	73	60000	F
10482	BCXNZW	NMMBJCAVNT	3121638973 Dell Way	\N	OBOKRDH	\N	0	Russia	2	NMMBJCAVNT@dell.com	3121638973	3	5250211419072002	2011/04	user10482	password	88	20000	F
10483	BXVAUJ	NGLXIMTWFH	5470085201 Dell Way	\N	YTSPWZJ	\N	0	Canada	2	NGLXIMTWFH@dell.com	5470085201	5	8420175726059825	2011/10	user10483	password	79	20000	M
10484	TXXNGL	USJDECZJJX	7367506722 Dell Way	\N	CBNZBWC	\N	0	Germany	2	USJDECZJJX@dell.com	7367506722	5	3857659556902945	2010/10	user10484	password	47	40000	M
10485	IHBPTV	HCZLEYUOWX	8996429125 Dell Way	\N	QKWRHZF	\N	0	UK	2	HCZLEYUOWX@dell.com	8996429125	3	5457859960850328	2011/12	user10485	password	81	20000	F
10486	EFVXAC	ZZODYIRVFH	7677781576 Dell Way	\N	FCZNCFM	\N	0	UK	2	ZZODYIRVFH@dell.com	7677781576	5	6559323245659471	2011/11	user10486	password	74	100000	F
10487	ZUXZXW	ZLAYTSTZAZ	9655771531 Dell Way	\N	CZMEFZD	\N	0	UK	2	ZLAYTSTZAZ@dell.com	9655771531	4	6641735324636102	2012/07	user10487	password	59	100000	M
10488	JTNGQN	RRLLJELKEN	6676764232 Dell Way	\N	KQSPQWN	\N	0	Germany	2	RRLLJELKEN@dell.com	6676764232	1	4671723743434996	2008/09	user10488	password	36	80000	F
10489	ZFIQSA	HDLRIWBNKL	7503569113 Dell Way	\N	EDAUZOJ	\N	0	Japan	2	HDLRIWBNKL@dell.com	7503569113	4	8081023643724621	2010/01	user10489	password	53	60000	F
10490	RWQKWY	OHPXEQKPBO	5477360123 Dell Way	\N	SCJRRSH	\N	0	China	2	OHPXEQKPBO@dell.com	5477360123	1	8609423224348576	2010/07	user10490	password	45	60000	F
10491	GERCDF	KSCPINEKBW	9571042589 Dell Way	\N	NKOEDWP	\N	0	Japan	2	KSCPINEKBW@dell.com	9571042589	3	2461235976312309	2010/10	user10491	password	69	80000	F
10492	XLDAQO	STEBGIMIFZ	2647410911 Dell Way	\N	TUEXRTN	\N	0	Japan	2	STEBGIMIFZ@dell.com	2647410911	4	2122493182308972	2012/05	user10492	password	83	20000	F
10493	IEIYTA	SXCYGOHLOA	2055754956 Dell Way	\N	GTXXMLN	\N	0	Japan	2	SXCYGOHLOA@dell.com	2055754956	4	6946121166925878	2010/07	user10493	password	68	100000	M
10494	XDVQEN	OGLUVSGJTN	6014844785 Dell Way	\N	CQKPBXH	\N	0	Canada	2	OGLUVSGJTN@dell.com	6014844785	5	7361848388798536	2008/08	user10494	password	55	100000	M
10495	QTEUGS	BSMWLTGEGJ	2553358125 Dell Way	\N	VRZXOGC	\N	0	Canada	2	BSMWLTGEGJ@dell.com	2553358125	5	2986241125036031	2012/04	user10495	password	29	40000	M
10496	XMTEEV	XRRILYNRIJ	2598441264 Dell Way	\N	IHGXNJA	\N	0	Japan	2	XRRILYNRIJ@dell.com	2598441264	2	5509709835518152	2010/05	user10496	password	77	60000	F
10497	HFNMAK	DSTORGGZPO	7860017105 Dell Way	\N	GWMUGNM	\N	0	France	2	DSTORGGZPO@dell.com	7860017105	5	9265995343681426	2008/10	user10497	password	45	60000	F
10498	PAPQKT	JEIAKOAADH	5916731436 Dell Way	\N	XQBDDOO	\N	0	South Africa	2	JEIAKOAADH@dell.com	5916731436	3	1590478872414678	2009/11	user10498	password	60	60000	F
10499	PBCAUL	ECMPRMPUTM	6651791043 Dell Way	\N	KUQOJEL	\N	0	UK	2	ECMPRMPUTM@dell.com	6651791043	3	3340253902599216	2010/01	user10499	password	71	100000	M
10500	UAROLW	RXLIKBDDNO	1068583112 Dell Way	\N	YECHINE	\N	0	UK	2	RXLIKBDDNO@dell.com	1068583112	3	4828600377775729	2008/03	user10500	password	43	80000	M
10501	JLNVHE	TSNDTQGHEF	2038807221 Dell Way	\N	MHMUURT	\N	0	Russia	2	TSNDTQGHEF@dell.com	2038807221	1	8871549690142275	2009/07	user10501	password	63	40000	M
10502	BTRIYL	BMOVCVDHAP	3507922304 Dell Way	\N	OMJJECE	\N	0	Chile	2	BMOVCVDHAP@dell.com	3507922304	1	6050345234572888	2011/08	user10502	password	76	80000	M
10503	OJANUC	ZIXCDAKEQY	5587924265 Dell Way	\N	QZIUCMB	\N	0	China	2	ZIXCDAKEQY@dell.com	5587924265	4	2612142730038613	2008/06	user10503	password	79	100000	F
10504	FXNZZN	IWPMXZQNYH	8106705652 Dell Way	\N	NGCQTEA	\N	0	Chile	2	IWPMXZQNYH@dell.com	8106705652	1	4659409684129059	2009/01	user10504	password	37	40000	F
10505	DTFDHN	ZWZXWQLUXY	7931377092 Dell Way	\N	BZOUDPA	\N	0	UK	2	ZWZXWQLUXY@dell.com	7931377092	3	2393151809461415	2012/09	user10505	password	46	20000	M
10506	EGZLUZ	HUWDKHYHGZ	3239167031 Dell Way	\N	HUUKJVI	\N	0	Canada	2	HUWDKHYHGZ@dell.com	3239167031	3	9641394128091634	2012/11	user10506	password	18	100000	F
10507	GUMBTU	VQYFYXNEWV	1722658203 Dell Way	\N	ZRGJMPN	\N	0	Russia	2	VQYFYXNEWV@dell.com	1722658203	3	7065114147029818	2012/06	user10507	password	53	20000	M
10508	GNUAHP	RGVPDJUAET	2169955767 Dell Way	\N	RKDDZQW	\N	0	Australia	2	RGVPDJUAET@dell.com	2169955767	3	1284380959346890	2011/01	user10508	password	22	40000	F
10509	ODIWSZ	COPGXJGBDX	5223454737 Dell Way	\N	LHBLYYM	\N	0	Australia	2	COPGXJGBDX@dell.com	5223454737	3	7005745638161898	2010/07	user10509	password	19	80000	F
10510	DCAWCD	KRJHBQIFOU	2812582663 Dell Way	\N	MPFKNRM	\N	0	Australia	2	KRJHBQIFOU@dell.com	2812582663	1	5458775851409883	2011/02	user10510	password	38	100000	F
10511	JYEMBO	ELVGBELPYY	9779921954 Dell Way	\N	FEJTWVT	\N	0	Australia	2	ELVGBELPYY@dell.com	9779921954	2	8486580188851804	2008/07	user10511	password	72	60000	M
10512	RPJTDN	EZTGEFVDDA	7726949259 Dell Way	\N	HNTDINF	\N	0	China	2	EZTGEFVDDA@dell.com	7726949259	1	5065358611289412	2009/10	user10512	password	82	20000	F
10513	MNFPBK	PVQTALWEMD	5761995297 Dell Way	\N	RGHATMI	\N	0	Germany	2	PVQTALWEMD@dell.com	5761995297	4	7938189580570907	2009/09	user10513	password	85	80000	F
10514	LZTMJI	HABILYMYBE	4088099633 Dell Way	\N	EJFYWOL	\N	0	China	2	HABILYMYBE@dell.com	4088099633	2	7295697843190283	2008/02	user10514	password	52	20000	M
10515	MXCWGK	WHSHFFGHKL	1661104763 Dell Way	\N	RPJNDVX	\N	0	France	2	WHSHFFGHKL@dell.com	1661104763	4	5571860662661493	2009/01	user10515	password	66	100000	M
10516	OYKUIG	CBOIHUQRFH	3824344027 Dell Way	\N	GPUKLSX	\N	0	Germany	2	CBOIHUQRFH@dell.com	3824344027	3	7674561341758818	2009/01	user10516	password	59	100000	M
10517	NILVPO	WDXDYNVDUC	8162865635 Dell Way	\N	TPMEIKR	\N	0	Japan	2	WDXDYNVDUC@dell.com	8162865635	3	1233174923807382	2012/01	user10517	password	89	60000	M
10518	IZIXNF	BKJZYFCTHV	2164345521 Dell Way	\N	IUAQESH	\N	0	UK	2	BKJZYFCTHV@dell.com	2164345521	2	8442771291825921	2008/04	user10518	password	43	80000	M
10519	IZNVFO	GONFTQYBMG	5540864929 Dell Way	\N	VMXZEFY	\N	0	China	2	GONFTQYBMG@dell.com	5540864929	4	5045817507430911	2011/02	user10519	password	24	40000	F
10520	BXGGLN	VYSPOQQBXL	1751970599 Dell Way	\N	NVKSAIA	\N	0	Germany	2	VYSPOQQBXL@dell.com	1751970599	3	3719627582468092	2008/07	user10520	password	68	80000	M
10521	OWWAKS	YCHNTXOQIC	4020106150 Dell Way	\N	MSVMBWZ	\N	0	Canada	2	YCHNTXOQIC@dell.com	4020106150	2	3906998146325350	2012/12	user10521	password	85	60000	M
10522	UKOECN	HKBAHPRPSD	9209174920 Dell Way	\N	INQKJQN	\N	0	Russia	2	HKBAHPRPSD@dell.com	9209174920	5	6528220106847585	2012/10	user10522	password	28	60000	M
10523	OATRNA	BOBIESYXWH	1637775152 Dell Way	\N	KMRUCFM	\N	0	Australia	2	BOBIESYXWH@dell.com	1637775152	1	9180265736766160	2012/04	user10523	password	44	60000	M
10524	JDMXEO	LFXQYVNUDY	3978685814 Dell Way	\N	HVSKAFK	\N	0	Australia	2	LFXQYVNUDY@dell.com	3978685814	2	9533415165729822	2010/09	user10524	password	44	60000	F
10525	NXYRLK	XIAWEOQHNY	1702461995 Dell Way	\N	CGIDMTG	\N	0	Russia	2	XIAWEOQHNY@dell.com	1702461995	1	4420223292894662	2011/07	user10525	password	75	100000	F
10526	RTTDDR	LENQSEYGCB	6473858640 Dell Way	\N	MLEYFKS	\N	0	Chile	2	LENQSEYGCB@dell.com	6473858640	1	1405584326945245	2008/11	user10526	password	79	40000	M
10527	PZSSQD	WDTPHSVKTI	1773692171 Dell Way	\N	WXGCIZJ	\N	0	UK	2	WDTPHSVKTI@dell.com	1773692171	3	1895154745317995	2012/04	user10527	password	41	60000	M
10528	HGOYKK	CEAKWWVPER	5885524349 Dell Way	\N	NKTVKDU	\N	0	France	2	CEAKWWVPER@dell.com	5885524349	5	5063961980864406	2012/03	user10528	password	18	80000	M
10529	GELQPO	VQYRMTGQLU	3299709786 Dell Way	\N	BFPLIJX	\N	0	South Africa	2	VQYRMTGQLU@dell.com	3299709786	2	7036755561828614	2010/05	user10529	password	40	100000	M
10530	MKGCYC	SXTFQAVCUW	6017706610 Dell Way	\N	HKHPUFM	\N	0	Australia	2	SXTFQAVCUW@dell.com	6017706610	1	5403250658884645	2012/06	user10530	password	50	60000	M
10531	WUBVWU	SQZJRVLLST	9807632690 Dell Way	\N	VAJQFVR	\N	0	Russia	2	SQZJRVLLST@dell.com	9807632690	1	7173626789357514	2010/08	user10531	password	33	40000	F
10532	AMHWGZ	NGJEBVQTOM	8989060791 Dell Way	\N	TXCZSTT	\N	0	Russia	2	NGJEBVQTOM@dell.com	8989060791	3	2344016510527581	2010/08	user10532	password	58	100000	M
10533	AFOGFB	NPFOKVIYHC	3409208387 Dell Way	\N	WKBPDVH	\N	0	Australia	2	NPFOKVIYHC@dell.com	3409208387	3	5509033554233611	2012/12	user10533	password	50	60000	F
10534	RDGXET	MKIWGRVOTR	9986408161 Dell Way	\N	YVGBQOB	\N	0	UK	2	MKIWGRVOTR@dell.com	9986408161	3	8572148896753789	2012/01	user10534	password	48	100000	M
10535	OGPSAB	DJXJATXTKV	6026967846 Dell Way	\N	PRXGGZE	\N	0	Chile	2	DJXJATXTKV@dell.com	6026967846	1	2997477334458381	2010/06	user10535	password	33	40000	M
10536	MWSNXV	WVFXOCRZYG	6980971548 Dell Way	\N	RWMXVRD	\N	0	China	2	WVFXOCRZYG@dell.com	6980971548	2	9768167873844504	2008/07	user10536	password	36	20000	F
10537	CTOAPL	WUILXZKVGC	5375385097 Dell Way	\N	RSZNKDX	\N	0	Australia	2	WUILXZKVGC@dell.com	5375385097	5	2307175762020051	2008/02	user10537	password	33	20000	F
10538	ZRGOCD	JLOGLZBRBT	1848332403 Dell Way	\N	KBHUEFV	\N	0	Japan	2	JLOGLZBRBT@dell.com	1848332403	5	7600253812968732	2009/03	user10538	password	79	60000	F
10539	NTTQWC	BKIMJKDLEO	2055063302 Dell Way	\N	MLIRRDJ	\N	0	Russia	2	BKIMJKDLEO@dell.com	2055063302	1	9861286798957736	2009/12	user10539	password	51	60000	F
10540	FFCCHE	MPRWAVIEJV	9602494562 Dell Way	\N	QRMHVWA	\N	0	UK	2	MPRWAVIEJV@dell.com	9602494562	1	3130504223052412	2012/06	user10540	password	69	40000	M
10541	XLTEQG	UHDUCLYLGO	8807440951 Dell Way	\N	DTVYPWW	\N	0	Germany	2	UHDUCLYLGO@dell.com	8807440951	1	5133645511232317	2009/10	user10541	password	77	20000	M
10542	HUXXBR	EEMGPKSVZV	7673573010 Dell Way	\N	PVTFRQT	\N	0	Germany	2	EEMGPKSVZV@dell.com	7673573010	2	8909443985205145	2010/01	user10542	password	84	40000	F
10543	SEFTVJ	XHQMSIIRDY	1937463813 Dell Way	\N	MXDEOXS	\N	0	Chile	2	XHQMSIIRDY@dell.com	1937463813	3	8521750097163022	2008/06	user10543	password	25	60000	F
10544	GQXCZV	KPHCYQUCOH	7517600226 Dell Way	\N	ZSLNPDV	\N	0	Japan	2	KPHCYQUCOH@dell.com	7517600226	4	8413344609085471	2009/09	user10544	password	37	40000	F
10545	XHCXCM	NKPLBJNQQN	5707418010 Dell Way	\N	ICBXFWP	\N	0	UK	2	NKPLBJNQQN@dell.com	5707418010	3	2446731880772859	2009/09	user10545	password	58	40000	M
10546	WJMZWA	KLMLVABMOK	3667190576 Dell Way	\N	OPHUMXS	\N	0	UK	2	KLMLVABMOK@dell.com	3667190576	5	3447806255426258	2012/06	user10546	password	58	60000	F
10547	YBGUCQ	GOCCPEODOC	5480475928 Dell Way	\N	SWWFTPF	\N	0	Australia	2	GOCCPEODOC@dell.com	5480475928	3	1340565870516002	2012/01	user10547	password	62	40000	M
10548	RMTTDA	IGCXKQAZTT	6764947624 Dell Way	\N	WQYQGES	\N	0	Russia	2	IGCXKQAZTT@dell.com	6764947624	4	7093253738246859	2011/05	user10548	password	84	80000	F
10549	KKTOKC	UNZFEAFXTC	2712790611 Dell Way	\N	OSTUXLN	\N	0	Germany	2	UNZFEAFXTC@dell.com	2712790611	1	2767809386365115	2010/02	user10549	password	78	60000	M
10550	FIBQKW	DJCHKIEDKS	3043812717 Dell Way	\N	WENTPAH	\N	0	South Africa	2	DJCHKIEDKS@dell.com	3043812717	3	4028840986080468	2009/04	user10550	password	82	100000	M
10551	FXDPUH	ZWOJFTNQMK	9492787955 Dell Way	\N	UZEKALF	\N	0	Chile	2	ZWOJFTNQMK@dell.com	9492787955	3	6190525029785932	2009/06	user10551	password	48	80000	M
10552	IYFDFF	ATPFNCVZNQ	7640736351 Dell Way	\N	ZRAZDFF	\N	0	Australia	2	ATPFNCVZNQ@dell.com	7640736351	5	4016851210035384	2008/03	user10552	password	26	80000	M
10553	BZSGFS	AUYNXTNKJM	5551808987 Dell Way	\N	CKMFPSH	\N	0	China	2	AUYNXTNKJM@dell.com	5551808987	4	5441061394754797	2011/09	user10553	password	37	40000	M
10554	GABMSB	GQPDKCNUPQ	7839287096 Dell Way	\N	EBVUTDD	\N	0	Chile	2	GQPDKCNUPQ@dell.com	7839287096	4	1024421198759227	2010/11	user10554	password	40	40000	F
10555	IJPBLW	RAZCDNWSDB	6193085650 Dell Way	\N	UZVOCZU	\N	0	South Africa	2	RAZCDNWSDB@dell.com	6193085650	5	4276140104047954	2010/02	user10555	password	66	80000	F
10556	AFMLBE	MBGPODISFC	3212023461 Dell Way	\N	RAQTZLP	\N	0	Germany	2	MBGPODISFC@dell.com	3212023461	5	1306504678446799	2009/08	user10556	password	64	100000	M
10557	VHDXLP	YSFNVNFAPW	2845585107 Dell Way	\N	BGQBRFQ	\N	0	UK	2	YSFNVNFAPW@dell.com	2845585107	4	3563490688800812	2012/04	user10557	password	24	60000	F
10558	JQBUGZ	NLNIYSJOOK	7876121554 Dell Way	\N	UEMMKCJ	\N	0	Japan	2	NLNIYSJOOK@dell.com	7876121554	4	5186023030895740	2008/10	user10558	password	90	40000	F
10559	QGYWGL	ITTGLDVANP	2145786076 Dell Way	\N	FZBPCLF	\N	0	South Africa	2	ITTGLDVANP@dell.com	2145786076	4	9288033190183342	2012/09	user10559	password	27	20000	F
10560	KYFQJN	KDUWGPXUFC	6456072175 Dell Way	\N	THSWTXS	\N	0	South Africa	2	KDUWGPXUFC@dell.com	6456072175	4	7792492925655098	2009/10	user10560	password	73	60000	F
10561	SUVBHF	FCCLRZFXBZ	2770656157 Dell Way	\N	ETWYROU	\N	0	Chile	2	FCCLRZFXBZ@dell.com	2770656157	3	6095910618081689	2012/04	user10561	password	29	20000	F
10562	YYCGEH	IGSAGYYHYC	4515735054 Dell Way	\N	BUATIVA	\N	0	Germany	2	IGSAGYYHYC@dell.com	4515735054	3	5550620991270990	2011/10	user10562	password	64	80000	M
10563	PUYTBH	AUIGTGORJP	9639954892 Dell Way	\N	LKJUGJI	\N	0	Japan	2	AUIGTGORJP@dell.com	9639954892	5	4006780948489904	2011/06	user10563	password	21	60000	F
10564	VJUXRU	SABLGPCQFO	5787499991 Dell Way	\N	AOJGYRX	\N	0	South Africa	2	SABLGPCQFO@dell.com	5787499991	2	6392682930454612	2008/04	user10564	password	19	20000	F
10565	KWABRT	BSEIIHYNWZ	4121056744 Dell Way	\N	BFGAXDX	\N	0	France	2	BSEIIHYNWZ@dell.com	4121056744	3	4884175974875689	2011/07	user10565	password	53	80000	M
10566	JUYANA	SSJAZHOVGQ	9971705096 Dell Way	\N	ANQYQNJ	\N	0	UK	2	SSJAZHOVGQ@dell.com	9971705096	4	6331285435240716	2010/04	user10566	password	42	40000	M
10567	CIQQJJ	ISJHAYDHOE	2884637509 Dell Way	\N	UECKRLJ	\N	0	Japan	2	ISJHAYDHOE@dell.com	2884637509	5	2545782900881022	2010/04	user10567	password	58	20000	F
10568	XSBHCJ	ZMRAKUHYYC	8578814349 Dell Way	\N	CAMULWL	\N	0	Japan	2	ZMRAKUHYYC@dell.com	8578814349	4	2276176822837442	2008/03	user10568	password	35	60000	F
10569	ZPJBYJ	NQJXKRWITY	8401858962 Dell Way	\N	JGTVCFM	\N	0	UK	2	NQJXKRWITY@dell.com	8401858962	4	1869821851141750	2008/11	user10569	password	66	20000	M
10570	GMWFVK	VFHGWEPQCY	8641097753 Dell Way	\N	WWTZBGX	\N	0	South Africa	2	VFHGWEPQCY@dell.com	8641097753	1	8901273716706783	2011/09	user10570	password	89	60000	M
10571	MKEHVA	NDGKHVAKUX	8274857027 Dell Way	\N	GNWHTUD	\N	0	Japan	2	NDGKHVAKUX@dell.com	8274857027	1	3871203149203211	2010/01	user10571	password	80	60000	F
10572	HPUCPH	FWSMSTWMQD	6111535478 Dell Way	\N	ANKTHOJ	\N	0	Canada	2	FWSMSTWMQD@dell.com	6111535478	4	6375782872084529	2010/07	user10572	password	19	20000	M
10573	QVXGDD	CVQUPNHFQH	2036307851 Dell Way	\N	SABAOKD	\N	0	Canada	2	CVQUPNHFQH@dell.com	2036307851	4	7366958587896080	2011/10	user10573	password	73	60000	F
10574	PKQSOT	OENDRUJHCC	9951950513 Dell Way	\N	IDCWOGA	\N	0	Japan	2	OENDRUJHCC@dell.com	9951950513	4	3905197076499462	2011/06	user10574	password	77	20000	F
10575	GUUUNJ	YBMQVVYYYG	8824457308 Dell Way	\N	BBDPHDG	\N	0	Chile	2	YBMQVVYYYG@dell.com	8824457308	3	1468379039317369	2009/05	user10575	password	32	60000	M
10576	ZFKMOJ	OBZKXYIVEJ	7759536028 Dell Way	\N	WIYEMEL	\N	0	China	2	OBZKXYIVEJ@dell.com	7759536028	3	7229400438256562	2008/09	user10576	password	25	80000	M
10577	IDEWMT	XMDVKLQPUM	6389280003 Dell Way	\N	XTQKXCT	\N	0	Japan	2	XMDVKLQPUM@dell.com	6389280003	3	8257246657740326	2009/07	user10577	password	58	100000	M
10578	SESFXQ	RALCMCSGOQ	2760888096 Dell Way	\N	ZFAXITP	\N	0	UK	2	RALCMCSGOQ@dell.com	2760888096	2	2980213321279734	2011/12	user10578	password	33	60000	M
10579	KIWIZN	JKQVMICBYC	9813844828 Dell Way	\N	HYZPSPN	\N	0	UK	2	JKQVMICBYC@dell.com	9813844828	4	6801848010625691	2012/12	user10579	password	35	60000	F
10580	OLRNYB	YPWLXYNVAU	6846903422 Dell Way	\N	UAKMPXK	\N	0	Germany	2	YPWLXYNVAU@dell.com	6846903422	1	5677489259745926	2011/04	user10580	password	25	100000	M
10581	NQJMRH	BOTYMGUNAO	5513567531 Dell Way	\N	OLBEILT	\N	0	UK	2	BOTYMGUNAO@dell.com	5513567531	2	6302935806103051	2011/05	user10581	password	58	80000	M
10582	FZJWHL	LAJYHELITA	2959824974 Dell Way	\N	TUEBGYB	\N	0	Russia	2	LAJYHELITA@dell.com	2959824974	4	5849305877927691	2010/03	user10582	password	30	60000	F
10583	EWGLHR	MRPTWBBPCV	6127274513 Dell Way	\N	KGWQFYK	\N	0	France	2	MRPTWBBPCV@dell.com	6127274513	5	1082970778923481	2011/02	user10583	password	54	20000	F
10584	JKSRCF	JSZFUBVWWF	2628258359 Dell Way	\N	DTWIRGT	\N	0	Chile	2	JSZFUBVWWF@dell.com	2628258359	4	9940718059428036	2009/03	user10584	password	28	60000	M
10585	OGHRLR	KKXEMSBIYE	9726764025 Dell Way	\N	BUMSAFY	\N	0	Chile	2	KKXEMSBIYE@dell.com	9726764025	5	5447365348692984	2009/02	user10585	password	20	100000	M
10586	HDITVS	ETXQLYYKCA	6405694741 Dell Way	\N	EPSFVRL	\N	0	Russia	2	ETXQLYYKCA@dell.com	6405694741	5	1125173539854586	2011/12	user10586	password	80	40000	F
10587	AQZVJD	OGTAFSKHSP	2359489436 Dell Way	\N	XKUSCGN	\N	0	Japan	2	OGTAFSKHSP@dell.com	2359489436	3	4265662649646402	2008/05	user10587	password	68	40000	F
10588	JIGSLU	ZEVEWGLPVJ	2360667798 Dell Way	\N	ZQCBWPT	\N	0	Australia	2	ZEVEWGLPVJ@dell.com	2360667798	1	2122334139887243	2010/10	user10588	password	51	100000	F
10589	UEWFZV	KUZHBLWWUW	8267857191 Dell Way	\N	NXYJMRK	\N	0	Japan	2	KUZHBLWWUW@dell.com	8267857191	3	2779319596011191	2011/12	user10589	password	28	80000	M
10590	IQZIMJ	CLQEXMASJN	8618453643 Dell Way	\N	PHXCZIT	\N	0	Russia	2	CLQEXMASJN@dell.com	8618453643	5	4714490212500096	2012/01	user10590	password	31	60000	F
10591	VOSIYV	UOZRBAJKOY	7362670976 Dell Way	\N	SMASUUM	\N	0	Japan	2	UOZRBAJKOY@dell.com	7362670976	5	5229250638745725	2011/02	user10591	password	22	20000	M
10592	QXGOTA	DTRETBPIAI	4890043193 Dell Way	\N	UBAOVNF	\N	0	Germany	2	DTRETBPIAI@dell.com	4890043193	4	3757961634080857	2010/09	user10592	password	54	60000	F
10593	KSYESB	XKGRMWZMET	2765678115 Dell Way	\N	NFIISNV	\N	0	Canada	2	XKGRMWZMET@dell.com	2765678115	1	7228178260382266	2012/08	user10593	password	29	40000	F
10594	WFGPHE	ANVMJVYOPL	7836113150 Dell Way	\N	TYUMLPQ	\N	0	Japan	2	ANVMJVYOPL@dell.com	7836113150	2	6224412980489433	2010/06	user10594	password	82	60000	F
10595	CSZKWZ	XSMHOKVDWO	1075311387 Dell Way	\N	BQBNGRE	\N	0	Australia	2	XSMHOKVDWO@dell.com	1075311387	4	4878153292462230	2010/08	user10595	password	84	100000	M
10596	QVDNUB	GGIURDYOSA	5191858428 Dell Way	\N	FTNMLSM	\N	0	France	2	GGIURDYOSA@dell.com	5191858428	5	9440491497050972	2008/10	user10596	password	75	100000	F
10597	PZZKAF	RIAJMYXFYD	1038581879 Dell Way	\N	YMPJFCV	\N	0	Japan	2	RIAJMYXFYD@dell.com	1038581879	4	7996250604745001	2012/07	user10597	password	63	40000	F
10598	PGPQMH	ZMQLLORKRP	6199655587 Dell Way	\N	XHZCJVU	\N	0	China	2	ZMQLLORKRP@dell.com	6199655587	3	2784931259229779	2008/03	user10598	password	53	40000	M
10599	TXKGEJ	SVVDJMOBCL	8847452066 Dell Way	\N	ICNSXIB	\N	0	France	2	SVVDJMOBCL@dell.com	8847452066	2	6477442780509592	2008/09	user10599	password	84	100000	M
10600	VGTZQM	ULPEYEFAPO	6216111468 Dell Way	\N	CDGALIM	\N	0	China	2	ULPEYEFAPO@dell.com	6216111468	1	4292383314576000	2009/01	user10600	password	32	100000	M
10601	LPVBBP	NQULVAMKOP	2426983794 Dell Way	\N	NVPZEBH	\N	0	Russia	2	NQULVAMKOP@dell.com	2426983794	4	1584224350750446	2008/11	user10601	password	83	100000	F
10602	MUINKV	EEHZETJTIX	8265340080 Dell Way	\N	PXWTZEM	\N	0	Canada	2	EEHZETJTIX@dell.com	8265340080	3	3793428509030491	2011/06	user10602	password	39	100000	M
10603	CHLMCQ	RJPWDZQLWF	1325017507 Dell Way	\N	JTZJXMN	\N	0	Russia	2	RJPWDZQLWF@dell.com	1325017507	5	4374807631131262	2010/02	user10603	password	40	60000	F
10604	PXSSNJ	CCGFCWRZCB	7562414511 Dell Way	\N	TCKQOXJ	\N	0	Japan	2	CCGFCWRZCB@dell.com	7562414511	4	1848817619029432	2012/01	user10604	password	56	20000	M
10605	KTIXDK	AJQDFHCIIV	6178851067 Dell Way	\N	KTMZQVO	\N	0	China	2	AJQDFHCIIV@dell.com	6178851067	4	2943268201313913	2011/03	user10605	password	37	40000	M
10606	APNDAO	MQRSYUAGPL	6751043992 Dell Way	\N	ZBKQXZA	\N	0	France	2	MQRSYUAGPL@dell.com	6751043992	2	2003388240933418	2012/06	user10606	password	45	60000	F
10607	ZYQZMC	QEVOYVVNHV	7021055880 Dell Way	\N	PRLNQLZ	\N	0	Chile	2	QEVOYVVNHV@dell.com	7021055880	1	2079928976949304	2008/06	user10607	password	57	80000	F
10608	MHLZKC	DFRCBMPIHF	8501176849 Dell Way	\N	ZSSQESY	\N	0	South Africa	2	DFRCBMPIHF@dell.com	8501176849	1	9980571192689240	2009/08	user10608	password	65	80000	F
10609	YGCIIG	NZIOMYWTDW	5618017728 Dell Way	\N	MWNQPLM	\N	0	France	2	NZIOMYWTDW@dell.com	5618017728	3	7811766378581525	2008/02	user10609	password	57	40000	F
10610	UHJDNX	CWLPUIIYEV	5058561671 Dell Way	\N	VRMKDYW	\N	0	Japan	2	CWLPUIIYEV@dell.com	5058561671	4	7988925064448268	2010/02	user10610	password	90	80000	M
10611	HABVYE	RJTMRCKWXF	1790150952 Dell Way	\N	OJQRIMI	\N	0	Russia	2	RJTMRCKWXF@dell.com	1790150952	1	4274950401857495	2009/02	user10611	password	19	20000	F
10612	BFGZKY	JDKAGVWDAK	6014077447 Dell Way	\N	MQCVDLP	\N	0	Chile	2	JDKAGVWDAK@dell.com	6014077447	5	5117018778342754	2011/12	user10612	password	63	20000	F
10613	WIAGGJ	KRKQMHUNRH	6825976073 Dell Way	\N	EUCHFSN	\N	0	Russia	2	KRKQMHUNRH@dell.com	6825976073	5	5115357103757560	2011/08	user10613	password	57	80000	F
10614	WRSDBD	VLUHTOVLVZ	8213683840 Dell Way	\N	FYHLQVG	\N	0	Chile	2	VLUHTOVLVZ@dell.com	8213683840	4	9139836460817606	2010/03	user10614	password	59	100000	F
10615	GPGISB	UMJNBEYXEE	5721232304 Dell Way	\N	VMPLHVT	\N	0	Australia	2	UMJNBEYXEE@dell.com	5721232304	4	5584785087965429	2011/03	user10615	password	46	100000	F
10616	ZCUSDO	FNCGRADWEZ	8295593416 Dell Way	\N	IULQQET	\N	0	Canada	2	FNCGRADWEZ@dell.com	8295593416	2	9058024429716172	2008/08	user10616	password	72	60000	M
10617	VHIZWN	MYUEYYADXJ	9846103689 Dell Way	\N	XIANMTR	\N	0	China	2	MYUEYYADXJ@dell.com	9846103689	3	3957571343984455	2011/04	user10617	password	77	40000	F
10618	CODYBQ	WWUVUVZREX	7093788398 Dell Way	\N	AELMYCU	\N	0	UK	2	WWUVUVZREX@dell.com	7093788398	1	5742789729498327	2012/12	user10618	password	72	20000	F
10619	HHZJXW	FSSANRRSOR	2124200374 Dell Way	\N	XZEVCZT	\N	0	Russia	2	FSSANRRSOR@dell.com	2124200374	2	7903358648996801	2008/01	user10619	password	85	20000	F
10620	FDSDZY	WSYKJQCYHA	8975535660 Dell Way	\N	XMWAMPU	\N	0	Germany	2	WSYKJQCYHA@dell.com	8975535660	3	7097750692162663	2012/06	user10620	password	76	40000	M
10621	YZVYXS	QVCZLEYTFW	2685093936 Dell Way	\N	GBWSQQI	\N	0	Germany	2	QVCZLEYTFW@dell.com	2685093936	5	5139680858701468	2011/10	user10621	password	70	40000	M
10622	RFROXH	KZHWEFPJBV	8647559848 Dell Way	\N	KYOBOWP	\N	0	Russia	2	KZHWEFPJBV@dell.com	8647559848	1	4695109056308866	2011/10	user10622	password	73	40000	F
10623	ZAAWHL	VPHAUXJWTU	5783154938 Dell Way	\N	UHWJEMC	\N	0	Australia	2	VPHAUXJWTU@dell.com	5783154938	3	6977241446729750	2009/04	user10623	password	20	80000	F
10624	BUCJGY	YOYTLIPFDK	4095855894 Dell Way	\N	NZTRLVS	\N	0	UK	2	YOYTLIPFDK@dell.com	4095855894	2	3657923330552876	2011/05	user10624	password	22	100000	F
10625	WZVCXT	RWNCFDHINU	5875352289 Dell Way	\N	IGMTCET	\N	0	France	2	RWNCFDHINU@dell.com	5875352289	1	1440820230171084	2012/02	user10625	password	84	40000	M
10626	WFCUZT	QMWWPEEDYM	1507943851 Dell Way	\N	JLGLQAX	\N	0	Canada	2	QMWWPEEDYM@dell.com	1507943851	5	1912874293979257	2008/11	user10626	password	53	20000	M
10627	SGMRAD	EWZUAEXZRH	6081380886 Dell Way	\N	LYTBYQF	\N	0	UK	2	EWZUAEXZRH@dell.com	6081380886	2	2456042561680078	2010/10	user10627	password	40	20000	M
10628	OQEOTI	LTCLYALPHW	4867845533 Dell Way	\N	NAXLQDL	\N	0	Canada	2	LTCLYALPHW@dell.com	4867845533	4	6467838309705258	2009/12	user10628	password	71	80000	F
10629	JXBDGN	XIYVIKKPGY	4831206391 Dell Way	\N	QEJGHVL	\N	0	Russia	2	XIYVIKKPGY@dell.com	4831206391	1	9519281051587314	2009/10	user10629	password	67	100000	F
10630	PXHVKE	EJANTKDAIT	5442564835 Dell Way	\N	ESZLOLE	\N	0	UK	2	EJANTKDAIT@dell.com	5442564835	1	3810037367511541	2009/10	user10630	password	28	60000	F
10631	BTFLYJ	UYXOJAOSTT	5442715056 Dell Way	\N	KTFYFJY	\N	0	Japan	2	UYXOJAOSTT@dell.com	5442715056	2	9806870251428336	2009/05	user10631	password	48	80000	F
10632	EXWCHR	AEFJEUBYNM	6526138218 Dell Way	\N	SSLXCJP	\N	0	Germany	2	AEFJEUBYNM@dell.com	6526138218	3	8820389864034952	2012/01	user10632	password	58	60000	F
10633	LHGSYG	XEQCYSALFT	8531393606 Dell Way	\N	EQQGAGV	\N	0	Japan	2	XEQCYSALFT@dell.com	8531393606	4	6725403741933406	2012/03	user10633	password	22	100000	M
10634	JGKINI	MDKKWLWBEA	7896767853 Dell Way	\N	SVHSCCJ	\N	0	UK	2	MDKKWLWBEA@dell.com	7896767853	5	7887566129211337	2008/01	user10634	password	73	80000	F
10635	ACSNKF	RVQNGMOKNG	3736197071 Dell Way	\N	GUYIWIH	\N	0	Japan	2	RVQNGMOKNG@dell.com	3736197071	1	6850304652005435	2009/10	user10635	password	42	80000	M
10636	LMIVRZ	QHMXUAIIHO	3026850792 Dell Way	\N	DGXZOEQ	\N	0	South Africa	2	QHMXUAIIHO@dell.com	3026850792	2	2913858433254063	2008/08	user10636	password	89	100000	F
10637	LEXDDO	LQLFRUOYIR	6464220730 Dell Way	\N	FGRTLIP	\N	0	Japan	2	LQLFRUOYIR@dell.com	6464220730	5	7321971383877099	2009/10	user10637	password	57	40000	F
10638	SFJWUV	MGAEAPDJGI	5283125866 Dell Way	\N	PXBBFRT	\N	0	South Africa	2	MGAEAPDJGI@dell.com	5283125866	3	1461678931489586	2009/12	user10638	password	44	60000	M
10639	PXOJSA	PTEPIIYOQO	8257513374 Dell Way	\N	LRQQIJM	\N	0	South Africa	2	PTEPIIYOQO@dell.com	8257513374	3	1742834459058940	2011/11	user10639	password	61	60000	F
10640	MAVFBK	YGAGOYVENG	9031362991 Dell Way	\N	VDXENJZ	\N	0	China	2	YGAGOYVENG@dell.com	9031362991	1	1940037146210670	2011/09	user10640	password	60	40000	F
10641	PAJQLH	WLOKKJOXQK	6945014634 Dell Way	\N	BNPOXPW	\N	0	South Africa	2	WLOKKJOXQK@dell.com	6945014634	5	6155392429325730	2009/07	user10641	password	75	60000	F
10642	VWUGDQ	SSBCBPARAB	5466349076 Dell Way	\N	FPQDENY	\N	0	South Africa	2	SSBCBPARAB@dell.com	5466349076	3	2572610108181834	2008/04	user10642	password	67	40000	F
10643	NAJRQC	KSELIEDIFJ	9343433081 Dell Way	\N	XWMCJKY	\N	0	South Africa	2	KSELIEDIFJ@dell.com	9343433081	1	9244619625620544	2009/10	user10643	password	27	40000	F
10644	DTAUVK	MZVUDZDJIB	2757390504 Dell Way	\N	FUDPFCL	\N	0	Canada	2	MZVUDZDJIB@dell.com	2757390504	2	4248067316599190	2012/06	user10644	password	70	40000	M
10645	LHKHSX	GNSKMVUUWA	4588571194 Dell Way	\N	PAPUCBX	\N	0	China	2	GNSKMVUUWA@dell.com	4588571194	2	3591700478456914	2012/12	user10645	password	61	60000	F
10646	XYSPWZ	COKPKFKHFZ	9784981514 Dell Way	\N	IVULWST	\N	0	Chile	2	COKPKFKHFZ@dell.com	9784981514	1	2341725954320282	2012/08	user10646	password	66	60000	M
10647	PECMDF	AOVLTFTYFB	3173230081 Dell Way	\N	TZMQRFX	\N	0	Japan	2	AOVLTFTYFB@dell.com	3173230081	1	6556001769844443	2012/09	user10647	password	21	40000	F
10648	FLUIRU	XMGQRZOWAI	9133819863 Dell Way	\N	WNZNSWE	\N	0	UK	2	XMGQRZOWAI@dell.com	9133819863	4	8421102471183986	2011/10	user10648	password	31	100000	F
10649	QSJING	UTXMTMJTVF	7059813024 Dell Way	\N	HUSAQXZ	\N	0	Germany	2	UTXMTMJTVF@dell.com	7059813024	4	2456677562091499	2010/12	user10649	password	24	60000	M
10650	UXYHES	BBEUNNOITV	6354966838 Dell Way	\N	CMVTJUH	\N	0	Australia	2	BBEUNNOITV@dell.com	6354966838	3	5794785994105042	2010/07	user10650	password	22	40000	F
10651	ZDQDWS	EBMSPBAIWD	6994163193 Dell Way	\N	USXDMFE	\N	0	Australia	2	EBMSPBAIWD@dell.com	6994163193	4	7035666178446264	2009/10	user10651	password	81	60000	M
10652	AFWWXB	XKTMLUVIXP	6926085794 Dell Way	\N	AUTNZYP	\N	0	Japan	2	XKTMLUVIXP@dell.com	6926085794	2	8893831077031792	2010/02	user10652	password	50	20000	F
10653	RBBPCZ	ZVMLPHTNXU	2868640462 Dell Way	\N	HRIHPYY	\N	0	Chile	2	ZVMLPHTNXU@dell.com	2868640462	5	7316716022789479	2009/04	user10653	password	81	60000	M
10654	XPNAOM	WAYLISZFMH	4012115036 Dell Way	\N	WUOMSNT	\N	0	UK	2	WAYLISZFMH@dell.com	4012115036	3	3745017699897289	2011/04	user10654	password	79	60000	F
10655	LBGZOC	AMOIEONRVK	1954765788 Dell Way	\N	MKXFXQE	\N	0	Chile	2	AMOIEONRVK@dell.com	1954765788	3	8526508629322053	2010/04	user10655	password	45	80000	M
10656	KYTYBT	LQCQEQIAAV	7095688207 Dell Way	\N	KYBHPFN	\N	0	Japan	2	LQCQEQIAAV@dell.com	7095688207	2	2155394038185477	2012/09	user10656	password	77	80000	F
10657	TMCVGO	MIERYNRZIB	2908421054 Dell Way	\N	XJINPWF	\N	0	Chile	2	MIERYNRZIB@dell.com	2908421054	2	3310304511804134	2012/02	user10657	password	18	20000	M
10658	METTTF	BYWALNATPY	9657543193 Dell Way	\N	DXLTUQZ	\N	0	UK	2	BYWALNATPY@dell.com	9657543193	2	9341138820629568	2008/04	user10658	password	18	20000	M
10659	FTMYZO	WWOHJPBZNF	2754826589 Dell Way	\N	WYYRPYQ	\N	0	Germany	2	WWOHJPBZNF@dell.com	2754826589	3	6941207552794368	2010/07	user10659	password	67	20000	M
10660	LRSKFO	GUWQKYPXDM	4256122736 Dell Way	\N	WCDMAUA	\N	0	Chile	2	GUWQKYPXDM@dell.com	4256122736	4	7009601661469788	2012/05	user10660	password	81	80000	M
10661	OLFUAL	PWCZUSWYET	9215021415 Dell Way	\N	AIFBCGG	\N	0	France	2	PWCZUSWYET@dell.com	9215021415	5	4767360324040055	2009/10	user10661	password	28	20000	F
10662	PGCPSR	MURHMOFRHG	5575067888 Dell Way	\N	ANHCTOP	\N	0	Japan	2	MURHMOFRHG@dell.com	5575067888	1	9307930076494814	2009/02	user10662	password	89	80000	M
10663	GTIYLU	TCBGQHXYOX	6668365238 Dell Way	\N	LWAFKQW	\N	0	UK	2	TCBGQHXYOX@dell.com	6668365238	4	3128223046194762	2011/10	user10663	password	82	60000	M
10664	QVYCQR	FSXWZVUNTG	1868398805 Dell Way	\N	JULUKIS	\N	0	Australia	2	FSXWZVUNTG@dell.com	1868398805	5	8328105708118529	2012/11	user10664	password	41	100000	F
10665	EUPULU	MJQLELZYSJ	8729904432 Dell Way	\N	SEEDMXD	\N	0	Germany	2	MJQLELZYSJ@dell.com	8729904432	5	4958347272593528	2011/04	user10665	password	38	40000	F
10666	BUFMPS	WFEARDYKNR	9125641066 Dell Way	\N	ORUBPYQ	\N	0	France	2	WFEARDYKNR@dell.com	9125641066	1	2318816901184618	2008/05	user10666	password	43	80000	F
10667	DWXSOT	YSUQWTAKLO	3924525062 Dell Way	\N	CFPRDGC	\N	0	Australia	2	YSUQWTAKLO@dell.com	3924525062	2	3218809249345213	2011/08	user10667	password	82	20000	M
10668	TALIUJ	BOAYIAITOK	4828442441 Dell Way	\N	YEBCLEE	\N	0	Russia	2	BOAYIAITOK@dell.com	4828442441	3	5001968054566533	2008/04	user10668	password	57	80000	F
10669	OFJIPK	WPIFPRYEBX	6205214964 Dell Way	\N	JDAUIEO	\N	0	Russia	2	WPIFPRYEBX@dell.com	6205214964	5	7951978729106487	2012/07	user10669	password	56	100000	F
10670	SHKHSH	XAMMSKQUIZ	3807277743 Dell Way	\N	YIUGMIA	\N	0	Australia	2	XAMMSKQUIZ@dell.com	3807277743	4	9514231918845328	2012/04	user10670	password	81	100000	F
10671	DIIVPF	WCSONIJVIH	3691491704 Dell Way	\N	DCNQLNS	\N	0	Russia	2	WCSONIJVIH@dell.com	3691491704	4	6236271692905576	2010/07	user10671	password	54	80000	M
10672	VYNLEK	NWZAFIWOPZ	1225770275 Dell Way	\N	QCQBQJV	\N	0	UK	2	NWZAFIWOPZ@dell.com	1225770275	2	5815029170364142	2010/11	user10672	password	29	40000	M
10673	CTEHDR	DCSJKOXZON	8268653116 Dell Way	\N	CEPTOKR	\N	0	Germany	2	DCSJKOXZON@dell.com	8268653116	2	2168189855758101	2011/05	user10673	password	44	60000	F
10674	CPTFHX	IZGSNDSCRV	5021475194 Dell Way	\N	HHOVSGK	\N	0	Germany	2	IZGSNDSCRV@dell.com	5021475194	3	2900432263035327	2012/11	user10674	password	64	40000	M
10675	GAFNYN	MEGAHZDZUK	2318370053 Dell Way	\N	GIFYOPM	\N	0	Australia	2	MEGAHZDZUK@dell.com	2318370053	4	8525532900355757	2008/04	user10675	password	27	20000	M
10676	EGCCUO	GAPOZSOUCV	9202358593 Dell Way	\N	DITRYGS	\N	0	Australia	2	GAPOZSOUCV@dell.com	9202358593	3	2116214235778898	2009/09	user10676	password	28	80000	M
10677	JWYDLE	EBTEUHYXCB	1155488276 Dell Way	\N	FWTECMG	\N	0	Australia	2	EBTEUHYXCB@dell.com	1155488276	2	3275678769219667	2011/07	user10677	password	21	60000	M
10678	XLBJQF	KKKFRJCUKI	1907810543 Dell Way	\N	REMUQSU	\N	0	Japan	2	KKKFRJCUKI@dell.com	1907810543	1	4096630256623030	2011/02	user10678	password	81	60000	F
10679	IPJYVU	JFZBOCVZKN	2339879706 Dell Way	\N	DWHUPCL	\N	0	Japan	2	JFZBOCVZKN@dell.com	2339879706	4	3860130365937948	2009/08	user10679	password	79	40000	M
10680	LQXGLH	LLIANEZYRC	1619527543 Dell Way	\N	UYWKBHC	\N	0	Chile	2	LLIANEZYRC@dell.com	1619527543	3	5079228976275772	2011/03	user10680	password	70	80000	M
10681	JPXVWJ	GEJUIISAKM	4339218560 Dell Way	\N	ZHXAPZF	\N	0	Japan	2	GEJUIISAKM@dell.com	4339218560	4	4384835543110967	2011/05	user10681	password	21	40000	M
10682	QEPNNV	RWPAFIAQVA	9412045136 Dell Way	\N	XSANRGE	\N	0	Australia	2	RWPAFIAQVA@dell.com	9412045136	3	6896573880687357	2009/08	user10682	password	86	20000	F
10683	DRTRNL	ODMTLNJGNH	5912626248 Dell Way	\N	YOUPUZQ	\N	0	Russia	2	ODMTLNJGNH@dell.com	5912626248	2	1624214058741927	2008/03	user10683	password	30	60000	F
10684	WEAJPO	MCHXPRDCYC	6923047019 Dell Way	\N	QTSLSJE	\N	0	Chile	2	MCHXPRDCYC@dell.com	6923047019	2	4801599275320769	2012/06	user10684	password	78	40000	F
10685	ZHQPWC	REAGVDJUGA	9218417989 Dell Way	\N	NYMGHRN	\N	0	UK	2	REAGVDJUGA@dell.com	9218417989	5	8737688680645079	2009/10	user10685	password	27	80000	M
10686	LGIIIZ	MJGINPDTQQ	4109265041 Dell Way	\N	SCXZTKY	\N	0	Japan	2	MJGINPDTQQ@dell.com	4109265041	5	9927547595929356	2008/12	user10686	password	62	100000	F
10687	WERFEE	OKNBAQUQHM	3219090994 Dell Way	\N	SEMLPLC	\N	0	UK	2	OKNBAQUQHM@dell.com	3219090994	1	1302815295755863	2008/09	user10687	password	82	60000	M
10688	BGTGLI	RYJRPEIWRB	7487816633 Dell Way	\N	ADNPPQO	\N	0	South Africa	2	RYJRPEIWRB@dell.com	7487816633	3	1191713072825223	2010/06	user10688	password	61	100000	M
10689	WTUHBL	GLDVPLRGMS	5013300341 Dell Way	\N	KAIZQWV	\N	0	China	2	GLDVPLRGMS@dell.com	5013300341	5	7949450638145209	2012/06	user10689	password	73	60000	F
10690	NFOPQU	AUQPFIWSAG	9031510068 Dell Way	\N	SJGIGBR	\N	0	Japan	2	AUQPFIWSAG@dell.com	9031510068	3	6256034330464900	2009/03	user10690	password	19	60000	M
10691	FEIWZI	QPYWXUPYBH	7967199360 Dell Way	\N	HHQNIIF	\N	0	Chile	2	QPYWXUPYBH@dell.com	7967199360	4	5975747784134001	2012/10	user10691	password	29	80000	F
10692	IBXHKO	WILUDASEIA	5547875792 Dell Way	\N	LZNUHSA	\N	0	Australia	2	WILUDASEIA@dell.com	5547875792	3	1561175722163170	2009/09	user10692	password	75	40000	F
10693	VGIGVF	OGZRHSVPSH	7141594788 Dell Way	\N	PFCWYCY	\N	0	France	2	OGZRHSVPSH@dell.com	7141594788	1	7807892765849829	2010/10	user10693	password	25	60000	M
10694	JUWEZL	LZCSRYIJGX	7829477712 Dell Way	\N	PIUNLTZ	\N	0	Canada	2	LZCSRYIJGX@dell.com	7829477712	4	5769382398575545	2010/10	user10694	password	89	40000	F
10695	TCJTNU	SQNKPVTWTI	6189132619 Dell Way	\N	EOWQHVT	\N	0	Australia	2	SQNKPVTWTI@dell.com	6189132619	2	6489343201275916	2010/04	user10695	password	78	60000	F
10696	XZTLTM	CHWSCQOWZT	4260186513 Dell Way	\N	KVJSRCT	\N	0	Chile	2	CHWSCQOWZT@dell.com	4260186513	2	6962182255461813	2011/03	user10696	password	36	80000	F
10697	FKOZWQ	GTJJJXGIQQ	4826664376 Dell Way	\N	EAIWCCC	\N	0	France	2	GTJJJXGIQQ@dell.com	4826664376	4	1651984469033777	2010/01	user10697	password	69	80000	F
10698	CGFZXM	SGWCECLVTP	3796443898 Dell Way	\N	VCLXEOJ	\N	0	Germany	2	SGWCECLVTP@dell.com	3796443898	3	2629492863081395	2009/02	user10698	password	81	60000	F
10699	DUFAHY	GDALGLGZBB	8178135615 Dell Way	\N	BMZFAJU	\N	0	China	2	GDALGLGZBB@dell.com	8178135615	5	7111989592667670	2012/11	user10699	password	36	20000	M
10700	BKZJIG	MIRTUYSVAU	8012566926 Dell Way	\N	IZZJIUS	\N	0	Canada	2	MIRTUYSVAU@dell.com	8012566926	2	1726926289964467	2011/08	user10700	password	37	80000	M
10701	RPBZWN	IOHCMZYMTG	7130499064 Dell Way	\N	MTPVOHY	\N	0	China	2	IOHCMZYMTG@dell.com	7130499064	1	9740093875210732	2009/04	user10701	password	60	20000	M
10702	EBYAPG	OWJBWIOQOA	8339229797 Dell Way	\N	JEVYMUG	\N	0	Canada	2	OWJBWIOQOA@dell.com	8339229797	2	5308721486944705	2008/10	user10702	password	53	20000	M
10703	OAADHP	ZQRWYFMNFV	3456462334 Dell Way	\N	SBTEVAJ	\N	0	Japan	2	ZQRWYFMNFV@dell.com	3456462334	5	7919325206428767	2008/04	user10703	password	79	20000	M
10704	VDZCSZ	TJVSPHGVDY	3800247275 Dell Way	\N	WXDSYMJ	\N	0	Chile	2	TJVSPHGVDY@dell.com	3800247275	1	3700037796515971	2011/12	user10704	password	46	60000	M
10705	NMYFMR	PHKFPQASPX	1944406799 Dell Way	\N	QSPOFZT	\N	0	Germany	2	PHKFPQASPX@dell.com	1944406799	1	2203378560487181	2008/06	user10705	password	63	100000	M
10706	CVEONU	WYALOAEDXU	2419420497 Dell Way	\N	WNIBMCO	\N	0	Germany	2	WYALOAEDXU@dell.com	2419420497	4	6890289016533644	2011/04	user10706	password	58	60000	F
10707	KTZXOV	VOGKPLOMFK	7426309406 Dell Way	\N	ZNLLQAA	\N	0	Russia	2	VOGKPLOMFK@dell.com	7426309406	4	4564868802670390	2008/03	user10707	password	88	60000	M
10708	SKNHGJ	VNTLYHXDSX	1712948439 Dell Way	\N	REJHEKB	\N	0	UK	2	VNTLYHXDSX@dell.com	1712948439	3	9369271048344672	2009/06	user10708	password	45	100000	F
10709	UMLAVH	NPSLXQOPNG	1632126227 Dell Way	\N	TWNYHPW	\N	0	China	2	NPSLXQOPNG@dell.com	1632126227	4	7042611167766154	2010/02	user10709	password	63	80000	M
10710	CCYYKM	NCYKSMAGTU	4566620067 Dell Way	\N	DGTKWPT	\N	0	UK	2	NCYKSMAGTU@dell.com	4566620067	3	4857788637280464	2010/01	user10710	password	24	60000	F
10711	FLBPYP	SWAKJARCVU	4211079109 Dell Way	\N	IPEFEYD	\N	0	Germany	2	SWAKJARCVU@dell.com	4211079109	3	2263769120909273	2009/08	user10711	password	64	60000	M
10712	CPLAED	XEOGFFJBZS	6012312411 Dell Way	\N	QEXVDAK	\N	0	France	2	XEOGFFJBZS@dell.com	6012312411	3	8829175184015186	2008/03	user10712	password	46	20000	F
10713	ZMIEPF	JELPJUQJMH	1700621933 Dell Way	\N	OKCRKND	\N	0	UK	2	JELPJUQJMH@dell.com	1700621933	1	2385262938216328	2009/05	user10713	password	32	60000	F
10714	RWOHBX	LNMUIDEVKS	5543215617 Dell Way	\N	FNJQAMO	\N	0	Canada	2	LNMUIDEVKS@dell.com	5543215617	4	4428541070315987	2012/12	user10714	password	86	40000	M
10715	UVWWTI	KFDSJHOTZU	7276132867 Dell Way	\N	GIKHVZK	\N	0	China	2	KFDSJHOTZU@dell.com	7276132867	4	3277489021420479	2011/09	user10715	password	57	40000	M
10716	KCKDKU	JNNSVCMUWT	3187069789 Dell Way	\N	DGAZFLI	\N	0	UK	2	JNNSVCMUWT@dell.com	3187069789	3	5925676989369095	2012/02	user10716	password	73	60000	M
10717	WXQHRA	VFSQHELDYO	5194029487 Dell Way	\N	KZOQKXO	\N	0	Japan	2	VFSQHELDYO@dell.com	5194029487	1	6620552490931005	2010/11	user10717	password	26	20000	M
10718	ATARTV	WMMERXHPMR	9607147955 Dell Way	\N	OBIZYWQ	\N	0	China	2	WMMERXHPMR@dell.com	9607147955	2	9881048853974790	2012/05	user10718	password	24	60000	F
10719	WOBPKY	CWCTUKJHCX	7921347105 Dell Way	\N	IKXGGNQ	\N	0	Chile	2	CWCTUKJHCX@dell.com	7921347105	4	1234583951067179	2008/09	user10719	password	59	60000	M
10720	DPENNG	KQAFAKMCIU	3461372654 Dell Way	\N	NFATSQY	\N	0	France	2	KQAFAKMCIU@dell.com	3461372654	5	6711829723324627	2012/07	user10720	password	29	60000	M
10721	TSGGZQ	XAVYKHBSBO	3253985632 Dell Way	\N	YCHRTGE	\N	0	Australia	2	XAVYKHBSBO@dell.com	3253985632	4	1066732777748256	2012/12	user10721	password	58	60000	M
10722	HTYHKW	HFUSNVLPJJ	9981907850 Dell Way	\N	SRBLYFL	\N	0	Canada	2	HFUSNVLPJJ@dell.com	9981907850	3	9983476041816176	2012/01	user10722	password	55	80000	F
10723	GOPQKX	WFPKABZKLR	1467944500 Dell Way	\N	BMDZRPE	\N	0	Japan	2	WFPKABZKLR@dell.com	1467944500	1	6696491703856737	2008/09	user10723	password	36	40000	M
10724	VZPGWL	LMWLOWWZOX	3312904527 Dell Way	\N	MRXEGCW	\N	0	China	2	LMWLOWWZOX@dell.com	3312904527	3	4472231845371425	2012/09	user10724	password	74	100000	M
10725	TMVQYG	DUSRQOQEMD	6562447901 Dell Way	\N	VJHCLDK	\N	0	Russia	2	DUSRQOQEMD@dell.com	6562447901	4	6901080767158420	2009/07	user10725	password	57	100000	F
10726	ATYYAB	STTJIJNUNJ	6642075537 Dell Way	\N	EULQXVI	\N	0	Germany	2	STTJIJNUNJ@dell.com	6642075537	5	9073008045554162	2008/07	user10726	password	78	60000	M
10727	PLMPNF	IGORQBLDKP	5919289094 Dell Way	\N	YWFWSOK	\N	0	China	2	IGORQBLDKP@dell.com	5919289094	2	5591414972208441	2008/02	user10727	password	19	80000	M
10728	MCHAHQ	GWHXYTBIJZ	5619316094 Dell Way	\N	FOVXDFF	\N	0	Japan	2	GWHXYTBIJZ@dell.com	5619316094	4	7810747197829188	2011/09	user10728	password	45	40000	F
10729	MQFUGM	QOKOHLXQLC	9296313873 Dell Way	\N	FHZINFA	\N	0	Australia	2	QOKOHLXQLC@dell.com	9296313873	4	6833857744466514	2011/02	user10729	password	89	100000	M
10730	PCKWOB	KYQSKOIVQO	7248416776 Dell Way	\N	DQWQVXQ	\N	0	Russia	2	KYQSKOIVQO@dell.com	7248416776	2	4763136360328645	2012/04	user10730	password	39	60000	M
10731	JXSYZD	XPVHDDDURG	8453127963 Dell Way	\N	LOXGMNA	\N	0	Canada	2	XPVHDDDURG@dell.com	8453127963	3	1207488560583442	2008/09	user10731	password	55	100000	F
10732	KRBKUY	ZPGDTJXLQI	1532935619 Dell Way	\N	ZNPMBQQ	\N	0	South Africa	2	ZPGDTJXLQI@dell.com	1532935619	4	9817508483305574	2011/03	user10732	password	86	100000	M
10733	PYZKWZ	ACCTMAEDJE	9699415866 Dell Way	\N	QYRSPHP	\N	0	Japan	2	ACCTMAEDJE@dell.com	9699415866	3	4816810300573707	2008/07	user10733	password	40	80000	F
10734	GSNDRN	FUHSUMVDRM	4187940869 Dell Way	\N	CIFRQUI	\N	0	Germany	2	FUHSUMVDRM@dell.com	4187940869	4	7551516553852708	2012/01	user10734	password	51	100000	F
10735	EMKWAQ	QIJKUFOLSR	4603043619 Dell Way	\N	UXIKRRZ	\N	0	Australia	2	QIJKUFOLSR@dell.com	4603043619	4	9019733863417060	2010/02	user10735	password	81	80000	F
10736	JEFKUV	SEGMJVYBMS	7996961184 Dell Way	\N	YVCQMBR	\N	0	South Africa	2	SEGMJVYBMS@dell.com	7996961184	3	3981979617848992	2012/05	user10736	password	24	40000	M
10737	GMEBIW	FOJPJIQWAP	4786978461 Dell Way	\N	RDFDFWA	\N	0	UK	2	FOJPJIQWAP@dell.com	4786978461	2	9411574186757208	2012/06	user10737	password	33	80000	M
10738	SUTARZ	OAOYJFUJUM	9848697997 Dell Way	\N	NAPTWQT	\N	0	Chile	2	OAOYJFUJUM@dell.com	9848697997	4	2212409097235650	2010/11	user10738	password	72	20000	M
10739	NWPFVE	FJDPOXZIJM	6605488241 Dell Way	\N	JZFFQYN	\N	0	Japan	2	FJDPOXZIJM@dell.com	6605488241	4	1234015431720763	2010/05	user10739	password	27	20000	M
10740	ZRDUWJ	EZYSXXBHKK	8350563475 Dell Way	\N	HQQXPEN	\N	0	Chile	2	EZYSXXBHKK@dell.com	8350563475	3	7448917654342950	2009/09	user10740	password	77	20000	M
10741	MILJRP	IQHGOJNZTV	7845851404 Dell Way	\N	PKSEOFK	\N	0	China	2	IQHGOJNZTV@dell.com	7845851404	1	6335379475262017	2010/11	user10741	password	73	20000	F
10742	CNUUCD	KKJZTXYNSN	2952402954 Dell Way	\N	XLSMQCV	\N	0	France	2	KKJZTXYNSN@dell.com	2952402954	3	8565930681303144	2008/03	user10742	password	84	60000	F
10743	LIBNLM	YULSSKFKYD	8723743624 Dell Way	\N	VQPMTLX	\N	0	UK	2	YULSSKFKYD@dell.com	8723743624	4	1966241733171045	2008/08	user10743	password	65	40000	F
10744	ZJQKVO	FHGYRMJPPF	4223019817 Dell Way	\N	GFSAQPZ	\N	0	France	2	FHGYRMJPPF@dell.com	4223019817	1	5880701260175556	2008/09	user10744	password	81	20000	M
10745	GTDCHJ	JNHBZQRPVX	1093795089 Dell Way	\N	UNYLDXX	\N	0	France	2	JNHBZQRPVX@dell.com	1093795089	3	5710660197306425	2011/04	user10745	password	64	60000	M
10746	JQQRZA	EHBEYSTUQO	4239295646 Dell Way	\N	IOZLMXY	\N	0	France	2	EHBEYSTUQO@dell.com	4239295646	3	3251312287524342	2011/02	user10746	password	71	40000	F
10747	JXDJYI	QZNPSGJJVR	6144381370 Dell Way	\N	XUDKSCX	\N	0	Australia	2	QZNPSGJJVR@dell.com	6144381370	1	7750461725518108	2011/11	user10747	password	18	20000	F
10748	XIPVRG	VEVOLFXGXV	3245137377 Dell Way	\N	BAFTDCV	\N	0	Russia	2	VEVOLFXGXV@dell.com	3245137377	3	4499707024078816	2008/07	user10748	password	59	40000	F
10749	XZIOFD	SBRDHPKEKL	6508155947 Dell Way	\N	FQFISAA	\N	0	UK	2	SBRDHPKEKL@dell.com	6508155947	3	1948784852400422	2008/12	user10749	password	52	80000	M
10750	LZLRDD	SVHZKRDVDJ	2121766454 Dell Way	\N	LIREJSD	\N	0	UK	2	SVHZKRDVDJ@dell.com	2121766454	2	2625975384842604	2008/09	user10750	password	80	100000	F
10751	WKVZON	VVNGMRBQAM	1414806126 Dell Way	\N	ZSQIKUI	\N	0	Germany	2	VVNGMRBQAM@dell.com	1414806126	3	6733020343817771	2011/05	user10751	password	63	100000	F
10752	ATFPHB	KUHXMIOMVN	7210606643 Dell Way	\N	EMVPHEC	\N	0	China	2	KUHXMIOMVN@dell.com	7210606643	4	1853303337004035	2008/05	user10752	password	19	40000	F
10753	TNZBOK	VWIHFWUBJY	4439016399 Dell Way	\N	NFNVKQD	\N	0	Australia	2	VWIHFWUBJY@dell.com	4439016399	2	2244918924756348	2011/04	user10753	password	49	20000	F
10754	YDBNOX	KWFPTZQCYE	4261806731 Dell Way	\N	IMZSDDU	\N	0	Germany	2	KWFPTZQCYE@dell.com	4261806731	5	3271535011939704	2011/05	user10754	password	47	80000	F
10755	OSVCQF	ZVUSVLVTQD	5599167821 Dell Way	\N	GQVJTPW	\N	0	Canada	2	ZVUSVLVTQD@dell.com	5599167821	1	7554580923169852	2012/07	user10755	password	45	20000	F
10756	CYESDE	NYXJKSDAVJ	7704934990 Dell Way	\N	QRTKGQM	\N	0	Russia	2	NYXJKSDAVJ@dell.com	7704934990	2	6675850542262197	2009/08	user10756	password	74	40000	M
10757	SOJWSX	VQGFIKFETW	9817625716 Dell Way	\N	VNGCDTX	\N	0	South Africa	2	VQGFIKFETW@dell.com	9817625716	3	2314321015961468	2010/04	user10757	password	55	40000	F
10758	BQWUOR	KVXTFDXZZT	3499065310 Dell Way	\N	MGWPATM	\N	0	UK	2	KVXTFDXZZT@dell.com	3499065310	4	6021563794929535	2010/02	user10758	password	77	60000	F
10759	LLZADK	VADBDBADUN	2770185215 Dell Way	\N	KRCKLPJ	\N	0	Russia	2	VADBDBADUN@dell.com	2770185215	5	3488654349930584	2009/09	user10759	password	80	60000	F
10760	HMFLXA	MABPBCTWPD	8451190318 Dell Way	\N	OSNZHXR	\N	0	France	2	MABPBCTWPD@dell.com	8451190318	5	8186219814233483	2010/10	user10760	password	40	80000	F
10761	VZOSZA	SBQUEKRTOF	8826471362 Dell Way	\N	LBFSZXF	\N	0	Russia	2	SBQUEKRTOF@dell.com	8826471362	1	4315711014438421	2011/04	user10761	password	27	100000	F
10762	CJVCKO	EBJILABZGN	5070325010 Dell Way	\N	BMGBJLV	\N	0	Chile	2	EBJILABZGN@dell.com	5070325010	2	9343759586103260	2011/05	user10762	password	72	100000	F
10763	DSNNHR	PQZBRBBXPC	2690111042 Dell Way	\N	JVDTHZZ	\N	0	Russia	2	PQZBRBBXPC@dell.com	2690111042	5	5543445352930576	2010/08	user10763	password	47	100000	M
10764	DMHKEX	AEYRGZPVBZ	6368013522 Dell Way	\N	QFSYFRR	\N	0	China	2	AEYRGZPVBZ@dell.com	6368013522	1	9237795293796808	2009/07	user10764	password	81	20000	M
10765	JICNFD	SDVYCKTEJK	2675759267 Dell Way	\N	KCIPUAZ	\N	0	China	2	SDVYCKTEJK@dell.com	2675759267	5	6615229592658580	2011/10	user10765	password	64	60000	F
10766	YORDSJ	HNHJYAOHLY	4682597925 Dell Way	\N	KTNETNO	\N	0	UK	2	HNHJYAOHLY@dell.com	4682597925	1	7459595285356045	2008/10	user10766	password	31	40000	M
10767	TZYLIF	ZQPXQDEBBP	5566909380 Dell Way	\N	VPTPCIO	\N	0	Germany	2	ZQPXQDEBBP@dell.com	5566909380	2	7324531430844218	2009/06	user10767	password	19	20000	F
10768	ZARIFQ	YVNPYSRAHN	9491405502 Dell Way	\N	PBCSJRG	\N	0	South Africa	2	YVNPYSRAHN@dell.com	9491405502	5	2933071871753782	2010/12	user10768	password	40	80000	M
10769	IGHOXG	JKWICNIKAY	8607659483 Dell Way	\N	LDRVVXS	\N	0	Russia	2	JKWICNIKAY@dell.com	8607659483	5	2492331252899021	2012/03	user10769	password	74	80000	M
10770	BBDYHN	IDVLREVSCG	7495838898 Dell Way	\N	WTCRRUL	\N	0	Germany	2	IDVLREVSCG@dell.com	7495838898	4	3781335396692157	2012/05	user10770	password	23	60000	F
10771	DRJLFS	PADGEYZHFV	6339217293 Dell Way	\N	BHNSCZF	\N	0	South Africa	2	PADGEYZHFV@dell.com	6339217293	3	7940061435569079	2012/08	user10771	password	40	60000	M
10772	ZUEEMT	FPAKOASTWT	2295437040 Dell Way	\N	AJLDJQY	\N	0	UK	2	FPAKOASTWT@dell.com	2295437040	4	9366407936904580	2011/01	user10772	password	43	60000	F
10773	DQEPJK	FKVTKNMGGN	3597005485 Dell Way	\N	QRQZIPY	\N	0	France	2	FKVTKNMGGN@dell.com	3597005485	5	2740569160785526	2009/03	user10773	password	65	40000	F
10774	GMYQXD	BSWLFISMWJ	2220588862 Dell Way	\N	ENIMCHY	\N	0	China	2	BSWLFISMWJ@dell.com	2220588862	1	7156937481369824	2009/10	user10774	password	90	80000	F
10775	MPRKTS	CPEIYXUVGY	5514386258 Dell Way	\N	IPLKWJU	\N	0	Australia	2	CPEIYXUVGY@dell.com	5514386258	3	4138807825744152	2009/06	user10775	password	19	40000	M
10776	QAJJTL	ZXUXVPSCOB	7511547138 Dell Way	\N	RZLOJGO	\N	0	South Africa	2	ZXUXVPSCOB@dell.com	7511547138	5	2218441150616854	2008/12	user10776	password	51	20000	M
10777	LMYFYX	DTVYJOAXPS	7365180471 Dell Way	\N	XBGGIUC	\N	0	Australia	2	DTVYJOAXPS@dell.com	7365180471	2	3143846498802304	2011/09	user10777	password	46	40000	F
10778	XDJWBM	PXKYLLWBDT	3917411407 Dell Way	\N	DKZMFCN	\N	0	UK	2	PXKYLLWBDT@dell.com	3917411407	4	5910752474330366	2008/02	user10778	password	72	20000	F
10779	XNWYZM	VKLHVHJZAN	3188374659 Dell Way	\N	JAZPCMM	\N	0	France	2	VKLHVHJZAN@dell.com	3188374659	1	5030994949862361	2009/10	user10779	password	63	60000	M
10780	DHPDTL	NESJMBINOS	8182996729 Dell Way	\N	NOHQATB	\N	0	Chile	2	NESJMBINOS@dell.com	8182996729	3	6914729296695442	2010/02	user10780	password	23	40000	F
10781	JVJDHX	IZGUBOHQHU	1034177859 Dell Way	\N	EOLFIMM	\N	0	Canada	2	IZGUBOHQHU@dell.com	1034177859	1	7179949426557869	2008/03	user10781	password	85	40000	M
10782	UURBRZ	BXUCMBTTWY	7855037161 Dell Way	\N	HHDPUQS	\N	0	Russia	2	BXUCMBTTWY@dell.com	7855037161	3	9328674008604140	2012/04	user10782	password	41	60000	F
10783	CFETFF	RZIDBBXXAE	9212652572 Dell Way	\N	FDUZTNU	\N	0	Germany	2	RZIDBBXXAE@dell.com	9212652572	4	5476195042952895	2009/01	user10783	password	20	40000	F
10784	GNWMSN	LARNCOKCTQ	2248487595 Dell Way	\N	GOQZBKN	\N	0	UK	2	LARNCOKCTQ@dell.com	2248487595	1	2879463536664843	2008/01	user10784	password	58	40000	F
10785	BEUUSG	UJTWYEZSUF	7853275557 Dell Way	\N	GKFHVTG	\N	0	UK	2	UJTWYEZSUF@dell.com	7853275557	3	2170618147589266	2012/01	user10785	password	49	20000	F
10786	PXWHDQ	RXNQBNIVSO	6220439547 Dell Way	\N	FYWARCZ	\N	0	France	2	RXNQBNIVSO@dell.com	6220439547	1	3235563282389194	2011/07	user10786	password	45	80000	F
10787	HOLLED	ISTJGCEYRK	5686190173 Dell Way	\N	XNKOQKZ	\N	0	Chile	2	ISTJGCEYRK@dell.com	5686190173	2	8293679505120964	2008/08	user10787	password	54	40000	M
10788	BQIGUQ	YOAFQEDHOA	8201295366 Dell Way	\N	UZPLKOQ	\N	0	UK	2	YOAFQEDHOA@dell.com	8201295366	3	9840750955976548	2010/12	user10788	password	31	40000	M
10789	VQFQHE	EHJUMNCBOW	4509417731 Dell Way	\N	BDILSYJ	\N	0	Germany	2	EHJUMNCBOW@dell.com	4509417731	2	9267450169660152	2009/07	user10789	password	34	40000	F
10790	WOZESE	LCYYPBZEYB	2751005967 Dell Way	\N	HGMAEWN	\N	0	Germany	2	LCYYPBZEYB@dell.com	2751005967	3	9128311645705254	2011/09	user10790	password	34	20000	M
10791	TCRMGD	OFCEGBJECR	6699854485 Dell Way	\N	KPRPLFE	\N	0	Japan	2	OFCEGBJECR@dell.com	6699854485	1	4264892985578627	2009/04	user10791	password	51	100000	F
10792	ONNVRC	ATHHVQLXHW	7043074628 Dell Way	\N	NZLYEPP	\N	0	Russia	2	ATHHVQLXHW@dell.com	7043074628	5	1824168704915791	2012/05	user10792	password	85	20000	M
10793	LNUCQV	WXCROOPWKC	6112316621 Dell Way	\N	VWBZMQU	\N	0	Canada	2	WXCROOPWKC@dell.com	6112316621	5	1829983532894402	2012/10	user10793	password	24	100000	F
10794	QTIGOF	EQWTELPPNK	1251935743 Dell Way	\N	LOKXFEB	\N	0	Russia	2	EQWTELPPNK@dell.com	1251935743	1	7661629121284933	2012/03	user10794	password	68	20000	M
10795	LKCZPH	PLBUXQJLBV	8998272364 Dell Way	\N	ZLSEQTY	\N	0	Japan	2	PLBUXQJLBV@dell.com	8998272364	4	5177885103970766	2008/05	user10795	password	55	100000	M
10796	XCUMJJ	YLEVBOGDJG	1730105151 Dell Way	\N	OBLFVKV	\N	0	Russia	2	YLEVBOGDJG@dell.com	1730105151	2	8514827558770777	2010/10	user10796	password	76	40000	M
10797	XBFHLE	SPZTDGWNML	8248223723 Dell Way	\N	OYQKIMD	\N	0	France	2	SPZTDGWNML@dell.com	8248223723	5	8848984315991403	2011/10	user10797	password	28	40000	M
10798	EOYPSQ	FSKIZHVMSK	9160103559 Dell Way	\N	KJVTWYD	\N	0	Japan	2	FSKIZHVMSK@dell.com	9160103559	1	3712012443225831	2011/02	user10798	password	65	40000	F
10799	FGYYXD	RHMQOIDHTN	5093474536 Dell Way	\N	QOHNNLF	\N	0	France	2	RHMQOIDHTN@dell.com	5093474536	3	1912408540956676	2011/02	user10799	password	49	100000	F
10800	RXIPBA	WNRKWURPII	5940109612 Dell Way	\N	EPWSABD	\N	0	France	2	WNRKWURPII@dell.com	5940109612	2	1851235274225473	2011/09	user10800	password	21	20000	F
10801	YKYZKU	NBFJWXZEGE	3230560987 Dell Way	\N	TCWUEAG	\N	0	Russia	2	NBFJWXZEGE@dell.com	3230560987	2	4617735322564840	2012/05	user10801	password	52	40000	F
10802	WFIHAW	IFGFCFJJJC	5463978259 Dell Way	\N	LGXPGDI	\N	0	Germany	2	IFGFCFJJJC@dell.com	5463978259	4	4826523124240339	2012/03	user10802	password	68	40000	F
10803	XPIXLR	CRWFXGOHIA	6852169281 Dell Way	\N	NGQUJYH	\N	0	South Africa	2	CRWFXGOHIA@dell.com	6852169281	4	7946713603101672	2012/06	user10803	password	19	100000	F
10804	PGGBXI	TUOQADYJEM	3683891220 Dell Way	\N	PUGZSOW	\N	0	China	2	TUOQADYJEM@dell.com	3683891220	4	2878925380762666	2011/08	user10804	password	25	20000	F
10805	IHIGQC	BFSCIRLMDB	5742134076 Dell Way	\N	HKBZYXJ	\N	0	Chile	2	BFSCIRLMDB@dell.com	5742134076	3	9794153148308396	2008/09	user10805	password	20	60000	F
10806	IUHYWI	DOKMGWZJXG	2621153338 Dell Way	\N	TYGSWPY	\N	0	China	2	DOKMGWZJXG@dell.com	2621153338	5	6071164825931192	2012/12	user10806	password	18	100000	F
10807	UDFQMJ	FXWLTVURBO	2103643593 Dell Way	\N	QHGMWFW	\N	0	Australia	2	FXWLTVURBO@dell.com	2103643593	3	9320043959189208	2008/06	user10807	password	76	40000	F
10808	YPVLZA	IVMBQGTRUJ	2657747772 Dell Way	\N	YBWVGTX	\N	0	China	2	IVMBQGTRUJ@dell.com	2657747772	5	5006680226419121	2011/08	user10808	password	76	100000	M
10809	KRAJSI	EEKULELGOK	9469152069 Dell Way	\N	HKFOEDX	\N	0	China	2	EEKULELGOK@dell.com	9469152069	2	9714351722039284	2010/02	user10809	password	77	20000	M
10810	NEXFNC	KYWWCIDQSL	3148101689 Dell Way	\N	BYZFCXO	\N	0	Australia	2	KYWWCIDQSL@dell.com	3148101689	3	6235709409695119	2009/04	user10810	password	70	100000	M
10811	WWBKYM	IVIKDMBWXC	4156020332 Dell Way	\N	VXHXUVY	\N	0	Australia	2	IVIKDMBWXC@dell.com	4156020332	3	4706795562524349	2011/03	user10811	password	44	60000	F
10812	GONFAV	AJFEVHBTJW	3084871914 Dell Way	\N	QRUKNSK	\N	0	South Africa	2	AJFEVHBTJW@dell.com	3084871914	5	5756272276397795	2010/03	user10812	password	20	60000	F
10813	PCQPXQ	ZDVUKWOUTE	8267713312 Dell Way	\N	LOOYHZU	\N	0	Germany	2	ZDVUKWOUTE@dell.com	8267713312	2	9735490408260376	2008/05	user10813	password	58	60000	M
10814	QBOOSN	SNIDKWXEAI	4683837965 Dell Way	\N	SPHZPCM	\N	0	China	2	SNIDKWXEAI@dell.com	4683837965	3	4537206627894193	2011/01	user10814	password	78	80000	M
10815	XHFPUY	DDBNAYSBHK	4348721178 Dell Way	\N	QPKFRXQ	\N	0	Australia	2	DDBNAYSBHK@dell.com	4348721178	1	8672624379396439	2009/11	user10815	password	59	20000	M
10816	VHIQFL	THZTGRUNCL	3829971808 Dell Way	\N	DNRUKHX	\N	0	Russia	2	THZTGRUNCL@dell.com	3829971808	4	2578868150245398	2008/04	user10816	password	35	100000	F
10817	NFUTQN	AQHGHCUKOY	4333976929 Dell Way	\N	XGTHOQC	\N	0	South Africa	2	AQHGHCUKOY@dell.com	4333976929	2	1082186798565089	2011/06	user10817	password	82	100000	F
10818	CPUSDV	ILCQOXACVX	5935090918 Dell Way	\N	IOFXEHT	\N	0	Germany	2	ILCQOXACVX@dell.com	5935090918	4	3073310285806656	2008/08	user10818	password	21	20000	M
10819	QWLURU	FTKTQLWLIF	6239213891 Dell Way	\N	AOCEVVT	\N	0	China	2	FTKTQLWLIF@dell.com	6239213891	5	4919478497467935	2009/01	user10819	password	54	100000	M
10820	JKLAEQ	TPKJAGVJMV	7408417299 Dell Way	\N	XOATKTE	\N	0	UK	2	TPKJAGVJMV@dell.com	7408417299	3	2747463938314467	2011/02	user10820	password	27	40000	F
10821	NVLSMF	HWPIDLRPGP	1977748405 Dell Way	\N	EHJOANN	\N	0	Russia	2	HWPIDLRPGP@dell.com	1977748405	4	5148072011303157	2009/11	user10821	password	79	80000	F
10822	RCCDIJ	AYRDJJTQYX	7498935236 Dell Way	\N	XIMXVZQ	\N	0	UK	2	AYRDJJTQYX@dell.com	7498935236	1	2241844207979738	2010/12	user10822	password	75	100000	M
10823	XBTFKU	ECYNLRDJPA	7293466949 Dell Way	\N	RBYNBPL	\N	0	Russia	2	ECYNLRDJPA@dell.com	7293466949	3	4245638542808592	2011/05	user10823	password	41	40000	F
10824	JBNUVR	WTEHLHRAIJ	9016845928 Dell Way	\N	CGWDWHX	\N	0	Germany	2	WTEHLHRAIJ@dell.com	9016845928	2	2918342009652406	2009/08	user10824	password	54	60000	M
10825	OATJSP	DWXPEOPMXR	1303817922 Dell Way	\N	TUVPCTE	\N	0	UK	2	DWXPEOPMXR@dell.com	1303817922	2	3160564363934100	2011/11	user10825	password	74	80000	F
10826	VJVNZY	JWONLDAJVU	9524346340 Dell Way	\N	DRKFLOF	\N	0	France	2	JWONLDAJVU@dell.com	9524346340	3	1886725375428795	2012/03	user10826	password	70	40000	F
10827	CCNBBX	YPLJSLTOFW	7714442432 Dell Way	\N	GQCREHD	\N	0	Canada	2	YPLJSLTOFW@dell.com	7714442432	2	9622375170700252	2012/12	user10827	password	34	100000	F
10828	HNCILA	XWKQHDFNAL	5144102077 Dell Way	\N	DDDILGL	\N	0	Canada	2	XWKQHDFNAL@dell.com	5144102077	3	2307911131531000	2009/08	user10828	password	28	60000	M
10829	RMHCNF	YXWGBBUCNY	2336563209 Dell Way	\N	FQGRWSV	\N	0	China	2	YXWGBBUCNY@dell.com	2336563209	5	7598208025097848	2011/02	user10829	password	28	80000	M
10830	QAWEFV	BBCDDWGQUL	9609487663 Dell Way	\N	HBDDUZM	\N	0	UK	2	BBCDDWGQUL@dell.com	9609487663	2	7566665397956968	2008/05	user10830	password	51	100000	F
10831	MTERPG	SRJWNQMICT	6680535431 Dell Way	\N	JFXEEKC	\N	0	Canada	2	SRJWNQMICT@dell.com	6680535431	5	2866209736093879	2008/04	user10831	password	23	20000	M
10832	VELKKE	BUAPKMXMGH	4599523379 Dell Way	\N	SELWOOZ	\N	0	Chile	2	BUAPKMXMGH@dell.com	4599523379	1	2881370231043547	2011/04	user10832	password	34	60000	F
10833	KXNVBP	QBEAOCNVJF	3391245889 Dell Way	\N	ZVCOJBT	\N	0	Russia	2	QBEAOCNVJF@dell.com	3391245889	5	5193083979655057	2010/03	user10833	password	85	80000	M
10834	VEKWTA	YYBMAPIKVH	6228098163 Dell Way	\N	FXWOZPI	\N	0	Chile	2	YYBMAPIKVH@dell.com	6228098163	4	8155341092497111	2011/09	user10834	password	50	40000	M
10835	PULJVJ	IXWJMETIMY	6727005657 Dell Way	\N	GINFYVM	\N	0	Germany	2	IXWJMETIMY@dell.com	6727005657	2	3544021053239703	2009/09	user10835	password	65	100000	F
10836	LISGSB	DPKQTDZFCF	2838437138 Dell Way	\N	OPLMLYZ	\N	0	Australia	2	DPKQTDZFCF@dell.com	2838437138	2	4807435959111899	2012/12	user10836	password	42	40000	F
10837	RZPJAT	YLKSOJYROM	2912519759 Dell Way	\N	GAZRYYS	\N	0	Canada	2	YLKSOJYROM@dell.com	2912519759	1	1598972917068749	2008/06	user10837	password	42	60000	F
10838	ICNJWM	UGFJQDAEQG	8221521075 Dell Way	\N	FPYDOQH	\N	0	Russia	2	UGFJQDAEQG@dell.com	8221521075	2	9014606242533774	2009/09	user10838	password	45	60000	M
10839	MZJIMD	ORMEVNJLTO	3812246313 Dell Way	\N	BRSPIZJ	\N	0	Canada	2	ORMEVNJLTO@dell.com	3812246313	2	4840593758039177	2012/08	user10839	password	81	100000	F
10840	VIKHLZ	ZYEULNFFCG	5078999588 Dell Way	\N	XVWGUFK	\N	0	Australia	2	ZYEULNFFCG@dell.com	5078999588	5	1746822141110897	2008/09	user10840	password	22	20000	M
10841	KOVVNU	USOGFUMIBK	8489076516 Dell Way	\N	DXQYCAA	\N	0	Germany	2	USOGFUMIBK@dell.com	8489076516	1	6745456695090980	2010/03	user10841	password	76	20000	M
10842	JWKXRF	PFLVAYDBIH	4331887161 Dell Way	\N	YYFBZGQ	\N	0	South Africa	2	PFLVAYDBIH@dell.com	4331887161	2	3886116989888251	2010/01	user10842	password	44	20000	F
10843	FNIWSX	CETCCXELED	1983999515 Dell Way	\N	KKEJRVE	\N	0	Australia	2	CETCCXELED@dell.com	1983999515	3	6222158919088543	2008/11	user10843	password	67	80000	F
10844	FYYXWA	BPDEMHPRKZ	1209387271 Dell Way	\N	BPJTKNU	\N	0	Germany	2	BPDEMHPRKZ@dell.com	1209387271	2	7429729826748372	2012/01	user10844	password	42	100000	F
10845	HWDDXF	TAKFIAWSAY	8431580042 Dell Way	\N	IJSTXMG	\N	0	UK	2	TAKFIAWSAY@dell.com	8431580042	5	8133402994833887	2012/04	user10845	password	71	20000	M
10846	PGSNLL	NVRWVOOWNX	8685635582 Dell Way	\N	FFQCRWA	\N	0	Germany	2	NVRWVOOWNX@dell.com	8685635582	5	4294819246511907	2008/07	user10846	password	51	80000	F
10847	SMRDYF	ZPBVEQRRNX	8783941891 Dell Way	\N	WDAOAAB	\N	0	South Africa	2	ZPBVEQRRNX@dell.com	8783941891	3	1243032343685627	2010/11	user10847	password	74	60000	M
10848	GGSELS	UMNYDFPQCM	5357042450 Dell Way	\N	UCAUDBQ	\N	0	Australia	2	UMNYDFPQCM@dell.com	5357042450	4	4817708253860474	2009/06	user10848	password	18	100000	M
10849	GRWRJQ	EXOHDDYFQS	8295416545 Dell Way	\N	IQMLSDM	\N	0	Canada	2	EXOHDDYFQS@dell.com	8295416545	5	6012202051468194	2009/11	user10849	password	54	100000	F
10850	EUVOLZ	LZHODFUTXC	9232065072 Dell Way	\N	KKOCNAH	\N	0	China	2	LZHODFUTXC@dell.com	9232065072	5	6401430837810040	2012/05	user10850	password	58	100000	M
10851	JTBUSN	UZCXFWRCZB	4001697433 Dell Way	\N	NOEAPMJ	\N	0	France	2	UZCXFWRCZB@dell.com	4001697433	5	3679825599770993	2011/07	user10851	password	34	40000	M
10852	ZHRSUL	RWJXTAATCN	9103293517 Dell Way	\N	HGOWTXJ	\N	0	Australia	2	RWJXTAATCN@dell.com	9103293517	4	7924178407993168	2010/11	user10852	password	89	40000	M
10853	GZOBKG	YUDSUDLXQS	6669556281 Dell Way	\N	EEPXCZZ	\N	0	Australia	2	YUDSUDLXQS@dell.com	6669556281	4	4939342530909926	2010/09	user10853	password	72	40000	F
10854	SYBDFA	YISSMDQCWU	5087490033 Dell Way	\N	HLSKKSK	\N	0	Australia	2	YISSMDQCWU@dell.com	5087490033	5	6141949797049165	2008/08	user10854	password	88	40000	F
10855	XGMCGK	LYDXCTAYOI	1232825863 Dell Way	\N	KGTVYEW	\N	0	France	2	LYDXCTAYOI@dell.com	1232825863	3	6496544701978565	2011/05	user10855	password	77	100000	F
10856	CLKIWW	HZTKTUIIDS	8325872970 Dell Way	\N	PWNOAKZ	\N	0	Australia	2	HZTKTUIIDS@dell.com	8325872970	3	7217578417621554	2009/05	user10856	password	66	60000	F
10857	CXUZTC	ZNNSIVBLOQ	7500970806 Dell Way	\N	ICEIMDK	\N	0	Chile	2	ZNNSIVBLOQ@dell.com	7500970806	1	5417376093566418	2008/10	user10857	password	90	60000	M
10858	XJVRMU	FZNNVOZJFH	2175730622 Dell Way	\N	MKQYNAF	\N	0	Chile	2	FZNNVOZJFH@dell.com	2175730622	4	4312683362048119	2012/09	user10858	password	86	80000	M
10859	IOHVIM	UWAQKAAQHM	4070823298 Dell Way	\N	AYKOZQU	\N	0	Australia	2	UWAQKAAQHM@dell.com	4070823298	1	9804195338860156	2008/02	user10859	password	70	80000	F
10860	HZGQMB	MMRXMRNUDN	1317992826 Dell Way	\N	SNBREWU	\N	0	Germany	2	MMRXMRNUDN@dell.com	1317992826	4	5966979416552932	2008/06	user10860	password	34	60000	M
10861	EVJQWW	DNTQFHKIUD	4182639785 Dell Way	\N	WWVASPN	\N	0	Russia	2	DNTQFHKIUD@dell.com	4182639785	1	9105588603764772	2012/04	user10861	password	52	60000	F
10862	HYDEVH	SOXXWIGQLC	7726647703 Dell Way	\N	MHDFWRZ	\N	0	Chile	2	SOXXWIGQLC@dell.com	7726647703	5	1512343240436166	2008/05	user10862	password	64	60000	M
10863	PRVKYN	ZWKVEQMQTZ	1084070840 Dell Way	\N	YXEUODA	\N	0	China	2	ZWKVEQMQTZ@dell.com	1084070840	1	4204687170684338	2009/09	user10863	password	83	100000	F
10864	OUTNIT	KSOOJBFDAD	1546355381 Dell Way	\N	AEYOIZW	\N	0	China	2	KSOOJBFDAD@dell.com	1546355381	2	7265496949199588	2011/02	user10864	password	68	20000	M
10865	MWFVPQ	NDEXEKAFOA	7288798179 Dell Way	\N	KNPSMMB	\N	0	Germany	2	NDEXEKAFOA@dell.com	7288798179	4	3891260205302388	2012/06	user10865	password	49	60000	M
10866	HTTWJH	AOEFZFKNFU	4106563847 Dell Way	\N	AVNNHPA	\N	0	UK	2	AOEFZFKNFU@dell.com	4106563847	2	8310559048783035	2012/10	user10866	password	42	80000	F
10867	CNXMVY	AADAFNNLHO	5099450045 Dell Way	\N	GVBNKCN	\N	0	Russia	2	AADAFNNLHO@dell.com	5099450045	2	5895467503927649	2009/09	user10867	password	40	40000	M
10868	VGGQEG	QHGVUUHCJN	9186642286 Dell Way	\N	XKBHNOB	\N	0	UK	2	QHGVUUHCJN@dell.com	9186642286	3	2814707844518125	2010/11	user10868	password	55	40000	M
10869	TPJXWZ	EDVYXCBGQY	8945864737 Dell Way	\N	RRGEGHD	\N	0	Canada	2	EDVYXCBGQY@dell.com	8945864737	2	7705906780436636	2011/11	user10869	password	25	60000	M
10870	RVMNVR	QRQOTRVKQM	1899869767 Dell Way	\N	BWQIEUM	\N	0	Australia	2	QRQOTRVKQM@dell.com	1899869767	2	8446617780718953	2012/04	user10870	password	40	60000	F
10871	DANZRE	QHTKYOUOBV	8718252430 Dell Way	\N	LSEQMQR	\N	0	Germany	2	QHTKYOUOBV@dell.com	8718252430	3	5699514416046441	2008/10	user10871	password	20	20000	M
10872	BSXSXO	ZRYXGSMHOY	7420327045 Dell Way	\N	ASOMIFB	\N	0	Canada	2	ZRYXGSMHOY@dell.com	7420327045	3	4272602106910199	2010/08	user10872	password	57	60000	M
10873	GKJEYJ	VWGBOTJCRJ	5527546462 Dell Way	\N	UFVDKXI	\N	0	Canada	2	VWGBOTJCRJ@dell.com	5527546462	4	6919382376130671	2008/03	user10873	password	27	100000	F
10874	NEQLNM	IUOWOXZFGU	8899158782 Dell Way	\N	KCXVAFZ	\N	0	Germany	2	IUOWOXZFGU@dell.com	8899158782	4	6830567449331284	2008/10	user10874	password	51	60000	F
10875	QFTESB	ZGYNEXSLRD	6339443109 Dell Way	\N	NPZNUYB	\N	0	Japan	2	ZGYNEXSLRD@dell.com	6339443109	4	7861388628371061	2009/02	user10875	password	42	80000	M
10876	OKZHLY	OKMSIEDZIR	9211578532 Dell Way	\N	PIEJHFB	\N	0	South Africa	2	OKMSIEDZIR@dell.com	9211578532	5	3140333496499807	2008/02	user10876	password	82	100000	M
10877	HVZTUN	DGGLLJLTAA	3006761013 Dell Way	\N	CFJJLKG	\N	0	China	2	DGGLLJLTAA@dell.com	3006761013	3	4697361730504781	2009/05	user10877	password	37	20000	M
10878	CBKWPN	CVYNFJHGKJ	5627516994 Dell Way	\N	LUTXEAG	\N	0	France	2	CVYNFJHGKJ@dell.com	5627516994	4	7998835596255959	2012/12	user10878	password	79	60000	F
10879	XYWNLZ	IKMOUUUEEG	1478770633 Dell Way	\N	YYDDYKO	\N	0	France	2	IKMOUUUEEG@dell.com	1478770633	2	4157818845473230	2012/02	user10879	password	83	100000	F
10880	VWOHVX	SILMCGQGNO	5984676480 Dell Way	\N	ERSDBGP	\N	0	Canada	2	SILMCGQGNO@dell.com	5984676480	5	1730969300959259	2011/11	user10880	password	22	80000	M
10881	YJZTHR	BTEEZULNJQ	3367009670 Dell Way	\N	EBTFIII	\N	0	South Africa	2	BTEEZULNJQ@dell.com	3367009670	2	6227118784561754	2008/06	user10881	password	45	80000	F
10882	TUDALF	TQJTKUGUKK	3914107190 Dell Way	\N	WEPEMYB	\N	0	Russia	2	TQJTKUGUKK@dell.com	3914107190	4	8705588900018484	2011/12	user10882	password	64	20000	M
10883	KITWNM	MXGXSMSDWP	4744136383 Dell Way	\N	HMTUKUN	\N	0	Russia	2	MXGXSMSDWP@dell.com	4744136383	2	5655821511987597	2010/01	user10883	password	68	20000	F
10884	AWIOJV	LPSDBLHYAO	3363112961 Dell Way	\N	KUIVOWO	\N	0	UK	2	LPSDBLHYAO@dell.com	3363112961	1	4555262525565922	2009/10	user10884	password	56	80000	M
10885	KBIUWT	JPXLAEKBTV	3329271337 Dell Way	\N	VCQKYEJ	\N	0	Chile	2	JPXLAEKBTV@dell.com	3329271337	4	5625276498962194	2008/04	user10885	password	36	100000	M
10886	IDMEXW	TVIUZSVTNQ	2554698194 Dell Way	\N	VEAUIKZ	\N	0	Japan	2	TVIUZSVTNQ@dell.com	2554698194	3	6668162824120373	2010/10	user10886	password	49	20000	F
10887	ORGMOA	HWVGOQACHV	2120996421 Dell Way	\N	GIPPSPF	\N	0	South Africa	2	HWVGOQACHV@dell.com	2120996421	5	4323572854045779	2012/04	user10887	password	58	100000	M
10888	FFHTGO	QBVFSVHZRO	2539863072 Dell Way	\N	IHDAXIY	\N	0	Australia	2	QBVFSVHZRO@dell.com	2539863072	2	9201628471259028	2010/11	user10888	password	82	40000	F
10889	COWJDM	LZRDVZDMNL	7520244196 Dell Way	\N	TRMRAKR	\N	0	Canada	2	LZRDVZDMNL@dell.com	7520244196	3	6514816601295025	2010/06	user10889	password	82	80000	M
10890	LNYPZJ	ORNJRQVECP	5773700872 Dell Way	\N	WPGWAYA	\N	0	Russia	2	ORNJRQVECP@dell.com	5773700872	4	3785444109234959	2008/07	user10890	password	89	60000	M
10891	MNOMXC	ELMVCIAEXW	4448797225 Dell Way	\N	TESTDTM	\N	0	Japan	2	ELMVCIAEXW@dell.com	4448797225	5	6924266611691565	2012/10	user10891	password	35	100000	F
10892	ULTSOY	DATFIUKGRD	2928545447 Dell Way	\N	LJXODKF	\N	0	Germany	2	DATFIUKGRD@dell.com	2928545447	5	4658474762458354	2012/02	user10892	password	38	40000	M
10893	SAPGYS	HSYPNIWEMH	9198162696 Dell Way	\N	NKVQUBE	\N	0	Australia	2	HSYPNIWEMH@dell.com	9198162696	3	1092675216495990	2008/11	user10893	password	37	100000	M
10894	HNVGGC	ZESMMOQZVE	5826595836 Dell Way	\N	JRVESZE	\N	0	Japan	2	ZESMMOQZVE@dell.com	5826595836	1	6888754570856691	2009/06	user10894	password	59	100000	M
10895	CUZIXY	MPLZEBYAFI	8790463753 Dell Way	\N	RBMKARA	\N	0	Germany	2	MPLZEBYAFI@dell.com	8790463753	4	9497898594476284	2009/04	user10895	password	83	20000	F
10896	RCROBE	EMDINCITKA	2419810645 Dell Way	\N	VXLVOMK	\N	0	France	2	EMDINCITKA@dell.com	2419810645	2	7951078956946731	2010/03	user10896	password	80	80000	M
10897	YLMZPQ	MTYZWHTHIO	2443059031 Dell Way	\N	ETKTFVF	\N	0	China	2	MTYZWHTHIO@dell.com	2443059031	5	8214420140720905	2009/11	user10897	password	59	40000	M
10898	AUUQKG	KJGGRZOZOS	7085586316 Dell Way	\N	TZMYUSI	\N	0	UK	2	KJGGRZOZOS@dell.com	7085586316	1	4232471113558859	2010/09	user10898	password	66	40000	M
10899	LBJVIT	FOAWOOVDHO	1046349565 Dell Way	\N	CUNXMWW	\N	0	Canada	2	FOAWOOVDHO@dell.com	1046349565	2	6929525631479920	2011/11	user10899	password	87	60000	F
10900	AVEIOJ	XOGLDCOKRR	6882241148 Dell Way	\N	EFOQBLU	\N	0	Australia	2	XOGLDCOKRR@dell.com	6882241148	3	8047265583183617	2010/05	user10900	password	34	100000	F
10901	BBTPLQ	ERCHTQSKHW	7371265859 Dell Way	\N	QWMRHHT	\N	0	UK	2	ERCHTQSKHW@dell.com	7371265859	3	5337276904378087	2008/10	user10901	password	44	60000	M
10902	KHKVYP	NAXHRPSYLI	3387412497 Dell Way	\N	UYZCFTA	\N	0	UK	2	NAXHRPSYLI@dell.com	3387412497	3	1103414915502071	2008/11	user10902	password	57	100000	F
10903	VGDTVQ	USYLHQJSYE	8274108771 Dell Way	\N	RYHWRHU	\N	0	UK	2	USYLHQJSYE@dell.com	8274108771	4	9784091909881682	2011/04	user10903	password	76	100000	F
10904	ABXWSR	OQCWHMPFRG	6852774769 Dell Way	\N	EZCWGWV	\N	0	Australia	2	OQCWHMPFRG@dell.com	6852774769	4	7721100002527238	2012/08	user10904	password	68	20000	M
10905	UAMMRA	DUWKHLQZSU	3366614372 Dell Way	\N	YURFRMH	\N	0	China	2	DUWKHLQZSU@dell.com	3366614372	1	3533942434936762	2012/09	user10905	password	46	60000	F
10906	KYZCZC	WWNEIDEAYC	6721211059 Dell Way	\N	VPIMBPU	\N	0	China	2	WWNEIDEAYC@dell.com	6721211059	1	2684822141192853	2009/06	user10906	password	66	100000	M
10907	PWYPZV	LMAUQEVOHQ	9883253143 Dell Way	\N	EPCFFXO	\N	0	South Africa	2	LMAUQEVOHQ@dell.com	9883253143	4	2870435962919146	2010/05	user10907	password	23	40000	F
10908	XHPWCB	JCWZHRNOHR	3094279041 Dell Way	\N	EKXJIMF	\N	0	China	2	JCWZHRNOHR@dell.com	3094279041	3	7861969611607493	2011/07	user10908	password	24	80000	F
10909	JHHLJR	OFQWWELEWP	6799738918 Dell Way	\N	PUZXHFF	\N	0	Germany	2	OFQWWELEWP@dell.com	6799738918	5	2337323267478496	2008/01	user10909	password	77	60000	F
10910	CWWLOL	QEHNJSRGIG	3951837032 Dell Way	\N	AHDHNJU	\N	0	Canada	2	QEHNJSRGIG@dell.com	3951837032	5	3787618655711412	2009/10	user10910	password	82	80000	M
10911	TQHHBY	MJLWCCCKJD	2511786819 Dell Way	\N	SNKFWFJ	\N	0	Chile	2	MJLWCCCKJD@dell.com	2511786819	4	6226693294011057	2012/07	user10911	password	44	80000	F
10912	ABQCZD	LLANNCYXFQ	9472554359 Dell Way	\N	KQWHWGM	\N	0	Australia	2	LLANNCYXFQ@dell.com	9472554359	1	9542151883244516	2010/06	user10912	password	71	100000	F
10913	UNNUQZ	FQNTTLRYCB	9169068721 Dell Way	\N	PYJLFVL	\N	0	Canada	2	FQNTTLRYCB@dell.com	9169068721	3	6997943917755038	2009/02	user10913	password	56	80000	M
10914	AITRHY	IVSBHJAJLP	8929631199 Dell Way	\N	IVANQMR	\N	0	Germany	2	IVSBHJAJLP@dell.com	8929631199	2	9073111809324474	2008/11	user10914	password	67	100000	M
10915	ZROHQW	DJXKTXTFNC	6889571676 Dell Way	\N	ANQRAHF	\N	0	South Africa	2	DJXKTXTFNC@dell.com	6889571676	1	9120140119921416	2010/10	user10915	password	80	60000	M
10916	OZCEWF	OUPHSJMFLN	5303774793 Dell Way	\N	TBETJJQ	\N	0	Australia	2	OUPHSJMFLN@dell.com	5303774793	3	5900497567839921	2009/05	user10916	password	88	20000	M
10917	YDCVIR	PYZHHLNSZG	2025699785 Dell Way	\N	UDZDMPE	\N	0	UK	2	PYZHHLNSZG@dell.com	2025699785	4	3105236179661006	2010/09	user10917	password	39	60000	M
10918	LNLUEB	SDIZPVSOCM	5588954493 Dell Way	\N	SBQEQUD	\N	0	Russia	2	SDIZPVSOCM@dell.com	5588954493	2	3192326131742447	2008/09	user10918	password	66	100000	F
10919	EGWJIO	NRODNHSPUK	2091626182 Dell Way	\N	QKPGFTA	\N	0	Russia	2	NRODNHSPUK@dell.com	2091626182	2	9209332236554476	2011/12	user10919	password	71	100000	F
10920	ZTMIIA	ZXEMEWBYHS	3252571144 Dell Way	\N	JWZOQZH	\N	0	Russia	2	ZXEMEWBYHS@dell.com	3252571144	2	5779098839033396	2008/12	user10920	password	48	40000	M
10921	ETGNUG	KYSPUUNCNW	9764580683 Dell Way	\N	ZMLPMTI	\N	0	Russia	2	KYSPUUNCNW@dell.com	9764580683	5	8979065820574761	2012/04	user10921	password	29	100000	F
10922	YDYSJJ	QCYKXMNKJM	2983863501 Dell Way	\N	WUBIOJB	\N	0	Germany	2	QCYKXMNKJM@dell.com	2983863501	5	5124624508898705	2010/02	user10922	password	41	100000	F
10923	LXSVHI	XFTURHFATB	4673354497 Dell Way	\N	VUKKDMY	\N	0	China	2	XFTURHFATB@dell.com	4673354497	3	8790903837420047	2010/09	user10923	password	77	60000	F
10924	SGZZPX	FJRXQWXJYT	5530916075 Dell Way	\N	EJEIVCR	\N	0	Chile	2	FJRXQWXJYT@dell.com	5530916075	3	7759452846366913	2009/05	user10924	password	39	40000	F
10925	OJBEGH	OYEFVBOUVT	3756244303 Dell Way	\N	DZBZCTF	\N	0	Germany	2	OYEFVBOUVT@dell.com	3756244303	5	8382346570957453	2011/04	user10925	password	33	80000	M
10926	PVZWCN	UGSQIHKDBO	7213903045 Dell Way	\N	DCNGWTV	\N	0	Canada	2	UGSQIHKDBO@dell.com	7213903045	4	8515631186310203	2012/11	user10926	password	60	80000	F
10927	KTINHC	TATBIDFJSJ	1653731425 Dell Way	\N	MFPIYLM	\N	0	Japan	2	TATBIDFJSJ@dell.com	1653731425	2	6261565866880119	2012/11	user10927	password	43	40000	F
10928	CSVJUO	JOQSRWBKGN	7075696551 Dell Way	\N	PWWOHJF	\N	0	China	2	JOQSRWBKGN@dell.com	7075696551	4	3534136698115617	2010/02	user10928	password	66	100000	F
10929	JTPEIZ	SZRKVSUCGK	9496377400 Dell Way	\N	YDZFMEO	\N	0	Canada	2	SZRKVSUCGK@dell.com	9496377400	5	7564019436482341	2008/07	user10929	password	64	40000	M
10930	JWBRVU	RMEMFZPMJN	2209291557 Dell Way	\N	PJTBNHF	\N	0	France	2	RMEMFZPMJN@dell.com	2209291557	5	5701082468964160	2011/07	user10930	password	76	60000	M
10931	ROQNIH	ANUFNJSXXH	5312440357 Dell Way	\N	GQJTYOF	\N	0	Australia	2	ANUFNJSXXH@dell.com	5312440357	4	7419372975360603	2008/07	user10931	password	35	100000	F
10932	VQSDYS	RSYECQBAYH	9515537861 Dell Way	\N	QHAPVFQ	\N	0	China	2	RSYECQBAYH@dell.com	9515537861	2	4352238107938320	2010/08	user10932	password	44	80000	F
10933	AJOYCG	RAKTRMTQUK	1065402695 Dell Way	\N	XVZTBQC	\N	0	UK	2	RAKTRMTQUK@dell.com	1065402695	3	5135916478931904	2011/10	user10933	password	27	20000	M
10934	NOTPVK	QFEHSYYMJV	2212762696 Dell Way	\N	HIPIZRI	\N	0	UK	2	QFEHSYYMJV@dell.com	2212762696	4	6404279121663422	2012/12	user10934	password	62	80000	F
10935	EOAAYQ	FDYYBWKKSS	2709911712 Dell Way	\N	TIBTZKT	\N	0	Canada	2	FDYYBWKKSS@dell.com	2709911712	2	1776338158175349	2008/12	user10935	password	81	60000	F
10936	KODJFJ	MDIOASZTLS	5947562360 Dell Way	\N	BNMBXFE	\N	0	Australia	2	MDIOASZTLS@dell.com	5947562360	2	2883708681445569	2010/02	user10936	password	72	80000	M
10937	HUXMEK	QMZRFYKQRM	9664192636 Dell Way	\N	EDNBJSE	\N	0	UK	2	QMZRFYKQRM@dell.com	9664192636	2	4650053225457668	2008/02	user10937	password	21	80000	F
10938	VOXZZO	MYFRWQIOCM	1900889069 Dell Way	\N	RPOBHSY	\N	0	Chile	2	MYFRWQIOCM@dell.com	1900889069	2	4277601480484009	2009/05	user10938	password	18	80000	F
10939	OOGOCS	MHJJYSXAEP	9416821220 Dell Way	\N	QSQYLPE	\N	0	Germany	2	MHJJYSXAEP@dell.com	9416821220	3	7928485826123507	2009/07	user10939	password	47	60000	F
10940	YVRBNE	JXNHPKHUAX	6304378549 Dell Way	\N	NQVYGAM	\N	0	Canada	2	JXNHPKHUAX@dell.com	6304378549	2	5573791995644570	2008/09	user10940	password	24	40000	M
10941	XZRLDA	IQHYBPSBNF	9333345733 Dell Way	\N	SJEYKRD	\N	0	UK	2	IQHYBPSBNF@dell.com	9333345733	4	2258691724389791	2011/09	user10941	password	49	40000	M
10942	KXBNYK	EGIFVAHJGZ	7357993471 Dell Way	\N	SKYDBBC	\N	0	UK	2	EGIFVAHJGZ@dell.com	7357993471	2	6330872672609985	2010/09	user10942	password	78	20000	F
10943	SCPRMT	XVYTWFCCFV	3814594687 Dell Way	\N	MEYOGBO	\N	0	UK	2	XVYTWFCCFV@dell.com	3814594687	1	4352608546148986	2012/12	user10943	password	48	20000	M
10944	NRJAKH	VJARPDTUZG	5751236072 Dell Way	\N	ZYVFAJE	\N	0	China	2	VJARPDTUZG@dell.com	5751236072	3	3768215597607195	2010/12	user10944	password	45	20000	F
10945	AOMLVI	UWAJZUEZBE	1541926166 Dell Way	\N	XWJXGNG	\N	0	Russia	2	UWAJZUEZBE@dell.com	1541926166	3	3506442919373512	2008/11	user10945	password	52	60000	M
10946	AZJWIE	SINSCSRDWP	3659592808 Dell Way	\N	AFNHTTB	\N	0	South Africa	2	SINSCSRDWP@dell.com	3659592808	2	8501884085591883	2009/10	user10946	password	41	20000	M
10947	INSQRL	ZFDBXVFULG	9077608163 Dell Way	\N	AYNTSOP	\N	0	Australia	2	ZFDBXVFULG@dell.com	9077608163	3	2923586130607873	2011/09	user10947	password	44	60000	F
10948	WGSORR	TVTRRZLDFL	2845690045 Dell Way	\N	BSFUHUU	\N	0	Canada	2	TVTRRZLDFL@dell.com	2845690045	1	9048052152618768	2012/05	user10948	password	50	20000	F
10949	SSUJKO	FEFXDQAJCC	6949328464 Dell Way	\N	BHWJCRO	\N	0	Chile	2	FEFXDQAJCC@dell.com	6949328464	3	3219142924528569	2008/11	user10949	password	37	40000	M
10950	ZBZKPE	OVCRMCAOEC	5276005296 Dell Way	\N	WBMYSAG	\N	0	China	2	OVCRMCAOEC@dell.com	5276005296	3	4659447180572897	2009/10	user10950	password	67	100000	M
10951	TYDICR	EFJQHJFMMB	8152707506 Dell Way	\N	OYAHZHR	\N	0	France	2	EFJQHJFMMB@dell.com	8152707506	1	8316998131573201	2010/09	user10951	password	73	40000	F
10952	RLVUDZ	AMPIWVVJXJ	4346294429 Dell Way	\N	HXQHFHS	\N	0	Australia	2	AMPIWVVJXJ@dell.com	4346294429	3	6072213339153678	2008/04	user10952	password	81	60000	M
10953	IKUMKU	YADVVYFSHM	1317938721 Dell Way	\N	QYUVGMV	\N	0	Japan	2	YADVVYFSHM@dell.com	1317938721	2	7560412087477744	2009/04	user10953	password	41	40000	M
10954	SDBCYA	CBWYZBQHOG	3786018378 Dell Way	\N	FICMVXC	\N	0	South Africa	2	CBWYZBQHOG@dell.com	3786018378	5	2754962556529790	2010/02	user10954	password	56	20000	M
10955	RGYPGB	RDZQEQXSWD	5544698120 Dell Way	\N	AYPWWSS	\N	0	Canada	2	RDZQEQXSWD@dell.com	5544698120	5	7891462176106871	2011/06	user10955	password	87	60000	F
10956	ELRLNI	PNZTDXLABM	9757035046 Dell Way	\N	ZRJVJBA	\N	0	South Africa	2	PNZTDXLABM@dell.com	9757035046	4	5439551508054137	2010/09	user10956	password	89	60000	M
10957	KFKYNZ	LNSOLEOMRN	2505811029 Dell Way	\N	DAJNBJJ	\N	0	Australia	2	LNSOLEOMRN@dell.com	2505811029	5	5097098435275257	2012/10	user10957	password	87	100000	F
10958	DFEREP	FWDQBSDSFH	9932697944 Dell Way	\N	SOUUYDV	\N	0	Canada	2	FWDQBSDSFH@dell.com	9932697944	2	1152824365533888	2012/03	user10958	password	79	20000	F
10959	BGCGVH	DZYERCWXJP	5617125349 Dell Way	\N	LDKKHFN	\N	0	Chile	2	DZYERCWXJP@dell.com	5617125349	3	1798104975838214	2011/05	user10959	password	29	20000	F
10960	KGRGOV	FNZXPWUYMG	7126539315 Dell Way	\N	CWQJBDQ	\N	0	Germany	2	FNZXPWUYMG@dell.com	7126539315	4	4158571041654796	2008/11	user10960	password	55	60000	F
10961	TFNIAS	VZPLWJKIPM	2595931521 Dell Way	\N	EGVGKMW	\N	0	Australia	2	VZPLWJKIPM@dell.com	2595931521	1	2242863979656249	2008/09	user10961	password	65	40000	F
10962	VVVVOQ	VECSOMAEYF	5710670326 Dell Way	\N	KUMUGIW	\N	0	France	2	VECSOMAEYF@dell.com	5710670326	1	5322962864302099	2009/08	user10962	password	76	80000	F
10963	QNIEEE	JHWXTXBSDM	2488559731 Dell Way	\N	MPGTYDE	\N	0	France	2	JHWXTXBSDM@dell.com	2488559731	4	7159136071335525	2012/06	user10963	password	47	40000	F
10964	YRHDWQ	KSNDQPVTBI	9194456797 Dell Way	\N	JICHLGT	\N	0	Japan	2	KSNDQPVTBI@dell.com	9194456797	3	5044506489764899	2009/10	user10964	password	74	60000	M
10965	LTWHJH	AXKRMGLNPU	3204460118 Dell Way	\N	VRCHYVX	\N	0	South Africa	2	AXKRMGLNPU@dell.com	3204460118	2	2939886363223195	2008/02	user10965	password	67	100000	M
10966	LSXUZX	SKPFRASGVO	2284915728 Dell Way	\N	YXWWTUS	\N	0	UK	2	SKPFRASGVO@dell.com	2284915728	5	1423500456381589	2009/08	user10966	password	81	100000	F
10967	PTVORO	ZHTQHMWCBU	3800954628 Dell Way	\N	AXRTRJS	\N	0	South Africa	2	ZHTQHMWCBU@dell.com	3800954628	4	2017152679618448	2012/08	user10967	password	90	100000	F
10968	TUULJT	SCJAOGCQBD	4493314343 Dell Way	\N	NSWFCPB	\N	0	France	2	SCJAOGCQBD@dell.com	4493314343	1	3996351757086814	2008/02	user10968	password	39	40000	M
10969	CCILWB	NGBCMESOHG	7000841487 Dell Way	\N	GEMJUNU	\N	0	Canada	2	NGBCMESOHG@dell.com	7000841487	1	2968690949492156	2012/05	user10969	password	54	80000	F
10970	PBXLCL	RDOEIHSPNY	2749094038 Dell Way	\N	UAIONCT	\N	0	Canada	2	RDOEIHSPNY@dell.com	2749094038	5	9937548824120314	2010/06	user10970	password	69	20000	F
10971	TZMWKE	AZIIGAXUYS	1082504284 Dell Way	\N	UHHHJAM	\N	0	Germany	2	AZIIGAXUYS@dell.com	1082504284	3	2311985708773136	2010/03	user10971	password	33	60000	M
10972	EAUPEU	OMCVMAPLSJ	6349611230 Dell Way	\N	SARCBDQ	\N	0	Australia	2	OMCVMAPLSJ@dell.com	6349611230	4	5772870858665556	2011/01	user10972	password	22	80000	F
10973	CLUGGJ	TIFGIURBDK	9413284078 Dell Way	\N	BUMCYDE	\N	0	Germany	2	TIFGIURBDK@dell.com	9413284078	4	3560861482750624	2012/09	user10973	password	88	20000	M
10974	LYCRIV	ZNBIHTKLDL	4654123544 Dell Way	\N	GQOEUSR	\N	0	Russia	2	ZNBIHTKLDL@dell.com	4654123544	5	6984077735338361	2008/12	user10974	password	76	100000	F
10975	TBBBXA	OYJWSTIVFO	4281653346 Dell Way	\N	MUSHMKA	\N	0	UK	2	OYJWSTIVFO@dell.com	4281653346	4	1510958143509924	2009/06	user10975	password	21	80000	F
10976	CSHATV	ZDSRWAMCOZ	9526421402 Dell Way	\N	WHHJRHG	\N	0	Australia	2	ZDSRWAMCOZ@dell.com	9526421402	2	4159246535040438	2010/05	user10976	password	20	80000	F
10977	TXMMTL	PMCMMPPBPL	4634432849 Dell Way	\N	JWVADCB	\N	0	Australia	2	PMCMMPPBPL@dell.com	4634432849	3	5584476374089718	2011/06	user10977	password	28	40000	F
10978	BTSUEI	GHUTXKUMVD	7061993346 Dell Way	\N	JRENTGP	\N	0	Canada	2	GHUTXKUMVD@dell.com	7061993346	1	9211019023321570	2008/03	user10978	password	29	40000	F
10979	XABCII	JDBHNWUJZD	4295534742 Dell Way	\N	AEQTKGX	\N	0	Australia	2	JDBHNWUJZD@dell.com	4295534742	5	2973907657433301	2011/12	user10979	password	57	100000	M
10980	OZYXHI	AJPOFJYFNY	4956936711 Dell Way	\N	KESULQX	\N	0	Russia	2	AJPOFJYFNY@dell.com	4956936711	1	4720523342955858	2010/08	user10980	password	41	40000	F
10981	HGDPOE	ZESEOQKBPU	6522786244 Dell Way	\N	GIPRYMM	\N	0	China	2	ZESEOQKBPU@dell.com	6522786244	5	8128710738383234	2009/03	user10981	password	24	60000	M
10982	IQCXUC	BNGPERRUMY	9774088447 Dell Way	\N	CBPBOCK	\N	0	Canada	2	BNGPERRUMY@dell.com	9774088447	2	5043831813614816	2008/04	user10982	password	87	80000	M
10983	PUNKXO	YEEDVWXHUA	7141698163 Dell Way	\N	JKBXMMC	\N	0	France	2	YEEDVWXHUA@dell.com	7141698163	3	6833926492836327	2012/06	user10983	password	42	60000	F
10984	DCMARL	EVOASMHMNR	2771011319 Dell Way	\N	XOOKBRW	\N	0	Russia	2	EVOASMHMNR@dell.com	2771011319	3	7257338478229941	2011/11	user10984	password	38	80000	M
10985	JHAASF	WGFOTNBGEY	7187934333 Dell Way	\N	UTIWLEO	\N	0	Japan	2	WGFOTNBGEY@dell.com	7187934333	2	3825544542167336	2010/07	user10985	password	24	60000	M
10986	JNYBTU	IZIBMKHRIC	8148937901 Dell Way	\N	LRYWWNN	\N	0	Germany	2	IZIBMKHRIC@dell.com	8148937901	5	1610846561845392	2009/11	user10986	password	60	40000	F
10987	DEIWZR	VHSISAZADL	6726856493 Dell Way	\N	RCIOPVC	\N	0	China	2	VHSISAZADL@dell.com	6726856493	1	7649852526374162	2010/09	user10987	password	90	100000	M
10988	EDSDUN	LNVDOVERHW	6717773674 Dell Way	\N	TPKJKMT	\N	0	Australia	2	LNVDOVERHW@dell.com	6717773674	3	6374437304213644	2009/06	user10988	password	47	40000	M
10989	OYUJLG	WHJKDOCKKV	4600168203 Dell Way	\N	AUEKHXM	\N	0	UK	2	WHJKDOCKKV@dell.com	4600168203	1	3659690822474659	2012/06	user10989	password	55	60000	F
10990	LHKXNH	FXSILUTWPT	7457974242 Dell Way	\N	RUEYSQW	\N	0	Australia	2	FXSILUTWPT@dell.com	7457974242	1	9709877755492928	2009/09	user10990	password	53	40000	F
10991	UQAIXG	GQOSKHOABF	3199538939 Dell Way	\N	UFEMWBO	\N	0	Germany	2	GQOSKHOABF@dell.com	3199538939	3	8051129699219019	2012/01	user10991	password	19	20000	M
10992	RCDPJK	FXCPFQQHWK	9981533560 Dell Way	\N	MBWJDLY	\N	0	China	2	FXCPFQQHWK@dell.com	9981533560	4	3733315146528184	2008/10	user10992	password	45	100000	F
10993	MZAVKF	TMVZDLGAVT	8187682929 Dell Way	\N	BSDEEBO	\N	0	Canada	2	TMVZDLGAVT@dell.com	8187682929	5	2825306589249521	2010/03	user10993	password	21	100000	M
10994	BZPLEI	YAIBLPCHJD	7702738211 Dell Way	\N	AMIEOXJ	\N	0	China	2	YAIBLPCHJD@dell.com	7702738211	3	9159698620904238	2012/08	user10994	password	82	80000	M
10995	WHCBQB	BZCNOEUXIU	9203381177 Dell Way	\N	KRZYOII	\N	0	Chile	2	BZCNOEUXIU@dell.com	9203381177	2	3527494127862155	2010/02	user10995	password	90	20000	M
10996	HHZXIB	WLOLQIJZDT	3305413264 Dell Way	\N	QDSEMAM	\N	0	China	2	WLOLQIJZDT@dell.com	3305413264	4	9165379983838648	2009/10	user10996	password	25	40000	F
10997	KHYTJV	FXHVGQUKKK	8645789728 Dell Way	\N	NCPZDCJ	\N	0	France	2	FXHVGQUKKK@dell.com	8645789728	2	7823169140610845	2011/05	user10997	password	22	80000	M
10998	JPNSLS	QSNXJIHTTU	4611237432 Dell Way	\N	WIUALDK	\N	0	Chile	2	QSNXJIHTTU@dell.com	4611237432	1	8982816902454943	2011/03	user10998	password	57	60000	M
10999	DBIPUZ	IHWSQELJYI	9386087639 Dell Way	\N	SSIDWTL	\N	0	Chile	2	IHWSQELJYI@dell.com	9386087639	2	1295985172037035	2008/11	user10999	password	59	80000	M
11000	QDPKDY	SAQIECSCKL	3755840719 Dell Way	\N	VTOSMZZ	\N	0	France	2	SAQIECSCKL@dell.com	3755840719	1	6448837369214744	2008/07	user11000	password	46	20000	F
11001	NTPRSI	RIRVKJYVUU	5078406359 Dell Way	\N	OJMBJLM	\N	0	Japan	2	RIRVKJYVUU@dell.com	5078406359	1	8400694079231472	2008/06	user11001	password	89	40000	F
11002	TWRLEI	TVEEFCZZWO	2629692067 Dell Way	\N	JJPSUCK	\N	0	Chile	2	TVEEFCZZWO@dell.com	2629692067	2	3535373116843402	2011/03	user11002	password	56	80000	M
11003	JJJOSC	JWHPYGPVUY	3390707444 Dell Way	\N	EKRZMBF	\N	0	Japan	2	JWHPYGPVUY@dell.com	3390707444	3	4039831245318055	2010/01	user11003	password	20	40000	F
11004	KTYDWI	ZDXYKMTEKY	6656918941 Dell Way	\N	PCXBDDT	\N	0	France	2	ZDXYKMTEKY@dell.com	6656918941	1	8753526865039022	2011/02	user11004	password	35	20000	M
11005	ZZQVIQ	YFOISINDGC	9883340223 Dell Way	\N	FEEIHXT	\N	0	UK	2	YFOISINDGC@dell.com	9883340223	4	6109566607512534	2008/11	user11005	password	63	80000	M
11006	PGRXWQ	DKZVTMYZPD	8686463182 Dell Way	\N	DUMLSGJ	\N	0	Japan	2	DKZVTMYZPD@dell.com	8686463182	5	8041686479467899	2011/07	user11006	password	46	60000	F
11007	QFBMVF	WUAQHZPXDT	5331769432 Dell Way	\N	SPFKWOC	\N	0	Russia	2	WUAQHZPXDT@dell.com	5331769432	5	4786292197648436	2008/04	user11007	password	88	20000	M
11008	EGJALG	VMWDLMBOGT	2119331897 Dell Way	\N	ELDAZGT	\N	0	France	2	VMWDLMBOGT@dell.com	2119331897	1	5492533119861037	2009/02	user11008	password	66	40000	F
11009	XQIIWD	UTHGFIULBZ	9198844572 Dell Way	\N	XFAXLTJ	\N	0	Germany	2	UTHGFIULBZ@dell.com	9198844572	5	9710305924061688	2008/07	user11009	password	35	40000	F
11010	WRTTVO	NCUSKPEMOB	2553410227 Dell Way	\N	ROYDIIS	\N	0	Chile	2	NCUSKPEMOB@dell.com	2553410227	4	3414027877151966	2011/12	user11010	password	63	20000	M
11011	HXOCMB	FHUPWYCLAT	3384615204 Dell Way	\N	AYWIGPO	\N	0	France	2	FHUPWYCLAT@dell.com	3384615204	5	2271198756061494	2008/06	user11011	password	38	100000	M
11012	EOVQPB	YKRUITGJMG	9677395353 Dell Way	\N	IJPPZDA	\N	0	Chile	2	YKRUITGJMG@dell.com	9677395353	1	4763328331056982	2010/06	user11012	password	47	20000	M
11013	YZHOAF	YRAHLGQYNZ	7478782643 Dell Way	\N	HCOHGON	\N	0	Canada	2	YRAHLGQYNZ@dell.com	7478782643	5	6444555742200465	2008/04	user11013	password	72	80000	F
11014	SBVTGU	LGBWMSUARC	8463275669 Dell Way	\N	CGKIUXN	\N	0	Germany	2	LGBWMSUARC@dell.com	8463275669	1	7016253334470094	2008/11	user11014	password	50	60000	M
11015	MGJSBU	ZDRMVMMNPO	6087747851 Dell Way	\N	TZXOXLB	\N	0	Russia	2	ZDRMVMMNPO@dell.com	6087747851	4	8864991856738926	2010/03	user11015	password	40	20000	M
11016	PKJQFJ	TWVPJHCZVW	3032058615 Dell Way	\N	YTLVEMO	\N	0	Russia	2	TWVPJHCZVW@dell.com	3032058615	3	2592033563647419	2010/09	user11016	password	34	20000	F
11017	QLYVUR	SPGCXJBTGZ	8148741131 Dell Way	\N	MRVQDJJ	\N	0	China	2	SPGCXJBTGZ@dell.com	8148741131	3	7990325743332506	2010/10	user11017	password	79	100000	F
11018	HTGBLY	RRBOBCHHCU	3902623304 Dell Way	\N	YYKCHUM	\N	0	Australia	2	RRBOBCHHCU@dell.com	3902623304	2	6567115716636181	2008/02	user11018	password	50	60000	F
11019	FTLQSD	ITRKVZRYTQ	5052796891 Dell Way	\N	WESEYFG	\N	0	Chile	2	ITRKVZRYTQ@dell.com	5052796891	5	4218684932217002	2010/04	user11019	password	80	100000	M
11020	PIEHLN	ADXWDPUWFR	9664896431 Dell Way	\N	BYVZECG	\N	0	Japan	2	ADXWDPUWFR@dell.com	9664896431	4	2277914550621062	2009/06	user11020	password	21	100000	F
11021	JAIVOJ	ZLFCBAZHRA	8701951082 Dell Way	\N	GNAKPGZ	\N	0	Germany	2	ZLFCBAZHRA@dell.com	8701951082	1	8700705531984568	2009/03	user11021	password	67	40000	M
11022	SRKGBJ	SGLTHLAZLG	8101825478 Dell Way	\N	MLRCRQR	\N	0	Germany	2	SGLTHLAZLG@dell.com	8101825478	3	8766235112678260	2012/03	user11022	password	34	60000	M
11023	XYDZHV	FTPNEPMPWZ	3337103723 Dell Way	\N	BNCTETH	\N	0	UK	2	FTPNEPMPWZ@dell.com	3337103723	1	9415032430086286	2010/05	user11023	password	52	40000	F
11024	KNGRIM	LXAPNMFKMG	5201242060 Dell Way	\N	XOACHIB	\N	0	Germany	2	LXAPNMFKMG@dell.com	5201242060	5	1185131279751658	2012/06	user11024	password	45	20000	M
11025	WKNFXY	DXOQKTAXAY	1785806288 Dell Way	\N	LABTICI	\N	0	South Africa	2	DXOQKTAXAY@dell.com	1785806288	2	6912105404771865	2010/09	user11025	password	77	40000	M
11026	FXVDWY	BKPMEQJEPV	2907293311 Dell Way	\N	FQOOSWJ	\N	0	South Africa	2	BKPMEQJEPV@dell.com	2907293311	1	4156581458635628	2012/10	user11026	password	72	60000	F
11027	RIENHG	YWSCNCHCXM	4657913920 Dell Way	\N	SMAKJKF	\N	0	Germany	2	YWSCNCHCXM@dell.com	4657913920	3	5369503306224942	2009/04	user11027	password	18	40000	M
11028	JMNQSL	NKNAMVCKHU	1164928273 Dell Way	\N	WIFFSLU	\N	0	Canada	2	NKNAMVCKHU@dell.com	1164928273	2	4282115273643285	2009/04	user11028	password	64	40000	M
11029	CVGVGT	GUTTPVDXPZ	3120359454 Dell Way	\N	GVFZGZC	\N	0	Chile	2	GUTTPVDXPZ@dell.com	3120359454	3	6526747792027891	2010/02	user11029	password	86	20000	F
11030	TJBACH	VVALRDIHDP	2229138403 Dell Way	\N	CJOJIRQ	\N	0	Germany	2	VVALRDIHDP@dell.com	2229138403	2	1696652674581855	2009/03	user11030	password	31	60000	M
11031	ONYQUU	MVFEZOLDDN	7808345275 Dell Way	\N	MRXVJNK	\N	0	France	2	MVFEZOLDDN@dell.com	7808345275	3	7636872893664987	2012/09	user11031	password	33	100000	F
11032	TVWOPJ	JVNIJYLMMY	6961306941 Dell Way	\N	EJUNXEA	\N	0	Japan	2	JVNIJYLMMY@dell.com	6961306941	4	6288476398680360	2009/12	user11032	password	51	60000	M
11033	HLGWUP	SHYBGKOTIT	1101444564 Dell Way	\N	DCGAHGR	\N	0	UK	2	SHYBGKOTIT@dell.com	1101444564	2	3623817726969719	2012/09	user11033	password	79	80000	F
11034	HXXBNP	JLRPVFJEYM	5481894959 Dell Way	\N	HFNOMFN	\N	0	France	2	JLRPVFJEYM@dell.com	5481894959	5	5019588017836213	2009/09	user11034	password	26	40000	M
11035	ADZOSJ	ZKZVPIZNVG	2615515180 Dell Way	\N	TJVFPJR	\N	0	Australia	2	ZKZVPIZNVG@dell.com	2615515180	1	3793549208436161	2012/03	user11035	password	58	80000	F
11036	RUUKDU	UCPKLOYHVR	6869099288 Dell Way	\N	QQWFANH	\N	0	Canada	2	UCPKLOYHVR@dell.com	6869099288	4	1362798038870096	2012/02	user11036	password	78	20000	M
11037	QYGTTB	WIMIXKPSCG	4297972715 Dell Way	\N	JYLKMTP	\N	0	Canada	2	WIMIXKPSCG@dell.com	4297972715	4	1211933148559182	2010/06	user11037	password	30	40000	F
11038	DQVWSS	FEBDPQVRWF	8370279467 Dell Way	\N	QIPCCFG	\N	0	France	2	FEBDPQVRWF@dell.com	8370279467	2	9837446160148830	2009/06	user11038	password	44	40000	M
11039	AFLSXR	XYUMPQEMVU	4516876066 Dell Way	\N	VLXXQDJ	\N	0	France	2	XYUMPQEMVU@dell.com	4516876066	2	7714184186421335	2012/09	user11039	password	25	60000	M
11040	HWKFNI	EIUTYZGUTB	6610396985 Dell Way	\N	GQYXUHJ	\N	0	Canada	2	EIUTYZGUTB@dell.com	6610396985	1	9954970337450504	2009/03	user11040	password	47	20000	F
11041	GKSUTW	COQANWVHXB	4655735963 Dell Way	\N	XVYRDHW	\N	0	Russia	2	COQANWVHXB@dell.com	4655735963	5	1675395707134157	2011/04	user11041	password	24	20000	M
11042	NUHGRK	UHLHDGOAHM	8857909496 Dell Way	\N	WFEANAU	\N	0	UK	2	UHLHDGOAHM@dell.com	8857909496	5	5882834249176086	2008/12	user11042	password	65	80000	F
11043	LYRCIL	JUTNAHNHUK	1467091076 Dell Way	\N	NYLBZFZ	\N	0	South Africa	2	JUTNAHNHUK@dell.com	1467091076	3	9737052380107344	2012/03	user11043	password	62	60000	M
11044	OCSXOC	RHPRPDZJON	1899572645 Dell Way	\N	IZOHEOD	\N	0	Chile	2	RHPRPDZJON@dell.com	1899572645	1	2933510513510555	2009/09	user11044	password	64	100000	F
11045	TQDHTV	OIMEMLNAZW	4580537442 Dell Way	\N	AODECHK	\N	0	Chile	2	OIMEMLNAZW@dell.com	4580537442	4	5429946580436081	2008/04	user11045	password	47	40000	M
11046	ANHTIV	CVZPHNPGJP	8341752108 Dell Way	\N	VNUXUFD	\N	0	Chile	2	CVZPHNPGJP@dell.com	8341752108	4	3895534485578537	2008/01	user11046	password	69	20000	F
11047	GIVPEX	KEMSSCZCSU	5001660472 Dell Way	\N	PMRKRVQ	\N	0	Germany	2	KEMSSCZCSU@dell.com	5001660472	5	6217922508250923	2010/08	user11047	password	65	60000	M
11048	ZIMEGX	JTPBWOEOIT	7556665292 Dell Way	\N	BAETVUG	\N	0	Chile	2	JTPBWOEOIT@dell.com	7556665292	5	7675494528375567	2009/06	user11048	password	37	40000	F
11049	PSRWPA	QFCMTGBBAD	9906602921 Dell Way	\N	CEXXZDE	\N	0	Russia	2	QFCMTGBBAD@dell.com	9906602921	5	1664584405720234	2010/03	user11049	password	42	100000	M
11050	BQQRQG	WTTQZVSZYU	8099945023 Dell Way	\N	EVRDZWW	\N	0	UK	2	WTTQZVSZYU@dell.com	8099945023	5	5039834022987634	2012/04	user11050	password	48	80000	F
11051	BKZRRW	LLMKGEKEYP	5585471934 Dell Way	\N	AQTANPZ	\N	0	Chile	2	LLMKGEKEYP@dell.com	5585471934	3	3426449342165142	2011/10	user11051	password	20	20000	M
11052	LCODYZ	OLKVQUZPJA	4690361068 Dell Way	\N	GCATSZA	\N	0	Chile	2	OLKVQUZPJA@dell.com	4690361068	2	9751029425766320	2009/05	user11052	password	22	20000	M
11053	DRXCQM	NBHDVHTFHZ	1436858611 Dell Way	\N	IISAHTG	\N	0	Russia	2	NBHDVHTFHZ@dell.com	1436858611	2	9616748541593552	2009/04	user11053	password	23	20000	F
11054	TBMKNZ	LUDGBXMJWV	3477918590 Dell Way	\N	RPVZIBS	\N	0	China	2	LUDGBXMJWV@dell.com	3477918590	4	7935892147012056	2010/09	user11054	password	86	100000	F
11055	ZKVNKH	IONKLATIVL	7872545733 Dell Way	\N	YRKGTCR	\N	0	Australia	2	IONKLATIVL@dell.com	7872545733	3	5925979324616492	2010/05	user11055	password	53	100000	F
11056	XUWHBF	WPPIPJQLUO	9287420766 Dell Way	\N	CEVVHMW	\N	0	Australia	2	WPPIPJQLUO@dell.com	9287420766	2	5946629815269262	2009/11	user11056	password	54	80000	M
11057	HNBJSX	YHGORWALLC	2738702762 Dell Way	\N	QHYXUUZ	\N	0	Russia	2	YHGORWALLC@dell.com	2738702762	3	9938655025791378	2008/01	user11057	password	63	100000	F
11058	DXRVVQ	DBEUYEGJHW	3700505569 Dell Way	\N	RGUMATF	\N	0	Chile	2	DBEUYEGJHW@dell.com	3700505569	1	3685912210959941	2009/10	user11058	password	27	80000	M
11059	AIUVYY	XDTVIZFPVW	7603217415 Dell Way	\N	WQJXKOD	\N	0	Japan	2	XDTVIZFPVW@dell.com	7603217415	3	1150180453434586	2010/07	user11059	password	66	60000	M
11060	ZHKYFI	BYDKYIATFW	3543611303 Dell Way	\N	JOTTCWL	\N	0	South Africa	2	BYDKYIATFW@dell.com	3543611303	3	4427392531652004	2012/02	user11060	password	81	60000	F
11061	DVBJDD	HGNFPOZUKJ	1519479848 Dell Way	\N	IEDLAPH	\N	0	China	2	HGNFPOZUKJ@dell.com	1519479848	4	2240164772141725	2008/07	user11061	password	58	40000	M
11062	JKANOI	UCNJQNEAXN	9077650115 Dell Way	\N	EAYFPGN	\N	0	Japan	2	UCNJQNEAXN@dell.com	9077650115	4	8770556407049299	2010/03	user11062	password	31	20000	M
11063	PDCDLX	FZGVMLWJYB	4729688367 Dell Way	\N	KWGACTR	\N	0	Australia	2	FZGVMLWJYB@dell.com	4729688367	3	4957380072213710	2011/09	user11063	password	57	20000	F
11064	RHLCER	BLMOWIYVJI	6265163036 Dell Way	\N	SQJUKBV	\N	0	South Africa	2	BLMOWIYVJI@dell.com	6265163036	2	4743168328423053	2009/10	user11064	password	62	80000	F
11065	XCOCTP	OFELOCGYLY	8423319719 Dell Way	\N	OVTYWOT	\N	0	France	2	OFELOCGYLY@dell.com	8423319719	1	7824690879322589	2011/10	user11065	password	47	20000	M
11066	MQUGGI	LKUANAYZZN	4492554100 Dell Way	\N	USMQHFB	\N	0	Canada	2	LKUANAYZZN@dell.com	4492554100	5	7629270696081222	2008/03	user11066	password	77	100000	M
11067	LQYRZK	BTLPUKOTYI	9025901691 Dell Way	\N	MKZUQBX	\N	0	Australia	2	BTLPUKOTYI@dell.com	9025901691	4	2544968951027840	2008/06	user11067	password	19	100000	M
11068	RVOQFQ	KRFFBUYZDL	7682050626 Dell Way	\N	KCFAECA	\N	0	Australia	2	KRFFBUYZDL@dell.com	7682050626	1	2641460439655930	2008/03	user11068	password	20	20000	M
11069	VPNBGY	TLDVFCVJOF	4784197455 Dell Way	\N	LTFQWGR	\N	0	Japan	2	TLDVFCVJOF@dell.com	4784197455	5	8228570649866016	2011/11	user11069	password	81	60000	M
11070	MAUSZO	ECJJFETTJF	4341312112 Dell Way	\N	MPVJVNZ	\N	0	Chile	2	ECJJFETTJF@dell.com	4341312112	4	8845683673396707	2009/08	user11070	password	46	20000	F
11071	KVVKJZ	MSJSXCLGIY	1909318753 Dell Way	\N	VDHRQHX	\N	0	Australia	2	MSJSXCLGIY@dell.com	1909318753	4	3512534991372377	2011/02	user11071	password	38	100000	M
11072	CTZLSM	ECEBFPINNE	5473286895 Dell Way	\N	RVVHDSI	\N	0	Chile	2	ECEBFPINNE@dell.com	5473286895	3	9938500907737764	2011/11	user11072	password	83	40000	M
11073	QFLJRP	MVRRLZFYEW	1822264240 Dell Way	\N	UZEXSMD	\N	0	Chile	2	MVRRLZFYEW@dell.com	1822264240	1	8823363344185055	2012/01	user11073	password	25	100000	M
11074	HJAZZM	VREGRJFVGZ	2365896337 Dell Way	\N	VLWOYAT	\N	0	Australia	2	VREGRJFVGZ@dell.com	2365896337	4	9999146307352932	2008/09	user11074	password	87	100000	F
11075	IVAIHV	ZMBRVGNCGI	3573364151 Dell Way	\N	ODWMDQN	\N	0	Chile	2	ZMBRVGNCGI@dell.com	3573364151	3	5234745500143618	2008/06	user11075	password	39	20000	M
11076	DBCLXC	XZUTFHWMPK	9027490765 Dell Way	\N	PMWTDJA	\N	0	France	2	XZUTFHWMPK@dell.com	9027490765	3	5074385803658515	2009/10	user11076	password	55	20000	M
11077	PGJMJG	LDARKWDAGT	1094450608 Dell Way	\N	NDMRNNC	\N	0	China	2	LDARKWDAGT@dell.com	1094450608	3	7739267480093987	2012/01	user11077	password	82	80000	M
11078	DCDMJO	QJGBGKBMDP	9297471565 Dell Way	\N	QPGDCJN	\N	0	Canada	2	QJGBGKBMDP@dell.com	9297471565	2	9266701506450772	2012/02	user11078	password	65	80000	F
11079	TTUDIK	MPMTZOFCDV	7932268629 Dell Way	\N	RKZUUMX	\N	0	Japan	2	MPMTZOFCDV@dell.com	7932268629	5	7143074115272612	2012/06	user11079	password	41	40000	F
11080	CAIKLV	AXOZLUBOQT	3127574236 Dell Way	\N	ZPNTCLL	\N	0	South Africa	2	AXOZLUBOQT@dell.com	3127574236	1	8179879876784981	2011/06	user11080	password	19	100000	M
11081	AGYMCY	JQYULZJBTJ	7217790597 Dell Way	\N	RHCTSOQ	\N	0	UK	2	JQYULZJBTJ@dell.com	7217790597	3	6808170270640404	2008/06	user11081	password	59	80000	F
11082	VQZXPI	ONDZNNBGWS	6000276987 Dell Way	\N	NZMGODE	\N	0	Chile	2	ONDZNNBGWS@dell.com	6000276987	5	4442427054978907	2008/05	user11082	password	21	60000	F
11083	RMDGUR	TYRGLSNILB	3526058664 Dell Way	\N	IYHWBLD	\N	0	Japan	2	TYRGLSNILB@dell.com	3526058664	3	6744053706992418	2011/07	user11083	password	28	100000	F
11084	PAMKRG	IJNUCADOBL	9554720672 Dell Way	\N	MIIOULF	\N	0	Australia	2	IJNUCADOBL@dell.com	9554720672	5	7645704150665552	2010/12	user11084	password	63	80000	M
11085	QFZIMI	RZCTZFIBRU	4575013759 Dell Way	\N	JZJELOG	\N	0	China	2	RZCTZFIBRU@dell.com	4575013759	5	9123716020025314	2009/08	user11085	password	64	100000	F
11086	WXOIFF	IIZIOIJFCT	2118856722 Dell Way	\N	FMXRBDB	\N	0	France	2	IIZIOIJFCT@dell.com	2118856722	5	8313797024078668	2011/08	user11086	password	73	100000	F
11087	RNVXTD	FSLUAVZDOF	8775348362 Dell Way	\N	QMWRQXD	\N	0	Russia	2	FSLUAVZDOF@dell.com	8775348362	5	5354828907176852	2010/09	user11087	password	49	100000	F
11088	YTGRWM	KIGLDGPSLF	9436136721 Dell Way	\N	EHXVFAP	\N	0	Australia	2	KIGLDGPSLF@dell.com	9436136721	1	5793613650836051	2011/07	user11088	password	51	100000	F
11089	FGCBTN	KAYNGNFSSK	9205558569 Dell Way	\N	ZPGFPVG	\N	0	Germany	2	KAYNGNFSSK@dell.com	9205558569	5	2612319315783679	2010/04	user11089	password	30	100000	F
11090	LZNEMY	ELLLYRDRCC	4375708907 Dell Way	\N	HIHXEOL	\N	0	Australia	2	ELLLYRDRCC@dell.com	4375708907	4	5589416969567538	2011/10	user11090	password	45	20000	F
11091	JQKVOO	GAZFRCWUFD	1896173196 Dell Way	\N	DNAHCMK	\N	0	France	2	GAZFRCWUFD@dell.com	1896173196	5	1978667980059981	2012/04	user11091	password	33	20000	M
11092	WMMKBT	LBYCDVXJYA	6536876513 Dell Way	\N	WZIZMSL	\N	0	Germany	2	LBYCDVXJYA@dell.com	6536876513	3	5131426171865314	2012/10	user11092	password	59	60000	M
11093	BZADTL	EROHMMRLMO	5797454037 Dell Way	\N	LVNXNZM	\N	0	Canada	2	EROHMMRLMO@dell.com	5797454037	5	1393452532123774	2009/07	user11093	password	59	100000	M
11094	OYRHKV	ZZDMLVYYJJ	7220128552 Dell Way	\N	TWHHWTL	\N	0	China	2	ZZDMLVYYJJ@dell.com	7220128552	3	7252737186383457	2008/01	user11094	password	62	80000	M
11095	OLYZHY	YKKKFIJPSD	4440433796 Dell Way	\N	MZLITWS	\N	0	France	2	YKKKFIJPSD@dell.com	4440433796	3	6555395016446710	2010/01	user11095	password	45	20000	M
11096	VAOCYN	MJYSRHHJKU	3084845775 Dell Way	\N	JVCCSVN	\N	0	Australia	2	MJYSRHHJKU@dell.com	3084845775	1	5814375306479633	2009/07	user11096	password	63	100000	F
11097	QKKPYX	YWQQDYAOSJ	1812317716 Dell Way	\N	JULBPYD	\N	0	South Africa	2	YWQQDYAOSJ@dell.com	1812317716	4	1958614213857799	2010/04	user11097	password	88	100000	M
11098	JHOIFM	FVCITCWLMG	2180165935 Dell Way	\N	GXHWWLS	\N	0	UK	2	FVCITCWLMG@dell.com	2180165935	5	6089115212205798	2010/10	user11098	password	52	40000	F
11099	UXMZKR	UNAOQXACDG	6638812119 Dell Way	\N	ALCXXVW	\N	0	Australia	2	UNAOQXACDG@dell.com	6638812119	3	5188637979328633	2010/11	user11099	password	79	60000	M
11100	TBRESM	RTAIRBKUHL	6941121273 Dell Way	\N	GKJEFFE	\N	0	South Africa	2	RTAIRBKUHL@dell.com	6941121273	4	3151387491729110	2010/06	user11100	password	76	40000	F
11101	VYLOKD	ILLZMWUUIA	1265212456 Dell Way	\N	EREKXJG	\N	0	Germany	2	ILLZMWUUIA@dell.com	1265212456	3	2078574243467301	2010/04	user11101	password	46	80000	F
11102	IGRTJA	FVZSSTMAUR	8094231955 Dell Way	\N	RZBOJID	\N	0	China	2	FVZSSTMAUR@dell.com	8094231955	2	9187968521378936	2008/08	user11102	password	69	20000	M
11103	YWSIWX	DVPVPCWJUO	5399558845 Dell Way	\N	JWDSEGC	\N	0	UK	2	DVPVPCWJUO@dell.com	5399558845	5	1196289625484496	2008/09	user11103	password	32	20000	M
11104	BUYXRC	THYIKVSEJB	8789626661 Dell Way	\N	BMUFTWE	\N	0	Chile	2	THYIKVSEJB@dell.com	8789626661	1	4118695193435997	2010/05	user11104	password	48	40000	F
11105	EEJWHD	EFMOAETKGU	4309768253 Dell Way	\N	XBZQXEW	\N	0	Russia	2	EFMOAETKGU@dell.com	4309768253	2	4113815224263817	2011/08	user11105	password	58	40000	M
11106	TPRASV	GEKHIDRPXO	3733495516 Dell Way	\N	QXFOCCI	\N	0	France	2	GEKHIDRPXO@dell.com	3733495516	4	2895040167961269	2012/03	user11106	password	48	80000	M
11107	ALZSHF	WRNFUEVSTL	1434941360 Dell Way	\N	QZASBJE	\N	0	China	2	WRNFUEVSTL@dell.com	1434941360	2	3653872591443360	2009/10	user11107	password	21	40000	M
11108	MGMTMJ	LZOGEJZYVP	8598377317 Dell Way	\N	XWIYFMI	\N	0	Chile	2	LZOGEJZYVP@dell.com	8598377317	4	5958261114079506	2011/08	user11108	password	78	60000	F
11109	CYXPHJ	PVPTFOSAEP	5296781206 Dell Way	\N	WMOCYWJ	\N	0	Russia	2	PVPTFOSAEP@dell.com	5296781206	5	4908009581267834	2008/09	user11109	password	81	40000	M
11110	UFKCOZ	YDTDSLEWBB	4517676483 Dell Way	\N	JPDHMMC	\N	0	UK	2	YDTDSLEWBB@dell.com	4517676483	3	1848481542430818	2008/05	user11110	password	45	100000	F
11111	OIHCIF	GCJZONVPPE	2036767636 Dell Way	\N	FSMSFPR	\N	0	Japan	2	GCJZONVPPE@dell.com	2036767636	4	7559430139139295	2010/02	user11111	password	66	80000	M
11112	ZAVIFB	KOAZCWORBU	9021359043 Dell Way	\N	KNMQDDG	\N	0	Chile	2	KOAZCWORBU@dell.com	9021359043	5	7737558456137777	2008/08	user11112	password	51	80000	M
11113	MNYRPJ	GQIJMXANSL	3827676533 Dell Way	\N	BECEIIK	\N	0	Chile	2	GQIJMXANSL@dell.com	3827676533	1	3057806145399809	2012/08	user11113	password	86	60000	F
11114	MOUBYB	RGKEELSWWU	5841589028 Dell Way	\N	BZYJHJP	\N	0	Japan	2	RGKEELSWWU@dell.com	5841589028	5	6078730524517596	2008/10	user11114	password	29	40000	F
11115	SBHQCZ	XMDBXWYUQZ	7638273694 Dell Way	\N	TPJBYYR	\N	0	France	2	XMDBXWYUQZ@dell.com	7638273694	2	6924207611475141	2010/05	user11115	password	85	80000	F
11116	ZZSBZP	OCRMZPGPPA	9697151985 Dell Way	\N	EYBDXTP	\N	0	Japan	2	OCRMZPGPPA@dell.com	9697151985	2	1993927867617458	2009/03	user11116	password	77	60000	F
11117	VDGUTU	XKGWANLQOQ	6530256708 Dell Way	\N	PQTMJJC	\N	0	China	2	XKGWANLQOQ@dell.com	6530256708	2	7075359711889178	2012/01	user11117	password	25	100000	M
11118	GFQZAN	KHJLUVBJLQ	4719075251 Dell Way	\N	ZEDINFR	\N	0	Canada	2	KHJLUVBJLQ@dell.com	4719075251	2	9628886974882336	2010/06	user11118	password	86	40000	M
11119	DXREKC	LUNGQPPBGO	9222027735 Dell Way	\N	GJXUPOY	\N	0	UK	2	LUNGQPPBGO@dell.com	9222027735	5	4859356857836247	2009/11	user11119	password	69	20000	M
11120	PTEZVP	UJVKYLMFZT	4471091613 Dell Way	\N	OXNDMMD	\N	0	China	2	UJVKYLMFZT@dell.com	4471091613	3	7715707924216986	2009/04	user11120	password	76	40000	M
11121	NJWJZQ	SUAQGNVFGK	3265986456 Dell Way	\N	DUOPGRZ	\N	0	Japan	2	SUAQGNVFGK@dell.com	3265986456	4	8764685860369355	2010/07	user11121	password	24	40000	F
11122	MFKLWC	GXTMKPSQZV	2325690304 Dell Way	\N	KNLRFKH	\N	0	France	2	GXTMKPSQZV@dell.com	2325690304	1	9797611014451832	2011/03	user11122	password	43	80000	M
11123	PDELGK	IZXTOPKOLU	9301810792 Dell Way	\N	BWMGHTS	\N	0	France	2	IZXTOPKOLU@dell.com	9301810792	4	1853623810689896	2008/01	user11123	password	78	100000	M
11124	ZBBFLK	EIETYOHJII	1365870639 Dell Way	\N	FVPMOIX	\N	0	France	2	EIETYOHJII@dell.com	1365870639	1	6990071969572455	2008/10	user11124	password	58	80000	M
11125	PVZBFE	KJXIXFRGNX	3763975905 Dell Way	\N	BDKQMHD	\N	0	Germany	2	KJXIXFRGNX@dell.com	3763975905	5	6586554033216090	2008/05	user11125	password	43	100000	M
11126	EYAKCK	TASRFKYTHA	6748440665 Dell Way	\N	XRRJZVX	\N	0	Chile	2	TASRFKYTHA@dell.com	6748440665	3	4898717487230897	2008/11	user11126	password	44	100000	F
11127	HYLKIF	KBWQLVJTWH	1746903097 Dell Way	\N	KNRKJOS	\N	0	Australia	2	KBWQLVJTWH@dell.com	1746903097	1	1042852735612541	2012/07	user11127	password	88	20000	M
11128	XLEGQP	INGTIPMFXX	2506698631 Dell Way	\N	TOICCAC	\N	0	Canada	2	INGTIPMFXX@dell.com	2506698631	1	2315021818503737	2011/01	user11128	password	28	60000	M
11129	PRGFGP	SMIBCVGZTZ	3749610919 Dell Way	\N	NCCQCFV	\N	0	Chile	2	SMIBCVGZTZ@dell.com	3749610919	5	9552384539972992	2009/02	user11129	password	48	40000	M
11130	BQXIFQ	VORXJYXDXL	8557291822 Dell Way	\N	FABIFWP	\N	0	Germany	2	VORXJYXDXL@dell.com	8557291822	3	9042155718430878	2012/12	user11130	password	37	80000	F
11131	XOJCEF	QWCAUAESLK	9106739707 Dell Way	\N	SNSYJIL	\N	0	Chile	2	QWCAUAESLK@dell.com	9106739707	2	2575480155646801	2012/08	user11131	password	77	100000	F
11132	JHPONG	KPGEQLWBVP	3543743893 Dell Way	\N	OONYWYE	\N	0	Russia	2	KPGEQLWBVP@dell.com	3543743893	2	6969559277407826	2012/03	user11132	password	61	40000	M
11133	XZCKFM	AMQQXMSTCH	7988775216 Dell Way	\N	HPGENKY	\N	0	South Africa	2	AMQQXMSTCH@dell.com	7988775216	4	7240048388950527	2012/03	user11133	password	22	60000	F
11134	APMGBN	SRDQEVJGDQ	4070338187 Dell Way	\N	WJUJUTE	\N	0	Germany	2	SRDQEVJGDQ@dell.com	4070338187	5	5579821681138129	2010/12	user11134	password	18	80000	M
11135	PDFRQY	IUONQXUTOQ	1912624119 Dell Way	\N	DIAXBFL	\N	0	France	2	IUONQXUTOQ@dell.com	1912624119	5	9517098655458540	2008/12	user11135	password	60	20000	M
11136	SGFJFO	ETCURXOFOR	9777210011 Dell Way	\N	NPOPUAZ	\N	0	UK	2	ETCURXOFOR@dell.com	9777210011	5	9634144552983344	2012/07	user11136	password	90	60000	F
11137	GSQLHU	FKPWHDBWUP	2152634405 Dell Way	\N	LJEGJEE	\N	0	China	2	FKPWHDBWUP@dell.com	2152634405	1	3725761157460511	2011/02	user11137	password	77	100000	F
11138	ONVVIA	GXWNAYKVNV	4362674574 Dell Way	\N	FSCPXGY	\N	0	Australia	2	GXWNAYKVNV@dell.com	4362674574	2	7148847327101976	2010/01	user11138	password	61	100000	M
11139	DRLLSR	JPFJNPFBLK	2537121855 Dell Way	\N	TNZRUYR	\N	0	Canada	2	JPFJNPFBLK@dell.com	2537121855	2	6820705947466195	2009/12	user11139	password	54	100000	F
11140	EGOWYX	MDHZSNAEXU	5635908490 Dell Way	\N	RXMMVDQ	\N	0	Australia	2	MDHZSNAEXU@dell.com	5635908490	2	3112617522478103	2010/10	user11140	password	22	60000	M
11141	IDWGBI	JIHCWIGUDY	3974033133 Dell Way	\N	RPKNTBN	\N	0	Chile	2	JIHCWIGUDY@dell.com	3974033133	4	7637210919056088	2008/10	user11141	password	41	20000	F
11142	LYJNGT	WOVSWBMAAE	9894267081 Dell Way	\N	PKRJMFP	\N	0	Russia	2	WOVSWBMAAE@dell.com	9894267081	2	9231198358815164	2012/08	user11142	password	18	100000	F
11143	YIQEBM	TWEPYRQYVF	5734058028 Dell Way	\N	JNPVTEQ	\N	0	Russia	2	TWEPYRQYVF@dell.com	5734058028	3	5891824401915074	2008/07	user11143	password	53	40000	F
11144	VYRWKK	SPARGQPCWY	9348220049 Dell Way	\N	QLUJQKC	\N	0	Canada	2	SPARGQPCWY@dell.com	9348220049	4	4059847028926015	2010/02	user11144	password	65	100000	M
11145	OPUZZN	OAEVQUYNTO	6637490381 Dell Way	\N	YNXOXZS	\N	0	South Africa	2	OAEVQUYNTO@dell.com	6637490381	1	3630922739394009	2011/09	user11145	password	34	80000	F
11146	VMGVAV	VERLZPYSDX	3434029453 Dell Way	\N	FBMDAFY	\N	0	Japan	2	VERLZPYSDX@dell.com	3434029453	2	4720705565530807	2012/06	user11146	password	25	40000	F
11147	PNCPJY	UBKTQJLUGR	9619393740 Dell Way	\N	VTUWYSN	\N	0	Chile	2	UBKTQJLUGR@dell.com	9619393740	5	2719039655756205	2010/01	user11147	password	51	80000	M
11148	ZVFJTZ	KDSBMEVTVR	9989001723 Dell Way	\N	MPNKHBQ	\N	0	Chile	2	KDSBMEVTVR@dell.com	9989001723	5	7200384531635792	2008/04	user11148	password	47	80000	F
11149	FWQZVA	DOCPSXJNPV	7294318986 Dell Way	\N	CCGKEWR	\N	0	Canada	2	DOCPSXJNPV@dell.com	7294318986	2	2850686560384929	2012/10	user11149	password	81	40000	M
11150	SWZOXC	CZSUXBIMWK	8743863310 Dell Way	\N	ODVTAMX	\N	0	Russia	2	CZSUXBIMWK@dell.com	8743863310	1	7110762796364725	2011/12	user11150	password	85	80000	M
11151	UPGRRJ	RJEOKMAHWP	4203334042 Dell Way	\N	KSIKFGD	\N	0	Australia	2	RJEOKMAHWP@dell.com	4203334042	4	7204100275412203	2009/09	user11151	password	40	20000	M
11152	XHEORV	YVJJHKQEZB	4340718690 Dell Way	\N	WHLBOOD	\N	0	South Africa	2	YVJJHKQEZB@dell.com	4340718690	5	3118370035197586	2008/02	user11152	password	38	60000	F
11153	OUPGPO	BZXIKNNJOK	4878776243 Dell Way	\N	RAMFPPC	\N	0	UK	2	BZXIKNNJOK@dell.com	4878776243	2	1571226131170988	2010/08	user11153	password	65	80000	F
11154	LFLBTM	AQVLEIUSSL	2042447775 Dell Way	\N	TERJUUI	\N	0	Chile	2	AQVLEIUSSL@dell.com	2042447775	3	8115462122019381	2011/01	user11154	password	46	100000	F
11155	PJNIWO	ZRZDAUWTFP	7397532811 Dell Way	\N	YXZTRIY	\N	0	Russia	2	ZRZDAUWTFP@dell.com	7397532811	4	5613477008882911	2011/02	user11155	password	50	40000	M
11156	VUBRIA	JIEJCADIQB	5575156607 Dell Way	\N	FPUWXTQ	\N	0	Japan	2	JIEJCADIQB@dell.com	5575156607	1	4433156628161669	2011/08	user11156	password	63	40000	F
11157	KLBSML	BQUDRYLHAQ	3595020885 Dell Way	\N	WUMUODK	\N	0	Australia	2	BQUDRYLHAQ@dell.com	3595020885	4	7487557368818671	2012/05	user11157	password	25	40000	M
11158	OJOAUP	RPSINDQNUN	5431595682 Dell Way	\N	IHHXKSZ	\N	0	Russia	2	RPSINDQNUN@dell.com	5431595682	4	6332536174450070	2012/10	user11158	password	82	80000	F
11159	GGJBVB	QOJESARMNA	6178267866 Dell Way	\N	TVXENWX	\N	0	Australia	2	QOJESARMNA@dell.com	6178267866	3	9340310931671412	2009/05	user11159	password	65	80000	M
11160	XBRTCH	HMLZNDMAEF	7843827900 Dell Way	\N	VBKJYHK	\N	0	Germany	2	HMLZNDMAEF@dell.com	7843827900	2	9110211960971356	2008/12	user11160	password	62	80000	M
11161	RKQURX	HDXUHJULPQ	7349251913 Dell Way	\N	NZAMGKA	\N	0	Australia	2	HDXUHJULPQ@dell.com	7349251913	5	2342212792020291	2011/07	user11161	password	82	60000	F
11162	HDZZBG	DZAKIVWXLK	8594567072 Dell Way	\N	XLXEVXF	\N	0	Germany	2	DZAKIVWXLK@dell.com	8594567072	2	2946265205275267	2009/03	user11162	password	72	60000	M
11163	XOMZVP	YVAHQWECHC	8137448373 Dell Way	\N	OEGKCLY	\N	0	UK	2	YVAHQWECHC@dell.com	8137448373	1	3682732271961868	2008/11	user11163	password	81	60000	M
11164	LAUGPS	BQASMFVTHJ	8785568056 Dell Way	\N	YOTAZSY	\N	0	Russia	2	BQASMFVTHJ@dell.com	8785568056	2	8259817052166910	2011/02	user11164	password	42	60000	M
11165	IKUYCW	ODOBIJVPTT	9450037189 Dell Way	\N	DNUDFSX	\N	0	Australia	2	ODOBIJVPTT@dell.com	9450037189	4	8745036453939975	2008/01	user11165	password	51	60000	F
11166	VJJYFY	BTZJDVZXPC	8833518418 Dell Way	\N	KJGQBDS	\N	0	UK	2	BTZJDVZXPC@dell.com	8833518418	3	1393458382692188	2012/01	user11166	password	63	40000	M
11167	ZRVEPX	YPHCKGAZJL	4191031365 Dell Way	\N	JPBKTUK	\N	0	Japan	2	YPHCKGAZJL@dell.com	4191031365	3	6012495330069215	2009/01	user11167	password	82	40000	F
11168	OCGEZF	UHHEOIEXTO	8310545021 Dell Way	\N	NUYHOJX	\N	0	UK	2	UHHEOIEXTO@dell.com	8310545021	3	3840397266205400	2012/05	user11168	password	60	100000	M
11169	RFCRKW	YSBMAGKTUX	6109917566 Dell Way	\N	OTEDCCB	\N	0	UK	2	YSBMAGKTUX@dell.com	6109917566	2	8231268654577435	2012/12	user11169	password	73	100000	M
11170	YYHIVF	AWSBDCUXZI	8757896736 Dell Way	\N	RELTHNR	\N	0	South Africa	2	AWSBDCUXZI@dell.com	8757896736	3	8011509587056936	2012/03	user11170	password	63	60000	F
11171	ORNJXO	GPPJRKHRTY	8937937707 Dell Way	\N	WFSESKA	\N	0	Germany	2	GPPJRKHRTY@dell.com	8937937707	4	4302318308968097	2008/06	user11171	password	74	40000	M
11172	LVJJJP	YZZQKHHDGE	2397728860 Dell Way	\N	IYIBJJP	\N	0	Chile	2	YZZQKHHDGE@dell.com	2397728860	5	4245959133841097	2010/10	user11172	password	66	60000	F
11173	MXOWNN	WMDGTLJZPS	4338967451 Dell Way	\N	YYUIHKO	\N	0	France	2	WMDGTLJZPS@dell.com	4338967451	5	1193845378700643	2008/07	user11173	password	60	40000	F
11174	MXXZKT	MNAFYKFODE	9640860297 Dell Way	\N	MXMUHBG	\N	0	Japan	2	MNAFYKFODE@dell.com	9640860297	2	8024752025958151	2010/10	user11174	password	26	60000	F
11175	ANHLHT	YHZXRFMUJZ	3333865794 Dell Way	\N	RVTZWAQ	\N	0	South Africa	2	YHZXRFMUJZ@dell.com	3333865794	3	4383951134979725	2008/07	user11175	password	88	60000	M
11176	MSZTMY	BLWSQINAIF	2851878379 Dell Way	\N	VCESCUO	\N	0	China	2	BLWSQINAIF@dell.com	2851878379	5	4945981685537845	2011/11	user11176	password	79	40000	F
11177	OGDAEF	MAYCJLCRRY	2377200494 Dell Way	\N	UVRWQFF	\N	0	South Africa	2	MAYCJLCRRY@dell.com	2377200494	4	6161365964449943	2008/06	user11177	password	79	60000	F
11178	CPBHUN	ISQRESJVRD	8749295894 Dell Way	\N	RIAHOFD	\N	0	Russia	2	ISQRESJVRD@dell.com	8749295894	4	7986432906705887	2009/07	user11178	password	34	40000	M
11179	VLYPYG	IOYMHIIYLZ	2042104830 Dell Way	\N	HMGWRKP	\N	0	Germany	2	IOYMHIIYLZ@dell.com	2042104830	2	8996388020925225	2011/08	user11179	password	37	40000	F
11180	SHAQNI	FLVMTDLFCT	6371279040 Dell Way	\N	RJQJUFX	\N	0	South Africa	2	FLVMTDLFCT@dell.com	6371279040	4	6075591593980790	2008/01	user11180	password	83	60000	M
11181	EPKRYQ	DTCXXOCAIU	8387064807 Dell Way	\N	JYDDEBA	\N	0	Russia	2	DTCXXOCAIU@dell.com	8387064807	3	9702246652916076	2012/06	user11181	password	58	80000	M
11182	EBJCRM	WUKUINURHE	9472115298 Dell Way	\N	QLHUMIP	\N	0	China	2	WUKUINURHE@dell.com	9472115298	3	2640341124497354	2010/02	user11182	password	77	20000	F
11183	WLJNYG	IIARWUIDYY	9061712156 Dell Way	\N	PGTCPIK	\N	0	Germany	2	IIARWUIDYY@dell.com	9061712156	3	9774303188081832	2008/05	user11183	password	23	40000	F
11184	OQUMXC	VXURRCVQBL	5373829554 Dell Way	\N	XUNMDXA	\N	0	Australia	2	VXURRCVQBL@dell.com	5373829554	5	1442218930926174	2012/01	user11184	password	41	20000	M
11185	ZYCWBY	UVQLYMCZXZ	5243875463 Dell Way	\N	ULMYJMZ	\N	0	South Africa	2	UVQLYMCZXZ@dell.com	5243875463	1	7497152171097697	2010/05	user11185	password	80	20000	F
11186	UGFWFZ	RVLPINOGNJ	3309007357 Dell Way	\N	RZHBLGX	\N	0	UK	2	RVLPINOGNJ@dell.com	3309007357	4	5142406825441867	2010/06	user11186	password	63	100000	F
11187	WDDCCU	YNKGAZNNIE	7585459297 Dell Way	\N	MPGYWDW	\N	0	Canada	2	YNKGAZNNIE@dell.com	7585459297	2	7410226072650403	2009/12	user11187	password	64	60000	M
11188	TPXVKV	IUCJUPXDUK	5464890521 Dell Way	\N	TAIPDES	\N	0	South Africa	2	IUCJUPXDUK@dell.com	5464890521	3	1738446117844432	2010/01	user11188	password	58	40000	M
11189	EDQOZZ	JCJDRGHMQA	7741130010 Dell Way	\N	NZQREIN	\N	0	Japan	2	JCJDRGHMQA@dell.com	7741130010	4	1700749023817479	2012/03	user11189	password	41	80000	F
11190	MGWLGG	OPKGWRSMSF	1227596042 Dell Way	\N	MIWQQKH	\N	0	China	2	OPKGWRSMSF@dell.com	1227596042	2	2818421509582549	2008/09	user11190	password	77	60000	F
11191	BKPIRD	XBJTTBGLHS	9692559553 Dell Way	\N	TEJKPQU	\N	0	Japan	2	XBJTTBGLHS@dell.com	9692559553	1	8256457836832852	2011/10	user11191	password	42	80000	M
11192	TJFKMD	LVXFXEQFXK	6740682907 Dell Way	\N	KGVZWQP	\N	0	South Africa	2	LVXFXEQFXK@dell.com	6740682907	2	5179169341456145	2010/09	user11192	password	34	40000	F
11193	PPWBSI	XQNVUEBSOL	4318282351 Dell Way	\N	YKKVAZQ	\N	0	Japan	2	XQNVUEBSOL@dell.com	4318282351	1	2115790212061256	2008/05	user11193	password	53	60000	M
11194	BKZUSX	LGSGKTYZFX	5094202600 Dell Way	\N	JPSKPIB	\N	0	UK	2	LGSGKTYZFX@dell.com	5094202600	1	1334110007155686	2011/09	user11194	password	60	80000	M
11195	ZSOSPZ	YIFJCEIHBS	4063182075 Dell Way	\N	XTCMCEL	\N	0	Germany	2	YIFJCEIHBS@dell.com	4063182075	3	4049580748192966	2008/01	user11195	password	22	80000	F
11196	THTJHS	SNBVRKDSDA	4779319891 Dell Way	\N	LGNNKYB	\N	0	Russia	2	SNBVRKDSDA@dell.com	4779319891	3	7750379012897611	2010/06	user11196	password	54	60000	F
11197	UHQCZI	PBEGMHYQIK	4743939631 Dell Way	\N	WVYGUAZ	\N	0	Canada	2	PBEGMHYQIK@dell.com	4743939631	4	7077300797216595	2012/04	user11197	password	32	20000	F
11198	MTDMCS	NGZAOXQWIM	5439118239 Dell Way	\N	SGTMGTR	\N	0	Japan	2	NGZAOXQWIM@dell.com	5439118239	2	5873714210465551	2011/07	user11198	password	67	80000	F
11199	LYMNRA	UQBIORFWEX	4626113474 Dell Way	\N	CXJJRBZ	\N	0	Canada	2	UQBIORFWEX@dell.com	4626113474	3	9126865394413472	2012/03	user11199	password	69	100000	M
11200	QMEIMY	YNHNFMKJKN	4628095908 Dell Way	\N	HTWZVWD	\N	0	Chile	2	YNHNFMKJKN@dell.com	4628095908	1	2518661467824131	2011/09	user11200	password	28	40000	F
11201	PLRCKQ	QSEVEPFPCN	6767133004 Dell Way	\N	IZMEVPJ	\N	0	Chile	2	QSEVEPFPCN@dell.com	6767133004	3	8617461289279164	2009/09	user11201	password	26	80000	F
11202	OLJYCZ	QHVVWBKYOT	8556841219 Dell Way	\N	XBXTRHZ	\N	0	Chile	2	QHVVWBKYOT@dell.com	8556841219	5	7012683389708400	2010/12	user11202	password	48	100000	F
11203	WFLYFC	FAXCBIBQCY	5404835295 Dell Way	\N	RASIHRQ	\N	0	Canada	2	FAXCBIBQCY@dell.com	5404835295	2	6967472187709064	2010/09	user11203	password	53	100000	M
11204	RINWKT	XIVZQWPSVG	5312179700 Dell Way	\N	TOPAFFE	\N	0	Russia	2	XIVZQWPSVG@dell.com	5312179700	5	2110731016844511	2008/04	user11204	password	19	80000	M
11205	JGWTAT	BWSSTILOOE	2843771050 Dell Way	\N	DDFIIJB	\N	0	South Africa	2	BWSSTILOOE@dell.com	2843771050	1	1001600675284862	2010/03	user11205	password	72	60000	M
11206	AJHADJ	WVBPDNESSH	8544374282 Dell Way	\N	WXQFHRA	\N	0	France	2	WVBPDNESSH@dell.com	8544374282	1	1099266313482075	2008/10	user11206	password	55	60000	M
11207	WVUZFR	VHHZUMRNUO	7986162468 Dell Way	\N	KKTSCTF	\N	0	UK	2	VHHZUMRNUO@dell.com	7986162468	2	9588087181095036	2010/09	user11207	password	55	40000	M
11208	JCPOUK	VCKQOCDIQO	7221705511 Dell Way	\N	TJGWDMU	\N	0	UK	2	VCKQOCDIQO@dell.com	7221705511	4	5048580589238554	2010/04	user11208	password	73	20000	M
11209	WQDRBZ	TLPINSRDGK	8335051388 Dell Way	\N	NNHRZBO	\N	0	Japan	2	TLPINSRDGK@dell.com	8335051388	1	1933480813167989	2008/10	user11209	password	27	80000	M
11210	TVIUUB	GJJTCAXILL	7209897442 Dell Way	\N	WTCVURN	\N	0	Japan	2	GJJTCAXILL@dell.com	7209897442	4	7154696223326028	2010/10	user11210	password	43	20000	M
11211	ELIYNO	IXHKYFTKQP	6277865495 Dell Way	\N	DSLXKYN	\N	0	Australia	2	IXHKYFTKQP@dell.com	6277865495	2	6044362165033818	2009/07	user11211	password	68	100000	M
11212	DERRSZ	OAKMFDWWSZ	6982146222 Dell Way	\N	PDXZCLB	\N	0	Japan	2	OAKMFDWWSZ@dell.com	6982146222	4	1383202235680073	2009/04	user11212	password	84	100000	F
11213	CRDUQS	VBEBEBXXBM	2650143420 Dell Way	\N	BZMDLOV	\N	0	Australia	2	VBEBEBXXBM@dell.com	2650143420	5	3915082906838507	2010/10	user11213	password	39	100000	M
11214	YCRPUM	QZNVBLSDXT	6736742751 Dell Way	\N	CKXNYTP	\N	0	Canada	2	QZNVBLSDXT@dell.com	6736742751	5	6762452407740057	2010/03	user11214	password	62	40000	F
11215	SZUNLL	NZGOKYRISU	8631975153 Dell Way	\N	SPHRJXV	\N	0	Australia	2	NZGOKYRISU@dell.com	8631975153	3	4878150321077556	2008/01	user11215	password	71	40000	M
11216	SAIELV	DSKORCWJWP	5928544610 Dell Way	\N	ZEHJCCJ	\N	0	UK	2	DSKORCWJWP@dell.com	5928544610	4	1042622451204806	2011/07	user11216	password	36	60000	F
11217	HSJTON	LYBDAYMXOM	9723748677 Dell Way	\N	BVVDYEB	\N	0	France	2	LYBDAYMXOM@dell.com	9723748677	1	1926989737432450	2010/04	user11217	password	55	80000	M
11218	FCJUPV	SRYTPLQEXS	9659801675 Dell Way	\N	ATVYYXL	\N	0	South Africa	2	SRYTPLQEXS@dell.com	9659801675	3	4408539862837643	2009/01	user11218	password	24	100000	F
11219	EHBTCU	LANBLEFJWF	2505207440 Dell Way	\N	CREAPQX	\N	0	Germany	2	LANBLEFJWF@dell.com	2505207440	2	8463589667808265	2009/05	user11219	password	71	60000	M
11220	AOHCIS	DWTOAZYXFA	3136756536 Dell Way	\N	OJADZYR	\N	0	Canada	2	DWTOAZYXFA@dell.com	3136756536	3	4489201087970287	2011/04	user11220	password	83	20000	F
11221	LLJUEM	RYBSXZPCAD	5532230643 Dell Way	\N	MBHMZZR	\N	0	Chile	2	RYBSXZPCAD@dell.com	5532230643	1	8549679285846651	2011/12	user11221	password	89	20000	F
11222	LJEPWW	NXOLXDOXHB	3264416714 Dell Way	\N	YOOYOFE	\N	0	Australia	2	NXOLXDOXHB@dell.com	3264416714	1	8411951524205507	2008/01	user11222	password	79	60000	F
11223	FTACPO	AEAXHPVOQU	9407296377 Dell Way	\N	DETSKXT	\N	0	Japan	2	AEAXHPVOQU@dell.com	9407296377	3	8544413673691452	2012/06	user11223	password	48	40000	M
11224	EKTUZT	YZRGONUFHY	1036462121 Dell Way	\N	KAQUYKL	\N	0	South Africa	2	YZRGONUFHY@dell.com	1036462121	2	8429029651917518	2010/09	user11224	password	32	20000	M
11225	PVROPQ	OHXDURICQT	3706037801 Dell Way	\N	DHOCRAZ	\N	0	Japan	2	OHXDURICQT@dell.com	3706037801	4	2156538528390229	2008/12	user11225	password	34	100000	M
11226	BPDRGR	YDUTVDVLWY	8176976398 Dell Way	\N	SLAKLAC	\N	0	Russia	2	YDUTVDVLWY@dell.com	8176976398	2	7690029351972044	2011/06	user11226	password	65	40000	M
11227	GNEMED	PZWKDRWZQP	3660192206 Dell Way	\N	KRZWRBP	\N	0	France	2	PZWKDRWZQP@dell.com	3660192206	2	3304715467151254	2011/12	user11227	password	63	40000	F
11228	DLSIOI	HLSKDPKUEV	6281895716 Dell Way	\N	LERCGGP	\N	0	Germany	2	HLSKDPKUEV@dell.com	6281895716	5	3412092621438205	2010/06	user11228	password	56	80000	M
11229	ZMXNUF	ZNPCCAWHWI	8653419373 Dell Way	\N	LNLRUAF	\N	0	China	2	ZNPCCAWHWI@dell.com	8653419373	3	9490269411355258	2009/12	user11229	password	70	100000	M
11230	FUMZZL	NPOPQLXMTI	6897974555 Dell Way	\N	AEZUEEE	\N	0	Australia	2	NPOPQLXMTI@dell.com	6897974555	1	4094384648371488	2011/11	user11230	password	35	60000	F
11231	ABAANN	QCDGNASGJS	8500463621 Dell Way	\N	LJNQOSQ	\N	0	Chile	2	QCDGNASGJS@dell.com	8500463621	5	8616590698715300	2011/03	user11231	password	50	80000	F
11232	NTHBHY	DLERMXYVPJ	6623721189 Dell Way	\N	EDZTVQY	\N	0	Japan	2	DLERMXYVPJ@dell.com	6623721189	4	4141230049077422	2012/03	user11232	password	23	20000	M
11233	VLUDJX	ONPAKNWAWB	5529771644 Dell Way	\N	DWUZMSR	\N	0	Canada	2	ONPAKNWAWB@dell.com	5529771644	1	9734481147490444	2011/01	user11233	password	25	60000	M
11234	OGBXEQ	LTRWGNWDOA	7097619201 Dell Way	\N	ZJAMCRP	\N	0	Germany	2	LTRWGNWDOA@dell.com	7097619201	3	3769149257801473	2011/08	user11234	password	74	80000	F
11235	ATCEJO	YAKFOHIDHI	9393078763 Dell Way	\N	MIUOAJD	\N	0	Japan	2	YAKFOHIDHI@dell.com	9393078763	3	4939010896719992	2010/03	user11235	password	26	80000	F
11236	WXKFLJ	FVOUCXXKFJ	5867465656 Dell Way	\N	TAYTKCK	\N	0	China	2	FVOUCXXKFJ@dell.com	5867465656	5	9254075527191164	2011/12	user11236	password	69	100000	M
11237	PKAAUG	WIBZGYJLIC	2098738906 Dell Way	\N	MGWWJGE	\N	0	South Africa	2	WIBZGYJLIC@dell.com	2098738906	1	6951280940789730	2008/10	user11237	password	66	100000	F
11238	CYLWFI	FGHLFRXNUJ	5569853196 Dell Way	\N	UQFDXKB	\N	0	Australia	2	FGHLFRXNUJ@dell.com	5569853196	4	2017310988623649	2009/05	user11238	password	20	80000	F
11239	ZEIFNN	LUYQLWEGFY	8632701123 Dell Way	\N	WLCTVDU	\N	0	China	2	LUYQLWEGFY@dell.com	8632701123	5	6978557133115829	2009/12	user11239	password	47	80000	M
11240	PZCCNO	WLEIIIONHL	8690175904 Dell Way	\N	YKEUNZD	\N	0	China	2	WLEIIIONHL@dell.com	8690175904	5	6346701439935715	2011/03	user11240	password	36	80000	M
11241	GUWTIT	FMCNVQBDBA	7772582481 Dell Way	\N	NGUBFYL	\N	0	Australia	2	FMCNVQBDBA@dell.com	7772582481	1	8671863369643689	2012/04	user11241	password	56	80000	M
11242	HQGPJM	CLZYCABEAP	1750772289 Dell Way	\N	LVQRUBT	\N	0	Germany	2	CLZYCABEAP@dell.com	1750772289	3	5399430564604700	2009/02	user11242	password	35	100000	F
11243	WDAGPD	SPBUQDZRSL	4959950043 Dell Way	\N	MJCGLVU	\N	0	Germany	2	SPBUQDZRSL@dell.com	4959950043	2	8871651966124774	2010/07	user11243	password	73	100000	F
11244	XAPNEH	DGCTJCKCNX	3188539967 Dell Way	\N	MQEXMYK	\N	0	UK	2	DGCTJCKCNX@dell.com	3188539967	2	5341297560837120	2011/01	user11244	password	52	20000	M
11245	MTMQBP	WEJGHTJUQV	4678692311 Dell Way	\N	LUSXTDV	\N	0	UK	2	WEJGHTJUQV@dell.com	4678692311	2	7850395297165961	2010/10	user11245	password	84	60000	F
11246	RWYSMV	XVBEOLZFGK	5379039217 Dell Way	\N	AZITCET	\N	0	Germany	2	XVBEOLZFGK@dell.com	5379039217	3	9759943839628250	2009/06	user11246	password	45	60000	F
11247	GMVSHS	OJXDUWIBHJ	4533336548 Dell Way	\N	BQCEUWR	\N	0	Chile	2	OJXDUWIBHJ@dell.com	4533336548	4	5950852446258069	2012/01	user11247	password	25	100000	F
11248	PSAXLO	GISBEBDMKE	7247884936 Dell Way	\N	CNIWKAE	\N	0	Russia	2	GISBEBDMKE@dell.com	7247884936	4	6394848131109030	2011/10	user11248	password	54	20000	F
11249	FAHRPO	ZIQEJTQTYT	5470567923 Dell Way	\N	HHQRHUL	\N	0	UK	2	ZIQEJTQTYT@dell.com	5470567923	1	7537604727782310	2009/07	user11249	password	72	80000	M
11250	UALKOL	SEPCYGVWAD	3688280303 Dell Way	\N	DQULLGL	\N	0	UK	2	SEPCYGVWAD@dell.com	3688280303	1	3114836761262268	2012/11	user11250	password	87	80000	M
11251	ZCCNNU	SDWRKSNKWR	7354958305 Dell Way	\N	BQCMXOK	\N	0	Canada	2	SDWRKSNKWR@dell.com	7354958305	4	1477620628196746	2011/08	user11251	password	68	40000	M
11252	UKCHFV	LCMVUAGRRH	8235326279 Dell Way	\N	IUTFIEK	\N	0	Australia	2	LCMVUAGRRH@dell.com	8235326279	3	6903471956495196	2009/02	user11252	password	88	100000	M
11253	JAGOVR	QINLITCABK	5414895331 Dell Way	\N	UVQDZAE	\N	0	Russia	2	QINLITCABK@dell.com	5414895331	5	2536672404967248	2011/10	user11253	password	26	60000	F
11254	DVRZMI	HZTPTVPUGK	5685357276 Dell Way	\N	PWNOXSI	\N	0	China	2	HZTPTVPUGK@dell.com	5685357276	3	1261748362332582	2009/08	user11254	password	62	60000	M
11255	LDSXLA	XFPQAFKHPA	4821211952 Dell Way	\N	DDOAVXK	\N	0	China	2	XFPQAFKHPA@dell.com	4821211952	3	6741730239242316	2008/01	user11255	password	24	100000	F
11256	FOKROH	WEYXJJEYJI	3059430885 Dell Way	\N	BYJWVUF	\N	0	Chile	2	WEYXJJEYJI@dell.com	3059430885	5	3795361656695604	2009/12	user11256	password	26	80000	F
11257	REVFLS	JKPTTURCCT	7459345760 Dell Way	\N	ALQWFWD	\N	0	France	2	JKPTTURCCT@dell.com	7459345760	3	7700042520184071	2011/07	user11257	password	55	100000	F
11258	RQLDIU	NYNHSFJUZK	8519026498 Dell Way	\N	GQHMNKY	\N	0	Chile	2	NYNHSFJUZK@dell.com	8519026498	4	8971475441474468	2009/03	user11258	password	69	80000	M
11259	JBASWN	QJVIPEDPPK	5266894641 Dell Way	\N	GWWTHUZ	\N	0	Canada	2	QJVIPEDPPK@dell.com	5266894641	5	5497464692220092	2011/07	user11259	password	26	60000	M
11260	EOQACG	KXPZCTPRDV	5210819156 Dell Way	\N	OZPVUPY	\N	0	Chile	2	KXPZCTPRDV@dell.com	5210819156	3	9332988207694144	2008/07	user11260	password	51	100000	M
11261	APSCWC	ZLCCESUINI	5897151176 Dell Way	\N	HDECTCI	\N	0	Chile	2	ZLCCESUINI@dell.com	5897151176	2	3230002430267632	2008/09	user11261	password	34	100000	M
11262	VNVRQV	DSXHKRQYAX	6564508026 Dell Way	\N	CEAVHJA	\N	0	South Africa	2	DSXHKRQYAX@dell.com	6564508026	2	9360260091722012	2009/07	user11262	password	71	20000	F
11263	GYZWTC	PRKAJAZJYB	2946445080 Dell Way	\N	OYXWIYR	\N	0	UK	2	PRKAJAZJYB@dell.com	2946445080	4	3504995574243367	2011/05	user11263	password	45	20000	M
11264	IAMBDC	TOCCPCMOEB	2784868353 Dell Way	\N	NBXVZPT	\N	0	Chile	2	TOCCPCMOEB@dell.com	2784868353	1	9364743156824262	2010/05	user11264	password	88	20000	M
11265	ZQUDSN	SVQHYDWCEJ	9797062708 Dell Way	\N	DCFDRYJ	\N	0	South Africa	2	SVQHYDWCEJ@dell.com	9797062708	2	4763716157525778	2009/03	user11265	password	59	20000	F
11266	FWJYKC	UBKSEGUJQX	7122833449 Dell Way	\N	MVBDUKA	\N	0	Russia	2	UBKSEGUJQX@dell.com	7122833449	3	2169994223862886	2012/12	user11266	password	34	20000	F
11267	CODNQX	OAPTHKDXIP	2675612604 Dell Way	\N	SJTMUTG	\N	0	France	2	OAPTHKDXIP@dell.com	2675612604	2	4385998548939824	2008/08	user11267	password	57	40000	M
11268	CNFTLU	TBNBLRYTHR	8155210900 Dell Way	\N	DAEXUKI	\N	0	UK	2	TBNBLRYTHR@dell.com	8155210900	4	2278683837503195	2009/04	user11268	password	56	20000	F
11269	BHCNBW	OPXZHWTONW	8255612894 Dell Way	\N	OSTICCH	\N	0	UK	2	OPXZHWTONW@dell.com	8255612894	3	3700340881943703	2008/12	user11269	password	46	60000	F
11270	RNNTJC	JHCQDVERST	8034340617 Dell Way	\N	JLBLOJJ	\N	0	China	2	JHCQDVERST@dell.com	8034340617	4	4705652912147343	2011/01	user11270	password	78	80000	M
11271	JHNSJW	AMNDHSUZLD	6644644532 Dell Way	\N	LNPZWZI	\N	0	Japan	2	AMNDHSUZLD@dell.com	6644644532	4	4471308063250035	2011/07	user11271	password	29	60000	M
11272	LYRVVR	HIUPAPPMTB	1958528374 Dell Way	\N	ZIAVHJM	\N	0	UK	2	HIUPAPPMTB@dell.com	1958528374	5	6452612046152354	2011/01	user11272	password	20	80000	F
11273	ZGHUYP	DTFDIUPBVP	7834540420 Dell Way	\N	KWKRGXP	\N	0	China	2	DTFDIUPBVP@dell.com	7834540420	2	1220249123871326	2011/04	user11273	password	64	40000	F
11274	XNAVDD	OIHXDXYYMI	8690681446 Dell Way	\N	VXABUQK	\N	0	Germany	2	OIHXDXYYMI@dell.com	8690681446	3	3866530527360737	2008/01	user11274	password	58	40000	M
11275	CIVFMJ	OTHRQFQDOL	4085848446 Dell Way	\N	APNUGXI	\N	0	Australia	2	OTHRQFQDOL@dell.com	4085848446	4	2782615603413433	2010/03	user11275	password	56	40000	F
11276	WENJOB	CVSTBJWQUW	6914589205 Dell Way	\N	FIRMFAO	\N	0	Germany	2	CVSTBJWQUW@dell.com	6914589205	4	9818868388421834	2012/04	user11276	password	44	20000	F
11277	ORNCTQ	YMJAVGQQDW	6925371329 Dell Way	\N	YUIEVXT	\N	0	France	2	YMJAVGQQDW@dell.com	6925371329	4	3993489567656070	2012/01	user11277	password	54	20000	M
11278	EQTYGR	KQSGWIWAFV	5069330510 Dell Way	\N	VOZQLSC	\N	0	Canada	2	KQSGWIWAFV@dell.com	5069330510	3	1474746083840727	2010/12	user11278	password	29	20000	F
11279	UXBAPL	QHSNQPNVKI	5088211991 Dell Way	\N	KJYVCAY	\N	0	Germany	2	QHSNQPNVKI@dell.com	5088211991	5	1856317846570164	2009/02	user11279	password	36	60000	M
11280	ENYTZP	ARCRGQMRZW	6847416834 Dell Way	\N	BXSDYRS	\N	0	France	2	ARCRGQMRZW@dell.com	6847416834	5	8049529468175025	2012/01	user11280	password	36	80000	F
11281	URZTHZ	LKRSADJAAK	1662107088 Dell Way	\N	YTOWKGH	\N	0	Australia	2	LKRSADJAAK@dell.com	1662107088	1	8668728156480939	2008/05	user11281	password	60	40000	F
11282	HIWOII	ZZAADKADUY	2682841405 Dell Way	\N	XJVHQCI	\N	0	Russia	2	ZZAADKADUY@dell.com	2682841405	1	8580467814113946	2010/10	user11282	password	32	80000	F
11283	NNQVVP	UWPYGPBBNZ	8100400856 Dell Way	\N	LIGBLPU	\N	0	Japan	2	UWPYGPBBNZ@dell.com	8100400856	4	2473409483674913	2010/10	user11283	password	76	80000	F
11284	IGEDVZ	ALXHAYIOYT	2942108694 Dell Way	\N	XEVJUPZ	\N	0	Germany	2	ALXHAYIOYT@dell.com	2942108694	1	2208178448956460	2008/12	user11284	password	73	40000	F
11285	ANLWML	HJSIIBWGVU	3531937621 Dell Way	\N	LQDFGDT	\N	0	France	2	HJSIIBWGVU@dell.com	3531937621	5	5470363723579794	2009/08	user11285	password	80	60000	M
11286	JYNVKV	FCDNEATZUE	1507465287 Dell Way	\N	QXKXBEJ	\N	0	China	2	FCDNEATZUE@dell.com	1507465287	5	6075351871550084	2011/09	user11286	password	24	40000	F
11287	AYXLTC	OWQSXKRRPI	4681057390 Dell Way	\N	PZFQDOY	\N	0	Canada	2	OWQSXKRRPI@dell.com	4681057390	3	9155077116098256	2008/08	user11287	password	39	20000	M
11288	FCBZEP	VVHTFZKUHZ	1805689475 Dell Way	\N	TMQXBOC	\N	0	France	2	VVHTFZKUHZ@dell.com	1805689475	5	6118480531033129	2011/04	user11288	password	72	40000	M
11289	VKMAAI	VIBAHLVPLO	5750408288 Dell Way	\N	CCMDQOP	\N	0	Russia	2	VIBAHLVPLO@dell.com	5750408288	1	4890967872925103	2012/11	user11289	password	73	40000	M
11290	EUTEDO	MEPTQKJCZL	3730856428 Dell Way	\N	ELOVZDO	\N	0	Germany	2	MEPTQKJCZL@dell.com	3730856428	1	3874829349108040	2009/10	user11290	password	64	100000	M
11291	LRBOGO	TVHKGRMFCR	1462177998 Dell Way	\N	QQMQUBD	\N	0	Canada	2	TVHKGRMFCR@dell.com	1462177998	3	3798080293461680	2012/02	user11291	password	35	80000	M
11292	XUCEIW	AQGGHSLKKC	3784854480 Dell Way	\N	BWSVXWY	\N	0	UK	2	AQGGHSLKKC@dell.com	3784854480	2	8033505876082928	2010/07	user11292	password	55	100000	F
11293	HBPQXP	HEVPXHZHJA	1596339478 Dell Way	\N	DCWBZUA	\N	0	Chile	2	HEVPXHZHJA@dell.com	1596339478	5	7134573637507857	2010/04	user11293	password	63	100000	M
11294	RPHPEO	TADQHDXRDB	9506540575 Dell Way	\N	UZCTUDB	\N	0	South Africa	2	TADQHDXRDB@dell.com	9506540575	4	4903258995153010	2009/05	user11294	password	49	100000	F
11295	AEQFSJ	FWZNZXFDYA	5984397610 Dell Way	\N	DBUXEVU	\N	0	Canada	2	FWZNZXFDYA@dell.com	5984397610	2	4541014153510332	2012/08	user11295	password	38	100000	M
11296	LOWEXC	BXQBUWETWH	2660566522 Dell Way	\N	URFZMZC	\N	0	Australia	2	BXQBUWETWH@dell.com	2660566522	3	9568577928468586	2012/10	user11296	password	82	60000	F
11297	LJKJML	GDMBZRVWYP	3018011174 Dell Way	\N	NDPADSB	\N	0	China	2	GDMBZRVWYP@dell.com	3018011174	1	2207410511560738	2008/11	user11297	password	63	40000	F
11298	ZRRMDY	PQAOHVLFLY	1495845479 Dell Way	\N	JAZNTAU	\N	0	UK	2	PQAOHVLFLY@dell.com	1495845479	5	9864565983880312	2012/07	user11298	password	35	40000	M
11299	XZBAXQ	QXFYTQEEPN	8054505929 Dell Way	\N	EOAYPVX	\N	0	Japan	2	QXFYTQEEPN@dell.com	8054505929	5	6591926091350616	2009/02	user11299	password	84	100000	F
11300	XZBVPS	TVQMMUQBIV	5986730126 Dell Way	\N	QJTGFRX	\N	0	UK	2	TVQMMUQBIV@dell.com	5986730126	3	4109550641849637	2011/06	user11300	password	37	80000	F
11301	GUDVMX	RDJDYZEGVV	5381884160 Dell Way	\N	QPBVGYV	\N	0	Russia	2	RDJDYZEGVV@dell.com	5381884160	1	5329381918534637	2012/06	user11301	password	32	40000	M
11302	ZKNMIE	QRHORMVMHL	3776538907 Dell Way	\N	BJHHIDC	\N	0	South Africa	2	QRHORMVMHL@dell.com	3776538907	3	7612392812035979	2011/10	user11302	password	18	60000	M
11303	KYGTDW	KLLBYGOFSP	6301805460 Dell Way	\N	PAXXDAS	\N	0	France	2	KLLBYGOFSP@dell.com	6301805460	3	2801741681527346	2009/06	user11303	password	64	20000	M
11304	PKPSGA	ESBCYQIRFX	9750450387 Dell Way	\N	RDVUDNG	\N	0	Russia	2	ESBCYQIRFX@dell.com	9750450387	3	1910591373685747	2010/02	user11304	password	35	40000	M
11305	QXKXXO	PZROPZFVXW	4548476616 Dell Way	\N	YSRCGYV	\N	0	Chile	2	PZROPZFVXW@dell.com	4548476616	5	6745877692941577	2010/02	user11305	password	85	20000	M
11306	VORSDH	RVVHUBCSYB	8795737370 Dell Way	\N	LQDROYX	\N	0	UK	2	RVVHUBCSYB@dell.com	8795737370	3	4917891945689917	2008/06	user11306	password	61	100000	F
11307	ENAIUS	DQZYRBQPCB	2603850731 Dell Way	\N	FGTUEQT	\N	0	Australia	2	DQZYRBQPCB@dell.com	2603850731	1	1749301000963896	2011/10	user11307	password	83	100000	M
11308	KYGFQJ	VPHNRYDUAJ	1625703816 Dell Way	\N	BTDFKXH	\N	0	Germany	2	VPHNRYDUAJ@dell.com	1625703816	2	2947934892959893	2012/04	user11308	password	28	80000	M
11309	BAXSKT	HRGZQKUQTV	7365495966 Dell Way	\N	JXBUUIJ	\N	0	South Africa	2	HRGZQKUQTV@dell.com	7365495966	3	7441628839354963	2012/09	user11309	password	54	80000	M
11310	NOMXHU	POUFYOVSJF	9250896422 Dell Way	\N	PLZKTJH	\N	0	France	2	POUFYOVSJF@dell.com	9250896422	5	5085645067505539	2011/06	user11310	password	26	60000	F
11311	RXYYRN	MMTLAPDKUS	4720349418 Dell Way	\N	VUDPDKC	\N	0	Australia	2	MMTLAPDKUS@dell.com	4720349418	3	7218196092639119	2012/08	user11311	password	25	100000	F
11312	ZVGRJT	DCFERIPMBK	6702540122 Dell Way	\N	HEALPCM	\N	0	Australia	2	DCFERIPMBK@dell.com	6702540122	1	9220042640808972	2009/04	user11312	password	78	60000	F
11313	RWYAQC	DVHVDWHEGO	6947211413 Dell Way	\N	JHZYJMZ	\N	0	Australia	2	DVHVDWHEGO@dell.com	6947211413	5	3685855193063617	2012/09	user11313	password	83	40000	F
11314	TEKKHO	FOJJKQOQFX	7495879643 Dell Way	\N	YFWIRVI	\N	0	China	2	FOJJKQOQFX@dell.com	7495879643	4	3604141460731626	2010/07	user11314	password	54	100000	F
11315	RGSYUY	MDHWUWNATM	7779409424 Dell Way	\N	FQUXMDG	\N	0	Chile	2	MDHWUWNATM@dell.com	7779409424	3	6766733154654504	2009/01	user11315	password	51	60000	M
11316	RHRMFE	PMBKIPKCBQ	3652266782 Dell Way	\N	TVNGZTL	\N	0	Russia	2	PMBKIPKCBQ@dell.com	3652266782	1	1004427530802786	2009/07	user11316	password	60	20000	F
11317	WSSBWI	OYSXNDZOTT	5731300378 Dell Way	\N	KGZJALC	\N	0	China	2	OYSXNDZOTT@dell.com	5731300378	1	6761356960050762	2008/09	user11317	password	68	40000	M
11318	KAPHID	FAATEAHXUS	3211581022 Dell Way	\N	DTBDFEL	\N	0	Russia	2	FAATEAHXUS@dell.com	3211581022	1	8172878582030536	2012/10	user11318	password	25	60000	F
11319	CANLDT	LEMPFUNZMQ	4134217774 Dell Way	\N	TOUYSGR	\N	0	UK	2	LEMPFUNZMQ@dell.com	4134217774	3	8823470272123814	2008/07	user11319	password	40	40000	M
11320	IWCMPO	QBEVVRUIIN	6283045482 Dell Way	\N	WCMPJDO	\N	0	Russia	2	QBEVVRUIIN@dell.com	6283045482	3	8622627760283650	2008/09	user11320	password	32	100000	F
11321	BXNQLE	SPZOGUWOIT	3658674558 Dell Way	\N	RVIAYWT	\N	0	Germany	2	SPZOGUWOIT@dell.com	3658674558	3	7028880223166198	2008/10	user11321	password	52	20000	M
11322	JOMUSE	KSTRNPFWJX	3517982587 Dell Way	\N	RSYPPRD	\N	0	South Africa	2	KSTRNPFWJX@dell.com	3517982587	5	9087256145197900	2008/04	user11322	password	87	100000	M
11323	NJLGOW	ZHNNXSJHQB	6427235855 Dell Way	\N	ZOQOGUL	\N	0	Germany	2	ZHNNXSJHQB@dell.com	6427235855	2	6456783698406071	2012/04	user11323	password	54	60000	M
11324	WZCLVB	SIOQBXXSYX	3435251086 Dell Way	\N	HPMOKXC	\N	0	Australia	2	SIOQBXXSYX@dell.com	3435251086	4	9080414085648956	2010/03	user11324	password	49	60000	F
11325	LMNGOG	PCWRAUKZRR	9920562423 Dell Way	\N	PDFABHA	\N	0	China	2	PCWRAUKZRR@dell.com	9920562423	5	9184110959991814	2008/05	user11325	password	41	40000	M
11326	VUBJAQ	LXIMRSMJKB	1046531921 Dell Way	\N	NQBOXCX	\N	0	UK	2	LXIMRSMJKB@dell.com	1046531921	5	1902345437556505	2009/02	user11326	password	44	20000	M
11327	DEHDVT	BEGSXSCHUP	8943346667 Dell Way	\N	XVEVYBT	\N	0	UK	2	BEGSXSCHUP@dell.com	8943346667	5	3676818319596350	2008/03	user11327	password	49	100000	F
11328	PGMLZO	PFHMYJUSZR	2060027824 Dell Way	\N	ODNMFGL	\N	0	Australia	2	PFHMYJUSZR@dell.com	2060027824	4	1953971486072987	2009/02	user11328	password	21	80000	M
11329	HEEHSU	NZGLJADISS	4043315283 Dell Way	\N	MFERMPU	\N	0	Japan	2	NZGLJADISS@dell.com	4043315283	5	9514420742169024	2010/12	user11329	password	63	40000	F
11330	ULNNFA	NMMWMQEFIQ	9802853697 Dell Way	\N	LNIYDCO	\N	0	France	2	NMMWMQEFIQ@dell.com	9802853697	3	9628414218779654	2012/02	user11330	password	33	20000	M
11331	QQLWRY	IEUVUZADQL	4969712504 Dell Way	\N	QZKTBYG	\N	0	Australia	2	IEUVUZADQL@dell.com	4969712504	1	9663102842401714	2010/05	user11331	password	25	60000	F
11332	TXXLWG	PRBKQCNHNE	4153905439 Dell Way	\N	HYYIWEK	\N	0	China	2	PRBKQCNHNE@dell.com	4153905439	2	8892360576894135	2011/06	user11332	password	43	80000	F
11333	GSQDYG	UZQLBESPIZ	1937758668 Dell Way	\N	NGIKKTS	\N	0	Russia	2	UZQLBESPIZ@dell.com	1937758668	4	5646164256148041	2010/12	user11333	password	40	80000	F
11334	ALIYRD	YIOANHPVHD	8950449026 Dell Way	\N	CQONJHG	\N	0	France	2	YIOANHPVHD@dell.com	8950449026	4	1359968937002122	2012/02	user11334	password	77	20000	F
11335	GKBYNA	GCATJQPRUR	3248915419 Dell Way	\N	HIFQPMD	\N	0	France	2	GCATJQPRUR@dell.com	3248915419	1	3998008905444294	2009/12	user11335	password	47	60000	F
11336	VNEIOL	LOFUFUMZMT	7264906268 Dell Way	\N	HSKXENK	\N	0	France	2	LOFUFUMZMT@dell.com	7264906268	4	7807334757409991	2011/02	user11336	password	34	100000	M
11337	TCHHNS	WSNBNZAATI	4235046532 Dell Way	\N	SDGWRQH	\N	0	China	2	WSNBNZAATI@dell.com	4235046532	1	1331539038568735	2010/04	user11337	password	87	60000	F
11338	BSIOLF	HYGVYHVRQO	7787236114 Dell Way	\N	UWLLMSV	\N	0	South Africa	2	HYGVYHVRQO@dell.com	7787236114	5	3976248692721129	2008/10	user11338	password	73	20000	M
11339	MJKXOS	VVNUCJLSXG	4135987415 Dell Way	\N	PISBBNX	\N	0	South Africa	2	VVNUCJLSXG@dell.com	4135987415	2	8429041327908636	2008/12	user11339	password	80	100000	F
11340	FKJUCE	PPZRYKKWQZ	2676430678 Dell Way	\N	FJBGWYB	\N	0	Chile	2	PPZRYKKWQZ@dell.com	2676430678	5	4154331965371966	2008/10	user11340	password	43	80000	M
11341	TZTVEI	LDAKOLGFKM	7198780038 Dell Way	\N	OMSKKUP	\N	0	Japan	2	LDAKOLGFKM@dell.com	7198780038	5	8004323609638960	2010/04	user11341	password	48	60000	F
11342	KEXOMI	SNTGYZMILA	9930053269 Dell Way	\N	UELFZAV	\N	0	Japan	2	SNTGYZMILA@dell.com	9930053269	3	1994065821170807	2009/01	user11342	password	56	40000	F
11343	RFZEOR	RHYPHKYTKT	4400276224 Dell Way	\N	YWZXWUP	\N	0	South Africa	2	RHYPHKYTKT@dell.com	4400276224	4	2514800386037677	2009/03	user11343	password	55	80000	M
11344	TTBHLT	PJJWUHQFBO	7706288299 Dell Way	\N	BAMYUBV	\N	0	Canada	2	PJJWUHQFBO@dell.com	7706288299	5	5959033879451454	2012/06	user11344	password	42	100000	F
11345	CYNOSD	YBASIQXKFZ	7347642056 Dell Way	\N	KRXETSI	\N	0	France	2	YBASIQXKFZ@dell.com	7347642056	5	4988123111892492	2008/03	user11345	password	40	60000	F
11346	GYXYBV	ZCNISLSXLC	5777560344 Dell Way	\N	PJHIBQV	\N	0	Russia	2	ZCNISLSXLC@dell.com	5777560344	2	9749071392230690	2011/07	user11346	password	46	20000	M
11347	IZTKVT	MICFUUDFXT	2546051871 Dell Way	\N	OFCQVXL	\N	0	China	2	MICFUUDFXT@dell.com	2546051871	2	2276868128683418	2011/10	user11347	password	36	60000	F
11348	GIOBBB	KDHFYKLWEA	5381385672 Dell Way	\N	BGRXDCH	\N	0	China	2	KDHFYKLWEA@dell.com	5381385672	3	1597567192278802	2009/09	user11348	password	63	60000	M
11349	YZZAAK	EIPDSBZXBB	7330695687 Dell Way	\N	DSZHUHP	\N	0	Chile	2	EIPDSBZXBB@dell.com	7330695687	4	6125864434521646	2009/04	user11349	password	90	40000	F
11350	ZIHASL	IIPBJOYKQB	6763659485 Dell Way	\N	DPJXWZF	\N	0	Germany	2	IIPBJOYKQB@dell.com	6763659485	4	9719161191023888	2012/10	user11350	password	38	40000	M
11351	PMTHYB	PNCZCBJSCM	4608013832 Dell Way	\N	IMKFLQU	\N	0	Australia	2	PNCZCBJSCM@dell.com	4608013832	4	1214959681965410	2008/01	user11351	password	34	100000	M
11352	SQYQSO	DUNFWWYZJG	9712602050 Dell Way	\N	LULWKFY	\N	0	South Africa	2	DUNFWWYZJG@dell.com	9712602050	5	9729930373374374	2012/03	user11352	password	81	80000	M
11353	NOOFCS	APYWMWVWDH	1730700443 Dell Way	\N	QODAUCV	\N	0	Russia	2	APYWMWVWDH@dell.com	1730700443	5	7845576658379287	2009/09	user11353	password	46	20000	F
11354	YTLALL	QJIDGEZJLQ	3553341985 Dell Way	\N	YPQTSMM	\N	0	Russia	2	QJIDGEZJLQ@dell.com	3553341985	2	1609407879412174	2012/08	user11354	password	37	20000	M
11355	APQLAG	VJKBOJLZZK	8907485331 Dell Way	\N	PQDHDQB	\N	0	France	2	VJKBOJLZZK@dell.com	8907485331	1	4389133104123175	2010/05	user11355	password	57	20000	F
11356	DSWEZR	NKTBUFBUPR	2543989638 Dell Way	\N	KSYOJAZ	\N	0	Chile	2	NKTBUFBUPR@dell.com	2543989638	2	7749240415170790	2010/11	user11356	password	80	100000	F
11357	PWEONS	ZHUTNVNDMY	8192966051 Dell Way	\N	WLMFMLL	\N	0	Japan	2	ZHUTNVNDMY@dell.com	8192966051	1	2981851367279887	2011/01	user11357	password	33	80000	M
11358	BWEPOE	XIXKEKNQIJ	2529145623 Dell Way	\N	CVOOHZF	\N	0	Australia	2	XIXKEKNQIJ@dell.com	2529145623	3	7832348254974932	2008/08	user11358	password	50	100000	M
11359	HZHWDE	EBPILDZUMB	3606536790 Dell Way	\N	PBQXBWZ	\N	0	Chile	2	EBPILDZUMB@dell.com	3606536790	4	4849595922045410	2012/03	user11359	password	35	80000	F
11360	GXIKCM	LRVXUURHWH	8871292143 Dell Way	\N	JNEKJDQ	\N	0	Japan	2	LRVXUURHWH@dell.com	8871292143	1	6306375927757472	2008/04	user11360	password	33	60000	M
11361	DVYFIJ	XDGRXYZUGI	4959759254 Dell Way	\N	HKTROJI	\N	0	France	2	XDGRXYZUGI@dell.com	4959759254	5	5349873526021838	2011/02	user11361	password	18	40000	F
11362	VFMEPJ	HWBFVBABJH	3137587023 Dell Way	\N	LCZAMIL	\N	0	UK	2	HWBFVBABJH@dell.com	3137587023	5	7010771330911667	2009/12	user11362	password	87	80000	M
11363	ECYUMF	QOLLPLMYTY	4182348179 Dell Way	\N	BSZOAKM	\N	0	Chile	2	QOLLPLMYTY@dell.com	4182348179	1	6727132203523070	2009/02	user11363	password	38	20000	F
11364	KZBWFS	KQDABQZUPA	2860995886 Dell Way	\N	NOPNZBU	\N	0	China	2	KQDABQZUPA@dell.com	2860995886	3	6460660701617599	2009/09	user11364	password	66	60000	F
11365	RQZWIJ	NMKOCJJSKW	6476260881 Dell Way	\N	GZKFBEN	\N	0	Chile	2	NMKOCJJSKW@dell.com	6476260881	1	6115247584879399	2009/10	user11365	password	28	40000	F
11366	UJIDTV	PDKSNUKXQQ	5273755489 Dell Way	\N	XAVYFJF	\N	0	South Africa	2	PDKSNUKXQQ@dell.com	5273755489	4	2190438989084214	2009/12	user11366	password	56	80000	M
11367	WBVQXL	THDGBNESEB	1275653784 Dell Way	\N	TAAYJGU	\N	0	South Africa	2	THDGBNESEB@dell.com	1275653784	5	1866108957212418	2012/06	user11367	password	77	80000	F
11368	WNYTYS	BCZDQDVUFO	2927374713 Dell Way	\N	UFNDMHZ	\N	0	Germany	2	BCZDQDVUFO@dell.com	2927374713	1	5235594955738634	2011/11	user11368	password	29	100000	M
11369	RXNQQP	TPSJSOEYDY	2280209130 Dell Way	\N	ERCQZBD	\N	0	Canada	2	TPSJSOEYDY@dell.com	2280209130	4	8458107756450773	2008/10	user11369	password	76	80000	F
11370	SICIYW	YRGRFKPJJT	2185611184 Dell Way	\N	ALKZNNE	\N	0	Japan	2	YRGRFKPJJT@dell.com	2185611184	5	7319287674501539	2012/10	user11370	password	54	40000	M
11371	VMWTIU	LOLQYAAIUA	2391110954 Dell Way	\N	TEAHSEZ	\N	0	South Africa	2	LOLQYAAIUA@dell.com	2391110954	4	7590101681184024	2012/03	user11371	password	24	60000	F
11372	OHUXBF	LNWKOWTIXM	4778831323 Dell Way	\N	NXUFBTB	\N	0	Chile	2	LNWKOWTIXM@dell.com	4778831323	4	2521751339081675	2010/11	user11372	password	63	60000	F
11373	XJIZOU	NKFBHYKELX	9318409756 Dell Way	\N	BFCDZDJ	\N	0	France	2	NKFBHYKELX@dell.com	9318409756	3	9921921486500652	2011/02	user11373	password	60	40000	F
11374	YOBNIO	XOQEMAJXXL	5443627920 Dell Way	\N	DAPDEYN	\N	0	Australia	2	XOQEMAJXXL@dell.com	5443627920	3	8882179858628661	2011/02	user11374	password	25	80000	F
11375	QUOZJM	NZQAZAYXLB	3464002975 Dell Way	\N	XAFBZTD	\N	0	France	2	NZQAZAYXLB@dell.com	3464002975	1	2075889025349170	2009/02	user11375	password	79	60000	M
11376	QZTZLH	ZCHYCFWOHT	9741702341 Dell Way	\N	OMUOGYA	\N	0	Germany	2	ZCHYCFWOHT@dell.com	9741702341	1	9005422530695797	2008/12	user11376	password	41	100000	M
11377	IPPTWP	WEOZJKNQDC	7976135260 Dell Way	\N	DYQJXQW	\N	0	South Africa	2	WEOZJKNQDC@dell.com	7976135260	4	9578428517095746	2011/02	user11377	password	77	40000	F
11378	KZDHOA	LCZVMMMQPP	6605229449 Dell Way	\N	OFZLWWI	\N	0	Japan	2	LCZVMMMQPP@dell.com	6605229449	2	4490612822584808	2011/01	user11378	password	73	20000	F
11379	SGUHHG	JGBWTOMIEB	1806376749 Dell Way	\N	NDNKZVA	\N	0	Japan	2	JGBWTOMIEB@dell.com	1806376749	3	3998778963461518	2008/03	user11379	password	50	80000	M
11380	SLEZSO	FTLYIYHMZV	6910896227 Dell Way	\N	PMFPHGF	\N	0	China	2	FTLYIYHMZV@dell.com	6910896227	3	6020365756936372	2012/01	user11380	password	33	80000	M
11381	RXRJMX	DYWLWDXVYN	9142796345 Dell Way	\N	IDCPKIZ	\N	0	Australia	2	DYWLWDXVYN@dell.com	9142796345	3	8848521324805916	2012/10	user11381	password	62	80000	F
11382	NHUAFY	YBJUEGQDTY	1855857776 Dell Way	\N	HWNRFNS	\N	0	Canada	2	YBJUEGQDTY@dell.com	1855857776	3	1284905276726931	2012/03	user11382	password	65	40000	M
11383	YDSDBQ	EKLJRBMLZT	7203782316 Dell Way	\N	HNKNBDQ	\N	0	Canada	2	EKLJRBMLZT@dell.com	7203782316	4	1128307122737169	2012/04	user11383	password	42	60000	F
11384	LGKMXP	XIYOJLZIFH	2206520969 Dell Way	\N	WQVXTLB	\N	0	France	2	XIYOJLZIFH@dell.com	2206520969	1	3637359135784209	2010/05	user11384	password	80	80000	M
11385	CDIASG	IRUSCUBHCX	9217155246 Dell Way	\N	XXVRJWC	\N	0	Germany	2	IRUSCUBHCX@dell.com	9217155246	2	9635089134797456	2009/03	user11385	password	67	20000	F
11386	UMJMSS	ENLGIMOKKM	6480820469 Dell Way	\N	IFDSBFF	\N	0	UK	2	ENLGIMOKKM@dell.com	6480820469	1	3510950866155326	2012/11	user11386	password	48	20000	M
11387	XODPHH	DSOLECWPOE	3231887373 Dell Way	\N	USXWXCV	\N	0	Germany	2	DSOLECWPOE@dell.com	3231887373	1	4387550194282085	2008/07	user11387	password	59	80000	F
11388	DWAKDE	DRPIUMXIRS	5774681043 Dell Way	\N	BOOYQKM	\N	0	South Africa	2	DRPIUMXIRS@dell.com	5774681043	5	9749882571864874	2008/06	user11388	password	68	60000	M
11389	ONZSSC	KHLEUINLAO	8798667524 Dell Way	\N	ZPNQAZN	\N	0	Germany	2	KHLEUINLAO@dell.com	8798667524	3	6424676755443216	2009/03	user11389	password	25	100000	M
11390	QWLIZV	QLZKTMWUAV	5113101562 Dell Way	\N	JNMJNZX	\N	0	China	2	QLZKTMWUAV@dell.com	5113101562	3	7359180982224644	2011/08	user11390	password	61	40000	F
11391	MUPMPG	XPQRBMLCIV	6571478560 Dell Way	\N	QUFEUCO	\N	0	Chile	2	XPQRBMLCIV@dell.com	6571478560	2	8803629238624127	2009/11	user11391	password	34	60000	F
11392	ACVQIS	FYJGLUJUQZ	9594630098 Dell Way	\N	PVDJXSP	\N	0	Germany	2	FYJGLUJUQZ@dell.com	9594630098	3	7932803160045297	2012/09	user11392	password	37	20000	M
11393	JYIRRO	QAVCVEWLDM	9476142442 Dell Way	\N	GHWEZMS	\N	0	UK	2	QAVCVEWLDM@dell.com	9476142442	3	7665269029792399	2011/09	user11393	password	82	40000	F
11394	VSTNGJ	NBMJGIVJVC	5019282388 Dell Way	\N	RRGQDZO	\N	0	Australia	2	NBMJGIVJVC@dell.com	5019282388	2	7646793186198921	2008/03	user11394	password	25	40000	F
11395	VANCKB	DWLKFGTBIK	9197892053 Dell Way	\N	TPBWOPZ	\N	0	Australia	2	DWLKFGTBIK@dell.com	9197892053	4	2859900631476193	2008/10	user11395	password	53	20000	M
11396	NRSYSW	UEGALABULU	4347082923 Dell Way	\N	KMRYCRZ	\N	0	Australia	2	UEGALABULU@dell.com	4347082923	1	2018535165581852	2008/08	user11396	password	35	100000	F
11397	XODQLY	USYGTAAEVK	5605753805 Dell Way	\N	RNJUEIU	\N	0	Germany	2	USYGTAAEVK@dell.com	5605753805	5	7744758800137789	2008/02	user11397	password	60	40000	F
11398	DMRPKM	IJSBKTGFDX	4747375779 Dell Way	\N	TMSYVNM	\N	0	China	2	IJSBKTGFDX@dell.com	4747375779	2	5677708639297635	2010/10	user11398	password	82	80000	M
11399	JHPUUX	DMYNGETJCN	2712646744 Dell Way	\N	WULSIYB	\N	0	Russia	2	DMYNGETJCN@dell.com	2712646744	3	3655253853648901	2008/06	user11399	password	84	20000	M
11400	FPPZMS	MLGSPACSNY	3357234267 Dell Way	\N	NZRVXSO	\N	0	Canada	2	MLGSPACSNY@dell.com	3357234267	5	2163763020653277	2011/10	user11400	password	27	60000	M
11401	SCZFVL	QCEGCHYPFM	7599774024 Dell Way	\N	PXINPWP	\N	0	South Africa	2	QCEGCHYPFM@dell.com	7599774024	4	6034531919285656	2010/11	user11401	password	23	60000	M
11402	ELUAXL	CCREJQUPCK	3202003382 Dell Way	\N	MLXBHNY	\N	0	Australia	2	CCREJQUPCK@dell.com	3202003382	3	5860509460791946	2008/07	user11402	password	19	80000	M
11403	MNTKYW	MPAWGVLIFY	4864752184 Dell Way	\N	UCABPYC	\N	0	South Africa	2	MPAWGVLIFY@dell.com	4864752184	4	9786734958644956	2012/09	user11403	password	68	80000	F
11404	FMODJB	TJXZFJILHC	9587604970 Dell Way	\N	NIEDGHA	\N	0	Japan	2	TJXZFJILHC@dell.com	9587604970	5	7103615581057966	2011/09	user11404	password	48	80000	M
11405	XJAGKU	QHUWRDHZFV	9691703069 Dell Way	\N	HKZNSZF	\N	0	Japan	2	QHUWRDHZFV@dell.com	9691703069	5	3722722264938057	2011/04	user11405	password	24	60000	F
11406	LOMVID	DCAVGHULDB	7205934583 Dell Way	\N	WCPPCUG	\N	0	Australia	2	DCAVGHULDB@dell.com	7205934583	3	7230871671810747	2008/08	user11406	password	33	40000	F
11407	TTYCWC	FXXLERXHSU	2783389387 Dell Way	\N	KHJMCQO	\N	0	Russia	2	FXXLERXHSU@dell.com	2783389387	2	8117075508460403	2012/06	user11407	password	19	100000	F
11408	TXIQZN	NWZSOXAGRK	7227147378 Dell Way	\N	OBXRRLL	\N	0	South Africa	2	NWZSOXAGRK@dell.com	7227147378	2	7591408059466631	2008/04	user11408	password	68	40000	F
11409	PRROFE	LFWZCXGTHU	2392992662 Dell Way	\N	UFMMRXJ	\N	0	China	2	LFWZCXGTHU@dell.com	2392992662	1	5530595425982029	2010/10	user11409	password	81	60000	F
11410	OCYTHJ	ZEIBBOVJJQ	5978641472 Dell Way	\N	OVCGTLP	\N	0	UK	2	ZEIBBOVJJQ@dell.com	5978641472	1	3891943594440818	2009/12	user11410	password	73	80000	M
11411	WQHEZG	IIHJWCTGSI	3385339694 Dell Way	\N	CVOVHET	\N	0	South Africa	2	IIHJWCTGSI@dell.com	3385339694	1	2575649931095540	2009/10	user11411	password	81	80000	M
11412	MAVMHE	UOORRHYKPA	6664343308 Dell Way	\N	FEVNIOJ	\N	0	Germany	2	UOORRHYKPA@dell.com	6664343308	3	8421676556114108	2010/05	user11412	password	60	20000	M
11413	PZJWDE	LSVDZTNPTT	2483175524 Dell Way	\N	TPHCEQR	\N	0	South Africa	2	LSVDZTNPTT@dell.com	2483175524	3	3337025344371796	2010/01	user11413	password	47	60000	M
11414	JVONZA	GVDFORVIKP	8642504731 Dell Way	\N	YRRDIJY	\N	0	France	2	GVDFORVIKP@dell.com	8642504731	1	1463527841027826	2012/08	user11414	password	55	80000	M
11415	JENJET	EIZTZUCKKA	3332726505 Dell Way	\N	CBDKKBW	\N	0	Chile	2	EIZTZUCKKA@dell.com	3332726505	5	2741649852134287	2012/06	user11415	password	76	100000	M
11416	ZIEECI	MBCLWEWGEY	2228396328 Dell Way	\N	IIITKFA	\N	0	Japan	2	MBCLWEWGEY@dell.com	2228396328	2	5449729858431965	2010/01	user11416	password	41	40000	M
11417	QODTXQ	UZCRDYYIWG	3356132085 Dell Way	\N	QFAAKBR	\N	0	Germany	2	UZCRDYYIWG@dell.com	3356132085	1	2199089159257710	2009/06	user11417	password	56	40000	F
11418	CLWZBQ	YDICCGKYNA	8815185552 Dell Way	\N	ENBOPSD	\N	0	South Africa	2	YDICCGKYNA@dell.com	8815185552	2	2110046152491122	2009/10	user11418	password	46	60000	M
11419	VIVWZU	AHWCNGBBHF	2397511467 Dell Way	\N	PIUEAXA	\N	0	UK	2	AHWCNGBBHF@dell.com	2397511467	1	3244058408308774	2012/07	user11419	password	70	80000	F
11420	BQFAKG	HHIVNKXVQM	8229741350 Dell Way	\N	DKREHRC	\N	0	France	2	HHIVNKXVQM@dell.com	8229741350	2	4547746808268130	2009/01	user11420	password	31	80000	F
11421	VXCFEK	MNGAXDVNQZ	5911951572 Dell Way	\N	YHDGYFS	\N	0	Russia	2	MNGAXDVNQZ@dell.com	5911951572	1	1903733258601278	2010/04	user11421	password	75	80000	F
11422	SUIWEV	KLVHPRVGQT	8047776300 Dell Way	\N	NTZMZSG	\N	0	Germany	2	KLVHPRVGQT@dell.com	8047776300	2	2034931031521409	2008/02	user11422	password	75	20000	M
11423	OMSTHD	FDKVUGBKAO	7088603785 Dell Way	\N	EABDSIR	\N	0	France	2	FDKVUGBKAO@dell.com	7088603785	4	5869613804388792	2012/07	user11423	password	68	80000	F
11424	EKXMND	PYYJEZUFOY	5794710037 Dell Way	\N	FQCXYTJ	\N	0	Japan	2	PYYJEZUFOY@dell.com	5794710037	5	4945678650401533	2008/08	user11424	password	26	40000	M
11425	NEGBHV	ZGFEFZKUYP	8051589790 Dell Way	\N	KAMITWY	\N	0	Chile	2	ZGFEFZKUYP@dell.com	8051589790	2	4643614016938955	2010/06	user11425	password	66	20000	F
11426	VLBDHB	JNGPMQJLGT	4679591567 Dell Way	\N	LSCFPAM	\N	0	China	2	JNGPMQJLGT@dell.com	4679591567	5	7920699272770435	2012/07	user11426	password	88	100000	F
11427	KAOSCX	FINSZWDFQO	2473566183 Dell Way	\N	YSTNTGX	\N	0	Canada	2	FINSZWDFQO@dell.com	2473566183	4	1435697902459651	2011/08	user11427	password	89	20000	F
11428	ZRTBPY	KCQKZUPPIN	6396878722 Dell Way	\N	HCBAJYE	\N	0	Germany	2	KCQKZUPPIN@dell.com	6396878722	2	3327439938206226	2009/03	user11428	password	46	40000	F
11429	BZGQXR	TOBSIQIREP	1323972652 Dell Way	\N	UGQDEVR	\N	0	Russia	2	TOBSIQIREP@dell.com	1323972652	5	1018354997504502	2009/04	user11429	password	36	60000	F
11430	FRBDJU	SKNBBVTGLN	3752049705 Dell Way	\N	MCRRXJL	\N	0	UK	2	SKNBBVTGLN@dell.com	3752049705	3	2615942904725671	2011/09	user11430	password	62	20000	M
11431	HCBQWU	AKWCFPIRDU	4301798182 Dell Way	\N	TUMREXP	\N	0	France	2	AKWCFPIRDU@dell.com	4301798182	4	1990356476977467	2008/05	user11431	password	28	100000	M
11432	FBICWJ	MSLSHUJKPD	2661425516 Dell Way	\N	FBUKZKW	\N	0	China	2	MSLSHUJKPD@dell.com	2661425516	5	4571838832926005	2010/02	user11432	password	46	40000	F
11433	LPKIYX	AKPIEZSTCY	2486312354 Dell Way	\N	UXITHFC	\N	0	France	2	AKPIEZSTCY@dell.com	2486312354	3	1489817403722554	2009/11	user11433	password	40	80000	F
11434	XAQVYQ	FNYKNRDQQY	3291214060 Dell Way	\N	NZRUEUH	\N	0	China	2	FNYKNRDQQY@dell.com	3291214060	2	6419527878053487	2008/08	user11434	password	33	60000	M
11435	GCKETQ	SRAFJDVABJ	7990215169 Dell Way	\N	ZTEDNLL	\N	0	Russia	2	SRAFJDVABJ@dell.com	7990215169	1	9208463875576856	2010/04	user11435	password	44	100000	M
11436	LJREZJ	WZPGDLGFUF	8597358224 Dell Way	\N	ZYINJUH	\N	0	Canada	2	WZPGDLGFUF@dell.com	8597358224	2	6257031156681479	2008/07	user11436	password	59	80000	F
11437	YHFXQB	XGHBROHLTG	3427713815 Dell Way	\N	KCTUWBY	\N	0	Russia	2	XGHBROHLTG@dell.com	3427713815	3	8436042802874000	2012/01	user11437	password	49	100000	F
11438	SBXJDV	PLWHZDTSKD	4181080495 Dell Way	\N	VEXRFVK	\N	0	France	2	PLWHZDTSKD@dell.com	4181080495	2	3954380047507584	2010/09	user11438	password	32	60000	F
11439	GJTKEI	VBQUEJNOMI	7052041617 Dell Way	\N	TKAYGLL	\N	0	Germany	2	VBQUEJNOMI@dell.com	7052041617	4	1176602458581328	2009/12	user11439	password	51	80000	F
11440	ULPZUK	ALFFUTUHCN	6802408081 Dell Way	\N	RDLXOWM	\N	0	Chile	2	ALFFUTUHCN@dell.com	6802408081	3	6205495532136411	2010/12	user11440	password	39	100000	M
11441	TKTOVT	ZAYTUTAWGS	6603652864 Dell Way	\N	ARPOOCV	\N	0	Chile	2	ZAYTUTAWGS@dell.com	6603652864	2	8331081220880152	2010/09	user11441	password	63	40000	F
11442	ACZVWZ	WVTROUOUMO	3748171831 Dell Way	\N	MCCBFXH	\N	0	South Africa	2	WVTROUOUMO@dell.com	3748171831	1	4803054939489812	2012/09	user11442	password	75	60000	M
11443	XLOTKL	PDCEYQYKFL	8793194129 Dell Way	\N	NHMSFUO	\N	0	Germany	2	PDCEYQYKFL@dell.com	8793194129	5	5665810100268573	2010/10	user11443	password	87	40000	M
11444	JXLUIA	YLEWCDHHOU	1643456276 Dell Way	\N	PBNVVCJ	\N	0	Russia	2	YLEWCDHHOU@dell.com	1643456276	5	3578321427106857	2012/10	user11444	password	61	60000	F
11445	MYZVYX	GDTJGARVVG	3797205717 Dell Way	\N	XJCTLLL	\N	0	Germany	2	GDTJGARVVG@dell.com	3797205717	4	4210700301919133	2008/05	user11445	password	80	40000	M
11446	UHQTEX	WYHDYYZUFW	8204206582 Dell Way	\N	DHPPSBC	\N	0	Australia	2	WYHDYYZUFW@dell.com	8204206582	3	2439344482030719	2008/04	user11446	password	52	100000	F
11447	TPWYMT	WTXVSWQXST	9252207301 Dell Way	\N	EIJXKLY	\N	0	Chile	2	WTXVSWQXST@dell.com	9252207301	1	4051493951119483	2009/07	user11447	password	39	40000	F
11448	WFHJZD	DWZVSPSLJX	8221792099 Dell Way	\N	USUEESK	\N	0	Australia	2	DWZVSPSLJX@dell.com	8221792099	4	3832732380367816	2009/01	user11448	password	66	80000	M
11449	XZGWCK	SCGKRYWAWQ	9304172812 Dell Way	\N	SQVWJFY	\N	0	Canada	2	SCGKRYWAWQ@dell.com	9304172812	2	5785126043483615	2012/12	user11449	password	34	100000	M
11450	ECRHMK	JSVBRRBOHU	9067312521 Dell Way	\N	EDROIQS	\N	0	Chile	2	JSVBRRBOHU@dell.com	9067312521	2	2590362052898854	2012/06	user11450	password	18	80000	M
11451	CJYPTI	IPJAGLOOFT	3305628252 Dell Way	\N	RWHZMAF	\N	0	China	2	IPJAGLOOFT@dell.com	3305628252	3	3117329845204949	2011/05	user11451	password	84	40000	M
11452	HIDARM	PAMWLBKRUC	7252126250 Dell Way	\N	OCBACHL	\N	0	China	2	PAMWLBKRUC@dell.com	7252126250	4	1834548749029636	2008/07	user11452	password	52	80000	M
11453	VTWMFM	NSJZTUQOWE	3812206549 Dell Way	\N	RYFUFQD	\N	0	UK	2	NSJZTUQOWE@dell.com	3812206549	2	1164943072013556	2012/09	user11453	password	64	80000	M
11454	KQAPDN	IMMCGDQCHH	5007021265 Dell Way	\N	ANCGDFE	\N	0	France	2	IMMCGDQCHH@dell.com	5007021265	1	4145517908036709	2008/10	user11454	password	24	80000	F
11455	SSVVFD	ISGOVWRDES	3626475917 Dell Way	\N	QGYUMCG	\N	0	UK	2	ISGOVWRDES@dell.com	3626475917	3	1732917414512485	2008/09	user11455	password	73	40000	F
11456	LEGRIO	KODGLUKQMA	7025110147 Dell Way	\N	XLVJOBH	\N	0	South Africa	2	KODGLUKQMA@dell.com	7025110147	2	9681153031997384	2009/02	user11456	password	39	80000	M
11457	MAHUOS	IRYUMIKZJH	3995308981 Dell Way	\N	KERZGYV	\N	0	UK	2	IRYUMIKZJH@dell.com	3995308981	4	3517019137740135	2010/02	user11457	password	21	20000	M
11458	BJIPBR	HALTIVSSDD	7409813481 Dell Way	\N	WUCDSYB	\N	0	Australia	2	HALTIVSSDD@dell.com	7409813481	2	5805636577308178	2011/05	user11458	password	62	40000	F
11459	ZRABIH	BUBKPUCSXY	5118903528 Dell Way	\N	MACFYDH	\N	0	Japan	2	BUBKPUCSXY@dell.com	5118903528	5	5007561080623418	2012/06	user11459	password	75	40000	F
11460	LGMUON	OPXEJAXHYK	7308210100 Dell Way	\N	HBQFEXW	\N	0	Japan	2	OPXEJAXHYK@dell.com	7308210100	2	5114973216783256	2008/02	user11460	password	68	60000	M
11461	YAJMNY	CLDMLATKKA	4947439914 Dell Way	\N	LAGQYDG	\N	0	Japan	2	CLDMLATKKA@dell.com	4947439914	4	7795348845422269	2010/05	user11461	password	39	20000	F
11462	HMWVKY	HNKSOEDZEP	2564054682 Dell Way	\N	ALFYOMO	\N	0	Australia	2	HNKSOEDZEP@dell.com	2564054682	2	5906501541845501	2010/08	user11462	password	65	100000	M
11463	DUTNTA	BETPIXPNMP	4571251064 Dell Way	\N	ZRNNDCN	\N	0	China	2	BETPIXPNMP@dell.com	4571251064	1	9134151757694782	2008/09	user11463	password	79	100000	M
11464	QRKKSM	OLBXIRLVGK	5859398104 Dell Way	\N	NTYQVLZ	\N	0	Chile	2	OLBXIRLVGK@dell.com	5859398104	5	3237452119123191	2009/09	user11464	password	30	20000	F
11465	VNTNZH	ZBFISQDZAQ	2247360673 Dell Way	\N	TYHPKGV	\N	0	UK	2	ZBFISQDZAQ@dell.com	2247360673	1	2959961758926511	2012/03	user11465	password	43	40000	F
11466	WYPWGO	YLXRCAQCRJ	8630967854 Dell Way	\N	BYYLFUK	\N	0	China	2	YLXRCAQCRJ@dell.com	8630967854	4	2797930723521858	2008/12	user11466	password	48	20000	M
11467	JTSQIR	CFJEGZHXJI	7917986520 Dell Way	\N	VITBDEK	\N	0	UK	2	CFJEGZHXJI@dell.com	7917986520	3	1490004144143313	2011/01	user11467	password	33	60000	F
11468	ZHAHZC	NIHUIORSXN	5898878586 Dell Way	\N	BROEVYD	\N	0	Germany	2	NIHUIORSXN@dell.com	5898878586	1	3900245337281376	2010/05	user11468	password	83	100000	F
11469	FYREBF	MJZVYRNVEO	1363988880 Dell Way	\N	MTSISWX	\N	0	Chile	2	MJZVYRNVEO@dell.com	1363988880	2	8147611716296525	2010/02	user11469	password	70	100000	F
11470	RMMSRZ	BRUZIHVMWH	7640412311 Dell Way	\N	GPPYLNE	\N	0	France	2	BRUZIHVMWH@dell.com	7640412311	5	9241298703011126	2012/09	user11470	password	70	20000	F
11471	FRCXQE	OLEWTZJPHP	7293480951 Dell Way	\N	FXNQKSC	\N	0	Canada	2	OLEWTZJPHP@dell.com	7293480951	1	1022422785405069	2009/09	user11471	password	31	80000	M
11472	VWVMAK	YEGRDQHKFM	3073515235 Dell Way	\N	HTCSMFW	\N	0	Canada	2	YEGRDQHKFM@dell.com	3073515235	5	6156302557326854	2012/01	user11472	password	42	100000	M
11473	EUJEEH	JLZMBGXHTF	6740069117 Dell Way	\N	AWXNBUR	\N	0	Chile	2	JLZMBGXHTF@dell.com	6740069117	2	3450208898633719	2011/08	user11473	password	32	60000	M
11474	ZYZDGI	OFUQMSXGXY	4464207618 Dell Way	\N	CVLEQDL	\N	0	Chile	2	OFUQMSXGXY@dell.com	4464207618	4	9424700045958162	2012/12	user11474	password	54	80000	M
11475	LSARAP	WVGJODPMCR	1110139993 Dell Way	\N	IOVYRHF	\N	0	Australia	2	WVGJODPMCR@dell.com	1110139993	1	1338463672436773	2012/08	user11475	password	75	100000	F
11476	NWSNMP	JSYXWOJYFR	9511816526 Dell Way	\N	NBQEJVG	\N	0	China	2	JSYXWOJYFR@dell.com	9511816526	2	3655003146734089	2010/01	user11476	password	27	80000	M
11477	ZICMXM	EWKBKUAQMN	3088897922 Dell Way	\N	SCSBXYK	\N	0	South Africa	2	EWKBKUAQMN@dell.com	3088897922	4	4782858500722796	2009/10	user11477	password	20	100000	M
11478	JZHHLL	EWMOQMFCAX	1324690960 Dell Way	\N	ESYCRIY	\N	0	South Africa	2	EWMOQMFCAX@dell.com	1324690960	2	2720594674814492	2012/05	user11478	password	23	80000	M
11479	BYBNKF	JXUZKZBKWG	6284902174 Dell Way	\N	CVITEGQ	\N	0	Canada	2	JXUZKZBKWG@dell.com	6284902174	5	1461420726962387	2012/11	user11479	password	70	80000	M
11480	RUMBZV	YTVITWTPCW	1919818013 Dell Way	\N	LKPPRGU	\N	0	Chile	2	YTVITWTPCW@dell.com	1919818013	5	2974349291529506	2008/07	user11480	password	87	100000	F
11481	SLHSHF	MCOFZHUCDF	4761378536 Dell Way	\N	NTVEAPK	\N	0	Canada	2	MCOFZHUCDF@dell.com	4761378536	4	2205878634937107	2012/07	user11481	password	26	20000	F
11482	OLAWRM	YFRXNMARSN	7219272412 Dell Way	\N	KNRLCBO	\N	0	Germany	2	YFRXNMARSN@dell.com	7219272412	4	5385416211094707	2009/10	user11482	password	66	60000	F
11483	CPFUBE	ZTCNFCEXPP	3730070977 Dell Way	\N	LGBNIPB	\N	0	Australia	2	ZTCNFCEXPP@dell.com	3730070977	3	3631931983400136	2008/03	user11483	password	80	60000	F
11484	LSCNWC	GYPLBUJQKU	9005275331 Dell Way	\N	XLHGBJH	\N	0	China	2	GYPLBUJQKU@dell.com	9005275331	3	5082250178791583	2008/06	user11484	password	86	60000	M
11485	QMJMPP	LEBMZKDJEB	2494662721 Dell Way	\N	UMIVWPE	\N	0	Russia	2	LEBMZKDJEB@dell.com	2494662721	4	8451831831596793	2011/07	user11485	password	34	60000	F
11486	SWRHMD	MNQLYTVDVP	3123200626 Dell Way	\N	QDLMSPF	\N	0	South Africa	2	MNQLYTVDVP@dell.com	3123200626	1	5441880218684674	2011/04	user11486	password	88	100000	M
11487	VRHHUU	VLFTEAXAQN	3114066175 Dell Way	\N	DBZWRFT	\N	0	UK	2	VLFTEAXAQN@dell.com	3114066175	2	7384146560449154	2010/03	user11487	password	68	60000	F
11488	JUJEOE	PUYUVVULJY	8648711991 Dell Way	\N	NIVEOPC	\N	0	Russia	2	PUYUVVULJY@dell.com	8648711991	5	3511212255805731	2008/07	user11488	password	74	20000	M
11489	OMBCRQ	WQLRMGDVEQ	7749917325 Dell Way	\N	EAVSPYM	\N	0	France	2	WQLRMGDVEQ@dell.com	7749917325	4	5749015668872744	2009/07	user11489	password	66	20000	F
11490	EFEVVB	MHTYNWTSNX	8793162940 Dell Way	\N	SJQIHCT	\N	0	Australia	2	MHTYNWTSNX@dell.com	8793162940	2	3797649870160967	2009/12	user11490	password	50	60000	F
11491	QRYMSL	UMJHJCAXAS	1744004451 Dell Way	\N	GQAOTUP	\N	0	Japan	2	UMJHJCAXAS@dell.com	1744004451	5	1045271358918398	2008/05	user11491	password	53	20000	F
11492	DCMWNG	JXOSZOPAHW	9331416286 Dell Way	\N	QIKKCAZ	\N	0	Canada	2	JXOSZOPAHW@dell.com	9331416286	5	3074693362694234	2009/06	user11492	password	46	40000	M
11493	NUNBBW	YPPXEFYLBO	9496505103 Dell Way	\N	TMYWMYB	\N	0	France	2	YPPXEFYLBO@dell.com	9496505103	2	7251907507888973	2010/09	user11493	password	90	20000	F
11494	UPFVLE	LBBPGABIOV	1584046780 Dell Way	\N	UNSGMTR	\N	0	France	2	LBBPGABIOV@dell.com	1584046780	2	8627664190251381	2011/05	user11494	password	84	100000	F
11495	MEZYIK	ZKAGKCOZXI	6564315674 Dell Way	\N	MPPZJGK	\N	0	France	2	ZKAGKCOZXI@dell.com	6564315674	2	2680436767172068	2012/02	user11495	password	26	20000	M
11496	HBPPMO	ZMVJOJIMSV	4798475042 Dell Way	\N	BIULOEX	\N	0	Canada	2	ZMVJOJIMSV@dell.com	4798475042	1	2450270221568644	2010/03	user11496	password	36	40000	F
11497	IUBUJB	HELVOTHHPJ	8067750724 Dell Way	\N	PKVEOSJ	\N	0	UK	2	HELVOTHHPJ@dell.com	8067750724	3	6061991306487471	2012/10	user11497	password	73	60000	F
11498	ONWXPD	BAZQTHXJRM	5700549937 Dell Way	\N	TNQIFAI	\N	0	UK	2	BAZQTHXJRM@dell.com	5700549937	5	9802305228076876	2009/08	user11498	password	49	40000	F
11499	YHCNLE	NKUHSRRJEK	9162601902 Dell Way	\N	WVSCVAC	\N	0	China	2	NKUHSRRJEK@dell.com	9162601902	1	6860295930877329	2010/06	user11499	password	21	80000	F
11500	IVZTZN	DTVWLMFQXC	4160890414 Dell Way	\N	MQFHRHQ	\N	0	Germany	2	DTVWLMFQXC@dell.com	4160890414	2	2015956602990627	2012/05	user11500	password	79	40000	M
11501	RHKQVO	KQKWDQNBTZ	2852359236 Dell Way	\N	RYGIFXX	\N	0	Germany	2	KQKWDQNBTZ@dell.com	2852359236	1	4751792355440557	2010/11	user11501	password	70	40000	M
11502	APEVDO	MOLQEYRXXJ	6622219995 Dell Way	\N	WESBCPQ	\N	0	Chile	2	MOLQEYRXXJ@dell.com	6622219995	1	8511523710098118	2010/10	user11502	password	20	20000	M
11503	QEQUTC	IETNDLLBUH	1392746499 Dell Way	\N	FNJHCZP	\N	0	Russia	2	IETNDLLBUH@dell.com	1392746499	3	2966708478517830	2012/06	user11503	password	34	80000	F
11504	KFXDIG	ICTLNFMIMS	1097543057 Dell Way	\N	VWAYWPR	\N	0	South Africa	2	ICTLNFMIMS@dell.com	1097543057	5	7422571639530361	2010/02	user11504	password	41	60000	M
11505	OLQWRZ	ZLLMRXUEQQ	1774116119 Dell Way	\N	AQOWGFT	\N	0	Chile	2	ZLLMRXUEQQ@dell.com	1774116119	3	7418368848506362	2008/10	user11505	password	38	80000	F
11506	TIFLIE	WTRNRMRHCS	8417122433 Dell Way	\N	YQOEVIK	\N	0	UK	2	WTRNRMRHCS@dell.com	8417122433	1	2061909335199743	2011/05	user11506	password	77	100000	F
11507	EEPMJM	FAZWMREOKD	8532595408 Dell Way	\N	FZHAISZ	\N	0	Canada	2	FAZWMREOKD@dell.com	8532595408	1	7815594326704741	2009/11	user11507	password	70	40000	F
11508	XZNGLT	GLPTDUHNXN	6208317178 Dell Way	\N	MFNVXMY	\N	0	Russia	2	GLPTDUHNXN@dell.com	6208317178	4	9902206885628404	2010/06	user11508	password	46	60000	F
11509	JBOVUV	GKOKEWYCJL	8991437870 Dell Way	\N	HXGFKEY	\N	0	UK	2	GKOKEWYCJL@dell.com	8991437870	5	5183757897000760	2009/04	user11509	password	90	80000	M
11510	AENVAT	FPEKMCNVNU	8782871799 Dell Way	\N	TTZEYYE	\N	0	South Africa	2	FPEKMCNVNU@dell.com	8782871799	4	2218629621900618	2008/08	user11510	password	73	100000	M
11511	YJMYDR	OHCAKPWXKP	6084451022 Dell Way	\N	RKUPIYL	\N	0	Canada	2	OHCAKPWXKP@dell.com	6084451022	3	4357727428898215	2008/04	user11511	password	35	100000	F
11512	QHFTZU	BBULRQJBGA	6530178287 Dell Way	\N	LAQUZBZ	\N	0	Germany	2	BBULRQJBGA@dell.com	6530178287	2	7364994443953038	2012/07	user11512	password	57	40000	F
11513	VLYVFA	WALOQVPXVB	2126920901 Dell Way	\N	XMVWNUK	\N	0	Canada	2	WALOQVPXVB@dell.com	2126920901	1	1588000142481178	2011/08	user11513	password	37	100000	F
11514	SWHXWE	XISODILZJJ	7674246731 Dell Way	\N	LFGYZQC	\N	0	Canada	2	XISODILZJJ@dell.com	7674246731	1	8409314711578191	2009/06	user11514	password	70	100000	F
11515	PEBLIZ	TBNXKZWUII	5469954632 Dell Way	\N	ZOGZFJC	\N	0	UK	2	TBNXKZWUII@dell.com	5469954632	5	3953645461704582	2012/08	user11515	password	32	20000	F
11516	JCQRBK	TPHDOEXXMW	8593174062 Dell Way	\N	LTWRCYP	\N	0	Japan	2	TPHDOEXXMW@dell.com	8593174062	5	5691374330781401	2010/02	user11516	password	59	80000	F
11517	QIESTX	HBAVGYSSVE	4268049069 Dell Way	\N	MRVPPLF	\N	0	France	2	HBAVGYSSVE@dell.com	4268049069	4	9246507200878114	2010/04	user11517	password	62	100000	M
11518	YCQRAX	TATZZMSURE	7345046147 Dell Way	\N	LMUBYZM	\N	0	Chile	2	TATZZMSURE@dell.com	7345046147	2	7978083613328636	2012/12	user11518	password	71	100000	M
11519	VOQVMJ	WFJVRBQIGB	9848665488 Dell Way	\N	VACTAPB	\N	0	Russia	2	WFJVRBQIGB@dell.com	9848665488	5	7330541456583888	2012/07	user11519	password	63	100000	F
11520	EOGQYC	WHYOJPXPQS	4431273478 Dell Way	\N	QTMQJOJ	\N	0	China	2	WHYOJPXPQS@dell.com	4431273478	1	3864108991343528	2012/09	user11520	password	35	40000	M
11521	UOMTRJ	BQXKFUZWNP	6788930060 Dell Way	\N	QAGZOPI	\N	0	UK	2	BQXKFUZWNP@dell.com	6788930060	4	8879142688587309	2009/11	user11521	password	33	20000	M
11522	URLMAM	CYWHSVEFLU	7468857908 Dell Way	\N	GSUUHCS	\N	0	UK	2	CYWHSVEFLU@dell.com	7468857908	3	3281958801206201	2010/10	user11522	password	49	40000	M
11523	CSBDED	BALTWQZIKF	3771927875 Dell Way	\N	AEZHHSG	\N	0	UK	2	BALTWQZIKF@dell.com	3771927875	3	6281050560530276	2008/12	user11523	password	80	80000	F
11524	OTDSXE	TJXPZXXKDY	9745423189 Dell Way	\N	PDGWVMV	\N	0	Canada	2	TJXPZXXKDY@dell.com	9745423189	3	3295342286583036	2012/04	user11524	password	87	100000	M
11525	SAPQFI	ZDYYAWJDUY	1637312559 Dell Way	\N	GAUCMQG	\N	0	France	2	ZDYYAWJDUY@dell.com	1637312559	3	4182363442610949	2009/06	user11525	password	36	40000	F
11526	HVUMDU	PBTQXCURAB	9025734572 Dell Way	\N	SVEFLKR	\N	0	Germany	2	PBTQXCURAB@dell.com	9025734572	1	9056582004763188	2009/04	user11526	password	26	60000	M
11527	YIBBCR	DVHAXCSYDL	3567346992 Dell Way	\N	THQFRHT	\N	0	Germany	2	DVHAXCSYDL@dell.com	3567346992	4	9360876425635072	2010/10	user11527	password	50	20000	M
11528	TDTVUW	RCXOEQNIBG	8675813706 Dell Way	\N	QRMIZFX	\N	0	Chile	2	RCXOEQNIBG@dell.com	8675813706	5	8223331914283336	2011/04	user11528	password	84	40000	F
11529	BBWWXN	ZVCDMPMOVC	2136467214 Dell Way	\N	GIKFNHL	\N	0	China	2	ZVCDMPMOVC@dell.com	2136467214	2	9933830435853452	2009/02	user11529	password	39	60000	F
11530	IHCGVB	CXEOMRCITI	3204305233 Dell Way	\N	QEOEMZO	\N	0	Germany	2	CXEOMRCITI@dell.com	3204305233	3	9926797264721246	2010/10	user11530	password	48	80000	F
11531	SSKNTN	KYBXPEFJNW	2046940270 Dell Way	\N	NBAZBOP	\N	0	Chile	2	KYBXPEFJNW@dell.com	2046940270	3	7312490868847818	2012/12	user11531	password	41	20000	M
11532	ANFUBP	SDNIHSRVOE	4189267674 Dell Way	\N	WPEYEUF	\N	0	Chile	2	SDNIHSRVOE@dell.com	4189267674	5	3043907747138291	2009/03	user11532	password	42	20000	F
11533	WGBYWT	BJCICTDQYA	1771286783 Dell Way	\N	GDYKXER	\N	0	Chile	2	BJCICTDQYA@dell.com	1771286783	5	6401883037295193	2009/03	user11533	password	65	80000	F
11534	XRBTLC	DNLFGOWFPC	1558800077 Dell Way	\N	IOMFSEM	\N	0	South Africa	2	DNLFGOWFPC@dell.com	1558800077	1	2188849507831037	2009/09	user11534	password	72	60000	M
11535	KMJVON	JZSPOOUEQD	8776105767 Dell Way	\N	SDIKHUF	\N	0	China	2	JZSPOOUEQD@dell.com	8776105767	2	6967502446379513	2010/02	user11535	password	24	20000	M
11536	OOIDBR	CTHRICVZFO	5886443014 Dell Way	\N	COZKIET	\N	0	Chile	2	CTHRICVZFO@dell.com	5886443014	3	8022063501179219	2011/07	user11536	password	88	20000	F
11537	NMFPEI	JLAROVRTJT	4255201799 Dell Way	\N	HJEQNYW	\N	0	Australia	2	JLAROVRTJT@dell.com	4255201799	4	7453104980755598	2012/08	user11537	password	80	100000	F
11538	IESNNB	ZNSNJJHTDP	7485211902 Dell Way	\N	CIGQGCS	\N	0	Japan	2	ZNSNJJHTDP@dell.com	7485211902	3	5467217509169132	2009/04	user11538	password	51	60000	M
11539	QDDEEC	RXPAHXULMW	6456251191 Dell Way	\N	TSMAVEQ	\N	0	Germany	2	RXPAHXULMW@dell.com	6456251191	1	8699473128188402	2012/08	user11539	password	39	60000	F
11540	LQKQSB	NICVFXGSTA	8146434084 Dell Way	\N	LGBGLRU	\N	0	Australia	2	NICVFXGSTA@dell.com	8146434084	4	9250177456066012	2009/12	user11540	password	48	80000	F
11541	AAZTCN	BEJHBQAVQL	2484362942 Dell Way	\N	BRSMJNN	\N	0	Canada	2	BEJHBQAVQL@dell.com	2484362942	3	5787538648582995	2008/11	user11541	password	28	60000	M
11542	EMQGAS	LJZMZAIQLJ	8587753959 Dell Way	\N	IEWRRKV	\N	0	South Africa	2	LJZMZAIQLJ@dell.com	8587753959	2	9624871121253820	2011/07	user11542	password	50	60000	M
11543	YFXYYI	IYVIYEZKNH	2692682396 Dell Way	\N	OKZGVVC	\N	0	Japan	2	IYVIYEZKNH@dell.com	2692682396	1	4190805075224489	2011/06	user11543	password	86	40000	F
11544	EHJCQS	AMAYQZJDHX	3727151912 Dell Way	\N	OHEJCGA	\N	0	Chile	2	AMAYQZJDHX@dell.com	3727151912	2	9899413855280728	2012/04	user11544	password	44	40000	F
11545	RQPHIQ	TJOJJYNQVC	8933888267 Dell Way	\N	XAMAGMH	\N	0	Germany	2	TJOJJYNQVC@dell.com	8933888267	2	4236914850771427	2009/08	user11545	password	61	80000	F
11546	FHPOYJ	XNSGLGXHIV	4840042714 Dell Way	\N	HUVNHDC	\N	0	Canada	2	XNSGLGXHIV@dell.com	4840042714	3	4403979818336666	2008/01	user11546	password	24	60000	F
11547	KAUIJS	VCYGIVNRRU	8629402768 Dell Way	\N	LMISQKX	\N	0	Australia	2	VCYGIVNRRU@dell.com	8629402768	2	2317367795854807	2012/05	user11547	password	58	20000	M
11548	OYBXQX	AODIKRZCLL	3944172980 Dell Way	\N	PTEFEBH	\N	0	Australia	2	AODIKRZCLL@dell.com	3944172980	3	9096158220898360	2011/12	user11548	password	20	60000	M
11549	ZNLPKL	EOUPFURRFH	2724260801 Dell Way	\N	KJMPKTP	\N	0	Russia	2	EOUPFURRFH@dell.com	2724260801	3	4897736460901797	2008/07	user11549	password	82	80000	M
11550	KDDVPH	JKXPEPGJWQ	3935875286 Dell Way	\N	SJGDDVX	\N	0	China	2	JKXPEPGJWQ@dell.com	3935875286	2	5258405869361013	2012/03	user11550	password	30	40000	M
11551	IMKXUU	HSJLHPVDGO	9066609682 Dell Way	\N	MMRPIOX	\N	0	Japan	2	HSJLHPVDGO@dell.com	9066609682	2	5465495937503875	2008/07	user11551	password	81	80000	M
11552	JCUDWC	VFODVJHBYU	7289790034 Dell Way	\N	NPJVEHM	\N	0	Australia	2	VFODVJHBYU@dell.com	7289790034	5	2627756199799478	2009/11	user11552	password	81	20000	F
11553	ZYJWAE	BOIXYPYWJM	8076205868 Dell Way	\N	MTIRBVT	\N	0	Russia	2	BOIXYPYWJM@dell.com	8076205868	5	1064137681853026	2011/10	user11553	password	28	100000	M
11554	CEQCJS	RRPQHONQBZ	4452674476 Dell Way	\N	JJRKELE	\N	0	UK	2	RRPQHONQBZ@dell.com	4452674476	1	6454695007763804	2009/04	user11554	password	49	100000	F
11555	QQMZIE	RYUYNIOOHY	7236045590 Dell Way	\N	YZJDKNC	\N	0	Russia	2	RYUYNIOOHY@dell.com	7236045590	4	9959625290241092	2008/02	user11555	password	90	60000	M
11556	PXTYBK	XWJKEYZMWX	8421450295 Dell Way	\N	LGAWTDR	\N	0	France	2	XWJKEYZMWX@dell.com	8421450295	4	5155826105736196	2012/08	user11556	password	81	80000	F
11557	TMFVXD	SGNXEMJBKV	1228690781 Dell Way	\N	HKSBNJN	\N	0	China	2	SGNXEMJBKV@dell.com	1228690781	5	3895273028872907	2011/11	user11557	password	21	100000	M
11558	NDLKGD	RUBWHLYRGF	8014986773 Dell Way	\N	CZHPIUY	\N	0	China	2	RUBWHLYRGF@dell.com	8014986773	2	1301394374575465	2011/04	user11558	password	88	40000	M
11559	CRHJVY	DWVKHTCOZE	1162458939 Dell Way	\N	NGUWBTF	\N	0	South Africa	2	DWVKHTCOZE@dell.com	1162458939	2	5208556713070721	2009/03	user11559	password	68	40000	F
11560	JMRELV	AGGIZIWZNK	7731976184 Dell Way	\N	GHGHAMD	\N	0	Australia	2	AGGIZIWZNK@dell.com	7731976184	4	4491099727340043	2012/04	user11560	password	61	40000	M
11561	CZVNVW	UBEUKBTXLZ	1518016866 Dell Way	\N	FSHFFLG	\N	0	UK	2	UBEUKBTXLZ@dell.com	1518016866	4	9316234664991500	2009/03	user11561	password	33	20000	F
11562	FWVATQ	BYKMZDKLCP	7416742465 Dell Way	\N	EKVJVBI	\N	0	South Africa	2	BYKMZDKLCP@dell.com	7416742465	2	3340427567251027	2012/06	user11562	password	39	40000	M
11563	EDRXTT	VDFVGPGJEK	4164667748 Dell Way	\N	TAUPBCM	\N	0	Russia	2	VDFVGPGJEK@dell.com	4164667748	4	7620254542678595	2012/01	user11563	password	18	60000	F
11564	DDCWWY	ZCTGRAQWKK	2992305633 Dell Way	\N	WFZYIMS	\N	0	Japan	2	ZCTGRAQWKK@dell.com	2992305633	3	5304345115087927	2009/06	user11564	password	87	60000	M
11565	CPMZNM	BHSTHIPSSM	6414370405 Dell Way	\N	XSKFEDX	\N	0	France	2	BHSTHIPSSM@dell.com	6414370405	2	7010538414586336	2008/04	user11565	password	28	80000	F
11566	TDKGQL	OIEVRUOKHL	9462804739 Dell Way	\N	CSRHVOS	\N	0	France	2	OIEVRUOKHL@dell.com	9462804739	2	5620134197175503	2009/07	user11566	password	31	80000	F
11567	IBNYNB	HSWZMKJTWM	8597842120 Dell Way	\N	LOUHDMT	\N	0	Australia	2	HSWZMKJTWM@dell.com	8597842120	2	3992866456974298	2009/06	user11567	password	18	60000	M
11568	CCTPDA	HAAULJOHWA	3622778362 Dell Way	\N	WRHZDBB	\N	0	UK	2	HAAULJOHWA@dell.com	3622778362	2	3986513242591173	2011/05	user11568	password	85	60000	F
11569	AGCDHJ	EHEPRSXNST	2909517273 Dell Way	\N	EATIBVH	\N	0	China	2	EHEPRSXNST@dell.com	2909517273	4	1636480357963591	2011/07	user11569	password	60	20000	M
11570	VFSCOX	KTMBLKPDEU	1378960125 Dell Way	\N	DXCFTKN	\N	0	UK	2	KTMBLKPDEU@dell.com	1378960125	4	6069555890280754	2011/03	user11570	password	67	20000	F
11571	WXDLUN	EHOPSETWYX	3269658693 Dell Way	\N	TACNLQL	\N	0	France	2	EHOPSETWYX@dell.com	3269658693	1	1766397099476307	2010/09	user11571	password	37	60000	M
11572	EPZZDE	HSTZWNVULP	5955620944 Dell Way	\N	VNCGEOT	\N	0	France	2	HSTZWNVULP@dell.com	5955620944	5	8853844876866789	2009/02	user11572	password	42	80000	F
11573	YTGBXN	TRNPFIKQYF	1744486632 Dell Way	\N	EAMIOGT	\N	0	Canada	2	TRNPFIKQYF@dell.com	1744486632	4	4132268822286278	2008/12	user11573	password	27	60000	M
11574	WSZUGS	MTIRBSHZYL	2652333524 Dell Way	\N	ALUPROS	\N	0	Russia	2	MTIRBSHZYL@dell.com	2652333524	1	9619937403127552	2008/03	user11574	password	48	20000	F
11575	DAWJTI	CBADUHDTTE	5413301168 Dell Way	\N	FNTXCLR	\N	0	Chile	2	CBADUHDTTE@dell.com	5413301168	4	4841700399760157	2011/01	user11575	password	54	80000	F
11576	NONHXP	JXTDFXXYBC	3225840203 Dell Way	\N	MUZPGQW	\N	0	Russia	2	JXTDFXXYBC@dell.com	3225840203	2	4475452503655106	2009/10	user11576	password	25	60000	F
11577	RYOONX	MGBREYQFBD	8487194825 Dell Way	\N	ZASFQOY	\N	0	South Africa	2	MGBREYQFBD@dell.com	8487194825	2	2480862361844629	2011/06	user11577	password	61	100000	F
11578	NMSBJE	ILWMKMRLQR	2787382517 Dell Way	\N	LIXCXWZ	\N	0	Russia	2	ILWMKMRLQR@dell.com	2787382517	1	3918119112960994	2011/09	user11578	password	34	80000	F
11579	RLHBQQ	NMCXZTJPLU	1120743113 Dell Way	\N	YIXVFWO	\N	0	France	2	NMCXZTJPLU@dell.com	1120743113	5	1410344338510185	2011/02	user11579	password	76	20000	M
11580	GIWXYJ	KAHJUQZFLY	3151979794 Dell Way	\N	OJUUFJE	\N	0	Chile	2	KAHJUQZFLY@dell.com	3151979794	2	9874695228878410	2009/01	user11580	password	90	20000	F
11581	HAFFJP	GRZAIZGUXV	9963048924 Dell Way	\N	DSPJBUP	\N	0	Chile	2	GRZAIZGUXV@dell.com	9963048924	3	6693134986329824	2008/07	user11581	password	74	40000	M
11582	UNCDCI	VCJDBPXYLB	6094892820 Dell Way	\N	RAKSUZZ	\N	0	Russia	2	VCJDBPXYLB@dell.com	6094892820	4	8325939572881908	2008/05	user11582	password	28	20000	F
11583	RCIUKD	WUHXJFWUGN	8422236748 Dell Way	\N	VQFPQFK	\N	0	Canada	2	WUHXJFWUGN@dell.com	8422236748	2	3895683968439698	2009/05	user11583	password	41	40000	F
11584	KSUVWQ	PDOZIKUOYP	8466795896 Dell Way	\N	FEFVJQA	\N	0	Canada	2	PDOZIKUOYP@dell.com	8466795896	2	4621990613639355	2008/08	user11584	password	75	20000	F
11585	MZXIQN	MEMUPHJNXO	7439950250 Dell Way	\N	RCJATKF	\N	0	Germany	2	MEMUPHJNXO@dell.com	7439950250	4	7678856622893364	2009/05	user11585	password	86	60000	M
11586	XIGNVS	SIMHQWUNKM	4208446973 Dell Way	\N	QUNJETX	\N	0	South Africa	2	SIMHQWUNKM@dell.com	4208446973	4	3287448813673109	2011/08	user11586	password	68	80000	M
11587	AXBWPT	ECAVYVIIIY	9096865041 Dell Way	\N	DVIHOGE	\N	0	UK	2	ECAVYVIIIY@dell.com	9096865041	3	7139195607509465	2010/02	user11587	password	43	20000	F
11588	GBAVUF	YVAWRIFZHI	3387088922 Dell Way	\N	UPQJVVH	\N	0	Russia	2	YVAWRIFZHI@dell.com	3387088922	5	3084429689217359	2009/04	user11588	password	35	60000	M
11589	HOKCTI	XTEPBKOJTJ	9851150249 Dell Way	\N	YJTUFAN	\N	0	France	2	XTEPBKOJTJ@dell.com	9851150249	4	8716138258576394	2009/12	user11589	password	46	100000	F
11590	YGJROH	KTWMELWXUV	8970407281 Dell Way	\N	HOPMODY	\N	0	Germany	2	KTWMELWXUV@dell.com	8970407281	4	8531147405039520	2012/03	user11590	password	68	20000	F
11591	YOUNVF	GSSKEOIZJP	8100390001 Dell Way	\N	NZBBCZP	\N	0	UK	2	GSSKEOIZJP@dell.com	8100390001	3	8744491496123374	2012/02	user11591	password	20	20000	F
11592	PXOLCV	DVGHJOGSET	8803828924 Dell Way	\N	SFVUFLT	\N	0	Australia	2	DVGHJOGSET@dell.com	8803828924	4	9803752828855068	2012/08	user11592	password	23	20000	F
11593	ZPRCLU	XRCHGJAKDS	8801528779 Dell Way	\N	QYMVJGV	\N	0	Chile	2	XRCHGJAKDS@dell.com	8801528779	5	3206030405126512	2010/11	user11593	password	39	80000	M
11594	XKZJFW	AIDHSDSVVI	8258574024 Dell Way	\N	UIEEOZL	\N	0	France	2	AIDHSDSVVI@dell.com	8258574024	4	9613212878815832	2011/12	user11594	password	70	60000	M
11595	DOGJKH	SOOKSGGOPA	3830807979 Dell Way	\N	WTFLSQW	\N	0	Germany	2	SOOKSGGOPA@dell.com	3830807979	5	3106077203061432	2009/07	user11595	password	77	20000	M
11596	JKBTRT	IGEAMKOBLK	5866401976 Dell Way	\N	VQWNHSB	\N	0	Japan	2	IGEAMKOBLK@dell.com	5866401976	2	9020893851760776	2008/02	user11596	password	22	80000	F
11597	MVFDON	JSOWDCYONT	6952521822 Dell Way	\N	FJHNBJC	\N	0	Japan	2	JSOWDCYONT@dell.com	6952521822	1	7292806505691261	2011/01	user11597	password	51	40000	M
11598	HLRVZB	ONXSQWGDQM	1998381948 Dell Way	\N	MXZOHCE	\N	0	UK	2	ONXSQWGDQM@dell.com	1998381948	5	7367892486974598	2008/05	user11598	password	86	80000	M
11599	KJLJKA	XISNFZQVMD	7860143538 Dell Way	\N	TMSAOWY	\N	0	Japan	2	XISNFZQVMD@dell.com	7860143538	4	8717102546244861	2008/08	user11599	password	59	80000	M
11600	YEJJFG	SYUXYLTKOM	2127651937 Dell Way	\N	WGNLDMC	\N	0	UK	2	SYUXYLTKOM@dell.com	2127651937	5	1071270501241087	2011/07	user11600	password	71	80000	F
11601	XCVDJN	BDLZOFJDRG	7768501077 Dell Way	\N	JERNRUL	\N	0	Russia	2	BDLZOFJDRG@dell.com	7768501077	3	5565156158525497	2009/02	user11601	password	34	80000	F
11602	IPFRDG	VPGJUQMLWW	3395682422 Dell Way	\N	QOKHIVC	\N	0	Australia	2	VPGJUQMLWW@dell.com	3395682422	3	4298911157529801	2010/10	user11602	password	26	60000	F
11603	SSUVZP	KGZEWMQTJH	3242982016 Dell Way	\N	HUPQPRS	\N	0	South Africa	2	KGZEWMQTJH@dell.com	3242982016	1	3745813942980021	2008/03	user11603	password	77	20000	M
11604	OZTNPE	UPJQCAKLHS	2068563409 Dell Way	\N	FWIVOBS	\N	0	Russia	2	UPJQCAKLHS@dell.com	2068563409	1	8672898375429214	2009/10	user11604	password	21	40000	F
11605	BZXRER	GNIINSUVLA	5974323878 Dell Way	\N	STVGUOA	\N	0	UK	2	GNIINSUVLA@dell.com	5974323878	5	3192155451048165	2009/12	user11605	password	52	80000	M
11606	MQQQIW	DQFRJANVAF	4191140778 Dell Way	\N	PWLKKMI	\N	0	UK	2	DQFRJANVAF@dell.com	4191140778	3	3955493755172938	2009/01	user11606	password	23	40000	F
11607	SXDBTH	SZYCZMXZRM	7523333347 Dell Way	\N	WCWGPEF	\N	0	UK	2	SZYCZMXZRM@dell.com	7523333347	3	3032463461160660	2011/08	user11607	password	53	40000	F
11608	JJJDQC	DPECBBCTOY	9213215999 Dell Way	\N	WKFLPKJ	\N	0	China	2	DPECBBCTOY@dell.com	9213215999	4	1513123331591487	2010/02	user11608	password	40	100000	F
11609	RFPIHS	XMVZNYSBWO	9890882712 Dell Way	\N	MCABMJJ	\N	0	China	2	XMVZNYSBWO@dell.com	9890882712	3	9040548949502408	2008/09	user11609	password	71	60000	F
11610	YDSGVQ	SQPGOIHLXU	6517799213 Dell Way	\N	NXVAHFJ	\N	0	Chile	2	SQPGOIHLXU@dell.com	6517799213	2	4005623290315271	2009/01	user11610	password	81	80000	M
11611	ZLFVBX	MRDBZLNXFA	7217868779 Dell Way	\N	UBABGKH	\N	0	South Africa	2	MRDBZLNXFA@dell.com	7217868779	4	2862559358589351	2011/07	user11611	password	86	80000	F
11612	JWILTU	DWVDIIAOJU	7903815286 Dell Way	\N	PKVWVDT	\N	0	Germany	2	DWVDIIAOJU@dell.com	7903815286	5	2838238038588315	2009/11	user11612	password	80	80000	F
11613	SBSLWV	ISYRAYFKSV	4456300743 Dell Way	\N	UORQRLD	\N	0	France	2	ISYRAYFKSV@dell.com	4456300743	2	7517848871182651	2009/03	user11613	password	53	60000	M
11614	OGILBR	DAIEYNORJJ	4944107487 Dell Way	\N	GAZYMCJ	\N	0	South Africa	2	DAIEYNORJJ@dell.com	4944107487	1	2116437437478453	2011/08	user11614	password	65	60000	F
11615	XVOYNS	YVWXJKPSUV	3222703712 Dell Way	\N	TTTFWDC	\N	0	Chile	2	YVWXJKPSUV@dell.com	3222703712	2	9296637519728392	2012/11	user11615	password	49	100000	M
11616	HOSUGR	QCPZNESHAM	9777417425 Dell Way	\N	BTSXXUF	\N	0	Canada	2	QCPZNESHAM@dell.com	9777417425	1	9933769201859832	2012/07	user11616	password	89	60000	M
11617	OHQVYG	XNGLSZTSLU	1105787341 Dell Way	\N	MDRKXXO	\N	0	South Africa	2	XNGLSZTSLU@dell.com	1105787341	3	7485811967402697	2010/07	user11617	password	40	60000	F
11618	PAWOHU	CNGUMZNYTZ	5130274628 Dell Way	\N	CLJZIYW	\N	0	China	2	CNGUMZNYTZ@dell.com	5130274628	3	9081584630999716	2012/11	user11618	password	39	20000	M
11619	IXBPSE	DYYQXMORMQ	2091596561 Dell Way	\N	CWQKUNT	\N	0	Chile	2	DYYQXMORMQ@dell.com	2091596561	4	2934966165106743	2008/12	user11619	password	36	60000	F
11620	EPWWTZ	VSQSEFJRWM	3230650975 Dell Way	\N	NNWHAPN	\N	0	Canada	2	VSQSEFJRWM@dell.com	3230650975	4	2551240793894976	2008/01	user11620	password	69	60000	F
11621	HHBBHW	TYPYDZPZLD	7458254503 Dell Way	\N	MILNYZR	\N	0	Canada	2	TYPYDZPZLD@dell.com	7458254503	5	4300182155799121	2011/07	user11621	password	76	100000	M
11622	CYXKVQ	IKPMJFMVIZ	1011962916 Dell Way	\N	DTMCTEH	\N	0	France	2	IKPMJFMVIZ@dell.com	1011962916	4	2569696667604148	2010/06	user11622	password	23	40000	M
11623	AHZVXI	GNUQSHLBGP	6364371363 Dell Way	\N	VTROXYA	\N	0	UK	2	GNUQSHLBGP@dell.com	6364371363	1	5027391070965678	2008/04	user11623	password	78	60000	F
11624	CODAWJ	ORAGYLIFBE	9303323973 Dell Way	\N	YTSVSTT	\N	0	China	2	ORAGYLIFBE@dell.com	9303323973	1	4106693611480296	2008/01	user11624	password	86	60000	F
11625	NPDKZR	BZYALHFNLE	9531795941 Dell Way	\N	GEAZXTG	\N	0	South Africa	2	BZYALHFNLE@dell.com	9531795941	4	1101982200983911	2012/07	user11625	password	53	20000	F
11626	CGMBYN	BXOMEUZQZG	1848728775 Dell Way	\N	UZFRSMN	\N	0	Japan	2	BXOMEUZQZG@dell.com	1848728775	3	6845173988491297	2011/01	user11626	password	72	80000	F
11627	ZEEYSF	VHSZCSPBYK	2213996721 Dell Way	\N	AECTQPL	\N	0	Russia	2	VHSZCSPBYK@dell.com	2213996721	1	4504202833864838	2008/10	user11627	password	25	40000	M
11628	HKTAPO	HIOJAEKYPL	7039620429 Dell Way	\N	CRETHPN	\N	0	France	2	HIOJAEKYPL@dell.com	7039620429	5	5985592811368406	2010/12	user11628	password	76	40000	F
11629	FBHVQO	DFYDJIBYTE	4058936523 Dell Way	\N	QYYXNLH	\N	0	Chile	2	DFYDJIBYTE@dell.com	4058936523	5	7314947474747897	2009/08	user11629	password	18	80000	M
11630	BXRSMU	XKXHTZGNEW	9218220821 Dell Way	\N	LCTZOBF	\N	0	UK	2	XKXHTZGNEW@dell.com	9218220821	5	3164132033009082	2010/11	user11630	password	80	60000	M
11631	TCSFWP	QTXJTDXXZI	4889686975 Dell Way	\N	ATIPUNM	\N	0	Russia	2	QTXJTDXXZI@dell.com	4889686975	4	3552948756609112	2009/07	user11631	password	69	40000	F
11632	UAOQQF	KNODQLAQUB	8414939500 Dell Way	\N	JDQERCX	\N	0	Australia	2	KNODQLAQUB@dell.com	8414939500	1	4930335186887533	2010/11	user11632	password	74	80000	M
11633	UHILMS	YBVPNWFIXP	9063733398 Dell Way	\N	LNUCQSE	\N	0	France	2	YBVPNWFIXP@dell.com	9063733398	4	8655948532745243	2011/05	user11633	password	61	60000	F
11634	XTQKMO	LHEZEKHBAS	6802096718 Dell Way	\N	PVVFNAR	\N	0	France	2	LHEZEKHBAS@dell.com	6802096718	3	2803494588937610	2008/02	user11634	password	66	40000	F
11635	LWKXLW	FPVJACLAVA	4765347259 Dell Way	\N	VRGJRXT	\N	0	China	2	FPVJACLAVA@dell.com	4765347259	5	4388635059818626	2010/08	user11635	password	62	60000	F
11636	MXYYTD	OPNOSYOOZK	5470788082 Dell Way	\N	FFTXDNG	\N	0	Germany	2	OPNOSYOOZK@dell.com	5470788082	4	1569296294357627	2008/03	user11636	password	60	20000	M
11637	NCQHGE	WTTOSIDRSJ	2230353163 Dell Way	\N	XMGAANO	\N	0	Germany	2	WTTOSIDRSJ@dell.com	2230353163	4	6734027442056686	2009/03	user11637	password	76	20000	M
11638	XTZEYW	YRKQZOISXF	4520758572 Dell Way	\N	FEFFRUT	\N	0	South Africa	2	YRKQZOISXF@dell.com	4520758572	2	2713035597931593	2010/03	user11638	password	39	40000	F
11639	BHHZDF	QOVQCEJAJO	9091330320 Dell Way	\N	EPUWJNR	\N	0	Russia	2	QOVQCEJAJO@dell.com	9091330320	5	4045500295236707	2008/02	user11639	password	64	20000	F
11640	YLEBRU	QNLSRUTAJX	3445963670 Dell Way	\N	PDTYRKS	\N	0	Germany	2	QNLSRUTAJX@dell.com	3445963670	1	6853840323165060	2010/09	user11640	password	78	60000	M
11641	HTRYOH	MAADUTEERT	5064592647 Dell Way	\N	IKSZVKO	\N	0	Canada	2	MAADUTEERT@dell.com	5064592647	2	5726645681075752	2008/01	user11641	password	26	80000	F
11642	WKHLST	LSXGMBKDVS	5191234244 Dell Way	\N	OOSKYGN	\N	0	France	2	LSXGMBKDVS@dell.com	5191234244	1	5887885225936771	2010/02	user11642	password	38	100000	F
11643	RDLKXX	CUDPWOTRHH	3141102158 Dell Way	\N	FZSEGFP	\N	0	Russia	2	CUDPWOTRHH@dell.com	3141102158	1	2912345344666391	2009/06	user11643	password	21	60000	F
11644	EWNBUQ	WXFSLYKSGQ	5868556066 Dell Way	\N	SYUYDKR	\N	0	China	2	WXFSLYKSGQ@dell.com	5868556066	5	7919729771558196	2012/12	user11644	password	31	20000	F
11645	BPEWFA	TKTFJDYPTR	2270874200 Dell Way	\N	OOPRYGB	\N	0	France	2	TKTFJDYPTR@dell.com	2270874200	5	5143340053968132	2008/01	user11645	password	57	20000	F
11646	DIYIJS	TCXCGWSZNG	8352567793 Dell Way	\N	ODYNKZA	\N	0	Germany	2	TCXCGWSZNG@dell.com	8352567793	3	6463536306284369	2012/01	user11646	password	74	100000	F
11647	CWLLOE	OMHUJAUWHI	3797906079 Dell Way	\N	AFVKFWZ	\N	0	Australia	2	OMHUJAUWHI@dell.com	3797906079	3	8786401544231922	2009/05	user11647	password	75	60000	F
11648	QWXFBL	RJGBKAYRJY	9027437708 Dell Way	\N	XFJCBID	\N	0	China	2	RJGBKAYRJY@dell.com	9027437708	1	7184939336962999	2009/10	user11648	password	26	80000	F
11649	ZOQBAI	LGJVHHMQGK	6980986116 Dell Way	\N	WPNYXQI	\N	0	South Africa	2	LGJVHHMQGK@dell.com	6980986116	5	1393007981125265	2010/02	user11649	password	69	100000	F
11650	GOEGXP	NGLUOYLVII	6063766002 Dell Way	\N	KVGIMOD	\N	0	Canada	2	NGLUOYLVII@dell.com	6063766002	1	6567515709437431	2011/11	user11650	password	56	80000	F
11651	BZLYPY	FATUZEPHNA	7098225342 Dell Way	\N	DTIQIMU	\N	0	South Africa	2	FATUZEPHNA@dell.com	7098225342	3	6098362827673555	2010/12	user11651	password	44	80000	M
11652	IEYXDE	YWZXBOFOPJ	2530032244 Dell Way	\N	IXZQKTN	\N	0	Australia	2	YWZXBOFOPJ@dell.com	2530032244	1	6963729022536427	2008/06	user11652	password	47	20000	M
11653	OBSRFR	OEOPTUDIDM	7504294659 Dell Way	\N	GCCRWQT	\N	0	Australia	2	OEOPTUDIDM@dell.com	7504294659	3	2164125328417867	2008/10	user11653	password	34	100000	F
11654	HRBMIQ	RXFLRJTUVA	8412098417 Dell Way	\N	XYRTPKU	\N	0	China	2	RXFLRJTUVA@dell.com	8412098417	5	5287747970316559	2011/02	user11654	password	49	20000	F
11655	CCXLSO	IYAZHTUDUR	1858625564 Dell Way	\N	CLKRWEZ	\N	0	Japan	2	IYAZHTUDUR@dell.com	1858625564	3	3872104924637824	2009/11	user11655	password	42	80000	M
11656	LNKDCT	BCSJWMNRDQ	7457946212 Dell Way	\N	COHZTGQ	\N	0	South Africa	2	BCSJWMNRDQ@dell.com	7457946212	5	1591885762289166	2011/04	user11656	password	69	80000	M
11657	FAWITY	LMIIZVZDLC	7048145172 Dell Way	\N	RTBLASH	\N	0	Russia	2	LMIIZVZDLC@dell.com	7048145172	2	4059535532258451	2012/01	user11657	password	86	80000	F
11658	ZPPSNB	FVJFRJIDLA	1603102567 Dell Way	\N	XMMXETQ	\N	0	South Africa	2	FVJFRJIDLA@dell.com	1603102567	5	8563964969944210	2008/11	user11658	password	58	40000	M
11659	DYPQAV	MJAESJHEKE	7246261914 Dell Way	\N	QWCVPSS	\N	0	Japan	2	MJAESJHEKE@dell.com	7246261914	3	7829129411373288	2011/02	user11659	password	26	60000	F
11660	CCWCYJ	LYNEIVISZZ	1491575470 Dell Way	\N	PBVEUNV	\N	0	France	2	LYNEIVISZZ@dell.com	1491575470	3	1885868405457586	2008/09	user11660	password	60	40000	M
11661	RFWQPI	OCNXXVQXVF	8293628660 Dell Way	\N	ZQKTEFG	\N	0	Chile	2	OCNXXVQXVF@dell.com	8293628660	2	4184297558385879	2010/12	user11661	password	70	40000	M
11662	YFGNNV	PBSNXJKSOJ	7594783720 Dell Way	\N	JYDNEJS	\N	0	UK	2	PBSNXJKSOJ@dell.com	7594783720	1	5566666577477009	2011/10	user11662	password	78	40000	M
11663	AOGOJW	QCKNLUGAEP	9253081370 Dell Way	\N	YHCDRVC	\N	0	France	2	QCKNLUGAEP@dell.com	9253081370	4	1771590706892311	2011/06	user11663	password	45	60000	F
11664	XSBHPR	JZEUUKUYAT	6592135085 Dell Way	\N	GCXXYAI	\N	0	South Africa	2	JZEUUKUYAT@dell.com	6592135085	3	6225963900797070	2008/10	user11664	password	20	60000	M
11665	TPAIGJ	IKECVZAVTG	9373809589 Dell Way	\N	YQEXQNT	\N	0	Chile	2	IKECVZAVTG@dell.com	9373809589	2	3820379931945354	2011/05	user11665	password	80	60000	F
11666	LLMSVU	DZWYZXUSDS	7643059287 Dell Way	\N	IIQYVKF	\N	0	Russia	2	DZWYZXUSDS@dell.com	7643059287	3	5470625829882920	2008/05	user11666	password	87	40000	M
11667	KSNGMQ	GJPFGJXJCG	9165027608 Dell Way	\N	SSFOCKH	\N	0	South Africa	2	GJPFGJXJCG@dell.com	9165027608	5	9672307085711510	2009/10	user11667	password	33	20000	F
11668	XPKKGQ	TVWZEUJGAB	7538047501 Dell Way	\N	ZGQCQYY	\N	0	Germany	2	TVWZEUJGAB@dell.com	7538047501	5	8363569905050100	2010/02	user11668	password	84	80000	F
11669	NBKTSE	OODTJNZKPZ	9123081929 Dell Way	\N	QFBGDAV	\N	0	South Africa	2	OODTJNZKPZ@dell.com	9123081929	4	4130793691147119	2008/07	user11669	password	90	20000	F
11670	BLUTQJ	ITCSHCCXBS	4854965268 Dell Way	\N	CDZGDUC	\N	0	Australia	2	ITCSHCCXBS@dell.com	4854965268	3	1391649111174047	2012/06	user11670	password	23	20000	M
11671	NVHDEP	XGHFIKCKCF	1113880882 Dell Way	\N	NCLQXOR	\N	0	China	2	XGHFIKCKCF@dell.com	1113880882	4	3602061856072396	2010/10	user11671	password	40	100000	F
11672	DGMHWJ	NEOWOQGQWU	8637290705 Dell Way	\N	THLQVDZ	\N	0	South Africa	2	NEOWOQGQWU@dell.com	8637290705	2	3890259950887412	2011/07	user11672	password	40	100000	M
11673	OLYKVM	OJJDAPUWJN	4364917999 Dell Way	\N	EVEAYDW	\N	0	Russia	2	OJJDAPUWJN@dell.com	4364917999	1	4839547859970480	2012/06	user11673	password	47	80000	F
11674	WOLRBA	AKDBZXYJKC	2268829309 Dell Way	\N	EPCCSZX	\N	0	Australia	2	AKDBZXYJKC@dell.com	2268829309	2	1062890022993087	2011/09	user11674	password	62	80000	M
11675	ECFFDG	QGIQEGAPJE	5491320032 Dell Way	\N	EMHWLEY	\N	0	Germany	2	QGIQEGAPJE@dell.com	5491320032	5	2810421234462410	2009/07	user11675	password	80	80000	M
11676	YZZBGP	IOFMVFBFKF	9746088310 Dell Way	\N	RSCDXAS	\N	0	China	2	IOFMVFBFKF@dell.com	9746088310	5	6470784360077233	2010/10	user11676	password	46	40000	M
11677	KGTQVC	FAOBGQGQWX	6665069055 Dell Way	\N	JYAGZSQ	\N	0	UK	2	FAOBGQGQWX@dell.com	6665069055	2	5298765898216516	2009/08	user11677	password	72	20000	F
11678	ZWRUYW	VNXCDESACC	3070403575 Dell Way	\N	YCIYVZW	\N	0	France	2	VNXCDESACC@dell.com	3070403575	2	8673230952583254	2012/02	user11678	password	86	100000	F
11679	UOWSLS	GJUKNNKPPI	5431007997 Dell Way	\N	SYGOXDA	\N	0	Canada	2	GJUKNNKPPI@dell.com	5431007997	5	1118551333434879	2010/10	user11679	password	84	80000	M
11680	MNIXGO	GAYUNJKDRC	6171737714 Dell Way	\N	BYRZCSD	\N	0	Germany	2	GAYUNJKDRC@dell.com	6171737714	1	2613954951986670	2009/01	user11680	password	79	100000	M
11681	JIKPXR	QWLEFVHXYI	6140146606 Dell Way	\N	WPIYHLO	\N	0	South Africa	2	QWLEFVHXYI@dell.com	6140146606	4	3448898836504668	2011/07	user11681	password	37	20000	M
11682	PNONEE	JQJOMQMLZI	5868036418 Dell Way	\N	BHHJSVG	\N	0	Chile	2	JQJOMQMLZI@dell.com	5868036418	3	9184985904954376	2008/10	user11682	password	19	20000	F
11683	OPWTUG	JDVWUHHTPI	4904996530 Dell Way	\N	AWSTSYB	\N	0	Chile	2	JDVWUHHTPI@dell.com	4904996530	5	4116352288052440	2009/12	user11683	password	46	60000	M
11684	ZLHUSQ	YNNSUVLKDM	3702426739 Dell Way	\N	GWGZUIF	\N	0	Chile	2	YNNSUVLKDM@dell.com	3702426739	3	4766199945937842	2009/12	user11684	password	90	100000	M
11685	LDTDTR	QHKLCWVGIC	8413126667 Dell Way	\N	CPBWYGC	\N	0	Chile	2	QHKLCWVGIC@dell.com	8413126667	3	5795225281268359	2011/06	user11685	password	45	80000	M
11686	MMCGDT	ONEQKZWSCZ	4619233847 Dell Way	\N	IDVHKXN	\N	0	Chile	2	ONEQKZWSCZ@dell.com	4619233847	1	1069469443988055	2012/05	user11686	password	71	100000	M
11687	FYEIRS	WWIGWFZYEI	2358653517 Dell Way	\N	CZPMXCS	\N	0	China	2	WWIGWFZYEI@dell.com	2358653517	4	2817717396188527	2010/06	user11687	password	21	60000	M
11688	ZQZRIW	NRDJWDIBLK	4116333386 Dell Way	\N	BBXYEPG	\N	0	China	2	NRDJWDIBLK@dell.com	4116333386	3	8984067641664297	2012/07	user11688	password	44	60000	F
11689	ZMDIIR	ZMBWPJYBUZ	6565571744 Dell Way	\N	DRXHHEQ	\N	0	Japan	2	ZMBWPJYBUZ@dell.com	6565571744	3	4850652243010700	2008/11	user11689	password	83	80000	M
11690	JTESLE	EMBUWZWQYZ	4579558331 Dell Way	\N	HWHOAXE	\N	0	Japan	2	EMBUWZWQYZ@dell.com	4579558331	4	7864360205829144	2009/07	user11690	password	44	20000	M
11691	DHPOMT	BNOYNKOLKW	3120067404 Dell Way	\N	IRLIOQZ	\N	0	UK	2	BNOYNKOLKW@dell.com	3120067404	4	2986287518870085	2011/02	user11691	password	42	80000	F
11692	QFUCZW	QNUDYJOIFX	9571813858 Dell Way	\N	AQFPGFO	\N	0	France	2	QNUDYJOIFX@dell.com	9571813858	4	3210115950088948	2008/02	user11692	password	81	40000	M
11693	BCUBZK	PTONCCWIZX	7963968303 Dell Way	\N	YFMFLAS	\N	0	China	2	PTONCCWIZX@dell.com	7963968303	5	5040311213117093	2012/10	user11693	password	72	60000	M
11694	WKYVUN	OJBRMYZMVY	8252979854 Dell Way	\N	RHDDIWN	\N	0	Australia	2	OJBRMYZMVY@dell.com	8252979854	5	9644735540263356	2011/09	user11694	password	57	60000	M
11695	YMJTAY	CCQOAPAWNS	3424668799 Dell Way	\N	ERVMNIP	\N	0	China	2	CCQOAPAWNS@dell.com	3424668799	3	9471155298408122	2012/02	user11695	password	52	60000	F
11696	YXTZWV	BMJCBKYPCC	7500498855 Dell Way	\N	GXPTFEB	\N	0	France	2	BMJCBKYPCC@dell.com	7500498855	1	5187553289812058	2012/06	user11696	password	90	100000	F
11697	XOKUKL	GUNIEMYGPE	9908529443 Dell Way	\N	EEYKJZW	\N	0	Australia	2	GUNIEMYGPE@dell.com	9908529443	2	9018677492160352	2010/05	user11697	password	69	100000	F
11698	HHBRTI	MHQQUPXJTB	7300257573 Dell Way	\N	NSMXRJZ	\N	0	Japan	2	MHQQUPXJTB@dell.com	7300257573	5	2244414103683084	2008/08	user11698	password	20	40000	M
11699	IJOCRA	JIRDXONRQB	8159409978 Dell Way	\N	JCYBLXS	\N	0	Canada	2	JIRDXONRQB@dell.com	8159409978	5	2878883810713887	2009/11	user11699	password	56	40000	F
11700	WUIOVS	WMWUAJLRKV	5186805594 Dell Way	\N	UIWGGPK	\N	0	Australia	2	WMWUAJLRKV@dell.com	5186805594	4	4899926434271038	2009/02	user11700	password	67	60000	F
11701	MXOHPL	TMFUVRMFMG	5733036739 Dell Way	\N	OJNUYXW	\N	0	France	2	TMFUVRMFMG@dell.com	5733036739	2	8047994716558606	2011/12	user11701	password	45	80000	F
11702	HGSXRM	JWGEOTKAZY	9181229886 Dell Way	\N	JMTIKQT	\N	0	UK	2	JWGEOTKAZY@dell.com	9181229886	3	6266577109228820	2012/11	user11702	password	37	40000	F
11703	NBCENM	BURPNBQNAA	6571459809 Dell Way	\N	ATIKJCI	\N	0	Chile	2	BURPNBQNAA@dell.com	6571459809	5	2542049391660839	2010/03	user11703	password	54	80000	M
11704	OVWCIX	WZNKBDYBDY	6056513728 Dell Way	\N	VMIFORM	\N	0	Canada	2	WZNKBDYBDY@dell.com	6056513728	4	7488022145349533	2011/02	user11704	password	51	60000	M
11705	HGUPER	PSCQWARZYN	8701003986 Dell Way	\N	MHSBYFG	\N	0	France	2	PSCQWARZYN@dell.com	8701003986	5	2982895752415061	2008/06	user11705	password	64	80000	M
11706	XNICEY	UGOQGGQFTC	4463948098 Dell Way	\N	MLEKQKW	\N	0	Germany	2	UGOQGGQFTC@dell.com	4463948098	1	5705977890174836	2012/09	user11706	password	35	60000	M
11707	TWSYUM	EICLPTQIWC	5217985013 Dell Way	\N	UAMLLJZ	\N	0	South Africa	2	EICLPTQIWC@dell.com	5217985013	3	6671466588974000	2008/09	user11707	password	29	100000	F
11708	ANKUAP	DDASWRBSTW	8118998191 Dell Way	\N	TGIEPHZ	\N	0	Australia	2	DDASWRBSTW@dell.com	8118998191	4	3513978174887598	2010/10	user11708	password	25	20000	M
11709	QKPQAS	TALQRNILKB	8647505173 Dell Way	\N	RSGHAFJ	\N	0	South Africa	2	TALQRNILKB@dell.com	8647505173	4	4113922990392894	2011/10	user11709	password	43	60000	F
11710	UAAUSU	VEKMSTYCUP	9425940584 Dell Way	\N	VAXWGHR	\N	0	Canada	2	VEKMSTYCUP@dell.com	9425940584	1	7656790219247342	2011/05	user11710	password	29	20000	F
11711	ECYXXT	BHGTBEWVUR	2908952040 Dell Way	\N	WRNDZFG	\N	0	UK	2	BHGTBEWVUR@dell.com	2908952040	5	6390293962322176	2010/02	user11711	password	67	80000	F
11712	URFRKG	ZQAAUWWOOT	2199026123 Dell Way	\N	GBXFGDD	\N	0	France	2	ZQAAUWWOOT@dell.com	2199026123	4	1464255478233099	2009/05	user11712	password	75	60000	F
11713	LUWVBW	MCXGYTVMNC	2604419623 Dell Way	\N	OKIVOLH	\N	0	Japan	2	MCXGYTVMNC@dell.com	2604419623	2	9686910431366416	2010/02	user11713	password	59	80000	M
11714	JRKLNW	NLDMFYZSAN	9644222002 Dell Way	\N	DJJRUQJ	\N	0	UK	2	NLDMFYZSAN@dell.com	9644222002	2	6065309261903167	2008/11	user11714	password	43	80000	F
11715	AAROXE	ZAQEZQXAEA	3982798173 Dell Way	\N	JNRDDAD	\N	0	Australia	2	ZAQEZQXAEA@dell.com	3982798173	4	2539202281273901	2009/01	user11715	password	76	60000	F
11716	VCPTHP	TYTSORSSRB	1224394410 Dell Way	\N	FIFJJIL	\N	0	Japan	2	TYTSORSSRB@dell.com	1224394410	4	8998131989035756	2008/06	user11716	password	42	20000	F
11717	LSZSHT	QBMFSFXKHD	5873360896 Dell Way	\N	SNMBVYT	\N	0	South Africa	2	QBMFSFXKHD@dell.com	5873360896	4	9344489436130972	2012/12	user11717	password	20	40000	F
11718	TFDBZU	DLZWRXGYAZ	5074310823 Dell Way	\N	LMBHKUE	\N	0	UK	2	DLZWRXGYAZ@dell.com	5074310823	1	9348805215209724	2010/02	user11718	password	29	100000	M
11719	JZYJTB	VSYMPELQEW	4510903184 Dell Way	\N	DFDOAHN	\N	0	France	2	VSYMPELQEW@dell.com	4510903184	3	9122897028457374	2010/08	user11719	password	72	40000	M
11720	SIILKE	EIQUNBKRYN	1167674290 Dell Way	\N	WCBXKPJ	\N	0	Russia	2	EIQUNBKRYN@dell.com	1167674290	2	3646675700787455	2011/01	user11720	password	67	60000	M
11721	ZXEJBJ	SSDFUOWSCT	3688076133 Dell Way	\N	UEQFTAZ	\N	0	Russia	2	SSDFUOWSCT@dell.com	3688076133	2	4413479364477098	2009/12	user11721	password	88	20000	M
11722	WGIYPA	RTGLICEKWZ	4982276881 Dell Way	\N	ONEINEC	\N	0	South Africa	2	RTGLICEKWZ@dell.com	4982276881	3	2296286601107567	2009/06	user11722	password	32	40000	F
11723	LRGASY	UYJCBOMXNB	9481133086 Dell Way	\N	LSJYWMU	\N	0	China	2	UYJCBOMXNB@dell.com	9481133086	5	7482211759779603	2009/02	user11723	password	23	80000	M
11724	TYPMWJ	LGLNUYLIAW	5627995035 Dell Way	\N	BJVYWPG	\N	0	Russia	2	LGLNUYLIAW@dell.com	5627995035	5	2510899138171226	2011/01	user11724	password	79	20000	M
11725	UTHQDS	XPFRNQANMB	2829245371 Dell Way	\N	XHZTXGO	\N	0	France	2	XPFRNQANMB@dell.com	2829245371	4	1325500208418816	2009/07	user11725	password	33	20000	F
11726	ZIZCAW	RFOFWPTJQQ	6995196732 Dell Way	\N	RQKOWYY	\N	0	Australia	2	RFOFWPTJQQ@dell.com	6995196732	5	3850841993466020	2009/03	user11726	password	43	60000	F
11727	RPHRMZ	XAEUQYDGOU	3569382584 Dell Way	\N	XYJUXHV	\N	0	Germany	2	XAEUQYDGOU@dell.com	3569382584	1	8200488231610508	2010/07	user11727	password	46	80000	F
11728	ZZWLYU	LDOBBSIQMG	1113402791 Dell Way	\N	PVAMDWB	\N	0	France	2	LDOBBSIQMG@dell.com	1113402791	5	9236640078946948	2010/03	user11728	password	61	80000	F
11729	OOQNJC	RXETPMKCSZ	4426352044 Dell Way	\N	YTMBPNM	\N	0	Germany	2	RXETPMKCSZ@dell.com	4426352044	3	2147640924435109	2011/01	user11729	password	79	100000	M
11730	KLCTOU	RSNGFXIYXH	3237360278 Dell Way	\N	RJIGXVW	\N	0	Chile	2	RSNGFXIYXH@dell.com	3237360278	5	9006029669661076	2009/10	user11730	password	70	100000	F
11731	EYZSSQ	KGWPEFOBNF	3549241646 Dell Way	\N	KWLHRHO	\N	0	UK	2	KGWPEFOBNF@dell.com	3549241646	3	2710382922552526	2008/03	user11731	password	19	40000	F
11732	YHBQXM	XUCBAQCNVN	8782523354 Dell Way	\N	KHVBPKA	\N	0	South Africa	2	XUCBAQCNVN@dell.com	8782523354	2	9813966169487686	2008/03	user11732	password	39	40000	F
11733	PLUNYS	IATIQVWMJG	5975842579 Dell Way	\N	UEIJPJG	\N	0	France	2	IATIQVWMJG@dell.com	5975842579	2	5435905036516488	2011/07	user11733	password	82	100000	F
11734	ITQGLY	HEHYAEKJLF	1738578095 Dell Way	\N	OTPDDVP	\N	0	Japan	2	HEHYAEKJLF@dell.com	1738578095	1	4982157032471150	2011/12	user11734	password	45	80000	F
11735	CJOOIW	SPUSUFCFKQ	4818371773 Dell Way	\N	ZZTCVJT	\N	0	UK	2	SPUSUFCFKQ@dell.com	4818371773	2	5864946349989623	2009/07	user11735	password	38	80000	M
11736	RGFZCY	PXQJDTOOJO	6644812991 Dell Way	\N	ODQJMKH	\N	0	UK	2	PXQJDTOOJO@dell.com	6644812991	5	3601489627733827	2009/02	user11736	password	89	100000	M
11737	GDUJBJ	GSTKLIYVWM	1065069460 Dell Way	\N	YNWLYEI	\N	0	Germany	2	GSTKLIYVWM@dell.com	1065069460	4	7884281588252635	2008/08	user11737	password	66	100000	M
11738	USEWBL	PUVBCTWZGV	3013323515 Dell Way	\N	MCGKGPY	\N	0	Chile	2	PUVBCTWZGV@dell.com	3013323515	4	4596485886257142	2012/05	user11738	password	41	80000	F
11739	AVBCHQ	WDRZWOYCKK	5381798812 Dell Way	\N	FQVMGTS	\N	0	France	2	WDRZWOYCKK@dell.com	5381798812	1	3674663328099996	2012/06	user11739	password	87	20000	F
11740	UCOCTL	FLKCAIFKTK	7501292491 Dell Way	\N	BOWHIPT	\N	0	South Africa	2	FLKCAIFKTK@dell.com	7501292491	1	7136405058205128	2008/01	user11740	password	72	80000	M
11741	WFXPQD	AAFBJKLDVM	6149649224 Dell Way	\N	RRTZHNU	\N	0	UK	2	AAFBJKLDVM@dell.com	6149649224	3	2533093265257776	2010/03	user11741	password	77	60000	F
11742	AIRRLS	RQTBAEEVQW	2351905109 Dell Way	\N	NKWUXRU	\N	0	France	2	RQTBAEEVQW@dell.com	2351905109	5	1719044891186058	2009/10	user11742	password	53	60000	M
11743	UDLFVD	WPFXUKTKGG	8371889719 Dell Way	\N	VDBTUWG	\N	0	UK	2	WPFXUKTKGG@dell.com	8371889719	2	3804843818768859	2011/10	user11743	password	73	60000	M
11744	XWVSAS	IFPCQINXPI	6721834974 Dell Way	\N	ARCUNIS	\N	0	China	2	IFPCQINXPI@dell.com	6721834974	1	9467813441995532	2010/10	user11744	password	43	20000	M
11745	FWLFOT	LEVBMIYCRZ	5784558370 Dell Way	\N	TTTHBMQ	\N	0	Russia	2	LEVBMIYCRZ@dell.com	5784558370	3	2358931692317128	2009/11	user11745	password	31	20000	F
11746	BLIQFU	UBVHJUJBUD	6292169511 Dell Way	\N	VNKXAAP	\N	0	Germany	2	UBVHJUJBUD@dell.com	6292169511	4	9012654239777476	2010/12	user11746	password	85	80000	F
11747	JYQPSK	QORAJBBDEX	2520484900 Dell Way	\N	ROURPKG	\N	0	Canada	2	QORAJBBDEX@dell.com	2520484900	1	7168953580781818	2008/01	user11747	password	39	20000	F
11748	GUAYEQ	NWQWXSZCPQ	7235921127 Dell Way	\N	RKIHUOM	\N	0	UK	2	NWQWXSZCPQ@dell.com	7235921127	1	1759556184057146	2011/06	user11748	password	34	20000	M
11749	ZEQEUD	BLZZDZCTQT	6757120327 Dell Way	\N	DYAXNMW	\N	0	Chile	2	BLZZDZCTQT@dell.com	6757120327	5	9574264031369240	2008/03	user11749	password	26	80000	F
11750	HJJCNL	OMKRMMLCGO	3741695972 Dell Way	\N	AGMOTIT	\N	0	China	2	OMKRMMLCGO@dell.com	3741695972	4	5224717856384814	2010/11	user11750	password	34	80000	F
11751	PAGDLU	PWMBJXDPLE	3023953968 Dell Way	\N	VXTPGNZ	\N	0	Germany	2	PWMBJXDPLE@dell.com	3023953968	3	1450735372025519	2008/09	user11751	password	70	40000	F
11752	TLKFGA	BSBKPFABKV	8487953467 Dell Way	\N	ZDLGQKU	\N	0	South Africa	2	BSBKPFABKV@dell.com	8487953467	5	9484163639135660	2010/07	user11752	password	28	80000	F
11753	PENVEP	OGAEMAFWWF	1658282123 Dell Way	\N	AHLRRFO	\N	0	Germany	2	OGAEMAFWWF@dell.com	1658282123	3	1059375792741775	2011/08	user11753	password	75	100000	F
11754	ZMBDBP	JCTWCZSZET	5008245064 Dell Way	\N	GPKYVYL	\N	0	South Africa	2	JCTWCZSZET@dell.com	5008245064	3	5800738071557135	2008/03	user11754	password	53	40000	F
11755	ZJIBZS	DSOGRHFWAL	3221685696 Dell Way	\N	LKJHJVE	\N	0	South Africa	2	DSOGRHFWAL@dell.com	3221685696	4	9090127554722132	2010/03	user11755	password	33	80000	F
11756	PZFORI	GGOYNUVNGG	4756983108 Dell Way	\N	YQOILSD	\N	0	Japan	2	GGOYNUVNGG@dell.com	4756983108	1	2312720956746489	2011/03	user11756	password	76	80000	M
11757	UYJMHQ	SWPFQKTWRS	2719142237 Dell Way	\N	MFAXYEP	\N	0	China	2	SWPFQKTWRS@dell.com	2719142237	4	9653807705733926	2010/07	user11757	password	71	40000	F
11758	RQUZGM	VWSMHMIYEV	1777602316 Dell Way	\N	EFTCJIM	\N	0	Germany	2	VWSMHMIYEV@dell.com	1777602316	3	9886409164872020	2011/02	user11758	password	35	100000	M
11759	WTVDFQ	AYCHLLGPHK	4799806407 Dell Way	\N	VANEJZS	\N	0	France	2	AYCHLLGPHK@dell.com	4799806407	4	1751639254391193	2010/12	user11759	password	20	60000	M
11760	UFZAWZ	YZHJLNZSYV	4927913940 Dell Way	\N	TLZCLSO	\N	0	South Africa	2	YZHJLNZSYV@dell.com	4927913940	4	5066744567360729	2009/09	user11760	password	81	40000	F
11761	CFLZFK	ZMUKAUCYPW	2397866361 Dell Way	\N	KPYVHNS	\N	0	Russia	2	ZMUKAUCYPW@dell.com	2397866361	1	2203780032694340	2012/01	user11761	password	45	40000	F
11762	PSCVDB	HXMHRPGGLQ	4296347162 Dell Way	\N	WKMDXFW	\N	0	Australia	2	HXMHRPGGLQ@dell.com	4296347162	1	8968464795965702	2010/05	user11762	password	29	60000	M
11763	XRUATC	XFKPUQWGGS	7667634432 Dell Way	\N	QSWNXSO	\N	0	Chile	2	XFKPUQWGGS@dell.com	7667634432	3	7175676017999650	2008/08	user11763	password	35	20000	M
11764	XXNQZL	WJAQZWWGPN	1414789500 Dell Way	\N	ZLAWEPE	\N	0	UK	2	WJAQZWWGPN@dell.com	1414789500	5	1349410249385982	2011/01	user11764	password	28	20000	M
11765	BRPADL	KDCKAZQQMP	5346196544 Dell Way	\N	BNMGCQD	\N	0	Canada	2	KDCKAZQQMP@dell.com	5346196544	1	8270309619139881	2010/04	user11765	password	89	60000	F
11766	RDKUPU	YSEYRVOELQ	2704458576 Dell Way	\N	RYWUOAX	\N	0	Australia	2	YSEYRVOELQ@dell.com	2704458576	4	6457515425980092	2010/09	user11766	password	28	100000	F
11767	HHEWBC	OGBGCPKNGC	5639907882 Dell Way	\N	LCWACUB	\N	0	Chile	2	OGBGCPKNGC@dell.com	5639907882	4	8349341356195510	2009/10	user11767	password	69	60000	F
11768	ZTYBWN	IXULNFYTHK	2752040034 Dell Way	\N	WELZZNG	\N	0	France	2	IXULNFYTHK@dell.com	2752040034	1	7325489205773921	2008/10	user11768	password	39	20000	M
11769	BBVXPE	UJPHONBWYX	2841294051 Dell Way	\N	BKWAXDM	\N	0	Canada	2	UJPHONBWYX@dell.com	2841294051	1	2091883364599198	2012/06	user11769	password	34	80000	M
11770	HPLWTG	GINUWPRUMS	4462512211 Dell Way	\N	FJSDMFG	\N	0	Japan	2	GINUWPRUMS@dell.com	4462512211	2	7029255514498801	2012/07	user11770	password	48	60000	M
11771	AWSTCZ	BQTXFKSSCX	6666433394 Dell Way	\N	BVBNAHF	\N	0	China	2	BQTXFKSSCX@dell.com	6666433394	5	3431383202783763	2009/04	user11771	password	68	20000	F
11772	OUBQTC	GNAMYSEBQG	8791657399 Dell Way	\N	WRTWZZH	\N	0	Germany	2	GNAMYSEBQG@dell.com	8791657399	3	8203127194195987	2008/03	user11772	password	81	60000	M
11773	ROKLRR	YREWKIYBPU	5645711733 Dell Way	\N	TIRSIZH	\N	0	Canada	2	YREWKIYBPU@dell.com	5645711733	1	4293079989030957	2011/12	user11773	password	80	60000	M
11774	KYBBQA	SUXDDVESQX	1145124091 Dell Way	\N	BIQKHXP	\N	0	Russia	2	SUXDDVESQX@dell.com	1145124091	5	5915919460821897	2012/10	user11774	password	23	80000	F
11775	ARGRRZ	LODPJHIZFK	3844431761 Dell Way	\N	IWUPTJK	\N	0	Russia	2	LODPJHIZFK@dell.com	3844431761	5	7865141298621894	2008/01	user11775	password	45	40000	F
11776	BPRSOD	GSTQZBQFLY	8743618944 Dell Way	\N	BFOVPYQ	\N	0	UK	2	GSTQZBQFLY@dell.com	8743618944	2	1254513606429100	2012/10	user11776	password	43	100000	M
11777	YPNNTU	FMKFNBLZAN	4070126075 Dell Way	\N	FOIUMYS	\N	0	China	2	FMKFNBLZAN@dell.com	4070126075	4	2926295140758157	2008/01	user11777	password	26	100000	F
11778	SKOLET	XPZLQKKRXP	8390188759 Dell Way	\N	FGKSFCB	\N	0	Germany	2	XPZLQKKRXP@dell.com	8390188759	2	6915031640324742	2012/05	user11778	password	57	100000	F
11779	YMNDFL	SEWJPHANWF	3072637227 Dell Way	\N	UHYZJZO	\N	0	Canada	2	SEWJPHANWF@dell.com	3072637227	2	1866734419018030	2011/10	user11779	password	19	80000	M
11780	MFVSQN	XMWMTXZQCU	5904126123 Dell Way	\N	XAUHAIM	\N	0	Chile	2	XMWMTXZQCU@dell.com	5904126123	3	8594215241726489	2009/08	user11780	password	56	20000	F
11781	SVUJJR	VGDPDDFGXD	5241318488 Dell Way	\N	HRKHAXN	\N	0	Germany	2	VGDPDDFGXD@dell.com	5241318488	2	8857450235169382	2008/11	user11781	password	82	20000	M
11782	SXZCOV	ISKMWQTUTA	3048430094 Dell Way	\N	MEIMBWB	\N	0	Germany	2	ISKMWQTUTA@dell.com	3048430094	5	6487942270934582	2008/10	user11782	password	72	80000	M
11783	RTQGPZ	ZZMVQFQJFC	6271751815 Dell Way	\N	OOPQKQE	\N	0	Japan	2	ZZMVQFQJFC@dell.com	6271751815	4	7766100517008454	2010/07	user11783	password	56	100000	F
11784	HPLWPK	WCGMHWWNYK	1107181017 Dell Way	\N	BOBLFFB	\N	0	Russia	2	WCGMHWWNYK@dell.com	1107181017	5	2697671770583838	2010/05	user11784	password	29	80000	M
11785	TFMJQI	LWUTSQHRBI	7141290081 Dell Way	\N	FCUKIWE	\N	0	China	2	LWUTSQHRBI@dell.com	7141290081	2	9047787385061384	2008/07	user11785	password	65	80000	F
11786	WDRMLD	IGWBXETYMY	9334193458 Dell Way	\N	BHJJDOS	\N	0	South Africa	2	IGWBXETYMY@dell.com	9334193458	4	8706751729827375	2010/04	user11786	password	54	80000	F
11787	QKPBOY	ILZFPSDCRF	9328453229 Dell Way	\N	JAONOHJ	\N	0	Germany	2	ILZFPSDCRF@dell.com	9328453229	2	9619902530219408	2008/09	user11787	password	69	40000	F
11788	DYKRWS	CWXROBTGGD	2689365773 Dell Way	\N	HVQWDZJ	\N	0	Australia	2	CWXROBTGGD@dell.com	2689365773	2	3214645991567522	2012/01	user11788	password	59	40000	F
11789	MQUJIX	FGOUHIAOLH	8094921987 Dell Way	\N	JBDMBMN	\N	0	Chile	2	FGOUHIAOLH@dell.com	8094921987	4	2193302649538964	2012/05	user11789	password	44	100000	M
11790	ZTFIQK	OEEWNEKYMT	6046269169 Dell Way	\N	APGBCUH	\N	0	South Africa	2	OEEWNEKYMT@dell.com	6046269169	3	7054730175994337	2012/10	user11790	password	62	80000	M
11791	JYCZIQ	ENNRSXPERP	4335883845 Dell Way	\N	TYRWSYS	\N	0	Chile	2	ENNRSXPERP@dell.com	4335883845	2	2688856393098831	2008/01	user11791	password	86	100000	F
11792	XZIFQM	TEELCTPUJJ	4064825380 Dell Way	\N	SAFKZYS	\N	0	China	2	TEELCTPUJJ@dell.com	4064825380	5	5382561812642962	2009/10	user11792	password	47	80000	M
11793	KAYBNR	FRDHLTBUCT	8017072576 Dell Way	\N	VIEUHXD	\N	0	Japan	2	FRDHLTBUCT@dell.com	8017072576	4	9708414476364852	2011/01	user11793	password	66	40000	F
11794	SGLFYR	XCYIVADYUZ	5538361695 Dell Way	\N	GZTOWXE	\N	0	Japan	2	XCYIVADYUZ@dell.com	5538361695	1	3337433786131442	2010/10	user11794	password	60	100000	F
11795	WKSUBP	XAYSBCQVBX	7902297927 Dell Way	\N	VVLRSQI	\N	0	Chile	2	XAYSBCQVBX@dell.com	7902297927	3	7689612561836839	2010/03	user11795	password	67	20000	F
11796	BUVDJT	DILEKCAMZV	5182073989 Dell Way	\N	ILNACWG	\N	0	South Africa	2	DILEKCAMZV@dell.com	5182073989	1	4773821162059903	2011/09	user11796	password	53	80000	M
11797	GNWQGA	ZSFKUFWUBE	5315424750 Dell Way	\N	FPFIMME	\N	0	UK	2	ZSFKUFWUBE@dell.com	5315424750	3	6161672524176539	2008/01	user11797	password	36	100000	F
11798	UTZAUY	SZIMFFGHKM	5886805720 Dell Way	\N	XQUJCZH	\N	0	Germany	2	SZIMFFGHKM@dell.com	5886805720	5	7618291488382966	2011/02	user11798	password	64	100000	M
11799	KXXEWP	EFCKKJRUWO	1339043540 Dell Way	\N	LRXNQEC	\N	0	Canada	2	EFCKKJRUWO@dell.com	1339043540	5	8024523765780032	2008/06	user11799	password	70	20000	M
11800	QXBMNG	RPQBYHWVWI	8057722212 Dell Way	\N	MUVCZYH	\N	0	Australia	2	RPQBYHWVWI@dell.com	8057722212	1	2324389018584043	2009/10	user11800	password	29	20000	F
11801	BFXOLO	DBQCJNYFVK	8810212858 Dell Way	\N	ARNZPUZ	\N	0	China	2	DBQCJNYFVK@dell.com	8810212858	1	6817548807244749	2011/04	user11801	password	75	20000	F
11802	ZYXKMB	MDEVQCBMNB	2528455139 Dell Way	\N	DABTVAD	\N	0	Japan	2	MDEVQCBMNB@dell.com	2528455139	4	4062007707543671	2010/07	user11802	password	46	100000	M
11803	ISYVUK	YYGPBHBOJF	8410108779 Dell Way	\N	OKYKLBC	\N	0	Germany	2	YYGPBHBOJF@dell.com	8410108779	3	1504582675173878	2009/10	user11803	password	81	100000	F
11804	PVZJGY	HMNITPXCVL	4005379381 Dell Way	\N	NTVYVXN	\N	0	Japan	2	HMNITPXCVL@dell.com	4005379381	3	1092525876127183	2008/06	user11804	password	84	40000	F
11805	TGKAFS	MTAGJYJEJW	8805848330 Dell Way	\N	YFUTDHJ	\N	0	France	2	MTAGJYJEJW@dell.com	8805848330	2	6458872070536018	2009/04	user11805	password	83	40000	F
11806	ESBJKO	CLULJDQTZO	1538747748 Dell Way	\N	YUHCBRO	\N	0	UK	2	CLULJDQTZO@dell.com	1538747748	1	3189880372025072	2009/01	user11806	password	60	60000	F
11807	HMPSAR	EUDNYTHYIG	1206682116 Dell Way	\N	SPIUHWS	\N	0	China	2	EUDNYTHYIG@dell.com	1206682116	5	7246303916443140	2008/07	user11807	password	26	40000	M
11808	PWNPOS	KSFILNGTTZ	4702029683 Dell Way	\N	JBTQYLZ	\N	0	UK	2	KSFILNGTTZ@dell.com	4702029683	4	1395920717623084	2012/10	user11808	password	42	80000	F
11809	FHZTZJ	LFSXTYRMYB	4127444844 Dell Way	\N	ORSNDRM	\N	0	Germany	2	LFSXTYRMYB@dell.com	4127444844	3	5397053054533899	2008/11	user11809	password	36	60000	F
11810	OLVOVH	UNENMWAKYO	1611159789 Dell Way	\N	CQBFHOT	\N	0	Japan	2	UNENMWAKYO@dell.com	1611159789	2	8011520303320140	2012/07	user11810	password	38	100000	F
11811	TUQOCK	BHYNDYYBMA	3232202449 Dell Way	\N	SOGACZQ	\N	0	Canada	2	BHYNDYYBMA@dell.com	3232202449	3	1840504158288240	2011/09	user11811	password	23	100000	F
11812	WLZZWB	GUPKSNLFOE	3202147593 Dell Way	\N	TUEWUVA	\N	0	Australia	2	GUPKSNLFOE@dell.com	3202147593	1	8110541295260192	2012/03	user11812	password	62	40000	F
11813	BKBYLH	SBRLPDQDHK	4732714347 Dell Way	\N	XLGSGHT	\N	0	Germany	2	SBRLPDQDHK@dell.com	4732714347	3	5171487763058394	2011/02	user11813	password	80	80000	F
11814	GTDRBW	SSHHWXLDIJ	4126796403 Dell Way	\N	POBWWVJ	\N	0	Chile	2	SSHHWXLDIJ@dell.com	4126796403	5	9055886378046126	2010/09	user11814	password	61	80000	M
11815	JWQKSJ	CZRYXCCFLS	7982279288 Dell Way	\N	UNORIYY	\N	0	Japan	2	CZRYXCCFLS@dell.com	7982279288	5	2674793843645602	2010/06	user11815	password	83	60000	M
11816	TAELJH	LAGJDIOPAJ	8359290474 Dell Way	\N	CPBLNZD	\N	0	Chile	2	LAGJDIOPAJ@dell.com	8359290474	2	7900742979720236	2009/03	user11816	password	30	20000	M
11817	FFKOMW	PTFSBTHCDK	4132864494 Dell Way	\N	REWFEAM	\N	0	UK	2	PTFSBTHCDK@dell.com	4132864494	2	3102702284231782	2010/06	user11817	password	37	60000	M
11818	MYFZUV	SZNUTVWXGO	5612767321 Dell Way	\N	CDTGDGG	\N	0	France	2	SZNUTVWXGO@dell.com	5612767321	3	1600147422868758	2012/09	user11818	password	62	60000	F
11819	OUFJPX	JDSDZOBFDD	2029700371 Dell Way	\N	JWKNDQZ	\N	0	Japan	2	JDSDZOBFDD@dell.com	2029700371	1	6301681823097170	2012/09	user11819	password	30	20000	F
11820	YHPOFZ	RXCRMDXPHG	8343514395 Dell Way	\N	MRTPITG	\N	0	France	2	RXCRMDXPHG@dell.com	8343514395	5	3742018784862012	2010/01	user11820	password	46	80000	M
11821	RINXHF	UKWGOUWVAI	1180725416 Dell Way	\N	NUYWNEH	\N	0	China	2	UKWGOUWVAI@dell.com	1180725416	4	8554621679242701	2008/01	user11821	password	58	100000	M
11822	XNOETJ	OPQDJMYKVM	3330875081 Dell Way	\N	FTISYQC	\N	0	UK	2	OPQDJMYKVM@dell.com	3330875081	5	9961630606092514	2009/06	user11822	password	90	100000	F
11823	NNOGWD	VNGFZFQVRV	6083528434 Dell Way	\N	PAONRQM	\N	0	UK	2	VNGFZFQVRV@dell.com	6083528434	3	2763938007410616	2008/06	user11823	password	28	60000	M
11824	QZFNCB	AIHANYVFTK	9379370558 Dell Way	\N	GIYXZLW	\N	0	Germany	2	AIHANYVFTK@dell.com	9379370558	1	6179393556434662	2010/03	user11824	password	90	40000	M
11825	YPJBRK	JZKXXGDQQJ	2778688438 Dell Way	\N	ZPHYADL	\N	0	UK	2	JZKXXGDQQJ@dell.com	2778688438	1	4272543852683157	2009/01	user11825	password	73	40000	M
11826	JPABZK	AKHXQLOHUN	9500024094 Dell Way	\N	WBLWFXV	\N	0	France	2	AKHXQLOHUN@dell.com	9500024094	1	8235690573696048	2012/12	user11826	password	20	100000	F
11827	QZJPJK	ARHQCWXXJU	7063689751 Dell Way	\N	ZVQETMP	\N	0	Japan	2	ARHQCWXXJU@dell.com	7063689751	3	6886119086761028	2011/06	user11827	password	62	100000	F
11828	PIRZTR	QAITXGRGAQ	8448900235 Dell Way	\N	CRVVDKN	\N	0	South Africa	2	QAITXGRGAQ@dell.com	8448900235	1	4976794483605772	2009/10	user11828	password	47	40000	F
11829	TAIMSZ	NBTKHKRHAT	3383725993 Dell Way	\N	YVPCGCX	\N	0	Australia	2	NBTKHKRHAT@dell.com	3383725993	2	4186599233187735	2008/09	user11829	password	68	60000	F
11830	STYLSL	MLVTVMAWGZ	3811407351 Dell Way	\N	SVBYXZB	\N	0	Canada	2	MLVTVMAWGZ@dell.com	3811407351	2	3020383374299854	2008/02	user11830	password	63	60000	M
11831	JMFBYS	NULJHMFNLX	3812197350 Dell Way	\N	INWGMXL	\N	0	South Africa	2	NULJHMFNLX@dell.com	3812197350	4	8696315853856505	2010/04	user11831	password	46	40000	M
11832	WLSUDG	POPWBVJMTS	1425140006 Dell Way	\N	AQYNNKH	\N	0	South Africa	2	POPWBVJMTS@dell.com	1425140006	1	3209624225739390	2009/07	user11832	password	50	100000	F
11833	WSFAYU	POQQJADCSD	2032062526 Dell Way	\N	SQQGBYC	\N	0	Australia	2	POQQJADCSD@dell.com	2032062526	2	4812408284284175	2011/10	user11833	password	48	20000	M
11834	DISBCH	QTXZTBCMFV	5911188090 Dell Way	\N	DVCEUFG	\N	0	UK	2	QTXZTBCMFV@dell.com	5911188090	4	6212260507512838	2009/02	user11834	password	66	20000	F
11835	ZSHCAX	VYXPZACEVF	3662455224 Dell Way	\N	AYJVDQT	\N	0	Japan	2	VYXPZACEVF@dell.com	3662455224	2	1173057395499199	2009/12	user11835	password	21	60000	M
11836	UWAUUW	SRMRROWNTW	7465249964 Dell Way	\N	LDRPTKG	\N	0	Australia	2	SRMRROWNTW@dell.com	7465249964	2	4826495426241309	2011/04	user11836	password	19	80000	F
11837	XRWRNP	IZGAOCOHZA	2321951741 Dell Way	\N	LQPEBWF	\N	0	Russia	2	IZGAOCOHZA@dell.com	2321951741	4	5123878523707390	2010/08	user11837	password	24	60000	M
11838	TLFHAO	HHPVKDCJDO	6167247344 Dell Way	\N	ZTSBPYU	\N	0	Russia	2	HHPVKDCJDO@dell.com	6167247344	2	3134300596546382	2009/05	user11838	password	77	80000	F
11839	GZKHOR	ODMYGPIKDH	4752453314 Dell Way	\N	EVIUUDN	\N	0	China	2	ODMYGPIKDH@dell.com	4752453314	4	6219519285950810	2011/07	user11839	password	44	100000	M
11840	IHDWYS	AKQGZZRCGV	9125007989 Dell Way	\N	YPPSTDC	\N	0	Canada	2	AKQGZZRCGV@dell.com	9125007989	4	9592024114914240	2010/01	user11840	password	79	40000	F
11841	DLGBDG	LUNLTEOAAN	9739373940 Dell Way	\N	QPGKTIP	\N	0	Japan	2	LUNLTEOAAN@dell.com	9739373940	3	2091152466833591	2012/05	user11841	password	50	40000	F
11842	XPOAVZ	VJLPNZQNMG	7875203542 Dell Way	\N	DSRWAGN	\N	0	Australia	2	VJLPNZQNMG@dell.com	7875203542	4	9953810952603818	2008/01	user11842	password	42	80000	M
11843	YEATEV	CPLQOBEBHI	3867189944 Dell Way	\N	UYEVERV	\N	0	UK	2	CPLQOBEBHI@dell.com	3867189944	5	1765071832574904	2009/03	user11843	password	70	40000	F
11844	XJWBEZ	QPPFRUHYCB	6149629510 Dell Way	\N	XGXCYTA	\N	0	Chile	2	QPPFRUHYCB@dell.com	6149629510	1	7007581295911223	2011/11	user11844	password	19	100000	M
11845	KSUPRK	FHQWBYUDAS	9501111126 Dell Way	\N	KXUJQVQ	\N	0	Chile	2	FHQWBYUDAS@dell.com	9501111126	2	9681702541187408	2011/05	user11845	password	76	60000	M
11846	NHHESM	LIINGDQHWB	4456290588 Dell Way	\N	EQLVMBB	\N	0	France	2	LIINGDQHWB@dell.com	4456290588	1	2789643099997192	2011/10	user11846	password	69	60000	F
11847	ZTMRGY	APLGTCNPES	6530747875 Dell Way	\N	GPOSRPD	\N	0	Australia	2	APLGTCNPES@dell.com	6530747875	2	8034123701974750	2010/01	user11847	password	34	80000	F
11848	ZGRFFR	URYNUMCYFJ	5783233774 Dell Way	\N	OTBFIFH	\N	0	UK	2	URYNUMCYFJ@dell.com	5783233774	1	4520850710105151	2010/04	user11848	password	29	60000	F
11849	KGMQXG	HVUBIXANGO	2209588993 Dell Way	\N	GIUPNBO	\N	0	Australia	2	HVUBIXANGO@dell.com	2209588993	5	6540018033701927	2010/02	user11849	password	31	80000	M
11850	KEDILK	EFMMDMAKAH	4454989989 Dell Way	\N	SVWFWLH	\N	0	Australia	2	EFMMDMAKAH@dell.com	4454989989	5	4930468999780715	2010/01	user11850	password	27	100000	F
11851	HDVSOZ	YAMBMNLNUE	6199827869 Dell Way	\N	IQKFCRF	\N	0	France	2	YAMBMNLNUE@dell.com	6199827869	4	9573481677100064	2011/10	user11851	password	87	20000	F
11852	BZUPZT	QMUCZGQTLY	1046121149 Dell Way	\N	KVDMNJY	\N	0	Australia	2	QMUCZGQTLY@dell.com	1046121149	5	7684956661891193	2011/11	user11852	password	83	100000	M
11853	WQNWJE	IEGHLXAWWK	7522165823 Dell Way	\N	RZXEJVH	\N	0	China	2	IEGHLXAWWK@dell.com	7522165823	1	2285507079679519	2010/12	user11853	password	89	60000	M
11854	PAQZEZ	DLGOIHKESC	6283704304 Dell Way	\N	EPHNKOX	\N	0	Canada	2	DLGOIHKESC@dell.com	6283704304	1	7345281146466733	2010/01	user11854	password	31	40000	M
11855	FYQJXT	VEIDLTIDVM	9739410909 Dell Way	\N	SDADSYH	\N	0	Chile	2	VEIDLTIDVM@dell.com	9739410909	5	8185204036533833	2008/03	user11855	password	25	80000	F
11856	BGTZAO	DISPCATYMM	8747548644 Dell Way	\N	BNPULWB	\N	0	France	2	DISPCATYMM@dell.com	8747548644	5	4815956943202764	2008/12	user11856	password	22	60000	F
11857	IEZJSD	RKSUKLSXXT	5134389476 Dell Way	\N	LNNXKPI	\N	0	Chile	2	RKSUKLSXXT@dell.com	5134389476	4	3519702889025211	2010/10	user11857	password	68	60000	F
11858	VKMONE	ZGYJRQHPKS	7104400734 Dell Way	\N	CYQMNYT	\N	0	UK	2	ZGYJRQHPKS@dell.com	7104400734	1	4713404760230333	2010/09	user11858	password	79	80000	M
11859	GCCUHB	AGLSWSHHLK	6570037614 Dell Way	\N	FCWTAPT	\N	0	Russia	2	AGLSWSHHLK@dell.com	6570037614	1	2679541332647204	2009/01	user11859	password	77	100000	F
11860	YYBFAB	LMTIFBQRLW	5648011137 Dell Way	\N	TIPTYJL	\N	0	Germany	2	LMTIFBQRLW@dell.com	5648011137	4	8850367003120483	2010/06	user11860	password	71	80000	F
11861	SVPSXB	ERJJSAAEWT	6693765259 Dell Way	\N	NMNLVZZ	\N	0	China	2	ERJJSAAEWT@dell.com	6693765259	5	8736407946795226	2008/08	user11861	password	64	60000	F
11862	MBAJCE	AMOTNPXJJK	7206254126 Dell Way	\N	VWVQWVZ	\N	0	France	2	AMOTNPXJJK@dell.com	7206254126	5	6262888300698251	2009/06	user11862	password	22	60000	M
11863	DPIGTI	TIBGXZPGJL	9404620413 Dell Way	\N	DFCAACM	\N	0	Russia	2	TIBGXZPGJL@dell.com	9404620413	1	1097553199157118	2010/02	user11863	password	60	40000	F
11864	ESNYAG	GCMEBCLKNP	2572446024 Dell Way	\N	QQPRSCJ	\N	0	Japan	2	GCMEBCLKNP@dell.com	2572446024	2	1669784739613533	2009/12	user11864	password	51	60000	F
11865	DCCEIJ	GVNHXZSLOI	7960569777 Dell Way	\N	CEZUGJL	\N	0	France	2	GVNHXZSLOI@dell.com	7960569777	3	7694585247430951	2011/12	user11865	password	41	100000	F
11866	KZHTIO	OWWLVOXKXZ	7614703765 Dell Way	\N	OXUVHFG	\N	0	Australia	2	OWWLVOXKXZ@dell.com	7614703765	5	8277440615464003	2011/04	user11866	password	69	100000	M
11867	SDLASA	XOLTDJDBIS	8158269888 Dell Way	\N	YCOFIUH	\N	0	Australia	2	XOLTDJDBIS@dell.com	8158269888	1	7993778949137778	2008/10	user11867	password	62	100000	F
11868	TINLIK	AUDDDHEMAD	7618623269 Dell Way	\N	POJYIQZ	\N	0	Canada	2	AUDDDHEMAD@dell.com	7618623269	4	3314583829604089	2010/05	user11868	password	25	20000	F
11869	KOPSZP	NDTQKYCLCS	4508083466 Dell Way	\N	ZLQICQL	\N	0	South Africa	2	NDTQKYCLCS@dell.com	4508083466	4	4221113001927734	2011/10	user11869	password	46	100000	F
11870	YNYXCL	BWCLVFWXXW	4008130405 Dell Way	\N	INEKEQG	\N	0	Germany	2	BWCLVFWXXW@dell.com	4008130405	3	3897562399040908	2008/12	user11870	password	35	40000	M
11871	TIWWUX	SWINCFKZBT	9933153957 Dell Way	\N	NGERWKG	\N	0	Canada	2	SWINCFKZBT@dell.com	9933153957	3	4151984336785972	2012/10	user11871	password	71	100000	M
11872	BTJWQC	SZQUFAUHUI	8113996433 Dell Way	\N	NYAKIGP	\N	0	China	2	SZQUFAUHUI@dell.com	8113996433	5	3693069740198553	2010/09	user11872	password	33	20000	M
11873	ZMPPPI	PFCVFXCAFQ	6397644753 Dell Way	\N	YFBGLQP	\N	0	Chile	2	PFCVFXCAFQ@dell.com	6397644753	5	8436721368227155	2009/02	user11873	password	86	20000	F
11874	KPRZXG	FACLYELEVJ	1905212090 Dell Way	\N	JWQVNFC	\N	0	Canada	2	FACLYELEVJ@dell.com	1905212090	5	4690583578776568	2008/11	user11874	password	49	40000	F
11875	BXGYEL	ZGWYLICHRL	3439931407 Dell Way	\N	EIHSNJV	\N	0	Japan	2	ZGWYLICHRL@dell.com	3439931407	2	8366911505814643	2008/09	user11875	password	22	40000	M
11876	ZQRECR	LZPXHREYDJ	2406870009 Dell Way	\N	GKBUUXK	\N	0	Australia	2	LZPXHREYDJ@dell.com	2406870009	2	2386082235723734	2012/04	user11876	password	56	60000	F
11877	DFLFXX	FMUMDZLGIR	2135221860 Dell Way	\N	RKMLIXM	\N	0	France	2	FMUMDZLGIR@dell.com	2135221860	4	3762424486223608	2010/02	user11877	password	80	80000	F
11878	CEOZBT	LVFPVQWDIN	1719383230 Dell Way	\N	OUYWRLI	\N	0	South Africa	2	LVFPVQWDIN@dell.com	1719383230	4	3195157232694328	2009/07	user11878	password	87	60000	M
11879	DCOEVA	AAPVRLZZZO	4707031819 Dell Way	\N	UYKMJTH	\N	0	France	2	AAPVRLZZZO@dell.com	4707031819	3	7227611752692611	2012/06	user11879	password	35	60000	M
11880	ICUECV	ESRVEQVDFP	8775055016 Dell Way	\N	BPBLJIW	\N	0	Russia	2	ESRVEQVDFP@dell.com	8775055016	3	7383778179995716	2009/10	user11880	password	34	100000	F
11881	HTHKOM	CGIGXEKCTL	3916943848 Dell Way	\N	SVWCDTW	\N	0	Australia	2	CGIGXEKCTL@dell.com	3916943848	3	4271131485234946	2008/10	user11881	password	41	40000	F
11882	BPNQCQ	WKWUPGWISO	1942351624 Dell Way	\N	DPRHINI	\N	0	Japan	2	WKWUPGWISO@dell.com	1942351624	4	8182598748244346	2012/12	user11882	password	24	20000	F
11883	RNSTDP	EAJTHGCAUF	5709454716 Dell Way	\N	PLNXZVP	\N	0	Australia	2	EAJTHGCAUF@dell.com	5709454716	2	9999347640667112	2010/06	user11883	password	19	60000	F
11884	OHXSXB	SGVAMXAHDP	5424555134 Dell Way	\N	TRNTNCV	\N	0	Australia	2	SGVAMXAHDP@dell.com	5424555134	5	5941655918490142	2012/11	user11884	password	28	20000	F
11885	LZCIBV	PWWCUWKXME	6448106106 Dell Way	\N	OAXBDTC	\N	0	Japan	2	PWWCUWKXME@dell.com	6448106106	4	6213785825297237	2010/10	user11885	password	66	100000	F
11886	RZOSVE	PSGJPRGBVV	6927648529 Dell Way	\N	CTXFNAW	\N	0	Canada	2	PSGJPRGBVV@dell.com	6927648529	3	6170098260510713	2010/02	user11886	password	51	80000	M
11887	LGLHKB	ZQKOIRQDMS	2862565976 Dell Way	\N	WKYJKUM	\N	0	Australia	2	ZQKOIRQDMS@dell.com	2862565976	1	5658700339496136	2009/07	user11887	password	32	20000	M
11888	LNGVOF	MYUUPKXCCU	7277003940 Dell Way	\N	NBEYVQZ	\N	0	Australia	2	MYUUPKXCCU@dell.com	7277003940	3	4003342364914715	2009/09	user11888	password	46	20000	F
11889	XKZMQL	KKGAUEDXYQ	1776126628 Dell Way	\N	YDPTTOU	\N	0	France	2	KKGAUEDXYQ@dell.com	1776126628	1	7022821108810604	2011/07	user11889	password	78	100000	F
11890	GXXWIH	GPIBTMYSDW	5999070924 Dell Way	\N	VSQPHLB	\N	0	China	2	GPIBTMYSDW@dell.com	5999070924	4	2410508903674781	2008/07	user11890	password	24	60000	M
11891	ZJQIRX	XAYQMWJPTE	5841824195 Dell Way	\N	IKTPVVZ	\N	0	China	2	XAYQMWJPTE@dell.com	5841824195	1	5026060720440000	2008/03	user11891	password	86	100000	F
11892	INNZLK	AJBMGKCZPL	1995362522 Dell Way	\N	JIAFEZP	\N	0	Japan	2	AJBMGKCZPL@dell.com	1995362522	1	8119872943498195	2009/12	user11892	password	67	60000	F
11893	FAHQKH	ZMUGWXFLJP	4807979022 Dell Way	\N	UJVZJKR	\N	0	France	2	ZMUGWXFLJP@dell.com	4807979022	3	8140506318304689	2009/02	user11893	password	39	80000	F
11894	HZYSGY	EBEBZKNIAI	4534633630 Dell Way	\N	SVHBFYO	\N	0	Japan	2	EBEBZKNIAI@dell.com	4534633630	2	1369808478280901	2010/08	user11894	password	70	100000	M
11895	RUQYTV	AYWAJJIJRA	9970064686 Dell Way	\N	FYCKXQB	\N	0	Chile	2	AYWAJJIJRA@dell.com	9970064686	1	8265242155175657	2011/10	user11895	password	65	60000	M
11896	MFMFAM	EWMNGVWXWB	7033096353 Dell Way	\N	WYMTPOB	\N	0	Japan	2	EWMNGVWXWB@dell.com	7033096353	5	3146079538390040	2010/07	user11896	password	76	20000	M
11897	ZMFAZJ	WMWCISAEUW	5962237099 Dell Way	\N	DHQSVSI	\N	0	France	2	WMWCISAEUW@dell.com	5962237099	3	1013246395159512	2008/05	user11897	password	19	20000	F
11898	NGJNPG	ZLIIEIMYFP	3111003050 Dell Way	\N	FWIBORN	\N	0	Canada	2	ZLIIEIMYFP@dell.com	3111003050	3	2554834643844515	2011/07	user11898	password	33	100000	F
11899	LJPAPP	MXXQGJOMZU	9036706597 Dell Way	\N	IHVXYJA	\N	0	Canada	2	MXXQGJOMZU@dell.com	9036706597	1	8154969778377564	2010/05	user11899	password	74	60000	M
11900	DDWSTI	QQZWAOJZIS	8003698332 Dell Way	\N	HDPGMPK	\N	0	China	2	QQZWAOJZIS@dell.com	8003698332	2	8582011383492500	2008/12	user11900	password	46	20000	F
11901	NWVGFL	XFIYTRXBKF	1709670352 Dell Way	\N	FZLRPWC	\N	0	China	2	XFIYTRXBKF@dell.com	1709670352	5	5848341275937856	2008/04	user11901	password	57	20000	M
11902	LACRLZ	WUYPMWRWBW	5916225316 Dell Way	\N	WMOLJQV	\N	0	France	2	WUYPMWRWBW@dell.com	5916225316	2	5577436530962587	2012/11	user11902	password	68	80000	F
11903	SUZETW	YSLLOCHPZE	8089347405 Dell Way	\N	CNPLDLX	\N	0	Japan	2	YSLLOCHPZE@dell.com	8089347405	3	5789412888232619	2011/02	user11903	password	33	20000	M
11904	ZAYTXX	LIIZLQPKUR	4937036258 Dell Way	\N	XJDBUAS	\N	0	Germany	2	LIIZLQPKUR@dell.com	4937036258	2	3593715659808368	2010/06	user11904	password	41	40000	F
11905	JHFGEQ	ONQADFKXXI	4393606546 Dell Way	\N	HAJCBCR	\N	0	Germany	2	ONQADFKXXI@dell.com	4393606546	5	1384536948986351	2012/04	user11905	password	45	40000	M
11906	RNWWEL	JUMMAXKXFR	4607489543 Dell Way	\N	YPTASLN	\N	0	Australia	2	JUMMAXKXFR@dell.com	4607489543	3	9557602672837676	2011/12	user11906	password	36	40000	M
11907	TFMYRV	SDITASQGKP	7380005246 Dell Way	\N	WEPOPDR	\N	0	Australia	2	SDITASQGKP@dell.com	7380005246	4	7207466640509666	2011/11	user11907	password	19	40000	M
11908	FSPXOH	AXAAPRHAGD	1057918284 Dell Way	\N	EWSUAJU	\N	0	Russia	2	AXAAPRHAGD@dell.com	1057918284	3	4440409975126386	2012/06	user11908	password	65	60000	M
11909	JDPYKQ	VLRLDYLKBQ	7114420202 Dell Way	\N	HUKHEFA	\N	0	Canada	2	VLRLDYLKBQ@dell.com	7114420202	3	1506374998483806	2008/01	user11909	password	61	100000	F
11910	SMJDDE	PUQSSCDUSK	2215780403 Dell Way	\N	ODSSISX	\N	0	Australia	2	PUQSSCDUSK@dell.com	2215780403	5	2732959922403097	2008/07	user11910	password	24	80000	F
11911	PZKSEA	MUSFWWZPGO	2220658155 Dell Way	\N	TYHCREC	\N	0	South Africa	2	MUSFWWZPGO@dell.com	2220658155	2	1113528645597398	2011/05	user11911	password	64	100000	M
11912	QJRUJD	PCIMYICFWV	3656419298 Dell Way	\N	EEXWIAR	\N	0	France	2	PCIMYICFWV@dell.com	3656419298	4	2478138314560056	2011/04	user11912	password	26	80000	M
11913	MHTWKJ	YTVXBYCYTH	5668863418 Dell Way	\N	CRDLRVX	\N	0	UK	2	YTVXBYCYTH@dell.com	5668863418	1	6614575741346926	2012/03	user11913	password	36	80000	M
11914	NOOYXM	SSKTQNSKUV	3374253747 Dell Way	\N	BYGSTER	\N	0	Chile	2	SSKTQNSKUV@dell.com	3374253747	2	2148541375529021	2010/07	user11914	password	85	20000	F
11915	MSAJFS	CPMSCFDXAE	8596171372 Dell Way	\N	VGXPLOW	\N	0	Russia	2	CPMSCFDXAE@dell.com	8596171372	1	2575647890102118	2009/12	user11915	password	42	60000	F
11916	AMTFFV	VROXXRVXWQ	2023924993 Dell Way	\N	ETGPHCH	\N	0	Canada	2	VROXXRVXWQ@dell.com	2023924993	3	5739846461918206	2008/10	user11916	password	89	60000	M
11917	LECRZX	INVGFQDBHH	7116210408 Dell Way	\N	VNXCQFG	\N	0	Russia	2	INVGFQDBHH@dell.com	7116210408	4	7983932161703707	2010/10	user11917	password	32	40000	F
11918	JLWJIF	XELCUPEBWZ	2201854215 Dell Way	\N	PTCFYJY	\N	0	Japan	2	XELCUPEBWZ@dell.com	2201854215	4	2225102718453854	2012/12	user11918	password	53	20000	F
11919	XZQGFO	KRRFGVGDVW	7387162511 Dell Way	\N	XYBWHZM	\N	0	France	2	KRRFGVGDVW@dell.com	7387162511	4	3803015977144241	2011/02	user11919	password	49	100000	F
11920	KOHQDS	IUXOQESMAP	6018717191 Dell Way	\N	KBLRBYC	\N	0	Russia	2	IUXOQESMAP@dell.com	6018717191	3	4594981598667801	2011/10	user11920	password	41	80000	F
11921	XZXARF	VPTLTLXTBH	5188290557 Dell Way	\N	VMZXKBR	\N	0	UK	2	VPTLTLXTBH@dell.com	5188290557	1	6777353059500456	2009/05	user11921	password	43	60000	F
11922	ILHAQC	PKOIWLCXTX	5724623471 Dell Way	\N	JSVUUMT	\N	0	Chile	2	PKOIWLCXTX@dell.com	5724623471	3	5902637082152069	2012/10	user11922	password	24	20000	F
11923	NMCDOR	OCAKOCHIAR	6865014959 Dell Way	\N	AVMVIGB	\N	0	South Africa	2	OCAKOCHIAR@dell.com	6865014959	4	7644513983279467	2010/09	user11923	password	84	60000	F
11924	JPJYGY	BHIQKQYLHZ	5319119904 Dell Way	\N	GUUPAWK	\N	0	Japan	2	BHIQKQYLHZ@dell.com	5319119904	1	1724753231275826	2008/01	user11924	password	59	60000	F
11925	DUKKSL	RBCBRANZAT	9176861837 Dell Way	\N	TUIURTL	\N	0	Canada	2	RBCBRANZAT@dell.com	9176861837	3	3929804093670100	2012/02	user11925	password	71	60000	F
11926	NVRGGI	HIKYJXYJRR	5115290253 Dell Way	\N	EAMVUXZ	\N	0	Japan	2	HIKYJXYJRR@dell.com	5115290253	2	7024960501585156	2010/01	user11926	password	24	100000	M
11927	XMUEVC	NGAWDYGVQK	5413010215 Dell Way	\N	WCFRAFJ	\N	0	France	2	NGAWDYGVQK@dell.com	5413010215	1	1395097568631172	2010/02	user11927	password	80	20000	F
11928	IWEDYR	JZNNYTJPEF	3368786232 Dell Way	\N	SKWSPGF	\N	0	Australia	2	JZNNYTJPEF@dell.com	3368786232	2	6434952792711557	2009/02	user11928	password	67	40000	F
11929	ONONFY	MSLLMUARAT	9187195923 Dell Way	\N	BXLQERS	\N	0	France	2	MSLLMUARAT@dell.com	9187195923	2	8121741391252727	2008/01	user11929	password	30	60000	M
11930	SABXYO	QJACEBTFUV	5721789692 Dell Way	\N	DFLHXES	\N	0	Russia	2	QJACEBTFUV@dell.com	5721789692	3	8284747665282340	2010/09	user11930	password	36	20000	F
11931	GEGETW	OTZTUTZOOD	6619558560 Dell Way	\N	UAKRFDL	\N	0	Russia	2	OTZTUTZOOD@dell.com	6619558560	2	3449284228030592	2009/07	user11931	password	45	80000	M
11932	OYYHVN	AUHUOHICKC	5355711400 Dell Way	\N	DVTIYFB	\N	0	Germany	2	AUHUOHICKC@dell.com	5355711400	2	8690235495567323	2012/09	user11932	password	55	80000	F
11933	LSNGGO	BOJPVRSGUV	6018223849 Dell Way	\N	BODZUFO	\N	0	Chile	2	BOJPVRSGUV@dell.com	6018223849	3	3440388271119446	2009/12	user11933	password	20	60000	F
11934	TBQAQR	PZHLRZRLUT	7504467074 Dell Way	\N	AYTVEIC	\N	0	Russia	2	PZHLRZRLUT@dell.com	7504467074	2	1064097176305949	2011/05	user11934	password	57	20000	F
11935	PRFFJU	EQFVQXHLRI	6182506813 Dell Way	\N	KKDOSFI	\N	0	France	2	EQFVQXHLRI@dell.com	6182506813	2	1913341513834893	2012/11	user11935	password	27	20000	F
11936	UIREDW	UJSLGAWYIG	5110798744 Dell Way	\N	JMVBRDN	\N	0	Chile	2	UJSLGAWYIG@dell.com	5110798744	4	3102877080440521	2009/10	user11936	password	44	80000	M
11937	SLSVHN	EAYLAVJJBS	9217102805 Dell Way	\N	VXUNBHU	\N	0	Germany	2	EAYLAVJJBS@dell.com	9217102805	1	8294984345324338	2011/05	user11937	password	59	40000	F
11938	AYXIMB	IKMJGVSINO	8778547692 Dell Way	\N	FIBGPWT	\N	0	Germany	2	IKMJGVSINO@dell.com	8778547692	3	2676470915786922	2009/02	user11938	password	48	40000	F
11939	JFMVGV	GTEMOXUCLA	6545526130 Dell Way	\N	KNHAJBN	\N	0	Chile	2	GTEMOXUCLA@dell.com	6545526130	4	5437032377347350	2011/02	user11939	password	77	100000	F
11940	AKIHFO	AKBOHVRTWC	4271999087 Dell Way	\N	HDCREQY	\N	0	Russia	2	AKBOHVRTWC@dell.com	4271999087	3	6009167584590614	2010/03	user11940	password	53	100000	F
11941	XHNCWO	NXDUTUOPWW	9048004413 Dell Way	\N	TZOXQMS	\N	0	UK	2	NXDUTUOPWW@dell.com	9048004413	2	5390483519993723	2008/09	user11941	password	52	40000	M
11942	UXTQMG	OPBIJQXGMR	6002538764 Dell Way	\N	GAPWNHW	\N	0	China	2	OPBIJQXGMR@dell.com	6002538764	2	5740704349707813	2009/10	user11942	password	84	100000	M
11943	VRGHYV	XZDHPBNCSU	8930553229 Dell Way	\N	DHRQONA	\N	0	Canada	2	XZDHPBNCSU@dell.com	8930553229	3	4889145496301353	2011/06	user11943	password	45	40000	F
11944	BPPZKM	ZNTPPHRHBU	1007016344 Dell Way	\N	OSKDGLG	\N	0	Canada	2	ZNTPPHRHBU@dell.com	1007016344	4	8653841548599304	2010/01	user11944	password	30	80000	F
11945	TJCEVC	SPRHWIOYDD	2977241886 Dell Way	\N	ROGXANB	\N	0	Australia	2	SPRHWIOYDD@dell.com	2977241886	5	5193404092919082	2009/02	user11945	password	34	60000	M
11946	PNAKPS	ZHZWPOUTRL	4122346668 Dell Way	\N	HYJHMLH	\N	0	Japan	2	ZHZWPOUTRL@dell.com	4122346668	4	9792920480482280	2010/12	user11946	password	46	40000	M
11947	XHZNAZ	VAVLOQEGCM	8439325399 Dell Way	\N	FMTRXBJ	\N	0	Chile	2	VAVLOQEGCM@dell.com	8439325399	2	7219283766113222	2012/09	user11947	password	88	40000	M
11948	GJEHJZ	HEKWVPCXBH	6699110487 Dell Way	\N	KVYHWHO	\N	0	Russia	2	HEKWVPCXBH@dell.com	6699110487	2	5739561146125198	2009/03	user11948	password	84	100000	F
11949	HEUQDB	VOXQDAOFIY	1776084505 Dell Way	\N	AGGXOVQ	\N	0	Chile	2	VOXQDAOFIY@dell.com	1776084505	1	6014962560031564	2009/01	user11949	password	57	100000	F
11950	SPZWQU	LOLPOAUWZV	5458901684 Dell Way	\N	DGSSBJY	\N	0	Canada	2	LOLPOAUWZV@dell.com	5458901684	3	5152068276423961	2010/01	user11950	password	37	100000	M
11951	WWPMRA	BCPQDKNCFQ	8062347401 Dell Way	\N	IYJJHHN	\N	0	Russia	2	BCPQDKNCFQ@dell.com	8062347401	5	3957825935911387	2012/04	user11951	password	34	60000	F
11952	CEPUEQ	XUGAETCKKL	3999619081 Dell Way	\N	IUVPCIJ	\N	0	South Africa	2	XUGAETCKKL@dell.com	3999619081	4	7219717672094703	2010/12	user11952	password	36	80000	F
11953	KHVPYS	KFSPZVZKGH	9631097525 Dell Way	\N	EBXGKGD	\N	0	Russia	2	KFSPZVZKGH@dell.com	9631097525	5	4056812817696482	2012/02	user11953	password	21	100000	F
11954	ITCHLM	MECMABWGJA	3543178759 Dell Way	\N	IGHTNLM	\N	0	France	2	MECMABWGJA@dell.com	3543178759	5	4173686454538256	2009/11	user11954	password	37	100000	F
11955	AYNLLA	QNMQPIXYJF	3732543424 Dell Way	\N	ERZSDME	\N	0	France	2	QNMQPIXYJF@dell.com	3732543424	3	7909547984600068	2008/10	user11955	password	64	60000	M
11956	PXGBXW	PJMESJDBPH	7133425383 Dell Way	\N	TOAWBEG	\N	0	China	2	PJMESJDBPH@dell.com	7133425383	1	5719353798311204	2010/08	user11956	password	85	40000	F
11957	VNHTJW	DWBVGEXVMR	8345395642 Dell Way	\N	KMNLQUU	\N	0	China	2	DWBVGEXVMR@dell.com	8345395642	2	8130623459350319	2010/03	user11957	password	22	80000	F
11958	OAUYXY	UZTADRWPIG	8148979093 Dell Way	\N	CWSSQMB	\N	0	France	2	UZTADRWPIG@dell.com	8148979093	5	9330675682518632	2008/11	user11958	password	66	20000	F
11959	RXKPVF	OPFSHCHPIK	9918999823 Dell Way	\N	LACBNEN	\N	0	China	2	OPFSHCHPIK@dell.com	9918999823	3	4100276707205922	2012/02	user11959	password	50	40000	M
11960	ITKEYZ	TERBGZQPJC	2156189526 Dell Way	\N	PMEDQRL	\N	0	Japan	2	TERBGZQPJC@dell.com	2156189526	4	5467686451505870	2009/03	user11960	password	79	20000	M
11961	PLTNKN	RBOYAFNJHC	5503934947 Dell Way	\N	WLGMDSC	\N	0	Chile	2	RBOYAFNJHC@dell.com	5503934947	3	5309242736548186	2011/06	user11961	password	55	40000	F
11962	YBNIOF	KDDKIQUPTQ	7864106007 Dell Way	\N	AACDSEK	\N	0	Chile	2	KDDKIQUPTQ@dell.com	7864106007	5	9464323536027224	2008/05	user11962	password	36	20000	F
11963	ISQXXA	ABLIRGYLWZ	4662495431 Dell Way	\N	LZDDENJ	\N	0	UK	2	ABLIRGYLWZ@dell.com	4662495431	2	2014180527999997	2011/07	user11963	password	39	20000	M
11964	ATTYUT	ZGCRMACJAO	3821810328 Dell Way	\N	IDRNRAL	\N	0	Australia	2	ZGCRMACJAO@dell.com	3821810328	3	8915744615718723	2012/11	user11964	password	90	80000	M
11965	TLUOET	UHLHINQIBZ	5511019968 Dell Way	\N	MTNEUYG	\N	0	Australia	2	UHLHINQIBZ@dell.com	5511019968	1	9431425203103572	2009/02	user11965	password	64	40000	M
11966	BZLGTG	NENWSEETER	2690888246 Dell Way	\N	NRVHPBJ	\N	0	Canada	2	NENWSEETER@dell.com	2690888246	2	5230831109452993	2009/12	user11966	password	67	20000	F
11967	RQHLWU	PKQIPVBTMP	5917624650 Dell Way	\N	LHWBJGE	\N	0	Germany	2	PKQIPVBTMP@dell.com	5917624650	4	8671113876625896	2010/04	user11967	password	20	60000	M
11968	RUKNPA	YFINBKHNZS	5691643515 Dell Way	\N	VWTECXS	\N	0	Japan	2	YFINBKHNZS@dell.com	5691643515	3	2218740975484252	2012/08	user11968	password	64	100000	F
11969	KFVZGT	FOHHYOUYGQ	2169662095 Dell Way	\N	UZVXXOO	\N	0	France	2	FOHHYOUYGQ@dell.com	2169662095	4	3153973987791687	2011/04	user11969	password	21	20000	M
11970	HWSNQY	BXFALAZSQT	9090532228 Dell Way	\N	SMRPAFA	\N	0	Canada	2	BXFALAZSQT@dell.com	9090532228	2	9056316562462600	2009/04	user11970	password	86	100000	M
11971	URBKQD	HVDTWCMMWE	1033295505 Dell Way	\N	YOTZTTD	\N	0	Japan	2	HVDTWCMMWE@dell.com	1033295505	1	8895441974047572	2009/12	user11971	password	78	100000	M
11972	NYDDBL	ZFFVIRIEVH	4406406534 Dell Way	\N	SPGMJJD	\N	0	China	2	ZFFVIRIEVH@dell.com	4406406534	1	6994064693339170	2009/11	user11972	password	56	20000	F
11973	LFNMRM	SWHAOPFKWY	6186255493 Dell Way	\N	ZCKJMOT	\N	0	South Africa	2	SWHAOPFKWY@dell.com	6186255493	2	2619636252056807	2010/12	user11973	password	35	80000	F
11974	LHWCTO	ZBPNQUXNSX	4646258352 Dell Way	\N	QDHCRAY	\N	0	Chile	2	ZBPNQUXNSX@dell.com	4646258352	1	7221492246724666	2009/05	user11974	password	53	80000	M
11975	UOYODX	PSLGNJTFGJ	6121641028 Dell Way	\N	IOMAOLH	\N	0	UK	2	PSLGNJTFGJ@dell.com	6121641028	5	3513578785583377	2012/06	user11975	password	89	80000	F
11976	OSURQK	KBQXLKCSUL	7770921133 Dell Way	\N	GGMUSTT	\N	0	Chile	2	KBQXLKCSUL@dell.com	7770921133	1	2924695140216499	2009/12	user11976	password	90	60000	M
11977	SHFIRP	KIMVSPNNAT	3767014550 Dell Way	\N	UNOMHHT	\N	0	Australia	2	KIMVSPNNAT@dell.com	3767014550	5	3324702639132738	2009/12	user11977	password	71	100000	M
11978	AAZRQJ	ADFTSTGTNA	2969681330 Dell Way	\N	GBNOIGP	\N	0	Japan	2	ADFTSTGTNA@dell.com	2969681330	5	9578653512522580	2008/07	user11978	password	75	100000	M
11979	VUGLEH	OJAHCHAPIH	3141805300 Dell Way	\N	RVVACKR	\N	0	China	2	OJAHCHAPIH@dell.com	3141805300	4	5317979085259140	2012/05	user11979	password	39	40000	F
11980	CRRGYG	QZNSGNIOVA	3728015755 Dell Way	\N	KQAMARV	\N	0	Chile	2	QZNSGNIOVA@dell.com	3728015755	2	1695153969340026	2011/08	user11980	password	52	100000	M
11981	DPXBWN	AJGHXPVSPG	8564510053 Dell Way	\N	IPTJHOQ	\N	0	Germany	2	AJGHXPVSPG@dell.com	8564510053	4	3720266249962151	2010/03	user11981	password	35	20000	F
11982	VZJRNK	BURYJMRYTZ	7489303025 Dell Way	\N	OMJWAAL	\N	0	South Africa	2	BURYJMRYTZ@dell.com	7489303025	4	3572531484998763	2012/12	user11982	password	45	40000	M
11983	JONXYO	RQNACEZWEO	6395775739 Dell Way	\N	IOKIOWF	\N	0	Chile	2	RQNACEZWEO@dell.com	6395775739	3	2616607732139528	2010/11	user11983	password	46	60000	F
11984	YYDXMU	NAVQFUMJIV	8659486634 Dell Way	\N	YTEMPJT	\N	0	Canada	2	NAVQFUMJIV@dell.com	8659486634	5	7978085256181658	2011/04	user11984	password	31	100000	F
11985	CBFPWT	QRJVMWFVSD	4087949052 Dell Way	\N	OWQEFKJ	\N	0	Australia	2	QRJVMWFVSD@dell.com	4087949052	1	8003293829970063	2011/04	user11985	password	70	100000	F
11986	UEARXR	IHMVESQWVF	8751008480 Dell Way	\N	SMJXWTZ	\N	0	Chile	2	IHMVESQWVF@dell.com	8751008480	4	8947789142839611	2008/06	user11986	password	79	60000	F
11987	AQYXHH	FUDJMUFIZY	6464665092 Dell Way	\N	UJWQCVW	\N	0	UK	2	FUDJMUFIZY@dell.com	6464665092	4	2322131478693336	2008/08	user11987	password	72	40000	M
11988	JINRQS	LTCYNHGNGA	3482173889 Dell Way	\N	XCRZYNZ	\N	0	Germany	2	LTCYNHGNGA@dell.com	3482173889	1	6796238380018622	2012/11	user11988	password	20	60000	F
11989	JZXZRJ	TUHGCOTIPQ	7494295777 Dell Way	\N	KGQJUPX	\N	0	Australia	2	TUHGCOTIPQ@dell.com	7494295777	3	9400421544909478	2010/07	user11989	password	46	100000	M
11990	JTYBCR	VKXXZRFOHQ	5064444195 Dell Way	\N	UYAPOXR	\N	0	Chile	2	VKXXZRFOHQ@dell.com	5064444195	4	8605481273960323	2008/01	user11990	password	67	100000	F
11991	KXLNOG	YLEXDKLKAG	2277273636 Dell Way	\N	JAWXYND	\N	0	China	2	YLEXDKLKAG@dell.com	2277273636	5	4771531150676310	2008/08	user11991	password	46	60000	F
11992	HYPVEO	HJLKTXVUEE	2737831203 Dell Way	\N	VABTOFD	\N	0	Russia	2	HJLKTXVUEE@dell.com	2737831203	3	8630026612896473	2012/12	user11992	password	44	100000	F
11993	HOBMCI	VOTOLOJQSE	6575520359 Dell Way	\N	QUXFZBX	\N	0	Canada	2	VOTOLOJQSE@dell.com	6575520359	4	1259670970495790	2010/02	user11993	password	88	80000	F
11994	NWXPES	DYHPMRFFVW	7801997559 Dell Way	\N	ATBZUZD	\N	0	France	2	DYHPMRFFVW@dell.com	7801997559	1	9809923036955298	2012/02	user11994	password	74	40000	M
11995	QEGVXK	TFZGXFMSBM	8003091260 Dell Way	\N	LDLGDPQ	\N	0	South Africa	2	TFZGXFMSBM@dell.com	8003091260	4	7790224057622255	2012/05	user11995	password	21	60000	F
11996	GVVEFO	KFVHKHZLTK	9284315807 Dell Way	\N	OFQSUHO	\N	0	Germany	2	KFVHKHZLTK@dell.com	9284315807	2	5505071541760117	2009/05	user11996	password	23	40000	M
11997	XEUCSE	HOLSVLDPVS	3788021393 Dell Way	\N	UMKPUZE	\N	0	Russia	2	HOLSVLDPVS@dell.com	3788021393	4	1263169924728572	2011/09	user11997	password	44	40000	M
11998	NCTGGB	URTPCXEYPZ	4267552027 Dell Way	\N	LAOGASY	\N	0	China	2	URTPCXEYPZ@dell.com	4267552027	5	9950977852568032	2008/05	user11998	password	39	80000	M
11999	JMCQNX	HGNKDRJTRV	1242849593 Dell Way	\N	TFBTXAC	\N	0	Chile	2	HGNKDRJTRV@dell.com	1242849593	1	4343228894751519	2009/05	user11999	password	25	40000	M
12000	OIJCGR	JTCMLLGCHA	9405071803 Dell Way	\N	HJUFKWM	\N	0	France	2	JTCMLLGCHA@dell.com	9405071803	5	8202938215807081	2009/12	user12000	password	20	20000	M
12001	KKPQBY	JDLUPSWWSD	7087720097 Dell Way	\N	FMJQJVB	\N	0	Chile	2	JDLUPSWWSD@dell.com	7087720097	5	6277906919363887	2011/11	user12001	password	63	20000	F
12002	ATXBSG	FDAUVWROAX	4786111299 Dell Way	\N	AJNJFOR	\N	0	South Africa	2	FDAUVWROAX@dell.com	4786111299	2	5596012982539833	2009/11	user12002	password	65	60000	M
12003	KMZCTE	FTYBQQPRNQ	9478252406 Dell Way	\N	BAAGPRE	\N	0	Australia	2	FTYBQQPRNQ@dell.com	9478252406	4	3913185688201338	2012/04	user12003	password	84	80000	M
12004	KRUDWA	XVCNLRFYIH	4271000371 Dell Way	\N	YIOOASO	\N	0	UK	2	XVCNLRFYIH@dell.com	4271000371	5	8020059622824193	2011/10	user12004	password	54	40000	F
12005	EEIBFF	WHTHZZGHGF	2825096672 Dell Way	\N	PUTQMIP	\N	0	South Africa	2	WHTHZZGHGF@dell.com	2825096672	2	5775243951473386	2008/11	user12005	password	85	40000	F
12006	CNCITZ	PNHPMNWTTM	1591992505 Dell Way	\N	NMCAUSW	\N	0	Australia	2	PNHPMNWTTM@dell.com	1591992505	3	1093264803756028	2012/04	user12006	password	33	100000	F
12007	TCTNCJ	AJYNXVGQHU	1820185008 Dell Way	\N	DKVYCRY	\N	0	Canada	2	AJYNXVGQHU@dell.com	1820185008	5	1984938951209187	2010/02	user12007	password	25	100000	M
12008	FPKHYK	RXYOSFFAAI	2046488104 Dell Way	\N	LVGONES	\N	0	Japan	2	RXYOSFFAAI@dell.com	2046488104	5	1150172737892717	2009/12	user12008	password	81	20000	F
12009	MOLKZC	IYQBDVBDEN	6230972146 Dell Way	\N	ZKBMOTB	\N	0	Japan	2	IYQBDVBDEN@dell.com	6230972146	1	9585532154887916	2010/12	user12009	password	27	80000	F
12010	SBVREE	QVFTRHXVUW	5470063228 Dell Way	\N	FVIUPKL	\N	0	Canada	2	QVFTRHXVUW@dell.com	5470063228	3	7119469263590873	2010/07	user12010	password	41	100000	F
12011	KSXOWN	JCHAKEVEAB	7120146617 Dell Way	\N	AJVPTHU	\N	0	Chile	2	JCHAKEVEAB@dell.com	7120146617	3	7439801760483534	2009/10	user12011	password	60	60000	F
12012	HJTEWC	HEDRIYWJAW	7443580163 Dell Way	\N	TVMNCGT	\N	0	Russia	2	HEDRIYWJAW@dell.com	7443580163	3	9827360496856272	2010/01	user12012	password	48	80000	F
12013	UKNQNU	VQMDPINPEG	1055815017 Dell Way	\N	KRTNXNH	\N	0	Japan	2	VQMDPINPEG@dell.com	1055815017	2	2237733990885317	2008/09	user12013	password	77	60000	F
12014	FZCTTX	JGBZOPOTVZ	1006678348 Dell Way	\N	KPMIDTZ	\N	0	Canada	2	JGBZOPOTVZ@dell.com	1006678348	1	2813606060110032	2011/12	user12014	password	64	20000	F
12015	PFXJCG	PEFETUXPTI	7635330921 Dell Way	\N	EGQHZQL	\N	0	UK	2	PEFETUXPTI@dell.com	7635330921	4	7003819707315416	2011/04	user12015	password	74	100000	M
12016	ZSFCYV	GEZAZXPSFT	2184447986 Dell Way	\N	ZWBZMMZ	\N	0	Chile	2	GEZAZXPSFT@dell.com	2184447986	4	8955192102584989	2009/05	user12016	password	68	40000	F
12017	KMMJIT	NHTMEIFKCE	7719138092 Dell Way	\N	GEESRDY	\N	0	Russia	2	NHTMEIFKCE@dell.com	7719138092	5	2708517970051616	2008/07	user12017	password	50	60000	M
12018	YBHGUU	NOHSWNCZSI	8646719956 Dell Way	\N	DWBUZAP	\N	0	Russia	2	NOHSWNCZSI@dell.com	8646719956	4	8812123354524375	2009/03	user12018	password	48	40000	F
12019	MOKGJY	URRRETRWCU	9888349529 Dell Way	\N	SEPREFJ	\N	0	Australia	2	URRRETRWCU@dell.com	9888349529	2	4733849558979273	2009/09	user12019	password	70	40000	F
12020	HUKRTE	IKWMEOIGIB	4022008980 Dell Way	\N	LYSPECQ	\N	0	Canada	2	IKWMEOIGIB@dell.com	4022008980	1	4306835576426238	2008/10	user12020	password	73	20000	F
12021	ONTHSB	SPNWDWCMXN	8792288066 Dell Way	\N	LQDPSUT	\N	0	Australia	2	SPNWDWCMXN@dell.com	8792288066	1	1473427497316151	2011/11	user12021	password	31	80000	F
12022	SLSKNK	ABGDXJPVXB	5157547191 Dell Way	\N	LBQEWJF	\N	0	Russia	2	ABGDXJPVXB@dell.com	5157547191	2	4266592064406723	2009/06	user12022	password	23	80000	F
12023	NLPBVP	CCTZLJVJKH	9603515917 Dell Way	\N	KAMGJRZ	\N	0	South Africa	2	CCTZLJVJKH@dell.com	9603515917	2	2454006886575371	2010/05	user12023	password	83	60000	M
12024	IEZEUB	GNBSWXBGEL	9898631312 Dell Way	\N	HQSRIRN	\N	0	Chile	2	GNBSWXBGEL@dell.com	9898631312	4	7287149420939387	2009/07	user12024	password	38	40000	M
12025	MIBGKH	TLZQIBXNMF	1448694395 Dell Way	\N	EEWMWJU	\N	0	South Africa	2	TLZQIBXNMF@dell.com	1448694395	3	3137945701833814	2011/10	user12025	password	60	60000	F
12026	XOMHWG	TVWBXUPJZT	5350933057 Dell Way	\N	OWGKFAG	\N	0	Chile	2	TVWBXUPJZT@dell.com	5350933057	3	9022940917871892	2009/01	user12026	password	46	60000	M
12027	YYGUEZ	QABNVQXUKM	6793615896 Dell Way	\N	RQXXRDE	\N	0	Canada	2	QABNVQXUKM@dell.com	6793615896	1	4402327896095812	2011/06	user12027	password	79	80000	F
12028	TYEXYV	YAIURFPBSG	4102288217 Dell Way	\N	SPDJSHM	\N	0	China	2	YAIURFPBSG@dell.com	4102288217	5	1799280927516520	2011/09	user12028	password	75	20000	F
12029	TJKREI	SNCJTRKLYC	8566515759 Dell Way	\N	ABMSIZC	\N	0	Japan	2	SNCJTRKLYC@dell.com	8566515759	1	5270761385560036	2010/12	user12029	password	66	20000	M
12030	AKKFTC	SWLLOWWMZW	8966808825 Dell Way	\N	NLPWKSN	\N	0	Chile	2	SWLLOWWMZW@dell.com	8966808825	1	8247834400739522	2012/08	user12030	password	78	60000	M
12031	GZXZBP	VNBJJXVJUJ	7674835853 Dell Way	\N	UJFFBTM	\N	0	UK	2	VNBJJXVJUJ@dell.com	7674835853	2	8270104170311243	2010/02	user12031	password	45	20000	F
12032	JZIKPD	YQNINJRHSM	4903205971 Dell Way	\N	RYRTRER	\N	0	France	2	YQNINJRHSM@dell.com	4903205971	3	8306084508076311	2010/11	user12032	password	84	100000	F
12033	XEQMIO	DWWQFNYYAQ	5887389281 Dell Way	\N	WSJOWBY	\N	0	Chile	2	DWWQFNYYAQ@dell.com	5887389281	4	8385784831829370	2010/09	user12033	password	68	80000	M
12034	WGBFVE	CSVIGUGGKD	4497842088 Dell Way	\N	YTRUVQB	\N	0	China	2	CSVIGUGGKD@dell.com	4497842088	5	7913331743329764	2008/08	user12034	password	47	80000	F
12035	RRRMWU	FRCLLJRWNP	4219301308 Dell Way	\N	PEKKVMU	\N	0	Chile	2	FRCLLJRWNP@dell.com	4219301308	3	3360652504488826	2012/12	user12035	password	82	60000	M
12036	OCCKWH	CZTNIKJVAZ	7509535565 Dell Way	\N	AKKVWEB	\N	0	Chile	2	CZTNIKJVAZ@dell.com	7509535565	2	2584434274584055	2011/03	user12036	password	60	40000	M
12037	RKEORG	OKUWVDSVDT	9446119693 Dell Way	\N	GOPDSQJ	\N	0	France	2	OKUWVDSVDT@dell.com	9446119693	3	2052976380567997	2008/02	user12037	password	46	100000	M
12038	UBJMHY	XBVSFNOJGU	8074987256 Dell Way	\N	XWXQMGB	\N	0	France	2	XBVSFNOJGU@dell.com	8074987256	1	5933366082143039	2012/08	user12038	password	49	80000	F
12039	MCVUAS	VVLBJZKQTH	2570953223 Dell Way	\N	MRXYXZJ	\N	0	Russia	2	VVLBJZKQTH@dell.com	2570953223	5	6475137027911842	2011/05	user12039	password	41	20000	M
12040	KYPLRL	HCNQBXGVFT	1027142559 Dell Way	\N	MCSKCCC	\N	0	Chile	2	HCNQBXGVFT@dell.com	1027142559	4	1263393759261816	2009/01	user12040	password	29	20000	F
12041	CVXUGE	XTUYRBUWVH	5655674962 Dell Way	\N	ZNRBPUI	\N	0	Japan	2	XTUYRBUWVH@dell.com	5655674962	2	9668127902317792	2010/07	user12041	password	29	20000	M
12042	ZXKGBH	ZWGRYBNTIM	3295987081 Dell Way	\N	GZOWUXM	\N	0	China	2	ZWGRYBNTIM@dell.com	3295987081	3	8781418255530299	2011/08	user12042	password	82	40000	M
12043	UVUWCU	SJMQKZKSMR	4900463940 Dell Way	\N	SANMXZU	\N	0	Canada	2	SJMQKZKSMR@dell.com	4900463940	4	9533374899066986	2008/07	user12043	password	43	60000	F
12044	EKEHFX	QROBQYTDPM	4959237610 Dell Way	\N	EDZCDUG	\N	0	Germany	2	QROBQYTDPM@dell.com	4959237610	2	6433940594084561	2012/07	user12044	password	32	40000	M
12045	PNZUKP	MYRDXKGNWK	9568314866 Dell Way	\N	RWMUQTJ	\N	0	Australia	2	MYRDXKGNWK@dell.com	9568314866	5	1409057992976158	2010/03	user12045	password	44	40000	M
12046	WFPGVB	FMEDWLQTWH	5139395668 Dell Way	\N	PICFCMH	\N	0	Australia	2	FMEDWLQTWH@dell.com	5139395668	2	5915187029168010	2011/09	user12046	password	73	60000	M
12047	YAVTBB	FGECRVWNDM	3729790581 Dell Way	\N	WFSYSZZ	\N	0	Canada	2	FGECRVWNDM@dell.com	3729790581	3	8232690460048617	2012/04	user12047	password	34	60000	F
12048	FJAHKG	NPJFKFSNSP	1864799494 Dell Way	\N	TKOLJOQ	\N	0	Japan	2	NPJFKFSNSP@dell.com	1864799494	3	7018717722967268	2010/08	user12048	password	33	80000	M
12049	PREAYS	PIXANQOGGH	8117064737 Dell Way	\N	QUTAIJR	\N	0	France	2	PIXANQOGGH@dell.com	8117064737	2	8516082182992251	2010/07	user12049	password	54	40000	F
12050	EMEDEU	LCUZTIFZQV	8895889190 Dell Way	\N	TJWCTNN	\N	0	Germany	2	LCUZTIFZQV@dell.com	8895889190	2	9679974741768092	2010/11	user12050	password	38	80000	F
12051	TUEYOP	BIPUQUTHQN	5309695677 Dell Way	\N	QMPJADX	\N	0	UK	2	BIPUQUTHQN@dell.com	5309695677	5	4102569492999464	2009/02	user12051	password	87	40000	M
12052	SOWGEX	PTRGOLNEYD	3550569402 Dell Way	\N	RNNSRKP	\N	0	Canada	2	PTRGOLNEYD@dell.com	3550569402	5	5231863894034177	2010/11	user12052	password	80	40000	M
12053	KFWOCM	IUSWGFBEJS	9850508740 Dell Way	\N	SWLJHAN	\N	0	Germany	2	IUSWGFBEJS@dell.com	9850508740	5	1137441502884030	2012/10	user12053	password	43	60000	F
12054	OJURVC	MOYSTZXDSQ	5488269019 Dell Way	\N	ADAHENX	\N	0	Canada	2	MOYSTZXDSQ@dell.com	5488269019	5	1369870680384337	2009/04	user12054	password	57	60000	M
12055	XJMTMY	HKRBKPEDFE	3482686799 Dell Way	\N	HFMLSJP	\N	0	Chile	2	HKRBKPEDFE@dell.com	3482686799	4	5988293297123164	2010/03	user12055	password	26	40000	F
12056	MVWYUD	JMEUBIXGNE	9224762088 Dell Way	\N	MZQFIGK	\N	0	Japan	2	JMEUBIXGNE@dell.com	9224762088	5	2381825779564678	2008/02	user12056	password	55	40000	M
12057	JBNEFW	QJQRSOYFTK	9985031232 Dell Way	\N	EJPNQAD	\N	0	Germany	2	QJQRSOYFTK@dell.com	9985031232	2	6888317102566362	2008/10	user12057	password	81	80000	F
12058	YEIDAY	MRQFFPKYAP	5961265468 Dell Way	\N	IQDYQGM	\N	0	Japan	2	MRQFFPKYAP@dell.com	5961265468	1	7580987576860935	2009/01	user12058	password	45	60000	M
12059	NVBOUO	FKTKAEIATR	3054156744 Dell Way	\N	QXPHDCY	\N	0	Japan	2	FKTKAEIATR@dell.com	3054156744	4	1451581424567848	2009/01	user12059	password	59	20000	M
12060	KFDETJ	PNTPRCQLTG	2327065045 Dell Way	\N	IJOMLME	\N	0	Japan	2	PNTPRCQLTG@dell.com	2327065045	2	9147035216446968	2008/10	user12060	password	23	80000	F
12061	HXIBGY	OANGDERXLZ	8550288939 Dell Way	\N	GZMRMQJ	\N	0	Japan	2	OANGDERXLZ@dell.com	8550288939	2	8267664525192232	2011/04	user12061	password	60	80000	M
12062	MCRTAG	UONXSEUEEB	4107712821 Dell Way	\N	DQTPHCF	\N	0	Canada	2	UONXSEUEEB@dell.com	4107712821	1	7545119443442673	2011/08	user12062	password	54	40000	F
12063	QZWRGR	FTOYYJCDKG	2047254830 Dell Way	\N	UDWBGCE	\N	0	Germany	2	FTOYYJCDKG@dell.com	2047254830	5	3362541089765728	2011/05	user12063	password	59	100000	F
12064	OSRVJX	OYVNIYQTFK	5583642529 Dell Way	\N	XBLDEQS	\N	0	Chile	2	OYVNIYQTFK@dell.com	5583642529	5	1064789974130690	2012/07	user12064	password	79	100000	F
12065	OPXYMM	WIAEHQXMBU	6527181433 Dell Way	\N	ONYSDQZ	\N	0	Japan	2	WIAEHQXMBU@dell.com	6527181433	1	5918713538907469	2008/11	user12065	password	51	40000	F
12066	AEINRF	VRKCIIOKDD	8592696989 Dell Way	\N	XBVASVR	\N	0	China	2	VRKCIIOKDD@dell.com	8592696989	2	5234502353705466	2011/09	user12066	password	71	20000	M
12067	XLFPRA	HBDPKRZNVX	8405738941 Dell Way	\N	ORXHMPP	\N	0	China	2	HBDPKRZNVX@dell.com	8405738941	1	1341994909569621	2010/10	user12067	password	28	40000	M
12068	PLHGMO	IPESHDGCAV	7609469908 Dell Way	\N	UYCGORP	\N	0	China	2	IPESHDGCAV@dell.com	7609469908	4	8889713823329658	2010/10	user12068	password	25	40000	F
12069	ONRBBZ	QFSYJYBKTV	4199978787 Dell Way	\N	JVCXNSG	\N	0	Chile	2	QFSYJYBKTV@dell.com	4199978787	1	7973043495323510	2008/03	user12069	password	18	60000	M
12070	NFVPFM	VXLFWMPPIY	3265992608 Dell Way	\N	LKVZCCF	\N	0	France	2	VXLFWMPPIY@dell.com	3265992608	5	6577933061402292	2010/12	user12070	password	30	40000	M
12071	JDCOQX	MBCIOSYWQK	6259418461 Dell Way	\N	GMJJPPW	\N	0	South Africa	2	MBCIOSYWQK@dell.com	6259418461	3	4169022759422660	2010/08	user12071	password	65	20000	F
12072	UFOKDB	MGJAYIXPSE	8680804308 Dell Way	\N	CCNRRJO	\N	0	Chile	2	MGJAYIXPSE@dell.com	8680804308	5	8532349583692850	2010/07	user12072	password	85	60000	F
12073	DBTGCG	MMGLUDAMHC	3149149632 Dell Way	\N	OVUGFIN	\N	0	Australia	2	MMGLUDAMHC@dell.com	3149149632	2	6057491817045957	2011/04	user12073	password	21	20000	F
12074	CWQFCD	RJOLNPYVRN	6595934288 Dell Way	\N	RMUWVHY	\N	0	Australia	2	RJOLNPYVRN@dell.com	6595934288	3	8714409847278149	2012/07	user12074	password	89	40000	M
12075	WYWZBO	JQAWFZRXMJ	7302829665 Dell Way	\N	KHFFOEH	\N	0	Canada	2	JQAWFZRXMJ@dell.com	7302829665	1	1622253971640020	2009/02	user12075	password	44	100000	M
12076	IVZKKI	AKEGJWDWFN	2804271067 Dell Way	\N	DLTSQBW	\N	0	China	2	AKEGJWDWFN@dell.com	2804271067	5	6402988203801215	2009/04	user12076	password	57	40000	M
12077	JHZTPA	EUGORJKWXO	1665877067 Dell Way	\N	IRGYSDH	\N	0	UK	2	EUGORJKWXO@dell.com	1665877067	5	3194699740037322	2009/06	user12077	password	59	100000	M
12078	WZPMAT	GGIXQTUOHD	3358638798 Dell Way	\N	FOCYSJV	\N	0	Russia	2	GGIXQTUOHD@dell.com	3358638798	1	2309834795072675	2011/08	user12078	password	28	60000	M
12079	DCZDWG	KEEAXZPFCU	6787815925 Dell Way	\N	TETLOOF	\N	0	South Africa	2	KEEAXZPFCU@dell.com	6787815925	2	5687687303405256	2009/06	user12079	password	20	100000	M
12080	DUTZBE	DFFBFUGHPZ	1184107765 Dell Way	\N	MILBXRW	\N	0	Germany	2	DFFBFUGHPZ@dell.com	1184107765	2	8430096831638367	2010/06	user12080	password	64	20000	M
12081	LXOMBR	SGTXBZFQZS	1149391242 Dell Way	\N	ZLTWCQK	\N	0	Canada	2	SGTXBZFQZS@dell.com	1149391242	2	6650835695210845	2010/11	user12081	password	74	20000	F
12082	ROTTGM	AZJBYPSYHR	2391068696 Dell Way	\N	JAOLQYO	\N	0	Japan	2	AZJBYPSYHR@dell.com	2391068696	1	1960689560510218	2008/12	user12082	password	25	40000	M
12083	QBKWNK	WXMVMETTWD	3993222520 Dell Way	\N	UKOKIDC	\N	0	Germany	2	WXMVMETTWD@dell.com	3993222520	1	5568930164910853	2009/04	user12083	password	76	100000	M
12084	WIVJTR	HFNTKGMHJG	9570991468 Dell Way	\N	SYRACTO	\N	0	France	2	HFNTKGMHJG@dell.com	9570991468	1	7427335829474033	2009/11	user12084	password	66	20000	M
12085	AABTSI	ZFCKMPRVVJ	9963605177 Dell Way	\N	UNKWHYH	\N	0	Chile	2	ZFCKMPRVVJ@dell.com	9963605177	5	5445615555159748	2012/08	user12085	password	68	60000	M
12086	SPKLYK	QBUCQMYMVS	8598164299 Dell Way	\N	ZGOHFWN	\N	0	Canada	2	QBUCQMYMVS@dell.com	8598164299	1	1338471798691898	2010/09	user12086	password	60	20000	F
12087	EOWDYM	ETPUFNHBGG	2034793375 Dell Way	\N	HVONRCS	\N	0	Germany	2	ETPUFNHBGG@dell.com	2034793375	4	1134220991283655	2012/04	user12087	password	30	40000	M
12088	SCQRPV	KFQQSXRZEZ	9324443046 Dell Way	\N	USMMVEZ	\N	0	UK	2	KFQQSXRZEZ@dell.com	9324443046	1	7805808823555709	2009/03	user12088	password	19	80000	M
12089	DKOTFZ	YWPRTHQYHL	9035136486 Dell Way	\N	QTXLYXK	\N	0	South Africa	2	YWPRTHQYHL@dell.com	9035136486	1	1982702667824924	2008/02	user12089	password	80	100000	F
12090	GNALNY	HDPBKGZRRQ	6645677325 Dell Way	\N	LOCJLMG	\N	0	China	2	HDPBKGZRRQ@dell.com	6645677325	2	4718083106912673	2011/03	user12090	password	44	20000	F
12091	XCXKBF	NRHXXGPOXA	1305799643 Dell Way	\N	DAKPMRY	\N	0	Canada	2	NRHXXGPOXA@dell.com	1305799643	2	9140524221118540	2009/09	user12091	password	89	80000	M
12092	BPACVN	UCLRJBGGCK	3852425179 Dell Way	\N	HNZTEYW	\N	0	Chile	2	UCLRJBGGCK@dell.com	3852425179	4	5198053635191173	2008/10	user12092	password	29	80000	M
12093	TSYPGS	RRKATQHVAO	9920435668 Dell Way	\N	JAINZFT	\N	0	Chile	2	RRKATQHVAO@dell.com	9920435668	2	4144472542218864	2011/05	user12093	password	19	60000	F
12094	SNTYGK	QQLJHSFIHO	1636624857 Dell Way	\N	JPCIVWQ	\N	0	South Africa	2	QQLJHSFIHO@dell.com	1636624857	5	6079106478020549	2010/01	user12094	password	28	80000	M
12095	RIRYTI	PESWXXEFMN	5336904156 Dell Way	\N	VPWQLNL	\N	0	Germany	2	PESWXXEFMN@dell.com	5336904156	1	9599286053329708	2010/02	user12095	password	58	40000	M
12096	XXUQFJ	VYFSVKYIYT	8338429031 Dell Way	\N	XUJIHVV	\N	0	Russia	2	VYFSVKYIYT@dell.com	8338429031	4	3491128700319678	2012/05	user12096	password	54	100000	F
12097	KPXPYS	ODLKNJSMCQ	6365689673 Dell Way	\N	HMZPHUJ	\N	0	Australia	2	ODLKNJSMCQ@dell.com	6365689673	4	1560437921900302	2012/02	user12097	password	81	40000	M
12098	LCDJVR	NGCBQUNSKU	4600447584 Dell Way	\N	EJJLETO	\N	0	Russia	2	NGCBQUNSKU@dell.com	4600447584	4	7555567527655513	2010/06	user12098	password	86	20000	M
12099	AFIVXV	CZWSUKLFFQ	3213337425 Dell Way	\N	PPCTIQO	\N	0	Russia	2	CZWSUKLFFQ@dell.com	3213337425	2	3504779446870089	2011/03	user12099	password	43	80000	F
12100	PZCMVE	MSXHCIMHYB	6783706827 Dell Way	\N	XBVFRJZ	\N	0	UK	2	MSXHCIMHYB@dell.com	6783706827	2	6832912077195943	2012/08	user12100	password	40	20000	F
12101	HERCIE	UGLXPYFNZC	5865510032 Dell Way	\N	OVIGFHE	\N	0	South Africa	2	UGLXPYFNZC@dell.com	5865510032	5	7133521557785571	2008/02	user12101	password	73	40000	F
12102	YZNGDI	NPGCNLQNOF	4795571031 Dell Way	\N	IXLNEPJ	\N	0	Russia	2	NPGCNLQNOF@dell.com	4795571031	1	8787496023811401	2010/10	user12102	password	31	100000	M
12103	EMZIVN	XBPLNFYCLG	2652795266 Dell Way	\N	ZWUEMDW	\N	0	UK	2	XBPLNFYCLG@dell.com	2652795266	4	5056276513263583	2012/12	user12103	password	48	80000	F
12104	XSKTFI	VVUIASKLZK	2565400753 Dell Way	\N	IUOVXLS	\N	0	Canada	2	VVUIASKLZK@dell.com	2565400753	1	1772738788742572	2008/07	user12104	password	76	20000	M
12105	NQGSYB	NSKOLVALGI	1259644944 Dell Way	\N	FUDCFWF	\N	0	China	2	NSKOLVALGI@dell.com	1259644944	2	5331113389227540	2011/02	user12105	password	67	20000	M
12106	HJIGLV	ZWKLSKWYTB	7159514040 Dell Way	\N	SXEXUJH	\N	0	South Africa	2	ZWKLSKWYTB@dell.com	7159514040	4	4756824569310993	2011/06	user12106	password	56	40000	M
12107	XSAINA	FYLXJHWCIO	6117272531 Dell Way	\N	ANMUXUP	\N	0	Germany	2	FYLXJHWCIO@dell.com	6117272531	1	4222440779209137	2008/07	user12107	password	72	80000	F
12108	LVUZVZ	XGXGOTJXIJ	8016434445 Dell Way	\N	KUEHPTW	\N	0	Canada	2	XGXGOTJXIJ@dell.com	8016434445	2	2664970043580979	2009/12	user12108	password	89	80000	F
12109	UOKQOH	XLOLFXINHT	2283448928 Dell Way	\N	IMBXGXB	\N	0	Australia	2	XLOLFXINHT@dell.com	2283448928	2	4034881274681538	2008/03	user12109	password	25	60000	F
12110	RXQFFN	RTZXRHKZBT	9556853129 Dell Way	\N	LCQRASS	\N	0	Canada	2	RTZXRHKZBT@dell.com	9556853129	1	3341232045553625	2008/02	user12110	password	75	20000	M
12111	SVAXJS	RIPJQAJSTU	2859221881 Dell Way	\N	UKMUDEY	\N	0	Australia	2	RIPJQAJSTU@dell.com	2859221881	2	3215148101095110	2009/12	user12111	password	50	20000	M
12112	HFPRXG	ANQROZJIUD	1797148319 Dell Way	\N	TGYWLXY	\N	0	Japan	2	ANQROZJIUD@dell.com	1797148319	1	9830575589556248	2008/08	user12112	password	28	80000	M
12113	IJOGQO	TGFIFPQZTJ	3891922723 Dell Way	\N	GRFRODH	\N	0	Japan	2	TGFIFPQZTJ@dell.com	3891922723	2	7543530226219446	2012/06	user12113	password	53	100000	M
12114	VKZLZT	SFCXUSXNCD	4685272473 Dell Way	\N	EIVTMDK	\N	0	South Africa	2	SFCXUSXNCD@dell.com	4685272473	1	7650243584066630	2012/08	user12114	password	60	60000	F
12115	ZPXYJP	DLNYELLHOQ	9332443295 Dell Way	\N	PKKCNUX	\N	0	UK	2	DLNYELLHOQ@dell.com	9332443295	4	7833719777408988	2010/03	user12115	password	43	100000	F
12116	YXDHNH	TAFXLREAHU	4240740074 Dell Way	\N	KSWYMTW	\N	0	France	2	TAFXLREAHU@dell.com	4240740074	4	9637858356349172	2010/12	user12116	password	87	80000	M
12117	WWFJEY	KKVVBAWJUH	7151520974 Dell Way	\N	BQFOJBZ	\N	0	Russia	2	KKVVBAWJUH@dell.com	7151520974	5	3530047272332013	2011/11	user12117	password	19	60000	M
12118	XTCBRN	LNJNNFWHNY	4365103813 Dell Way	\N	XSMGULZ	\N	0	France	2	LNJNNFWHNY@dell.com	4365103813	2	2009900958742946	2009/04	user12118	password	66	20000	F
12119	KCGCQS	PZFCFCJSAG	7946809332 Dell Way	\N	KNNEYNQ	\N	0	China	2	PZFCFCJSAG@dell.com	7946809332	4	6295329400803894	2008/06	user12119	password	61	40000	M
12120	SMXIFN	HLPMNZEOGP	2814177844 Dell Way	\N	BTUAHLI	\N	0	Australia	2	HLPMNZEOGP@dell.com	2814177844	5	1896245930809527	2011/07	user12120	password	43	60000	F
12121	VJOBWW	MMJZLONRDP	8929196350 Dell Way	\N	LXPSJYT	\N	0	Germany	2	MMJZLONRDP@dell.com	8929196350	5	2698675189167261	2010/03	user12121	password	65	80000	F
12122	AEBXAO	KKNVYBMBRX	2754234391 Dell Way	\N	ZHPIFJX	\N	0	Canada	2	KKNVYBMBRX@dell.com	2754234391	1	5532305045053363	2009/09	user12122	password	27	60000	M
12123	IMRJAB	TOXRQJSHHS	1422165047 Dell Way	\N	OXBUHYX	\N	0	France	2	TOXRQJSHHS@dell.com	1422165047	2	8594299500808121	2011/07	user12123	password	36	60000	M
12124	SGFTIY	HFPYPIGXAU	8924685185 Dell Way	\N	VCPCAMO	\N	0	Australia	2	HFPYPIGXAU@dell.com	8924685185	2	8842240416910500	2010/08	user12124	password	49	40000	F
12125	RLCAJK	FZJVHPSIKN	6127391244 Dell Way	\N	KZQKMEN	\N	0	China	2	FZJVHPSIKN@dell.com	6127391244	2	7836615892592818	2009/10	user12125	password	18	60000	F
12126	LRNVCS	ULOBAHJKVT	1601783239 Dell Way	\N	KLEWPRF	\N	0	Canada	2	ULOBAHJKVT@dell.com	1601783239	5	4502330308314413	2012/12	user12126	password	88	40000	F
12127	QWHTPB	FDDFLNQGHB	2365231069 Dell Way	\N	RLYHDEL	\N	0	Chile	2	FDDFLNQGHB@dell.com	2365231069	5	1853250782471150	2008/10	user12127	password	52	60000	F
12128	IWFYYK	CBQNOHTVJL	1003263896 Dell Way	\N	HHSLLEQ	\N	0	Germany	2	CBQNOHTVJL@dell.com	1003263896	4	7698815904092044	2012/03	user12128	password	42	40000	M
12129	FMNDXP	ENDTVXOEIW	7095861021 Dell Way	\N	LBHXFYM	\N	0	Chile	2	ENDTVXOEIW@dell.com	7095861021	2	1095586854964494	2012/07	user12129	password	38	60000	M
12130	TYYQOC	ESWAQKEYGQ	3389602374 Dell Way	\N	AONFMAK	\N	0	Canada	2	ESWAQKEYGQ@dell.com	3389602374	3	1417921319138258	2012/09	user12130	password	54	80000	F
12131	LOCARH	TNIJYMIFDI	4198392151 Dell Way	\N	TRNFSYJ	\N	0	UK	2	TNIJYMIFDI@dell.com	4198392151	3	8342928575817496	2008/12	user12131	password	50	60000	F
12132	AQKRXE	EFNDSWIWEC	1986450317 Dell Way	\N	OSHGRRF	\N	0	Australia	2	EFNDSWIWEC@dell.com	1986450317	1	1577299004420638	2008/06	user12132	password	59	60000	F
12133	EVECZJ	INMBJVYOXM	9915777496 Dell Way	\N	HFSYWYY	\N	0	UK	2	INMBJVYOXM@dell.com	9915777496	1	1182990466244518	2010/08	user12133	password	49	100000	M
12134	GDXGMF	UZHEUFSRSA	9257909728 Dell Way	\N	WLYTJXT	\N	0	China	2	UZHEUFSRSA@dell.com	9257909728	4	8665245756506921	2010/03	user12134	password	78	40000	F
12135	YESLKN	LSRFYJXQKU	1331083800 Dell Way	\N	BINLGHV	\N	0	Canada	2	LSRFYJXQKU@dell.com	1331083800	4	6934195357374848	2009/06	user12135	password	87	80000	F
12136	DKXNXI	GPOEYLUJFW	8122936671 Dell Way	\N	RTHXADB	\N	0	Australia	2	GPOEYLUJFW@dell.com	8122936671	4	3746721682138741	2009/09	user12136	password	18	80000	M
12137	LQIIYO	YNTXYNGEKX	6627686219 Dell Way	\N	YSVZVXA	\N	0	Japan	2	YNTXYNGEKX@dell.com	6627686219	2	9018434362486006	2009/05	user12137	password	63	20000	M
12138	GLCFAA	STXRHEVRBT	1859678419 Dell Way	\N	JXSFUTU	\N	0	France	2	STXRHEVRBT@dell.com	1859678419	4	7524302240926773	2010/04	user12138	password	78	40000	M
12139	HIUHJN	BHEJLABNTL	2162234957 Dell Way	\N	KMQFGLQ	\N	0	China	2	BHEJLABNTL@dell.com	2162234957	2	8049402511678637	2010/03	user12139	password	90	20000	F
12140	HVTRIU	YNEJNFWHQG	4967936693 Dell Way	\N	UGMARCJ	\N	0	South Africa	2	YNEJNFWHQG@dell.com	4967936693	1	3354356136173010	2011/02	user12140	password	39	20000	F
12141	DVCLQB	ZUKMZHUPOO	2017038329 Dell Way	\N	WAPNCYI	\N	0	Germany	2	ZUKMZHUPOO@dell.com	2017038329	4	2437913653440773	2009/11	user12141	password	34	80000	F
12142	BVMRWL	LGXLNRACGW	4161495835 Dell Way	\N	CVKEUTS	\N	0	South Africa	2	LGXLNRACGW@dell.com	4161495835	5	2323193126358092	2009/02	user12142	password	80	40000	F
12143	RSVNEH	UCSIUTKAQM	3632199793 Dell Way	\N	VARPUKM	\N	0	Canada	2	UCSIUTKAQM@dell.com	3632199793	4	4399944745004177	2010/06	user12143	password	64	60000	F
12144	JKSNSM	PLVJEGKUTF	9622557682 Dell Way	\N	VLVPVIT	\N	0	Canada	2	PLVJEGKUTF@dell.com	9622557682	1	5840846836101264	2010/10	user12144	password	26	80000	F
12145	NIQGVG	RRQWXAQQGM	9730829118 Dell Way	\N	CBCXJWB	\N	0	China	2	RRQWXAQQGM@dell.com	9730829118	3	8096849481575192	2011/09	user12145	password	48	100000	F
12146	TNMOTD	FKZDKQUQDW	4781985621 Dell Way	\N	SGUCCVK	\N	0	Australia	2	FKZDKQUQDW@dell.com	4781985621	2	8099493921734393	2008/08	user12146	password	64	40000	F
12147	DVYXZD	HZHSQBJTYB	7826314290 Dell Way	\N	ATDCOOE	\N	0	UK	2	HZHSQBJTYB@dell.com	7826314290	5	1986075168475508	2009/08	user12147	password	51	80000	M
12148	HRQGUY	GCRWEAQCCQ	8533221364 Dell Way	\N	WFTKUXK	\N	0	Germany	2	GCRWEAQCCQ@dell.com	8533221364	3	9240063671488316	2010/12	user12148	password	65	20000	F
12149	HVNCTT	FKQJLGMNXI	7126448115 Dell Way	\N	TQTNNEB	\N	0	China	2	FKQJLGMNXI@dell.com	7126448115	5	8095912376418711	2011/08	user12149	password	87	100000	M
12150	TLBNFG	YWPJCCWALQ	2875548265 Dell Way	\N	QEEEIFN	\N	0	Australia	2	YWPJCCWALQ@dell.com	2875548265	2	7166454901918770	2012/04	user12150	password	62	80000	F
12151	BVNHBM	DRVGTSGEIX	9036911358 Dell Way	\N	JMBSSPT	\N	0	UK	2	DRVGTSGEIX@dell.com	9036911358	3	7917547962162644	2008/01	user12151	password	57	20000	F
12152	JSKKEN	BAUVTAZBXJ	2975074741 Dell Way	\N	OYBHNUF	\N	0	France	2	BAUVTAZBXJ@dell.com	2975074741	5	6294657004531474	2009/07	user12152	password	74	40000	M
12153	MTHRGI	SBDLBDNZNC	6314074123 Dell Way	\N	YOJMJPX	\N	0	Germany	2	SBDLBDNZNC@dell.com	6314074123	3	8596912659704686	2008/04	user12153	password	32	20000	M
12154	YHLFQD	GUOHXBHLDF	1398478643 Dell Way	\N	ANRJCOZ	\N	0	Russia	2	GUOHXBHLDF@dell.com	1398478643	5	8440427409950645	2009/01	user12154	password	78	20000	M
12155	CMDTPJ	NDRLFYWIEW	1140244243 Dell Way	\N	WVGZJFR	\N	0	France	2	NDRLFYWIEW@dell.com	1140244243	3	7526854739990086	2008/05	user12155	password	74	100000	F
12156	GCEVMS	ZEDEDZNHWJ	5847656264 Dell Way	\N	CCJMHAX	\N	0	China	2	ZEDEDZNHWJ@dell.com	5847656264	4	3987704964820296	2012/05	user12156	password	39	40000	M
12157	KNMWFL	BJPEIDLFNN	5985184591 Dell Way	\N	HWAPXXX	\N	0	France	2	BJPEIDLFNN@dell.com	5985184591	2	3764416969381273	2012/07	user12157	password	64	60000	M
12158	DBUJMV	SCABFLGTZN	3140344158 Dell Way	\N	PZDMXAY	\N	0	France	2	SCABFLGTZN@dell.com	3140344158	2	4878605039324612	2011/11	user12158	password	19	80000	F
12159	CMJOHB	RIDXTJQTXG	9022261883 Dell Way	\N	TATRARD	\N	0	Chile	2	RIDXTJQTXG@dell.com	9022261883	3	1251090106088668	2011/08	user12159	password	69	80000	M
12160	EDGMFX	UIVOSMHPSA	4582878746 Dell Way	\N	QLRQCVX	\N	0	UK	2	UIVOSMHPSA@dell.com	4582878746	5	7776027590502054	2012/08	user12160	password	55	80000	M
12161	QXHWVB	ERQWDXMWYC	6414139315 Dell Way	\N	HQTKLRK	\N	0	South Africa	2	ERQWDXMWYC@dell.com	6414139315	1	8503287538886071	2009/09	user12161	password	54	20000	F
12162	KJEGLJ	XBFBYSXXUE	2207168622 Dell Way	\N	NNPYEZU	\N	0	Russia	2	XBFBYSXXUE@dell.com	2207168622	4	1233544310089200	2012/02	user12162	password	24	20000	M
12163	LHUWQS	YWTXPQUJVH	6645986194 Dell Way	\N	WKFBKAV	\N	0	Germany	2	YWTXPQUJVH@dell.com	6645986194	5	3980162324849516	2011/12	user12163	password	50	40000	F
12164	TBHKTF	GNCVDWFYDC	8637204451 Dell Way	\N	JJDTJZH	\N	0	UK	2	GNCVDWFYDC@dell.com	8637204451	4	7693342110607774	2012/01	user12164	password	19	40000	M
12165	CMFWRM	JUIMQNLUQV	5519571743 Dell Way	\N	EUPNTWN	\N	0	Japan	2	JUIMQNLUQV@dell.com	5519571743	2	4721962360665202	2010/04	user12165	password	62	40000	F
12166	CPFUCO	OKBFYNAOIE	5111718544 Dell Way	\N	JXRCUFS	\N	0	Chile	2	OKBFYNAOIE@dell.com	5111718544	1	8671903317794205	2011/09	user12166	password	36	20000	M
12167	WIQYXE	JZJHMJWUNF	2717858075 Dell Way	\N	RFILKBS	\N	0	South Africa	2	JZJHMJWUNF@dell.com	2717858075	3	6495372379664332	2012/10	user12167	password	71	80000	M
12168	BKQZOA	ZYILIEFWKX	7073142623 Dell Way	\N	CTJNUCJ	\N	0	UK	2	ZYILIEFWKX@dell.com	7073142623	5	9345036652870476	2010/09	user12168	password	69	40000	M
12169	CVURWT	QEEZJKWTIZ	8498327841 Dell Way	\N	MRMHUWH	\N	0	France	2	QEEZJKWTIZ@dell.com	8498327841	2	9690342393238098	2010/11	user12169	password	30	40000	F
12170	ADSWWJ	ABIJMFDUEQ	4629663881 Dell Way	\N	MRXGNFS	\N	0	China	2	ABIJMFDUEQ@dell.com	4629663881	4	8966530709527434	2009/11	user12170	password	34	40000	M
12171	IBSFKT	GTCTYGNDWA	7161266135 Dell Way	\N	UUHHZZQ	\N	0	China	2	GTCTYGNDWA@dell.com	7161266135	3	7283552830107511	2010/09	user12171	password	21	60000	F
12172	CDHMWO	GZHFGVICVD	6054813832 Dell Way	\N	WCKWCBG	\N	0	Russia	2	GZHFGVICVD@dell.com	6054813832	5	3986273721326143	2009/12	user12172	password	71	40000	F
12173	WROTGU	TOAZKIBFLY	9630825646 Dell Way	\N	IWULXAG	\N	0	France	2	TOAZKIBFLY@dell.com	9630825646	3	8015322125051171	2012/04	user12173	password	30	100000	F
12174	WOXCJR	RJQBRSGDQP	8634616911 Dell Way	\N	ALBYMHK	\N	0	France	2	RJQBRSGDQP@dell.com	8634616911	1	4313335486687720	2008/05	user12174	password	44	40000	F
12175	XGIHXZ	QOAIGHMXWM	1259080511 Dell Way	\N	IXLVFVG	\N	0	Australia	2	QOAIGHMXWM@dell.com	1259080511	4	2835689546074718	2009/12	user12175	password	56	60000	M
12176	UXERWV	FWDMDQJACS	4686688608 Dell Way	\N	YNNDJUF	\N	0	France	2	FWDMDQJACS@dell.com	4686688608	3	8094051698688418	2010/12	user12176	password	45	40000	M
12177	HMKDIP	ALBECLFEDD	9168752036 Dell Way	\N	SQHCLNN	\N	0	South Africa	2	ALBECLFEDD@dell.com	9168752036	2	3175379319116473	2012/09	user12177	password	58	60000	M
12178	BYCJOD	VQIXBNCFRV	7396841661 Dell Way	\N	WZXHMKD	\N	0	China	2	VQIXBNCFRV@dell.com	7396841661	2	2934711359441280	2009/11	user12178	password	74	40000	M
12179	SLIHPD	XXAZKCEBYA	8175917017 Dell Way	\N	AVIMGLW	\N	0	UK	2	XXAZKCEBYA@dell.com	8175917017	1	4175648419186473	2011/11	user12179	password	68	80000	M
12180	DZVSCT	PDTAGXCEYC	5874798753 Dell Way	\N	AGPGSMG	\N	0	France	2	PDTAGXCEYC@dell.com	5874798753	3	2855275895446539	2009/04	user12180	password	81	100000	F
12181	WUDZOT	CHUJFWNEZN	6496909939 Dell Way	\N	LOUDAAQ	\N	0	Germany	2	CHUJFWNEZN@dell.com	6496909939	5	9661686849780382	2012/09	user12181	password	84	40000	M
12182	SLNHFQ	OZZUWMYVAK	9872593361 Dell Way	\N	JVNKVDZ	\N	0	France	2	OZZUWMYVAK@dell.com	9872593361	5	4018715663813055	2011/11	user12182	password	65	40000	M
12183	CUWILK	IKFEXEZYOJ	7296380167 Dell Way	\N	TBTPFTA	\N	0	Chile	2	IKFEXEZYOJ@dell.com	7296380167	2	9173293774481864	2010/01	user12183	password	30	20000	F
12184	ZZLKKT	VPXSUWRIFK	4260644609 Dell Way	\N	KZZQTAV	\N	0	France	2	VPXSUWRIFK@dell.com	4260644609	4	1000479143112897	2009/11	user12184	password	28	60000	M
12185	DXHOQC	EOUYKMGQWQ	8686346824 Dell Way	\N	QWHJWCU	\N	0	Chile	2	EOUYKMGQWQ@dell.com	8686346824	4	6256116665899754	2011/12	user12185	password	22	80000	F
12186	ZXQQZU	EUSPGZGDPW	8198634301 Dell Way	\N	ZXFVZAB	\N	0	South Africa	2	EUSPGZGDPW@dell.com	8198634301	4	6546732202172280	2011/09	user12186	password	37	100000	M
12187	ELHEFM	ZYBGXIJNEJ	8877349732 Dell Way	\N	KJFKKGG	\N	0	Canada	2	ZYBGXIJNEJ@dell.com	8877349732	5	9330353243276478	2010/02	user12187	password	71	40000	F
12188	EOMKAM	ICSGKCUPLE	7437419342 Dell Way	\N	ZQPJWWO	\N	0	Russia	2	ICSGKCUPLE@dell.com	7437419342	3	3986266969703138	2012/03	user12188	password	60	20000	F
12189	DQUDCD	GVKRXEGJJF	6190013473 Dell Way	\N	AYOXUCQ	\N	0	Germany	2	GVKRXEGJJF@dell.com	6190013473	5	4244971448089928	2011/07	user12189	password	55	20000	M
12190	EYVGCC	CMTAQAJAGJ	9058673239 Dell Way	\N	YVGTXXG	\N	0	France	2	CMTAQAJAGJ@dell.com	9058673239	4	3497887196484953	2010/02	user12190	password	50	20000	F
12191	KZOMBR	YVRPWBPCKO	2844798185 Dell Way	\N	XRIVPOI	\N	0	France	2	YVRPWBPCKO@dell.com	2844798185	3	9521457345690580	2009/01	user12191	password	24	80000	F
12192	BFXDXW	YOMVPBXAQU	5649275199 Dell Way	\N	SYPHNYU	\N	0	Russia	2	YOMVPBXAQU@dell.com	5649275199	4	1541888791136443	2010/10	user12192	password	70	100000	M
12193	YXAVTY	KFTZHRAXMS	5695859227 Dell Way	\N	VCZJAUB	\N	0	Germany	2	KFTZHRAXMS@dell.com	5695859227	1	1640218959189951	2009/11	user12193	password	21	40000	M
12194	YFPSEZ	YYZFQZDCRZ	5637870216 Dell Way	\N	ERIELKR	\N	0	UK	2	YYZFQZDCRZ@dell.com	5637870216	4	3832957610487938	2009/10	user12194	password	57	20000	M
12195	TSLYSJ	XRPNQTPIST	4377482359 Dell Way	\N	ZBYLLQK	\N	0	UK	2	XRPNQTPIST@dell.com	4377482359	4	3830219213385135	2008/04	user12195	password	49	100000	F
12196	EKYWUW	OJJECZNVSM	1375072397 Dell Way	\N	XQXIGIH	\N	0	Japan	2	OJJECZNVSM@dell.com	1375072397	4	8454488056711853	2009/01	user12196	password	73	40000	F
12197	EGCYDQ	HMVKLIGEUD	4485614798 Dell Way	\N	VSMCBUT	\N	0	Australia	2	HMVKLIGEUD@dell.com	4485614798	3	4388751756865531	2010/04	user12197	password	68	80000	F
12198	YTKBJS	OECZMJEHMZ	4237907163 Dell Way	\N	ZYBASUC	\N	0	Canada	2	OECZMJEHMZ@dell.com	4237907163	3	5891020501963795	2011/03	user12198	password	32	20000	F
12199	YOEHGT	LJTXSXEFWE	8161200516 Dell Way	\N	DYFWTIY	\N	0	Canada	2	LJTXSXEFWE@dell.com	8161200516	3	8112299839500339	2012/09	user12199	password	87	20000	M
12200	NHXUAJ	ETHWQMBNQF	5818655462 Dell Way	\N	MVBFEAI	\N	0	UK	2	ETHWQMBNQF@dell.com	5818655462	1	9276850310619920	2009/01	user12200	password	18	100000	M
12201	HUJHDN	BKKSWMFNSS	4064903504 Dell Way	\N	JUXNUFM	\N	0	China	2	BKKSWMFNSS@dell.com	4064903504	2	6169544732198120	2010/05	user12201	password	50	100000	M
12202	FJZJXB	THTQTZDMRM	8873877407 Dell Way	\N	GOABUMJ	\N	0	Canada	2	THTQTZDMRM@dell.com	8873877407	5	5928721288219095	2009/05	user12202	password	57	100000	M
12203	XYZUZS	BTJVSMHJZO	9201284155 Dell Way	\N	YAPTMYX	\N	0	China	2	BTJVSMHJZO@dell.com	9201284155	3	6747074373066426	2009/12	user12203	password	61	100000	M
12204	NWQNPS	GYOZLWILKH	4054310765 Dell Way	\N	LZAYYXH	\N	0	South Africa	2	GYOZLWILKH@dell.com	4054310765	5	2346551327966153	2009/07	user12204	password	22	20000	F
12205	YVPONW	MCVYYDJIKU	9608515400 Dell Way	\N	ILSGIAC	\N	0	Japan	2	MCVYYDJIKU@dell.com	9608515400	2	9947696903254838	2010/04	user12205	password	30	60000	F
12206	ZDUNZH	QUFOYOXJJF	8504736916 Dell Way	\N	VCMECPV	\N	0	Australia	2	QUFOYOXJJF@dell.com	8504736916	5	5984903219621629	2008/01	user12206	password	25	60000	M
12207	GFNGMD	BRSZGQJPWE	1101618451 Dell Way	\N	SIIVYEX	\N	0	Russia	2	BRSZGQJPWE@dell.com	1101618451	3	9148246279917658	2008/07	user12207	password	40	20000	M
12208	NOAZRB	RKBXALNWQF	4323245989 Dell Way	\N	FYBDDYX	\N	0	Canada	2	RKBXALNWQF@dell.com	4323245989	5	2475186648312956	2012/02	user12208	password	30	80000	M
12209	STPKVG	UXEVIRSYXX	7874690209 Dell Way	\N	XYBBXYF	\N	0	Chile	2	UXEVIRSYXX@dell.com	7874690209	2	2538265209645033	2012/07	user12209	password	81	60000	F
12210	PCQLIL	IMHQEZPCXM	1875627861 Dell Way	\N	BYOYXTF	\N	0	Japan	2	IMHQEZPCXM@dell.com	1875627861	2	6015818499028683	2011/03	user12210	password	21	100000	M
12211	DNHLZP	YHFDGVFDIH	7953898759 Dell Way	\N	CWFAPKS	\N	0	Japan	2	YHFDGVFDIH@dell.com	7953898759	2	3932489374652505	2008/04	user12211	password	33	100000	F
12212	TDXTTW	AZZGUFKCMN	5696037330 Dell Way	\N	YROOCGG	\N	0	South Africa	2	AZZGUFKCMN@dell.com	5696037330	3	8913094379473478	2012/10	user12212	password	72	40000	M
12213	XEGQAH	PAOKFYMRML	8047052251 Dell Way	\N	JAZLHFI	\N	0	South Africa	2	PAOKFYMRML@dell.com	8047052251	1	6727544442284853	2010/12	user12213	password	84	20000	M
12214	CJMCQC	CEMIDYZPJJ	3973544925 Dell Way	\N	QJVXODS	\N	0	China	2	CEMIDYZPJJ@dell.com	3973544925	2	9269972405862064	2009/03	user12214	password	18	20000	F
12215	JPLZSO	DEWGDVWNFM	4813400927 Dell Way	\N	WAJLDCU	\N	0	France	2	DEWGDVWNFM@dell.com	4813400927	4	7700548271648587	2011/09	user12215	password	81	20000	F
12216	MLBEZF	JVLMRIZWUW	8575869455 Dell Way	\N	WEIZGDM	\N	0	Japan	2	JVLMRIZWUW@dell.com	8575869455	2	4225684450007975	2010/01	user12216	password	44	80000	M
12217	USTUXC	PJPHRPDMLZ	6976582809 Dell Way	\N	QTZXWLP	\N	0	Russia	2	PJPHRPDMLZ@dell.com	6976582809	5	3531898616813123	2011/04	user12217	password	85	40000	F
12218	QBXNDN	XTUOIXATXR	2345530831 Dell Way	\N	NXPJJFC	\N	0	Australia	2	XTUOIXATXR@dell.com	2345530831	2	7786033001262695	2010/04	user12218	password	22	60000	M
12219	CMMGZJ	ZTXIRYBOQP	4955912547 Dell Way	\N	LFZUKBV	\N	0	Germany	2	ZTXIRYBOQP@dell.com	4955912547	3	1347868905402720	2011/08	user12219	password	63	80000	M
12220	CDZCMZ	WKHNJJCZYO	7638524405 Dell Way	\N	FXJQZEF	\N	0	France	2	WKHNJJCZYO@dell.com	7638524405	2	2504511155653745	2009/11	user12220	password	79	20000	M
12221	ZCBMCY	XJLGTOFSCL	5444518112 Dell Way	\N	QLBPQGA	\N	0	China	2	XJLGTOFSCL@dell.com	5444518112	1	7579091276042164	2009/01	user12221	password	78	40000	F
12222	YKNAIK	KUQDJWWLHM	3890887659 Dell Way	\N	XJCOPDX	\N	0	Canada	2	KUQDJWWLHM@dell.com	3890887659	4	5151237575337291	2009/06	user12222	password	75	60000	F
12223	FYKNIU	IZYRWUDEHB	2210335900 Dell Way	\N	NJPDMMG	\N	0	South Africa	2	IZYRWUDEHB@dell.com	2210335900	4	2664392161648720	2011/06	user12223	password	61	20000	M
12224	NKFWFO	WEFTYJXGKK	5363244962 Dell Way	\N	PZOCMUY	\N	0	Japan	2	WEFTYJXGKK@dell.com	5363244962	1	3035359002184123	2012/09	user12224	password	34	80000	F
12225	QWCVLY	ZQRYAPFKAU	9560790080 Dell Way	\N	KOXXIVN	\N	0	South Africa	2	ZQRYAPFKAU@dell.com	9560790080	4	8218765273224563	2011/12	user12225	password	51	100000	M
12226	IZLUXL	LPKLEPWEKG	4644754538 Dell Way	\N	TIDBDRX	\N	0	Canada	2	LPKLEPWEKG@dell.com	4644754538	4	7806380071211607	2009/03	user12226	password	64	100000	M
12227	PKHNWS	CGDHWZMGGF	8920267675 Dell Way	\N	OKHSBEV	\N	0	France	2	CGDHWZMGGF@dell.com	8920267675	3	8566388773266227	2008/03	user12227	password	77	60000	M
12228	GVICOL	JRSFREMYJB	2362975210 Dell Way	\N	IQTKVOW	\N	0	Japan	2	JRSFREMYJB@dell.com	2362975210	4	7695210717618466	2009/07	user12228	password	40	20000	M
12229	DMWRXF	JQLBUYZEZI	3276452213 Dell Way	\N	UTSQHOI	\N	0	France	2	JQLBUYZEZI@dell.com	3276452213	1	8363919476512820	2011/05	user12229	password	89	60000	M
12230	MJFJPO	ZBQUZQYZYT	7578711844 Dell Way	\N	SQJAERM	\N	0	France	2	ZBQUZQYZYT@dell.com	7578711844	2	2848977259825915	2008/04	user12230	password	70	60000	M
12231	CUCSJC	UZWUQVTOOL	2865279315 Dell Way	\N	EXLJPXU	\N	0	China	2	UZWUQVTOOL@dell.com	2865279315	1	4725408081430942	2010/09	user12231	password	18	40000	M
12232	UIOEKI	EHCUCWIQHN	7127300421 Dell Way	\N	OTWERRM	\N	0	South Africa	2	EHCUCWIQHN@dell.com	7127300421	5	4146345470100641	2010/11	user12232	password	58	40000	M
12233	WUWHDB	OGVQCEHJRW	4408136425 Dell Way	\N	DOAUFMR	\N	0	South Africa	2	OGVQCEHJRW@dell.com	4408136425	1	3814855721313506	2009/07	user12233	password	59	100000	F
12234	JWSMXG	TSXVXEEOAI	7914065956 Dell Way	\N	CBCINTF	\N	0	UK	2	TSXVXEEOAI@dell.com	7914065956	3	2689661525189876	2009/02	user12234	password	30	80000	F
12235	AMZYTS	RQNOVSDWAF	3882130879 Dell Way	\N	XDOLWUI	\N	0	Japan	2	RQNOVSDWAF@dell.com	3882130879	3	9842240151949228	2010/09	user12235	password	73	100000	M
12236	GWRZOI	QCXLUAHVGF	5274414512 Dell Way	\N	YUQVPYL	\N	0	South Africa	2	QCXLUAHVGF@dell.com	5274414512	3	3893787323962897	2008/03	user12236	password	33	100000	F
12237	BOKQXA	SUMNUTIBYG	9672357926 Dell Way	\N	VPBKNNI	\N	0	Australia	2	SUMNUTIBYG@dell.com	9672357926	4	2641548139508813	2008/11	user12237	password	23	60000	M
12238	QAOOAH	INUDGCEFIA	4479100727 Dell Way	\N	VKLJYTJ	\N	0	South Africa	2	INUDGCEFIA@dell.com	4479100727	3	1491281650960445	2009/08	user12238	password	65	20000	F
12239	QSVRZD	ETHLWLRFMM	7834417013 Dell Way	\N	PXWOQFL	\N	0	Australia	2	ETHLWLRFMM@dell.com	7834417013	3	3388292031362653	2009/02	user12239	password	49	80000	M
12240	DMMDQR	XXDTIVYUIO	1282109228 Dell Way	\N	SECIJOJ	\N	0	Canada	2	XXDTIVYUIO@dell.com	1282109228	4	5686791801825166	2008/01	user12240	password	31	100000	F
12241	QLIGCG	EGZNBYHJNA	3995989880 Dell Way	\N	NPIXDSA	\N	0	Canada	2	EGZNBYHJNA@dell.com	3995989880	3	4157358716707677	2009/09	user12241	password	40	60000	F
12242	TYQWEV	CDIDCQMPQA	5342992360 Dell Way	\N	FYXJRYN	\N	0	UK	2	CDIDCQMPQA@dell.com	5342992360	5	4472402857150883	2009/03	user12242	password	89	60000	M
12243	XGUBBX	FJAHZNWPNB	8447024332 Dell Way	\N	OLKFJYF	\N	0	South Africa	2	FJAHZNWPNB@dell.com	8447024332	4	1572558740619570	2008/07	user12243	password	65	100000	F
12244	XTOYQT	HRBHFXWSZL	5275242669 Dell Way	\N	EKQNJWK	\N	0	Canada	2	HRBHFXWSZL@dell.com	5275242669	3	2913653826806694	2008/02	user12244	password	30	60000	M
12245	YCYPVG	GWNLUJEUVJ	7560439215 Dell Way	\N	FMXPIHU	\N	0	South Africa	2	GWNLUJEUVJ@dell.com	7560439215	5	8795598419848830	2012/03	user12245	password	47	100000	F
12246	MURIAY	FNKAXOVSYB	4806576290 Dell Way	\N	EVQNCLI	\N	0	South Africa	2	FNKAXOVSYB@dell.com	4806576290	1	6866903624031693	2010/08	user12246	password	53	80000	F
12247	GJKGIQ	USRRHMJFON	5817236238 Dell Way	\N	AEBCPJX	\N	0	Australia	2	USRRHMJFON@dell.com	5817236238	3	6603286583442242	2008/01	user12247	password	40	40000	F
12248	RQOZGI	SXAZKJEYXE	7954581448 Dell Way	\N	DYHTIFT	\N	0	South Africa	2	SXAZKJEYXE@dell.com	7954581448	2	9716280741617084	2012/09	user12248	password	30	20000	F
12249	USJBBB	YBBJLFHJKK	3725581881 Dell Way	\N	HREQXXM	\N	0	Japan	2	YBBJLFHJKK@dell.com	3725581881	3	5465044676791877	2008/08	user12249	password	64	40000	F
12250	ITLKVK	LXTWCAGNLN	1418130808 Dell Way	\N	FPDCNQT	\N	0	South Africa	2	LXTWCAGNLN@dell.com	1418130808	2	8534828971605749	2011/11	user12250	password	34	20000	F
12251	ZMQVWC	SPZVQFICSN	6876473171 Dell Way	\N	SWQGMKC	\N	0	Germany	2	SPZVQFICSN@dell.com	6876473171	5	2746539602987468	2010/02	user12251	password	35	80000	F
12252	SKYOMR	ELMUQVXJJP	8599598732 Dell Way	\N	GZWTJYH	\N	0	Australia	2	ELMUQVXJJP@dell.com	8599598732	3	6124543827958406	2012/09	user12252	password	43	20000	F
12253	UBAGTE	SGZJBWTLMA	6196717772 Dell Way	\N	KITUGBU	\N	0	Australia	2	SGZJBWTLMA@dell.com	6196717772	2	1651563056278973	2009/09	user12253	password	31	80000	F
12254	GTTAXM	GWVITOTFPE	1809900656 Dell Way	\N	NJYTLSW	\N	0	Australia	2	GWVITOTFPE@dell.com	1809900656	5	3842388567514718	2012/02	user12254	password	23	40000	F
12255	VAKTNR	QIAJXUPMYC	6799857132 Dell Way	\N	VWWGPSG	\N	0	Japan	2	QIAJXUPMYC@dell.com	6799857132	3	5524210724979640	2011/08	user12255	password	75	20000	F
12256	VNFIFW	RFFOZUBXXX	1064430390 Dell Way	\N	UUEKMLC	\N	0	Canada	2	RFFOZUBXXX@dell.com	1064430390	3	9066203792579472	2011/05	user12256	password	20	20000	F
12257	OJOTFF	YLUXGVVETP	7045800578 Dell Way	\N	YXZLICO	\N	0	China	2	YLUXGVVETP@dell.com	7045800578	3	9891244362108410	2008/06	user12257	password	26	40000	F
12258	MVURAT	DVRJRMNKCL	9174942490 Dell Way	\N	HCXQELY	\N	0	South Africa	2	DVRJRMNKCL@dell.com	9174942490	5	9045311521738768	2009/01	user12258	password	29	60000	M
12259	ZGFAAJ	VRTMEGXGSE	7222484680 Dell Way	\N	IPUNBTI	\N	0	UK	2	VRTMEGXGSE@dell.com	7222484680	2	4292306771036238	2011/05	user12259	password	77	40000	F
12260	BNKBWF	TPSXWPEPUM	6239788362 Dell Way	\N	FPAHJIG	\N	0	Australia	2	TPSXWPEPUM@dell.com	6239788362	4	8102014020550997	2012/06	user12260	password	23	40000	F
12261	PTOMZI	CSFZHJOCWU	9131239402 Dell Way	\N	RWBAFHB	\N	0	South Africa	2	CSFZHJOCWU@dell.com	9131239402	5	8052164235617966	2009/12	user12261	password	28	100000	M
12262	XJAXRC	PXBXHQZDLR	6626119935 Dell Way	\N	AMSGUTB	\N	0	Japan	2	PXBXHQZDLR@dell.com	6626119935	5	1160403554793447	2010/12	user12262	password	78	20000	M
12263	FCUXFJ	UHHBYGFJYG	4041907400 Dell Way	\N	WQMQKNI	\N	0	Australia	2	UHHBYGFJYG@dell.com	4041907400	2	6278889538254589	2009/03	user12263	password	67	20000	F
12264	UZHAJC	HQDFWJPVPL	7967722897 Dell Way	\N	LBCVPKW	\N	0	UK	2	HQDFWJPVPL@dell.com	7967722897	3	3134097096510231	2012/02	user12264	password	49	40000	M
12265	KQYTSF	JWLGFABVLN	7095716077 Dell Way	\N	XNJMYFK	\N	0	Russia	2	JWLGFABVLN@dell.com	7095716077	4	7064220028463752	2012/01	user12265	password	20	80000	F
12266	RRGKXP	GIWMIXIUKF	7957286619 Dell Way	\N	HTSFZDY	\N	0	Japan	2	GIWMIXIUKF@dell.com	7957286619	4	5323827943764627	2012/08	user12266	password	34	40000	F
12267	XOSUEZ	CALLYUFJZN	3692441076 Dell Way	\N	DRTCVRU	\N	0	Germany	2	CALLYUFJZN@dell.com	3692441076	2	4953278957866132	2012/06	user12267	password	75	40000	F
12268	JZENYH	OKSMEYWELZ	1978585338 Dell Way	\N	WFCRWWG	\N	0	Canada	2	OKSMEYWELZ@dell.com	1978585338	4	2126914129126817	2010/06	user12268	password	46	100000	M
12269	JDJILX	SEKXCHBOGX	5483781553 Dell Way	\N	TIOQEVV	\N	0	Chile	2	SEKXCHBOGX@dell.com	5483781553	5	8945759385358543	2012/04	user12269	password	80	80000	M
12270	ZDAKBS	OMPRTRGZOZ	4479861305 Dell Way	\N	IDQNYLU	\N	0	France	2	OMPRTRGZOZ@dell.com	4479861305	4	4770235886797309	2011/07	user12270	password	32	60000	M
12271	ILYKDN	WTEQLKPAKY	9358892278 Dell Way	\N	DALCMGO	\N	0	South Africa	2	WTEQLKPAKY@dell.com	9358892278	5	6163226621225477	2010/03	user12271	password	90	100000	M
12272	KYYOLU	IPLTAATKYX	6126783719 Dell Way	\N	LKAXQPU	\N	0	Germany	2	IPLTAATKYX@dell.com	6126783719	2	1316620181314647	2011/05	user12272	password	19	40000	M
12273	YFIKAQ	ALKAMELLCX	9372524681 Dell Way	\N	VCVMRPB	\N	0	Chile	2	ALKAMELLCX@dell.com	9372524681	1	1145933443680405	2009/02	user12273	password	40	20000	F
12274	NILOYM	ZJMMNYXPWT	4412092436 Dell Way	\N	SRGKGHQ	\N	0	Canada	2	ZJMMNYXPWT@dell.com	4412092436	4	5063710821326822	2010/12	user12274	password	51	60000	F
12275	UABTMA	CZNQYLFUEX	6712782012 Dell Way	\N	MLISSZX	\N	0	Australia	2	CZNQYLFUEX@dell.com	6712782012	2	6279690320137889	2011/10	user12275	password	28	20000	M
12276	EDJQEL	QRCOCHJHFV	8330504944 Dell Way	\N	SOOLNLN	\N	0	Canada	2	QRCOCHJHFV@dell.com	8330504944	1	7731321959756316	2011/04	user12276	password	79	40000	F
12277	ZPBEBS	VDHYLQFRMY	9899547353 Dell Way	\N	FAJSMWW	\N	0	Chile	2	VDHYLQFRMY@dell.com	9899547353	4	9409891821444036	2009/06	user12277	password	31	80000	F
12278	UTPVLL	ZTJLJPDWNI	5845923059 Dell Way	\N	XXBJTYR	\N	0	Russia	2	ZTJLJPDWNI@dell.com	5845923059	4	1004582176916301	2012/10	user12278	password	66	60000	M
12279	KBKWMK	PVVYLYVZHS	4191131789 Dell Way	\N	WICQGTJ	\N	0	South Africa	2	PVVYLYVZHS@dell.com	4191131789	2	8259982431307436	2008/01	user12279	password	36	80000	F
12280	HCHTNW	PJVBIQAPJW	3028282136 Dell Way	\N	YLMFEWA	\N	0	Germany	2	PJVBIQAPJW@dell.com	3028282136	5	7103171130642296	2009/01	user12280	password	45	80000	F
12281	MZDAWT	JRURIUHRRF	3322690454 Dell Way	\N	CDKHZLV	\N	0	Chile	2	JRURIUHRRF@dell.com	3322690454	3	5210099398158491	2009/11	user12281	password	30	80000	F
12282	EVKAPT	RJLAESRVXU	4767494568 Dell Way	\N	YICYUXD	\N	0	Australia	2	RJLAESRVXU@dell.com	4767494568	3	4293573922012001	2009/10	user12282	password	22	80000	M
12283	XCYMWQ	WIQAAIVYDU	4999042640 Dell Way	\N	HFSBCWC	\N	0	Germany	2	WIQAAIVYDU@dell.com	4999042640	3	8578206246718765	2009/07	user12283	password	57	20000	F
12284	QCXNTT	VKUWSPUWKC	7514277434 Dell Way	\N	BCEEYGS	\N	0	France	2	VKUWSPUWKC@dell.com	7514277434	3	6568406336940826	2009/01	user12284	password	73	80000	M
12285	WPGPIB	ZDXSSSODVQ	1178048609 Dell Way	\N	GZUFGMP	\N	0	UK	2	ZDXSSSODVQ@dell.com	1178048609	2	2888580813538283	2008/12	user12285	password	83	100000	M
12286	MBLVDL	YBERUSUPIA	1398986013 Dell Way	\N	ODFUPVT	\N	0	Japan	2	YBERUSUPIA@dell.com	1398986013	5	7561103762127460	2008/11	user12286	password	58	100000	F
12287	QIETUC	UYUORPEAPS	3130901495 Dell Way	\N	DVNTRHJ	\N	0	Russia	2	UYUORPEAPS@dell.com	3130901495	1	7634893859270961	2008/08	user12287	password	62	60000	F
12288	YPASSV	QMKHCOIRHL	6842289570 Dell Way	\N	NVEECOX	\N	0	China	2	QMKHCOIRHL@dell.com	6842289570	4	4747405120637268	2009/04	user12288	password	79	60000	F
12289	LPXEKO	RUWTJELQQY	7159191291 Dell Way	\N	LUDOJBW	\N	0	Australia	2	RUWTJELQQY@dell.com	7159191291	2	3764973548706621	2012/02	user12289	password	82	20000	M
12290	MBTWPK	RMDARORHND	8626949708 Dell Way	\N	CRRLSOL	\N	0	China	2	RMDARORHND@dell.com	8626949708	4	3938937870319933	2012/08	user12290	password	51	60000	F
12291	NHZCRQ	PVRGJJNXNP	3282620430 Dell Way	\N	OEBGTMQ	\N	0	Germany	2	PVRGJJNXNP@dell.com	3282620430	5	6180607553571463	2012/06	user12291	password	28	100000	M
12292	LYBDPQ	YHWIRKFEAT	6500938881 Dell Way	\N	IBACOQR	\N	0	South Africa	2	YHWIRKFEAT@dell.com	6500938881	2	7343548452015967	2008/05	user12292	password	68	100000	M
12293	QAYGQX	ONFFYLJYFS	7635721266 Dell Way	\N	AFUPVMK	\N	0	France	2	ONFFYLJYFS@dell.com	7635721266	1	5442110268399120	2008/10	user12293	password	51	100000	F
12294	MXSDVH	RBMPNVOSOP	7181870592 Dell Way	\N	XJETVPF	\N	0	Germany	2	RBMPNVOSOP@dell.com	7181870592	4	7314631799701602	2010/02	user12294	password	66	100000	M
12295	PRTKYL	MKBZGPRUEO	2732816767 Dell Way	\N	EJHZYNO	\N	0	Japan	2	MKBZGPRUEO@dell.com	2732816767	2	2004198586568236	2009/12	user12295	password	21	100000	M
12296	STYQEK	BFKHVBCAQG	1727038263 Dell Way	\N	JYGHLVY	\N	0	Japan	2	BFKHVBCAQG@dell.com	1727038263	1	9804900835268200	2008/02	user12296	password	87	60000	M
12297	SLLWWM	CGUXIXXYEH	5832468750 Dell Way	\N	XKPIFNY	\N	0	China	2	CGUXIXXYEH@dell.com	5832468750	5	3880014935042709	2011/11	user12297	password	79	60000	M
12298	HWMEIO	LDMTAKSERP	8343721579 Dell Way	\N	PGXVTWD	\N	0	Chile	2	LDMTAKSERP@dell.com	8343721579	3	9149614881258460	2011/04	user12298	password	42	40000	M
12299	FUTNJF	RVYRFQWWGL	8302230265 Dell Way	\N	CEGWAJD	\N	0	South Africa	2	RVYRFQWWGL@dell.com	8302230265	1	6084077369887382	2008/05	user12299	password	81	80000	M
12300	RLCAQT	VPLAGHXMSA	1423170695 Dell Way	\N	RZWSIAO	\N	0	Canada	2	VPLAGHXMSA@dell.com	1423170695	1	3239313153084367	2010/12	user12300	password	86	100000	M
12301	KCQBWM	QHMXPKKIKB	4803622289 Dell Way	\N	HHTQHIU	\N	0	China	2	QHMXPKKIKB@dell.com	4803622289	1	7711694178637118	2010/12	user12301	password	71	20000	F
12302	VRKRDB	ZQZOAJWLLE	6320972119 Dell Way	\N	SFUZNOI	\N	0	UK	2	ZQZOAJWLLE@dell.com	6320972119	1	4089025498367846	2010/10	user12302	password	46	100000	M
12303	CIHGKG	WJUXTRJEVB	5102650817 Dell Way	\N	KQBXEKV	\N	0	Russia	2	WJUXTRJEVB@dell.com	5102650817	1	4027118827681989	2009/07	user12303	password	36	100000	M
12304	PDXZJU	IESCVBHRDR	6317345181 Dell Way	\N	HFOMPKG	\N	0	Australia	2	IESCVBHRDR@dell.com	6317345181	3	3606259244959801	2008/11	user12304	password	29	100000	F
12305	HSKRMT	VEWRGDIJUQ	9574341895 Dell Way	\N	OJCDUJE	\N	0	China	2	VEWRGDIJUQ@dell.com	9574341895	3	5854633549693972	2012/08	user12305	password	44	40000	M
12306	CQOOKK	TGBAJKJEAY	7569231588 Dell Way	\N	ODCIMGS	\N	0	France	2	TGBAJKJEAY@dell.com	7569231588	2	3140105994883925	2009/08	user12306	password	52	40000	M
12307	DVGNGA	UIADSKITIW	2604865716 Dell Way	\N	WKFJRYU	\N	0	China	2	UIADSKITIW@dell.com	2604865716	1	7765038785524667	2011/06	user12307	password	19	60000	M
12308	WTDCTX	KUBDEJWNGS	8896650485 Dell Way	\N	YMBPKWA	\N	0	Germany	2	KUBDEJWNGS@dell.com	8896650485	4	4339614961761981	2009/10	user12308	password	80	100000	M
12309	PDSJAC	DBFILCWSUU	2265371304 Dell Way	\N	FWKPTKE	\N	0	Japan	2	DBFILCWSUU@dell.com	2265371304	3	9840208181645722	2012/05	user12309	password	88	60000	M
12310	CGICJM	EOVQRRJMMO	8856238241 Dell Way	\N	JWDCGIR	\N	0	China	2	EOVQRRJMMO@dell.com	8856238241	4	3614122534636408	2009/08	user12310	password	77	40000	M
12311	BPVKCA	ZYRQPACBOL	9017480874 Dell Way	\N	YSNEBFO	\N	0	UK	2	ZYRQPACBOL@dell.com	9017480874	5	2764131474308669	2010/08	user12311	password	51	40000	M
12312	BCCECB	CUSSUVTJGR	3249319326 Dell Way	\N	CUWDAKB	\N	0	UK	2	CUSSUVTJGR@dell.com	3249319326	2	4877983902581036	2012/09	user12312	password	68	80000	M
12313	USYWUB	QNTLINVOEX	4578048000 Dell Way	\N	JBBJLDH	\N	0	Russia	2	QNTLINVOEX@dell.com	4578048000	4	6534625833854080	2008/05	user12313	password	34	100000	F
12314	YWBTXS	GQDOEYDJWM	8700456115 Dell Way	\N	KYWWBDO	\N	0	France	2	GQDOEYDJWM@dell.com	8700456115	1	6175011334009469	2009/05	user12314	password	53	60000	F
12315	JMCHEI	YIWCHALDNV	4748717550 Dell Way	\N	BJRDNGO	\N	0	China	2	YIWCHALDNV@dell.com	4748717550	1	6637345135211945	2012/08	user12315	password	21	20000	M
12316	NGHRPF	ZMHHMSKZNM	3918699400 Dell Way	\N	JFPWLEG	\N	0	South Africa	2	ZMHHMSKZNM@dell.com	3918699400	5	7171916068065912	2012/12	user12316	password	80	100000	F
12317	DGDSLD	ESKRKURYHA	1316653495 Dell Way	\N	EXXPBDM	\N	0	China	2	ESKRKURYHA@dell.com	1316653495	1	4196288449224085	2012/01	user12317	password	40	60000	F
12318	ONWZQA	RASCVJBDJF	4908644715 Dell Way	\N	AGVCKHM	\N	0	France	2	RASCVJBDJF@dell.com	4908644715	5	4742900849319995	2010/02	user12318	password	77	60000	M
12319	ILRZMJ	AEMWNNZXTA	4984524974 Dell Way	\N	EODPVPA	\N	0	Chile	2	AEMWNNZXTA@dell.com	4984524974	3	7473770412150771	2010/04	user12319	password	39	40000	M
12320	SZPEJQ	JVMXJMUCNY	1136794243 Dell Way	\N	QQNMGOT	\N	0	Japan	2	JVMXJMUCNY@dell.com	1136794243	3	3478143707383424	2009/10	user12320	password	60	100000	M
12321	ONSXDB	SQYCDTEQRV	6120732823 Dell Way	\N	GFINUCE	\N	0	Russia	2	SQYCDTEQRV@dell.com	6120732823	3	1688563002273440	2009/01	user12321	password	89	100000	M
12322	MOMPQF	FPHJIMZZIG	4453948089 Dell Way	\N	FQTZSYU	\N	0	Chile	2	FPHJIMZZIG@dell.com	4453948089	5	6746521293185652	2010/10	user12322	password	54	20000	F
12323	BMXSSD	HAMPMMPVSV	4848875426 Dell Way	\N	LMUEKOL	\N	0	Russia	2	HAMPMMPVSV@dell.com	4848875426	1	2769792691338807	2009/08	user12323	password	32	60000	M
12324	RMJKPQ	KCGXOVSHRE	8660658814 Dell Way	\N	TLIDATY	\N	0	France	2	KCGXOVSHRE@dell.com	8660658814	1	7373037525452674	2010/04	user12324	password	37	20000	F
12325	TLLJCV	LITAEMHVRB	3464448666 Dell Way	\N	HZFITDT	\N	0	Japan	2	LITAEMHVRB@dell.com	3464448666	3	1380876257549971	2011/09	user12325	password	27	80000	F
12326	PBWRXH	ARIFDQBURJ	9250144934 Dell Way	\N	UXROALE	\N	0	China	2	ARIFDQBURJ@dell.com	9250144934	1	9172775391489268	2011/04	user12326	password	56	20000	M
12327	OAPMHQ	DQVGGXBYGW	7874267397 Dell Way	\N	VYKWJOE	\N	0	Chile	2	DQVGGXBYGW@dell.com	7874267397	1	9504442840814592	2008/08	user12327	password	25	20000	F
12328	CPQKGT	ABAHZCFFYA	2021649017 Dell Way	\N	DJXNYBU	\N	0	Japan	2	ABAHZCFFYA@dell.com	2021649017	4	8133483515586705	2011/11	user12328	password	76	100000	M
12329	KNJQGK	SHRSJXYIYC	2240041654 Dell Way	\N	SVPQWKI	\N	0	UK	2	SHRSJXYIYC@dell.com	2240041654	1	7146109453868122	2012/12	user12329	password	59	100000	F
12330	BHZIRS	QIKZFJIDLA	1847356552 Dell Way	\N	ZAQVLZU	\N	0	Germany	2	QIKZFJIDLA@dell.com	1847356552	3	5912090548779816	2008/01	user12330	password	52	40000	F
12331	TIMKBC	TMCZVKDGLC	2916888650 Dell Way	\N	HCYSBTH	\N	0	Canada	2	TMCZVKDGLC@dell.com	2916888650	5	2567979890387505	2009/04	user12331	password	56	40000	F
12332	WVMYYG	KAGGLJNWMU	6782156778 Dell Way	\N	YKNADVE	\N	0	China	2	KAGGLJNWMU@dell.com	6782156778	2	6549335378222168	2012/11	user12332	password	90	20000	M
12333	VMSTSC	UYJFIWCVRB	6496037798 Dell Way	\N	GEBJZGT	\N	0	Japan	2	UYJFIWCVRB@dell.com	6496037798	2	6200106915552170	2010/05	user12333	password	60	40000	F
12334	BYYUBS	TKYCGAXXCD	6513914130 Dell Way	\N	CENCKGS	\N	0	Australia	2	TKYCGAXXCD@dell.com	6513914130	2	5688062351662666	2012/11	user12334	password	74	20000	M
12335	SCTUVM	ETPLUMJWQL	5665504772 Dell Way	\N	BENLKFM	\N	0	Australia	2	ETPLUMJWQL@dell.com	5665504772	1	9876519403420390	2009/10	user12335	password	27	40000	F
12336	FBGAOL	UDWPQFMHRN	5037222662 Dell Way	\N	LEZWKLW	\N	0	UK	2	UDWPQFMHRN@dell.com	5037222662	5	3848531601484865	2009/12	user12336	password	65	80000	F
12337	SZGHLB	LHQCNCJEQU	4543564795 Dell Way	\N	JPRTANR	\N	0	France	2	LHQCNCJEQU@dell.com	4543564795	1	7341754837892950	2009/08	user12337	password	48	60000	F
12338	KVQVXC	DNEQQOVGJE	6502057052 Dell Way	\N	VAYWOPI	\N	0	UK	2	DNEQQOVGJE@dell.com	6502057052	1	3904177744872868	2009/06	user12338	password	85	80000	M
12339	THSQJW	EOMUCIBLMW	2181445902 Dell Way	\N	MKTAACY	\N	0	Japan	2	EOMUCIBLMW@dell.com	2181445902	2	9010888202115894	2011/03	user12339	password	55	60000	M
12340	UFPEBT	SOOVWPHIMT	9538450116 Dell Way	\N	TFTTHRK	\N	0	France	2	SOOVWPHIMT@dell.com	9538450116	2	1308239786885678	2008/10	user12340	password	55	20000	M
12341	SRUTLM	IZIEPPMBIG	6987354967 Dell Way	\N	HBZPTKA	\N	0	Japan	2	IZIEPPMBIG@dell.com	6987354967	1	8387566044926644	2010/07	user12341	password	83	20000	F
12342	OVBAIJ	AQNPFAROGZ	6831461157 Dell Way	\N	PGOIQPA	\N	0	China	2	AQNPFAROGZ@dell.com	6831461157	5	8010583512485028	2009/09	user12342	password	79	60000	F
12343	RPIZZI	QMYWNQKUPZ	2805286916 Dell Way	\N	BEISTJA	\N	0	France	2	QMYWNQKUPZ@dell.com	2805286916	5	6630322751589120	2012/08	user12343	password	28	40000	F
12344	TPISYY	FWVSMFNCFP	2265928123 Dell Way	\N	GOHZXIK	\N	0	Canada	2	FWVSMFNCFP@dell.com	2265928123	1	1494646494742482	2011/03	user12344	password	41	20000	M
12345	XLPVKU	SFNFKBHQQN	9488944010 Dell Way	\N	FYNCHXF	\N	0	France	2	SFNFKBHQQN@dell.com	9488944010	2	2836461946833879	2008/08	user12345	password	40	20000	F
12346	TQIDLB	IYGTANKQAP	2499580035 Dell Way	\N	PORWMXH	\N	0	France	2	IYGTANKQAP@dell.com	2499580035	3	5750536259263754	2011/10	user12346	password	58	40000	M
12347	EPRPQZ	OWTOJDFKSU	4730719609 Dell Way	\N	YKRKIYV	\N	0	France	2	OWTOJDFKSU@dell.com	4730719609	2	3127780561335385	2009/11	user12347	password	53	80000	F
12348	BKRRKG	OEVXIAHBVG	8651651428 Dell Way	\N	LMRUKMG	\N	0	South Africa	2	OEVXIAHBVG@dell.com	8651651428	3	1387366683688014	2011/12	user12348	password	75	100000	F
12349	FNTPUH	UPFCQMDLTP	2002186900 Dell Way	\N	YKJJXQE	\N	0	Russia	2	UPFCQMDLTP@dell.com	2002186900	2	5670064884237946	2008/01	user12349	password	44	20000	F
12350	XWVREQ	HJSXWVJPKH	1604492614 Dell Way	\N	ATQYJVS	\N	0	France	2	HJSXWVJPKH@dell.com	1604492614	2	6256064610090107	2008/07	user12350	password	70	40000	F
12351	PEDTUK	CMHZHQOSYP	4847698058 Dell Way	\N	MPNWKFJ	\N	0	France	2	CMHZHQOSYP@dell.com	4847698058	5	6126035873778165	2008/08	user12351	password	82	60000	F
12352	BPAVAD	HICPZRIXGU	9510896143 Dell Way	\N	MTRXZAJ	\N	0	France	2	HICPZRIXGU@dell.com	9510896143	5	4696076097432524	2011/10	user12352	password	81	100000	M
12353	MXRMAZ	UDPTUXRASD	3977740344 Dell Way	\N	UJAUJKE	\N	0	China	2	UDPTUXRASD@dell.com	3977740344	3	9198583258781584	2008/06	user12353	password	74	20000	M
12354	RSLRRG	UHZOEQPWUK	9733612149 Dell Way	\N	FUEPFJX	\N	0	Germany	2	UHZOEQPWUK@dell.com	9733612149	4	7158544053323568	2010/07	user12354	password	69	40000	F
12355	KVXCBS	KBHOSXLMHQ	9251718753 Dell Way	\N	HMGMWDA	\N	0	South Africa	2	KBHOSXLMHQ@dell.com	9251718753	4	3415621327236295	2010/05	user12355	password	66	80000	M
12356	MQYOJI	QRWIOIUWZC	3439031697 Dell Way	\N	IFOEIOA	\N	0	Chile	2	QRWIOIUWZC@dell.com	3439031697	2	7533920755609871	2011/12	user12356	password	51	60000	F
12357	CLAMTQ	DQYRYTNXVW	4207798939 Dell Way	\N	CJBKYBQ	\N	0	Chile	2	DQYRYTNXVW@dell.com	4207798939	2	9108186126220972	2009/10	user12357	password	46	80000	M
12358	VTKOKN	EIFDBSAWPC	5934857444 Dell Way	\N	GRNFTEL	\N	0	Australia	2	EIFDBSAWPC@dell.com	5934857444	2	4602968705818057	2009/09	user12358	password	28	40000	M
12359	XSDHFI	QKLRDMOTOV	8616772778 Dell Way	\N	KCBDHNG	\N	0	South Africa	2	QKLRDMOTOV@dell.com	8616772778	4	2797948287799954	2010/10	user12359	password	54	20000	M
12360	FHALPQ	VBIZNXSCTD	2746535269 Dell Way	\N	FUHMHOH	\N	0	Canada	2	VBIZNXSCTD@dell.com	2746535269	3	7508727751206607	2012/12	user12360	password	82	80000	F
12361	ESQUIM	VRLJOELHIQ	9132741963 Dell Way	\N	BQDJEKM	\N	0	China	2	VRLJOELHIQ@dell.com	9132741963	2	4139427558518946	2012/02	user12361	password	21	20000	F
12362	TTBCFW	TRGIVRPEIR	7714658526 Dell Way	\N	ULAYWNH	\N	0	Russia	2	TRGIVRPEIR@dell.com	7714658526	4	7005131839774550	2012/09	user12362	password	74	20000	F
12363	NDOSAI	JGQFYFJHXD	1108256273 Dell Way	\N	TYCPMJJ	\N	0	Chile	2	JGQFYFJHXD@dell.com	1108256273	1	1479233524296432	2011/10	user12363	password	29	20000	F
12364	ISBIAK	PRQOXAWUDP	6418267147 Dell Way	\N	SFFFPOK	\N	0	Japan	2	PRQOXAWUDP@dell.com	6418267147	3	3853752638678998	2010/08	user12364	password	52	80000	M
12365	EUHFFW	WVLTVIOZXH	4123620781 Dell Way	\N	FCMURXK	\N	0	Chile	2	WVLTVIOZXH@dell.com	4123620781	4	7251799494493753	2012/03	user12365	password	49	100000	F
12366	FEPKBM	FNGBVVASCF	2361616516 Dell Way	\N	VPANMKU	\N	0	South Africa	2	FNGBVVASCF@dell.com	2361616516	3	8055168921593577	2009/12	user12366	password	67	80000	F
12367	WJNXVT	KCUFXUYZAU	6511553006 Dell Way	\N	PAHBLCW	\N	0	Germany	2	KCUFXUYZAU@dell.com	6511553006	4	9544756744056940	2010/05	user12367	password	68	80000	F
12368	BFCXYM	ZTSXNQXOLM	1449865908 Dell Way	\N	OTNAWKP	\N	0	France	2	ZTSXNQXOLM@dell.com	1449865908	3	1046076755039393	2009/04	user12368	password	67	60000	F
12369	WQFVDE	OVBCMYQXLF	4449646622 Dell Way	\N	QYFNIVZ	\N	0	China	2	OVBCMYQXLF@dell.com	4449646622	5	7992298214696348	2011/08	user12369	password	43	100000	M
12370	ZDJDIX	YKALJQIUWZ	4743815796 Dell Way	\N	SCMBXLL	\N	0	China	2	YKALJQIUWZ@dell.com	4743815796	2	9418654891662300	2008/07	user12370	password	81	60000	M
12371	AYRIVQ	TWBCNKWJJP	4256813338 Dell Way	\N	LWRJHDR	\N	0	Russia	2	TWBCNKWJJP@dell.com	4256813338	4	7998580731917173	2012/06	user12371	password	44	60000	F
12372	HFVDVO	ZXRNHNWRDI	9758703343 Dell Way	\N	NUSVXJN	\N	0	Chile	2	ZXRNHNWRDI@dell.com	9758703343	2	2864886246155947	2010/09	user12372	password	70	100000	M
12373	YUDTJD	RAQYNMPQVD	7902850441 Dell Way	\N	LNYIWMP	\N	0	South Africa	2	RAQYNMPQVD@dell.com	7902850441	5	3676380465738475	2010/07	user12373	password	36	60000	F
12374	BNFKQW	KGVYTLPOOA	7888413644 Dell Way	\N	BMJYYYU	\N	0	Russia	2	KGVYTLPOOA@dell.com	7888413644	1	2422257209662348	2009/04	user12374	password	59	80000	F
12375	CYTTVE	AQDUBSIQTK	2805539521 Dell Way	\N	DDIBCDU	\N	0	South Africa	2	AQDUBSIQTK@dell.com	2805539521	5	2198371144477278	2010/07	user12375	password	81	100000	M
12376	VRJQVJ	HYDJRMZKWC	9198668737 Dell Way	\N	OFEQJYL	\N	0	Germany	2	HYDJRMZKWC@dell.com	9198668737	3	1726495828945189	2010/06	user12376	password	89	20000	F
12377	QKYLTF	KXOCJONGQB	7384772617 Dell Way	\N	MVRWUDK	\N	0	Japan	2	KXOCJONGQB@dell.com	7384772617	3	2007825008593499	2008/06	user12377	password	29	60000	F
12378	OKOIPY	FEAPSOWJPJ	1877373694 Dell Way	\N	EGFYJQQ	\N	0	Australia	2	FEAPSOWJPJ@dell.com	1877373694	4	3216176288202405	2010/11	user12378	password	69	80000	F
12379	CEUSDZ	WEPPSMZHVD	5410916910 Dell Way	\N	OBCXRTZ	\N	0	Russia	2	WEPPSMZHVD@dell.com	5410916910	2	3912774455267936	2009/12	user12379	password	88	100000	F
12380	DPTHPQ	MFFERFMNJB	2716502441 Dell Way	\N	PLZGFYA	\N	0	Japan	2	MFFERFMNJB@dell.com	2716502441	2	1702452343888580	2008/04	user12380	password	85	20000	F
12381	NXTDOF	JUKAZXOIYD	7747398374 Dell Way	\N	UXJZWKR	\N	0	Australia	2	JUKAZXOIYD@dell.com	7747398374	4	2815465979278087	2008/08	user12381	password	45	60000	F
12382	HGIVMR	PWSPUHXTKR	1388002576 Dell Way	\N	RUQOEHP	\N	0	UK	2	PWSPUHXTKR@dell.com	1388002576	5	9982778717763724	2011/03	user12382	password	55	100000	F
12383	UGIGYY	DQNXXKQICI	3458079413 Dell Way	\N	CTWHBMG	\N	0	Australia	2	DQNXXKQICI@dell.com	3458079413	2	8099542796611787	2010/09	user12383	password	68	100000	M
12384	XGTVEX	MSVKCLSEUV	6484525115 Dell Way	\N	YQDZCJB	\N	0	China	2	MSVKCLSEUV@dell.com	6484525115	5	8390969629865141	2009/07	user12384	password	73	100000	F
12385	AQHFOU	XJEZVXEPTC	9954839009 Dell Way	\N	FXCHGDR	\N	0	South Africa	2	XJEZVXEPTC@dell.com	9954839009	3	3077498999424279	2010/03	user12385	password	26	100000	F
12386	THMHBJ	RGJMEOBYRH	7651028582 Dell Way	\N	VTPCXGY	\N	0	South Africa	2	RGJMEOBYRH@dell.com	7651028582	1	4736578367184848	2012/04	user12386	password	46	40000	F
12387	RSJTCA	ZLMEZOCQVX	2262273051 Dell Way	\N	JLZHRYE	\N	0	France	2	ZLMEZOCQVX@dell.com	2262273051	3	4618215442169458	2010/12	user12387	password	65	60000	M
12388	JWJLWJ	WJOWYQMUOW	8879602712 Dell Way	\N	FODWNHH	\N	0	Japan	2	WJOWYQMUOW@dell.com	8879602712	4	1726087973918765	2012/05	user12388	password	59	60000	M
12389	LWEHGB	RUXQKKKZHP	5151054405 Dell Way	\N	NKMASTR	\N	0	Germany	2	RUXQKKKZHP@dell.com	5151054405	4	4958913273178041	2012/04	user12389	password	85	60000	M
12390	USBBTT	VRJGBTFIJT	2701715695 Dell Way	\N	TVUMPLB	\N	0	Australia	2	VRJGBTFIJT@dell.com	2701715695	3	8785905134398491	2010/06	user12390	password	46	40000	F
12391	CIHVBC	NLJOEPXOIQ	7060160748 Dell Way	\N	JDCZOEA	\N	0	Russia	2	NLJOEPXOIQ@dell.com	7060160748	5	3330195459537208	2008/04	user12391	password	56	40000	F
12392	WQFXTS	JCHNSECBUL	3780376234 Dell Way	\N	EXKSCLM	\N	0	Russia	2	JCHNSECBUL@dell.com	3780376234	4	8779844000004233	2010/04	user12392	password	32	100000	F
12393	VEAOXJ	REXJIZKDLP	5472241395 Dell Way	\N	BVHDGUX	\N	0	Germany	2	REXJIZKDLP@dell.com	5472241395	4	2476808219682425	2011/12	user12393	password	26	100000	M
12394	HWIEGA	IDJRDUUOJV	6408766499 Dell Way	\N	KRYRLWG	\N	0	UK	2	IDJRDUUOJV@dell.com	6408766499	3	7179936220869423	2010/07	user12394	password	57	40000	M
12395	KRAQRJ	UBAYWUNFQY	3847664095 Dell Way	\N	XPQILXH	\N	0	Australia	2	UBAYWUNFQY@dell.com	3847664095	5	6401974496431649	2012/07	user12395	password	86	80000	M
12396	QSOHCJ	JCIFXVLNUI	9311089999 Dell Way	\N	DKROHYP	\N	0	Japan	2	JCIFXVLNUI@dell.com	9311089999	2	5244915104005486	2010/02	user12396	password	31	40000	M
12397	XXBZGL	CPRZKCNELQ	1225895693 Dell Way	\N	PDFWCVM	\N	0	Australia	2	CPRZKCNELQ@dell.com	1225895693	5	5029648837167770	2008/02	user12397	password	74	100000	F
12398	RAAYLC	NCCYFPDRGS	1287492707 Dell Way	\N	VLPXHBY	\N	0	Chile	2	NCCYFPDRGS@dell.com	1287492707	2	5216685608495027	2008/03	user12398	password	47	40000	M
12399	KGUWJH	ZLGFBJXIBS	9686512789 Dell Way	\N	UQQBSOI	\N	0	Russia	2	ZLGFBJXIBS@dell.com	9686512789	5	9296085269656032	2008/03	user12399	password	27	100000	M
12400	JUNTBM	EHRGROOSHI	5728678673 Dell Way	\N	JXJCMSV	\N	0	France	2	EHRGROOSHI@dell.com	5728678673	4	6257045757956803	2011/11	user12400	password	59	40000	F
12401	IWAKJE	SBLKQACXJM	2251797240 Dell Way	\N	UTOHMJT	\N	0	UK	2	SBLKQACXJM@dell.com	2251797240	2	7550316881388427	2008/11	user12401	password	25	40000	F
12402	ZHRIMK	JYUZYWWHIR	1237487207 Dell Way	\N	BWZNGSN	\N	0	China	2	JYUZYWWHIR@dell.com	1237487207	2	4865758691448718	2012/04	user12402	password	71	20000	F
12403	AUQNEZ	LYZKVWREOT	9862202056 Dell Way	\N	BNGHGTS	\N	0	Chile	2	LYZKVWREOT@dell.com	9862202056	1	2583820572588593	2009/11	user12403	password	41	80000	M
12404	DGKIFV	HFFCBXHPQI	5114242344 Dell Way	\N	DXQJQIQ	\N	0	Japan	2	HFFCBXHPQI@dell.com	5114242344	4	9557418409269304	2009/02	user12404	password	58	20000	F
12405	UPOAKV	FQYGOFWEOZ	7929269831 Dell Way	\N	CEJTMZJ	\N	0	UK	2	FQYGOFWEOZ@dell.com	7929269831	2	3347948246635497	2012/11	user12405	password	51	20000	M
12406	BSSMOX	CNERTAWHAY	4527004875 Dell Way	\N	LJRYIBW	\N	0	Canada	2	CNERTAWHAY@dell.com	4527004875	1	1057342200540006	2009/08	user12406	password	28	100000	M
12407	WRDKPF	YTWRUTYVRK	3952107382 Dell Way	\N	EIINKFQ	\N	0	Russia	2	YTWRUTYVRK@dell.com	3952107382	4	1746897494420409	2012/10	user12407	password	21	60000	M
12408	SRCIXA	BURWNQRFAW	7094452790 Dell Way	\N	OIJYNAT	\N	0	South Africa	2	BURWNQRFAW@dell.com	7094452790	5	8008176506496967	2010/11	user12408	password	43	20000	M
12409	AFYYGZ	TXVHNNMOJA	6047470794 Dell Way	\N	XTZKUSH	\N	0	France	2	TXVHNNMOJA@dell.com	6047470794	1	9425344794522972	2010/05	user12409	password	23	20000	F
12410	HZKNZD	LVLZIXNSYK	2414000029 Dell Way	\N	LXVGQCS	\N	0	Chile	2	LVLZIXNSYK@dell.com	2414000029	4	6889921591617168	2010/09	user12410	password	70	100000	F
12411	SJNRNZ	MYYVVMOUXA	6296304911 Dell Way	\N	STGIVYO	\N	0	Australia	2	MYYVVMOUXA@dell.com	6296304911	2	6014813060406596	2009/12	user12411	password	57	40000	M
12412	XWHLVU	JUQFGEZEES	8186673455 Dell Way	\N	XKBTJPT	\N	0	UK	2	JUQFGEZEES@dell.com	8186673455	2	3356199844740331	2011/11	user12412	password	59	40000	M
12413	KQFGLO	ABUHGULKMI	2274081506 Dell Way	\N	VNCFCVE	\N	0	South Africa	2	ABUHGULKMI@dell.com	2274081506	3	6580027183517814	2012/01	user12413	password	88	80000	F
12414	PZRBNS	DIZJCKUOTQ	5081145301 Dell Way	\N	BVVERAB	\N	0	South Africa	2	DIZJCKUOTQ@dell.com	5081145301	4	8347375833429397	2010/08	user12414	password	60	100000	F
12415	OOIBGL	KFUMQPBKFC	1363272131 Dell Way	\N	GBHYCJT	\N	0	Germany	2	KFUMQPBKFC@dell.com	1363272131	3	1075166020076721	2011/02	user12415	password	83	100000	M
12416	LHTSSE	YNQPCRZIUG	5388755884 Dell Way	\N	KBENKXB	\N	0	France	2	YNQPCRZIUG@dell.com	5388755884	1	2408966763410717	2011/12	user12416	password	26	40000	F
12417	JCDCGC	PWRSORBJXL	1663432560 Dell Way	\N	KBYVZAH	\N	0	France	2	PWRSORBJXL@dell.com	1663432560	3	1902038228232413	2008/07	user12417	password	49	60000	M
12418	NPBTRQ	QIJFAKOXWZ	6109545107 Dell Way	\N	YVUYVCK	\N	0	UK	2	QIJFAKOXWZ@dell.com	6109545107	3	9441516033839436	2008/12	user12418	password	46	20000	F
12419	ZDFQUV	ZDBZOPXKOV	6990671971 Dell Way	\N	FJUBMEY	\N	0	Australia	2	ZDBZOPXKOV@dell.com	6990671971	5	2652593459468335	2010/04	user12419	password	38	20000	F
12420	KFXFBX	IDXXSUHHQM	4516089114 Dell Way	\N	QKODOME	\N	0	Chile	2	IDXXSUHHQM@dell.com	4516089114	2	8446001044474543	2011/08	user12420	password	80	100000	F
12421	CVGDTP	HQMZLTGBGX	5685511579 Dell Way	\N	MUABHEH	\N	0	Japan	2	HQMZLTGBGX@dell.com	5685511579	1	4271878279279918	2008/12	user12421	password	39	20000	F
12422	DLFXAM	NMLZGSANPM	9344847972 Dell Way	\N	IQNPUVH	\N	0	China	2	NMLZGSANPM@dell.com	9344847972	4	5222815776243806	2012/12	user12422	password	65	100000	F
12423	CDZCPN	PBMWTNJJAR	3215269797 Dell Way	\N	AOHVJPD	\N	0	China	2	PBMWTNJJAR@dell.com	3215269797	4	2771903589833528	2009/04	user12423	password	27	40000	F
12424	GHLWVB	XIXRWGBWYB	6527250358 Dell Way	\N	LFWVUAD	\N	0	Australia	2	XIXRWGBWYB@dell.com	6527250358	2	3254372440744191	2012/06	user12424	password	58	40000	M
12425	WRORSM	AQDWXFTVGE	4886054049 Dell Way	\N	BDZVDCW	\N	0	Russia	2	AQDWXFTVGE@dell.com	4886054049	1	6665118550416083	2012/09	user12425	password	80	60000	M
12426	NEGGQG	WUDTZWPGAQ	5327569005 Dell Way	\N	JAMNDJH	\N	0	Germany	2	WUDTZWPGAQ@dell.com	5327569005	5	5032092886976898	2008/10	user12426	password	20	80000	F
12427	EZNVGJ	PJDPFSVGJF	9006698113 Dell Way	\N	HVSKEZZ	\N	0	Japan	2	PJDPFSVGJF@dell.com	9006698113	3	8364534666296095	2011/06	user12427	password	57	100000	M
12428	NKMTUB	CYQIRMPARW	7170635229 Dell Way	\N	VKHZJGQ	\N	0	Chile	2	CYQIRMPARW@dell.com	7170635229	3	9196311939042062	2008/12	user12428	password	77	100000	M
12429	GHHBJJ	ZASQMHREEM	6006460527 Dell Way	\N	OLMYSCF	\N	0	China	2	ZASQMHREEM@dell.com	6006460527	1	5777651451993734	2010/12	user12429	password	42	20000	F
12430	QIFZSF	ZLWMTNQXZF	5182688047 Dell Way	\N	IMDAOIK	\N	0	Canada	2	ZLWMTNQXZF@dell.com	5182688047	5	7103627018164844	2010/04	user12430	password	72	60000	M
12431	CVWVAW	GXJZKZXKFF	6350104337 Dell Way	\N	WIGLRRO	\N	0	Canada	2	GXJZKZXKFF@dell.com	6350104337	2	5920171508099884	2012/12	user12431	password	27	80000	F
12432	YQXZNE	WWEHWBRBHN	7497146530 Dell Way	\N	JNYBEMF	\N	0	Russia	2	WWEHWBRBHN@dell.com	7497146530	4	6849015347659589	2011/11	user12432	password	48	80000	M
12433	BRVOVR	LZZHBQIIES	7322325137 Dell Way	\N	WCTAPYV	\N	0	China	2	LZZHBQIIES@dell.com	7322325137	3	1223835618700832	2010/11	user12433	password	76	60000	M
12434	MFNHXY	HWGINORRHN	8314965809 Dell Way	\N	UBNJAJS	\N	0	Russia	2	HWGINORRHN@dell.com	8314965809	4	3591526939533651	2011/07	user12434	password	69	80000	M
12435	YDHVCP	SIYGXPXECR	5422032739 Dell Way	\N	GQBGZTY	\N	0	Russia	2	SIYGXPXECR@dell.com	5422032739	2	5307814326137305	2008/12	user12435	password	26	20000	M
12436	GISJXL	SVRPLOUNGA	5022830305 Dell Way	\N	DHGCBFX	\N	0	Germany	2	SVRPLOUNGA@dell.com	5022830305	2	6075219844002277	2009/06	user12436	password	60	40000	M
12437	XYCVJV	QAKBPFPVGS	1865434968 Dell Way	\N	DNVESSS	\N	0	Canada	2	QAKBPFPVGS@dell.com	1865434968	2	5892394727561623	2010/11	user12437	password	75	40000	M
12438	SLOCGF	DRHSWWOCPR	8361031298 Dell Way	\N	PLVIEOM	\N	0	Chile	2	DRHSWWOCPR@dell.com	8361031298	1	8505124575458468	2011/10	user12438	password	29	60000	M
12439	PAQWFU	NNMJKAMZSC	9398374294 Dell Way	\N	LNKPBXV	\N	0	South Africa	2	NNMJKAMZSC@dell.com	9398374294	4	6026077319867910	2011/11	user12439	password	90	40000	F
12440	ZYHFSU	TFEDGRDYTO	6892547310 Dell Way	\N	MEDNBZK	\N	0	Australia	2	TFEDGRDYTO@dell.com	6892547310	5	7743267735000701	2010/12	user12440	password	21	100000	M
12441	ZFESAX	XEBEVECPSO	5459334107 Dell Way	\N	TWCVVNV	\N	0	Germany	2	XEBEVECPSO@dell.com	5459334107	3	9918429170735180	2010/08	user12441	password	85	60000	M
12442	DPHDNF	IOJESMULBN	7763003915 Dell Way	\N	HEJDSEQ	\N	0	Canada	2	IOJESMULBN@dell.com	7763003915	4	6903706729412080	2009/07	user12442	password	23	100000	M
12443	RHVEME	TWJLJDXLQE	6562283935 Dell Way	\N	PZIIEZN	\N	0	UK	2	TWJLJDXLQE@dell.com	6562283935	1	3659112764522433	2008/03	user12443	password	37	100000	M
12444	OSCBWW	XFIHIFSZKI	3995585592 Dell Way	\N	ZTRESEC	\N	0	China	2	XFIHIFSZKI@dell.com	3995585592	2	5572743960190565	2010/08	user12444	password	45	60000	F
12445	CPGYME	EULNZENJNM	2185108651 Dell Way	\N	CERVJTE	\N	0	Japan	2	EULNZENJNM@dell.com	2185108651	4	3372817797586322	2011/01	user12445	password	73	100000	F
12446	JFCVJG	QVUPAHZOUC	7935811747 Dell Way	\N	SLYCFCU	\N	0	China	2	QVUPAHZOUC@dell.com	7935811747	1	2051001746673137	2012/10	user12446	password	24	100000	F
12447	IAARHQ	NBGNJFCDIV	7309711626 Dell Way	\N	PGXUJRD	\N	0	Canada	2	NBGNJFCDIV@dell.com	7309711626	2	9473948006052524	2010/05	user12447	password	82	80000	M
12448	XRJEIW	GOKPUMSCHI	5386875860 Dell Way	\N	JFCSWGV	\N	0	Germany	2	GOKPUMSCHI@dell.com	5386875860	4	1556362967472523	2012/08	user12448	password	71	60000	M
12449	KVTTSZ	HDOBPHEXPO	8867682816 Dell Way	\N	CSGZYCN	\N	0	France	2	HDOBPHEXPO@dell.com	8867682816	3	3361609034705907	2010/04	user12449	password	72	20000	M
12450	PWMHVT	KKVARAYGOB	2322532653 Dell Way	\N	ZVAXXOI	\N	0	Russia	2	KKVARAYGOB@dell.com	2322532653	4	3834387185983360	2010/05	user12450	password	48	40000	M
12451	GSGCMQ	MHRDIPKWQJ	3117212108 Dell Way	\N	RRHPFQJ	\N	0	China	2	MHRDIPKWQJ@dell.com	3117212108	4	8508427363820375	2010/02	user12451	password	21	60000	F
12452	TTMFKY	NBCWRNSIXK	1503424623 Dell Way	\N	ZEAEVJO	\N	0	Australia	2	NBCWRNSIXK@dell.com	1503424623	2	6722719462588430	2008/06	user12452	password	29	60000	F
12453	XZKIYY	KBUBONJLYJ	5186542910 Dell Way	\N	QYOLICM	\N	0	China	2	KBUBONJLYJ@dell.com	5186542910	1	5703953614458442	2012/04	user12453	password	21	20000	F
12454	BMOZLY	BFAPSJBQSS	8185454437 Dell Way	\N	PGEXJRG	\N	0	South Africa	2	BFAPSJBQSS@dell.com	8185454437	4	7461411698255689	2008/11	user12454	password	76	40000	M
12455	HWWSUY	YUOREPIXIX	8486261349 Dell Way	\N	EMUNEBJ	\N	0	UK	2	YUOREPIXIX@dell.com	8486261349	1	1448736652731895	2011/11	user12455	password	44	60000	F
12456	FLXAJV	VXMAMUYVSC	1509524678 Dell Way	\N	IMQMNZL	\N	0	China	2	VXMAMUYVSC@dell.com	1509524678	3	1299208780750632	2012/11	user12456	password	60	20000	F
12457	AZCJVY	GIYTDXOVZW	3227402099 Dell Way	\N	IQJWQUF	\N	0	Japan	2	GIYTDXOVZW@dell.com	3227402099	2	6511717736255378	2008/10	user12457	password	70	20000	M
12458	SGEOFL	WEEZBSVBPD	4959502608 Dell Way	\N	SYZISEA	\N	0	UK	2	WEEZBSVBPD@dell.com	4959502608	4	1592341997660696	2009/04	user12458	password	34	20000	F
12459	MHPSSL	WWLYPHZFKR	6695658810 Dell Way	\N	EJAXOAW	\N	0	Australia	2	WWLYPHZFKR@dell.com	6695658810	5	3511594801675528	2012/02	user12459	password	45	20000	M
12460	RPJJBF	GMDVUDBEVF	9229238552 Dell Way	\N	OVCDWZD	\N	0	France	2	GMDVUDBEVF@dell.com	9229238552	3	5029162778984755	2008/10	user12460	password	51	80000	F
12461	BCVCIB	PMXJPZOLEC	7866408617 Dell Way	\N	GHFDHJP	\N	0	Canada	2	PMXJPZOLEC@dell.com	7866408617	1	3376770577393472	2010/07	user12461	password	90	20000	M
12462	CVQKXG	WVQLUEWZGD	9307308688 Dell Way	\N	HMHOVWT	\N	0	Germany	2	WVQLUEWZGD@dell.com	9307308688	1	2194540208205580	2010/12	user12462	password	28	100000	F
12463	ZQMXWI	SMTNRQNXUU	1766422236 Dell Way	\N	JBIEYCT	\N	0	South Africa	2	SMTNRQNXUU@dell.com	1766422236	5	3682804951444268	2008/01	user12463	password	38	20000	F
12464	XQXUYQ	HSDYJQWELF	1623446825 Dell Way	\N	GUKEWEB	\N	0	UK	2	HSDYJQWELF@dell.com	1623446825	2	1213667242787778	2008/08	user12464	password	31	20000	M
12465	VAITRQ	LVOVMKZXQF	8017053495 Dell Way	\N	RBJNFLM	\N	0	Chile	2	LVOVMKZXQF@dell.com	8017053495	3	4649073540233076	2010/09	user12465	password	56	100000	F
12466	OHGGXS	BMNNXNLNSC	6308602999 Dell Way	\N	PCQVNCC	\N	0	China	2	BMNNXNLNSC@dell.com	6308602999	3	7369236064143480	2009/01	user12466	password	65	80000	M
12467	YAWVSX	HGLETWSLYH	7658197586 Dell Way	\N	OPCBRFJ	\N	0	Chile	2	HGLETWSLYH@dell.com	7658197586	1	5906326825264842	2011/09	user12467	password	40	60000	M
12468	IHMBEU	HQYBMRNLYB	6316657329 Dell Way	\N	ABDSHNZ	\N	0	Australia	2	HQYBMRNLYB@dell.com	6316657329	3	8352772165555508	2009/11	user12468	password	34	100000	F
12469	NMFSGN	IEPVVCGUEH	6015358240 Dell Way	\N	WHADUAE	\N	0	China	2	IEPVVCGUEH@dell.com	6015358240	5	7481124840676785	2010/03	user12469	password	69	60000	M
12470	EULKIT	PXOLAVGECC	4781277657 Dell Way	\N	LDGGDLR	\N	0	Russia	2	PXOLAVGECC@dell.com	4781277657	2	1985980440396815	2011/02	user12470	password	68	40000	F
12471	MURVOG	TCSTXYXABJ	7000867860 Dell Way	\N	EHQHSHA	\N	0	Canada	2	TCSTXYXABJ@dell.com	7000867860	1	8026219273917378	2011/10	user12471	password	29	20000	F
12472	YRDMXW	PQPNONNPWS	2066683067 Dell Way	\N	WMAPUAT	\N	0	France	2	PQPNONNPWS@dell.com	2066683067	3	2823290439788252	2012/09	user12472	password	33	40000	M
12473	WJCUGS	KWFZJTOGLL	3779796403 Dell Way	\N	TLBNLUZ	\N	0	Germany	2	KWFZJTOGLL@dell.com	3779796403	1	5380965395364911	2012/05	user12473	password	70	60000	F
12474	CSBIKL	EPLNIZTULN	2514858854 Dell Way	\N	FMARHZF	\N	0	Germany	2	EPLNIZTULN@dell.com	2514858854	4	6096139879897237	2010/06	user12474	password	30	100000	M
12475	WWVGIZ	WTNFTHZEUE	7807087637 Dell Way	\N	RUVYUBN	\N	0	UK	2	WTNFTHZEUE@dell.com	7807087637	1	5632211970631034	2008/04	user12475	password	41	80000	F
12476	EMKMMG	FALYHKDBPU	4114230304 Dell Way	\N	WLTRMGQ	\N	0	Chile	2	FALYHKDBPU@dell.com	4114230304	1	4835401039104909	2011/06	user12476	password	25	80000	M
12477	PCDCJI	CVHJFLLVFI	7837965525 Dell Way	\N	HYZTFPA	\N	0	Germany	2	CVHJFLLVFI@dell.com	7837965525	3	2437229807488620	2009/07	user12477	password	82	100000	F
12478	ZZGJII	EPSKBEFHMM	7410691607 Dell Way	\N	FMGLCHA	\N	0	South Africa	2	EPSKBEFHMM@dell.com	7410691607	1	1615423491690307	2009/01	user12478	password	85	60000	F
12479	XQKFZO	VSYWWEDJRJ	9823672103 Dell Way	\N	VXVYEVT	\N	0	UK	2	VSYWWEDJRJ@dell.com	9823672103	5	2437717701308429	2008/10	user12479	password	59	20000	M
12480	FLWFAS	YYPUCTEUCA	5897773616 Dell Way	\N	RYYWTSU	\N	0	Russia	2	YYPUCTEUCA@dell.com	5897773616	5	7773192713502795	2009/07	user12480	password	77	100000	M
12481	GWYGOW	FDRIWVCZWU	4537533882 Dell Way	\N	XURRMLK	\N	0	Australia	2	FDRIWVCZWU@dell.com	4537533882	1	4164913326036185	2012/12	user12481	password	41	80000	F
12482	EOMSLS	WCATYDTUXQ	8599944783 Dell Way	\N	PPICBSD	\N	0	France	2	WCATYDTUXQ@dell.com	8599944783	3	4030518670100719	2012/10	user12482	password	88	20000	M
12483	ONSZFP	BGIAJBVHSK	2210581838 Dell Way	\N	WANYSQJ	\N	0	Germany	2	BGIAJBVHSK@dell.com	2210581838	4	4378873206209391	2012/08	user12483	password	47	100000	F
12484	XQEDGG	JOHTQCAJNX	9077960715 Dell Way	\N	KAVDRFR	\N	0	South Africa	2	JOHTQCAJNX@dell.com	9077960715	1	7732982863206417	2010/06	user12484	password	67	80000	F
12485	IYMOFW	DMPTOQDCON	4446351420 Dell Way	\N	CKQUPIP	\N	0	France	2	DMPTOQDCON@dell.com	4446351420	2	1469070018269121	2012/01	user12485	password	77	40000	F
12486	TSWYOA	LETAUXCIKF	8953264130 Dell Way	\N	TAZIIOV	\N	0	Russia	2	LETAUXCIKF@dell.com	8953264130	5	6115241118241102	2012/09	user12486	password	75	40000	F
12487	MCKBCV	GWWATYJEDC	2221139184 Dell Way	\N	EDLNRGG	\N	0	Germany	2	GWWATYJEDC@dell.com	2221139184	5	5150975573807955	2012/08	user12487	password	67	40000	F
12488	UREWNK	TKLNIURMXV	4685920256 Dell Way	\N	QJJIQPW	\N	0	Russia	2	TKLNIURMXV@dell.com	4685920256	2	6263698218856007	2008/01	user12488	password	80	20000	M
12489	OGRCQK	MCYVWPHULX	5161719006 Dell Way	\N	EUGUKDO	\N	0	South Africa	2	MCYVWPHULX@dell.com	5161719006	1	8289902606979013	2010/12	user12489	password	84	40000	M
12490	EYQVJC	XHXUWFPIDT	2732980684 Dell Way	\N	CJNNMBI	\N	0	UK	2	XHXUWFPIDT@dell.com	2732980684	1	4796310453675687	2008/01	user12490	password	69	80000	F
12491	QIAALX	IISFOHNRAQ	5946425083 Dell Way	\N	AODNPLL	\N	0	Russia	2	IISFOHNRAQ@dell.com	5946425083	5	9822931905742736	2010/07	user12491	password	69	80000	F
12492	BUGMSO	VKTJRGBRWB	8998508688 Dell Way	\N	FZPVKAQ	\N	0	UK	2	VKTJRGBRWB@dell.com	8998508688	4	5945201434195042	2010/04	user12492	password	41	80000	F
12493	CXVUMR	FFAWMBOIDU	8781250634 Dell Way	\N	ISQTTGS	\N	0	Japan	2	FFAWMBOIDU@dell.com	8781250634	2	1853960260283202	2008/08	user12493	password	74	60000	M
12494	RJNDAS	JBOVDDEHXN	3518429816 Dell Way	\N	ANGTUZK	\N	0	Japan	2	JBOVDDEHXN@dell.com	3518429816	3	8325241029262544	2012/04	user12494	password	43	60000	M
12495	SCCTUM	VJHZMMGKZG	9410072329 Dell Way	\N	XGARGLI	\N	0	Germany	2	VJHZMMGKZG@dell.com	9410072329	1	4725189359858632	2009/06	user12495	password	90	20000	F
12496	CGZXSU	GATTMADMHA	2405162364 Dell Way	\N	THSZTAN	\N	0	Japan	2	GATTMADMHA@dell.com	2405162364	5	8854699759744109	2011/12	user12496	password	19	100000	F
12497	HUXAPE	AIXNIAZPBS	2518077852 Dell Way	\N	XUSQUGI	\N	0	UK	2	AIXNIAZPBS@dell.com	2518077852	1	6292001542169601	2008/03	user12497	password	49	20000	F
12498	FANVFN	DCBMDACETA	2486292439 Dell Way	\N	YMRTSZR	\N	0	South Africa	2	DCBMDACETA@dell.com	2486292439	2	9827336000744254	2009/09	user12498	password	25	100000	M
12499	DJTIXX	LYJOZMSTMR	4381866740 Dell Way	\N	FEKYDCV	\N	0	Chile	2	LYJOZMSTMR@dell.com	4381866740	4	7130550336558372	2008/11	user12499	password	59	20000	F
12500	YTKWQV	UAJUNCNATT	3679063286 Dell Way	\N	EESHGNP	\N	0	Japan	2	UAJUNCNATT@dell.com	3679063286	2	7501207583118231	2008/11	user12500	password	71	40000	M
12501	MQQDLL	EVGRYURSNV	1313448821 Dell Way	\N	WFDDSTU	\N	0	Australia	2	EVGRYURSNV@dell.com	1313448821	3	3020918328315019	2012/03	user12501	password	52	80000	M
12502	CIVOTZ	JARHUIZHEW	3289601512 Dell Way	\N	NIZGCTH	\N	0	Canada	2	JARHUIZHEW@dell.com	3289601512	3	1013777933549135	2010/12	user12502	password	67	20000	F
12503	ZAQTAZ	TSHNBHVFEJ	4743525858 Dell Way	\N	ODQQXXT	\N	0	Canada	2	TSHNBHVFEJ@dell.com	4743525858	4	6850281459279359	2009/06	user12503	password	79	60000	F
12504	WCEXCY	PKMQRHWWRL	6579705557 Dell Way	\N	AHCXEWC	\N	0	Japan	2	PKMQRHWWRL@dell.com	6579705557	4	9962856006808580	2008/07	user12504	password	51	60000	F
12505	ORJQQZ	ACQSJMOBYO	3665389787 Dell Way	\N	IAMNWOC	\N	0	France	2	ACQSJMOBYO@dell.com	3665389787	1	5859337172005326	2012/07	user12505	password	20	40000	F
12506	SSTIRT	KHMUUAVSPE	8998931635 Dell Way	\N	SBROQUB	\N	0	UK	2	KHMUUAVSPE@dell.com	8998931635	3	8084895148407669	2010/08	user12506	password	26	60000	F
12507	VIRMCC	UOWOPSHEWA	3048382032 Dell Way	\N	GOPWIQT	\N	0	Chile	2	UOWOPSHEWA@dell.com	3048382032	3	7052627873141319	2012/09	user12507	password	36	20000	F
12508	OWZRYT	GVIVOQALQG	4660906889 Dell Way	\N	ZFCHVWN	\N	0	Australia	2	GVIVOQALQG@dell.com	4660906889	1	9360130075830968	2008/06	user12508	password	27	60000	F
12509	ZORYIY	UQTJHUUXAT	8037901031 Dell Way	\N	DDBZZPB	\N	0	China	2	UQTJHUUXAT@dell.com	8037901031	5	5137767739593983	2009/02	user12509	password	19	40000	F
12510	OYBWWV	NPEUKZSKTV	8281731978 Dell Way	\N	NVUNKVX	\N	0	Canada	2	NPEUKZSKTV@dell.com	8281731978	2	4679050545208156	2012/05	user12510	password	65	100000	M
12511	OAVLWJ	BBELBWVUSJ	2158429686 Dell Way	\N	PNWAJUE	\N	0	Canada	2	BBELBWVUSJ@dell.com	2158429686	3	1569194571580737	2010/03	user12511	password	22	60000	M
12512	CGGZQH	AUSBQOWJYL	3140086712 Dell Way	\N	WULFPQJ	\N	0	Russia	2	AUSBQOWJYL@dell.com	3140086712	3	2940511548426002	2010/06	user12512	password	66	40000	M
12513	YOOOVP	INRZCNIAZE	2816850191 Dell Way	\N	VLKKCTC	\N	0	China	2	INRZCNIAZE@dell.com	2816850191	2	8201871953904630	2011/12	user12513	password	25	40000	M
12514	QVMMLU	ZCTCQBCQGX	7943884400 Dell Way	\N	BQIDKLM	\N	0	Germany	2	ZCTCQBCQGX@dell.com	7943884400	2	3653630932793021	2011/05	user12514	password	60	80000	F
12515	LEMWYL	ZROQTQGZOH	2613201787 Dell Way	\N	QXLAIXQ	\N	0	Canada	2	ZROQTQGZOH@dell.com	2613201787	5	8874135197140277	2010/06	user12515	password	58	60000	M
12516	SAURMT	IAJCRPCFXS	3304441207 Dell Way	\N	DJSMHIP	\N	0	France	2	IAJCRPCFXS@dell.com	3304441207	3	1035778572782874	2011/01	user12516	password	57	80000	M
12517	OLKAFS	APVRFXXCPB	5879826026 Dell Way	\N	MINTRCF	\N	0	UK	2	APVRFXXCPB@dell.com	5879826026	2	7101915827486665	2010/10	user12517	password	43	40000	F
12518	URIZKJ	PFBUDZWSAJ	6212919828 Dell Way	\N	BODSQJR	\N	0	Canada	2	PFBUDZWSAJ@dell.com	6212919828	2	7550870820414276	2009/09	user12518	password	18	80000	F
12519	RAMCKB	HMVKLSDMBF	9290943198 Dell Way	\N	AFYQOPV	\N	0	Canada	2	HMVKLSDMBF@dell.com	9290943198	3	5290864470880479	2011/07	user12519	password	29	20000	F
12520	EOIPPQ	BKBMDEZEJZ	9713863794 Dell Way	\N	JIQYXLB	\N	0	South Africa	2	BKBMDEZEJZ@dell.com	9713863794	3	4786197016946972	2010/09	user12520	password	54	80000	M
12521	BCLQSN	BTAEXZJHYT	3141346336 Dell Way	\N	QORNZSI	\N	0	UK	2	BTAEXZJHYT@dell.com	3141346336	4	5314685043413192	2012/03	user12521	password	35	80000	F
12522	IGYATZ	TTERSNZRHP	2761103880 Dell Way	\N	FYCFRLE	\N	0	South Africa	2	TTERSNZRHP@dell.com	2761103880	4	8324116798117758	2010/11	user12522	password	61	80000	F
12523	VRFPQZ	JUQBIQTPFZ	1256112969 Dell Way	\N	OIFFTJC	\N	0	UK	2	JUQBIQTPFZ@dell.com	1256112969	5	4671619095373899	2012/07	user12523	password	28	20000	F
12524	VJYLIH	GZJPQDFVCT	9399984361 Dell Way	\N	EHYYRAX	\N	0	Japan	2	GZJPQDFVCT@dell.com	9399984361	2	6560889307875187	2010/06	user12524	password	73	80000	F
12525	DTSLBZ	LLOBOTXRMC	2959350554 Dell Way	\N	YLAQLXI	\N	0	China	2	LLOBOTXRMC@dell.com	2959350554	5	8437544500455261	2011/09	user12525	password	63	100000	M
12526	JQGLPS	WEUKXSBKUA	9004445041 Dell Way	\N	VUQHSYR	\N	0	UK	2	WEUKXSBKUA@dell.com	9004445041	3	6429938591551036	2010/02	user12526	password	56	40000	F
12527	EQXTJU	YDEWWGGQHC	6107820028 Dell Way	\N	LYKEXBC	\N	0	Russia	2	YDEWWGGQHC@dell.com	6107820028	4	4218054550234228	2011/03	user12527	password	71	20000	F
12528	JCDSWC	WBYSIFJPHU	7911897532 Dell Way	\N	OSYLTBF	\N	0	China	2	WBYSIFJPHU@dell.com	7911897532	3	1194075453560799	2012/04	user12528	password	32	40000	M
12529	HOKEQH	GOZOTIEBDS	9844352605 Dell Way	\N	TCENEKW	\N	0	UK	2	GOZOTIEBDS@dell.com	9844352605	5	9369119470007720	2009/01	user12529	password	41	100000	F
12530	WKOMRU	ARJUAOWDGP	8649488549 Dell Way	\N	GLDKVZI	\N	0	South Africa	2	ARJUAOWDGP@dell.com	8649488549	2	2082738205324858	2012/08	user12530	password	25	40000	F
12531	NWXERY	VATWPPZWFG	3289043223 Dell Way	\N	HIQDIZY	\N	0	Canada	2	VATWPPZWFG@dell.com	3289043223	1	1776622648350894	2012/03	user12531	password	46	40000	M
12532	GFWYES	ZXOONOKSUR	8379697998 Dell Way	\N	BLVJLTN	\N	0	Japan	2	ZXOONOKSUR@dell.com	8379697998	4	5688581451307983	2012/12	user12532	password	76	80000	F
12533	ANFEGE	CUTPJDIDVJ	8481496237 Dell Way	\N	PQSAKGS	\N	0	Chile	2	CUTPJDIDVJ@dell.com	8481496237	2	2990907271858305	2012/01	user12533	password	83	20000	F
12534	LHFRMH	MGXVJFZFPP	5750523028 Dell Way	\N	WHPHNHN	\N	0	China	2	MGXVJFZFPP@dell.com	5750523028	4	2671500816009939	2010/08	user12534	password	38	60000	F
12535	PUSBCF	HABRFAXUQT	3536816442 Dell Way	\N	CFBQNOZ	\N	0	Australia	2	HABRFAXUQT@dell.com	3536816442	1	6571281769778580	2012/06	user12535	password	33	100000	F
12536	ARCDXK	DYCJZZEPTH	1578358569 Dell Way	\N	VUXJJXL	\N	0	Japan	2	DYCJZZEPTH@dell.com	1578358569	1	5865610418841243	2010/04	user12536	password	54	60000	F
12537	ERKBBO	ADXZDCOXJK	2970805510 Dell Way	\N	SHTBEER	\N	0	Chile	2	ADXZDCOXJK@dell.com	2970805510	2	7833022105507553	2010/09	user12537	password	40	80000	M
12538	ZEZASZ	EQYISNFCXX	8802563626 Dell Way	\N	JQYOVQU	\N	0	Australia	2	EQYISNFCXX@dell.com	8802563626	3	5610519575886429	2010/11	user12538	password	37	60000	M
12539	KMWDLB	TJJMXOOUMY	8863686597 Dell Way	\N	LLNGBIH	\N	0	UK	2	TJJMXOOUMY@dell.com	8863686597	4	5714826145675034	2011/01	user12539	password	19	60000	F
12540	MLPXMI	HVUEKJZWHK	7287234664 Dell Way	\N	HVQJDXH	\N	0	UK	2	HVUEKJZWHK@dell.com	7287234664	5	7639702431391925	2011/11	user12540	password	41	40000	F
12541	TVGGEO	CZSNIRKQCS	2905495783 Dell Way	\N	LSBOPJO	\N	0	China	2	CZSNIRKQCS@dell.com	2905495783	2	1590727676637470	2008/08	user12541	password	39	40000	F
12542	CQQHET	GXGOPQFRIQ	1233958451 Dell Way	\N	KKFAUTI	\N	0	UK	2	GXGOPQFRIQ@dell.com	1233958451	2	1520325771067291	2011/09	user12542	password	50	20000	M
12543	CQBHJH	EPWUGBMPSW	6136283957 Dell Way	\N	ZXWUQET	\N	0	Japan	2	EPWUGBMPSW@dell.com	6136283957	5	3752365104388446	2009/04	user12543	password	40	20000	F
12544	YCQIKV	YHQEICTBZT	2061560656 Dell Way	\N	ZVNPAHH	\N	0	Germany	2	YHQEICTBZT@dell.com	2061560656	3	8526509140618146	2009/11	user12544	password	81	80000	M
12545	ZKEJFD	QVIZYBBXVA	5423089110 Dell Way	\N	SJQTQXI	\N	0	Russia	2	QVIZYBBXVA@dell.com	5423089110	1	2383048183750361	2009/01	user12545	password	84	40000	F
12546	HLJNOA	JWAHYBETBX	2599557780 Dell Way	\N	DRRTPAN	\N	0	Australia	2	JWAHYBETBX@dell.com	2599557780	4	5262082058936358	2009/08	user12546	password	70	40000	M
12547	EPKSQU	OQBNSGHUEK	4141714409 Dell Way	\N	MVEBVRD	\N	0	Australia	2	OQBNSGHUEK@dell.com	4141714409	4	3182070445735007	2012/04	user12547	password	52	100000	F
12548	CGFSAU	JBHCIOWNYI	2020850779 Dell Way	\N	JCJEUNF	\N	0	Canada	2	JBHCIOWNYI@dell.com	2020850779	3	1631133210845291	2010/12	user12548	password	83	100000	F
12549	DDTDXD	FEFOTCBSLK	3244865828 Dell Way	\N	VUPPIUT	\N	0	France	2	FEFOTCBSLK@dell.com	3244865828	5	8828323339577765	2008/09	user12549	password	76	20000	M
12550	XYYVCE	ZHSTKTLVDG	4493902950 Dell Way	\N	QTVYNPJ	\N	0	Russia	2	ZHSTKTLVDG@dell.com	4493902950	2	9608025109395386	2008/01	user12550	password	29	100000	M
12551	CWTEAT	MSMXMYSQEI	9119467899 Dell Way	\N	JAHWPRR	\N	0	UK	2	MSMXMYSQEI@dell.com	9119467899	4	1634368210565298	2012/10	user12551	password	89	100000	M
12552	VRBWLO	PXLBVESANB	2826110099 Dell Way	\N	AVYQMPP	\N	0	China	2	PXLBVESANB@dell.com	2826110099	4	3800328604876995	2012/08	user12552	password	33	100000	M
12553	WXJHMZ	FYBBCTBQUC	1138741821 Dell Way	\N	LSSXHIH	\N	0	Germany	2	FYBBCTBQUC@dell.com	1138741821	3	5343132422305644	2011/10	user12553	password	42	20000	M
12554	GOZTNE	ROGUIILCLW	7012132208 Dell Way	\N	VEUDMBQ	\N	0	Germany	2	ROGUIILCLW@dell.com	7012132208	1	2644548190291971	2010/06	user12554	password	44	20000	M
12555	XDLLIC	AOXIWILHFG	2161145897 Dell Way	\N	MZJYBAM	\N	0	Russia	2	AOXIWILHFG@dell.com	2161145897	4	2795522087253630	2010/01	user12555	password	43	40000	M
12556	MSJUVJ	ITSFCDNHKZ	1451168544 Dell Way	\N	HTYIUKB	\N	0	UK	2	ITSFCDNHKZ@dell.com	1451168544	2	5415995694696903	2008/08	user12556	password	74	100000	F
12557	NJVISE	CLKEPXLZXS	4225066863 Dell Way	\N	TVBNFCL	\N	0	Chile	2	CLKEPXLZXS@dell.com	4225066863	5	4020732073113322	2012/09	user12557	password	41	20000	F
12558	RWOKBQ	VLUKIGKFYD	9989747545 Dell Way	\N	BAQHCCO	\N	0	France	2	VLUKIGKFYD@dell.com	9989747545	5	4827503723092377	2011/03	user12558	password	51	100000	M
12559	ILGJBC	VWNDCXJBAK	2094281456 Dell Way	\N	BRRETGQ	\N	0	Russia	2	VWNDCXJBAK@dell.com	2094281456	1	5065663507208228	2009/07	user12559	password	43	20000	M
12560	UMFWOA	SCEVZOWAZY	8308884600 Dell Way	\N	SRDMXTF	\N	0	Australia	2	SCEVZOWAZY@dell.com	8308884600	4	4093490886036307	2009/01	user12560	password	57	20000	M
12561	AKROLJ	RQEREBSDAK	7977718958 Dell Way	\N	VDWSWCS	\N	0	Japan	2	RQEREBSDAK@dell.com	7977718958	1	1153752954676747	2011/08	user12561	password	32	80000	M
12562	PGFAQW	RVNVWFZXQU	3793869866 Dell Way	\N	ANNXQGP	\N	0	China	2	RVNVWFZXQU@dell.com	3793869866	3	2698172446805984	2012/10	user12562	password	75	60000	F
12563	BTKRPB	MDXJJXGZRH	4036307908 Dell Way	\N	NFEDLTN	\N	0	Russia	2	MDXJJXGZRH@dell.com	4036307908	4	7057249415665866	2008/06	user12563	password	33	60000	M
12564	YXFNZS	RXCAUJZMQM	8342072020 Dell Way	\N	RUPDODW	\N	0	South Africa	2	RXCAUJZMQM@dell.com	8342072020	3	1057448407635092	2009/10	user12564	password	55	100000	M
12565	LBGKUX	HXXCGXOWJG	7799617761 Dell Way	\N	RZJFCFC	\N	0	UK	2	HXXCGXOWJG@dell.com	7799617761	1	3105406089220196	2010/08	user12565	password	23	40000	F
12566	DLMYIU	VFWBDKYNRQ	1811033822 Dell Way	\N	MAWPFZO	\N	0	UK	2	VFWBDKYNRQ@dell.com	1811033822	4	5358513964805752	2011/11	user12566	password	68	80000	F
12567	DGYLAU	RWWUHUIYLV	7672031574 Dell Way	\N	ZHLEHZE	\N	0	China	2	RWWUHUIYLV@dell.com	7672031574	4	1745165566913783	2010/05	user12567	password	80	80000	F
12568	COXDIP	AEKIZSGKNF	3005525830 Dell Way	\N	SYKZXOJ	\N	0	Japan	2	AEKIZSGKNF@dell.com	3005525830	3	3313591831363738	2010/04	user12568	password	80	20000	F
12569	KYNTNN	XYVXRCHEIA	7978891456 Dell Way	\N	DTZBIIS	\N	0	Germany	2	XYVXRCHEIA@dell.com	7978891456	5	1879936800803989	2008/10	user12569	password	26	60000	F
12570	BZZOMX	NIUELCJTCM	2996410024 Dell Way	\N	MCOVKGJ	\N	0	Canada	2	NIUELCJTCM@dell.com	2996410024	3	3369025459978729	2008/07	user12570	password	70	40000	M
12571	SHEFES	NZWYBFSDSE	8214388029 Dell Way	\N	FGAQMJV	\N	0	Russia	2	NZWYBFSDSE@dell.com	8214388029	1	7920837607700378	2009/10	user12571	password	22	100000	M
12572	JESNWG	NSEOYWSQBY	5635003580 Dell Way	\N	XBOJKKC	\N	0	Chile	2	NSEOYWSQBY@dell.com	5635003580	5	6277150909416378	2009/12	user12572	password	58	100000	F
12573	SPVOVI	HZXGWPWYNT	1934150397 Dell Way	\N	ACDLNGQ	\N	0	Australia	2	HZXGWPWYNT@dell.com	1934150397	2	4233252772130072	2008/10	user12573	password	34	40000	M
12574	UDCQMK	QJQMZNLMHL	7897136217 Dell Way	\N	PLWCRNC	\N	0	Russia	2	QJQMZNLMHL@dell.com	7897136217	3	8294979043770582	2010/09	user12574	password	27	20000	F
12575	HECTOS	CFFBSQOACD	7905055611 Dell Way	\N	LZFCMIW	\N	0	Chile	2	CFFBSQOACD@dell.com	7905055611	4	8475003783125431	2010/10	user12575	password	84	100000	F
12576	CAVRTY	WZAPPOPSRA	7380799658 Dell Way	\N	RXDEFAL	\N	0	UK	2	WZAPPOPSRA@dell.com	7380799658	2	4842998215928674	2010/03	user12576	password	44	80000	F
12577	KMYDKU	CKJSZYLRZC	1087236870 Dell Way	\N	OCHUDTT	\N	0	South Africa	2	CKJSZYLRZC@dell.com	1087236870	1	4306835065130144	2008/07	user12577	password	90	60000	M
12578	LKCWFF	HOXGNJXNMM	2782216151 Dell Way	\N	QTGTMAP	\N	0	Germany	2	HOXGNJXNMM@dell.com	2782216151	5	7274955361150206	2011/12	user12578	password	30	80000	F
12579	OTGUYN	IWUWGRJSEA	3542173903 Dell Way	\N	LKTYLIL	\N	0	Japan	2	IWUWGRJSEA@dell.com	3542173903	1	4319917510263622	2009/04	user12579	password	21	80000	M
12580	VWRTKA	QEWWWGOAGA	6052904070 Dell Way	\N	LAZWJKN	\N	0	Japan	2	QEWWWGOAGA@dell.com	6052904070	5	8689754910767079	2012/12	user12580	password	53	80000	M
12581	JKMUKD	ZHAVOPWVQI	6163804901 Dell Way	\N	VPFEASU	\N	0	Germany	2	ZHAVOPWVQI@dell.com	6163804901	4	5075738165061921	2010/02	user12581	password	33	40000	F
12582	QSHBWG	IWBXMYSCGN	2199328755 Dell Way	\N	SLRSEMH	\N	0	Russia	2	IWBXMYSCGN@dell.com	2199328755	4	3029168623033911	2009/12	user12582	password	50	80000	M
12583	EAQAGZ	XIWJHOMOBE	9380297529 Dell Way	\N	ATXEGEX	\N	0	China	2	XIWJHOMOBE@dell.com	9380297529	1	6747160907834769	2012/07	user12583	password	46	60000	M
12584	LCTSCR	AYBINOWPSW	1480148388 Dell Way	\N	IPBPUYY	\N	0	Russia	2	AYBINOWPSW@dell.com	1480148388	3	6487713109701872	2011/12	user12584	password	24	40000	F
12585	FDCHUD	GWMTKIIDFR	8002155944 Dell Way	\N	SGGNFEG	\N	0	Chile	2	GWMTKIIDFR@dell.com	8002155944	5	8856936294585467	2011/12	user12585	password	35	20000	F
12586	JHKELR	AXKLGSOMJH	8959546861 Dell Way	\N	TPUYUBE	\N	0	Germany	2	AXKLGSOMJH@dell.com	8959546861	1	4062179842498154	2012/04	user12586	password	56	100000	M
12587	VJVGAW	ELILDWXNEQ	8602759003 Dell Way	\N	DZPYAUN	\N	0	UK	2	ELILDWXNEQ@dell.com	8602759003	5	7472255320288242	2008/05	user12587	password	66	100000	F
12588	BQLBNP	NVARSYEWPI	6412298063 Dell Way	\N	VEGWYTT	\N	0	Russia	2	NVARSYEWPI@dell.com	6412298063	3	9472994958516212	2012/02	user12588	password	72	20000	F
12589	JPGWFU	SFLKEPGTYC	2907093441 Dell Way	\N	YEZWYSR	\N	0	Germany	2	SFLKEPGTYC@dell.com	2907093441	4	5521101512480528	2009/05	user12589	password	65	60000	M
12590	GVQLPI	RASVQZPOBN	7205702421 Dell Way	\N	SAKRTBF	\N	0	UK	2	RASVQZPOBN@dell.com	7205702421	4	4041674199514091	2008/05	user12590	password	83	80000	M
12591	SKBITS	ILOZLDNMQG	8212892501 Dell Way	\N	NBXHDCG	\N	0	South Africa	2	ILOZLDNMQG@dell.com	8212892501	4	8735168389044703	2008/06	user12591	password	65	80000	F
12592	CUNVNW	HBVSEJFVPS	9011475790 Dell Way	\N	XNAAPHV	\N	0	France	2	HBVSEJFVPS@dell.com	9011475790	4	6109523302409798	2009/04	user12592	password	41	80000	F
12593	CDFPAN	RWFWFKSUDP	1703226286 Dell Way	\N	IEPXLKI	\N	0	China	2	RWFWFKSUDP@dell.com	1703226286	5	7491943769622595	2010/03	user12593	password	42	100000	F
12594	MAYMNP	ITLODEIHTQ	8298759143 Dell Way	\N	LIOWTXF	\N	0	South Africa	2	ITLODEIHTQ@dell.com	8298759143	5	3027508901432156	2008/04	user12594	password	20	40000	M
12595	BHFPXO	JJCMNLTGCF	2696819708 Dell Way	\N	PRBIOGE	\N	0	China	2	JJCMNLTGCF@dell.com	2696819708	2	4773149951826781	2010/05	user12595	password	75	20000	F
12596	CKCZYL	JBYWNSDPXS	6387356289 Dell Way	\N	HYBWFFG	\N	0	France	2	JBYWNSDPXS@dell.com	6387356289	4	8665041313506664	2008/06	user12596	password	19	60000	M
12597	KPNJBW	LZTZRXOOQW	6430510530 Dell Way	\N	NRSTXYD	\N	0	France	2	LZTZRXOOQW@dell.com	6430510530	1	5628782950807363	2008/01	user12597	password	19	60000	F
12598	QCVRZH	QSGIQVWGRK	3729087188 Dell Way	\N	XJDVIHI	\N	0	UK	2	QSGIQVWGRK@dell.com	3729087188	5	9648193226195872	2009/11	user12598	password	56	80000	F
12599	QQDPXT	IDCYYYEQJC	1687925826 Dell Way	\N	ZNYHVGF	\N	0	Canada	2	IDCYYYEQJC@dell.com	1687925826	1	5028090817388147	2012/09	user12599	password	34	40000	F
12600	WNYTHH	WJFVIKLRNL	2265590252 Dell Way	\N	FLTARZD	\N	0	Russia	2	WJFVIKLRNL@dell.com	2265590252	3	7159500353038312	2012/10	user12600	password	23	20000	M
12601	PDKWKH	GQDOBOGOAL	2321374358 Dell Way	\N	ZULRTOL	\N	0	South Africa	2	GQDOBOGOAL@dell.com	2321374358	1	7529669751878829	2012/03	user12601	password	84	60000	M
12602	BZRMGX	CJMDYSSZES	9392412179 Dell Way	\N	TPJMEVJ	\N	0	China	2	CJMDYSSZES@dell.com	9392412179	1	3560885170008987	2008/01	user12602	password	82	100000	F
12603	WPNDNP	NZTMSLMWEF	2271976391 Dell Way	\N	MNSRIBA	\N	0	Chile	2	NZTMSLMWEF@dell.com	2271976391	2	4662325806915760	2008/03	user12603	password	42	20000	F
12604	YSFLIS	LCFENRASXN	5739917247 Dell Way	\N	FPFOQFV	\N	0	Russia	2	LCFENRASXN@dell.com	5739917247	2	9391574064735324	2011/08	user12604	password	27	80000	M
12605	VZZERK	GXOUOPMLDS	4307369365 Dell Way	\N	BJHSPDM	\N	0	Canada	2	GXOUOPMLDS@dell.com	4307369365	3	8323808595538140	2012/07	user12605	password	60	60000	F
12606	OLOGWU	DLPSABDETF	8291004726 Dell Way	\N	NAXCDKF	\N	0	Germany	2	DLPSABDETF@dell.com	8291004726	1	5204587651416660	2009/08	user12606	password	86	80000	F
12607	JHJFCN	QRFRTJWNOK	7529133532 Dell Way	\N	OLMRVSF	\N	0	Japan	2	QRFRTJWNOK@dell.com	7529133532	4	1076022872701287	2009/08	user12607	password	73	60000	M
12608	BWFEJW	VOOPXKCLUQ	2735380825 Dell Way	\N	XHITANK	\N	0	Russia	2	VOOPXKCLUQ@dell.com	2735380825	2	1509773038793355	2011/02	user12608	password	56	80000	F
12609	JZJTWF	HKUEVXQQNN	1377490383 Dell Way	\N	YWGYJQR	\N	0	Germany	2	HKUEVXQQNN@dell.com	1377490383	4	4302511985413730	2008/03	user12609	password	28	60000	M
12610	DTJZZQ	KUVFRLWFZU	1923451103 Dell Way	\N	BGSLWJZ	\N	0	UK	2	KUVFRLWFZU@dell.com	1923451103	2	2049027292989194	2009/07	user12610	password	55	100000	M
12611	HIQGZB	BVHSGDXGYZ	7834168758 Dell Way	\N	MRKJBKH	\N	0	Canada	2	BVHSGDXGYZ@dell.com	7834168758	2	5496866479981691	2009/11	user12611	password	53	100000	F
12612	VPLVQN	QYFWCDCACO	6225893186 Dell Way	\N	RNXSXFW	\N	0	Japan	2	QYFWCDCACO@dell.com	6225893186	2	9457146673928948	2010/11	user12612	password	81	80000	M
12613	LDMCQC	AWZCZCCCRU	7978981600 Dell Way	\N	QPNNUKF	\N	0	China	2	AWZCZCCCRU@dell.com	7978981600	1	8588349673897029	2011/01	user12613	password	56	40000	F
12614	RUNHXO	EWQEZTGQOX	7877650744 Dell Way	\N	FBLZMQJ	\N	0	Chile	2	EWQEZTGQOX@dell.com	7877650744	1	8854230285156519	2011/09	user12614	password	31	40000	F
12615	ZTRWHV	TYZTRGJFEP	2197613324 Dell Way	\N	HPPTFYZ	\N	0	UK	2	TYZTRGJFEP@dell.com	2197613324	5	7618369515519590	2012/01	user12615	password	87	40000	F
12616	SXXZTR	XTKPZUUDKC	7082846339 Dell Way	\N	SZVYXVX	\N	0	Australia	2	XTKPZUUDKC@dell.com	7082846339	4	9060994640924036	2011/08	user12616	password	26	80000	F
12617	AQHTIE	MTUMNOQXRJ	8361110533 Dell Way	\N	XMHUHEW	\N	0	UK	2	MTUMNOQXRJ@dell.com	8361110533	4	7242666019592435	2010/11	user12617	password	49	80000	M
12618	CYQKDD	DXQRMGPDQM	9086404405 Dell Way	\N	QXHYCDX	\N	0	UK	2	DXQRMGPDQM@dell.com	9086404405	4	3948354536201805	2011/01	user12618	password	18	80000	F
12619	ZINDLR	BCJOJZRZMI	7933363452 Dell Way	\N	XTGAXEY	\N	0	South Africa	2	BCJOJZRZMI@dell.com	7933363452	2	6270939990412444	2012/04	user12619	password	35	100000	F
12620	OMJAEK	CNYLNQKZZI	5593431398 Dell Way	\N	TFIRKGM	\N	0	Canada	2	CNYLNQKZZI@dell.com	5593431398	1	9744435734581204	2011/04	user12620	password	84	20000	M
12621	JKWNUY	BTKOKVOJDH	5722130802 Dell Way	\N	OLZZRLD	\N	0	Canada	2	BTKOKVOJDH@dell.com	5722130802	1	9846765646245332	2012/01	user12621	password	18	80000	F
12622	KPXFOZ	YYOJTDSWKH	5315659150 Dell Way	\N	IKGZVJF	\N	0	China	2	YYOJTDSWKH@dell.com	5315659150	1	2837168172467500	2010/03	user12622	password	84	100000	M
12623	MUVAUU	ZIDSMVPWCX	3570677294 Dell Way	\N	GIXCSCM	\N	0	Chile	2	ZIDSMVPWCX@dell.com	3570677294	4	7205949591472746	2010/08	user12623	password	59	20000	F
12624	JXDDRC	MUVYPKVSIC	4164647778 Dell Way	\N	BFFUIRZ	\N	0	Japan	2	MUVYPKVSIC@dell.com	4164647778	4	1849224996287375	2012/03	user12624	password	30	20000	M
12625	BDSTGF	NBDDMZVUBX	3776299779 Dell Way	\N	AGRIYQY	\N	0	Chile	2	NBDDMZVUBX@dell.com	3776299779	1	3059353105258196	2010/03	user12625	password	36	20000	F
12626	KVAQAN	RERDDMXFJX	3306680076 Dell Way	\N	MBGKRFR	\N	0	UK	2	RERDDMXFJX@dell.com	3306680076	5	5795450976584107	2010/03	user12626	password	65	80000	M
12627	MUENIW	SZZWMXBWVN	5787236694 Dell Way	\N	XCXPHPP	\N	0	Germany	2	SZZWMXBWVN@dell.com	5787236694	1	1217282902449369	2011/10	user12627	password	75	40000	F
12628	OLUXHM	WHJIEKFAXC	4449959238 Dell Way	\N	CVRJLGY	\N	0	UK	2	WHJIEKFAXC@dell.com	4449959238	5	7192248758859933	2008/09	user12628	password	87	60000	F
12629	KFFSSB	ZBKELPEJSG	5545576917 Dell Way	\N	FKQRQOQ	\N	0	Australia	2	ZBKELPEJSG@dell.com	5545576917	2	2702181783504784	2009/04	user12629	password	62	60000	M
12630	VTJNVJ	OFNAVSKNYP	3310312160 Dell Way	\N	XPGODXP	\N	0	Japan	2	OFNAVSKNYP@dell.com	3310312160	4	8961584552656860	2010/05	user12630	password	49	40000	F
12631	EQSZZH	FNHBFRODHM	4835265398 Dell Way	\N	SNAWLQN	\N	0	Russia	2	FNHBFRODHM@dell.com	4835265398	2	3323080862406641	2012/10	user12631	password	54	20000	F
12632	CTACAF	PHGUZVYGHR	5040610438 Dell Way	\N	UIOGZBY	\N	0	France	2	PHGUZVYGHR@dell.com	5040610438	2	3029987602028996	2009/09	user12632	password	35	40000	M
12633	ZHXZNN	HUHGQGMYYH	6930381231 Dell Way	\N	GMNGNLR	\N	0	UK	2	HUHGQGMYYH@dell.com	6930381231	5	3354551472235471	2009/02	user12633	password	58	20000	F
12634	WBCJOJ	EWQUDDSBKZ	7874039359 Dell Way	\N	OXFCJWB	\N	0	Australia	2	EWQUDDSBKZ@dell.com	7874039359	2	4516337876673788	2012/11	user12634	password	58	100000	M
12635	QCCFMG	CCBFFTHQSV	3938251882 Dell Way	\N	OYYYVZY	\N	0	Germany	2	CCBFFTHQSV@dell.com	3938251882	2	5404590665362776	2009/11	user12635	password	53	100000	M
12636	OBTBIV	DJAJCIZVEN	7893218444 Dell Way	\N	UCLQCKF	\N	0	France	2	DJAJCIZVEN@dell.com	7893218444	4	6563695363700390	2011/03	user12636	password	58	40000	M
12637	PYVXTY	HUHKCHFGVA	6289237194 Dell Way	\N	JGQLRWV	\N	0	France	2	HUHKCHFGVA@dell.com	6289237194	3	2087720257695764	2011/01	user12637	password	41	60000	M
12638	GJOAIV	UQFXXLDSLN	3141368225 Dell Way	\N	ZCYRZUD	\N	0	Germany	2	UQFXXLDSLN@dell.com	3141368225	2	4095837823115289	2009/07	user12638	password	84	100000	M
12639	HKVQGQ	GLNDWRWHEW	9090247688 Dell Way	\N	KCNJXRY	\N	0	Canada	2	GLNDWRWHEW@dell.com	9090247688	2	4463454173877835	2010/03	user12639	password	37	40000	F
12640	RDCXTI	JHMFYJNDFX	5357637234 Dell Way	\N	GTHDKFG	\N	0	China	2	JHMFYJNDFX@dell.com	5357637234	4	7992056929040701	2011/11	user12640	password	23	20000	M
12641	FFNYNW	GABEJPHPNO	6076891866 Dell Way	\N	IURTAYB	\N	0	Germany	2	GABEJPHPNO@dell.com	6076891866	5	2470887000206858	2010/11	user12641	password	39	20000	F
12642	NOBBLH	BMMLCUAPIJ	1138873031 Dell Way	\N	KACKYEX	\N	0	France	2	BMMLCUAPIJ@dell.com	1138873031	1	9642727160826326	2012/05	user12642	password	19	20000	M
12643	PCXAKZ	NXKPRKEATO	9832290003 Dell Way	\N	AWZYAXL	\N	0	Australia	2	NXKPRKEATO@dell.com	9832290003	2	9772001178003848	2009/05	user12643	password	19	40000	F
12644	DDANCN	LMCCXHDQVD	9352770530 Dell Way	\N	NVCOTNP	\N	0	Russia	2	LMCCXHDQVD@dell.com	9352770530	3	1626284321770072	2009/07	user12644	password	39	40000	M
12645	LJGNWR	AYUYFXPBBC	7976085250 Dell Way	\N	XDQQRFJ	\N	0	Germany	2	AYUYFXPBBC@dell.com	7976085250	3	9425797823816540	2009/09	user12645	password	38	20000	F
12646	QHSMYS	LSRRPGTQIQ	1626147596 Dell Way	\N	UYHLEQA	\N	0	UK	2	LSRRPGTQIQ@dell.com	1626147596	5	3666119314730167	2011/04	user12646	password	43	100000	M
12647	QQJOJV	HANXGGNPXI	7981713916 Dell Way	\N	OETSVUR	\N	0	South Africa	2	HANXGGNPXI@dell.com	7981713916	5	7061578735709191	2008/04	user12647	password	63	100000	M
12648	GHNQDU	QQRXWFNTNB	4594823000 Dell Way	\N	YHUTCLQ	\N	0	South Africa	2	QQRXWFNTNB@dell.com	4594823000	2	9034814181271940	2011/11	user12648	password	77	80000	F
12649	CDUGXL	WPJTUWMIYL	1712764289 Dell Way	\N	PSERDUO	\N	0	Germany	2	WPJTUWMIYL@dell.com	1712764289	3	3167788214981556	2012/03	user12649	password	82	20000	F
12650	AZPYKM	NUFIQSQODF	8943202934 Dell Way	\N	GHXKCLY	\N	0	Canada	2	NUFIQSQODF@dell.com	8943202934	1	2437740726396441	2008/01	user12650	password	41	60000	F
12651	HCASOO	MUWDMMRQSY	5146446140 Dell Way	\N	YQJABHE	\N	0	UK	2	MUWDMMRQSY@dell.com	5146446140	2	1740527172572910	2010/09	user12651	password	59	60000	M
12652	RPRFED	AAGMNYDGXB	6432375101 Dell Way	\N	WGBYNGW	\N	0	UK	2	AAGMNYDGXB@dell.com	6432375101	5	5623446553479881	2009/07	user12652	password	25	40000	F
12653	SXLWBL	XHXKGBRDCN	3705223646 Dell Way	\N	KELYLIY	\N	0	Australia	2	XHXKGBRDCN@dell.com	3705223646	3	3750355819705874	2012/07	user12653	password	57	20000	F
12654	LMDMXB	UVMBWDEYQP	9367565595 Dell Way	\N	CCNOLMO	\N	0	Russia	2	UVMBWDEYQP@dell.com	9367565595	5	6081599675118924	2010/06	user12654	password	61	80000	M
12655	BXIYZD	TLEPOJOFYR	6962381292 Dell Way	\N	HMFSZUL	\N	0	UK	2	TLEPOJOFYR@dell.com	6962381292	1	4514440963976085	2008/08	user12655	password	29	100000	M
12656	BHQAKJ	LPZAYOFXFM	6673053195 Dell Way	\N	KLFJFQH	\N	0	South Africa	2	LPZAYOFXFM@dell.com	6673053195	4	9633517758455128	2009/10	user12656	password	83	100000	M
12657	ENXPXJ	FXJDLPBRBL	7826305451 Dell Way	\N	CGVHXCE	\N	0	Germany	2	FXJDLPBRBL@dell.com	7826305451	1	7803057585377247	2010/01	user12657	password	65	60000	F
12658	EJVCTB	ZDEKSGCURE	8224191541 Dell Way	\N	BMMYPRM	\N	0	China	2	ZDEKSGCURE@dell.com	8224191541	2	9357993222773076	2012/11	user12658	password	46	20000	F
12659	UYDNZC	RDNKJPEBUF	8733598181 Dell Way	\N	OGEDXQN	\N	0	Russia	2	RDNKJPEBUF@dell.com	8733598181	3	6155049307737500	2011/10	user12659	password	65	80000	M
12660	PYDOBU	SPECFJDZPS	8146670038 Dell Way	\N	GTWEKJX	\N	0	Chile	2	SPECFJDZPS@dell.com	8146670038	3	9926087799482048	2011/02	user12660	password	75	40000	M
12661	SJGTDY	JIBORENGXT	3379382219 Dell Way	\N	ATXKCUR	\N	0	UK	2	JIBORENGXT@dell.com	3379382219	4	5733273989520968	2009/06	user12661	password	72	20000	F
12662	CIYGHH	OIVGNINKCN	3678105411 Dell Way	\N	EAYHVQE	\N	0	Australia	2	OIVGNINKCN@dell.com	3678105411	4	5211661747191102	2011/06	user12662	password	58	100000	M
12663	WWUEDI	MZOAICKKQP	7571784062 Dell Way	\N	LOWGFAJ	\N	0	Germany	2	MZOAICKKQP@dell.com	7571784062	5	3302316960413009	2008/05	user12663	password	31	80000	F
12664	BMKEVX	EKXMMIXCXI	7917341063 Dell Way	\N	RUPWUYK	\N	0	Germany	2	EKXMMIXCXI@dell.com	7917341063	4	7358408028259874	2008/10	user12664	password	48	40000	M
12665	XUBTSF	DQSQZPSXYK	3742784220 Dell Way	\N	ROHLNRZ	\N	0	Chile	2	DQSQZPSXYK@dell.com	3742784220	4	4703429474029690	2008/02	user12665	password	75	100000	F
12666	PBUHHX	XZNWPGUOQL	6245242927 Dell Way	\N	CXXPOXX	\N	0	South Africa	2	XZNWPGUOQL@dell.com	6245242927	2	9987966462038458	2011/02	user12666	password	90	80000	M
12667	BNZILW	HYTWFNLVZN	4112614131 Dell Way	\N	TWDHTBE	\N	0	China	2	HYTWFNLVZN@dell.com	4112614131	1	1395811191294342	2010/02	user12667	password	75	20000	F
12668	HCNSYV	RSSWGDSFRL	1901736928 Dell Way	\N	CVTWWYF	\N	0	Canada	2	RSSWGDSFRL@dell.com	1901736928	2	6753122444264591	2009/01	user12668	password	73	60000	F
12669	VZBUUT	NMPUPIZHUC	4540768530 Dell Way	\N	CNYYLDD	\N	0	Germany	2	NMPUPIZHUC@dell.com	4540768530	4	8416072830557824	2010/07	user12669	password	39	80000	F
12670	HUEBNR	ODLEMLLGON	4442667879 Dell Way	\N	UMMGQPU	\N	0	Australia	2	ODLEMLLGON@dell.com	4442667879	4	5165547478944063	2012/11	user12670	password	32	40000	F
12671	ZLGNDV	RPZDALJPZE	8332999712 Dell Way	\N	CLKTBFU	\N	0	France	2	RPZDALJPZE@dell.com	8332999712	2	4124964379239827	2011/06	user12671	password	64	100000	F
12672	CEZFAQ	UATVLDKLHN	3241857965 Dell Way	\N	WSGYXAJ	\N	0	Russia	2	UATVLDKLHN@dell.com	3241857965	4	4871887916233391	2011/05	user12672	password	43	20000	F
12673	OCQOSL	OMHAQSLYFI	3937893887 Dell Way	\N	QLGNLQF	\N	0	Russia	2	OMHAQSLYFI@dell.com	3937893887	4	4607448393013328	2011/12	user12673	password	57	20000	M
12674	QSCJER	WMRMEDKKMB	4644670425 Dell Way	\N	VTOHJTA	\N	0	Japan	2	WMRMEDKKMB@dell.com	4644670425	3	4273183697834611	2009/12	user12674	password	50	100000	M
12675	EAYJRU	VJHANSKATG	9501430221 Dell Way	\N	TINDCNV	\N	0	France	2	VJHANSKATG@dell.com	9501430221	1	8981588375288994	2012/08	user12675	password	77	60000	M
12676	VKENFA	XNAKGKKZQE	4029775237 Dell Way	\N	IEIKSDX	\N	0	Japan	2	XNAKGKKZQE@dell.com	4029775237	4	5946926563978196	2012/08	user12676	password	19	100000	F
12677	LZZQAW	EAHKLSKCWS	8032406199 Dell Way	\N	HECZIAQ	\N	0	Japan	2	EAHKLSKCWS@dell.com	8032406199	2	6827042142394931	2009/03	user12677	password	51	100000	M
12678	LUHMQL	MXVYPGAMYH	2230686268 Dell Way	\N	RBHZBYR	\N	0	South Africa	2	MXVYPGAMYH@dell.com	2230686268	2	3046664374880493	2009/10	user12678	password	21	100000	F
12679	VHRLTE	JPCZVDLULC	1598887518 Dell Way	\N	VSCXRTT	\N	0	Russia	2	JPCZVDLULC@dell.com	1598887518	5	2355495610740036	2012/01	user12679	password	28	20000	M
12680	LSIEXR	TAQPECJPFF	8557114788 Dell Way	\N	IICZBWU	\N	0	Canada	2	TAQPECJPFF@dell.com	8557114788	5	9744706834666432	2012/01	user12680	password	19	80000	M
12681	TARQSL	RJAVLJKROT	4907559632 Dell Way	\N	ZRSBNNF	\N	0	China	2	RJAVLJKROT@dell.com	4907559632	1	3154625596944243	2010/03	user12681	password	87	20000	M
12682	ZSOREG	AEBMOMDDFD	5815529217 Dell Way	\N	VYEJLJS	\N	0	South Africa	2	AEBMOMDDFD@dell.com	5815529217	5	4478676657192409	2011/12	user12682	password	48	80000	M
12683	DFPHLQ	MNDBZGEEKA	1572707364 Dell Way	\N	DOJOYCL	\N	0	France	2	MNDBZGEEKA@dell.com	1572707364	5	2629100372083485	2012/03	user12683	password	78	100000	F
12684	BMRMCD	ZFEZMJEWJH	2038703063 Dell Way	\N	LTWJWHV	\N	0	UK	2	ZFEZMJEWJH@dell.com	2038703063	1	9100888589862736	2009/10	user12684	password	75	80000	M
12685	HJJKNJ	PSICBMZLTK	6411419560 Dell Way	\N	FPUBXPZ	\N	0	Australia	2	PSICBMZLTK@dell.com	6411419560	5	4314635817427188	2010/08	user12685	password	24	40000	M
12686	MRIZAY	RIATUAFOKK	3534575415 Dell Way	\N	EELBUKB	\N	0	China	2	RIATUAFOKK@dell.com	3534575415	3	8249270908068866	2012/07	user12686	password	25	100000	F
12687	TEZTDR	CDKWDPLOAP	2454053812 Dell Way	\N	SLQNWSW	\N	0	Canada	2	CDKWDPLOAP@dell.com	2454053812	4	1856382760219276	2011/10	user12687	password	88	80000	M
12688	ERIHJK	KTHOJSCKIV	9010271411 Dell Way	\N	VZISSFW	\N	0	South Africa	2	KTHOJSCKIV@dell.com	9010271411	5	5916981883812696	2011/12	user12688	password	35	40000	F
12689	YOJHYU	BGILZLVHHR	3008455054 Dell Way	\N	GPJYVGV	\N	0	Russia	2	BGILZLVHHR@dell.com	3008455054	2	4497213449794799	2008/08	user12689	password	62	40000	M
12690	EPUDKW	JSHIECQLTX	1029406071 Dell Way	\N	BDVWJQP	\N	0	Japan	2	JSHIECQLTX@dell.com	1029406071	5	7847296553663910	2010/08	user12690	password	18	20000	M
12691	QXWATG	TBOXDFJWCK	8603508588 Dell Way	\N	AYHJOWZ	\N	0	Germany	2	TBOXDFJWCK@dell.com	8603508588	4	2587113826535642	2010/10	user12691	password	39	20000	F
12692	FBKZHD	AWBDBKADVA	2145997887 Dell Way	\N	BCKQZKF	\N	0	South Africa	2	AWBDBKADVA@dell.com	2145997887	2	3209514003712684	2012/09	user12692	password	49	40000	M
12693	MRXUVX	QWBSHCWCDY	2673223288 Dell Way	\N	ENODYUY	\N	0	Australia	2	QWBSHCWCDY@dell.com	2673223288	2	9378990045282992	2012/08	user12693	password	32	80000	F
12694	WRYRPP	NRHUTDXXBC	4578972628 Dell Way	\N	KQGILFK	\N	0	Japan	2	NRHUTDXXBC@dell.com	4578972628	2	5464801957830787	2008/07	user12694	password	38	20000	F
12695	YCAORO	FZJZDGWFJH	4069989383 Dell Way	\N	VPQHUAX	\N	0	Canada	2	FZJZDGWFJH@dell.com	4069989383	2	2923256969079375	2012/08	user12695	password	46	40000	M
12696	MHEEVK	DFJGMFLVMH	8502849567 Dell Way	\N	KCOFDLJ	\N	0	France	2	DFJGMFLVMH@dell.com	8502849567	3	3935672192834318	2010/12	user12696	password	58	20000	F
12697	VHQRST	WBAJHMETUP	7663108615 Dell Way	\N	WIUAUEM	\N	0	Japan	2	WBAJHMETUP@dell.com	7663108615	4	2122550548054278	2011/05	user12697	password	36	20000	F
12698	OUVGOS	IPBPBGJVVF	5361174213 Dell Way	\N	EQFZURP	\N	0	Germany	2	IPBPBGJVVF@dell.com	5361174213	4	3179118138272315	2012/12	user12698	password	48	20000	M
12699	FWUTPC	JQRKXAGTGL	7756715216 Dell Way	\N	JMKEEAS	\N	0	Japan	2	JQRKXAGTGL@dell.com	7756715216	5	5380079922731966	2011/05	user12699	password	54	40000	M
12700	JBIYDR	PVCMWJFCUP	4556922096 Dell Way	\N	OFTTGLK	\N	0	UK	2	PVCMWJFCUP@dell.com	4556922096	5	7481671479064972	2011/05	user12700	password	89	40000	M
12701	AQREHH	ZJTVSZYNPN	5588174851 Dell Way	\N	SJGZVQZ	\N	0	Chile	2	ZJTVSZYNPN@dell.com	5588174851	4	9527796453330668	2012/08	user12701	password	35	80000	M
12702	WIWDPW	NJRGJQTYDM	1906109507 Dell Way	\N	HJLCAKH	\N	0	Germany	2	NJRGJQTYDM@dell.com	1906109507	2	4732192624360323	2011/06	user12702	password	21	60000	F
12703	JINZEA	IWGRMAQQMX	6172628518 Dell Way	\N	ZYAAJIO	\N	0	France	2	IWGRMAQQMX@dell.com	6172628518	5	3008243319112807	2008/01	user12703	password	67	60000	F
12704	AYIEYR	AFINFZDSWD	6864463584 Dell Way	\N	RXDAFSM	\N	0	Russia	2	AFINFZDSWD@dell.com	6864463584	4	8822016565129162	2011/05	user12704	password	39	20000	F
12705	GJOFAP	KJCQIFJFJA	2727117132 Dell Way	\N	DNAIFMD	\N	0	South Africa	2	KJCQIFJFJA@dell.com	2727117132	1	5638886010739953	2010/04	user12705	password	57	100000	M
12706	XMTYBE	HEUQKEWTEZ	5229394317 Dell Way	\N	HFIMSMI	\N	0	UK	2	HEUQKEWTEZ@dell.com	5229394317	5	5238660661969334	2011/05	user12706	password	48	40000	F
12707	XBGZGN	DAENFAHKAO	3148935307 Dell Way	\N	PIBIUJF	\N	0	Chile	2	DAENFAHKAO@dell.com	3148935307	4	1422968674916774	2011/02	user12707	password	45	100000	F
12708	LEZRSD	SWRXXYHYNX	2209005956 Dell Way	\N	GOFBYLI	\N	0	Canada	2	SWRXXYHYNX@dell.com	2209005956	2	8361171213909984	2009/09	user12708	password	73	40000	F
12709	YFWQJO	NAMKYUIMSP	4269055103 Dell Way	\N	AYRZJZE	\N	0	Germany	2	NAMKYUIMSP@dell.com	4269055103	5	7755060699768365	2008/09	user12709	password	90	40000	M
12710	FEHOTU	PGFOAOATEB	2360706191 Dell Way	\N	RVABVEO	\N	0	Canada	2	PGFOAOATEB@dell.com	2360706191	2	3551057237666100	2012/04	user12710	password	60	60000	M
12711	TVDMQS	SVGTKGNOHE	2186337225 Dell Way	\N	JIGENVJ	\N	0	Japan	2	SVGTKGNOHE@dell.com	2186337225	4	5820227769203485	2010/03	user12711	password	23	100000	M
12712	XCLNVE	JBYTILHQPQ	8290444693 Dell Way	\N	YWVMRED	\N	0	Russia	2	JBYTILHQPQ@dell.com	8290444693	4	3223533004987985	2008/09	user12712	password	35	100000	M
12713	JLDEPM	GOFOZMFPDE	4487512419 Dell Way	\N	LZQCDTX	\N	0	UK	2	GOFOZMFPDE@dell.com	4487512419	1	9838614702224732	2008/05	user12713	password	89	80000	M
12714	KWXAJD	OOSNBXDFBO	7429011317 Dell Way	\N	ERRIKOH	\N	0	South Africa	2	OOSNBXDFBO@dell.com	7429011317	2	9293338276911528	2008/03	user12714	password	65	100000	M
12715	NTRXXG	MQUNNXTPLY	8506728544 Dell Way	\N	HDHSRON	\N	0	France	2	MQUNNXTPLY@dell.com	8506728544	3	5557775582652540	2008/02	user12715	password	43	80000	M
12716	CKNARZ	QLNEIHUUFC	7853989134 Dell Way	\N	YMUQBIA	\N	0	South Africa	2	QLNEIHUUFC@dell.com	7853989134	3	9747318040579558	2012/11	user12716	password	69	60000	M
12717	DAAUZR	FNWOUQJZTH	5109635021 Dell Way	\N	MNXOWYL	\N	0	Japan	2	FNWOUQJZTH@dell.com	5109635021	3	5289243469480425	2009/02	user12717	password	88	40000	F
12718	ZIAYAG	MWVGNEGGMT	2609805956 Dell Way	\N	UKHQITG	\N	0	Russia	2	MWVGNEGGMT@dell.com	2609805956	4	2010735616087913	2009/09	user12718	password	49	60000	M
12719	UPQUVC	QQJEVPKHIF	8608096352 Dell Way	\N	RQWAKCU	\N	0	Germany	2	QQJEVPKHIF@dell.com	8608096352	5	8882130711339415	2010/05	user12719	password	49	40000	F
12720	AWXVYO	MHSIXDPFJH	1043499772 Dell Way	\N	WFIGICV	\N	0	Canada	2	MHSIXDPFJH@dell.com	1043499772	4	7420232669450343	2009/02	user12720	password	86	60000	F
12721	UJZTYM	BRUYUKEESB	8292917740 Dell Way	\N	JAHSDCW	\N	0	Canada	2	BRUYUKEESB@dell.com	8292917740	3	5212185993324965	2012/07	user12721	password	85	20000	F
12722	HBBFOC	WIBRTFWLGF	4179751788 Dell Way	\N	LOXORUS	\N	0	France	2	WIBRTFWLGF@dell.com	4179751788	1	4730338362976909	2012/02	user12722	password	54	20000	F
12723	OFQDHN	LJFEOBQVGC	5694117639 Dell Way	\N	JERBYJN	\N	0	China	2	LJFEOBQVGC@dell.com	5694117639	5	2587904072366655	2011/06	user12723	password	42	20000	M
12724	OQCWDO	FITTJKPQMY	4970631031 Dell Way	\N	VDZUMNC	\N	0	Australia	2	FITTJKPQMY@dell.com	4970631031	2	6690407443791629	2012/08	user12724	password	65	100000	F
12725	HZALOF	THZDSOUENQ	8070878330 Dell Way	\N	INKUANV	\N	0	France	2	THZDSOUENQ@dell.com	8070878330	3	4108690964523703	2010/02	user12725	password	33	60000	F
12726	EPVSUO	AUSSJNXWDF	3500152104 Dell Way	\N	KNALBVX	\N	0	South Africa	2	AUSSJNXWDF@dell.com	3500152104	2	3086668156087398	2009/06	user12726	password	76	80000	M
12727	JOJEDK	YWDHJAEMGP	2664763211 Dell Way	\N	AGACBYX	\N	0	China	2	YWDHJAEMGP@dell.com	2664763211	1	7547510364558548	2011/12	user12727	password	53	40000	F
12728	BRMECL	AFTKGYXMNY	1461871057 Dell Way	\N	SNAULXD	\N	0	Japan	2	AFTKGYXMNY@dell.com	1461871057	5	3678684541955590	2012/05	user12728	password	61	40000	F
12729	HUPJGP	OAAUZXHMVZ	8448897964 Dell Way	\N	AVUMTYD	\N	0	South Africa	2	OAAUZXHMVZ@dell.com	8448897964	3	8113477542996407	2008/01	user12729	password	25	60000	F
12730	XEREUF	EUAERHRNHR	7751951076 Dell Way	\N	JBECAIX	\N	0	South Africa	2	EUAERHRNHR@dell.com	7751951076	4	1350224961992353	2011/10	user12730	password	63	20000	M
12731	UTWPYB	JZFBGWPOOY	7128965301 Dell Way	\N	QTBQBZM	\N	0	South Africa	2	JZFBGWPOOY@dell.com	7128965301	3	6251418315805495	2010/02	user12731	password	67	20000	M
12732	KBNJCX	JIZPFODTMT	4813839343 Dell Way	\N	MOKNNXI	\N	0	Chile	2	JIZPFODTMT@dell.com	4813839343	5	7212640433106572	2010/08	user12732	password	81	60000	F
12733	YCJAZT	JYIOMMHZGU	6309475844 Dell Way	\N	NRIBORG	\N	0	UK	2	JYIOMMHZGU@dell.com	6309475844	5	6089161325246096	2008/10	user12733	password	25	20000	M
12734	EOUEID	CQSPDAPKUC	4579307678 Dell Way	\N	BDEQULP	\N	0	China	2	CQSPDAPKUC@dell.com	4579307678	1	6088413294870407	2009/04	user12734	password	73	100000	F
12735	IUQQYT	HQILQXVLAX	3866071203 Dell Way	\N	OFNJQDT	\N	0	Australia	2	HQILQXVLAX@dell.com	3866071203	2	3464261704124510	2010/01	user12735	password	37	20000	F
12736	BRAZKI	QTUGRPSSNG	6785746118 Dell Way	\N	XBPOFIP	\N	0	Germany	2	QTUGRPSSNG@dell.com	6785746118	5	2056731020566076	2011/02	user12736	password	31	20000	F
12737	WDEHLU	BFBSVTKJAI	3925057606 Dell Way	\N	KQWQZLD	\N	0	Japan	2	BFBSVTKJAI@dell.com	3925057606	2	3854518061503768	2010/06	user12737	password	47	80000	F
12738	NVPZPQ	FRJBLTLLCW	8857551547 Dell Way	\N	BYMBKPR	\N	0	Russia	2	FRJBLTLLCW@dell.com	8857551547	5	2691686898935586	2009/05	user12738	password	78	80000	M
12739	QFXGVD	XFFIYQUAMW	5932053710 Dell Way	\N	ZYXKOOD	\N	0	France	2	XFFIYQUAMW@dell.com	5932053710	2	7762713314499707	2012/02	user12739	password	44	100000	M
12740	OUAKXX	PDGOTAPFWP	4659033973 Dell Way	\N	ETZTICE	\N	0	South Africa	2	PDGOTAPFWP@dell.com	4659033973	5	8349746625404806	2010/04	user12740	password	67	40000	M
12741	MIHJGX	MNLGNBMKQQ	5787128702 Dell Way	\N	EQKMSPJ	\N	0	Canada	2	MNLGNBMKQQ@dell.com	5787128702	1	6978072877041996	2012/11	user12741	password	89	80000	F
12742	IASOXF	BJLPLYZBOD	2624442183 Dell Way	\N	RZQKOZN	\N	0	Canada	2	BJLPLYZBOD@dell.com	2624442183	1	9451345177367332	2008/03	user12742	password	65	40000	F
12743	RBBOHD	YSSJRSLFWD	3195584043 Dell Way	\N	FMNUMBW	\N	0	Japan	2	YSSJRSLFWD@dell.com	3195584043	5	7503002458717675	2010/06	user12743	password	24	100000	F
12744	EYSLCQ	EUAVNLBJPG	7670998073 Dell Way	\N	WDBJEYB	\N	0	France	2	EUAVNLBJPG@dell.com	7670998073	4	8519531210418791	2009/11	user12744	password	71	40000	F
12745	RBMUSR	PSMCEOMUVJ	6390103969 Dell Way	\N	XWTBUVM	\N	0	Germany	2	PSMCEOMUVJ@dell.com	6390103969	2	7736261901445688	2010/01	user12745	password	25	60000	M
12746	EANWRC	PEFTSRONBL	3829356602 Dell Way	\N	KUMFQZT	\N	0	Chile	2	PEFTSRONBL@dell.com	3829356602	3	7230242316611112	2009/07	user12746	password	33	20000	M
12747	FQPWTE	BYYTQMHRYS	2072212747 Dell Way	\N	MLXCKQI	\N	0	Russia	2	BYYTQMHRYS@dell.com	2072212747	1	1950954336207360	2011/03	user12747	password	34	60000	F
12748	WBIQGJ	PFDFSKXQCK	8867341543 Dell Way	\N	BANMQWF	\N	0	Russia	2	PFDFSKXQCK@dell.com	8867341543	2	5206092043779791	2008/07	user12748	password	84	60000	F
12749	YWBEGQ	KJWCUTSWET	7555887967 Dell Way	\N	XRFONLH	\N	0	France	2	KJWCUTSWET@dell.com	7555887967	4	5637470324058086	2009/09	user12749	password	22	80000	M
12750	YSVEJF	OFHIZZFDTC	7492511614 Dell Way	\N	VZQIKYT	\N	0	Canada	2	OFHIZZFDTC@dell.com	7492511614	2	4601627714466304	2010/05	user12750	password	23	20000	F
12751	UWMECA	JJIIJNLDQG	6724494221 Dell Way	\N	DGPNFJR	\N	0	UK	2	JJIIJNLDQG@dell.com	6724494221	1	4035119693726301	2012/02	user12751	password	45	40000	M
12752	GSCISM	SBUCPGFFNI	6142634472 Dell Way	\N	MDWRNNP	\N	0	Canada	2	SBUCPGFFNI@dell.com	6142634472	5	2062926579732448	2011/04	user12752	password	44	80000	M
12753	CUXUGP	WBRLIXQWGC	4039042260 Dell Way	\N	ZCUNPKQ	\N	0	Canada	2	WBRLIXQWGC@dell.com	4039042260	4	8903365487698466	2011/02	user12753	password	57	40000	F
12754	HDAOTW	PLIYIYUOBT	7140013744 Dell Way	\N	RVGGFXK	\N	0	Germany	2	PLIYIYUOBT@dell.com	7140013744	2	3062111300416291	2012/11	user12754	password	52	20000	F
12755	PBSJYH	UGGDFASHUK	4315059392 Dell Way	\N	CBQIYBX	\N	0	Japan	2	UGGDFASHUK@dell.com	4315059392	1	5128220228012651	2009/08	user12755	password	54	40000	F
12756	OBONJJ	UPNZPGGJRJ	7735931926 Dell Way	\N	KHSJJQA	\N	0	Russia	2	UPNZPGGJRJ@dell.com	7735931926	3	9506695431191476	2009/12	user12756	password	39	60000	M
12757	IDASNU	HBUWIBGZLQ	5389140822 Dell Way	\N	HDARTAK	\N	0	Germany	2	HBUWIBGZLQ@dell.com	5389140822	2	8717702015768737	2010/08	user12757	password	48	100000	M
12758	OARBUY	DPVLQBLCSS	2137869796 Dell Way	\N	FSKZTUM	\N	0	Chile	2	DPVLQBLCSS@dell.com	2137869796	2	7150870169512928	2011/10	user12758	password	65	80000	F
12759	RKKMJO	BFASGLUZEA	8708559605 Dell Way	\N	SOALJNR	\N	0	France	2	BFASGLUZEA@dell.com	8708559605	2	3144584382884204	2011/01	user12759	password	89	100000	M
12760	KJDUXF	ZXXGISFNSX	4754411419 Dell Way	\N	CTJLGBX	\N	0	Australia	2	ZXXGISFNSX@dell.com	4754411419	1	7479392816778273	2010/02	user12760	password	67	20000	M
12761	AGHYMH	VJNECSSUQU	3449305279 Dell Way	\N	NAFUBDW	\N	0	France	2	VJNECSSUQU@dell.com	3449305279	3	9328289580997080	2009/04	user12761	password	21	100000	F
12762	HFFTMB	DAGFSYAJSO	8074528343 Dell Way	\N	KYIMBFY	\N	0	China	2	DAGFSYAJSO@dell.com	8074528343	5	7582304298412056	2008/12	user12762	password	65	40000	F
12763	WOZJQD	JWJCUKMNYW	2461618576 Dell Way	\N	LHINMHV	\N	0	Chile	2	JWJCUKMNYW@dell.com	2461618576	3	3901887046173215	2008/03	user12763	password	66	40000	F
12764	FHMWLW	SUYNELADIM	4385860331 Dell Way	\N	KQZXYUE	\N	0	Australia	2	SUYNELADIM@dell.com	4385860331	3	2583333856426179	2011/03	user12764	password	53	80000	F
12765	UEGFBZ	AZMFLMITYT	4326245381 Dell Way	\N	KYRITWK	\N	0	Canada	2	AZMFLMITYT@dell.com	4326245381	3	7397766780108214	2010/01	user12765	password	48	100000	M
12766	PFBQEC	QQHBDPVCJF	5635818799 Dell Way	\N	AANTXYV	\N	0	Chile	2	QQHBDPVCJF@dell.com	5635818799	3	8216630850918592	2010/12	user12766	password	72	60000	M
12767	YNFCPW	TWYWMTYWZY	1738671482 Dell Way	\N	XMRUKNA	\N	0	UK	2	TWYWMTYWZY@dell.com	1738671482	5	5570064772851766	2008/08	user12767	password	86	80000	M
12768	LWQBTJ	YRGKLEHKDE	8392168723 Dell Way	\N	WVYHIZF	\N	0	France	2	YRGKLEHKDE@dell.com	8392168723	4	5339866380207241	2010/08	user12768	password	26	100000	F
12769	ZOESYC	KFNVKUFNZC	3856836034 Dell Way	\N	IXKRXPC	\N	0	Russia	2	KFNVKUFNZC@dell.com	3856836034	3	2172187591902911	2012/09	user12769	password	22	20000	M
12770	QGKPJU	UWQERWSQYB	5081544791 Dell Way	\N	OITMYWF	\N	0	Chile	2	UWQERWSQYB@dell.com	5081544791	2	3178500685375184	2008/05	user12770	password	42	100000	F
12771	PHQZBL	WRQNOIEMKT	7852245468 Dell Way	\N	VDGUALB	\N	0	France	2	WRQNOIEMKT@dell.com	7852245468	2	6625254239887000	2008/08	user12771	password	53	20000	F
12772	TVFVGB	NXOBGTOQNK	5671514341 Dell Way	\N	UTEUEFG	\N	0	UK	2	NXOBGTOQNK@dell.com	5671514341	5	1913971849717199	2008/05	user12772	password	39	40000	F
12773	DPYKQL	HFNNYBEMLY	8496181491 Dell Way	\N	FQSKWZJ	\N	0	China	2	HFNNYBEMLY@dell.com	8496181491	3	5812933024019003	2008/10	user12773	password	84	40000	M
12774	MGHDRO	IECHGGTSFZ	2947992350 Dell Way	\N	JXKFWTP	\N	0	Russia	2	IECHGGTSFZ@dell.com	2947992350	1	9135406474117192	2012/01	user12774	password	32	100000	M
12775	LDRDSZ	IVGOBAHGAQ	6252431260 Dell Way	\N	EKVBELU	\N	0	China	2	IVGOBAHGAQ@dell.com	6252431260	4	4225029680877924	2011/11	user12775	password	33	20000	F
12776	JWLBVT	XCIYCPFDFK	9545237722 Dell Way	\N	NBMSMGC	\N	0	Australia	2	XCIYCPFDFK@dell.com	9545237722	3	7436161646619440	2012/08	user12776	password	83	20000	F
12777	TPCPJZ	RRYUGEXMOL	7230444798 Dell Way	\N	NBDAHGC	\N	0	Chile	2	RRYUGEXMOL@dell.com	7230444798	5	1866112871561199	2009/09	user12777	password	37	40000	F
12778	WMAFLS	XKNEOKQDWD	1417893763 Dell Way	\N	EAEMGGT	\N	0	UK	2	XKNEOKQDWD@dell.com	1417893763	5	3791198646184057	2011/02	user12778	password	68	40000	M
12779	EGFQYC	ALGPWXSTAX	9590486865 Dell Way	\N	TEJALDZ	\N	0	France	2	ALGPWXSTAX@dell.com	9590486865	2	3044446221552789	2008/12	user12779	password	49	20000	F
12780	RFTQIU	BOJYMCRMZL	7072402685 Dell Way	\N	RJLCMKP	\N	0	France	2	BOJYMCRMZL@dell.com	7072402685	5	5334909343626350	2011/03	user12780	password	54	80000	M
12781	SNOAHP	PROBTGOTRG	7989933122 Dell Way	\N	CCJONYZ	\N	0	Canada	2	PROBTGOTRG@dell.com	7989933122	3	8338334219995887	2008/12	user12781	password	60	100000	M
12782	CMTKCI	CRKWXZPOGR	7438590998 Dell Way	\N	RPGEOGI	\N	0	China	2	CRKWXZPOGR@dell.com	7438590998	1	4347518966533244	2011/09	user12782	password	41	40000	M
12783	UDGXMJ	OXFLXUADMR	3712984940 Dell Way	\N	TSVIYDR	\N	0	Japan	2	OXFLXUADMR@dell.com	3712984940	1	4214373268652707	2008/05	user12783	password	72	100000	F
12784	WDBJNP	GSBDMBGZSA	9990349839 Dell Way	\N	RNIQRZH	\N	0	UK	2	GSBDMBGZSA@dell.com	9990349839	4	1185675776563584	2009/05	user12784	password	83	60000	F
12785	BNQODW	GEZTGGSYGK	9536710666 Dell Way	\N	MOAEOHE	\N	0	Germany	2	GEZTGGSYGK@dell.com	9536710666	1	8971444742754103	2009/01	user12785	password	45	80000	F
12786	XGRBCY	GCSMJLLPVX	4819777351 Dell Way	\N	EWCSEGH	\N	0	Canada	2	GCSMJLLPVX@dell.com	4819777351	1	5014907106291503	2010/07	user12786	password	22	80000	F
12787	HIMKGS	MYFVJQLFOQ	8110824213 Dell Way	\N	BRJFXQI	\N	0	China	2	MYFVJQLFOQ@dell.com	8110824213	4	8531633790116758	2009/10	user12787	password	52	80000	F
12788	UGMAZZ	ZFVJVGOKXQ	9357638127 Dell Way	\N	BGVZXEI	\N	0	Japan	2	ZFVJVGOKXQ@dell.com	9357638127	1	1037840642500668	2011/08	user12788	password	74	100000	F
12789	AJLAIK	FDTBKIMHZN	9783183592 Dell Way	\N	OUNLZVD	\N	0	South Africa	2	FDTBKIMHZN@dell.com	9783183592	1	6829677307978273	2010/11	user12789	password	55	100000	M
12790	WKYFVE	IPFTYRBXFP	3816224473 Dell Way	\N	STBROEO	\N	0	Germany	2	IPFTYRBXFP@dell.com	3816224473	2	2135545620229095	2009/09	user12790	password	26	20000	M
12791	NCUJGD	YMWWEXTKNL	8833222176 Dell Way	\N	DOCRTRF	\N	0	Australia	2	YMWWEXTKNL@dell.com	8833222176	2	3540899188257754	2010/06	user12791	password	49	20000	M
12792	NYIUCG	HYDLWWVKIY	2434410730 Dell Way	\N	ZKQSCVU	\N	0	UK	2	HYDLWWVKIY@dell.com	2434410730	1	5806261913385243	2011/07	user12792	password	69	60000	F
12793	RXVTEC	RHOODKZLIY	5856772858 Dell Way	\N	WYRYUMX	\N	0	UK	2	RHOODKZLIY@dell.com	5856772858	3	5920259505510331	2008/02	user12793	password	27	20000	M
12794	AXNEAF	MPTPZTBHRX	2478023352 Dell Way	\N	GJWBVTZ	\N	0	China	2	MPTPZTBHRX@dell.com	2478023352	3	4595117314253003	2009/08	user12794	password	53	20000	M
12795	KPWLUI	AOYZHAHYXO	1984162766 Dell Way	\N	HUPDNPM	\N	0	Japan	2	AOYZHAHYXO@dell.com	1984162766	5	9751376143191012	2011/05	user12795	password	20	60000	M
12796	QIFKRF	YQFFQNEOBM	9457662965 Dell Way	\N	IRPWGBN	\N	0	China	2	YQFFQNEOBM@dell.com	9457662965	3	2083447393961250	2009/07	user12796	password	59	20000	F
12797	XGOOLM	FRSVEWJGJS	6231547840 Dell Way	\N	XZODACN	\N	0	UK	2	FRSVEWJGJS@dell.com	6231547840	4	3414985300041735	2008/03	user12797	password	41	40000	F
12798	OVRAIW	SASWXBCHUA	3423814817 Dell Way	\N	GIDHKQG	\N	0	UK	2	SASWXBCHUA@dell.com	3423814817	3	1928710676264017	2010/11	user12798	password	46	60000	F
12799	FFLOCD	OUAMWCUQDA	1761688774 Dell Way	\N	YGHJXOI	\N	0	Canada	2	OUAMWCUQDA@dell.com	1761688774	3	6809961060062051	2012/10	user12799	password	32	40000	F
12800	LUPNYE	IYQEBLVELU	9240927866 Dell Way	\N	LTDJIMO	\N	0	France	2	IYQEBLVELU@dell.com	9240927866	1	4046270097605884	2011/05	user12800	password	67	80000	M
12801	MJJKNR	JEWKPRPBMB	2121199536 Dell Way	\N	VPKDCYO	\N	0	UK	2	JEWKPRPBMB@dell.com	2121199536	5	7633595950901509	2010/07	user12801	password	55	40000	F
12802	WRMKJV	OFGEXVGJWB	6710255639 Dell Way	\N	ZHFBFTB	\N	0	China	2	OFGEXVGJWB@dell.com	6710255639	5	8727593918796630	2009/04	user12802	password	32	40000	F
12803	WSPGOE	MUJJQPTNQT	7010705298 Dell Way	\N	UVUAOWJ	\N	0	Chile	2	MUJJQPTNQT@dell.com	7010705298	2	4773016847204417	2012/05	user12803	password	67	20000	F
12804	KUNYYZ	SIJJXDWNWQ	2905213015 Dell Way	\N	JRQYNAD	\N	0	Chile	2	SIJJXDWNWQ@dell.com	2905213015	3	2696335276123136	2011/04	user12804	password	45	100000	M
12805	ELPDLI	LURIXNWUEG	9097134628 Dell Way	\N	LUEZUIE	\N	0	Australia	2	LURIXNWUEG@dell.com	9097134628	2	6697999407071621	2008/09	user12805	password	57	80000	M
12806	ZKAKSL	EJUCWRWAXI	8781167246 Dell Way	\N	VBHQKMR	\N	0	Chile	2	EJUCWRWAXI@dell.com	8781167246	2	4946614020504058	2011/10	user12806	password	35	60000	M
12807	QOEIAJ	RULOLIPIRL	1253854851 Dell Way	\N	KZCUMTC	\N	0	China	2	RULOLIPIRL@dell.com	1253854851	3	9452648865059020	2012/10	user12807	password	51	80000	F
12808	ZVSAEK	UQYGZOPQZZ	4521557664 Dell Way	\N	QBUCVWK	\N	0	South Africa	2	UQYGZOPQZZ@dell.com	4521557664	2	7222977046389133	2008/10	user12808	password	42	60000	M
12809	EGVJQP	ZPWZDLQDLG	1956095695 Dell Way	\N	FGIADTW	\N	0	Germany	2	ZPWZDLQDLG@dell.com	1956095695	3	6941687567625195	2012/11	user12809	password	31	80000	F
12810	LNKBDK	QAKUMAYYHE	6446748104 Dell Way	\N	EQEHJBV	\N	0	France	2	QAKUMAYYHE@dell.com	6446748104	3	4535600299015641	2010/08	user12810	password	26	60000	F
12811	QYDUJU	VTPHUOFBSK	9864222317 Dell Way	\N	RXSBYNN	\N	0	Germany	2	VTPHUOFBSK@dell.com	9864222317	5	1511688433587551	2011/01	user12811	password	62	80000	M
12812	OXMYRH	RHPMVUNOEF	7197172397 Dell Way	\N	LXGKKUZ	\N	0	China	2	RHPMVUNOEF@dell.com	7197172397	1	1298828133381903	2011/08	user12812	password	74	60000	F
12813	RXDIEV	QTHLOVATAL	8564934462 Dell Way	\N	QGWBAVL	\N	0	Russia	2	QTHLOVATAL@dell.com	8564934462	3	5008754307404161	2010/03	user12813	password	80	80000	M
12814	TUFYQW	SXIGTIATTR	6263856066 Dell Way	\N	AQSBLDU	\N	0	Chile	2	SXIGTIATTR@dell.com	6263856066	2	7784607197623701	2012/01	user12814	password	48	80000	M
12815	FYTWUL	UCSNKSGEJH	3802102479 Dell Way	\N	UBIGECN	\N	0	Russia	2	UCSNKSGEJH@dell.com	3802102479	2	6276358023285866	2009/09	user12815	password	39	20000	M
12816	FYUAJO	CCBNUISDPN	6341344330 Dell Way	\N	FXUKZHE	\N	0	China	2	CCBNUISDPN@dell.com	6341344330	4	7225623003672809	2009/01	user12816	password	82	40000	F
12817	VAHFPK	HQYBZQFOEL	7737762006 Dell Way	\N	LYVLGZT	\N	0	South Africa	2	HQYBZQFOEL@dell.com	7737762006	3	2315243398305028	2011/05	user12817	password	46	20000	F
12818	KIJZTR	QRTPIYEMKP	3487659895 Dell Way	\N	LFBRFVN	\N	0	UK	2	QRTPIYEMKP@dell.com	3487659895	4	7848755109589548	2011/01	user12818	password	77	80000	F
12819	EEMXVC	POSXNWJXMV	7118029960 Dell Way	\N	DOMJJAI	\N	0	Japan	2	POSXNWJXMV@dell.com	7118029960	1	3435113049112260	2011/11	user12819	password	22	40000	F
12820	FRZBUO	PNLDKVBWRE	9515415602 Dell Way	\N	LDNUEWL	\N	0	South Africa	2	PNLDKVBWRE@dell.com	9515415602	4	6166281472891570	2012/10	user12820	password	74	100000	F
12821	LXBFMR	SYUCUVZLAK	4716602401 Dell Way	\N	OOFTKRP	\N	0	China	2	SYUCUVZLAK@dell.com	4716602401	1	2813643045257777	2008/12	user12821	password	27	40000	F
12822	BGPNYI	LSLFOLQOVF	7158110155 Dell Way	\N	CBYMTNV	\N	0	Canada	2	LSLFOLQOVF@dell.com	7158110155	1	4283214451279491	2011/03	user12822	password	59	100000	F
12823	VOSTXE	MIJATAOPGR	1356853094 Dell Way	\N	REELSZP	\N	0	France	2	MIJATAOPGR@dell.com	1356853094	5	1108415089547634	2009/07	user12823	password	90	60000	F
12824	ODCMIP	USPOSEEYVV	8138557207 Dell Way	\N	DZGVZVG	\N	0	Australia	2	USPOSEEYVV@dell.com	8138557207	2	3121433432213962	2009/03	user12824	password	66	80000	M
12825	VUHDJB	VZQNDUMZPP	9450353145 Dell Way	\N	ZWLYSRZ	\N	0	France	2	VZQNDUMZPP@dell.com	9450353145	2	8301722423173488	2008/11	user12825	password	53	20000	M
12826	HHVRJQ	QZEUTQTJFT	8768473374 Dell Way	\N	FRRYJRK	\N	0	Chile	2	QZEUTQTJFT@dell.com	8768473374	2	5307476711459458	2011/09	user12826	password	53	60000	F
12827	TFRCWH	CACWQWFWPL	1293990580 Dell Way	\N	OGJXXUE	\N	0	Russia	2	CACWQWFWPL@dell.com	1293990580	4	5648036953527481	2011/02	user12827	password	86	80000	M
12828	EKAASC	AUZRQEOGQC	8815611215 Dell Way	\N	MAAKVFF	\N	0	South Africa	2	AUZRQEOGQC@dell.com	8815611215	4	6352290140930564	2008/08	user12828	password	43	100000	M
12829	TYVMBW	HANYFCEVFR	9985121346 Dell Way	\N	WFCRKHM	\N	0	Chile	2	HANYFCEVFR@dell.com	9985121346	1	3604813048150390	2011/06	user12829	password	33	60000	F
12830	EHRGDZ	GRXMTBHYSD	4528950713 Dell Way	\N	EUUOBHV	\N	0	Australia	2	GRXMTBHYSD@dell.com	4528950713	1	7474759832955898	2012/05	user12830	password	30	20000	M
12831	LSTPRA	GPMAQUYJYC	6501172845 Dell Way	\N	DTRFAMH	\N	0	France	2	GPMAQUYJYC@dell.com	6501172845	1	3337117620743811	2012/03	user12831	password	39	60000	M
12832	AFFSFM	HRMYLKHJNL	9491554533 Dell Way	\N	CEQDRYO	\N	0	Chile	2	HRMYLKHJNL@dell.com	9491554533	5	3199431454297155	2008/02	user12832	password	69	80000	F
12833	XZWCLE	TXCFIJOWVR	2568829513 Dell Way	\N	BLUTKJA	\N	0	China	2	TXCFIJOWVR@dell.com	2568829513	2	5160825554747135	2009/12	user12833	password	34	60000	M
12834	FHYQLS	ONXXXMTSDU	8459630911 Dell Way	\N	EXNOHOX	\N	0	France	2	ONXXXMTSDU@dell.com	8459630911	2	7685522712767125	2012/08	user12834	password	31	80000	M
12835	MQLXIA	LGXJSQCVLH	2148838120 Dell Way	\N	TZWBNTM	\N	0	China	2	LGXJSQCVLH@dell.com	2148838120	2	2422553878743201	2011/05	user12835	password	78	60000	M
12836	LZUUZG	AXQTOTPZAJ	2153667202 Dell Way	\N	ZWKMQXW	\N	0	Russia	2	AXQTOTPZAJ@dell.com	2153667202	1	5274583143647760	2010/11	user12836	password	90	60000	F
12837	ZGBYNC	WDWKXMKXVJ	7403843542 Dell Way	\N	UGWKDSD	\N	0	Chile	2	WDWKXMKXVJ@dell.com	7403843542	4	8171193119604141	2010/08	user12837	password	34	100000	M
12838	LXOYAK	CXUZJFXEOR	8449252774 Dell Way	\N	KKBOCFU	\N	0	South Africa	2	CXUZJFXEOR@dell.com	8449252774	3	4282961950637400	2010/10	user12838	password	32	20000	F
12839	CPGDZI	AUIJZFOOWY	8990456487 Dell Way	\N	YYMBDHW	\N	0	UK	2	AUIJZFOOWY@dell.com	8990456487	2	4705598572269082	2011/06	user12839	password	50	100000	M
12840	BFRAOR	VWBVCPJYOH	5102321664 Dell Way	\N	XBJAIFZ	\N	0	Chile	2	VWBVCPJYOH@dell.com	5102321664	3	9369652207009496	2012/11	user12840	password	84	60000	M
12841	DCYRTT	NUOQKYPYFM	8997244299 Dell Way	\N	ZOMIUMO	\N	0	Chile	2	NUOQKYPYFM@dell.com	8997244299	3	2256632382981479	2011/05	user12841	password	59	80000	M
12842	QOEKIS	FXIQVXOAJO	8943907638 Dell Way	\N	PWWKJKR	\N	0	Chile	2	FXIQVXOAJO@dell.com	8943907638	4	9924596382305028	2009/05	user12842	password	63	80000	F
12843	EYLNQQ	KZHFWVGGJV	7279248898 Dell Way	\N	DFGMQXT	\N	0	Germany	2	KZHFWVGGJV@dell.com	7279248898	4	8060078470502050	2008/05	user12843	password	58	20000	M
12844	MMBDDL	DKQAGWGPSK	4435047359 Dell Way	\N	VZXMWQZ	\N	0	Germany	2	DKQAGWGPSK@dell.com	4435047359	4	6602847514208407	2011/05	user12844	password	68	40000	M
12845	EJZIVC	TLCAIJQBTM	7481891118 Dell Way	\N	AQYXHYL	\N	0	Japan	2	TLCAIJQBTM@dell.com	7481891118	1	4824609862640500	2008/10	user12845	password	71	100000	M
12846	CWHXYB	JBBSKSTEEU	2933146977 Dell Way	\N	VCRDBDU	\N	0	Russia	2	JBBSKSTEEU@dell.com	2933146977	2	8451264795847238	2012/12	user12846	password	70	100000	F
12847	OGYNIH	PKZZCTEGNZ	1925341809 Dell Way	\N	JFCLJXF	\N	0	Germany	2	PKZZCTEGNZ@dell.com	1925341809	1	5977189634926618	2008/09	user12847	password	54	20000	F
12848	TAWCIL	MHKPBOVPOF	8986070250 Dell Way	\N	VQQENWS	\N	0	Japan	2	MHKPBOVPOF@dell.com	8986070250	2	7118192230351270	2011/10	user12848	password	73	100000	M
12849	UUQCGC	KRRLFNAUTV	1088904294 Dell Way	\N	LKAYGTP	\N	0	Canada	2	KRRLFNAUTV@dell.com	1088904294	2	8011492274235935	2011/01	user12849	password	71	40000	M
12850	NYXTBH	KTSQHTLAPW	7099072740 Dell Way	\N	KQVRJKV	\N	0	China	2	KTSQHTLAPW@dell.com	7099072740	4	2339824398048222	2011/05	user12850	password	53	60000	M
12851	LKQNSB	GKSNEENUAY	1652909072 Dell Way	\N	KVQTGMD	\N	0	UK	2	GKSNEENUAY@dell.com	1652909072	2	6724319798406214	2010/09	user12851	password	29	40000	F
12852	OYRGZY	RSLWWZRXYC	2984362753 Dell Way	\N	TOVZAYX	\N	0	Canada	2	RSLWWZRXYC@dell.com	2984362753	3	5675834244582803	2012/09	user12852	password	76	20000	F
12853	TVNSUF	LFBIFSFDUY	4380772566 Dell Way	\N	SQXTPVV	\N	0	South Africa	2	LFBIFSFDUY@dell.com	4380772566	2	8048377325292677	2008/03	user12853	password	86	40000	M
12854	UWQOBC	UCKZVPDQNV	7901760509 Dell Way	\N	GLOWHKR	\N	0	Japan	2	UCKZVPDQNV@dell.com	7901760509	3	7562914751935751	2012/05	user12854	password	22	100000	F
12855	XMTYON	BYNXOQNCLU	7971618404 Dell Way	\N	NAQVKIM	\N	0	Canada	2	BYNXOQNCLU@dell.com	7971618404	1	2055387041065842	2008/04	user12855	password	88	40000	F
12856	LCDZQE	YEBMUPOGJC	6006748106 Dell Way	\N	GZXRIJW	\N	0	Australia	2	YEBMUPOGJC@dell.com	6006748106	5	3374924660194665	2012/12	user12856	password	63	100000	F
12857	SCJJHH	NJUIYIOHLV	3748501487 Dell Way	\N	HIMPSIR	\N	0	Chile	2	NJUIYIOHLV@dell.com	3748501487	5	1615334853064268	2009/07	user12857	password	21	60000	F
12858	DYRLGE	UANSJBZVXG	5573438308 Dell Way	\N	DJWWSOC	\N	0	Australia	2	UANSJBZVXG@dell.com	5573438308	1	3233903665561229	2008/03	user12858	password	79	40000	F
12859	UBUBGP	CTHLVGHSNK	6025765047 Dell Way	\N	BKHUYJU	\N	0	France	2	CTHLVGHSNK@dell.com	6025765047	1	5902265650685877	2011/11	user12859	password	85	20000	M
12860	ZYTFOV	ZVHUCONQZP	2979075993 Dell Way	\N	AGJZQEL	\N	0	Canada	2	ZVHUCONQZP@dell.com	2979075993	5	9671219014097006	2008/11	user12860	password	26	100000	M
12861	CODQJC	LQXNEKDDZE	5863446353 Dell Way	\N	KJDANOE	\N	0	Russia	2	LQXNEKDDZE@dell.com	5863446353	1	8752553633879871	2010/04	user12861	password	66	40000	F
12862	FLZOOK	FMYKWBOWFY	3602935987 Dell Way	\N	FJYTXDM	\N	0	France	2	FMYKWBOWFY@dell.com	3602935987	2	9195048145018520	2010/01	user12862	password	36	100000	F
12863	SWVHHA	TFLQHZMNXS	3925198313 Dell Way	\N	WVMUZZG	\N	0	Chile	2	TFLQHZMNXS@dell.com	3925198313	1	8438894481398166	2009/06	user12863	password	72	60000	F
12864	QKKXLD	DWUKVGYTZU	1262134726 Dell Way	\N	PLPOKWV	\N	0	Russia	2	DWUKVGYTZU@dell.com	1262134726	4	1784400425851345	2010/05	user12864	password	67	60000	F
12865	CZXODB	KXMGEKZDFO	6154678437 Dell Way	\N	PUDZRYT	\N	0	Japan	2	KXMGEKZDFO@dell.com	6154678437	5	2285815659444779	2012/07	user12865	password	70	100000	M
12866	SXDVYO	TKUXVUBAJQ	2786020277 Dell Way	\N	VMQMKJE	\N	0	UK	2	TKUXVUBAJQ@dell.com	2786020277	2	9383892771322280	2011/01	user12866	password	83	40000	M
12867	ULPSZI	DUGYOIYXZU	7953390413 Dell Way	\N	KPGUZLU	\N	0	Canada	2	DUGYOIYXZU@dell.com	7953390413	4	9005613554269076	2012/08	user12867	password	31	60000	F
12868	QECPNG	JTEYBDWBYG	5888204216 Dell Way	\N	QFBQQVV	\N	0	France	2	JTEYBDWBYG@dell.com	5888204216	4	3170164388138801	2008/11	user12868	password	77	60000	M
12869	ZQDMWN	GBMHFIJDPZ	2743622528 Dell Way	\N	JRQANML	\N	0	Australia	2	GBMHFIJDPZ@dell.com	2743622528	4	2755887725856155	2008/06	user12869	password	70	80000	F
12870	JTYGGE	HSMNBVRRVA	2121187793 Dell Way	\N	ILAVYLX	\N	0	Canada	2	HSMNBVRRVA@dell.com	2121187793	1	2975207237992436	2011/10	user12870	password	79	20000	F
12871	PZKWDS	PPGRLXIGYR	5472985758 Dell Way	\N	SZNQLKT	\N	0	Germany	2	PPGRLXIGYR@dell.com	5472985758	5	2423202788922936	2009/10	user12871	password	33	60000	F
12872	FXHIPW	YWNJTWQSNI	6552733938 Dell Way	\N	RAYDLRR	\N	0	UK	2	YWNJTWQSNI@dell.com	6552733938	5	3154699881561100	2010/01	user12872	password	70	100000	F
12873	QCOGZN	CMXWJNOWVG	8776025829 Dell Way	\N	XTJIKAG	\N	0	Australia	2	CMXWJNOWVG@dell.com	8776025829	3	5082980577833951	2012/03	user12873	password	38	20000	M
12874	JSBIGD	VDAEROBMVY	1055213813 Dell Way	\N	GEGRFNS	\N	0	Australia	2	VDAEROBMVY@dell.com	1055213813	1	9864254332147540	2009/06	user12874	password	27	20000	M
12875	VDDCHZ	FHEWVFJREP	2066490150 Dell Way	\N	VLHBYZD	\N	0	UK	2	FHEWVFJREP@dell.com	2066490150	1	2505774735938757	2010/03	user12875	password	34	40000	F
12876	IMEPMK	WQHSWQJAGF	5581805396 Dell Way	\N	LNGJMKI	\N	0	Japan	2	WQHSWQJAGF@dell.com	5581805396	3	2437765557784587	2011/09	user12876	password	55	100000	F
12877	ZARMKO	CRGYHQZOWK	6320002743 Dell Way	\N	CDUONCE	\N	0	Australia	2	CRGYHQZOWK@dell.com	6320002743	2	7982902277261020	2009/11	user12877	password	62	40000	M
12878	PAIAOL	RVJYMINITP	7318163380 Dell Way	\N	LNEZQJZ	\N	0	Chile	2	RVJYMINITP@dell.com	7318163380	4	5647605981212110	2010/05	user12878	password	81	60000	M
12879	XTZLER	HNQTWDCQSO	3810729029 Dell Way	\N	DWNTGNZ	\N	0	UK	2	HNQTWDCQSO@dell.com	3810729029	3	5442498610354960	2011/05	user12879	password	84	80000	F
12880	QSSUJA	IZUFCWVVLZ	3070574470 Dell Way	\N	RZTYNTW	\N	0	South Africa	2	IZUFCWVVLZ@dell.com	3070574470	2	5722474875394255	2011/04	user12880	password	34	100000	M
12881	XPRGPA	GJFIGBDRBV	9773363287 Dell Way	\N	RUTENQZ	\N	0	Russia	2	GJFIGBDRBV@dell.com	9773363287	3	4180909257847816	2009/09	user12881	password	33	20000	M
12882	UVXJVE	TBMZDQRELI	1056000832 Dell Way	\N	YFMMVMG	\N	0	South Africa	2	TBMZDQRELI@dell.com	1056000832	3	1401505122892558	2011/10	user12882	password	30	60000	M
12883	ZIZVMT	XZSAPJFBSE	5275019727 Dell Way	\N	GEQCRXX	\N	0	Japan	2	XZSAPJFBSE@dell.com	5275019727	5	4871574097778648	2009/02	user12883	password	78	100000	F
12884	EWZQPW	PIXFSCGKHN	5567785230 Dell Way	\N	PXQHUOY	\N	0	Chile	2	PIXFSCGKHN@dell.com	5567785230	2	6071000913623721	2011/03	user12884	password	50	80000	F
12885	ITAYPQ	GNWYQDJXQY	6161529139 Dell Way	\N	VHGQVEX	\N	0	China	2	GNWYQDJXQY@dell.com	6161529139	3	9842288779560478	2011/12	user12885	password	73	20000	F
12886	MFECVK	QSJGVTEMRZ	9961316494 Dell Way	\N	TYPPCNX	\N	0	Japan	2	QSJGVTEMRZ@dell.com	9961316494	5	5311606294941157	2012/08	user12886	password	65	20000	F
12887	WIGSTX	KDDFWHROHL	8512864558 Dell Way	\N	MXAPKYG	\N	0	France	2	KDDFWHROHL@dell.com	8512864558	4	3901842370629311	2010/05	user12887	password	53	80000	F
12888	VXZOUJ	RYPOGGCNSO	2496167729 Dell Way	\N	KSDVQKG	\N	0	France	2	RYPOGGCNSO@dell.com	2496167729	3	9686146249063314	2010/01	user12888	password	62	100000	M
12889	NUKIEC	HTROATBSIM	2019488431 Dell Way	\N	KLIBWON	\N	0	Australia	2	HTROATBSIM@dell.com	2019488431	3	6531998450867832	2008/02	user12889	password	50	20000	M
12890	GLZKOG	EFUEYWXGJI	4485255269 Dell Way	\N	SSJPGXQ	\N	0	China	2	EFUEYWXGJI@dell.com	4485255269	2	5682312064338476	2010/09	user12890	password	56	20000	M
12891	ZCJNJN	SDRQAOXKWQ	2070756626 Dell Way	\N	CGFIDWS	\N	0	Germany	2	SDRQAOXKWQ@dell.com	2070756626	2	1236059991642832	2012/10	user12891	password	29	80000	M
12892	GDFPQY	THOUWMETCH	6048089249 Dell Way	\N	AIQEEIR	\N	0	China	2	THOUWMETCH@dell.com	6048089249	4	2112006520386785	2009/11	user12892	password	82	20000	F
12893	AHTQFN	YUHVGMPJTP	2419031518 Dell Way	\N	RJTWSLE	\N	0	Chile	2	YUHVGMPJTP@dell.com	2419031518	2	6241807826794685	2008/03	user12893	password	63	20000	F
12894	XXVCKT	WSODEDMXTE	5371880413 Dell Way	\N	HMAZYFG	\N	0	Australia	2	WSODEDMXTE@dell.com	5371880413	5	2103854511864483	2011/06	user12894	password	38	100000	F
12895	ERLOKI	HZMLDZJWDQ	7543504703 Dell Way	\N	JEQHJXK	\N	0	South Africa	2	HZMLDZJWDQ@dell.com	7543504703	3	5614977235440165	2008/10	user12895	password	44	60000	M
12896	AAOLIV	KVGNUPKXGT	9488182288 Dell Way	\N	BXBLULH	\N	0	Germany	2	KVGNUPKXGT@dell.com	9488182288	5	7428386362735183	2011/02	user12896	password	37	80000	F
12897	HGPQBA	LHOFXYDERF	7540969240 Dell Way	\N	CTQXEYK	\N	0	Canada	2	LHOFXYDERF@dell.com	7540969240	1	8591255369596184	2012/05	user12897	password	57	20000	M
12898	URHVRS	DFXBEAGWFI	7904185372 Dell Way	\N	PWFTUQW	\N	0	Germany	2	DFXBEAGWFI@dell.com	7904185372	4	4635214691981673	2008/04	user12898	password	52	100000	F
12899	DCWVUA	BSCGTICZRR	9949542841 Dell Way	\N	WXLQOHD	\N	0	China	2	BSCGTICZRR@dell.com	9949542841	3	5206428409554064	2009/01	user12899	password	38	40000	F
12900	JEAEEC	XHIRQKQHBM	8464593647 Dell Way	\N	FMDTUHB	\N	0	Russia	2	XHIRQKQHBM@dell.com	8464593647	3	1188108519185334	2012/10	user12900	password	39	20000	F
12901	LBJQDG	XLYNWOVXBA	3997791386 Dell Way	\N	KETFLVZ	\N	0	Chile	2	XLYNWOVXBA@dell.com	3997791386	5	2157623980659991	2008/04	user12901	password	29	40000	M
12902	FRKJYI	UWVQLROMSZ	2395581643 Dell Way	\N	RLECHEJ	\N	0	Japan	2	UWVQLROMSZ@dell.com	2395581643	3	7684621545020492	2010/08	user12902	password	22	40000	M
12903	TPFSXA	PTRALGNDFE	2175291863 Dell Way	\N	PKGWOQM	\N	0	Russia	2	PTRALGNDFE@dell.com	2175291863	2	2527631730306893	2011/04	user12903	password	45	80000	F
12904	ZWSXXI	ROICUWFAAU	3968653426 Dell Way	\N	KHRZYDS	\N	0	Australia	2	ROICUWFAAU@dell.com	3968653426	5	8656669057905675	2010/03	user12904	password	55	80000	F
12905	KJDHRU	WAXRWDRXXC	6780020101 Dell Way	\N	EPBDSUE	\N	0	Australia	2	WAXRWDRXXC@dell.com	6780020101	1	6745234817732126	2012/07	user12905	password	36	20000	M
12906	PGGGBC	HYTDBLAZNF	6051052784 Dell Way	\N	OPJHJNI	\N	0	Australia	2	HYTDBLAZNF@dell.com	6051052784	5	9164283953607084	2008/03	user12906	password	19	20000	M
12907	HHCIKJ	GENIPNHDTW	4717831691 Dell Way	\N	SCDCQLC	\N	0	Chile	2	GENIPNHDTW@dell.com	4717831691	1	3791395021602511	2011/01	user12907	password	44	60000	F
12908	QNQBWX	FJGUXOXRKQ	8696583416 Dell Way	\N	UOSLAVQ	\N	0	France	2	FJGUXOXRKQ@dell.com	8696583416	5	1489953387528657	2012/04	user12908	password	54	40000	M
12909	AWAXUF	HAZFOXWZNR	7295668594 Dell Way	\N	OGCOCTZ	\N	0	UK	2	HAZFOXWZNR@dell.com	7295668594	1	8579922646749766	2008/07	user12909	password	22	100000	M
12910	YZLTET	TEYICVIQMW	5265604566 Dell Way	\N	WPLYILX	\N	0	Australia	2	TEYICVIQMW@dell.com	5265604566	4	1487529424950480	2008/10	user12910	password	19	60000	M
12911	AAMFTG	KRPMNXCZUZ	6163931187 Dell Way	\N	PFYYQVZ	\N	0	Canada	2	KRPMNXCZUZ@dell.com	6163931187	1	2237171062268317	2009/01	user12911	password	69	20000	F
12912	TQGMWQ	EMDSKFREFG	2615922951 Dell Way	\N	KDEBZEE	\N	0	Germany	2	EMDSKFREFG@dell.com	2615922951	2	9358100548852236	2009/01	user12912	password	22	40000	M
12913	ROGOEL	AIDKOVPTBZ	5542650840 Dell Way	\N	XGAWKFK	\N	0	Germany	2	AIDKOVPTBZ@dell.com	5542650840	2	8399054084438831	2010/05	user12913	password	26	40000	F
12914	RNQWZR	ECCSXSLZRI	9490921410 Dell Way	\N	GSFQXPG	\N	0	France	2	ECCSXSLZRI@dell.com	9490921410	1	9458602107595652	2009/03	user12914	password	33	60000	M
12915	TCRSTW	UWOSOARGJX	8747655999 Dell Way	\N	YOOWEUH	\N	0	Canada	2	UWOSOARGJX@dell.com	8747655999	2	5164681603200734	2008/06	user12915	password	83	100000	F
12916	ZOWTKR	PYJDZAKIYI	7628310435 Dell Way	\N	XNFCHNF	\N	0	Canada	2	PYJDZAKIYI@dell.com	7628310435	4	2800649004057050	2008/07	user12916	password	22	40000	M
12917	PFGAWW	ZGZYHKGFTE	2040563117 Dell Way	\N	SYGALLF	\N	0	Canada	2	ZGZYHKGFTE@dell.com	2040563117	2	4299468235578388	2011/06	user12917	password	70	20000	F
12918	YLCVHB	BHZIRGOKKG	8962344967 Dell Way	\N	JRHVDMA	\N	0	Chile	2	BHZIRGOKKG@dell.com	8962344967	2	9150195198133588	2009/02	user12918	password	25	60000	F
12919	OMWVOX	DNGVTUGEBP	8053167859 Dell Way	\N	WJKZVKF	\N	0	Russia	2	DNGVTUGEBP@dell.com	8053167859	1	1607983685098588	2012/03	user12919	password	53	100000	M
12920	ZTPNRT	BXOVRUASKW	2377235706 Dell Way	\N	BVVXGAQ	\N	0	Australia	2	BXOVRUASKW@dell.com	2377235706	4	9014870494604112	2009/03	user12920	password	75	20000	F
12921	NTSFMT	CBOTWOMGKO	8295055386 Dell Way	\N	CGMIHCI	\N	0	France	2	CBOTWOMGKO@dell.com	8295055386	2	8274244650267065	2012/01	user12921	password	86	20000	M
12922	RWTDPV	FEPBTCIEQK	3489622199 Dell Way	\N	KCSSFBD	\N	0	Australia	2	FEPBTCIEQK@dell.com	3489622199	5	1279647296294570	2009/11	user12922	password	32	100000	M
12923	BPSRLX	WAYPCHTTRE	9757609119 Dell Way	\N	WJWCLAD	\N	0	Russia	2	WAYPCHTTRE@dell.com	9757609119	1	1020624343305826	2012/05	user12923	password	80	60000	F
12924	LDCWAZ	XZOAHITYNQ	9788442335 Dell Way	\N	IKSTKVM	\N	0	China	2	XZOAHITYNQ@dell.com	9788442335	3	3233221039175987	2009/04	user12924	password	66	80000	M
12925	UWQVVO	VJOCSIAFYJ	1340134613 Dell Way	\N	PQCAMOK	\N	0	France	2	VJOCSIAFYJ@dell.com	1340134613	4	7999944048468024	2009/04	user12925	password	56	20000	F
12926	JTYEHU	OWWHEXMCGC	3018244404 Dell Way	\N	TJDGYOR	\N	0	UK	2	OWWHEXMCGC@dell.com	3018244404	3	4061064433306456	2010/12	user12926	password	51	80000	F
12927	FQONLC	JHJOFWRMZL	8365383245 Dell Way	\N	WDRURJU	\N	0	UK	2	JHJOFWRMZL@dell.com	8365383245	1	5195916865952313	2012/08	user12927	password	28	20000	M
12928	USIFVS	NFGSBXFBJB	8029447668 Dell Way	\N	EAWWJQU	\N	0	Canada	2	NFGSBXFBJB@dell.com	8029447668	2	9935107565484942	2009/05	user12928	password	29	20000	F
12929	WMKREX	XLQYJWASXF	1746410727 Dell Way	\N	SUBCLVH	\N	0	Chile	2	XLQYJWASXF@dell.com	1746410727	2	6182995432056487	2010/06	user12929	password	72	80000	F
12930	GBZKZW	WQVFMVXKAQ	3232421129 Dell Way	\N	ECSPYZV	\N	0	Australia	2	WQVFMVXKAQ@dell.com	3232421129	2	5481892209965736	2011/02	user12930	password	29	100000	F
12931	FYUFVQ	VQVIMTSNJX	7172613844 Dell Way	\N	QCMOCHP	\N	0	China	2	VQVIMTSNJX@dell.com	7172613844	1	1032635388430207	2012/03	user12931	password	88	20000	F
12932	YYRTPN	KLVXEOLOLB	3641984638 Dell Way	\N	RYQTGFC	\N	0	UK	2	KLVXEOLOLB@dell.com	3641984638	1	7690180171746761	2010/01	user12932	password	85	20000	M
12933	WRTMFD	XBACPLQBNI	3174168532 Dell Way	\N	ZDBGIDE	\N	0	Japan	2	XBACPLQBNI@dell.com	3174168532	5	2542388607282191	2009/10	user12933	password	31	40000	M
12934	WAECDB	DEDTQUUDCU	1922686644 Dell Way	\N	HEAQIEG	\N	0	Germany	2	DEDTQUUDCU@dell.com	1922686644	3	8843051718082280	2012/08	user12934	password	29	80000	F
12935	EUOIWR	NAKDUFHXZP	8930655891 Dell Way	\N	CAFKFLZ	\N	0	China	2	NAKDUFHXZP@dell.com	8930655891	5	3176425938028842	2010/01	user12935	password	82	100000	F
12936	RNNOFA	OQEJVMHVBJ	6467772859 Dell Way	\N	VHUBSTJ	\N	0	Japan	2	OQEJVMHVBJ@dell.com	6467772859	3	1878800566773861	2011/06	user12936	password	22	100000	F
12937	PISUIH	KNRGZYBBHX	9038452807 Dell Way	\N	IBYBVHR	\N	0	France	2	KNRGZYBBHX@dell.com	9038452807	4	1422474477905780	2009/10	user12937	password	79	60000	F
12938	EGFMNP	ZFWZDYALVJ	8407992835 Dell Way	\N	NUKICBT	\N	0	UK	2	ZFWZDYALVJ@dell.com	8407992835	4	4124499212950468	2011/08	user12938	password	81	20000	M
12939	DGHRWH	WSGZRHLMQY	8222671290 Dell Way	\N	HBGJCAJ	\N	0	UK	2	WSGZRHLMQY@dell.com	8222671290	4	6219335374422372	2010/07	user12939	password	64	40000	M
12940	WOJTVF	MCFDKQPBOX	3787997299 Dell Way	\N	CVGFVPD	\N	0	Japan	2	MCFDKQPBOX@dell.com	3787997299	4	1695313447620719	2012/05	user12940	password	42	60000	F
12941	WYZSEL	VJOFAEHPBJ	5216345060 Dell Way	\N	KIPGYTW	\N	0	Chile	2	VJOFAEHPBJ@dell.com	5216345060	5	2296103163156658	2012/04	user12941	password	70	20000	F
12942	RBWVMR	EBXFFFUHPF	3077316567 Dell Way	\N	QELPXHW	\N	0	China	2	EBXFFFUHPF@dell.com	3077316567	5	2859879559371620	2010/09	user12942	password	37	80000	F
12943	INEUFJ	VDPBIJJXOA	4943272926 Dell Way	\N	BZPZHLJ	\N	0	Germany	2	VDPBIJJXOA@dell.com	4943272926	3	1151369631756097	2008/11	user12943	password	66	60000	F
12944	ESYKCU	NRWVBFTPFU	7377873661 Dell Way	\N	PUUXGDK	\N	0	Japan	2	NRWVBFTPFU@dell.com	7377873661	3	8554464179091156	2010/02	user12944	password	45	80000	F
12945	CQRFKE	WHAYMTOSOE	8909426450 Dell Way	\N	MIBTMLL	\N	0	Canada	2	WHAYMTOSOE@dell.com	8909426450	2	7565553479827941	2012/08	user12945	password	48	40000	M
12946	BXYMCV	TCTGWHYKLL	8866458538 Dell Way	\N	TNEFYPK	\N	0	South Africa	2	TCTGWHYKLL@dell.com	8866458538	1	8234919618815184	2010/07	user12946	password	21	40000	M
12947	ZECBAW	ETCABALNLE	9526022310 Dell Way	\N	AQKZGVU	\N	0	Canada	2	ETCABALNLE@dell.com	9526022310	4	6677632011007518	2010/08	user12947	password	82	20000	M
12948	BFRBCW	VEWXFIKQNK	7990530387 Dell Way	\N	HXJNTEQ	\N	0	Japan	2	VEWXFIKQNK@dell.com	7990530387	2	2694390548858791	2010/02	user12948	password	40	20000	F
12949	NSHPOD	ULAZUKQHVX	4299206766 Dell Way	\N	FFLYJCQ	\N	0	Canada	2	ULAZUKQHVX@dell.com	4299206766	5	6296388776972890	2010/02	user12949	password	64	80000	M
12950	JBHYEB	KFAEQRMLOR	1863822688 Dell Way	\N	RAQBCHF	\N	0	France	2	KFAEQRMLOR@dell.com	1863822688	4	9903070745524020	2009/06	user12950	password	72	100000	M
12951	UESZGD	EHHVYTHNLY	9841011876 Dell Way	\N	NCZPJEB	\N	0	France	2	EHHVYTHNLY@dell.com	9841011876	1	7097431400325150	2010/10	user12951	password	60	40000	M
12952	TYPABT	HJPFCWSOUG	9730494106 Dell Way	\N	QUVZYXL	\N	0	UK	2	HJPFCWSOUG@dell.com	9730494106	1	4187439946457744	2011/09	user12952	password	58	40000	F
12953	MYLOST	XHYADROYXF	7403473439 Dell Way	\N	STERRPP	\N	0	Japan	2	XHYADROYXF@dell.com	7403473439	5	4622637461870909	2009/07	user12953	password	74	100000	F
12954	SHOLAM	TZMWRAVPFN	7872905116 Dell Way	\N	IKFZAUQ	\N	0	Russia	2	TZMWRAVPFN@dell.com	7872905116	1	2093473411630839	2009/10	user12954	password	88	40000	M
12955	GWYHIR	HUOYVKNBYW	5415534685 Dell Way	\N	MDWMXMF	\N	0	Japan	2	HUOYVKNBYW@dell.com	5415534685	2	9707516309339554	2009/04	user12955	password	37	100000	M
12956	DTWLLD	GACCKQDJMP	6689629406 Dell Way	\N	MICJUHB	\N	0	Chile	2	GACCKQDJMP@dell.com	6689629406	1	6129759735427797	2012/04	user12956	password	45	60000	F
12957	DIWPMD	POFAEJJQZV	3889869517 Dell Way	\N	ZBFTJHB	\N	0	UK	2	POFAEJJQZV@dell.com	3889869517	4	9265976727474482	2011/12	user12957	password	47	20000	F
12958	SYSEBH	THIXQSOPON	9254376110 Dell Way	\N	QUGABHZ	\N	0	China	2	THIXQSOPON@dell.com	9254376110	5	1048140040133148	2012/04	user12958	password	21	20000	F
12959	ZSGBAZ	IJWYBKNQXE	1972505034 Dell Way	\N	KEEMMEW	\N	0	France	2	IJWYBKNQXE@dell.com	1972505034	5	3738953615073115	2010/11	user12959	password	41	60000	M
12960	BSYBRG	KOFMZTDXYN	7140477196 Dell Way	\N	BDZOIVY	\N	0	France	2	KOFMZTDXYN@dell.com	7140477196	2	8574442939832807	2010/08	user12960	password	40	60000	M
12961	AKRSRC	GXPGQSDOGF	9962212875 Dell Way	\N	RFUZBSK	\N	0	Russia	2	GXPGQSDOGF@dell.com	9962212875	2	3911628230009228	2010/07	user12961	password	76	40000	M
12962	FXHXAO	UQULJYZPDR	3680259958 Dell Way	\N	VXQWQBP	\N	0	Japan	2	UQULJYZPDR@dell.com	3680259958	5	2986640728078782	2012/09	user12962	password	49	60000	M
12963	ISWJHR	ZBCIZCXDTT	2050290441 Dell Way	\N	BKPRMFI	\N	0	Russia	2	ZBCIZCXDTT@dell.com	2050290441	3	6619538582395763	2012/12	user12963	password	22	100000	F
12964	URRBIQ	CLZCOXGHQH	8436374784 Dell Way	\N	SGZFLHZ	\N	0	Germany	2	CLZCOXGHQH@dell.com	8436374784	3	4507126035168767	2012/08	user12964	password	31	20000	F
12965	WUMFLO	QKREIXMYEF	9550533451 Dell Way	\N	EDKQLJE	\N	0	Chile	2	QKREIXMYEF@dell.com	9550533451	3	1517645632382482	2010/09	user12965	password	30	20000	M
12966	YMUKBL	VSQDQDCUIH	6438981018 Dell Way	\N	YSXJCBQ	\N	0	Australia	2	VSQDQDCUIH@dell.com	6438981018	4	6644550579600037	2009/11	user12966	password	64	100000	M
12967	DTFEFA	WVEMYGHHNG	9325613243 Dell Way	\N	ZKPBMGC	\N	0	Australia	2	WVEMYGHHNG@dell.com	9325613243	4	4781578437425196	2011/05	user12967	password	44	80000	F
12968	DVQIWN	EAACGIJUOJ	3448141464 Dell Way	\N	FDLRKOT	\N	0	China	2	EAACGIJUOJ@dell.com	3448141464	1	1915907792747020	2011/07	user12968	password	69	20000	M
12969	NUZJID	KIGQQQLEZQ	2918392741 Dell Way	\N	IKHSYBB	\N	0	Chile	2	KIGQQQLEZQ@dell.com	2918392741	1	8841623676475138	2011/11	user12969	password	18	60000	F
12970	UKTCND	KTUBJFFJVO	5158858083 Dell Way	\N	UDHTEIY	\N	0	France	2	KTUBJFFJVO@dell.com	5158858083	5	2370363464113325	2009/11	user12970	password	58	80000	M
12971	YLSMOD	GIEQOKZJZT	3511978177 Dell Way	\N	NGMSPLD	\N	0	Australia	2	GIEQOKZJZT@dell.com	3511978177	2	4213918512687087	2008/10	user12971	password	20	80000	M
12972	MLGAPM	JUCXFCHEVU	9242311375 Dell Way	\N	LINAUQC	\N	0	Australia	2	JUCXFCHEVU@dell.com	9242311375	3	2596935673616826	2011/06	user12972	password	84	60000	M
12973	JTZYGI	TJFYLNDHIO	2165629305 Dell Way	\N	QVPKMRM	\N	0	China	2	TJFYLNDHIO@dell.com	2165629305	4	2243644569534808	2011/07	user12973	password	66	60000	M
12974	LNWRVP	ABOMORTWGJ	8849164799 Dell Way	\N	SWTENFP	\N	0	Japan	2	ABOMORTWGJ@dell.com	8849164799	4	3480356064625084	2010/05	user12974	password	78	40000	M
12975	IFMEVN	GKZVBSSHCK	9169233031 Dell Way	\N	EVPSBEJ	\N	0	UK	2	GKZVBSSHCK@dell.com	9169233031	4	4322459607385099	2009/06	user12975	password	70	20000	M
12976	YOZUCG	EBBGUTOWES	4565122774 Dell Way	\N	RUKTZTS	\N	0	South Africa	2	EBBGUTOWES@dell.com	4565122774	1	2528422667644918	2012/10	user12976	password	37	80000	M
12977	VRNXXR	ZZYTTMPXEH	8141534794 Dell Way	\N	SOARISO	\N	0	Russia	2	ZZYTTMPXEH@dell.com	8141534794	4	6247287072706968	2010/12	user12977	password	36	40000	M
12978	XVTVNT	ULMNXBLBIE	2336391673 Dell Way	\N	QJWZCKR	\N	0	South Africa	2	ULMNXBLBIE@dell.com	2336391673	2	5266896879766137	2008/07	user12978	password	74	100000	F
12979	PTGCMB	OYPLABNJFE	1816458669 Dell Way	\N	TBDVMVT	\N	0	Japan	2	OYPLABNJFE@dell.com	1816458669	2	8041053331457079	2011/12	user12979	password	73	20000	M
12980	NISZKG	YZRYBEHHJB	8386439177 Dell Way	\N	JMWVHPM	\N	0	China	2	YZRYBEHHJB@dell.com	8386439177	2	9986120662186296	2012/01	user12980	password	22	40000	M
12981	JCNUIL	TAJVERCOSL	9881897571 Dell Way	\N	APGHFTR	\N	0	Australia	2	TAJVERCOSL@dell.com	9881897571	4	8634167147334666	2008/09	user12981	password	35	60000	F
12982	IAXRMR	RWMWNOKGZK	1815627629 Dell Way	\N	WGSCZKD	\N	0	UK	2	RWMWNOKGZK@dell.com	1815627629	5	9840118679683656	2012/03	user12982	password	55	100000	M
12983	OWFANX	WZTKOEROON	7390032337 Dell Way	\N	UHPUSTT	\N	0	Russia	2	WZTKOEROON@dell.com	7390032337	4	6605395583435894	2012/04	user12983	password	60	60000	M
12984	LSVYPR	YJBMNSACGV	2194006968 Dell Way	\N	KWQCPKW	\N	0	China	2	YJBMNSACGV@dell.com	2194006968	3	3169697461649775	2009/02	user12984	password	71	20000	M
12985	LAMBRL	LTYYMZBSUL	9268262581 Dell Way	\N	PKNFUKN	\N	0	UK	2	LTYYMZBSUL@dell.com	9268262581	4	3967616795096546	2008/06	user12985	password	56	60000	M
12986	NAZFLK	YJJLIKEDVT	2774064398 Dell Way	\N	OJYJULH	\N	0	Russia	2	YJJLIKEDVT@dell.com	2774064398	4	7393845310900361	2011/02	user12986	password	35	60000	M
12987	GOXRZV	BIHKSLNOEB	4195581540 Dell Way	\N	YDLSPSL	\N	0	Russia	2	BIHKSLNOEB@dell.com	4195581540	1	5055375429335982	2010/05	user12987	password	21	20000	M
12988	QBIPXJ	XETQQHFUID	4993631635 Dell Way	\N	YUWNMHH	\N	0	South Africa	2	XETQQHFUID@dell.com	4993631635	4	4219555036630482	2012/10	user12988	password	57	60000	F
12989	PUZNDX	SXOIETDNXB	6436767240 Dell Way	\N	HUOUCWQ	\N	0	Germany	2	SXOIETDNXB@dell.com	6436767240	5	4192170843482018	2009/07	user12989	password	76	80000	F
12990	PURSSJ	PGSUAVHYXO	9593252855 Dell Way	\N	TMIVIZJ	\N	0	UK	2	PGSUAVHYXO@dell.com	9593252855	4	3951820604037494	2010/07	user12990	password	26	80000	F
12991	XHUQRK	XJFYEMWCBP	5304254431 Dell Way	\N	OKLXJUV	\N	0	China	2	XJFYEMWCBP@dell.com	5304254431	1	8144482274074108	2012/04	user12991	password	48	20000	F
12992	SXVJHS	SNQXZMZACN	4459441073 Dell Way	\N	KNKUHGC	\N	0	Russia	2	SNQXZMZACN@dell.com	4459441073	5	7900223645381630	2011/04	user12992	password	79	100000	M
12993	TQJBJB	OZYNMYOOLZ	7683528720 Dell Way	\N	CWTKCWE	\N	0	France	2	OZYNMYOOLZ@dell.com	7683528720	5	2233901227358728	2008/10	user12993	password	89	20000	M
12994	QKOZLC	YKQLIFZUFC	6214026981 Dell Way	\N	QYMTVQF	\N	0	Germany	2	YKQLIFZUFC@dell.com	6214026981	2	6427945903036744	2009/04	user12994	password	64	100000	M
12995	ALYMNX	WEIFJIZOLQ	9217550235 Dell Way	\N	NXJJOOX	\N	0	Canada	2	WEIFJIZOLQ@dell.com	9217550235	3	5491872290614993	2009/02	user12995	password	45	40000	F
12996	VERJCO	NLTXTSMFIA	8036032412 Dell Way	\N	DRJRGGV	\N	0	Canada	2	NLTXTSMFIA@dell.com	8036032412	2	4627154750283808	2012/09	user12996	password	62	20000	F
12997	UUVWIJ	HBGBUTGDTJ	2643257624 Dell Way	\N	UCBBJWF	\N	0	Canada	2	HBGBUTGDTJ@dell.com	2643257624	4	1739069425500929	2012/03	user12997	password	33	40000	F
12998	AFWIPE	KVFEPMIIWD	9845106507 Dell Way	\N	KXEUUJX	\N	0	UK	2	KVFEPMIIWD@dell.com	9845106507	1	8484595865476877	2009/03	user12998	password	32	40000	F
12999	KCOZGY	VMDKYLTUOD	8625402815 Dell Way	\N	STYMCVL	\N	0	Australia	2	VMDKYLTUOD@dell.com	8625402815	2	3692952091805637	2008/06	user12999	password	55	40000	M
13000	PVWVTS	IXDGIWBXAT	9810861805 Dell Way	\N	QYGTUSW	\N	0	Japan	2	IXDGIWBXAT@dell.com	9810861805	1	7209543202538044	2010/08	user13000	password	87	40000	F
13001	TGCNYK	KCRTYSRZMI	1679621347 Dell Way	\N	XTCRLYI	\N	0	France	2	KCRTYSRZMI@dell.com	1679621347	1	8891179855912925	2011/12	user13001	password	34	100000	M
13002	MCGKNR	NELLXDKKLI	4040018995 Dell Way	\N	DNAOLIZ	\N	0	Germany	2	NELLXDKKLI@dell.com	4040018995	5	3334985386114568	2009/02	user13002	password	36	20000	M
13003	JHZWZM	BLYZOJJZRN	9466224920 Dell Way	\N	NRCYABM	\N	0	China	2	BLYZOJJZRN@dell.com	9466224920	4	6863886943552644	2008/12	user13003	password	68	80000	F
13004	APFZBH	KZGYJQYADL	6362196112 Dell Way	\N	SFKSHWB	\N	0	Chile	2	KZGYJQYADL@dell.com	6362196112	4	3458615955896676	2010/05	user13004	password	81	100000	F
13005	LEKNLV	NSTWJSXNEP	1645475435 Dell Way	\N	SOHAKJG	\N	0	Australia	2	NSTWJSXNEP@dell.com	1645475435	3	6337452454026789	2010/05	user13005	password	56	100000	M
13006	RHJDCX	WWTFOQSSGL	3198657289 Dell Way	\N	GOMRXSR	\N	0	UK	2	WWTFOQSSGL@dell.com	3198657289	2	5204123394563794	2011/10	user13006	password	43	60000	F
13007	QWQSTM	ONSCELVKWB	7333398801 Dell Way	\N	ZITXBLX	\N	0	China	2	ONSCELVKWB@dell.com	7333398801	2	9545696489512920	2010/09	user13007	password	50	100000	F
13008	IQACCO	PVRUGMFDOE	3874197433 Dell Way	\N	MHBNSYV	\N	0	France	2	PVRUGMFDOE@dell.com	3874197433	4	9434658421669156	2008/03	user13008	password	85	40000	M
13009	OJQRYG	MPATCFWQJI	5451452980 Dell Way	\N	YLWRKSC	\N	0	Russia	2	MPATCFWQJI@dell.com	5451452980	1	7752969720866532	2011/12	user13009	password	25	40000	M
13010	MXEKER	AEKCJGSTPR	5182689036 Dell Way	\N	ELIPDLI	\N	0	Japan	2	AEKCJGSTPR@dell.com	5182689036	1	4416326139587909	2010/03	user13010	password	66	100000	M
13011	PDATUB	XEDHKWAZNF	2972667864 Dell Way	\N	LVVPHDG	\N	0	Russia	2	XEDHKWAZNF@dell.com	2972667864	4	2516784076578915	2009/04	user13011	password	26	20000	M
13012	GBQACO	EGVPCWPPCA	5219992684 Dell Way	\N	LXPSBWL	\N	0	Chile	2	EGVPCWPPCA@dell.com	5219992684	4	6902491252869368	2011/09	user13012	password	67	80000	M
13013	TGZWUE	CQTEMIUOJG	1408200331 Dell Way	\N	MZYNVKU	\N	0	Chile	2	CQTEMIUOJG@dell.com	1408200331	3	1351051053032279	2011/02	user13013	password	66	80000	M
13014	YTSSYV	ISAVAUJKAV	5969865276 Dell Way	\N	JZJEKDL	\N	0	France	2	ISAVAUJKAV@dell.com	5969865276	3	3155067256186157	2011/03	user13014	password	18	60000	F
13015	UGVSBE	KCZLWJVXFF	4001256616 Dell Way	\N	XOJHRVT	\N	0	Chile	2	KCZLWJVXFF@dell.com	4001256616	5	9165113041177392	2010/12	user13015	password	49	60000	M
13016	RKMTOW	VOISXEQDJN	5864054942 Dell Way	\N	STUKPOQ	\N	0	UK	2	VOISXEQDJN@dell.com	5864054942	3	4711681369692087	2010/12	user13016	password	18	40000	M
13017	KULZRG	OZZMDPPNCH	8697982612 Dell Way	\N	GXRVMIT	\N	0	Australia	2	OZZMDPPNCH@dell.com	8697982612	1	5888670631218702	2012/03	user13017	password	79	60000	M
13018	QXPHED	HEPLUEYWMF	9494969923 Dell Way	\N	UEAGMUH	\N	0	China	2	HEPLUEYWMF@dell.com	9494969923	5	2490591479931026	2008/08	user13018	password	66	80000	F
13019	PHOUKV	YZGSEFPQKK	7756351726 Dell Way	\N	VLRHFYQ	\N	0	Canada	2	YZGSEFPQKK@dell.com	7756351726	4	3567967710550875	2010/06	user13019	password	89	80000	F
13020	GGVRCT	RJMVPCMZMH	1190182185 Dell Way	\N	LDPRCFV	\N	0	South Africa	2	RJMVPCMZMH@dell.com	1190182185	1	3241779071278870	2010/02	user13020	password	87	60000	F
13021	FIBICS	SONHQAGDHS	3876018590 Dell Way	\N	HXJJDFF	\N	0	Canada	2	SONHQAGDHS@dell.com	3876018590	3	6592144825495780	2010/05	user13021	password	28	80000	M
13022	MVYONQ	DBXTBEXJWE	3086458101 Dell Way	\N	GGOKLUN	\N	0	Russia	2	DBXTBEXJWE@dell.com	3086458101	1	2618036963976919	2011/04	user13022	password	89	40000	M
13023	VFIJVL	KTFMXCVUHC	2640207127 Dell Way	\N	AWMLQAF	\N	0	South Africa	2	KTFMXCVUHC@dell.com	2640207127	2	5431371130980551	2010/05	user13023	password	72	40000	F
13024	YONUZY	NEKLHGFOJG	3841324116 Dell Way	\N	KWSAXXX	\N	0	Australia	2	NEKLHGFOJG@dell.com	3841324116	2	5930008404888213	2011/02	user13024	password	74	100000	F
13025	IKVHJJ	MUUTAAHKGS	1210855830 Dell Way	\N	GZTEXQF	\N	0	Chile	2	MUUTAAHKGS@dell.com	1210855830	4	9021883268374952	2008/07	user13025	password	74	40000	M
13026	EBEOLQ	IFJJFRTMKA	2621955595 Dell Way	\N	LDEIUKO	\N	0	South Africa	2	IFJJFRTMKA@dell.com	2621955595	3	9642572296783328	2011/03	user13026	password	31	80000	F
13027	GUXRLG	XVPDNIQXJB	4330405789 Dell Way	\N	ANKVYYQ	\N	0	Canada	2	XVPDNIQXJB@dell.com	4330405789	3	8649556107819081	2010/10	user13027	password	52	100000	F
13028	GWSSCQ	NRTAAJXJLY	9826659920 Dell Way	\N	XVUVUKY	\N	0	Canada	2	NRTAAJXJLY@dell.com	9826659920	5	7498457413632423	2011/04	user13028	password	66	80000	M
13029	NNGQDT	IXUJHRTTQQ	3254393634 Dell Way	\N	PKMJVLN	\N	0	Russia	2	IXUJHRTTQQ@dell.com	3254393634	2	5889846641570330	2010/11	user13029	password	42	20000	F
13030	VHCZBK	XVTFNMYEDN	6829829766 Dell Way	\N	PQWKBKE	\N	0	China	2	XVTFNMYEDN@dell.com	6829829766	4	8524918192531914	2010/01	user13030	password	83	20000	M
13031	FCXGMU	CGZPTXUWLJ	6769350722 Dell Way	\N	MITOSXW	\N	0	China	2	CGZPTXUWLJ@dell.com	6769350722	4	9329437314998360	2011/08	user13031	password	86	60000	M
13032	AMANGD	TGTNENJPWV	9336923209 Dell Way	\N	XPKPNGZ	\N	0	Canada	2	TGTNENJPWV@dell.com	9336923209	5	8766475928947330	2010/11	user13032	password	50	40000	M
13033	YIJELD	LEQPSAEOWB	6054558817 Dell Way	\N	EGRSMRW	\N	0	France	2	LEQPSAEOWB@dell.com	6054558817	4	9276642376556992	2009/03	user13033	password	33	40000	F
13034	OQHAUS	FLHXLMLHNQ	9476077516 Dell Way	\N	OFIAWFL	\N	0	France	2	FLHXLMLHNQ@dell.com	9476077516	2	8427813010290266	2008/07	user13034	password	24	40000	F
13035	SODNGI	YOFJBRROHF	1101076372 Dell Way	\N	UQGQVRB	\N	0	Russia	2	YOFJBRROHF@dell.com	1101076372	5	9217848786618560	2010/12	user13035	password	29	80000	M
13036	SUFYDD	NINOZFDHKX	5706963819 Dell Way	\N	YROUIQO	\N	0	China	2	NINOZFDHKX@dell.com	5706963819	3	9156346287112684	2010/08	user13036	password	61	40000	F
13037	KKHNOU	VCJVHNDSLC	9043302844 Dell Way	\N	JZWSPKA	\N	0	Canada	2	VCJVHNDSLC@dell.com	9043302844	5	6769774201326073	2010/07	user13037	password	79	100000	M
13038	GDLVYH	YHDGVHYGJI	1086887327 Dell Way	\N	FFBVQBZ	\N	0	Germany	2	YHDGVHYGJI@dell.com	1086887327	4	1418171405792236	2010/06	user13038	password	83	60000	M
13039	AXOYFN	GITBQSHZBN	9595814989 Dell Way	\N	ECJVDII	\N	0	Canada	2	GITBQSHZBN@dell.com	9595814989	2	7332443930674345	2010/04	user13039	password	30	20000	F
13040	CSGHGM	QZOHRWGSJL	9990290667 Dell Way	\N	UTGYBPD	\N	0	Australia	2	QZOHRWGSJL@dell.com	9990290667	5	5043642361648381	2009/12	user13040	password	62	60000	F
13041	IVKOIA	NWHFTOYCZT	6633270147 Dell Way	\N	WGRXWUY	\N	0	South Africa	2	NWHFTOYCZT@dell.com	6633270147	2	2340787210501730	2011/01	user13041	password	71	80000	F
13042	OCXXDL	ULQNZPQZIM	7704779192 Dell Way	\N	GAKCVIZ	\N	0	France	2	ULQNZPQZIM@dell.com	7704779192	1	1514975602272898	2011/11	user13042	password	73	20000	F
13043	WZHZKB	KBPKQFJZRP	8191008097 Dell Way	\N	ZBSUKRF	\N	0	Canada	2	KBPKQFJZRP@dell.com	8191008097	2	9150180370546878	2011/01	user13043	password	90	20000	M
13044	ZJWKLH	LARCFABWQA	3750471821 Dell Way	\N	YIVJAAN	\N	0	South Africa	2	LARCFABWQA@dell.com	3750471821	3	5103829543571919	2009/05	user13044	password	55	40000	F
13045	WCUIJF	IAINBKKRKJ	6885995520 Dell Way	\N	AGSAGGV	\N	0	Germany	2	IAINBKKRKJ@dell.com	6885995520	2	9225612071808428	2008/10	user13045	password	28	60000	M
13046	GFZQLI	RTWSDHKOQL	5881554512 Dell Way	\N	UJLBPGQ	\N	0	Chile	2	RTWSDHKOQL@dell.com	5881554512	3	3766568507533521	2009/09	user13046	password	72	20000	M
13047	ZAPKIG	EFZIMKXCVS	9708889679 Dell Way	\N	MGUBNKH	\N	0	Australia	2	EFZIMKXCVS@dell.com	9708889679	4	4715224731247872	2011/05	user13047	password	49	80000	F
13048	LFTUMX	ZLFMWDORVA	9841862916 Dell Way	\N	YPCMZJO	\N	0	UK	2	ZLFMWDORVA@dell.com	9841862916	5	6728713814169169	2009/05	user13048	password	37	80000	M
13049	MKQYHQ	KNCGQRYLSX	8800648617 Dell Way	\N	BUJAEXA	\N	0	Canada	2	KNCGQRYLSX@dell.com	8800648617	4	5388016005046666	2009/11	user13049	password	28	20000	F
13050	OTIVJT	JMAADYMWVN	2673187032 Dell Way	\N	QFOVCOY	\N	0	UK	2	JMAADYMWVN@dell.com	2673187032	3	3133290388621390	2008/08	user13050	password	43	60000	F
13051	CVZMOJ	YOJCNVYJIP	8311193848 Dell Way	\N	OWKRKJR	\N	0	Japan	2	YOJCNVYJIP@dell.com	8311193848	5	7230966483708472	2010/03	user13051	password	30	60000	F
13052	ZNVOWT	DGWQBVAJLP	8428093347 Dell Way	\N	GWHRFYH	\N	0	Australia	2	DGWQBVAJLP@dell.com	8428093347	5	4901833614800126	2008/02	user13052	password	89	40000	F
13053	NFRKZU	QVLRRLBDAI	2997571572 Dell Way	\N	ZHZEGGF	\N	0	Australia	2	QVLRRLBDAI@dell.com	2997571572	4	2118064167909324	2009/08	user13053	password	56	60000	F
13054	SDNSXD	OIVFUXIUFH	3879027655 Dell Way	\N	CFMIMRK	\N	0	Japan	2	OIVFUXIUFH@dell.com	3879027655	3	1432839736342430	2012/01	user13054	password	55	20000	M
13055	QPMOTA	WOGQMPLSXO	8565114045 Dell Way	\N	XJXJBIB	\N	0	China	2	WOGQMPLSXO@dell.com	8565114045	1	3876491790637374	2012/08	user13055	password	46	80000	F
13056	ZDVSES	GLJTAVLXJI	9262975750 Dell Way	\N	HHSJPUT	\N	0	France	2	GLJTAVLXJI@dell.com	9262975750	1	4012451557442546	2010/06	user13056	password	18	100000	F
13057	DRDIJK	TSDTNORXXZ	2221474879 Dell Way	\N	FPIVKBG	\N	0	China	2	TSDTNORXXZ@dell.com	2221474879	3	8946190169081093	2010/08	user13057	password	70	100000	M
13058	JCBTMV	MQPAEGYBGD	8074959751 Dell Way	\N	ROYCQFK	\N	0	Russia	2	MQPAEGYBGD@dell.com	8074959751	2	4271916157100350	2009/01	user13058	password	44	20000	F
13059	MEEZAQ	PPQTVOVBSN	4005960100 Dell Way	\N	QQPHVAC	\N	0	Japan	2	PPQTVOVBSN@dell.com	4005960100	3	1034658754710108	2009/10	user13059	password	27	80000	F
13060	IXGIOV	XFPTTLVMYL	3453017712 Dell Way	\N	COTYPVO	\N	0	UK	2	XFPTTLVMYL@dell.com	3453017712	3	3611531801521778	2008/09	user13060	password	21	40000	F
13061	ZPINKF	SAYMLTYKFB	2457704060 Dell Way	\N	ZZAOUPM	\N	0	Australia	2	SAYMLTYKFB@dell.com	2457704060	4	2303673970513046	2012/11	user13061	password	53	100000	M
13062	BFIMLB	MJNYDMIJOH	2281119350 Dell Way	\N	IOWDDJE	\N	0	China	2	MJNYDMIJOH@dell.com	2281119350	2	2509243963751942	2012/10	user13062	password	21	80000	M
13063	GDKREW	BSVFFDOTLW	5704188391 Dell Way	\N	HHZLQET	\N	0	Russia	2	BSVFFDOTLW@dell.com	5704188391	5	7975309668574483	2009/12	user13063	password	59	40000	F
13064	RQXWNY	OIEUMSNYPV	9143875381 Dell Way	\N	FOGWTZR	\N	0	Chile	2	OIEUMSNYPV@dell.com	9143875381	3	6662822089157999	2012/01	user13064	password	82	20000	M
13065	NZOAYD	JCXWUKUJGZ	9771426489 Dell Way	\N	YMWSMNZ	\N	0	China	2	JCXWUKUJGZ@dell.com	9771426489	4	3206933840177953	2012/06	user13065	password	41	80000	F
13066	HGAFJK	IHGCSAMYAK	7272488822 Dell Way	\N	KXCXLCH	\N	0	France	2	IHGCSAMYAK@dell.com	7272488822	3	4539160080719739	2008/11	user13066	password	23	20000	F
13067	IFJRQR	ZWURXGPYRA	7392757193 Dell Way	\N	WUXHWES	\N	0	Germany	2	ZWURXGPYRA@dell.com	7392757193	1	7669554152060301	2010/02	user13067	password	85	80000	F
13068	DBETSD	QNVOTKNKLJ	5103255094 Dell Way	\N	EJRBOJP	\N	0	Chile	2	QNVOTKNKLJ@dell.com	5103255094	2	8267491233535112	2011/04	user13068	password	54	20000	F
13069	OGEHKV	UFKNQXYBHD	2125479381 Dell Way	\N	LYEZIUF	\N	0	Russia	2	UFKNQXYBHD@dell.com	2125479381	1	4479172555729747	2009/07	user13069	password	53	100000	F
13070	TZJEVD	JGRADQCLTN	7693560693 Dell Way	\N	KYMSSSL	\N	0	South Africa	2	JGRADQCLTN@dell.com	7693560693	5	3205535776447505	2009/04	user13070	password	21	40000	F
13071	BSGWWQ	COQGESSYFC	1709863572 Dell Way	\N	XSUQKGM	\N	0	Canada	2	COQGESSYFC@dell.com	1709863572	4	4889444281812757	2010/10	user13071	password	75	60000	M
13072	NTSKJV	YZBDSTCYVZ	8305710578 Dell Way	\N	QQQBWCF	\N	0	UK	2	YZBDSTCYVZ@dell.com	8305710578	4	4089248729404062	2010/06	user13072	password	79	60000	M
13073	PCIYXH	YZKQTMOPMF	1499883327 Dell Way	\N	FCGBFLZ	\N	0	Australia	2	YZKQTMOPMF@dell.com	1499883327	2	6321202957071365	2010/03	user13073	password	18	60000	M
13074	CTSAAQ	AKHTXWJKBO	9585251306 Dell Way	\N	MHQRSQS	\N	0	Russia	2	AKHTXWJKBO@dell.com	9585251306	2	3085557738319039	2008/04	user13074	password	65	100000	F
13075	JPLKGL	UNFSJOCKDP	3516550576 Dell Way	\N	RTHKJZD	\N	0	China	2	UNFSJOCKDP@dell.com	3516550576	2	4958797678351402	2010/01	user13075	password	42	100000	F
13076	YKUEVP	SBIBPLMSBE	1689084981 Dell Way	\N	MIOVISD	\N	0	Japan	2	SBIBPLMSBE@dell.com	1689084981	3	2625910517293960	2008/11	user13076	password	28	60000	M
13077	OHAKXS	LFUBQGURLG	7670150323 Dell Way	\N	AZBJREZ	\N	0	Russia	2	LFUBQGURLG@dell.com	7670150323	1	8750656972639264	2011/04	user13077	password	44	60000	M
13078	QMFOER	TYSKFMBQSC	6027428243 Dell Way	\N	PULHYKB	\N	0	Japan	2	TYSKFMBQSC@dell.com	6027428243	5	3965933491010219	2012/04	user13078	password	76	80000	M
13079	GXMLPF	JHQOURENUU	1658594639 Dell Way	\N	HFCGQDY	\N	0	Canada	2	JHQOURENUU@dell.com	1658594639	2	1406836122274398	2009/01	user13079	password	71	40000	F
13080	RTTGZC	OPRIHWVCQD	5834837795 Dell Way	\N	HTJYWHD	\N	0	UK	2	OPRIHWVCQD@dell.com	5834837795	1	3783600861672312	2010/11	user13080	password	61	100000	M
13081	JQVJTJ	ZLSGHOJYRQ	8937756289 Dell Way	\N	RAPNISM	\N	0	South Africa	2	ZLSGHOJYRQ@dell.com	8937756289	4	4965048268903047	2011/05	user13081	password	42	40000	M
13082	ZECTOC	EGJLUSJMIA	8698838869 Dell Way	\N	MYOVQBR	\N	0	Germany	2	EGJLUSJMIA@dell.com	8698838869	1	3814258640632033	2009/06	user13082	password	67	20000	F
13083	WDEKFI	QOULGEXPEK	9923344151 Dell Way	\N	NTFEVWR	\N	0	Japan	2	QOULGEXPEK@dell.com	9923344151	5	9281740032136440	2010/09	user13083	password	86	100000	M
13084	BBYHKO	VEACIXRNHF	1435790585 Dell Way	\N	HNJCKBT	\N	0	China	2	VEACIXRNHF@dell.com	1435790585	4	8504038222134114	2011/08	user13084	password	69	40000	M
13085	TEYDTU	ITWRQNEYTM	9985790603 Dell Way	\N	MCOWEIG	\N	0	Chile	2	ITWRQNEYTM@dell.com	9985790603	1	9320045727770776	2011/10	user13085	password	30	40000	M
13086	IGSBAA	VWRMKWKDIX	2089254808 Dell Way	\N	GWTKFAP	\N	0	Chile	2	VWRMKWKDIX@dell.com	2089254808	3	8313833753578366	2012/09	user13086	password	25	60000	F
13087	IFCIFY	FXKPUVTCSZ	5532504106 Dell Way	\N	ZLJEMZK	\N	0	Japan	2	FXKPUVTCSZ@dell.com	5532504106	2	5751505353953690	2008/04	user13087	password	19	40000	M
13088	FIZLHE	JRUDMNGENF	9926383756 Dell Way	\N	QXKCWUS	\N	0	China	2	JRUDMNGENF@dell.com	9926383756	2	6216583515983075	2009/04	user13088	password	77	100000	F
13089	EXXLCH	CXKOLQTYWJ	4938537482 Dell Way	\N	WGMSBFC	\N	0	Australia	2	CXKOLQTYWJ@dell.com	4938537482	4	3996414839290083	2011/07	user13089	password	37	20000	M
13090	ECCGJE	EUTPKMOGWK	9236741810 Dell Way	\N	NJDOOFP	\N	0	Australia	2	EUTPKMOGWK@dell.com	9236741810	5	7293135248124600	2010/03	user13090	password	81	20000	F
13091	ZEQIIU	CCKNPYUMIH	4640063291 Dell Way	\N	VLWKRMK	\N	0	Germany	2	CCKNPYUMIH@dell.com	4640063291	1	1033470515161752	2011/12	user13091	password	23	100000	M
13092	GQGOKJ	RVWGTRSBYO	4998973917 Dell Way	\N	NUYFHIU	\N	0	Japan	2	RVWGTRSBYO@dell.com	4998973917	4	3544534147251397	2010/11	user13092	password	37	40000	F
13093	WQRHZI	CWOWNGYMUL	2883176242 Dell Way	\N	HTQOCLG	\N	0	Germany	2	CWOWNGYMUL@dell.com	2883176242	3	9474622451700272	2008/10	user13093	password	39	20000	M
13094	XVYXDB	URXHYWUTHB	4384935715 Dell Way	\N	MYQOJWC	\N	0	Germany	2	URXHYWUTHB@dell.com	4384935715	1	6814272861927748	2008/04	user13094	password	76	100000	F
13095	QTDTVX	LTFJPZDXBP	3449557737 Dell Way	\N	VREFOGU	\N	0	UK	2	LTFJPZDXBP@dell.com	3449557737	3	1625045727938413	2010/03	user13095	password	82	100000	M
13096	QZQMWB	FCLVBOSDDO	9867713103 Dell Way	\N	VITJOOG	\N	0	South Africa	2	FCLVBOSDDO@dell.com	9867713103	2	4818982801865786	2009/03	user13096	password	36	20000	M
13097	FSICTO	EEJGTCJXQE	2241278748 Dell Way	\N	FKNTZUP	\N	0	UK	2	EEJGTCJXQE@dell.com	2241278748	1	2627157509792596	2009/04	user13097	password	37	40000	F
13098	ZOOSCT	XMZQOINFNT	2064969350 Dell Way	\N	QBNPWCO	\N	0	Australia	2	XMZQOINFNT@dell.com	2064969350	4	4223892617039383	2009/01	user13098	password	59	100000	M
13099	DLSFEQ	SDGHMUMAOD	1565310238 Dell Way	\N	CBTYDIY	\N	0	Chile	2	SDGHMUMAOD@dell.com	1565310238	2	6870131063275040	2008/11	user13099	password	56	20000	F
13100	YUFDKY	HQFTLSUZVW	1520710370 Dell Way	\N	BPUEXTL	\N	0	UK	2	HQFTLSUZVW@dell.com	1520710370	1	1359736045822501	2012/08	user13100	password	25	100000	M
13101	WESGCZ	XITJANJWJK	2334490465 Dell Way	\N	LEPJXBI	\N	0	UK	2	XITJANJWJK@dell.com	2334490465	2	9243009147699924	2011/06	user13101	password	80	40000	F
13102	ACPDBN	MUWMIGJSQU	8329829178 Dell Way	\N	WGEUHMT	\N	0	France	2	MUWMIGJSQU@dell.com	8329829178	4	2803907791618258	2009/07	user13102	password	59	60000	M
13103	QESSRE	NORVUANLVK	6436385838 Dell Way	\N	RZEYLYJ	\N	0	Chile	2	NORVUANLVK@dell.com	6436385838	3	5739399719052017	2008/02	user13103	password	26	80000	M
13104	HKMZPZ	OGVJHJUCTL	4122113496 Dell Way	\N	CXKNVUU	\N	0	France	2	OGVJHJUCTL@dell.com	4122113496	2	6243667352013291	2010/06	user13104	password	38	40000	M
13105	SSTHSH	ONQVWLYQXA	6787074545 Dell Way	\N	NHOJBIV	\N	0	France	2	ONQVWLYQXA@dell.com	6787074545	2	9121091000735760	2008/09	user13105	password	29	100000	F
13106	XORPWG	DNBAYZQVAE	7769640228 Dell Way	\N	DONFXJQ	\N	0	Germany	2	DNBAYZQVAE@dell.com	7769640228	3	6455763474106789	2010/09	user13106	password	49	100000	M
13107	ZNEVTH	IVIHVYCVDG	6449384933 Dell Way	\N	JRLGABU	\N	0	Russia	2	IVIHVYCVDG@dell.com	6449384933	3	2790658181998879	2009/10	user13107	password	20	100000	M
13108	OAQHIZ	CRGXQJTTPD	6317779683 Dell Way	\N	KBKKDEE	\N	0	Russia	2	CRGXQJTTPD@dell.com	6317779683	2	1151772164274007	2010/05	user13108	password	82	40000	M
13109	XWFGWI	YCGOMAHBDR	6309404808 Dell Way	\N	CNBGSGY	\N	0	China	2	YCGOMAHBDR@dell.com	6309404808	5	7519354667514563	2012/11	user13109	password	87	100000	M
13110	VDARLY	USNGSUIVLL	6474350914 Dell Way	\N	JNRCTQK	\N	0	China	2	USNGSUIVLL@dell.com	6474350914	1	3913878473453224	2010/01	user13110	password	34	40000	M
13111	JHOVGJ	NTQGNYCZKL	1332385635 Dell Way	\N	NCNGSXP	\N	0	China	2	NTQGNYCZKL@dell.com	1332385635	5	8069522532634438	2008/02	user13111	password	19	100000	M
13112	HOINYW	HOCUNEUXQH	1631537595 Dell Way	\N	ZENSCDA	\N	0	Canada	2	HOCUNEUXQH@dell.com	1631537595	5	2967709248419851	2009/11	user13112	password	33	80000	F
13113	UCRSYY	HATUFNSVUS	3451781301 Dell Way	\N	ZIKBLLE	\N	0	Germany	2	HATUFNSVUS@dell.com	3451781301	3	7831881554797293	2008/08	user13113	password	54	40000	F
13114	PYDNWK	OPFTDXPXQP	3148767111 Dell Way	\N	GBRRNVF	\N	0	Russia	2	OPFTDXPXQP@dell.com	3148767111	5	9019646842498332	2012/06	user13114	password	28	40000	F
13115	BJPYUD	OZXRXNPNCV	7432892884 Dell Way	\N	OTNBPTW	\N	0	South Africa	2	OZXRXNPNCV@dell.com	7432892884	4	7175357015337796	2008/11	user13115	password	86	40000	M
13116	IWXCAM	CXDZLTMNOB	7645984797 Dell Way	\N	HCDWVZS	\N	0	Germany	2	CXDZLTMNOB@dell.com	7645984797	2	7681451391894371	2011/04	user13116	password	18	60000	M
13117	WMTWYV	UCUFWHTLJA	9826675083 Dell Way	\N	NNXJNPX	\N	0	Chile	2	UCUFWHTLJA@dell.com	9826675083	4	8803310940042139	2009/08	user13117	password	51	100000	M
13118	YSKXOE	AJKWRDHADV	7233759099 Dell Way	\N	NAEAQBG	\N	0	Japan	2	AJKWRDHADV@dell.com	7233759099	1	9256584725342692	2009/08	user13118	password	82	100000	M
13119	PGLDKL	NUIEYQEBLS	2189410332 Dell Way	\N	CPSSRZI	\N	0	China	2	NUIEYQEBLS@dell.com	2189410332	2	7171989820431919	2011/02	user13119	password	57	40000	M
13120	USWEEJ	ZMNXCSZNKC	4666837081 Dell Way	\N	DDVUDED	\N	0	Chile	2	ZMNXCSZNKC@dell.com	4666837081	5	9887407713569702	2010/05	user13120	password	36	40000	F
13121	YDICNI	PBFRTFFEHJ	1879568038 Dell Way	\N	IDDLHHS	\N	0	Japan	2	PBFRTFFEHJ@dell.com	1879568038	4	3071555999573320	2010/12	user13121	password	54	60000	M
13122	QXAEFP	GLHAQNEYWM	3983116237 Dell Way	\N	CAYJHQB	\N	0	China	2	GLHAQNEYWM@dell.com	3983116237	2	8561209222301842	2009/10	user13122	password	49	20000	F
13123	IEPOTW	ZBWQOAPLNR	4402877447 Dell Way	\N	LLBSCCC	\N	0	France	2	ZBWQOAPLNR@dell.com	4402877447	5	7179013054817916	2008/05	user13123	password	80	80000	M
13124	AFGUBG	VYXKYMVMEG	1292561613 Dell Way	\N	XFZZHCK	\N	0	Japan	2	VYXKYMVMEG@dell.com	1292561613	1	8528938920237125	2010/12	user13124	password	49	20000	M
13125	QJTSQP	QNZPZUBEBZ	5512907120 Dell Way	\N	JAZQDKI	\N	0	Canada	2	QNZPZUBEBZ@dell.com	5512907120	1	6068242965731770	2010/08	user13125	password	67	60000	F
13126	BEZRUQ	FUFFPHJQHS	8674471704 Dell Way	\N	RHJURRY	\N	0	Canada	2	FUFFPHJQHS@dell.com	8674471704	3	6710220829583705	2010/03	user13126	password	22	80000	F
13127	GRYAHD	UNIJUSACKS	9680919311 Dell Way	\N	JUMBMLF	\N	0	China	2	UNIJUSACKS@dell.com	9680919311	5	7962791631463916	2008/12	user13127	password	52	60000	F
13128	DJFLNA	YWKTOKWZCF	4075094561 Dell Way	\N	TPGFBMN	\N	0	Australia	2	YWKTOKWZCF@dell.com	4075094561	2	2559221740346402	2009/10	user13128	password	61	60000	M
13129	YQJMQI	IBCWLYVODP	6712467234 Dell Way	\N	EKUFXIF	\N	0	Chile	2	IBCWLYVODP@dell.com	6712467234	2	5461019116919488	2010/12	user13129	password	86	40000	M
13130	OTKFBS	HEPSCLHGAL	3141356289 Dell Way	\N	RVQODWU	\N	0	Russia	2	HEPSCLHGAL@dell.com	3141356289	2	2709929168224335	2009/03	user13130	password	57	20000	M
13131	HOAJHH	NXAQIHXITO	2922599568 Dell Way	\N	DJDHGYB	\N	0	France	2	NXAQIHXITO@dell.com	2922599568	2	7225799765437842	2010/10	user13131	password	79	40000	F
13132	KGLSOY	POPXWMGQBK	9905785807 Dell Way	\N	AFRGDTS	\N	0	China	2	POPXWMGQBK@dell.com	9905785807	3	7933493200223894	2011/04	user13132	password	18	100000	M
13133	GHJVGY	KVWHICXKNX	3575954101 Dell Way	\N	PEDSYWB	\N	0	UK	2	KVWHICXKNX@dell.com	3575954101	5	7330707120709122	2010/10	user13133	password	59	40000	F
13134	WOXCNH	YJOHMMRZJH	9119684299 Dell Way	\N	ENACKBA	\N	0	Japan	2	YJOHMMRZJH@dell.com	9119684299	4	3079747964628041	2011/04	user13134	password	50	100000	F
13135	ASGOAF	XPMKBEJLMO	4737682573 Dell Way	\N	YMRJORA	\N	0	France	2	XPMKBEJLMO@dell.com	4737682573	2	2746570733375847	2011/09	user13135	password	19	100000	M
13136	TCHTHF	JUPKYZVLNU	4936923995 Dell Way	\N	XFDMWEY	\N	0	Chile	2	JUPKYZVLNU@dell.com	4936923995	1	1034802475012838	2008/02	user13136	password	80	100000	M
13137	YDQGIA	AYKZXGKLAI	8674324430 Dell Way	\N	QEUNISV	\N	0	Russia	2	AYKZXGKLAI@dell.com	8674324430	5	9288631867617370	2012/09	user13137	password	76	100000	M
13138	YNWHOX	GYXDFHPGQG	4835628984 Dell Way	\N	KKUTDPN	\N	0	UK	2	GYXDFHPGQG@dell.com	4835628984	3	9950855200178922	2008/03	user13138	password	82	80000	F
13139	KQMYNS	XLWDSLJJST	4865434383 Dell Way	\N	UMMXBAX	\N	0	France	2	XLWDSLJJST@dell.com	4865434383	5	6409204805735499	2011/10	user13139	password	43	100000	F
13140	ZIENAC	YXFRIOABIU	5977533657 Dell Way	\N	NVSOVQB	\N	0	Chile	2	YXFRIOABIU@dell.com	5977533657	4	9068622692488136	2009/01	user13140	password	71	60000	M
13141	BSMCUL	ZACHODIWXW	2355836343 Dell Way	\N	RQKMHMT	\N	0	South Africa	2	ZACHODIWXW@dell.com	2355836343	4	2604468230158090	2008/05	user13141	password	71	20000	F
13142	LQMGBL	GETVHCRFYJ	2986601810 Dell Way	\N	WJWDWPZ	\N	0	Australia	2	GETVHCRFYJ@dell.com	2986601810	1	2566236198879778	2010/11	user13142	password	41	100000	F
13143	YMOAYV	FSQMVISTRO	8154278853 Dell Way	\N	DORADQA	\N	0	China	2	FSQMVISTRO@dell.com	8154278853	1	9457116444595160	2011/07	user13143	password	86	100000	F
13144	LONJJS	CAEXIXRZLV	1284497480 Dell Way	\N	NDVRUVA	\N	0	Germany	2	CAEXIXRZLV@dell.com	1284497480	5	3158097921870649	2010/11	user13144	password	34	20000	F
13145	UNSEFU	EKSMHKMSFA	6946845170 Dell Way	\N	WARQWSF	\N	0	South Africa	2	EKSMHKMSFA@dell.com	6946845170	3	4971494409255684	2010/09	user13145	password	51	100000	F
13146	ZPQEKU	PDHWNTPSTL	7342630361 Dell Way	\N	TLBQDGN	\N	0	Russia	2	PDHWNTPSTL@dell.com	7342630361	5	4135784687008709	2009/05	user13146	password	35	100000	F
13147	WLOHGD	KNAYHPRABK	5551680983 Dell Way	\N	LDAPKOJ	\N	0	Australia	2	KNAYHPRABK@dell.com	5551680983	4	5243851964361966	2012/12	user13147	password	40	40000	M
13148	TWCAAN	NALVQCVSNH	9627728000 Dell Way	\N	VOWFCGI	\N	0	Germany	2	NALVQCVSNH@dell.com	9627728000	4	5654246489517391	2012/02	user13148	password	77	80000	M
13149	RVWSIK	TUFJXBBKJX	3015759698 Dell Way	\N	YFDAMLQ	\N	0	France	2	TUFJXBBKJX@dell.com	3015759698	1	4133227540180087	2009/12	user13149	password	24	20000	M
13150	XAJGLC	BQMYROIALH	1883998335 Dell Way	\N	GOISAYE	\N	0	Chile	2	BQMYROIALH@dell.com	1883998335	3	5916970878373832	2008/08	user13150	password	69	80000	M
13151	TCUEFV	URTMFBNRJU	2522450871 Dell Way	\N	GRNGPRM	\N	0	Russia	2	URTMFBNRJU@dell.com	2522450871	1	7997372375801206	2011/09	user13151	password	54	40000	F
13152	PBQUWL	MPXRRLJAFQ	4714833237 Dell Way	\N	SSWHJJA	\N	0	Germany	2	MPXRRLJAFQ@dell.com	4714833237	4	3627844929695129	2008/04	user13152	password	59	80000	M
13153	PHRMTE	BQVTCFUHVM	6287239749 Dell Way	\N	ZSUICUW	\N	0	Germany	2	BQVTCFUHVM@dell.com	6287239749	1	7094667748548091	2012/09	user13153	password	41	80000	F
13154	QMUJQW	AMQCRKJNXI	7412229745 Dell Way	\N	GRRJMOW	\N	0	Australia	2	AMQCRKJNXI@dell.com	7412229745	3	9574817287269980	2010/11	user13154	password	71	80000	F
13155	FPWVLW	HCYZNINKQU	6185504843 Dell Way	\N	CIDOXAQ	\N	0	Germany	2	HCYZNINKQU@dell.com	6185504843	3	1330935390666127	2010/04	user13155	password	77	100000	M
13156	KVJVRR	YPQLXEVOYY	7471580983 Dell Way	\N	XCMUCDK	\N	0	Japan	2	YPQLXEVOYY@dell.com	7471580983	3	2300702602602541	2008/03	user13156	password	25	60000	M
13157	XXMOPK	EFVCKRRIPP	2621399205 Dell Way	\N	LCJOGTF	\N	0	UK	2	EFVCKRRIPP@dell.com	2621399205	2	9923855581320824	2010/06	user13157	password	58	20000	F
13158	MNYBXD	HTGRLXABML	6137844273 Dell Way	\N	DWZJPFI	\N	0	Russia	2	HTGRLXABML@dell.com	6137844273	2	2899077739100903	2008/11	user13158	password	36	60000	F
13159	TJKRNS	LTJWRJXEUB	1723341190 Dell Way	\N	AULQZTL	\N	0	Germany	2	LTJWRJXEUB@dell.com	1723341190	4	6296709292568267	2012/11	user13159	password	18	40000	M
13160	KTIXLU	RUQIEOMZQN	3135264259 Dell Way	\N	TBESVPH	\N	0	UK	2	RUQIEOMZQN@dell.com	3135264259	5	8771031153853984	2008/11	user13160	password	31	80000	F
13161	XDEIXV	DOEIDRHTEA	9016376081 Dell Way	\N	VITQYAO	\N	0	Canada	2	DOEIDRHTEA@dell.com	9016376081	3	3696508499793708	2011/08	user13161	password	24	20000	M
13162	FEVDAZ	SEHVVOPZPK	1057041260 Dell Way	\N	IJBGKPL	\N	0	Chile	2	SEHVVOPZPK@dell.com	1057041260	4	1420892997179180	2010/10	user13162	password	22	20000	F
13163	GYFGXX	LFTGUIGJSP	1088327062 Dell Way	\N	TTWDJHL	\N	0	China	2	LFTGUIGJSP@dell.com	1088327062	3	9663144077174366	2012/07	user13163	password	22	100000	M
13164	ACBXZM	DSTXBZHTPA	1665479865 Dell Way	\N	NLEXSPG	\N	0	Russia	2	DSTXBZHTPA@dell.com	1665479865	2	6053818510845304	2011/04	user13164	password	50	60000	F
13165	NMFNYI	GSGHRNBHOO	9237394311 Dell Way	\N	STLLJSE	\N	0	France	2	GSGHRNBHOO@dell.com	9237394311	4	1333398102782666	2008/03	user13165	password	50	60000	M
13166	XRFWZM	OGTGTUNIJF	5782019718 Dell Way	\N	CUQLNVW	\N	0	France	2	OGTGTUNIJF@dell.com	5782019718	5	6530293098185212	2011/05	user13166	password	23	60000	F
13167	TQCTCQ	ZVXTQKBZQE	4025308923 Dell Way	\N	UHPHCLS	\N	0	Japan	2	ZVXTQKBZQE@dell.com	4025308923	2	3922872473485768	2011/05	user13167	password	70	100000	F
13168	JAXLRW	GOPWZRWPVQ	9631323284 Dell Way	\N	WLXZWQP	\N	0	Chile	2	GOPWZRWPVQ@dell.com	9631323284	5	8931929031386972	2009/08	user13168	password	76	60000	M
13169	VKLMHR	AWOAOLPKBM	9455515999 Dell Way	\N	VZLSPAX	\N	0	Germany	2	AWOAOLPKBM@dell.com	9455515999	4	9393623448442668	2010/08	user13169	password	50	60000	F
13170	WAXDSY	AGYPSNZTZV	3297545612 Dell Way	\N	SKOILLX	\N	0	China	2	AGYPSNZTZV@dell.com	3297545612	5	9616589075885714	2012/04	user13170	password	56	40000	F
13171	NDHFBI	MZXENXYMSR	7521487509 Dell Way	\N	XHZISXS	\N	0	UK	2	MZXENXYMSR@dell.com	7521487509	4	8485559071879835	2008/03	user13171	password	24	20000	M
13172	GLZHTL	HRQVOOHHGF	9509535152 Dell Way	\N	OFOHDHG	\N	0	South Africa	2	HRQVOOHHGF@dell.com	9509535152	1	8702550317626447	2008/03	user13172	password	18	100000	F
13173	LWSFHA	WYVKNDSTIG	8911609470 Dell Way	\N	ZXNCEUY	\N	0	Canada	2	WYVKNDSTIG@dell.com	8911609470	5	3313464665319771	2008/10	user13173	password	28	60000	F
13174	AFMHFI	GATUELNMRN	4634216273 Dell Way	\N	JFQOZPQ	\N	0	South Africa	2	GATUELNMRN@dell.com	4634216273	5	9444413997232916	2009/01	user13174	password	48	60000	F
13175	PZJVIP	VBKANXMELW	9817943332 Dell Way	\N	KBLKRBH	\N	0	Australia	2	VBKANXMELW@dell.com	9817943332	2	3636483013164252	2008/08	user13175	password	76	20000	F
13176	ULBCBX	ELXRJKVVHG	2173355689 Dell Way	\N	XSQOUXP	\N	0	Russia	2	ELXRJKVVHG@dell.com	2173355689	5	8042391996830703	2011/09	user13176	password	81	100000	F
13177	IAOJYS	VVKFFFAMMX	9698315795 Dell Way	\N	ECLYABS	\N	0	Canada	2	VVKFFFAMMX@dell.com	9698315795	3	9277327199000866	2011/05	user13177	password	84	20000	M
13178	YSBWLW	SVBXBCKNZP	7373838705 Dell Way	\N	QLNRNFW	\N	0	France	2	SVBXBCKNZP@dell.com	7373838705	4	2259151484351605	2008/09	user13178	password	38	80000	M
13179	ATNLQF	HSDJUNXUCO	8544068607 Dell Way	\N	GQFTWBF	\N	0	Germany	2	HSDJUNXUCO@dell.com	8544068607	2	6553728023543955	2010/08	user13179	password	42	20000	M
13180	CQCTWK	MZTHMQBPEI	6886638714 Dell Way	\N	FKBBMHQ	\N	0	China	2	MZTHMQBPEI@dell.com	6886638714	2	8449484684970231	2009/07	user13180	password	88	100000	M
13181	QBLMLX	LFEYVGNAOT	6943439729 Dell Way	\N	KQUXYKF	\N	0	Germany	2	LFEYVGNAOT@dell.com	6943439729	1	8997110323049129	2009/01	user13181	password	79	100000	M
13182	XJCJHN	OLMKSZLHSV	9741045095 Dell Way	\N	YNTWYYL	\N	0	Japan	2	OLMKSZLHSV@dell.com	9741045095	2	8674099305178971	2012/03	user13182	password	75	60000	F
13183	ERLLFA	XRLPRWXKSV	5160867682 Dell Way	\N	XLRWKDM	\N	0	China	2	XRLPRWXKSV@dell.com	5160867682	2	4044124317821115	2011/02	user13183	password	85	80000	F
13184	PESVFP	MRFDODNGYL	2416823100 Dell Way	\N	SQICUVM	\N	0	Chile	2	MRFDODNGYL@dell.com	2416823100	5	8863049333915115	2009/09	user13184	password	62	60000	F
13185	UHDAXQ	RDUFGIMFUF	6321554146 Dell Way	\N	VCHPYUV	\N	0	Australia	2	RDUFGIMFUF@dell.com	6321554146	4	4251103363465518	2009/04	user13185	password	85	80000	F
13186	FVDCLU	FGALONQISM	6979468359 Dell Way	\N	LZCJUYL	\N	0	China	2	FGALONQISM@dell.com	6979468359	4	7267452832777054	2012/09	user13186	password	45	20000	M
13187	FFZRAF	XBQLOHUGUF	8034669690 Dell Way	\N	GWOAVZJ	\N	0	France	2	XBQLOHUGUF@dell.com	8034669690	1	5305277999956161	2010/06	user13187	password	60	60000	M
13188	UKIVPF	WGRLNLRIQY	4578705313 Dell Way	\N	FEYAEIN	\N	0	UK	2	WGRLNLRIQY@dell.com	4578705313	5	5074950035661459	2012/07	user13188	password	80	60000	F
13189	GUFWAC	CRNQCFYTDD	7162001538 Dell Way	\N	YCECKRB	\N	0	South Africa	2	CRNQCFYTDD@dell.com	7162001538	3	6868595171719790	2009/05	user13189	password	28	80000	M
13190	YVMZYP	QMFTREMVIK	1851805918 Dell Way	\N	XMNIEPD	\N	0	South Africa	2	QMFTREMVIK@dell.com	1851805918	4	2187271467875689	2010/12	user13190	password	73	20000	M
13191	PPVOEM	AKGSPSNXDL	7002827331 Dell Way	\N	KRTPGXM	\N	0	China	2	AKGSPSNXDL@dell.com	7002827331	4	8245821017306299	2010/05	user13191	password	84	60000	M
13192	MINRUO	CAGRTTPXFA	7658055102 Dell Way	\N	OYQUVDD	\N	0	Germany	2	CAGRTTPXFA@dell.com	7658055102	5	1902222026605159	2008/11	user13192	password	59	20000	F
13193	XQASFD	TLVMFKKKLY	8647642946 Dell Way	\N	ICTEFXR	\N	0	UK	2	TLVMFKKKLY@dell.com	8647642946	4	1687622963450849	2011/05	user13193	password	31	20000	F
13194	VCYAFR	LAEQLOBXNJ	1287985219 Dell Way	\N	ZHOFEGE	\N	0	Australia	2	LAEQLOBXNJ@dell.com	1287985219	2	7601637669373304	2009/06	user13194	password	75	80000	F
13195	WPHBHT	CLKOALLNVK	1075661331 Dell Way	\N	VJQZQUA	\N	0	Japan	2	CLKOALLNVK@dell.com	1075661331	4	1455861840397119	2010/07	user13195	password	68	80000	F
13196	HZMOSP	ACDAOOOJZJ	2436905520 Dell Way	\N	TPJJJKA	\N	0	China	2	ACDAOOOJZJ@dell.com	2436905520	1	8374613733030856	2011/10	user13196	password	54	20000	F
13197	MPQEFQ	HIQWXFFWPZ	5248714008 Dell Way	\N	MYJWJJG	\N	0	Germany	2	HIQWXFFWPZ@dell.com	5248714008	1	2941637556534260	2009/07	user13197	password	42	40000	F
13198	YYGDON	MFKJLPGAOS	9228208492 Dell Way	\N	ZXPIHVV	\N	0	Russia	2	MFKJLPGAOS@dell.com	9228208492	1	1276814037002623	2010/05	user13198	password	43	60000	F
13199	HUMWIY	CSINIONWHM	6926400539 Dell Way	\N	UWUCSQX	\N	0	Japan	2	CSINIONWHM@dell.com	6926400539	5	2137090170290321	2008/04	user13199	password	66	40000	M
13200	LVLTUN	MCAURORYBM	4489946452 Dell Way	\N	VWPOMMF	\N	0	Canada	2	MCAURORYBM@dell.com	4489946452	2	2519444731529802	2011/12	user13200	password	56	40000	F
13201	JQFDER	GFLXTDWVPS	7892394449 Dell Way	\N	REGDQLH	\N	0	Australia	2	GFLXTDWVPS@dell.com	7892394449	3	7261127643287183	2011/12	user13201	password	84	20000	F
13202	OKMSBS	XNPRRLMGDE	1582590420 Dell Way	\N	LKICWPD	\N	0	Japan	2	XNPRRLMGDE@dell.com	1582590420	5	4354709579143673	2008/09	user13202	password	59	40000	F
13203	YVAAOY	ODQFPDMTHY	9959826175 Dell Way	\N	EQAAGEQ	\N	0	China	2	ODQFPDMTHY@dell.com	9959826175	1	4119571638759226	2011/07	user13203	password	70	20000	M
13204	OBOCAD	GRJVUWPCUT	4530176838 Dell Way	\N	TVTZZKH	\N	0	UK	2	GRJVUWPCUT@dell.com	4530176838	4	7411839756648988	2012/05	user13204	password	73	60000	M
13205	VBAWEG	NNCIJSKDLE	1115568997 Dell Way	\N	YFDYPKX	\N	0	UK	2	NNCIJSKDLE@dell.com	1115568997	4	9551435964182020	2009/05	user13205	password	49	40000	F
13206	MHBQNP	EQXNIIRUMQ	1991123190 Dell Way	\N	ZPPPAMP	\N	0	Australia	2	EQXNIIRUMQ@dell.com	1991123190	3	4384971585590392	2010/12	user13206	password	64	80000	F
13207	XUCLJG	CHULQLFCCF	9549863879 Dell Way	\N	SRVTEKT	\N	0	Chile	2	CHULQLFCCF@dell.com	9549863879	1	7903273824136705	2012/10	user13207	password	52	40000	M
13208	GLDQSF	XMRNYWQBCJ	9714537024 Dell Way	\N	TXCXIVE	\N	0	Chile	2	XMRNYWQBCJ@dell.com	9714537024	5	2825150476302951	2011/05	user13208	password	59	60000	M
13209	AOHTUE	GLSFIIGLRZ	1024147403 Dell Way	\N	IUWRPBY	\N	0	Germany	2	GLSFIIGLRZ@dell.com	1024147403	1	3821458058431745	2010/09	user13209	password	71	20000	M
13210	HJNBNT	NGYVOFGGEP	4308436075 Dell Way	\N	ABGQDFF	\N	0	Canada	2	NGYVOFGGEP@dell.com	4308436075	3	5861006528604776	2008/04	user13210	password	63	100000	M
13211	ZJPNDC	TBYIGEPLUP	9908735135 Dell Way	\N	NBGQGMT	\N	0	Japan	2	TBYIGEPLUP@dell.com	9908735135	2	7490196033846588	2009/11	user13211	password	60	80000	M
13212	YKKBND	DLMKQBWKRJ	1268063430 Dell Way	\N	MXZSJTJ	\N	0	China	2	DLMKQBWKRJ@dell.com	1268063430	1	6589837258215994	2012/08	user13212	password	48	100000	M
13213	VFRIJV	UWGLXCWPLI	5079287968 Dell Way	\N	NLAWEJG	\N	0	Chile	2	UWGLXCWPLI@dell.com	5079287968	5	2353050047997385	2008/04	user13213	password	89	80000	F
13214	FJLOFF	KLRINNXZVK	4876446724 Dell Way	\N	LWHPGOV	\N	0	Japan	2	KLRINNXZVK@dell.com	4876446724	5	8148472391068936	2011/12	user13214	password	54	100000	F
13215	WHSCMD	NELBRJAMTL	8661895681 Dell Way	\N	IBBOQWG	\N	0	Australia	2	NELBRJAMTL@dell.com	8661895681	1	7965671452227981	2011/07	user13215	password	62	100000	F
13216	WQNJTB	NECEODRIPZ	8860729055 Dell Way	\N	JQOANVB	\N	0	China	2	NECEODRIPZ@dell.com	8860729055	5	2573421966750175	2010/06	user13216	password	25	100000	F
13217	TJRMKF	RNKFQCNFBX	8198749338 Dell Way	\N	WQXKLZU	\N	0	China	2	RNKFQCNFBX@dell.com	8198749338	5	7813398033380509	2009/01	user13217	password	62	60000	M
13218	ZGGKLY	XWDOYRUAPQ	8059483074 Dell Way	\N	RNBDMVL	\N	0	Chile	2	XWDOYRUAPQ@dell.com	8059483074	2	5673488191794605	2012/10	user13218	password	22	80000	M
13219	HXFTVD	QZSPRMQHDH	1669706896 Dell Way	\N	UEKHZWO	\N	0	Russia	2	QZSPRMQHDH@dell.com	1669706896	1	6643009298481048	2012/02	user13219	password	37	80000	F
13220	EYFACV	AULRHBYKIT	6982582143 Dell Way	\N	OTAOPPJ	\N	0	Japan	2	AULRHBYKIT@dell.com	6982582143	5	6146385164931417	2012/03	user13220	password	39	40000	F
13221	GMKIIK	DTCKUBUDUJ	3436016295 Dell Way	\N	WVYLKHD	\N	0	Australia	2	DTCKUBUDUJ@dell.com	3436016295	4	8936099916696549	2010/12	user13221	password	28	100000	F
13222	PIOXTR	RVCLXXPRGL	7218260457 Dell Way	\N	NFWXNAZ	\N	0	Russia	2	RVCLXXPRGL@dell.com	7218260457	5	3541166688315570	2011/01	user13222	password	32	100000	M
13223	NLOHDF	CGRADGSKRF	9959752892 Dell Way	\N	QODDODX	\N	0	Chile	2	CGRADGSKRF@dell.com	9959752892	1	9376375671010464	2008/05	user13223	password	78	80000	M
13224	HEELKH	RBHVHZFZFV	1118142019 Dell Way	\N	OIYDMVJ	\N	0	France	2	RBHVHZFZFV@dell.com	1118142019	2	5202830108813942	2009/02	user13224	password	25	40000	F
13225	HLWRTO	SBJAAPAGKO	4348571624 Dell Way	\N	PJRBFBN	\N	0	Chile	2	SBJAAPAGKO@dell.com	4348571624	5	6559496952220798	2010/01	user13225	password	83	100000	F
13226	JUACIS	DRTEHTKSIZ	5671475504 Dell Way	\N	BABHCON	\N	0	France	2	DRTEHTKSIZ@dell.com	5671475504	1	9699376073200256	2010/01	user13226	password	83	100000	F
13227	SYNARQ	SKVZEFSNFT	7774087079 Dell Way	\N	NHBPVPB	\N	0	China	2	SKVZEFSNFT@dell.com	7774087079	1	9353882024995984	2012/12	user13227	password	80	40000	M
13228	USRLJJ	WEJAKBNQVB	7826584514 Dell Way	\N	XXRSNSB	\N	0	Chile	2	WEJAKBNQVB@dell.com	7826584514	5	1512706554029136	2011/11	user13228	password	37	40000	M
13229	ZZCIJY	MSZWUNMQOJ	2175986148 Dell Way	\N	NFCAYDH	\N	0	Japan	2	MSZWUNMQOJ@dell.com	2175986148	2	4500146365724504	2012/08	user13229	password	69	80000	M
13230	RRXAQJ	TPGNCTDRDR	3587964777 Dell Way	\N	WFRVJYN	\N	0	Germany	2	TPGNCTDRDR@dell.com	3587964777	5	5246228824835271	2012/08	user13230	password	23	60000	F
13231	UIIKSB	AYPDSTUVKR	9337891541 Dell Way	\N	BCNKBAX	\N	0	China	2	AYPDSTUVKR@dell.com	9337891541	2	3109942500945181	2010/06	user13231	password	67	100000	F
13232	AEQTFR	RVUKPPFAGG	9640519757 Dell Way	\N	CTREUON	\N	0	Russia	2	RVUKPPFAGG@dell.com	9640519757	4	3292013459838927	2010/06	user13232	password	24	80000	F
13233	GHFMYX	HTHWIMXPTZ	5243235902 Dell Way	\N	JKEDZSW	\N	0	UK	2	HTHWIMXPTZ@dell.com	5243235902	1	4150247518438846	2012/03	user13233	password	18	40000	F
13234	HPXGMF	ZTCIFZXYZG	4599952536 Dell Way	\N	JEKIWHG	\N	0	China	2	ZTCIFZXYZG@dell.com	4599952536	3	3320643476210535	2011/08	user13234	password	65	20000	M
13235	GZDSFD	LHLRHIQHPA	2520759403 Dell Way	\N	LAIHHOQ	\N	0	Russia	2	LHLRHIQHPA@dell.com	2520759403	5	3818495114333928	2011/07	user13235	password	45	80000	M
13236	JVMOYY	WKQDSHKIHW	7190979663 Dell Way	\N	JPDREUJ	\N	0	China	2	WKQDSHKIHW@dell.com	7190979663	4	1926191436592489	2009/01	user13236	password	74	20000	F
13237	PMZOLV	YBYRIJZPFJ	1810966746 Dell Way	\N	EJAJEKR	\N	0	South Africa	2	YBYRIJZPFJ@dell.com	1810966746	4	1722700071521103	2008/07	user13237	password	24	60000	F
13238	ONRAIP	BHGJRGZXQE	9742367525 Dell Way	\N	GQNLBEH	\N	0	Canada	2	BHGJRGZXQE@dell.com	9742367525	2	3613737009000033	2010/06	user13238	password	80	80000	F
13239	JJASZC	AGLRNLPDPW	9087750480 Dell Way	\N	UCHVHOZ	\N	0	Chile	2	AGLRNLPDPW@dell.com	9087750480	2	8157375384587795	2009/02	user13239	password	52	40000	F
13240	VJFVLF	BXXOJNRYJL	5522322370 Dell Way	\N	BQHJEGQ	\N	0	Australia	2	BXXOJNRYJL@dell.com	5522322370	3	4660534703172743	2011/11	user13240	password	73	20000	M
13241	DHNPNP	NLDWYVVIHX	3589471281 Dell Way	\N	YOGCVWE	\N	0	China	2	NLDWYVVIHX@dell.com	3589471281	3	9400859247893096	2008/05	user13241	password	20	100000	F
13242	ILCWAP	IEMHZIPHFN	4504096760 Dell Way	\N	WLQRIVA	\N	0	Japan	2	IEMHZIPHFN@dell.com	4504096760	5	8143055996857584	2011/12	user13242	password	68	40000	F
13243	DHEDXM	IKUISJPYXM	1864406542 Dell Way	\N	KODSJEI	\N	0	Russia	2	IKUISJPYXM@dell.com	1864406542	1	5325501679908484	2008/11	user13243	password	69	40000	M
13244	AODYBL	IVTBFJACVK	6541182900 Dell Way	\N	RZDADMT	\N	0	Chile	2	IVTBFJACVK@dell.com	6541182900	2	3695821707602590	2010/12	user13244	password	66	60000	M
13245	FNWGZF	BSGHCGJXRA	1552186265 Dell Way	\N	XUBAHVG	\N	0	South Africa	2	BSGHCGJXRA@dell.com	1552186265	3	4068087923340499	2008/03	user13245	password	73	100000	F
13246	HVSGAU	ZHBBOKZFLW	7548247552 Dell Way	\N	ANXHIEF	\N	0	China	2	ZHBBOKZFLW@dell.com	7548247552	3	4468127508182079	2012/04	user13246	password	42	60000	M
13247	ECVFWU	MXWBIVHURI	4198900065 Dell Way	\N	HPQPTVZ	\N	0	France	2	MXWBIVHURI@dell.com	4198900065	2	4910794468596578	2011/09	user13247	password	79	40000	M
13248	YBCVWP	TSQCNYWFGE	2143741914 Dell Way	\N	UWTORTA	\N	0	Australia	2	TSQCNYWFGE@dell.com	2143741914	3	7223371318541468	2012/04	user13248	password	84	80000	F
13249	ZUCVJV	NAXBYUHFYC	1911427426 Dell Way	\N	BSQTMQU	\N	0	Germany	2	NAXBYUHFYC@dell.com	1911427426	3	4921587782446295	2009/05	user13249	password	29	80000	F
13250	YTEIOS	JMUIGBNFDP	6644545697 Dell Way	\N	YTIKKDZ	\N	0	Germany	2	JMUIGBNFDP@dell.com	6644545697	3	9246928060427308	2008/08	user13250	password	59	60000	M
13251	HPXWIG	ICOPDCVHRT	6176410755 Dell Way	\N	BZDMDDZ	\N	0	Russia	2	ICOPDCVHRT@dell.com	6176410755	5	8106967985164375	2008/06	user13251	password	32	80000	M
13252	UPQCWZ	FLPJNKQEES	1587576428 Dell Way	\N	EIEHMEB	\N	0	Australia	2	FLPJNKQEES@dell.com	1587576428	5	2860995303839445	2010/01	user13252	password	84	40000	M
13253	NYYJXD	UNMHXDMCVQ	8103378912 Dell Way	\N	KAXXEYY	\N	0	Chile	2	UNMHXDMCVQ@dell.com	8103378912	1	7930359835270793	2012/01	user13253	password	23	80000	M
13254	APYYST	LFAJJNLFDW	8438010672 Dell Way	\N	FBTJZRP	\N	0	Russia	2	LFAJJNLFDW@dell.com	8438010672	2	6451425860170276	2012/06	user13254	password	36	60000	F
13255	VKKODW	UDFDQRIUNO	9076694406 Dell Way	\N	VHXVZNP	\N	0	South Africa	2	UDFDQRIUNO@dell.com	9076694406	2	7172750737983734	2009/06	user13255	password	27	100000	F
13256	NFWQCQ	UHTLYCFMQB	7077411082 Dell Way	\N	UOWTBMO	\N	0	UK	2	UHTLYCFMQB@dell.com	7077411082	2	3886304472107440	2008/05	user13256	password	28	60000	M
13257	JHOLXI	TRUSTZEKBZ	5874579319 Dell Way	\N	YXSAJHZ	\N	0	Australia	2	TRUSTZEKBZ@dell.com	5874579319	2	2577840076293796	2012/06	user13257	password	62	100000	M
13258	WJHUSA	LMSFMXPNWN	8613869727 Dell Way	\N	KPOUWOV	\N	0	France	2	LMSFMXPNWN@dell.com	8613869727	5	4167852360755205	2009/08	user13258	password	31	20000	F
13259	OKGGKS	TDXGBMTXAE	8067202048 Dell Way	\N	NOYKCUV	\N	0	UK	2	TDXGBMTXAE@dell.com	8067202048	1	3310096234083176	2009/05	user13259	password	45	100000	M
13260	UDEFVY	ISEJFXHGCU	2324770168 Dell Way	\N	UBEXVZW	\N	0	Japan	2	ISEJFXHGCU@dell.com	2324770168	1	1104532156139612	2010/07	user13260	password	82	40000	F
13261	AOMVNV	ORFUPNARHV	7766429741 Dell Way	\N	SMTOLPE	\N	0	Japan	2	ORFUPNARHV@dell.com	7766429741	1	1856284595560282	2009/01	user13261	password	54	60000	F
13262	BBYOXM	FCGUQGMXCF	2257584407 Dell Way	\N	JVTVLYL	\N	0	Canada	2	FCGUQGMXCF@dell.com	2257584407	3	5038684373721481	2009/01	user13262	password	18	40000	F
13263	BFRZSX	CZSSGEPIJZ	8187308732 Dell Way	\N	DDVOCGT	\N	0	Chile	2	CZSSGEPIJZ@dell.com	8187308732	2	4920008531305939	2012/03	user13263	password	71	100000	F
13264	ZPGRMI	REBXJRGSQK	9259580530 Dell Way	\N	WMZYTSE	\N	0	Germany	2	REBXJRGSQK@dell.com	9259580530	3	4300580639857799	2008/05	user13264	password	38	60000	F
13265	WRZIAR	NBPWSVPJFL	2404391740 Dell Way	\N	VEKPXOD	\N	0	South Africa	2	NBPWSVPJFL@dell.com	2404391740	3	9532141640316696	2010/10	user13265	password	44	80000	M
13266	BUZBLN	DAKWWZFCLB	3313052510 Dell Way	\N	GWQEKTZ	\N	0	Germany	2	DAKWWZFCLB@dell.com	3313052510	5	1488830023910850	2008/04	user13266	password	80	80000	F
13267	QRKCFN	DPJZOPBAQI	4373990030 Dell Way	\N	WHMGBLV	\N	0	China	2	DPJZOPBAQI@dell.com	4373990030	5	4123580237850547	2011/09	user13267	password	20	20000	F
13268	SKMXYP	MIOBXQCOYY	9356089097 Dell Way	\N	WKFXWBF	\N	0	Chile	2	MIOBXQCOYY@dell.com	9356089097	3	9217407391406596	2011/08	user13268	password	84	20000	F
13269	INFGCS	PQUNHWCFUY	6967905163 Dell Way	\N	QAWNBCT	\N	0	UK	2	PQUNHWCFUY@dell.com	6967905163	4	6828645407687873	2009/08	user13269	password	68	60000	M
13270	EVEHOU	YIHFEJLZIB	1016210780 Dell Way	\N	AFOBHIB	\N	0	UK	2	YIHFEJLZIB@dell.com	1016210780	4	2930855114012956	2010/05	user13270	password	76	60000	M
13271	QRVELU	MTZRDKRLMR	5091338341 Dell Way	\N	QBSYJTW	\N	0	China	2	MTZRDKRLMR@dell.com	5091338341	1	9670670271851124	2012/11	user13271	password	51	40000	M
13272	DGRPAD	IAVMKMXWDO	4974203578 Dell Way	\N	XWMHQJR	\N	0	Australia	2	IAVMKMXWDO@dell.com	4974203578	4	9324455354828388	2009/02	user13272	password	41	100000	F
13273	ONVPQE	PMQZYOWCDU	4367024187 Dell Way	\N	ZPCPYTS	\N	0	France	2	PMQZYOWCDU@dell.com	4367024187	4	7589076356496663	2010/12	user13273	password	59	80000	M
13274	BOCSSR	FJRDYOGBIF	2593736577 Dell Way	\N	RKVQEOA	\N	0	Germany	2	FJRDYOGBIF@dell.com	2593736577	4	1048160680569708	2008/04	user13274	password	69	80000	F
13275	GTCZLH	IDLHRSIAXZ	4323484726 Dell Way	\N	LTPPHQD	\N	0	France	2	IDLHRSIAXZ@dell.com	4323484726	1	6452637916896493	2011/11	user13275	password	36	20000	F
13276	AFCMNL	PYSGRAHOAS	6418393643 Dell Way	\N	IPIQFLC	\N	0	Germany	2	PYSGRAHOAS@dell.com	6418393643	4	3546511861495674	2010/12	user13276	password	44	60000	M
13277	OQLBBA	AUHRUPGUHP	9940866247 Dell Way	\N	KQFQCHF	\N	0	Japan	2	AUHRUPGUHP@dell.com	9940866247	3	2279367121867835	2012/11	user13277	password	69	100000	F
13278	JJNKKN	ESFZHLUPAF	6148833267 Dell Way	\N	FGVHNBZ	\N	0	Germany	2	ESFZHLUPAF@dell.com	6148833267	1	5290830239187926	2010/10	user13278	password	47	100000	F
13279	UKPEXU	WDUDPOTQTY	4000348269 Dell Way	\N	WPGKRFX	\N	0	Chile	2	WDUDPOTQTY@dell.com	4000348269	2	7171137569472194	2008/10	user13279	password	59	40000	M
13280	YYTWSP	ZMTPBMFVLB	7786450063 Dell Way	\N	LRLCWJI	\N	0	Chile	2	ZMTPBMFVLB@dell.com	7786450063	1	4312530710827559	2010/08	user13280	password	69	20000	M
13281	QWLJML	VGAXSFTEHE	6672981827 Dell Way	\N	VSGSCPX	\N	0	South Africa	2	VGAXSFTEHE@dell.com	6672981827	2	4530016023665667	2009/12	user13281	password	55	80000	M
13282	JFYWQU	CQSVVLZDPU	6893674224 Dell Way	\N	VWMYMJU	\N	0	Canada	2	CQSVVLZDPU@dell.com	6893674224	1	4091324310749769	2011/09	user13282	password	26	40000	F
13283	IFXYAZ	PSULETOUOK	3247139461 Dell Way	\N	RAIDKCH	\N	0	Australia	2	PSULETOUOK@dell.com	3247139461	4	7324815028347076	2012/09	user13283	password	86	100000	F
13284	DWADWP	WRAALOUZYM	5533500547 Dell Way	\N	AGQLIXN	\N	0	Germany	2	WRAALOUZYM@dell.com	5533500547	2	5670895002782345	2009/02	user13284	password	54	40000	F
13285	JHLGXH	XXIJLDIKPJ	6016716674 Dell Way	\N	RFVACIP	\N	0	Japan	2	XXIJLDIKPJ@dell.com	6016716674	1	8698177269194276	2011/08	user13285	password	28	20000	M
13286	LMGIUE	GCNRGWCVFT	5249781984 Dell Way	\N	BBTEJJU	\N	0	UK	2	GCNRGWCVFT@dell.com	5249781984	4	6921834141481668	2008/10	user13286	password	67	20000	F
13287	DIPXMV	AZNGVPCBJE	8231584648 Dell Way	\N	CDJMMDL	\N	0	UK	2	AZNGVPCBJE@dell.com	8231584648	1	1288362820167094	2011/10	user13287	password	25	100000	M
13288	KLVXGV	WTCSJEUSIW	9057706219 Dell Way	\N	WRJIVUG	\N	0	Japan	2	WTCSJEUSIW@dell.com	9057706219	2	3250053748954087	2011/05	user13288	password	25	60000	M
13289	OKSVFP	OHHYMCRVZN	4654410817 Dell Way	\N	NIVJDCA	\N	0	Australia	2	OHHYMCRVZN@dell.com	4654410817	2	7313691245391966	2012/05	user13289	password	37	80000	M
13290	RJSWYH	EGGRIXNHLA	6875670466 Dell Way	\N	QGKUJKV	\N	0	Russia	2	EGGRIXNHLA@dell.com	6875670466	3	6306600206531585	2008/10	user13290	password	35	100000	F
13291	PQIOYN	VEFECSMNTC	3158293894 Dell Way	\N	UDXDOSY	\N	0	Chile	2	VEFECSMNTC@dell.com	3158293894	3	2973381093703210	2008/10	user13291	password	28	60000	F
13292	UVXTJT	YPXAHJOBMI	9269601301 Dell Way	\N	FJMTBKZ	\N	0	China	2	YPXAHJOBMI@dell.com	9269601301	1	4099849749822170	2011/05	user13292	password	79	20000	F
13293	RYWBRU	QOVYXJZJRF	2100253784 Dell Way	\N	TEZUOYC	\N	0	France	2	QOVYXJZJRF@dell.com	2100253784	3	2338526070583612	2010/04	user13293	password	30	60000	M
13294	CMATGQ	ICPFLOPDUI	7326736391 Dell Way	\N	HTDWRGI	\N	0	South Africa	2	ICPFLOPDUI@dell.com	7326736391	3	3337404688354582	2012/08	user13294	password	79	100000	M
13295	IZNPQV	RFBDURGOAO	3216892496 Dell Way	\N	HDKZKTU	\N	0	Canada	2	RFBDURGOAO@dell.com	3216892496	1	1864187686704099	2012/11	user13295	password	22	80000	F
13296	BEURZL	WBPQSWFSKM	3621312635 Dell Way	\N	WVMGPGJ	\N	0	South Africa	2	WBPQSWFSKM@dell.com	3621312635	3	7673528188373894	2008/07	user13296	password	46	40000	M
13297	OEFOQC	PFTHBYALLW	9404524159 Dell Way	\N	HXDXDMS	\N	0	France	2	PFTHBYALLW@dell.com	9404524159	3	6578961655031890	2010/11	user13297	password	18	20000	F
13298	EFZUIO	ZBWAZWMKTU	8648908878 Dell Way	\N	IWRLIJX	\N	0	Chile	2	ZBWAZWMKTU@dell.com	8648908878	3	7474159885663540	2011/07	user13298	password	70	20000	M
13299	YCMGRL	INMHKYSDTA	9222257315 Dell Way	\N	ZKMIUKP	\N	0	Japan	2	INMHKYSDTA@dell.com	9222257315	2	4005619137082249	2010/01	user13299	password	52	20000	M
13300	OPGFBO	TNWDMOGFPF	4886015831 Dell Way	\N	PCOJMDZ	\N	0	China	2	TNWDMOGFPF@dell.com	4886015831	2	8466831222176553	2010/10	user13300	password	87	60000	F
13301	ORPPFI	CBMPQSUFYK	1838885063 Dell Way	\N	IMUUPTE	\N	0	Australia	2	CBMPQSUFYK@dell.com	1838885063	1	5456525763031096	2012/12	user13301	password	85	40000	M
13302	PVCUEF	WQUMJPSHZA	1221644287 Dell Way	\N	TTVJNAK	\N	0	Japan	2	WQUMJPSHZA@dell.com	1221644287	5	5605976177845151	2012/10	user13302	password	73	60000	F
13303	PPFTVC	KQPTFHAFIU	5310725218 Dell Way	\N	ZDENEPD	\N	0	Canada	2	KQPTFHAFIU@dell.com	5310725218	4	2577422481495887	2009/06	user13303	password	67	80000	F
13304	HYUDAE	TPYZXZFFUE	5611752097 Dell Way	\N	JYSNNWS	\N	0	Australia	2	TPYZXZFFUE@dell.com	5611752097	5	3840930497739464	2012/07	user13304	password	20	100000	M
13305	ZSZAXT	QWSNVYTPCD	3327130507 Dell Way	\N	OVRCRJC	\N	0	Canada	2	QWSNVYTPCD@dell.com	3327130507	3	2119387716520577	2012/06	user13305	password	23	80000	F
13306	USLSLB	OEPKCIAFMO	2744972199 Dell Way	\N	ADRSMUX	\N	0	Russia	2	OEPKCIAFMO@dell.com	2744972199	1	6204933538101614	2011/02	user13306	password	38	20000	M
13307	ZOPKQE	OFOQOPWAEW	5523755210 Dell Way	\N	DVPQPMJ	\N	0	Russia	2	OFOQOPWAEW@dell.com	5523755210	5	5004916703328490	2010/03	user13307	password	57	60000	F
13308	CCQSGF	YVWNKSNOOR	6957460846 Dell Way	\N	KDIZQSU	\N	0	Canada	2	YVWNKSNOOR@dell.com	6957460846	2	7494314184412361	2012/10	user13308	password	33	20000	M
13309	HTPOYN	KUAUMOJBGT	7515643395 Dell Way	\N	EOSVHNY	\N	0	UK	2	KUAUMOJBGT@dell.com	7515643395	4	8512593928258867	2010/11	user13309	password	87	40000	F
13310	RXSQLC	KMXXAGYHAD	5847029181 Dell Way	\N	WTYDGWB	\N	0	UK	2	KMXXAGYHAD@dell.com	5847029181	5	5049336653668434	2010/11	user13310	password	75	60000	M
13311	SHEEKO	QILRPKYPNV	9048093521 Dell Way	\N	ILYOIZN	\N	0	South Africa	2	QILRPKYPNV@dell.com	9048093521	5	3526487352326512	2011/10	user13311	password	80	40000	F
13312	ELQOAH	XMYMWXBJSK	5276732263 Dell Way	\N	VQYEQMB	\N	0	Germany	2	XMYMWXBJSK@dell.com	5276732263	2	3456722785718739	2009/03	user13312	password	58	80000	F
13313	ZJXAQU	MPGIMISESO	1990229801 Dell Way	\N	VRTLEUZ	\N	0	Japan	2	MPGIMISESO@dell.com	1990229801	2	9098470922093840	2009/10	user13313	password	64	80000	M
13314	AOVRIH	GPQTYIYQXT	5269464956 Dell Way	\N	IQFNKFE	\N	0	Germany	2	GPQTYIYQXT@dell.com	5269464956	1	8395434631966055	2009/09	user13314	password	51	20000	M
13315	ZXKIEQ	YUKWDINBBV	5973498010 Dell Way	\N	RHICMMQ	\N	0	UK	2	YUKWDINBBV@dell.com	5973498010	3	3350361828226596	2009/11	user13315	password	44	100000	M
13316	GIFLZE	GKAKSNLUJD	3936720823 Dell Way	\N	CSGOFWO	\N	0	Russia	2	GKAKSNLUJD@dell.com	3936720823	5	9967266631312668	2009/02	user13316	password	87	20000	F
13317	HJWHND	ROOKBAFKDH	2831342540 Dell Way	\N	DKWIGKB	\N	0	Germany	2	ROOKBAFKDH@dell.com	2831342540	1	8414872965309770	2009/01	user13317	password	88	100000	F
13318	IRQWVH	KJSLKXWNEZ	5026653836 Dell Way	\N	YAIELJU	\N	0	Japan	2	KJSLKXWNEZ@dell.com	5026653836	4	1000706200487911	2010/07	user13318	password	76	80000	M
13319	MKTISD	SKOCILPMLO	1996649861 Dell Way	\N	NTSYDNP	\N	0	Germany	2	SKOCILPMLO@dell.com	1996649861	3	1450931898318231	2011/05	user13319	password	79	60000	M
13320	GHEYKW	JZYSLOFXCS	8701321823 Dell Way	\N	QVRUJGJ	\N	0	France	2	JZYSLOFXCS@dell.com	8701321823	3	2201371870003640	2009/03	user13320	password	68	20000	F
13321	ZHLKEV	KDNWSSTVLJ	9249836048 Dell Way	\N	RCEAJNM	\N	0	Chile	2	KDNWSSTVLJ@dell.com	9249836048	4	5303135417867452	2008/04	user13321	password	61	80000	F
13322	XCSCXD	FLZYDSUOCL	6360297205 Dell Way	\N	RGMBTZH	\N	0	Japan	2	FLZYDSUOCL@dell.com	6360297205	4	8527958878781647	2012/05	user13322	password	53	40000	F
13323	PYJNBP	YANCSIRVUJ	5508599778 Dell Way	\N	BHLVGSM	\N	0	South Africa	2	YANCSIRVUJ@dell.com	5508599778	2	7765500666107983	2012/10	user13323	password	88	20000	F
13324	XNYYCW	YQZRYQMTAO	2825898464 Dell Way	\N	ALJGEWC	\N	0	Japan	2	YQZRYQMTAO@dell.com	2825898464	5	5821038902737201	2008/10	user13324	password	67	60000	M
13325	EJQHGO	XGGWWSPXHP	8290395500 Dell Way	\N	IQWMNYE	\N	0	Russia	2	XGGWWSPXHP@dell.com	8290395500	4	7760338499210776	2011/05	user13325	password	32	40000	M
13326	OYVVNT	BTPYMFVTVE	5476783649 Dell Way	\N	KRQYQUR	\N	0	France	2	BTPYMFVTVE@dell.com	5476783649	3	1643261942081153	2012/08	user13326	password	46	60000	F
13327	IHZWAA	QQZDVUXQYI	4061055104 Dell Way	\N	IPGZKXK	\N	0	UK	2	QQZDVUXQYI@dell.com	4061055104	3	7964577110949905	2012/11	user13327	password	32	20000	F
13328	MDCMDS	DDWYXTPWBY	8198388904 Dell Way	\N	LHXWFIT	\N	0	Germany	2	DDWYXTPWBY@dell.com	8198388904	3	5645531812217087	2011/09	user13328	password	64	100000	F
13329	TASXSV	APUYIJUJIG	4763443464 Dell Way	\N	RFCXNWL	\N	0	China	2	APUYIJUJIG@dell.com	4763443464	5	1065039528533816	2008/08	user13329	password	84	40000	F
13330	XCHQXI	FSGOCBXKHP	9226054338 Dell Way	\N	PKMDHYM	\N	0	Russia	2	FSGOCBXKHP@dell.com	9226054338	3	8806835505180062	2010/05	user13330	password	36	100000	F
13331	IFYGNE	YTSAUQLCFB	2034487071 Dell Way	\N	NREUQQM	\N	0	Germany	2	YTSAUQLCFB@dell.com	2034487071	2	1590058452915400	2010/08	user13331	password	89	100000	M
13332	ETFRYE	LQEGGQIMRV	5493337057 Dell Way	\N	DVQTMDH	\N	0	Japan	2	LQEGGQIMRV@dell.com	5493337057	2	1925487591419369	2008/05	user13332	password	84	20000	M
13333	RGEPLQ	FQWMGFYXBC	5816467186 Dell Way	\N	TRWGVEV	\N	0	China	2	FQWMGFYXBC@dell.com	5816467186	5	4801623390056193	2012/11	user13333	password	53	40000	M
13334	TOCEFH	UBUAGTYHVR	7220758796 Dell Way	\N	ZSXUWTC	\N	0	France	2	UBUAGTYHVR@dell.com	7220758796	3	3533249775413424	2010/01	user13334	password	66	20000	M
13335	GDYLKT	NFUUYSCUKB	5334527849 Dell Way	\N	MIWIBYT	\N	0	Russia	2	NFUUYSCUKB@dell.com	5334527849	1	3589147878810763	2010/09	user13335	password	41	40000	M
13336	LFKWYX	BSRAKTUVUG	4530737546 Dell Way	\N	DRPEQJY	\N	0	Australia	2	BSRAKTUVUG@dell.com	4530737546	2	6323094677180052	2008/07	user13336	password	79	20000	M
13337	BLWZIY	SZYDTTYOZB	4471361321 Dell Way	\N	FPGVZEY	\N	0	China	2	SZYDTTYOZB@dell.com	4471361321	3	5041009144857526	2012/05	user13337	password	53	100000	F
13338	XUKGSC	GQFZJENJFT	1106455170 Dell Way	\N	ZLOYPMH	\N	0	UK	2	GQFZJENJFT@dell.com	1106455170	4	9279781147837640	2009/03	user13338	password	79	80000	F
13339	QFKIHQ	ZNPJRDTXWS	7397336247 Dell Way	\N	ILRYYZX	\N	0	UK	2	ZNPJRDTXWS@dell.com	7397336247	5	3830222704447806	2012/09	user13339	password	26	20000	F
13340	IMQPCP	DSZVVSSSKA	7364344435 Dell Way	\N	DCYBBWZ	\N	0	Russia	2	DSZVVSSSKA@dell.com	7364344435	2	7343373249284924	2009/05	user13340	password	76	80000	M
13341	HHIKXM	CWHYPZQAAU	2223336827 Dell Way	\N	CZVDWVX	\N	0	Germany	2	CWHYPZQAAU@dell.com	2223336827	4	9522161019034684	2010/05	user13341	password	63	40000	M
13342	YPCVCF	SKDHKUIKOK	1299389402 Dell Way	\N	KKNGGLV	\N	0	China	2	SKDHKUIKOK@dell.com	1299389402	4	9346566597465428	2010/05	user13342	password	32	20000	F
13343	VFEXKX	HOFRINCXXM	3894839776 Dell Way	\N	ILTOWOY	\N	0	UK	2	HOFRINCXXM@dell.com	3894839776	5	4115492162294686	2011/01	user13343	password	52	20000	M
13344	RFUCCC	QHUZVWXSJF	6292110632 Dell Way	\N	ECUBRSY	\N	0	UK	2	QHUZVWXSJF@dell.com	6292110632	2	7292535221204162	2011/10	user13344	password	71	60000	F
13345	YJOBLE	JFEECBWLHB	4026341213 Dell Way	\N	OBCFUAF	\N	0	China	2	JFEECBWLHB@dell.com	4026341213	5	1400891249068081	2008/08	user13345	password	61	60000	M
13346	YCQJHZ	PMDSNADVCS	1431041474 Dell Way	\N	XEYSFDC	\N	0	Germany	2	PMDSNADVCS@dell.com	1431041474	1	6798594004940242	2011/09	user13346	password	32	40000	M
13347	IYBPXR	BBJPCMLEFI	3360155847 Dell Way	\N	JDBOGDC	\N	0	China	2	BBJPCMLEFI@dell.com	3360155847	4	1079153576400131	2012/12	user13347	password	39	80000	F
13348	FSWDJX	FSNIFYNKHW	3005448499 Dell Way	\N	NIKULMD	\N	0	Russia	2	FSNIFYNKHW@dell.com	3005448499	1	7358792623504997	2008/06	user13348	password	44	60000	M
13349	BGULEZ	DRHIQVTXRH	3937041883 Dell Way	\N	GBCSOFK	\N	0	Russia	2	DRHIQVTXRH@dell.com	3937041883	1	9365454428363592	2011/06	user13349	password	42	40000	M
13350	PEZTED	LMMBHFZYMF	5322172689 Dell Way	\N	ZPYNUJH	\N	0	Canada	2	LMMBHFZYMF@dell.com	5322172689	2	8729229156859220	2012/07	user13350	password	35	60000	F
13351	KNXOQI	ACKIIJGVPF	3753099698 Dell Way	\N	KOTEXBH	\N	0	China	2	ACKIIJGVPF@dell.com	3753099698	1	4103933509439230	2012/05	user13351	password	81	20000	M
13352	JYJAGK	CRSKBZFRFQ	3296180895 Dell Way	\N	FYUCACM	\N	0	China	2	CRSKBZFRFQ@dell.com	3296180895	5	2919682133477181	2011/09	user13352	password	35	60000	F
13353	EWCLGE	CZPEYVVELA	4663204934 Dell Way	\N	DGDDJPM	\N	0	Japan	2	CZPEYVVELA@dell.com	4663204934	4	3424134528730065	2008/12	user13353	password	71	20000	F
13354	PGOWKR	VAVUWQYHRB	4636999232 Dell Way	\N	OUFXJSN	\N	0	Russia	2	VAVUWQYHRB@dell.com	4636999232	5	8918870344758035	2009/07	user13354	password	21	60000	F
13355	HAZSSV	SNPOEOWWQL	7368849624 Dell Way	\N	QWJAOXV	\N	0	UK	2	SNPOEOWWQL@dell.com	7368849624	4	3794487164355815	2009/09	user13355	password	74	40000	F
13356	UJSNEL	BUAGIXCZIT	3556193927 Dell Way	\N	VSUKPPJ	\N	0	China	2	BUAGIXCZIT@dell.com	3556193927	4	6068917985539884	2008/06	user13356	password	86	20000	F
13357	HTTLFU	FFBOCDOLWK	8470854644 Dell Way	\N	ERUTGEB	\N	0	Germany	2	FFBOCDOLWK@dell.com	8470854644	4	5989448780193925	2009/07	user13357	password	61	60000	M
13358	IHINCO	TDDWHRHECL	9394732998 Dell Way	\N	VWFBAHP	\N	0	South Africa	2	TDDWHRHECL@dell.com	9394732998	1	2250967712607234	2010/09	user13358	password	66	40000	F
13359	ZRQBGJ	FJFMANQCZL	3582757540 Dell Way	\N	ZFNANDW	\N	0	France	2	FJFMANQCZL@dell.com	3582757540	1	9591310500632972	2008/09	user13359	password	41	20000	M
13360	ATSGDX	PJJQXATXLS	6596679204 Dell Way	\N	CZTQCPB	\N	0	China	2	PJJQXATXLS@dell.com	6596679204	1	4788657763507217	2009/05	user13360	password	58	100000	F
13361	HQPLOF	UYVRYOOJHR	4427069199 Dell Way	\N	IAHLQJV	\N	0	Chile	2	UYVRYOOJHR@dell.com	4427069199	2	6067667434923351	2011/10	user13361	password	55	20000	F
13362	ESNSXI	QSZOHOYPFH	8262153750 Dell Way	\N	PNSGWON	\N	0	Chile	2	QSZOHOYPFH@dell.com	8262153750	1	9835857776924968	2011/08	user13362	password	23	80000	M
13363	TFMRNC	JNRRBQGHXW	7378030453 Dell Way	\N	UQDRFQY	\N	0	Australia	2	JNRRBQGHXW@dell.com	7378030453	5	6486239210702479	2009/12	user13363	password	40	20000	M
13364	NNKBQU	PHMRYSYVPT	3536844245 Dell Way	\N	MTLRJJR	\N	0	Australia	2	PHMRYSYVPT@dell.com	3536844245	2	4335768321994692	2009/08	user13364	password	48	20000	F
13365	YKFOFV	WRMUKLQZFC	7846062653 Dell Way	\N	SQUCAME	\N	0	Chile	2	WRMUKLQZFC@dell.com	7846062653	3	5983388483989984	2009/12	user13365	password	59	60000	M
13366	ZSLEOH	VACFLSFRVY	7662463858 Dell Way	\N	HPAHBFP	\N	0	South Africa	2	VACFLSFRVY@dell.com	7662463858	1	2703909951727837	2011/09	user13366	password	68	60000	M
13367	LAWZHS	ZKYLCDCXCK	4871644891 Dell Way	\N	NCSOIHK	\N	0	Australia	2	ZKYLCDCXCK@dell.com	4871644891	3	7724652315955610	2008/04	user13367	password	41	100000	M
13368	IRRQKR	AICDLFANPN	1677880484 Dell Way	\N	QHCYOMA	\N	0	Australia	2	AICDLFANPN@dell.com	1677880484	4	2278216705657542	2009/02	user13368	password	88	20000	F
13369	RSBBJC	JMFVRGJHUZ	7581849567 Dell Way	\N	OWYDJZD	\N	0	France	2	JMFVRGJHUZ@dell.com	7581849567	2	8204605263192207	2012/03	user13369	password	80	40000	M
13370	PHYZJH	LPCDVLKPLZ	5591411531 Dell Way	\N	MKCVJGH	\N	0	Canada	2	LPCDVLKPLZ@dell.com	5591411531	1	9295838766265660	2011/12	user13370	password	29	80000	M
13371	LPNVXY	KZCGLMVXLH	5703984376 Dell Way	\N	HODRULU	\N	0	Chile	2	KZCGLMVXLH@dell.com	5703984376	4	1381862744688987	2010/11	user13371	password	68	20000	F
13372	HNDEMO	EOUQAPNMXV	9858225245 Dell Way	\N	ABMVMHC	\N	0	UK	2	EOUQAPNMXV@dell.com	9858225245	1	5230519906152040	2012/11	user13372	password	52	20000	F
13373	ZHHLVM	ZPCAFQNCLO	6347373844 Dell Way	\N	DYJQGLQ	\N	0	Chile	2	ZPCAFQNCLO@dell.com	6347373844	1	1530770427081734	2010/07	user13373	password	33	60000	M
13374	MWZIIZ	XLADCOFNCJ	7133255583 Dell Way	\N	MMZSXPY	\N	0	Germany	2	XLADCOFNCJ@dell.com	7133255583	5	9492806667927654	2009/03	user13374	password	54	80000	M
13375	JUASUY	EVBGJGUMQG	9029320640 Dell Way	\N	YPZWEXJ	\N	0	South Africa	2	EVBGJGUMQG@dell.com	9029320640	2	2048320333939045	2008/10	user13375	password	84	80000	F
13376	SUWMSB	IUHSABERHD	7223771709 Dell Way	\N	GHZLEJI	\N	0	Australia	2	IUHSABERHD@dell.com	7223771709	3	2476384506095201	2010/05	user13376	password	87	80000	F
13377	TPOMQW	GXOHYTYGWF	4458682767 Dell Way	\N	NVQSFYU	\N	0	South Africa	2	GXOHYTYGWF@dell.com	4458682767	5	4717898105736822	2011/11	user13377	password	25	80000	M
13378	RIDHEJ	FTRDMPKIVY	4219179921 Dell Way	\N	ELQJKKG	\N	0	Russia	2	FTRDMPKIVY@dell.com	4219179921	4	5621119691058994	2009/10	user13378	password	38	100000	F
13379	PAUUKZ	NBDZRNHMLL	7846352139 Dell Way	\N	XCVINCC	\N	0	South Africa	2	NBDZRNHMLL@dell.com	7846352139	4	2031593764200806	2010/11	user13379	password	18	20000	M
13380	AUHKUU	MXTDLBPXMN	6190429224 Dell Way	\N	AHVNKYJ	\N	0	Canada	2	MXTDLBPXMN@dell.com	6190429224	3	7271204128395767	2010/06	user13380	password	70	100000	M
13381	NHYIBK	GVNRWCPJQP	9657164196 Dell Way	\N	RMCBKMF	\N	0	UK	2	GVNRWCPJQP@dell.com	9657164196	5	5300940985325724	2010/08	user13381	password	52	100000	F
13382	TXLVHR	QUJMXZVNOM	6677346146 Dell Way	\N	ZROKETK	\N	0	Canada	2	QUJMXZVNOM@dell.com	6677346146	5	6171051220037044	2009/05	user13382	password	57	40000	F
13383	LVXTNO	NXALWWZLJZ	7085382724 Dell Way	\N	DXKHQUK	\N	0	Chile	2	NXALWWZLJZ@dell.com	7085382724	5	5687001508660615	2008/07	user13383	password	83	20000	M
13384	TBSGPG	DPRAMRLVQO	2970474048 Dell Way	\N	TAWKVGR	\N	0	Germany	2	DPRAMRLVQO@dell.com	2970474048	1	5778886039275677	2011/02	user13384	password	66	80000	M
13385	SKCHQF	XHFKZRFPGZ	3262224146 Dell Way	\N	QCJLJBY	\N	0	Germany	2	XHFKZRFPGZ@dell.com	3262224146	3	3729066690895706	2009/02	user13385	password	18	20000	M
13386	KGEAMB	ISLHJRXQRN	4863944336 Dell Way	\N	TBZCCYQ	\N	0	China	2	ISLHJRXQRN@dell.com	4863944336	5	7250287114176900	2010/12	user13386	password	81	60000	F
13387	DPJPRS	HDARUXILLB	7668869166 Dell Way	\N	NKDPJUY	\N	0	Russia	2	HDARUXILLB@dell.com	7668869166	4	4363384689670056	2011/07	user13387	password	77	20000	M
13388	KLGCDO	FEFZBOLNPZ	2219773919 Dell Way	\N	XTOHOMC	\N	0	Chile	2	FEFZBOLNPZ@dell.com	2219773919	3	9817421973682940	2011/04	user13388	password	20	40000	M
13389	MNTPBZ	THZVVLILKG	1638839457 Dell Way	\N	FYOTLQA	\N	0	Germany	2	THZVVLILKG@dell.com	1638839457	1	3028800661675632	2009/01	user13389	password	54	20000	F
13390	AUCBTW	JSSEEAQOHV	6457501356 Dell Way	\N	MVOYLPN	\N	0	Germany	2	JSSEEAQOHV@dell.com	6457501356	4	8719854522030801	2011/03	user13390	password	82	20000	F
13391	RGILDR	EVWIWMWDIJ	5972423802 Dell Way	\N	ZXHLMUY	\N	0	Canada	2	EVWIWMWDIJ@dell.com	5972423802	5	7700240768957884	2012/09	user13391	password	82	20000	F
13392	DKUGBY	CYHYLDCTMC	3382411028 Dell Way	\N	QUNDPLG	\N	0	Canada	2	CYHYLDCTMC@dell.com	3382411028	5	9425660176202656	2012/11	user13392	password	90	40000	F
13393	KCGLBJ	KJIVMKOZNF	6005170104 Dell Way	\N	TAIIMOM	\N	0	Russia	2	KJIVMKOZNF@dell.com	6005170104	3	7335511698853225	2010/05	user13393	password	19	60000	M
13394	DSGFBQ	OJMAUAAHFT	9713625480 Dell Way	\N	IOCVDOO	\N	0	Japan	2	OJMAUAAHFT@dell.com	9713625480	2	2113635212182998	2009/04	user13394	password	58	20000	F
13395	GLQIBE	ROFMOFUUZD	8178237120 Dell Way	\N	JBYNQNF	\N	0	Germany	2	ROFMOFUUZD@dell.com	8178237120	2	9732742074411364	2008/11	user13395	password	28	60000	F
13396	ODLQID	ENQTTKOSNX	9722427664 Dell Way	\N	UMLKZQA	\N	0	Russia	2	ENQTTKOSNX@dell.com	9722427664	5	8936127966735513	2012/02	user13396	password	47	100000	M
13397	OLIWPM	JFGCPUVDSP	9961752906 Dell Way	\N	PDAPTAK	\N	0	Russia	2	JFGCPUVDSP@dell.com	9961752906	2	6294846142176539	2008/09	user13397	password	60	80000	F
13398	ACBQPL	VVOLQKPIZE	5076518629 Dell Way	\N	LAUFAEY	\N	0	Australia	2	VVOLQKPIZE@dell.com	5076518629	3	2167800331953913	2008/02	user13398	password	85	40000	F
13399	AKUQWP	MKBCUQLUVW	6361853104 Dell Way	\N	UPCVUBV	\N	0	Chile	2	MKBCUQLUVW@dell.com	6361853104	5	4319478239864111	2011/11	user13399	password	69	100000	M
13400	CRNYHZ	JICEZNYUKS	3907385339 Dell Way	\N	KMNEOJL	\N	0	Canada	2	JICEZNYUKS@dell.com	3907385339	5	8828400717116893	2009/07	user13400	password	73	20000	M
13401	LQOSPY	BSCAFAUPTE	6421667463 Dell Way	\N	CHJQRUU	\N	0	UK	2	BSCAFAUPTE@dell.com	6421667463	4	2674264044500887	2008/05	user13401	password	38	80000	M
13402	XHONGP	FIPKJJADOC	2830139875 Dell Way	\N	LYTCTOC	\N	0	China	2	FIPKJJADOC@dell.com	2830139875	2	5019870881922543	2011/07	user13402	password	30	60000	F
13403	MAZSPF	AEQKOQNCTZ	4645368730 Dell Way	\N	BNBUBDD	\N	0	Chile	2	AEQKOQNCTZ@dell.com	4645368730	3	8799190890975297	2012/09	user13403	password	41	60000	F
13404	IKXXPY	CGJQXWTQWU	3434561260 Dell Way	\N	DXPEBSL	\N	0	France	2	CGJQXWTQWU@dell.com	3434561260	2	4718265459407121	2008/08	user13404	password	78	40000	M
13405	GDWWBY	CKOZHIQDCT	7101355090 Dell Way	\N	BRYCJJO	\N	0	Japan	2	CKOZHIQDCT@dell.com	7101355090	5	6954308903310449	2009/10	user13405	password	82	40000	F
13406	ACXBAA	MPZUXPYAJZ	6820312727 Dell Way	\N	RICBRRS	\N	0	China	2	MPZUXPYAJZ@dell.com	6820312727	2	7021922338288278	2010/04	user13406	password	84	60000	F
13407	ALIBLV	QKPOANOKNG	4900659691 Dell Way	\N	SPIKHBT	\N	0	UK	2	QKPOANOKNG@dell.com	4900659691	3	4479733602609486	2011/05	user13407	password	83	100000	F
13408	IHKTCB	ESQFFEPTLH	9099114610 Dell Way	\N	JTSQVMO	\N	0	Chile	2	ESQFFEPTLH@dell.com	9099114610	5	9463115871418268	2009/11	user13408	password	83	80000	F
13409	EAYHCC	ZSIFXXYIFI	4958254711 Dell Way	\N	CXYXJMD	\N	0	Chile	2	ZSIFXXYIFI@dell.com	4958254711	1	5732101566623897	2009/12	user13409	password	28	60000	F
13410	EKMHMM	ZUSWSQFXYH	5070661837 Dell Way	\N	VXFFKJM	\N	0	South Africa	2	ZUSWSQFXYH@dell.com	5070661837	1	2095547358505428	2010/02	user13410	password	60	80000	F
13411	ZCPLOO	GGLYXRWWZS	4363503213 Dell Way	\N	UEXENJA	\N	0	UK	2	GGLYXRWWZS@dell.com	4363503213	1	4890747554600239	2010/09	user13411	password	22	100000	M
13412	ELDSZJ	ZLIXCFUBXO	8953948404 Dell Way	\N	GUTUETU	\N	0	Germany	2	ZLIXCFUBXO@dell.com	8953948404	2	1630764863919466	2010/04	user13412	password	84	40000	F
13413	IKDIUD	UDBXIVYGKF	9903276500 Dell Way	\N	BDAGXUU	\N	0	Russia	2	UDBXIVYGKF@dell.com	9903276500	5	4275852231774479	2009/10	user13413	password	64	80000	F
13414	AVKVZF	YACHVBNGGP	5165208233 Dell Way	\N	JGVGAPA	\N	0	Australia	2	YACHVBNGGP@dell.com	5165208233	2	3530432571657002	2009/01	user13414	password	87	40000	F
13415	UTWTYV	TACPBQVIFF	8990660197 Dell Way	\N	PBMQQMQ	\N	0	Canada	2	TACPBQVIFF@dell.com	8990660197	5	4045576310716570	2012/11	user13415	password	66	100000	M
13416	KWKIRE	JUTLLPTQVI	5827405871 Dell Way	\N	SHZIUPL	\N	0	Japan	2	JUTLLPTQVI@dell.com	5827405871	4	6246918239630759	2010/06	user13416	password	58	20000	M
13417	KMECRO	WLZHATYWCQ	3210577193 Dell Way	\N	DBZXQLP	\N	0	Canada	2	WLZHATYWCQ@dell.com	3210577193	1	6493353128898889	2011/09	user13417	password	68	60000	F
13418	FTGWHC	HHKIAJECAI	9761314938 Dell Way	\N	DAFUMUZ	\N	0	Russia	2	HHKIAJECAI@dell.com	9761314938	3	4739123779349029	2011/04	user13418	password	88	100000	F
13419	SBJZEQ	GPZHZDJALN	8959838061 Dell Way	\N	ARIMMHF	\N	0	France	2	GPZHZDJALN@dell.com	8959838061	4	2458488170523196	2008/08	user13419	password	90	80000	F
13420	BAHGRO	WQWVUFVGTW	2813120240 Dell Way	\N	YBJKJOW	\N	0	Chile	2	WQWVUFVGTW@dell.com	2813120240	1	4688853608444333	2011/01	user13420	password	23	20000	F
13421	CKJTYF	JUAEAWKUSI	7230718316 Dell Way	\N	VCTEQQK	\N	0	South Africa	2	JUAEAWKUSI@dell.com	7230718316	5	6823625716380776	2011/11	user13421	password	72	100000	M
13422	DFTCKD	XLHYHSSAAN	9754764343 Dell Way	\N	CUSTLDP	\N	0	Canada	2	XLHYHSSAAN@dell.com	9754764343	2	8861966253723950	2012/12	user13422	password	70	100000	F
13423	YPFISD	UZBCSTCSHF	8461265688 Dell Way	\N	NZZZDPC	\N	0	Canada	2	UZBCSTCSHF@dell.com	8461265688	5	9885897177271546	2012/09	user13423	password	80	100000	M
13424	LEZEHT	EIVWBYPJED	2710001864 Dell Way	\N	JDCMSFP	\N	0	Germany	2	EIVWBYPJED@dell.com	2710001864	3	4230699158273637	2012/06	user13424	password	40	60000	M
13425	MMBUFF	DBCFZRODUX	6029497375 Dell Way	\N	HXJZCZN	\N	0	Chile	2	DBCFZRODUX@dell.com	6029497375	5	2697083122096956	2012/03	user13425	password	70	100000	M
13426	FYMLEP	MGUMYIQTFX	3512730264 Dell Way	\N	QPXTOKB	\N	0	Canada	2	MGUMYIQTFX@dell.com	3512730264	2	2060374931432306	2010/12	user13426	password	18	20000	F
13427	YQODFB	JZOIHEBNBS	7535174290 Dell Way	\N	CZLRJMU	\N	0	Japan	2	JZOIHEBNBS@dell.com	7535174290	5	2034931375179439	2011/11	user13427	password	37	100000	M
13428	WKZCLJ	BZRJETXGLZ	4209562324 Dell Way	\N	FXROKLF	\N	0	Canada	2	BZRJETXGLZ@dell.com	4209562324	2	8237752618268133	2009/08	user13428	password	62	20000	F
13429	ACOLMQ	LDZPXXVJWA	2146104320 Dell Way	\N	GNPRZUV	\N	0	China	2	LDZPXXVJWA@dell.com	2146104320	4	6490397158544511	2011/03	user13429	password	71	20000	F
13430	VTRHJC	LJSIGOSDOY	1446250844 Dell Way	\N	REQRYLA	\N	0	Australia	2	LJSIGOSDOY@dell.com	1446250844	4	8252379378769548	2009/05	user13430	password	90	60000	F
13431	TENDHY	NAHUOZXCYP	8987701557 Dell Way	\N	GOGFAHI	\N	0	Australia	2	NAHUOZXCYP@dell.com	8987701557	1	4060475286096335	2009/02	user13431	password	79	60000	M
13432	AYAIXN	IFHWEFZDUG	9312256135 Dell Way	\N	SBMSIUU	\N	0	Chile	2	IFHWEFZDUG@dell.com	9312256135	1	5215755049604923	2008/12	user13432	password	84	100000	F
13433	WXITLR	YSODYNGTUZ	6473329877 Dell Way	\N	UGSDBMJ	\N	0	UK	2	YSODYNGTUZ@dell.com	6473329877	5	1323888515122234	2010/09	user13433	password	87	60000	M
13434	WXIHOH	ACKYQRRLQM	8624667064 Dell Way	\N	RIQTVAT	\N	0	France	2	ACKYQRRLQM@dell.com	8624667064	4	1036924781277775	2010/09	user13434	password	60	20000	M
13435	NNXCUY	FFWVWOGNBY	3186381199 Dell Way	\N	VSSRSLC	\N	0	Germany	2	FFWVWOGNBY@dell.com	3186381199	1	2336552216205746	2012/09	user13435	password	42	60000	F
13436	WMGRLL	WIHTWNGYMC	9200019414 Dell Way	\N	QETJQVX	\N	0	South Africa	2	WIHTWNGYMC@dell.com	9200019414	1	8804180600214750	2010/05	user13436	password	51	80000	F
13437	YAXJLU	RSNOGUNTWD	5164609640 Dell Way	\N	YQNOLKL	\N	0	China	2	RSNOGUNTWD@dell.com	5164609640	2	9435951309278608	2012/10	user13437	password	68	20000	M
13438	SACDUU	WIJDCWXZAV	2614012225 Dell Way	\N	PNKAYWK	\N	0	China	2	WIJDCWXZAV@dell.com	2614012225	2	3241981741506606	2012/01	user13438	password	43	80000	M
13439	JVWEPT	NZXQVUPWPE	9427210358 Dell Way	\N	KZFIVPS	\N	0	Australia	2	NZXQVUPWPE@dell.com	9427210358	5	9861543884500862	2012/04	user13439	password	67	80000	M
13440	MOWCHJ	BFZXZPUPUE	2689579520 Dell Way	\N	PZMKPFL	\N	0	Germany	2	BFZXZPUPUE@dell.com	2689579520	3	5483415147289634	2010/02	user13440	password	30	40000	M
13441	SCRAMT	GMRFBLVVPK	7082036706 Dell Way	\N	VCULIGZ	\N	0	Germany	2	GMRFBLVVPK@dell.com	7082036706	3	1234173053409904	2011/08	user13441	password	35	40000	F
13442	IBKUVQ	GMWIYRDOBZ	8788873966 Dell Way	\N	RWKZDKN	\N	0	Russia	2	GMWIYRDOBZ@dell.com	8788873966	3	6247519092168660	2010/10	user13442	password	88	100000	F
13443	AIWWZD	JVLINPWPON	6101006878 Dell Way	\N	MZNPJAK	\N	0	Chile	2	JVLINPWPON@dell.com	6101006878	5	7801043757703156	2009/12	user13443	password	65	60000	M
13444	ZHVYLF	UWNHLJXAXJ	3906239672 Dell Way	\N	ALYJMJQ	\N	0	Australia	2	UWNHLJXAXJ@dell.com	3906239672	2	4420610465575010	2009/01	user13444	password	76	40000	M
13445	CCYNHS	KUZWEXWCGX	3403686255 Dell Way	\N	OFHAOXB	\N	0	South Africa	2	KUZWEXWCGX@dell.com	3403686255	3	2266072220634669	2009/04	user13445	password	45	40000	F
13446	LFXTXH	OXDTUAWBXK	9594930887 Dell Way	\N	GELVBNS	\N	0	China	2	OXDTUAWBXK@dell.com	9594930887	5	6636070193257183	2009/03	user13446	password	85	60000	M
13447	DLLBTZ	ZWSUXOVUYC	5256279824 Dell Way	\N	YKYAXQJ	\N	0	South Africa	2	ZWSUXOVUYC@dell.com	5256279824	5	1483447723090648	2011/11	user13447	password	63	40000	F
13448	CUCVUB	RMVPBRJAUI	7118418151 Dell Way	\N	KSJHISD	\N	0	South Africa	2	RMVPBRJAUI@dell.com	7118418151	1	5544625906273723	2010/10	user13448	password	82	80000	M
13449	RSSLTK	YPZZHIZBRJ	9425657150 Dell Way	\N	TAQCSTX	\N	0	China	2	YPZZHIZBRJ@dell.com	9425657150	3	9645726243499668	2011/04	user13449	password	59	80000	M
13450	HHKARI	QRIXZHYQRS	2337570324 Dell Way	\N	QIVIBTS	\N	0	Australia	2	QRIXZHYQRS@dell.com	2337570324	4	7666858842130751	2010/04	user13450	password	43	60000	M
13451	RVOIEE	ZMCZTBQLTG	1192853757 Dell Way	\N	TPPUIIV	\N	0	France	2	ZMCZTBQLTG@dell.com	1192853757	3	9198208252433688	2009/11	user13451	password	41	100000	M
13452	DJXHOX	URXNSNYMTS	8827432079 Dell Way	\N	BJNJSIW	\N	0	Russia	2	URXNSNYMTS@dell.com	8827432079	4	1037593774497509	2011/01	user13452	password	77	40000	F
13453	EGNTDH	KAVDNUPHMQ	6819916837 Dell Way	\N	RZAJHXC	\N	0	Canada	2	KAVDNUPHMQ@dell.com	6819916837	1	9449428374413402	2011/11	user13453	password	37	100000	F
13454	NMWRTG	RPJFJZNWQE	7695994861 Dell Way	\N	VRODOQH	\N	0	Canada	2	RPJFJZNWQE@dell.com	7695994861	2	9283299908507616	2011/07	user13454	password	81	80000	F
13455	IPRCWJ	RGOBGCXWHT	4481921069 Dell Way	\N	NVWBMEG	\N	0	Chile	2	RGOBGCXWHT@dell.com	4481921069	1	8973698804154993	2012/01	user13455	password	65	100000	F
13456	GOMDYE	KNGQPENWXA	5752398190 Dell Way	\N	STCFYJL	\N	0	China	2	KNGQPENWXA@dell.com	5752398190	2	2819598508998751	2010/12	user13456	password	25	100000	F
13457	RMJPQU	CXKSBXPYYI	3364364019 Dell Way	\N	SANQJYY	\N	0	UK	2	CXKSBXPYYI@dell.com	3364364019	1	5326984333805740	2009/04	user13457	password	50	60000	M
13458	XVOOPQ	LZJMXYLVGD	8828133929 Dell Way	\N	WUTGSSD	\N	0	UK	2	LZJMXYLVGD@dell.com	8828133929	4	2863519333768636	2008/01	user13458	password	65	20000	M
13459	MPOBGZ	BQMYOXUVAR	7146499866 Dell Way	\N	PUXINBI	\N	0	China	2	BQMYOXUVAR@dell.com	7146499866	3	5538862706627697	2011/03	user13459	password	59	80000	M
13460	EHSLHT	BTSQQNMQEB	3129539440 Dell Way	\N	LCKYDSI	\N	0	South Africa	2	BTSQQNMQEB@dell.com	3129539440	5	6186398409307004	2010/05	user13460	password	41	20000	M
13461	PTZWNA	QFRGSDXXFI	4706053952 Dell Way	\N	ZPGCIPX	\N	0	Germany	2	QFRGSDXXFI@dell.com	4706053952	3	9742943780962380	2012/10	user13461	password	20	40000	F
13462	UJIHKY	NBEGEBDJJC	6453614722 Dell Way	\N	ZQFHFCW	\N	0	Japan	2	NBEGEBDJJC@dell.com	6453614722	5	4964819007087499	2010/11	user13462	password	76	100000	M
13463	EEYOCM	PGSTHVDRXC	1765906204 Dell Way	\N	IDKOFGE	\N	0	South Africa	2	PGSTHVDRXC@dell.com	1765906204	4	3311907999217510	2012/06	user13463	password	25	60000	M
13464	GODJAS	PSMXNPPLSX	3264145400 Dell Way	\N	ODLUJQQ	\N	0	France	2	PSMXNPPLSX@dell.com	3264145400	5	4616517989430577	2011/01	user13464	password	90	40000	F
13465	NKQNCF	GPDUESGXQV	2447953878 Dell Way	\N	ACQKSGW	\N	0	UK	2	GPDUESGXQV@dell.com	2447953878	2	6729442696087063	2008/04	user13465	password	83	60000	M
13466	HBIKHO	ZKJEDPBUKC	6398646579 Dell Way	\N	WBMOIIN	\N	0	France	2	ZKJEDPBUKC@dell.com	6398646579	1	6710592365823687	2012/01	user13466	password	23	80000	F
13467	DYSKNR	VWVZMXTWZP	8400965129 Dell Way	\N	YMEGVRS	\N	0	France	2	VWVZMXTWZP@dell.com	8400965129	2	3442911471240222	2012/05	user13467	password	84	40000	M
13468	WXYJPU	GLTSJNPICN	8232394918 Dell Way	\N	VGTQXMB	\N	0	Russia	2	GLTSJNPICN@dell.com	8232394918	2	6545848569367082	2009/03	user13468	password	77	80000	F
13469	TSMIMS	UGLDTAMVNH	3957150207 Dell Way	\N	CHYATZT	\N	0	Germany	2	UGLDTAMVNH@dell.com	3957150207	2	7914987961295993	2010/03	user13469	password	55	80000	M
13470	FDGSWB	YHERHQMVXP	7437881881 Dell Way	\N	CWPWWIK	\N	0	Canada	2	YHERHQMVXP@dell.com	7437881881	1	7689530909527094	2012/09	user13470	password	47	100000	M
13471	OCPKDO	RHFYYSTWHW	3880391031 Dell Way	\N	SWSOFDT	\N	0	UK	2	RHFYYSTWHW@dell.com	3880391031	3	8564619097858668	2008/11	user13471	password	66	100000	F
13472	TOUXCM	EHKDAEZHAR	5089798924 Dell Way	\N	ETGJXZI	\N	0	Chile	2	EHKDAEZHAR@dell.com	5089798924	1	3170910432003438	2009/10	user13472	password	31	80000	M
13473	TOMVAR	DLUDPUKQMO	4918566311 Dell Way	\N	KSYHSHN	\N	0	Canada	2	DLUDPUKQMO@dell.com	4918566311	4	5347391606774181	2009/12	user13473	password	35	100000	M
13474	UIMVAQ	GVTWPEMBSX	5220864485 Dell Way	\N	UREMYSP	\N	0	China	2	GVTWPEMBSX@dell.com	5220864485	1	6919996132608504	2010/04	user13474	password	55	20000	F
13475	WOZWEF	RYCGCPIVMC	3224292874 Dell Way	\N	MROLJEW	\N	0	South Africa	2	RYCGCPIVMC@dell.com	3224292874	3	3332660325802863	2010/01	user13475	password	42	80000	M
13476	XRTCXK	AARDPZYBBL	3232247753 Dell Way	\N	TPXDTTZ	\N	0	Australia	2	AARDPZYBBL@dell.com	3232247753	2	6324550307821483	2009/07	user13476	password	40	20000	F
13477	ZWPXHQ	XYTMXROZDH	6887947892 Dell Way	\N	PALJTKJ	\N	0	Australia	2	XYTMXROZDH@dell.com	6887947892	5	3442138596903533	2009/04	user13477	password	47	80000	F
13478	HHDOXB	MRNKICJMKZ	6813444193 Dell Way	\N	MVIGGRG	\N	0	UK	2	MRNKICJMKZ@dell.com	6813444193	3	2192411112599075	2012/12	user13478	password	79	20000	F
13479	DHTBJF	SWQBZANJZA	1035343233 Dell Way	\N	FHGLZMJ	\N	0	Japan	2	SWQBZANJZA@dell.com	1035343233	3	5846232246607543	2012/04	user13479	password	69	20000	F
13480	AWOJCH	FSIFTWOSXT	1401139604 Dell Way	\N	ADFZQOP	\N	0	Japan	2	FSIFTWOSXT@dell.com	1401139604	1	6110780319664628	2009/11	user13480	password	68	100000	M
13481	OKFQRL	JAQCWFVUZV	6184068156 Dell Way	\N	YEVOTLF	\N	0	Russia	2	JAQCWFVUZV@dell.com	6184068156	4	2447987213265151	2010/06	user13481	password	18	40000	F
13482	KMRBYB	BOEYUZTTUR	3016587893 Dell Way	\N	XPGRALL	\N	0	Japan	2	BOEYUZTTUR@dell.com	3016587893	4	1285277366172522	2011/08	user13482	password	41	80000	F
13483	UJCTLE	HPDCOWVJNT	5121136807 Dell Way	\N	YTKZFWP	\N	0	France	2	HPDCOWVJNT@dell.com	5121136807	4	2073916386347264	2008/12	user13483	password	78	20000	M
13484	FFMQJU	FMWUJRDXLC	3610698690 Dell Way	\N	QVCWRRH	\N	0	Canada	2	FMWUJRDXLC@dell.com	3610698690	2	2940609189216047	2009/03	user13484	password	41	100000	F
13485	NLCXGI	KDCTUFQGIH	8216690953 Dell Way	\N	BKDTBKW	\N	0	China	2	KDCTUFQGIH@dell.com	8216690953	1	6246519709471614	2008/06	user13485	password	58	60000	M
13486	AOVGWF	JYZEEPKNWM	2802379913 Dell Way	\N	XAFZKCI	\N	0	Chile	2	JYZEEPKNWM@dell.com	2802379913	5	3150026404764503	2011/06	user13486	password	69	60000	F
13487	HKSDPC	COHHERUAER	8988441281 Dell Way	\N	AKRLMZQ	\N	0	Japan	2	COHHERUAER@dell.com	8988441281	5	3823061700910330	2009/08	user13487	password	81	100000	M
13488	GOAWQC	LXKPPEQUWQ	6650213774 Dell Way	\N	ENCRNTJ	\N	0	China	2	LXKPPEQUWQ@dell.com	6650213774	4	7663641314487905	2009/07	user13488	password	58	20000	M
13489	CCRTFC	RPRHUHBQYG	9563152247 Dell Way	\N	EAXRTHB	\N	0	China	2	RPRHUHBQYG@dell.com	9563152247	4	6586284073069692	2010/05	user13489	password	70	40000	F
13490	VZFABX	QSEKAGBYMF	7546967359 Dell Way	\N	ZKWTRYD	\N	0	Japan	2	QSEKAGBYMF@dell.com	7546967359	4	2039652737788856	2008/06	user13490	password	48	60000	F
13491	KTILRZ	EVJEBKDOQC	7586743115 Dell Way	\N	YMWPKZF	\N	0	Canada	2	EVJEBKDOQC@dell.com	7586743115	2	3112307685427368	2009/10	user13491	password	75	60000	F
13492	OVPFUU	BEYDOCREFQ	8304203432 Dell Way	\N	RBGCAMG	\N	0	Russia	2	BEYDOCREFQ@dell.com	8304203432	3	9709676744882018	2010/04	user13492	password	51	80000	M
13493	HIACCB	GBEVEWZJMR	5713046893 Dell Way	\N	KTULFAF	\N	0	Australia	2	GBEVEWZJMR@dell.com	5713046893	1	6287804371211678	2011/08	user13493	password	41	80000	M
13494	QQATSG	VXBZUBJHTU	6786151266 Dell Way	\N	ANGFOLF	\N	0	Australia	2	VXBZUBJHTU@dell.com	6786151266	5	9038903611246496	2009/02	user13494	password	55	40000	M
13495	EHNXOJ	VPJPRSWLMX	2321583034 Dell Way	\N	ZSCOEIQ	\N	0	South Africa	2	VPJPRSWLMX@dell.com	2321583034	3	1979453850537538	2009/01	user13495	password	43	20000	F
13496	QPDEYY	UHNMAKXMIX	6748787219 Dell Way	\N	FKLJTCE	\N	0	UK	2	UHNMAKXMIX@dell.com	6748787219	2	2617547247093171	2011/08	user13496	password	35	100000	F
13497	VALUZF	CMRCXPPFMU	6540765217 Dell Way	\N	QXDKAIH	\N	0	Japan	2	CMRCXPPFMU@dell.com	6540765217	3	4115680625196546	2009/09	user13497	password	37	60000	M
13498	HYIGEL	TVNRKCXXWO	7481628840 Dell Way	\N	UAYVJGM	\N	0	UK	2	TVNRKCXXWO@dell.com	7481628840	5	2976904791314155	2010/01	user13498	password	72	100000	F
13499	SIQWTK	RHCCJZZGNU	8943629024 Dell Way	\N	GMPPSBO	\N	0	France	2	RHCCJZZGNU@dell.com	8943629024	4	8819362452253700	2012/07	user13499	password	80	40000	F
13500	EZCYKT	FMWPMWVAQC	1644991225 Dell Way	\N	MGSFIHQ	\N	0	Canada	2	FMWPMWVAQC@dell.com	1644991225	3	2439328099600971	2011/05	user13500	password	54	100000	M
13501	MXMXRR	JOGWKCWBEJ	7043626794 Dell Way	\N	HWOPEEV	\N	0	Chile	2	JOGWKCWBEJ@dell.com	7043626794	5	8519880408886821	2008/06	user13501	password	67	60000	M
13502	PAVHSF	VZCGBZHFIP	9835206741 Dell Way	\N	CWFGBAM	\N	0	Russia	2	VZCGBZHFIP@dell.com	9835206741	2	7751216176431627	2010/01	user13502	password	40	60000	M
13503	IGXBMS	AOZBNHHWWK	5353926247 Dell Way	\N	TBRUCEN	\N	0	Australia	2	AOZBNHHWWK@dell.com	5353926247	2	5608535571023822	2010/07	user13503	password	85	20000	M
13504	EZYRSZ	FRBTYIQVTJ	9699738439 Dell Way	\N	XKEZORA	\N	0	Australia	2	FRBTYIQVTJ@dell.com	9699738439	3	5859631552826614	2010/06	user13504	password	63	60000	M
13505	PLHHKN	ZLHYUYTNHQ	2692640193 Dell Way	\N	YLQNDQO	\N	0	Canada	2	ZLHYUYTNHQ@dell.com	2692640193	1	7013648821506650	2011/09	user13505	password	27	40000	F
13506	OPQZCP	KKNEIHSQYR	8714915573 Dell Way	\N	COEGETJ	\N	0	China	2	KKNEIHSQYR@dell.com	8714915573	1	1266994063276797	2010/02	user13506	password	41	100000	M
13507	XNRADC	LRHTYAKWRM	1903280602 Dell Way	\N	KVSPPBZ	\N	0	France	2	LRHTYAKWRM@dell.com	1903280602	1	1337188466452062	2009/05	user13507	password	87	100000	F
13508	MRGQTS	HBLFBVCSIN	2117840396 Dell Way	\N	OADDCCP	\N	0	Chile	2	HBLFBVCSIN@dell.com	2117840396	4	5158537714276463	2010/07	user13508	password	50	80000	F
13509	CZSWRZ	XCFZYIRGVF	6281758081 Dell Way	\N	HZJKBYP	\N	0	Canada	2	XCFZYIRGVF@dell.com	6281758081	1	6909637219272555	2008/07	user13509	password	44	40000	M
13510	IYMZYK	CDJBMBHIHP	6717247814 Dell Way	\N	HQZJPPO	\N	0	Canada	2	CDJBMBHIHP@dell.com	6717247814	2	4243268798571080	2008/07	user13510	password	62	80000	M
13511	OGWMQY	QAZCBHKJXS	8214682678 Dell Way	\N	ZWBPMPU	\N	0	Australia	2	QAZCBHKJXS@dell.com	8214682678	1	3096378087997436	2009/10	user13511	password	89	40000	F
13512	FCUWBK	XBNZIYIGQI	8882772882 Dell Way	\N	DSYPHSR	\N	0	Australia	2	XBNZIYIGQI@dell.com	8882772882	5	5124367364682257	2011/11	user13512	password	69	100000	F
13513	VSAWDX	YRXHQFNHOQ	8141291325 Dell Way	\N	ZMFGFWJ	\N	0	Australia	2	YRXHQFNHOQ@dell.com	8141291325	5	7497345742769540	2011/07	user13513	password	66	100000	F
13514	JVFNSD	FQKVWXCKOB	5560218454 Dell Way	\N	XTICQRF	\N	0	France	2	FQKVWXCKOB@dell.com	5560218454	5	1997405485715717	2008/07	user13514	password	85	40000	M
13515	TOMLSS	CDNYAQIOSF	5181558640 Dell Way	\N	IBIYTOJ	\N	0	Chile	2	CDNYAQIOSF@dell.com	5181558640	3	3449041706044227	2008/05	user13515	password	64	20000	F
13516	FNPXFR	ATPBJYQCEY	7753046147 Dell Way	\N	DMXWBHD	\N	0	Germany	2	ATPBJYQCEY@dell.com	7753046147	2	5956212962511927	2008/01	user13516	password	59	40000	F
13517	BWEHOE	ADGKBXMFWQ	1193134635 Dell Way	\N	STNTAQH	\N	0	Russia	2	ADGKBXMFWQ@dell.com	1193134635	5	9323877225629986	2008/05	user13517	password	33	40000	F
13518	CLTQQT	UXEWURCQIV	7037198314 Dell Way	\N	KVPKLWE	\N	0	France	2	UXEWURCQIV@dell.com	7037198314	1	5654726114589721	2008/04	user13518	password	76	60000	F
13519	GGBWAV	TFSOWUEEPO	3555999614 Dell Way	\N	ZEZLAEX	\N	0	Russia	2	TFSOWUEEPO@dell.com	3555999614	3	7853366086725146	2011/03	user13519	password	37	20000	F
13520	NBIOXC	TQRPKVUAKU	6135204716 Dell Way	\N	FKFGODY	\N	0	South Africa	2	TQRPKVUAKU@dell.com	6135204716	4	5164763029199094	2012/12	user13520	password	53	40000	M
13521	OQBMSU	CJKMFFNQZS	6221845142 Dell Way	\N	AFYPJWM	\N	0	UK	2	CJKMFFNQZS@dell.com	6221845142	5	7555914123542608	2010/05	user13521	password	18	20000	M
13522	QCLJXN	SHAYMOPMGQ	6508750182 Dell Way	\N	SEFBBRZ	\N	0	Japan	2	SHAYMOPMGQ@dell.com	6508750182	4	2825388979166746	2008/09	user13522	password	36	100000	F
13523	JLRGYK	OZJBNYNUOF	9732390361 Dell Way	\N	ZUHAMGR	\N	0	Australia	2	OZJBNYNUOF@dell.com	9732390361	5	1961087382398545	2011/02	user13523	password	24	20000	M
13524	NRTMCI	MLJZKXUZDT	4068697899 Dell Way	\N	TKUFRLI	\N	0	Japan	2	MLJZKXUZDT@dell.com	4068697899	3	3896055538207293	2010/07	user13524	password	42	100000	F
13525	ATNDBZ	PLZZITYLMS	7138613186 Dell Way	\N	WGYNSGE	\N	0	Australia	2	PLZZITYLMS@dell.com	7138613186	3	5697581817395986	2008/10	user13525	password	55	40000	M
13526	GTZISO	TROCKNNWFK	6385753053 Dell Way	\N	DEYVLCW	\N	0	Canada	2	TROCKNNWFK@dell.com	6385753053	2	3787797043565661	2010/11	user13526	password	57	40000	F
13527	HGMZVF	RKHBXVYDFB	1881646025 Dell Way	\N	IDWTGSW	\N	0	South Africa	2	RKHBXVYDFB@dell.com	1881646025	1	3493558270391077	2012/09	user13527	password	59	20000	M
13528	VPZRVQ	BCSZYQDDSL	2734219110 Dell Way	\N	HPEOIAK	\N	0	France	2	BCSZYQDDSL@dell.com	2734219110	4	4557650814764202	2012/03	user13528	password	55	100000	F
13529	CWSXMU	AFTYWXCOIK	1019960844 Dell Way	\N	EMYMNIX	\N	0	Russia	2	AFTYWXCOIK@dell.com	1019960844	2	6462732590734959	2009/10	user13529	password	53	40000	M
13530	JAVWVW	BPVXMXMUHQ	3749288824 Dell Way	\N	HGDUOAN	\N	0	Germany	2	BPVXMXMUHQ@dell.com	3749288824	1	8247149079572410	2008/08	user13530	password	25	20000	M
13531	DWUYSW	OOTALGUTXC	5396203469 Dell Way	\N	ZAWOAJD	\N	0	China	2	OOTALGUTXC@dell.com	5396203469	5	5046008258592338	2008/01	user13531	password	53	20000	F
13532	JVCCRQ	QLRBRMVOOU	4347521925 Dell Way	\N	PLIQVLY	\N	0	Chile	2	QLRBRMVOOU@dell.com	4347521925	3	4487199611030519	2009/11	user13532	password	49	60000	F
13533	GRIYIY	KZABLVQAPF	2788106097 Dell Way	\N	LYVGKUO	\N	0	Russia	2	KZABLVQAPF@dell.com	2788106097	5	2412026375997811	2008/05	user13533	password	69	40000	M
13534	JQORPY	RPADKRDAXO	3759835504 Dell Way	\N	YTVINJC	\N	0	Russia	2	RPADKRDAXO@dell.com	3759835504	2	8362633529119194	2011/12	user13534	password	28	40000	F
13535	UWAJVS	YVVJMYJKNI	1207366683 Dell Way	\N	DIRRSTK	\N	0	Australia	2	YVVJMYJKNI@dell.com	1207366683	2	7220227727666498	2012/05	user13535	password	89	40000	F
13536	VJMQBL	MWVZVFJJNM	8080342283 Dell Way	\N	SFELZOL	\N	0	UK	2	MWVZVFJJNM@dell.com	8080342283	1	9772477831691504	2008/02	user13536	password	40	40000	M
13537	RUPSGC	PBBLGKVUXN	5717418177 Dell Way	\N	ZCYYQKX	\N	0	France	2	PBBLGKVUXN@dell.com	5717418177	5	6204827787820250	2011/03	user13537	password	80	80000	M
13538	QFPWHF	YIQETLZRZY	7251763272 Dell Way	\N	TXWKHUV	\N	0	South Africa	2	YIQETLZRZY@dell.com	7251763272	3	5257366525940597	2012/04	user13538	password	23	80000	M
13539	HJVOOT	XFYRRXJQWD	8193983552 Dell Way	\N	OSNWNJS	\N	0	Chile	2	XFYRRXJQWD@dell.com	8193983552	1	2079863983672112	2008/03	user13539	password	82	20000	M
13540	GVCUOA	ANRRKBIGEX	6765450836 Dell Way	\N	ZSTNCMT	\N	0	South Africa	2	ANRRKBIGEX@dell.com	6765450836	5	9787020819261672	2012/09	user13540	password	89	60000	M
13541	UNUJNU	WFMHHUOLRN	7038880462 Dell Way	\N	ELBGXUE	\N	0	Germany	2	WFMHHUOLRN@dell.com	7038880462	1	5036353135947138	2010/02	user13541	password	81	60000	M
13542	JFHXZE	DLLKGZWYNA	6243828334 Dell Way	\N	KOHIJLW	\N	0	Australia	2	DLLKGZWYNA@dell.com	6243828334	2	5156482065096498	2011/03	user13542	password	81	80000	M
13543	BXMBBP	NNATMWSZXC	6287715036 Dell Way	\N	OEKYQHZ	\N	0	Chile	2	NNATMWSZXC@dell.com	6287715036	3	9145623004063964	2011/04	user13543	password	56	40000	F
13544	LVKNLX	ALRNHJMELB	4459168058 Dell Way	\N	JWZZDYE	\N	0	Russia	2	ALRNHJMELB@dell.com	4459168058	1	5397363625001163	2011/08	user13544	password	78	20000	F
13545	QMOCJP	NBCVLPAXQJ	6575824258 Dell Way	\N	TQJWONP	\N	0	UK	2	NBCVLPAXQJ@dell.com	6575824258	1	6822324161883444	2009/11	user13545	password	69	40000	M
13546	EWQOME	POZADAYUJR	2958190981 Dell Way	\N	KSOZGDY	\N	0	South Africa	2	POZADAYUJR@dell.com	2958190981	4	2025233919732272	2008/04	user13546	password	48	80000	F
13547	HIATMQ	IMRMMPGWGR	3088987776 Dell Way	\N	PURVYQS	\N	0	Canada	2	IMRMMPGWGR@dell.com	3088987776	5	3535657816566527	2010/03	user13547	password	88	100000	M
13548	HAHUQP	HHBUWIQDAG	6746210236 Dell Way	\N	XRCWIUA	\N	0	Germany	2	HHBUWIQDAG@dell.com	6746210236	2	1660230350680649	2012/04	user13548	password	23	60000	M
13549	CSJSHR	AJLWRCZRIX	1684646666 Dell Way	\N	JKURFUF	\N	0	South Africa	2	AJLWRCZRIX@dell.com	1684646666	2	7542115675285459	2009/05	user13549	password	28	100000	F
13550	WHEDYE	NKBEMAWUYG	4770502657 Dell Way	\N	FSXKNDG	\N	0	Germany	2	NKBEMAWUYG@dell.com	4770502657	5	9333403044845910	2011/02	user13550	password	78	40000	M
13551	CJCBOP	LPUYQRSPYY	5820220271 Dell Way	\N	HVIVZOK	\N	0	China	2	LPUYQRSPYY@dell.com	5820220271	2	2535004414618015	2011/02	user13551	password	46	80000	F
13552	USIIIU	XDSNVLCTJK	9586714242 Dell Way	\N	PRFOGQY	\N	0	Russia	2	XDSNVLCTJK@dell.com	9586714242	1	4821828805841506	2008/07	user13552	password	20	40000	F
13553	TSPCMN	GFBBQEUZOK	1203953316 Dell Way	\N	QUYWLXQ	\N	0	China	2	GFBBQEUZOK@dell.com	1203953316	1	5442013595718891	2010/02	user13553	password	82	100000	M
13554	PLZCYF	HAGXEBWSLN	2027393755 Dell Way	\N	NJKYHBI	\N	0	Chile	2	HAGXEBWSLN@dell.com	2027393755	5	8490274650976063	2009/09	user13554	password	66	20000	F
13555	CBKBGS	BMPFNMYZZM	6118802882 Dell Way	\N	IJKPKTX	\N	0	Germany	2	BMPFNMYZZM@dell.com	6118802882	4	7855957880150528	2009/05	user13555	password	80	60000	F
13556	XZOERP	RHUFTTETFM	7611731115 Dell Way	\N	DQCOJAC	\N	0	UK	2	RHUFTTETFM@dell.com	7611731115	5	2854966364335269	2008/09	user13556	password	75	80000	M
13557	UEULTM	TORNHVGMIK	9371905497 Dell Way	\N	CKZMKBK	\N	0	Canada	2	TORNHVGMIK@dell.com	9371905497	4	3536869923584163	2011/05	user13557	password	83	40000	F
13558	BCQUOJ	IFWQADDINF	7336404388 Dell Way	\N	TMSEOCI	\N	0	France	2	IFWQADDINF@dell.com	7336404388	4	2295970724895596	2008/07	user13558	password	49	40000	M
13559	NWJBGS	GCIHFMQTRK	5689055162 Dell Way	\N	GJOUMXH	\N	0	Canada	2	GCIHFMQTRK@dell.com	5689055162	3	3543137001339346	2008/11	user13559	password	57	80000	F
13560	LZLRRS	TAZZMPSEAY	5092727390 Dell Way	\N	OOSAMAF	\N	0	UK	2	TAZZMPSEAY@dell.com	5092727390	3	1314048458356410	2009/01	user13560	password	64	80000	F
13561	PDDHVX	IUWUKOZLMN	3645167037 Dell Way	\N	ZFOMGUM	\N	0	Japan	2	IUWUKOZLMN@dell.com	3645167037	3	1097701076883822	2009/02	user13561	password	69	100000	M
13562	VZBQWJ	LSEWHDHURH	7873847967 Dell Way	\N	ZFUFAGX	\N	0	China	2	LSEWHDHURH@dell.com	7873847967	5	6900273937731982	2012/08	user13562	password	53	80000	F
13563	LSCIBO	AFLIJTCABB	2365792368 Dell Way	\N	GVHGBFO	\N	0	South Africa	2	AFLIJTCABB@dell.com	2365792368	2	7694177509751172	2011/09	user13563	password	48	40000	F
13564	DJLFYM	LJUUCWUDYB	1867967296 Dell Way	\N	ZGHAMWW	\N	0	Japan	2	LJUUCWUDYB@dell.com	1867967296	4	4611141442786902	2012/01	user13564	password	65	100000	F
13565	AKJYXU	ISOLOJPNKO	1524851445 Dell Way	\N	TSPFPLV	\N	0	Japan	2	ISOLOJPNKO@dell.com	1524851445	2	5302507055923343	2008/11	user13565	password	49	40000	M
13566	VPWTJE	LYPAHENSTH	6229953141 Dell Way	\N	KINZUIR	\N	0	South Africa	2	LYPAHENSTH@dell.com	6229953141	1	9237607346381992	2010/07	user13566	password	28	40000	F
13567	SFECKP	AAPHFDZYKK	2615133468 Dell Way	\N	GYJBHBW	\N	0	South Africa	2	AAPHFDZYKK@dell.com	2615133468	4	3908677154686302	2011/12	user13567	password	69	20000	M
13568	YITIXT	INBNQBLBLS	4822729445 Dell Way	\N	ZVTGWQD	\N	0	Australia	2	INBNQBLBLS@dell.com	4822729445	3	8164886965416373	2009/02	user13568	password	87	20000	F
13569	HTKENS	SPGIQSKCLK	2930909713 Dell Way	\N	XFRUVUV	\N	0	Chile	2	SPGIQSKCLK@dell.com	2930909713	4	6557527431286872	2009/07	user13569	password	64	60000	M
13570	KVAYNS	NUBDNMFYWD	4049326085 Dell Way	\N	DNXZHSF	\N	0	Germany	2	NUBDNMFYWD@dell.com	4049326085	5	8823892250657082	2012/06	user13570	password	38	80000	M
13571	CUVQNI	KOMXBSWXVZ	1245361238 Dell Way	\N	LTYTMEG	\N	0	South Africa	2	KOMXBSWXVZ@dell.com	1245361238	1	7440240963827819	2010/06	user13571	password	52	40000	M
13572	GFDUOO	JAMKTJIPIT	8973879601 Dell Way	\N	IHMUMTP	\N	0	Germany	2	JAMKTJIPIT@dell.com	8973879601	2	1230784840881824	2009/10	user13572	password	48	100000	F
13573	QZVEOE	FAOZKWOTQW	6227681809 Dell Way	\N	BDRNWHB	\N	0	Russia	2	FAOZKWOTQW@dell.com	6227681809	1	1570117184426635	2009/06	user13573	password	82	60000	F
13574	WFIKKO	LYNVVCOLZP	3252911671 Dell Way	\N	OQDLXEF	\N	0	France	2	LYNVVCOLZP@dell.com	3252911671	2	8681020661722870	2011/02	user13574	password	37	100000	M
13575	MFJWTV	VHQQJECIUQ	5751313764 Dell Way	\N	YXCWBHJ	\N	0	China	2	VHQQJECIUQ@dell.com	5751313764	2	1660418147221207	2011/06	user13575	password	87	80000	M
13576	EAVXVR	EMHOQKWLAV	3132801698 Dell Way	\N	IDRKKAT	\N	0	UK	2	EMHOQKWLAV@dell.com	3132801698	5	6232515347190202	2011/10	user13576	password	35	80000	M
13577	HMVDEA	PMOGWLRXGA	9508391484 Dell Way	\N	AYKKYDI	\N	0	Canada	2	PMOGWLRXGA@dell.com	9508391484	5	9101459824945780	2011/02	user13577	password	58	80000	F
13578	BLNFMD	RAJNLALSBL	1340153862 Dell Way	\N	QLVPPDU	\N	0	Germany	2	RAJNLALSBL@dell.com	1340153862	4	3128639450762421	2008/03	user13578	password	80	60000	F
13579	ICNUFE	UPSGPDZRPP	6785247798 Dell Way	\N	CKEROYF	\N	0	Japan	2	UPSGPDZRPP@dell.com	6785247798	3	7962617962621153	2012/04	user13579	password	43	20000	M
13580	LSKRXF	GQMWTLNJAP	9727594978 Dell Way	\N	UFHJENY	\N	0	South Africa	2	GQMWTLNJAP@dell.com	9727594978	4	7291912940330804	2009/01	user13580	password	82	100000	M
13581	PHEMNK	CZGWKTFLJZ	1250206967 Dell Way	\N	RRIVEHQ	\N	0	Canada	2	CZGWKTFLJZ@dell.com	1250206967	2	4844579520635307	2008/03	user13581	password	42	80000	M
13582	QUHDFJ	DLGOFLZPLQ	5134692850 Dell Way	\N	GUMKCDO	\N	0	Canada	2	DLGOFLZPLQ@dell.com	5134692850	5	3015982225537300	2011/04	user13582	password	79	60000	M
13583	QUCVDG	HKUMVUCHLI	3524048113 Dell Way	\N	CXTEAHH	\N	0	France	2	HKUMVUCHLI@dell.com	3524048113	3	2587753822561353	2010/05	user13583	password	66	60000	M
13584	LRVPXC	ZRPVMRDXAF	2947715194 Dell Way	\N	VTKWARI	\N	0	China	2	ZRPVMRDXAF@dell.com	2947715194	3	9253008473198862	2010/03	user13584	password	52	60000	M
13585	DKGBNF	SDBFVECVKX	6676413701 Dell Way	\N	OUUPMCX	\N	0	Japan	2	SDBFVECVKX@dell.com	6676413701	5	3365064206067473	2012/04	user13585	password	79	60000	F
13586	GRMUXF	XZKSDNNNLC	4907386139 Dell Way	\N	IFRUIPL	\N	0	UK	2	XZKSDNNNLC@dell.com	4907386139	4	7896622381638736	2011/07	user13586	password	34	20000	M
13587	XRPVWM	UHFYVTMGVU	7671294084 Dell Way	\N	LNOUDAS	\N	0	Germany	2	UHFYVTMGVU@dell.com	7671294084	3	3738872549496591	2009/09	user13587	password	53	20000	M
13588	ESLBFG	ILFDESKANW	8372509003 Dell Way	\N	NCQRCIF	\N	0	South Africa	2	ILFDESKANW@dell.com	8372509003	3	2328374412376433	2010/01	user13588	password	37	20000	F
13589	ZPFEVO	PASUSCUFYI	7769435232 Dell Way	\N	HOZKXFG	\N	0	Russia	2	PASUSCUFYI@dell.com	7769435232	3	3263949159067124	2011/09	user13589	password	46	100000	M
13590	ZEVUSL	VLFONAUMIC	2456670148 Dell Way	\N	BINZOTS	\N	0	Chile	2	VLFONAUMIC@dell.com	2456670148	5	1642608396708965	2012/05	user13590	password	19	60000	F
13591	FIDYTY	JZNXAHKJJL	1812851513 Dell Way	\N	RWLFQDN	\N	0	South Africa	2	JZNXAHKJJL@dell.com	1812851513	3	6702924185898156	2010/08	user13591	password	26	80000	M
13592	LWTFVC	FIAFPKOZWG	6136138812 Dell Way	\N	WHLNLZI	\N	0	Germany	2	FIAFPKOZWG@dell.com	6136138812	5	9543949855957180	2008/01	user13592	password	69	20000	F
13593	OTRJWW	SWCIGQHCWE	9564716482 Dell Way	\N	KIRVIAI	\N	0	South Africa	2	SWCIGQHCWE@dell.com	9564716482	2	1707219752483070	2008/12	user13593	password	23	60000	M
13594	VFYRCQ	NEYUVGXSLH	7836368500 Dell Way	\N	BCDJDMG	\N	0	Australia	2	NEYUVGXSLH@dell.com	7836368500	2	1737098764628172	2011/05	user13594	password	61	40000	F
13595	UGXWWL	BVGWCDONLQ	6166935533 Dell Way	\N	QPZTBGU	\N	0	South Africa	2	BVGWCDONLQ@dell.com	6166935533	5	6057091069873423	2012/06	user13595	password	81	40000	F
13596	CDDZPE	VWBXAQKLGA	5066518050 Dell Way	\N	AGTCMOX	\N	0	Australia	2	VWBXAQKLGA@dell.com	5066518050	3	1325346882455051	2012/04	user13596	password	37	20000	F
13597	KILANG	WPEWFPILPJ	8436443369 Dell Way	\N	RJLEYJF	\N	0	China	2	WPEWFPILPJ@dell.com	8436443369	2	3890239058993757	2008/07	user13597	password	55	80000	M
13598	VBZJHV	YMSDBBPRLH	9272076582 Dell Way	\N	AXMZGRJ	\N	0	Australia	2	YMSDBBPRLH@dell.com	9272076582	4	3138263254426420	2010/03	user13598	password	79	40000	F
13599	WIKEEJ	QXNSZCJKKK	4913625200 Dell Way	\N	HWJOOTQ	\N	0	France	2	QXNSZCJKKK@dell.com	4913625200	5	9084230998996646	2011/09	user13599	password	37	80000	M
13600	PCTULK	RYCQBLBMWI	4150605434 Dell Way	\N	IFWXYMJ	\N	0	China	2	RYCQBLBMWI@dell.com	4150605434	2	1323196568060666	2008/07	user13600	password	70	80000	F
13601	VJXHUP	FWGHIHTEPC	6259156241 Dell Way	\N	KMZJZIT	\N	0	China	2	FWGHIHTEPC@dell.com	6259156241	4	4403281312435866	2008/07	user13601	password	90	40000	F
13602	JDQDSW	AYDJFXOVZY	8982505560 Dell Way	\N	IZIIICQ	\N	0	UK	2	AYDJFXOVZY@dell.com	8982505560	1	1037024924065917	2010/01	user13602	password	34	80000	F
13603	IJOBGO	ZJYFHMBHLJ	4089254152 Dell Way	\N	GURPWIM	\N	0	Russia	2	ZJYFHMBHLJ@dell.com	4089254152	3	2556004480924457	2009/09	user13603	password	85	80000	F
13604	IHCOWC	YVHFIJMUTT	3779931717 Dell Way	\N	OKILTVF	\N	0	Australia	2	YVHFIJMUTT@dell.com	3779931717	2	5018088633660227	2008/04	user13604	password	32	20000	M
13605	MEEJHC	EPIMYVGROV	8421926382 Dell Way	\N	CXGVSLX	\N	0	Australia	2	EPIMYVGROV@dell.com	8421926382	2	1497181111015379	2008/07	user13605	password	27	80000	F
13606	IXKPAP	EICCDJUSEW	9882065310 Dell Way	\N	QLSIXQJ	\N	0	Russia	2	EICCDJUSEW@dell.com	9882065310	3	8565045158378781	2010/07	user13606	password	60	80000	M
13607	MAMNQQ	WSTZCOSGKI	5225155207 Dell Way	\N	SDRPTAH	\N	0	Russia	2	WSTZCOSGKI@dell.com	5225155207	1	3505555451847613	2008/09	user13607	password	82	100000	F
13608	XJTOAP	HUOJIHPTPH	3969161273 Dell Way	\N	WGXPHEI	\N	0	Russia	2	HUOJIHPTPH@dell.com	3969161273	4	8199786067008973	2008/06	user13608	password	69	40000	F
13609	CAYDPF	XEOFLEYAMU	3948028182 Dell Way	\N	HJKPOSJ	\N	0	South Africa	2	XEOFLEYAMU@dell.com	3948028182	1	9548768834210932	2012/11	user13609	password	34	40000	M
13610	GEBVJZ	ZYEKDDLPYT	8615890151 Dell Way	\N	ZJIOBRL	\N	0	China	2	ZYEKDDLPYT@dell.com	8615890151	3	2933725806884467	2011/08	user13610	password	49	80000	M
13611	PTRZSQ	YXBBBNRAGR	1573042904 Dell Way	\N	JPFKHRV	\N	0	Canada	2	YXBBBNRAGR@dell.com	1573042904	1	8589398949872703	2011/06	user13611	password	55	60000	F
13612	HFBZWZ	XYAZMRZSJI	6445183136 Dell Way	\N	IOTPFOS	\N	0	Chile	2	XYAZMRZSJI@dell.com	6445183136	3	9746189840603620	2008/02	user13612	password	55	20000	F
13613	TEJPEG	OEGAWFTFNB	9561090671 Dell Way	\N	UHQZVJH	\N	0	France	2	OEGAWFTFNB@dell.com	9561090671	2	5692054777871818	2008/10	user13613	password	66	40000	M
13614	WTCAAR	EGRBLKHZMB	6213706364 Dell Way	\N	GDBCNIO	\N	0	France	2	EGRBLKHZMB@dell.com	6213706364	1	5492707404773683	2009/09	user13614	password	83	100000	M
13615	QZPRQT	YIVKTCJFDQ	4310698674 Dell Way	\N	IFTVNHH	\N	0	Canada	2	YIVKTCJFDQ@dell.com	4310698674	5	5117548648733646	2008/09	user13615	password	40	80000	F
13616	HGAXAY	FWIYYSECJM	4936525557 Dell Way	\N	ICIWKQY	\N	0	Russia	2	FWIYYSECJM@dell.com	4936525557	3	8819347545038910	2008/09	user13616	password	58	60000	M
13617	VNXWMD	SVBRNGUXSC	3996488604 Dell Way	\N	ZBYKSXE	\N	0	Canada	2	SVBRNGUXSC@dell.com	3996488604	1	3462773861829191	2008/08	user13617	password	73	20000	F
13618	HYGTCZ	OERCKLZCOZ	6192606713 Dell Way	\N	ENJWLOA	\N	0	Russia	2	OERCKLZCOZ@dell.com	6192606713	2	8375150518491865	2008/01	user13618	password	81	60000	F
13619	VVCXUQ	BLTLXTOLST	9284165834 Dell Way	\N	ZCQKQQE	\N	0	Chile	2	BLTLXTOLST@dell.com	9284165834	5	4502477012574673	2012/11	user13619	password	87	40000	M
13620	UJPPAR	ATDYMSKFLJ	9175899121 Dell Way	\N	IBTZSYF	\N	0	Japan	2	ATDYMSKFLJ@dell.com	9175899121	3	6357264896854759	2011/07	user13620	password	83	60000	F
13621	GBXHTY	BWWNOHTAQB	8288457256 Dell Way	\N	CKAUIFL	\N	0	Chile	2	BWWNOHTAQB@dell.com	8288457256	1	1146970976609736	2009/11	user13621	password	52	80000	F
13622	NOMGNN	DJBSRUTHVV	1614853379 Dell Way	\N	SWQBCBI	\N	0	UK	2	DJBSRUTHVV@dell.com	1614853379	2	3300257526803762	2012/10	user13622	password	85	20000	F
13623	MQPZDT	JELAZEIVAB	8105604920 Dell Way	\N	RQDURLR	\N	0	Russia	2	JELAZEIVAB@dell.com	8105604920	5	7617302880622447	2010/11	user13623	password	83	100000	F
13624	NNJRHS	VTTVXCQYEI	7481843802 Dell Way	\N	OICGTUA	\N	0	Germany	2	VTTVXCQYEI@dell.com	7481843802	4	2356946145184338	2010/08	user13624	password	24	100000	F
13625	QHVXAR	QUMOXCMBKB	1644800419 Dell Way	\N	JNIDHIS	\N	0	Australia	2	QUMOXCMBKB@dell.com	1644800419	5	6323478392325342	2011/12	user13625	password	56	100000	M
13626	VSMWKC	QWRNZDPKFZ	7229802576 Dell Way	\N	XNDFVVF	\N	0	UK	2	QWRNZDPKFZ@dell.com	7229802576	4	6675682086963207	2011/04	user13626	password	55	20000	F
13627	FRAPTQ	MKEMOTWTTU	9689940782 Dell Way	\N	HWZDSEB	\N	0	France	2	MKEMOTWTTU@dell.com	9689940782	4	1358834165614098	2009/03	user13627	password	34	60000	F
13628	XLAQBN	BGZPAWJTQQ	5384819947 Dell Way	\N	QPUIUVT	\N	0	Russia	2	BGZPAWJTQQ@dell.com	5384819947	4	1357682181987911	2011/01	user13628	password	53	20000	M
13629	YCOAPP	GPFGLPZCGQ	5549813885 Dell Way	\N	RAYMVSF	\N	0	China	2	GPFGLPZCGQ@dell.com	5549813885	2	9881770146079362	2010/09	user13629	password	22	60000	M
13630	EZRUPX	JVEVKDXQTP	5807463052 Dell Way	\N	QSBMLHU	\N	0	UK	2	JVEVKDXQTP@dell.com	5807463052	4	5232092095538974	2009/11	user13630	password	84	100000	F
13631	XPUNNE	IRZSVXJPMA	1587344426 Dell Way	\N	HNMTVHR	\N	0	China	2	IRZSVXJPMA@dell.com	1587344426	1	6593018718529493	2012/01	user13631	password	59	100000	M
13632	ETMSXU	JXNFVWUHWC	7130046508 Dell Way	\N	VJVQQNZ	\N	0	Russia	2	JXNFVWUHWC@dell.com	7130046508	4	6562385406345130	2011/03	user13632	password	58	80000	F
13633	HEBFZL	DMQYILGFOB	3748853602 Dell Way	\N	OKSEXSX	\N	0	Germany	2	DMQYILGFOB@dell.com	3748853602	3	4104616923723370	2010/01	user13633	password	22	100000	F
13634	GXOFIS	RZQALWFZYT	4203486337 Dell Way	\N	JQYHIVX	\N	0	Japan	2	RZQALWFZYT@dell.com	4203486337	2	2117215055972337	2010/04	user13634	password	87	80000	M
13635	WITEBK	ERLPOQPMKY	4242221446 Dell Way	\N	DIGLEDC	\N	0	Germany	2	ERLPOQPMKY@dell.com	4242221446	2	9662235881201924	2011/03	user13635	password	72	20000	F
13636	CXFDIK	UTZIKOVUNY	7361787670 Dell Way	\N	DTJHXMW	\N	0	Chile	2	UTZIKOVUNY@dell.com	7361787670	5	9065926917362960	2012/07	user13636	password	23	100000	M
13637	ZDTINO	CNXMBSGPQJ	4028462811 Dell Way	\N	JARGMNM	\N	0	Chile	2	CNXMBSGPQJ@dell.com	4028462811	2	1842365837655961	2012/06	user13637	password	18	60000	F
13638	DHURVW	ETIGLPWBZF	3752634674 Dell Way	\N	CQLPEYU	\N	0	Germany	2	ETIGLPWBZF@dell.com	3752634674	5	4597957689780742	2011/11	user13638	password	85	40000	F
13639	FZSBWX	UFDFUZHUFK	6893962280 Dell Way	\N	LQZPOTC	\N	0	South Africa	2	UFDFUZHUFK@dell.com	6893962280	3	6708644914440811	2010/06	user13639	password	80	80000	M
13640	WISSFM	XJSSJANOKY	2358284550 Dell Way	\N	EJNTDQQ	\N	0	Russia	2	XJSSJANOKY@dell.com	2358284550	2	4145332802087069	2010/02	user13640	password	87	40000	M
13641	GXRMKP	VCIECVSNTX	5929930348 Dell Way	\N	WHRAXHV	\N	0	Australia	2	VCIECVSNTX@dell.com	5929930348	1	6824015479069204	2011/02	user13641	password	82	80000	F
13642	UHWFWR	HFWKAPYTNU	8242237917 Dell Way	\N	AEVYMQA	\N	0	Australia	2	HFWKAPYTNU@dell.com	8242237917	4	7054057788103820	2012/07	user13642	password	38	40000	F
13643	OENLWV	QSGRIEKVZL	1505453223 Dell Way	\N	AVKMLKM	\N	0	Chile	2	QSGRIEKVZL@dell.com	1505453223	1	2619775203056633	2010/06	user13643	password	53	100000	F
13644	QLLMHC	FOTNSEJSQJ	5333805618 Dell Way	\N	NAVZLIG	\N	0	France	2	FOTNSEJSQJ@dell.com	5333805618	3	1703923996537923	2012/11	user13644	password	90	100000	M
13645	LKBSNG	GGTZLDSBMF	8920867831 Dell Way	\N	CHFOPLA	\N	0	Australia	2	GGTZLDSBMF@dell.com	8920867831	1	1222449725493788	2011/02	user13645	password	88	40000	M
13646	JJGWQN	DKMPNFQZKT	4981319546 Dell Way	\N	GQHWCIZ	\N	0	UK	2	DKMPNFQZKT@dell.com	4981319546	1	7746970180887730	2010/12	user13646	password	24	20000	F
13647	LIFCWJ	MJYZOPYZJF	1596158487 Dell Way	\N	PRCRZBQ	\N	0	France	2	MJYZOPYZJF@dell.com	1596158487	2	9793294895906002	2008/06	user13647	password	22	40000	M
13648	KPAHZM	QYLEOKEXPT	5287420585 Dell Way	\N	OSLOTCZ	\N	0	South Africa	2	QYLEOKEXPT@dell.com	5287420585	5	8825406969524921	2012/01	user13648	password	36	100000	F
13649	WXSWKI	UWNIGRGWLU	3513069044 Dell Way	\N	OWIIYIE	\N	0	France	2	UWNIGRGWLU@dell.com	3513069044	1	4494296128395945	2009/04	user13649	password	38	80000	F
13650	FLZPTU	LHDSZJOKDC	6621225905 Dell Way	\N	HMLGVPR	\N	0	Australia	2	LHDSZJOKDC@dell.com	6621225905	1	4512430384289473	2012/05	user13650	password	26	20000	M
13651	OBDIVO	PYGPIVZLXH	3081609103 Dell Way	\N	YJNTYEV	\N	0	Germany	2	PYGPIVZLXH@dell.com	3081609103	2	5384352551773191	2010/05	user13651	password	57	20000	M
13652	PFGLUW	KBLSWKEUSC	9459766982 Dell Way	\N	DFWCJSR	\N	0	Japan	2	KBLSWKEUSC@dell.com	9459766982	1	2564217572566122	2009/09	user13652	password	38	40000	F
13653	NLTHHD	ISVFDZZVCC	1346066444 Dell Way	\N	AZFKRWA	\N	0	Japan	2	ISVFDZZVCC@dell.com	1346066444	1	9139966225251556	2011/06	user13653	password	26	20000	M
13654	OUGVXP	OTUSTTOWWP	2661497106 Dell Way	\N	VBZMYZC	\N	0	UK	2	OTUSTTOWWP@dell.com	2661497106	5	7564947313163430	2011/02	user13654	password	74	80000	M
13655	OWNLLB	FGUYAIUWXQ	2694956147 Dell Way	\N	YXCXXEX	\N	0	Australia	2	FGUYAIUWXQ@dell.com	2694956147	4	7493847702164204	2009/05	user13655	password	42	100000	M
13656	FLKRNP	XHOXPJUNZT	2266479945 Dell Way	\N	KBQHGNJ	\N	0	France	2	XHOXPJUNZT@dell.com	2266479945	1	7670438916422427	2010/06	user13656	password	68	60000	M
13657	DWHRLE	ZZCPIWCHQN	3481619066 Dell Way	\N	JGUQUEB	\N	0	UK	2	ZZCPIWCHQN@dell.com	3481619066	5	5029733129777014	2011/07	user13657	password	84	40000	M
13658	TPIFUH	FWWNTZVJMF	7248345697 Dell Way	\N	QHVKMXI	\N	0	Russia	2	FWWNTZVJMF@dell.com	7248345697	4	5068441701587290	2008/09	user13658	password	74	100000	F
13659	JEQEMV	BJJUJFEVKU	3873692431 Dell Way	\N	DFFPCOJ	\N	0	Russia	2	BJJUJFEVKU@dell.com	3873692431	5	9916957702487708	2008/07	user13659	password	79	60000	M
13660	ACDNYE	XIZGNDBXYF	9643761491 Dell Way	\N	DEUFSEA	\N	0	Australia	2	XIZGNDBXYF@dell.com	9643761491	5	1224463071208447	2010/11	user13660	password	52	60000	M
13661	OQKNVH	VUNJYPGWUJ	6438032475 Dell Way	\N	APPSTPT	\N	0	Russia	2	VUNJYPGWUJ@dell.com	6438032475	4	3392332988791168	2010/03	user13661	password	74	40000	M
13662	KTIFAE	ZONXEUUZEV	1591086950 Dell Way	\N	PTOIJHB	\N	0	UK	2	ZONXEUUZEV@dell.com	1591086950	2	4734219104517251	2009/02	user13662	password	72	20000	M
13663	MMSNRS	CEQGZLFDGU	5842703947 Dell Way	\N	WUDGCFF	\N	0	Canada	2	CEQGZLFDGU@dell.com	5842703947	4	5141005735844374	2011/05	user13663	password	61	20000	M
13664	CWJTPM	YFTXRYAXTX	9713981476 Dell Way	\N	RXDTDJX	\N	0	Japan	2	YFTXRYAXTX@dell.com	9713981476	2	3660310894716531	2009/12	user13664	password	50	20000	F
13665	IPUXBT	DUQUTRRNOJ	4720102458 Dell Way	\N	KSDNBBF	\N	0	Australia	2	DUQUTRRNOJ@dell.com	4720102458	3	4330556106753647	2009/12	user13665	password	59	60000	F
13666	DGEFZH	ZPCSGTGVDR	8864055128 Dell Way	\N	OHEPIKQ	\N	0	Russia	2	ZPCSGTGVDR@dell.com	8864055128	1	2030996566172689	2012/07	user13666	password	58	20000	M
13667	UFXTNX	JPQPJWLMNZ	3117227912 Dell Way	\N	TSPCCFV	\N	0	UK	2	JPQPJWLMNZ@dell.com	3117227912	5	7958298767916859	2012/06	user13667	password	78	60000	F
13668	ALANIJ	DZZMVKYJKS	6008566933 Dell Way	\N	BZVDFQD	\N	0	France	2	DZZMVKYJKS@dell.com	6008566933	5	3288395092822611	2008/09	user13668	password	75	40000	M
13669	GIHPSK	ORWJCVTNOU	9603922113 Dell Way	\N	MJYSABD	\N	0	Germany	2	ORWJCVTNOU@dell.com	9603922113	2	6392910138703883	2011/03	user13669	password	84	60000	F
13670	FSZYDN	PAXSWQFLLS	9454519768 Dell Way	\N	VKKVLOJ	\N	0	France	2	PAXSWQFLLS@dell.com	9454519768	5	1754487433470785	2008/11	user13670	password	55	60000	F
13671	GNAJBQ	KZJGQPRBHM	6987184588 Dell Way	\N	LSIXGRI	\N	0	Canada	2	KZJGQPRBHM@dell.com	6987184588	2	3757798882666975	2010/11	user13671	password	78	80000	F
13672	JRNKIY	JSEZHWBPJM	2012720450 Dell Way	\N	HRKOJST	\N	0	Australia	2	JSEZHWBPJM@dell.com	2012720450	1	6276157741900534	2008/11	user13672	password	35	20000	F
13673	YSQHQZ	ZVZHSAWBNE	5607694166 Dell Way	\N	TYSDQME	\N	0	Russia	2	ZVZHSAWBNE@dell.com	5607694166	4	7993958594277502	2009/12	user13673	password	87	80000	M
13674	RGFHFE	CFMUFJWTNQ	7119945728 Dell Way	\N	RGTHSYB	\N	0	Chile	2	CFMUFJWTNQ@dell.com	7119945728	5	6647679510526360	2011/10	user13674	password	35	80000	F
13675	MVTSZW	XMRDVNWJEO	7679216403 Dell Way	\N	PXWIVXO	\N	0	Germany	2	XMRDVNWJEO@dell.com	7679216403	1	2774540121667087	2010/06	user13675	password	76	100000	M
13676	PSQPPO	CGRXUOGYCV	9419220502 Dell Way	\N	WYESWTF	\N	0	Japan	2	CGRXUOGYCV@dell.com	9419220502	3	2200405042618513	2009/03	user13676	password	26	40000	M
13677	VYLLMN	RELMSRKVNH	6845472970 Dell Way	\N	URZQLFG	\N	0	China	2	RELMSRKVNH@dell.com	6845472970	2	7658351151738317	2012/06	user13677	password	20	80000	F
13678	ZETLSL	PDXIUIEIPY	3052926934 Dell Way	\N	ZPPLVWU	\N	0	France	2	PDXIUIEIPY@dell.com	3052926934	3	4220949789509177	2011/07	user13678	password	23	20000	M
13679	GVZYGP	CEYWNCEDBE	9539707074 Dell Way	\N	SRQONKA	\N	0	Russia	2	CEYWNCEDBE@dell.com	9539707074	2	5218618320301175	2010/06	user13679	password	56	20000	M
13680	JBRQQT	UPQHSVLTAD	2108725508 Dell Way	\N	LQSYATR	\N	0	UK	2	UPQHSVLTAD@dell.com	2108725508	1	5541725000832230	2010/09	user13680	password	59	40000	F
13681	PZRGTM	VJUNEFHFJS	5642979640 Dell Way	\N	VBRWUJV	\N	0	UK	2	VJUNEFHFJS@dell.com	5642979640	2	5468859729357064	2009/11	user13681	password	76	40000	M
13682	UXTNKP	XEDCJKHSDC	2184396667 Dell Way	\N	TUYODUL	\N	0	Japan	2	XEDCJKHSDC@dell.com	2184396667	5	8872252885717899	2008/10	user13682	password	27	60000	M
13683	BICLXZ	PBBZMJRPLL	4636905506 Dell Way	\N	KKAOFLF	\N	0	China	2	PBBZMJRPLL@dell.com	4636905506	1	4284763699397445	2008/03	user13683	password	84	80000	F
13684	GUSDTI	FVHREZHQLR	5855513745 Dell Way	\N	BLFGXLO	\N	0	Chile	2	FVHREZHQLR@dell.com	5855513745	5	5090357637498528	2011/11	user13684	password	29	20000	F
13685	YTGSBL	OICSHJJSBK	2188003765 Dell Way	\N	EHQBSFJ	\N	0	Chile	2	OICSHJJSBK@dell.com	2188003765	5	1175153717864304	2012/12	user13685	password	21	20000	M
13686	UHQVSE	DVXLFGEGRI	5811166336 Dell Way	\N	OHKGMTN	\N	0	Japan	2	DVXLFGEGRI@dell.com	5811166336	3	6424522381741554	2010/08	user13686	password	66	60000	F
13687	YAERFI	NCUTJYAAHO	8825046627 Dell Way	\N	HRUUKIK	\N	0	UK	2	NCUTJYAAHO@dell.com	8825046627	1	4887196138035506	2010/09	user13687	password	79	100000	M
13688	WAICJV	FDOOBOOJCW	1981652067 Dell Way	\N	AXRKGCI	\N	0	Canada	2	FDOOBOOJCW@dell.com	1981652067	4	6187139294110239	2011/08	user13688	password	47	60000	M
13689	KTPTPU	WDIYSXHVUI	8537475951 Dell Way	\N	TLSZNBD	\N	0	Japan	2	WDIYSXHVUI@dell.com	8537475951	4	4807802952360362	2010/02	user13689	password	80	100000	M
13690	POHEID	IRCAOKWJSP	4751791056 Dell Way	\N	ULPHMSY	\N	0	China	2	IRCAOKWJSP@dell.com	4751791056	2	8048649992793799	2010/03	user13690	password	72	20000	M
13691	HHZQLH	HOIWYFFRVA	6345870152 Dell Way	\N	CLHOEGX	\N	0	Germany	2	HOIWYFFRVA@dell.com	6345870152	4	1744654794689268	2012/06	user13691	password	25	80000	M
13692	KPIVXQ	JGNILTZHTB	2873018175 Dell Way	\N	SBQWHNL	\N	0	South Africa	2	JGNILTZHTB@dell.com	2873018175	3	7133195811882616	2011/08	user13692	password	39	40000	F
13693	WRVUIF	AVOMONTIPL	3366725050 Dell Way	\N	JFIQTTN	\N	0	UK	2	AVOMONTIPL@dell.com	3366725050	2	6349809826817364	2012/06	user13693	password	86	100000	F
13694	QTEYYE	UNRIBKQQWA	4485468479 Dell Way	\N	WERQYEP	\N	0	Canada	2	UNRIBKQQWA@dell.com	4485468479	1	1652645717374980	2012/02	user13694	password	88	40000	M
13695	SKRQPL	EGUFRLWNLS	2068300687 Dell Way	\N	SCIQHYV	\N	0	Japan	2	EGUFRLWNLS@dell.com	2068300687	5	6021823843475432	2009/11	user13695	password	77	100000	M
13696	GQFVCJ	CWPTILHTDA	4506995839 Dell Way	\N	WMQEKMV	\N	0	Germany	2	CWPTILHTDA@dell.com	4506995839	2	8007653454784305	2009/03	user13696	password	73	100000	F
13697	KBHNKJ	JADSLKLPKI	7450254421 Dell Way	\N	BBMMOIA	\N	0	UK	2	JADSLKLPKI@dell.com	7450254421	5	2707668677903712	2012/07	user13697	password	18	40000	M
13698	BQMMAW	MDOXOAMZIO	8802487380 Dell Way	\N	AVBODBM	\N	0	South Africa	2	MDOXOAMZIO@dell.com	8802487380	4	8094998204149307	2010/09	user13698	password	29	40000	M
13699	UWFVSS	YGPNGCMPQM	3038778194 Dell Way	\N	KRBOTOK	\N	0	Japan	2	YGPNGCMPQM@dell.com	3038778194	1	1372657713480293	2012/05	user13699	password	49	80000	F
13700	HXZAPY	GELNHYCXKM	6921773070 Dell Way	\N	PMBJALZ	\N	0	Chile	2	GELNHYCXKM@dell.com	6921773070	1	2436240881215781	2008/06	user13700	password	78	20000	M
13701	SETHDA	MONTMPRXCH	6656539316 Dell Way	\N	JDQKPQQ	\N	0	Chile	2	MONTMPRXCH@dell.com	6656539316	4	3577256535645574	2008/08	user13701	password	52	100000	F
13702	QOQTOD	ICXVRPTUXC	9166285430 Dell Way	\N	YNMOEDV	\N	0	Russia	2	ICXVRPTUXC@dell.com	9166285430	1	8704007524065674	2010/07	user13702	password	66	100000	F
13703	GMZUQI	WNDOCWJAZH	8231677867 Dell Way	\N	NMWRPRM	\N	0	Germany	2	WNDOCWJAZH@dell.com	8231677867	2	1244390815496444	2009/01	user13703	password	82	80000	F
13704	JPAAXX	NAMQXVQWDE	7099488843 Dell Way	\N	JAWYRJL	\N	0	France	2	NAMQXVQWDE@dell.com	7099488843	3	8922382697463036	2011/05	user13704	password	53	100000	M
13705	CYTZWH	AIYXEOUHTD	1381919435 Dell Way	\N	HQCZZOM	\N	0	Japan	2	AIYXEOUHTD@dell.com	1381919435	2	3990792225115001	2010/11	user13705	password	35	20000	M
13706	EXXAEX	JDVNRQVLUC	9488025571 Dell Way	\N	BWCBLPS	\N	0	France	2	JDVNRQVLUC@dell.com	9488025571	1	8961990220006556	2011/04	user13706	password	21	80000	F
13707	YQMDOW	GKJYAFKUHL	3154519922 Dell Way	\N	RKNCZFO	\N	0	UK	2	GKJYAFKUHL@dell.com	3154519922	3	7524233086034656	2010/06	user13707	password	50	100000	F
13708	CMPQIW	ASUBXEVFQM	6500480734 Dell Way	\N	PDPPJEN	\N	0	Germany	2	ASUBXEVFQM@dell.com	6500480734	2	1943207328673452	2008/09	user13708	password	23	60000	M
13709	ODLXZL	PUMMZISPVI	7299715645 Dell Way	\N	TKXCOLR	\N	0	Canada	2	PUMMZISPVI@dell.com	7299715645	4	3544563819188625	2010/11	user13709	password	79	20000	F
13710	ZQIZBX	TOKSWCISLC	6940045649 Dell Way	\N	CIERUWW	\N	0	France	2	TOKSWCISLC@dell.com	6940045649	1	8992116804234684	2010/12	user13710	password	23	100000	M
13711	SHYTFR	IPKFSTXDVA	7087848387 Dell Way	\N	MASGWOT	\N	0	Germany	2	IPKFSTXDVA@dell.com	7087848387	4	1652186070568859	2011/09	user13711	password	20	60000	F
13712	INENFN	CQSVJQZFRL	1666989488 Dell Way	\N	FJSCXLQ	\N	0	Germany	2	CQSVJQZFRL@dell.com	1666989488	4	2972179489210248	2011/09	user13712	password	77	20000	F
13713	IJOOWR	EPNOFMTXXY	4450618152 Dell Way	\N	GQBDBRS	\N	0	Canada	2	EPNOFMTXXY@dell.com	4450618152	5	9302653341554106	2008/09	user13713	password	26	20000	F
13714	MTQJLU	ZYJEKCBIBI	1749725188 Dell Way	\N	YCLAUEE	\N	0	Canada	2	ZYJEKCBIBI@dell.com	1749725188	1	3679402523208410	2012/03	user13714	password	52	100000	M
13715	FNBRIA	PRFAUHJWPI	6213490258 Dell Way	\N	YBITFMY	\N	0	Chile	2	PRFAUHJWPI@dell.com	6213490258	2	2045163281727582	2011/09	user13715	password	19	60000	M
13716	ONPXOE	PTFKBOGQWF	1869391746 Dell Way	\N	SFYXSWE	\N	0	Chile	2	PTFKBOGQWF@dell.com	1869391746	2	1665303933434188	2011/04	user13716	password	57	80000	M
13717	BHUPMK	JRUKGABDFT	2288915182 Dell Way	\N	JEQBAVJ	\N	0	Canada	2	JRUKGABDFT@dell.com	2288915182	3	9281690193340184	2010/12	user13717	password	64	40000	F
13718	YEQLOA	DIKJJLNOFW	7414024218 Dell Way	\N	SVXTRHW	\N	0	South Africa	2	DIKJJLNOFW@dell.com	7414024218	4	3670553069096059	2011/06	user13718	password	66	80000	F
13719	VJVKJY	TUICGVRLRK	8339313536 Dell Way	\N	HPDZWAU	\N	0	Germany	2	TUICGVRLRK@dell.com	8339313536	1	3532553327269852	2009/09	user13719	password	18	80000	M
13720	JLZTKS	OTVUONFGXN	3984599364 Dell Way	\N	WBMTBGI	\N	0	South Africa	2	OTVUONFGXN@dell.com	3984599364	4	2289659189525991	2008/08	user13720	password	75	80000	M
13721	GQTQJH	JEBYRHFPUB	7402878471 Dell Way	\N	QHUSNCP	\N	0	South Africa	2	JEBYRHFPUB@dell.com	7402878471	4	9392286421731116	2009/07	user13721	password	61	40000	M
13722	FBLPJV	ULTLTYBNZS	8016775161 Dell Way	\N	VUKIWAE	\N	0	Germany	2	ULTLTYBNZS@dell.com	8016775161	1	9282743819523604	2009/09	user13722	password	35	20000	M
13723	INNRIH	CCTVBUJBME	8494165362 Dell Way	\N	VXNSYSH	\N	0	Russia	2	CCTVBUJBME@dell.com	8494165362	2	1300189610105007	2010/06	user13723	password	27	60000	M
13724	QALZHO	BBKCWUDJZY	2559563550 Dell Way	\N	HMRFFYY	\N	0	Australia	2	BBKCWUDJZY@dell.com	2559563550	5	6254487990867347	2011/02	user13724	password	22	40000	M
13725	BVSJKT	LUWHOAQNZX	1135874300 Dell Way	\N	AQDGPBH	\N	0	Russia	2	LUWHOAQNZX@dell.com	1135874300	5	4564467502292246	2008/12	user13725	password	75	100000	M
13726	QOJAIU	UEBJESXEQY	3642100996 Dell Way	\N	UTEKULE	\N	0	South Africa	2	UEBJESXEQY@dell.com	3642100996	3	9305514927487820	2009/05	user13726	password	73	40000	M
13727	HOZPJU	ULEZDBDUZY	1298917597 Dell Way	\N	NDIIPME	\N	0	South Africa	2	ULEZDBDUZY@dell.com	1298917597	1	1838007662910968	2009/11	user13727	password	40	40000	F
13728	WJTGEN	RIMVKQPJOD	7272337282 Dell Way	\N	NWMCJQZ	\N	0	China	2	RIMVKQPJOD@dell.com	7272337282	1	7967120540793986	2010/05	user13728	password	27	80000	F
13729	MKNQXE	ZKAJBPSPTG	4536088808 Dell Way	\N	MFIVVIG	\N	0	Germany	2	ZKAJBPSPTG@dell.com	4536088808	1	1523931724485009	2011/02	user13729	password	70	20000	M
13730	DNGBSF	LSPNIHCBNP	7089966967 Dell Way	\N	HWLCFRQ	\N	0	Germany	2	LSPNIHCBNP@dell.com	7089966967	4	4289279516786337	2012/05	user13730	password	46	60000	M
13731	XSPQYB	INORVQSJFA	4959184607 Dell Way	\N	GQCLITB	\N	0	UK	2	INORVQSJFA@dell.com	4959184607	3	8309411964379252	2012/10	user13731	password	37	40000	M
13732	ZZIYAR	LOIGEBQKBW	7866327065 Dell Way	\N	BEIJXJJ	\N	0	China	2	LOIGEBQKBW@dell.com	7866327065	1	2890482432674616	2010/06	user13732	password	61	40000	F
13733	OPJPHU	DPBIRSTSOV	7817993612 Dell Way	\N	XWFUGOE	\N	0	UK	2	DPBIRSTSOV@dell.com	7817993612	2	6027767048683018	2009/12	user13733	password	78	80000	M
13734	LZDSUG	IVPANISCDP	9593788803 Dell Way	\N	ZJKFXPF	\N	0	Japan	2	IVPANISCDP@dell.com	9593788803	4	8913078332319857	2012/08	user13734	password	55	60000	F
13735	MPUGWC	CMDQVVTZLT	9429335481 Dell Way	\N	IWYFLEX	\N	0	France	2	CMDQVVTZLT@dell.com	9429335481	4	4056941429618746	2010/04	user13735	password	77	60000	M
13736	KJBHMD	TPUPLOOXHW	7734335266 Dell Way	\N	UGBFKZQ	\N	0	China	2	TPUPLOOXHW@dell.com	7734335266	5	8877512693405152	2008/10	user13736	password	52	100000	F
13737	VWNIAH	YVWJJKHQGB	9034324648 Dell Way	\N	WIHHHXP	\N	0	Australia	2	YVWJJKHQGB@dell.com	9034324648	3	1667235543020069	2011/12	user13737	password	82	100000	M
13738	TKDTSB	OOLXYSOFUL	8034639800 Dell Way	\N	NBSVZHW	\N	0	South Africa	2	OOLXYSOFUL@dell.com	8034639800	5	5882575759664178	2011/10	user13738	password	50	60000	M
13739	WQHOSW	CDUBWIGQTU	4100264700 Dell Way	\N	SMPRULN	\N	0	Germany	2	CDUBWIGQTU@dell.com	4100264700	1	3559639619197696	2008/07	user13739	password	76	80000	F
13740	LZXEWA	IQBEYIVSCN	7950401158 Dell Way	\N	ERFZCSN	\N	0	France	2	IQBEYIVSCN@dell.com	7950401158	5	6288503618910909	2009/08	user13740	password	38	80000	F
13741	HOFDON	TQSSYOLBBQ	9116594834 Dell Way	\N	SGPVZCG	\N	0	Russia	2	TQSSYOLBBQ@dell.com	9116594834	5	1251668801065534	2010/02	user13741	password	66	60000	F
13742	FUNUHH	KAAJOLLQBD	1267715837 Dell Way	\N	XQYWTFQ	\N	0	Japan	2	KAAJOLLQBD@dell.com	1267715837	4	2368296419735998	2008/04	user13742	password	70	60000	M
13743	MCIUKT	VKDJVOAXSX	1746227671 Dell Way	\N	NQUHVLX	\N	0	South Africa	2	VKDJVOAXSX@dell.com	1746227671	1	1214302222244441	2010/10	user13743	password	60	100000	F
13744	RHCBAX	LDHHSHEKFS	9919269448 Dell Way	\N	BAZXLXT	\N	0	Germany	2	LDHHSHEKFS@dell.com	9919269448	4	9282620710320772	2011/05	user13744	password	81	20000	F
13745	DECECN	IJVARAKWSL	9064060518 Dell Way	\N	XSJIQCV	\N	0	Japan	2	IJVARAKWSL@dell.com	9064060518	4	4670163711998612	2009/08	user13745	password	53	40000	M
13746	QJYSXG	CSHTTSQLEN	4692620121 Dell Way	\N	ENVUQRL	\N	0	Germany	2	CSHTTSQLEN@dell.com	4692620121	5	7996319344732911	2008/04	user13746	password	22	80000	M
13747	LTRIAU	BHNUZEGERL	5470309899 Dell Way	\N	RNGHERV	\N	0	Japan	2	BHNUZEGERL@dell.com	5470309899	3	6669149902183563	2012/08	user13747	password	49	80000	F
13748	ELLEGN	LTILYPPQAG	9556266434 Dell Way	\N	DGOIXJY	\N	0	China	2	LTILYPPQAG@dell.com	9556266434	3	2852500752080232	2011/12	user13748	password	89	80000	F
13749	LDIRQU	LZFJOUZOBD	9778367262 Dell Way	\N	UQMRZKB	\N	0	UK	2	LZFJOUZOBD@dell.com	9778367262	2	5842739566229284	2012/04	user13749	password	34	20000	M
13750	JLJAFU	ZLENGDBHHV	8653300308 Dell Way	\N	XTNXDOV	\N	0	Canada	2	ZLENGDBHHV@dell.com	8653300308	2	1809003780130297	2008/08	user13750	password	33	80000	M
13751	REZXZY	IDLOGNWOIU	9096592793 Dell Way	\N	HWRKLNO	\N	0	Chile	2	IDLOGNWOIU@dell.com	9096592793	4	4438954931218177	2010/11	user13751	password	31	60000	M
13752	JMKIKS	LWHSKDGTXN	1971141911 Dell Way	\N	PPYACMH	\N	0	UK	2	LWHSKDGTXN@dell.com	1971141911	4	5588253720663488	2012/11	user13752	password	90	60000	F
13753	MWNWPY	TWQDZWWXKM	4802598431 Dell Way	\N	MIMOVTO	\N	0	UK	2	TWQDZWWXKM@dell.com	4802598431	1	8906809343490750	2009/01	user13753	password	43	60000	M
13754	FZKVXE	ROIRLFOVRA	3051270855 Dell Way	\N	EDPZXEX	\N	0	China	2	ROIRLFOVRA@dell.com	3051270855	4	6241000699810684	2009/02	user13754	password	21	100000	F
13755	AGEYKW	MTOXYCTPDX	6326598580 Dell Way	\N	TSXQWUY	\N	0	Australia	2	MTOXYCTPDX@dell.com	6326598580	3	4568778277374804	2011/07	user13755	password	34	20000	M
13756	MGNXDA	QRXOUREXPX	9875570555 Dell Way	\N	QMNMHMP	\N	0	South Africa	2	QRXOUREXPX@dell.com	9875570555	5	6550605010241271	2010/03	user13756	password	69	20000	M
13757	ZROCRE	UPTOGXLVVB	2100944264 Dell Way	\N	IJOQVDN	\N	0	South Africa	2	UPTOGXLVVB@dell.com	2100944264	1	4285466811154038	2009/11	user13757	password	55	20000	M
13758	EOXVTR	KNGRLRNGTW	2443337947 Dell Way	\N	QHMLLAG	\N	0	Germany	2	KNGRLRNGTW@dell.com	2443337947	4	9008089140988888	2008/02	user13758	password	83	100000	F
13759	MTDGLO	TRGEJTLCPB	4617319462 Dell Way	\N	KCNVDUK	\N	0	Chile	2	TRGEJTLCPB@dell.com	4617319462	2	3638399782590568	2010/03	user13759	password	26	100000	M
13760	WZXHNQ	YTVHNHKDJU	3741247306 Dell Way	\N	FXQJRAQ	\N	0	Australia	2	YTVHNHKDJU@dell.com	3741247306	5	6432335208170117	2010/01	user13760	password	49	20000	M
13761	KAEXRD	RNLEVVHEQN	5093249079 Dell Way	\N	BHWTHNV	\N	0	Japan	2	RNLEVVHEQN@dell.com	5093249079	3	1819478233810514	2010/11	user13761	password	34	60000	F
13762	GPEYSV	MEAHAHMQVO	5662682761 Dell Way	\N	XRHFFCV	\N	0	Japan	2	MEAHAHMQVO@dell.com	5662682761	5	2498112469445914	2009/02	user13762	password	59	80000	F
13763	EUJXQV	BQDBXPSTDQ	6367787999 Dell Way	\N	KKVQNRH	\N	0	Australia	2	BQDBXPSTDQ@dell.com	6367787999	3	4643219359219074	2011/01	user13763	password	19	20000	F
13764	VOCLJD	BNEZCXSFND	5675529357 Dell Way	\N	QJUEABF	\N	0	Japan	2	BNEZCXSFND@dell.com	5675529357	3	4365924163255841	2010/08	user13764	password	57	80000	F
13765	CVWLYY	ZDYBAQHOUY	9017032816 Dell Way	\N	XOCXQHO	\N	0	Canada	2	ZDYBAQHOUY@dell.com	9017032816	5	7190444009378553	2010/06	user13765	password	49	100000	M
13766	GVAFUZ	JSAKJIYDGV	2955171157 Dell Way	\N	RJTHQHL	\N	0	Germany	2	JSAKJIYDGV@dell.com	2955171157	1	1471797259058803	2011/07	user13766	password	18	40000	M
13767	WFBQFK	IGVROTVVPM	4425353080 Dell Way	\N	EJUVQGI	\N	0	South Africa	2	IGVROTVVPM@dell.com	4425353080	2	5893079717643560	2012/05	user13767	password	74	80000	F
13768	ZVWFGF	LBXZVSUKFY	5541453544 Dell Way	\N	TATKGCH	\N	0	Japan	2	LBXZVSUKFY@dell.com	5541453544	5	6250825413502753	2012/08	user13768	password	43	20000	M
13769	EBUKGF	MEEHWZSBYL	9654845917 Dell Way	\N	BSWIUDZ	\N	0	China	2	MEEHWZSBYL@dell.com	9654845917	3	2998943446669727	2010/11	user13769	password	46	20000	F
13770	LXMSCY	WHGSHYUFKW	7415112500 Dell Way	\N	XHESKEA	\N	0	China	2	WHGSHYUFKW@dell.com	7415112500	2	9341050823219120	2011/08	user13770	password	21	80000	F
13771	YEUBDQ	JKJQIDVTAT	7353415946 Dell Way	\N	AFLLJMV	\N	0	Australia	2	JKJQIDVTAT@dell.com	7353415946	4	7266131752636284	2009/10	user13771	password	46	60000	M
13772	PEVTVE	DEVLIQEJKF	2572335969 Dell Way	\N	OVQXHLZ	\N	0	Australia	2	DEVLIQEJKF@dell.com	2572335969	4	4114300523884595	2012/01	user13772	password	72	80000	M
13773	YNKTSN	YNZHEEQOJE	7861107847 Dell Way	\N	KZCSLBS	\N	0	Japan	2	YNZHEEQOJE@dell.com	7861107847	1	6102556830272079	2012/10	user13773	password	38	60000	M
13774	VXMNLL	AKSFOITYMD	6518280921 Dell Way	\N	XPWIROY	\N	0	France	2	AKSFOITYMD@dell.com	6518280921	3	3370663044974208	2010/10	user13774	password	74	20000	M
13775	RRDDCD	NUJCDCAQGY	7565555478 Dell Way	\N	FCHWRFH	\N	0	Chile	2	NUJCDCAQGY@dell.com	7565555478	3	7292032369878144	2010/04	user13775	password	80	20000	F
13776	NGDPKQ	KTTOWTECRJ	1529769883 Dell Way	\N	FZGXENE	\N	0	UK	2	KTTOWTECRJ@dell.com	1529769883	5	4881443059537560	2009/09	user13776	password	58	40000	F
13777	UNWEEH	YXVURZXJJD	1441787753 Dell Way	\N	IPAMCEK	\N	0	Canada	2	YXVURZXJJD@dell.com	1441787753	5	5850449827499688	2011/05	user13777	password	85	20000	F
13778	LWJPDI	NYCEYANHDV	5891069171 Dell Way	\N	WEIZJSD	\N	0	France	2	NYCEYANHDV@dell.com	5891069171	4	2587507767602801	2012/08	user13778	password	32	20000	F
13779	BMQFUD	EXIDYVKCQH	1756121565 Dell Way	\N	GZGPRKA	\N	0	Chile	2	EXIDYVKCQH@dell.com	1756121565	1	2328680620063096	2011/05	user13779	password	36	80000	F
13780	TJRONW	MVZKRKMIRS	5622179783 Dell Way	\N	HYIYJIE	\N	0	France	2	MVZKRKMIRS@dell.com	5622179783	2	2162226454354822	2012/07	user13780	password	80	40000	F
13781	FAWTWI	PWTGGFOYYV	3181785649 Dell Way	\N	WGTGPYR	\N	0	Canada	2	PWTGGFOYYV@dell.com	3181785649	5	1030252769589424	2012/09	user13781	password	43	20000	M
13782	JAQGIF	CBLIHAGFVD	8989268080 Dell Way	\N	MPKCNBF	\N	0	Russia	2	CBLIHAGFVD@dell.com	8989268080	1	6198144355788828	2010/07	user13782	password	70	60000	M
13783	SCDBIF	DUOKUVQPZD	6367631173 Dell Way	\N	FJFSLKM	\N	0	China	2	DUOKUVQPZD@dell.com	6367631173	1	8988454314880074	2008/10	user13783	password	42	20000	F
13784	LEOTKR	NZCIUTXUWD	4382856835 Dell Way	\N	DBVPLIX	\N	0	Australia	2	NZCIUTXUWD@dell.com	4382856835	5	2764782387763262	2008/02	user13784	password	35	80000	M
13785	LFIVWW	VZEPTCKPGN	8624212174 Dell Way	\N	RBDCKBE	\N	0	Russia	2	VZEPTCKPGN@dell.com	8624212174	2	9208903665654362	2012/08	user13785	password	58	60000	F
13786	TYWQUR	QZHJCRYIFP	3261375663 Dell Way	\N	KISUJXO	\N	0	Chile	2	QZHJCRYIFP@dell.com	3261375663	3	2953612697776407	2012/01	user13786	password	76	100000	M
13787	STKNLA	NTJQKHYQXJ	2825415390 Dell Way	\N	YQEINSO	\N	0	Russia	2	NTJQKHYQXJ@dell.com	2825415390	4	6511190686374903	2009/07	user13787	password	54	100000	F
13788	GKVSKI	LTYWBXMZGL	1684504698 Dell Way	\N	PLTCEIV	\N	0	China	2	LTYWBXMZGL@dell.com	1684504698	3	6311673169024289	2011/12	user13788	password	60	100000	F
13789	ZTYKBJ	DAGFYSEEDU	2517858112 Dell Way	\N	QXWUFSD	\N	0	Chile	2	DAGFYSEEDU@dell.com	2517858112	4	9273537107743324	2008/04	user13789	password	80	40000	F
13790	PHRRRV	SXBQQGVTAL	1788215105 Dell Way	\N	RXFWPJD	\N	0	Russia	2	SXBQQGVTAL@dell.com	1788215105	1	9157086455263198	2010/11	user13790	password	37	80000	M
13791	OKEGGW	EHMUNHOOTF	3348627105 Dell Way	\N	LYBBHFV	\N	0	China	2	EHMUNHOOTF@dell.com	3348627105	4	8207413372583688	2008/01	user13791	password	55	80000	M
13792	XWVDSA	LFUZNJNGPZ	6828085052 Dell Way	\N	FRBNWXX	\N	0	Canada	2	LFUZNJNGPZ@dell.com	6828085052	4	3634033536072820	2011/03	user13792	password	88	40000	F
13793	VBGNBS	TWRHGFNVFT	8869094676 Dell Way	\N	MGGIDEM	\N	0	Russia	2	TWRHGFNVFT@dell.com	8869094676	4	5130044855177403	2008/09	user13793	password	69	40000	M
13794	UMBWEV	SWCYBQUGKG	8359436692 Dell Way	\N	NQPQVBL	\N	0	Japan	2	SWCYBQUGKG@dell.com	8359436692	5	8047326766885818	2010/08	user13794	password	18	20000	F
13795	MDGRZY	NCXPSSVDYJ	4223645246 Dell Way	\N	TOZPPLH	\N	0	France	2	NCXPSSVDYJ@dell.com	4223645246	1	9604896367061884	2012/01	user13795	password	20	40000	M
13796	EPFEOT	GMIZEECDNW	7835853038 Dell Way	\N	RNLGZSR	\N	0	China	2	GMIZEECDNW@dell.com	7835853038	4	3741848267614842	2012/08	user13796	password	66	40000	M
13797	GPZUIG	HRFLWHOJDF	7860932376 Dell Way	\N	XOMWHDF	\N	0	Australia	2	HRFLWHOJDF@dell.com	7860932376	3	8647601762320847	2010/03	user13797	password	33	40000	F
13798	UGFCMN	USYQZMADSX	5720085165 Dell Way	\N	REUZIAZ	\N	0	Australia	2	USYQZMADSX@dell.com	5720085165	5	5417550361715257	2011/01	user13798	password	72	20000	M
13799	AJZMWT	FUJEHJHAHZ	8252088061 Dell Way	\N	EBYMBYO	\N	0	Germany	2	FUJEHJHAHZ@dell.com	8252088061	1	3641488765366375	2012/10	user13799	password	49	80000	M
13800	URHRKM	MURTEZULYY	1345903923 Dell Way	\N	MXLOWZD	\N	0	Japan	2	MURTEZULYY@dell.com	1345903923	3	5892757408320904	2012/11	user13800	password	36	80000	M
13801	YYIJLU	DCOHBITAHG	4584575914 Dell Way	\N	YSUVSYM	\N	0	Russia	2	DCOHBITAHG@dell.com	4584575914	1	6241822469979525	2009/04	user13801	password	34	100000	F
13802	EGOPBS	RQATYTTGAS	1238682353 Dell Way	\N	YVNRTZK	\N	0	Canada	2	RQATYTTGAS@dell.com	1238682353	5	4933454298414290	2009/03	user13802	password	45	60000	F
13803	QCYSVQ	IWJHQDNQVM	5809112456 Dell Way	\N	LIDFIOJ	\N	0	China	2	IWJHQDNQVM@dell.com	5809112456	5	6981170874554665	2011/03	user13803	password	32	20000	M
13804	IBODRW	ABDQERGZDS	2110785080 Dell Way	\N	IHYQVHZ	\N	0	China	2	ABDQERGZDS@dell.com	2110785080	4	1842843560036271	2009/11	user13804	password	33	20000	F
13805	GSIYOI	ASYEJFENYN	8313889208 Dell Way	\N	UWDPEDY	\N	0	Chile	2	ASYEJFENYN@dell.com	8313889208	1	6397532590664924	2011/03	user13805	password	73	100000	M
13806	LEMANM	SMQCRVQPIK	9990720336 Dell Way	\N	MMAQQYX	\N	0	France	2	SMQCRVQPIK@dell.com	9990720336	3	2134157405234873	2009/04	user13806	password	89	80000	M
13807	EGSRSL	DJOVEELNOX	9448418099 Dell Way	\N	APNQNLC	\N	0	Germany	2	DJOVEELNOX@dell.com	9448418099	2	8029887923970819	2008/03	user13807	password	57	100000	F
13808	UQAMBE	VQZAUKOJIO	5736613813 Dell Way	\N	YVFMHHA	\N	0	Chile	2	VQZAUKOJIO@dell.com	5736613813	4	4717689928598702	2011/04	user13808	password	41	20000	F
13809	YDPAHL	QHLLSAUAOS	9859951897 Dell Way	\N	WUFDCFJ	\N	0	Japan	2	QHLLSAUAOS@dell.com	9859951897	4	4033014398533851	2009/02	user13809	password	49	60000	F
13810	OACWLS	EWEWXYXLRU	1778101974 Dell Way	\N	FWYICHX	\N	0	Australia	2	EWEWXYXLRU@dell.com	1778101974	2	4386260081082583	2008/09	user13810	password	75	40000	F
13811	UICFBH	CFDZEBLWVR	2433457217 Dell Way	\N	TUZVCXW	\N	0	Canada	2	CFDZEBLWVR@dell.com	2433457217	2	4220039581879974	2012/01	user13811	password	61	20000	M
13812	YFBZME	FQEJRPGNHZ	9322269488 Dell Way	\N	HHUJERN	\N	0	China	2	FQEJRPGNHZ@dell.com	9322269488	5	2613119041547179	2012/06	user13812	password	38	100000	F
13813	MXKZBP	PGZGVFUDFB	8664075043 Dell Way	\N	KZKORYX	\N	0	Germany	2	PGZGVFUDFB@dell.com	8664075043	1	6041099412832410	2009/05	user13813	password	45	80000	M
13814	HEVIUK	OURKALOFMY	5457871414 Dell Way	\N	FXNWWKL	\N	0	Russia	2	OURKALOFMY@dell.com	5457871414	1	1526643257588148	2012/05	user13814	password	78	80000	M
13815	ANZUXO	OOZOZNTMLY	3330114825 Dell Way	\N	JYVGJGY	\N	0	South Africa	2	OOZOZNTMLY@dell.com	3330114825	1	7475630381610245	2011/10	user13815	password	48	40000	M
13816	XHQVVE	KVTJINVUMF	4517418681 Dell Way	\N	THLCOKZ	\N	0	South Africa	2	KVTJINVUMF@dell.com	4517418681	4	4982935044914484	2009/02	user13816	password	71	20000	F
13817	ARWWWG	RPPZDLUPRN	3324063783 Dell Way	\N	WDPKNOF	\N	0	South Africa	2	RPPZDLUPRN@dell.com	3324063783	4	2048199890181422	2009/05	user13817	password	30	40000	F
13818	WGHSMY	ICYLOSAFFX	2900534321 Dell Way	\N	IVIVKOS	\N	0	Japan	2	ICYLOSAFFX@dell.com	2900534321	5	1125461512710899	2011/01	user13818	password	47	20000	M
13819	QIODGX	FFITYJYDGH	7265035110 Dell Way	\N	ZPDJDWA	\N	0	China	2	FFITYJYDGH@dell.com	7265035110	1	9547295651864260	2011/06	user13819	password	89	60000	F
13820	HDFOAK	TJDSSCWYKV	3267814314 Dell Way	\N	NNFRJFA	\N	0	Australia	2	TJDSSCWYKV@dell.com	3267814314	5	8053918123710901	2011/12	user13820	password	44	80000	F
13821	NZUNJO	WNGPQCOAYB	7182411413 Dell Way	\N	ODTYITA	\N	0	Germany	2	WNGPQCOAYB@dell.com	7182411413	4	3559226588346064	2011/02	user13821	password	21	100000	M
13822	AQEJEB	XKQNNFOLGD	8832347482 Dell Way	\N	OABXTCN	\N	0	France	2	XKQNNFOLGD@dell.com	8832347482	4	1405500051099807	2008/11	user13822	password	82	80000	M
13823	NWGRYD	CPRPUGABJP	8380179882 Dell Way	\N	BLNUNAF	\N	0	China	2	CPRPUGABJP@dell.com	8380179882	2	4756175751332194	2011/02	user13823	password	24	60000	M
13824	YTIWXK	LPZGVAHFQI	6149116902 Dell Way	\N	RDCEEIP	\N	0	UK	2	LPZGVAHFQI@dell.com	6149116902	5	6943357058335096	2011/02	user13824	password	31	40000	F
13825	YRXWBJ	LBPGCXMSFD	9059637032 Dell Way	\N	WIIAQXA	\N	0	Canada	2	LBPGCXMSFD@dell.com	9059637032	4	9207317696418614	2012/11	user13825	password	37	20000	M
13826	YYRAIC	BYJDVWWAZS	5288429536 Dell Way	\N	IHTZFUE	\N	0	Australia	2	BYJDVWWAZS@dell.com	5288429536	1	1740531040821224	2009/05	user13826	password	25	20000	F
13827	BWHJZJ	IINDFJEECN	7562503154 Dell Way	\N	MWMRQQU	\N	0	Canada	2	IINDFJEECN@dell.com	7562503154	5	5133335644844920	2008/12	user13827	password	64	40000	F
13828	MRKLBS	UOWZYAEBOR	1080600192 Dell Way	\N	XAJNRDQ	\N	0	France	2	UOWZYAEBOR@dell.com	1080600192	1	5343601481989026	2012/09	user13828	password	80	20000	F
13829	NKRPDL	EZLDAQEOHB	3663046634 Dell Way	\N	OQPGUFQ	\N	0	Russia	2	EZLDAQEOHB@dell.com	3663046634	1	7914855548180641	2008/12	user13829	password	75	40000	M
13830	FXDIJH	IUKIKOWSQL	5297612560 Dell Way	\N	IFSCKIX	\N	0	Russia	2	IUKIKOWSQL@dell.com	5297612560	4	7504430144093931	2010/06	user13830	password	87	100000	M
13831	VCZEKH	ZUPKJMCZYK	1595908723 Dell Way	\N	EQNPZKH	\N	0	France	2	ZUPKJMCZYK@dell.com	1595908723	1	9183093606494368	2010/12	user13831	password	83	20000	M
13832	ACAKJZ	FZKPMMPKXU	7326039377 Dell Way	\N	ALJZVRK	\N	0	UK	2	FZKPMMPKXU@dell.com	7326039377	2	4672756096348167	2011/03	user13832	password	57	60000	F
13833	QNRANX	AXMMJBWHVX	6463239624 Dell Way	\N	SFWOWHL	\N	0	Germany	2	AXMMJBWHVX@dell.com	6463239624	5	3385367790702730	2012/05	user13833	password	74	20000	F
13834	HTCUQC	RCPBEMIAJB	9089708103 Dell Way	\N	FFPCMBR	\N	0	Australia	2	RCPBEMIAJB@dell.com	9089708103	5	9425496724899860	2009/09	user13834	password	19	40000	M
13835	ULUKOL	NDNSPWSYXX	6333016436 Dell Way	\N	DMZQNRT	\N	0	France	2	NDNSPWSYXX@dell.com	6333016436	4	7556828584987671	2009/09	user13835	password	24	40000	F
13836	NBXBNK	FACUWVSTSW	9478166622 Dell Way	\N	GSNUJGF	\N	0	UK	2	FACUWVSTSW@dell.com	9478166622	5	3186481179203838	2011/01	user13836	password	56	20000	M
13837	OAPBKU	CNPYIISBFZ	8839026229 Dell Way	\N	TTTCZYB	\N	0	UK	2	CNPYIISBFZ@dell.com	8839026229	2	6222965048626066	2012/10	user13837	password	68	60000	F
13838	SALDVO	QLMZTFAZEU	3058463186 Dell Way	\N	SXXSWYQ	\N	0	Russia	2	QLMZTFAZEU@dell.com	3058463186	2	6501222725957633	2008/11	user13838	password	20	60000	M
13839	BWTXKK	JXJCDKCHFU	4030530362 Dell Way	\N	FCMBADU	\N	0	Chile	2	JXJCDKCHFU@dell.com	4030530362	2	3628905035089701	2009/06	user13839	password	70	100000	M
13840	PPKAZT	XJWAUYIZTN	7860834169 Dell Way	\N	BFPCIJI	\N	0	Japan	2	XJWAUYIZTN@dell.com	7860834169	4	9283447258174420	2008/05	user13840	password	75	80000	M
13841	KCYKWW	TSXORGNKUP	6969350241 Dell Way	\N	QJRYSAQ	\N	0	France	2	TSXORGNKUP@dell.com	6969350241	3	7100175145082176	2008/04	user13841	password	45	100000	M
13842	MXCIUW	BSKTYYESNU	9117879093 Dell Way	\N	BFTUGJH	\N	0	UK	2	BSKTYYESNU@dell.com	9117879093	5	9378404485527428	2009/04	user13842	password	82	100000	M
13843	UBDPYF	IJYGHCZVXB	1877293182 Dell Way	\N	BQWHZDF	\N	0	South Africa	2	IJYGHCZVXB@dell.com	1877293182	1	2074783309828490	2010/01	user13843	password	23	40000	M
13844	DJLCPT	LOASRZOOBP	3371974821 Dell Way	\N	EXXEBCB	\N	0	Canada	2	LOASRZOOBP@dell.com	3371974821	1	6160524153150619	2009/04	user13844	password	77	20000	F
13845	EPMUIY	IJRAJFOKUT	2220142526 Dell Way	\N	ISXJVZN	\N	0	Australia	2	IJRAJFOKUT@dell.com	2220142526	1	4423294233623892	2009/11	user13845	password	56	80000	F
13846	DHWMFF	VWFECUPWNY	9114757379 Dell Way	\N	PLHKKVM	\N	0	Germany	2	VWFECUPWNY@dell.com	9114757379	5	9333533341530712	2012/05	user13846	password	70	100000	M
13847	ZTZFZU	BFZDZPANNP	4063045923 Dell Way	\N	YUAJPMX	\N	0	Germany	2	BFZDZPANNP@dell.com	4063045923	5	3841687006410211	2011/07	user13847	password	33	40000	M
13848	ZESYZU	DYYDNZQAPO	6586010102 Dell Way	\N	VPXLCUZ	\N	0	France	2	DYYDNZQAPO@dell.com	6586010102	2	2395469808019697	2008/06	user13848	password	45	80000	F
13849	OKKOEO	MDRADIBSXX	6490127881 Dell Way	\N	IUJKPIV	\N	0	Chile	2	MDRADIBSXX@dell.com	6490127881	5	4432992544025183	2008/05	user13849	password	21	60000	M
13850	LZMQNZ	TFAWNCPKZX	2461455997 Dell Way	\N	FJIVREB	\N	0	Chile	2	TFAWNCPKZX@dell.com	2461455997	3	4448699765373021	2010/07	user13850	password	86	60000	M
13851	XZOLYI	RYFFAUQASW	3147016718 Dell Way	\N	JASBEUI	\N	0	China	2	RYFFAUQASW@dell.com	3147016718	4	8990342439152301	2011/08	user13851	password	44	80000	M
13852	IGAHPS	GUXHPOHHKR	7816142281 Dell Way	\N	IDSNXBW	\N	0	Canada	2	GUXHPOHHKR@dell.com	7816142281	4	8954030970111490	2010/02	user13852	password	59	100000	F
13853	VASLSY	FQFVENDPFL	6041619086 Dell Way	\N	SXYQYVT	\N	0	Russia	2	FQFVENDPFL@dell.com	6041619086	4	2147812983952462	2011/03	user13853	password	26	20000	F
13854	DVMWUS	NANSOQHTCA	1613471488 Dell Way	\N	RBQQWKI	\N	0	France	2	NANSOQHTCA@dell.com	1613471488	3	1829066229984164	2009/07	user13854	password	33	40000	M
13855	BVPWNC	XBULSCFUCW	3739251755 Dell Way	\N	VTNREVC	\N	0	Chile	2	XBULSCFUCW@dell.com	3739251755	1	5816898695193232	2012/05	user13855	password	82	80000	F
13856	SEIGGF	HBRZDXUFUP	6296787131 Dell Way	\N	ZHHEDKK	\N	0	France	2	HBRZDXUFUP@dell.com	6296787131	5	3844159491825849	2012/10	user13856	password	85	60000	M
13857	CUTJAB	KSBOQVUKKT	3402246295 Dell Way	\N	RSXVCIG	\N	0	Japan	2	KSBOQVUKKT@dell.com	3402246295	3	7216612570919097	2008/06	user13857	password	29	80000	M
13858	YKYZLJ	SMXIIRSTLK	1048058345 Dell Way	\N	LJFORLG	\N	0	UK	2	SMXIIRSTLK@dell.com	1048058345	5	1356317972764372	2010/02	user13858	password	66	20000	F
13859	BAAMKT	ZHBHZUAKEM	2854406490 Dell Way	\N	UKAMVHK	\N	0	South Africa	2	ZHBHZUAKEM@dell.com	2854406490	3	3977411493193358	2009/02	user13859	password	46	40000	F
13860	KJRUDQ	CEYCZZNDMH	6482598015 Dell Way	\N	ONTKUEG	\N	0	UK	2	CEYCZZNDMH@dell.com	6482598015	3	3539924905169755	2011/12	user13860	password	63	100000	F
13861	AOEDFG	IDIHDVLQDZ	2721061613 Dell Way	\N	DWJXAQX	\N	0	Japan	2	IDIHDVLQDZ@dell.com	2721061613	1	4270821623038501	2008/10	user13861	password	36	60000	M
13862	USYZYG	DHOHDAXHZA	9870981404 Dell Way	\N	DJYEZVV	\N	0	Canada	2	DHOHDAXHZA@dell.com	9870981404	1	4022208687849343	2011/06	user13862	password	81	60000	F
13863	OOFNUJ	VJQZJOGJOK	6328637537 Dell Way	\N	SMOSIKX	\N	0	Chile	2	VJQZJOGJOK@dell.com	6328637537	2	1730264244601130	2008/02	user13863	password	67	40000	M
13864	FMEAVZ	JMYTAECPPV	7029329719 Dell Way	\N	CEOKOLS	\N	0	Canada	2	JMYTAECPPV@dell.com	7029329719	4	2654584697913378	2011/06	user13864	password	50	60000	M
13865	XPRTOB	GNVGSYWHTY	8455512673 Dell Way	\N	LHJATBE	\N	0	France	2	GNVGSYWHTY@dell.com	8455512673	2	2539556785486638	2009/10	user13865	password	60	100000	M
13866	EQMTSS	GNZZLVGFUS	3130143092 Dell Way	\N	NDSGEXQ	\N	0	Australia	2	GNZZLVGFUS@dell.com	3130143092	5	3656918189488351	2008/05	user13866	password	35	80000	M
13867	WFIPYO	DXNOTUUNMH	9926676854 Dell Way	\N	RFNWCEW	\N	0	China	2	DXNOTUUNMH@dell.com	9926676854	1	4204620136413723	2009/05	user13867	password	25	100000	F
13868	IHWGWZ	EKOXEILQQD	1022311817 Dell Way	\N	WDZYIVH	\N	0	China	2	EKOXEILQQD@dell.com	1022311817	4	7397789872251452	2010/09	user13868	password	68	80000	F
13869	ZPIVPM	FDKJMWADZX	7586578733 Dell Way	\N	GYVPUCX	\N	0	Russia	2	FDKJMWADZX@dell.com	7586578733	4	2846277993638068	2010/04	user13869	password	83	60000	F
13870	MVCBHI	FSRSOSVNQC	2563443772 Dell Way	\N	MLRHOOC	\N	0	Chile	2	FSRSOSVNQC@dell.com	2563443772	2	7764624128583819	2010/03	user13870	password	37	80000	M
13871	CVSKDY	CVQROLFENR	3956406209 Dell Way	\N	QEZETBM	\N	0	UK	2	CVQROLFENR@dell.com	3956406209	2	4536321293562651	2010/06	user13871	password	27	20000	M
13872	ZXZCWC	YMTMXYRLQH	2826890710 Dell Way	\N	QPMJQZH	\N	0	UK	2	YMTMXYRLQH@dell.com	2826890710	4	5298913788516075	2011/10	user13872	password	66	40000	M
13873	OGXKIV	XCIVAAGQIW	3275303021 Dell Way	\N	FUGWUOV	\N	0	UK	2	XCIVAAGQIW@dell.com	3275303021	2	7109103326220066	2008/12	user13873	password	88	100000	M
13874	FTYOPW	QXRRYYHGVN	5653601133 Dell Way	\N	BBKVQFU	\N	0	South Africa	2	QXRRYYHGVN@dell.com	5653601133	3	9632105076685548	2010/06	user13874	password	78	20000	M
13875	PZGEVW	CNOALWGGJH	4761442088 Dell Way	\N	IUDYZYV	\N	0	Germany	2	CNOALWGGJH@dell.com	4761442088	4	9886709521990270	2012/08	user13875	password	18	60000	F
13876	ZTJVQL	IFMUBSALAJ	9589869928 Dell Way	\N	FEIFCES	\N	0	Germany	2	IFMUBSALAJ@dell.com	9589869928	4	4459706679452211	2010/09	user13876	password	84	80000	M
13877	RDNIPV	NBQPURAVAF	8156635941 Dell Way	\N	ZIKCMCQ	\N	0	France	2	NBQPURAVAF@dell.com	8156635941	1	1164964324329048	2010/12	user13877	password	75	20000	M
13878	YRYNNM	PDBJUBFVHF	9313693456 Dell Way	\N	DRHQUXB	\N	0	Germany	2	PDBJUBFVHF@dell.com	9313693456	1	1694820206146687	2012/11	user13878	password	36	60000	M
13879	XKILWX	OYHJZMEHRI	2017039331 Dell Way	\N	YZYTWAI	\N	0	South Africa	2	OYHJZMEHRI@dell.com	2017039331	3	6870827653910965	2012/08	user13879	password	25	100000	M
13880	NDAJBP	HIZHUDOMLN	1153886172 Dell Way	\N	LKGIKPC	\N	0	Germany	2	HIZHUDOMLN@dell.com	1153886172	4	5765947192907334	2011/11	user13880	password	42	40000	F
13881	MHTNWB	VVJQZXCLLN	7323431658 Dell Way	\N	VSVGIYU	\N	0	China	2	VVJQZXCLLN@dell.com	7323431658	2	1084564082324504	2010/08	user13881	password	37	100000	F
13882	OSQLTM	GDCGAERMSM	8473743995 Dell Way	\N	ENTNMNV	\N	0	Canada	2	GDCGAERMSM@dell.com	8473743995	5	7700385658536107	2010/02	user13882	password	68	60000	M
13883	KGCESJ	HUPIZGUSTZ	2621967929 Dell Way	\N	GMMSZIW	\N	0	South Africa	2	HUPIZGUSTZ@dell.com	2621967929	4	3725287978071719	2009/04	user13883	password	83	100000	M
13884	DBWVKE	QZMQFHIYHP	7776613988 Dell Way	\N	LUHLCDG	\N	0	Chile	2	QZMQFHIYHP@dell.com	7776613988	3	6215446234215052	2008/06	user13884	password	57	80000	M
13885	PQLZVC	YHSEPBDWQO	8185404531 Dell Way	\N	QYZSBGA	\N	0	South Africa	2	YHSEPBDWQO@dell.com	8185404531	3	8944120823871345	2009/02	user13885	password	65	100000	M
13886	HHRCJQ	KCVZEYVVNL	8043141670 Dell Way	\N	TNEVTFQ	\N	0	Germany	2	KCVZEYVVNL@dell.com	8043141670	3	8293105638120324	2012/03	user13886	password	65	80000	F
13887	YIPHYA	KUZOTVKGHD	2172108320 Dell Way	\N	UMZNRPC	\N	0	France	2	KUZOTVKGHD@dell.com	2172108320	5	4188563934527338	2009/07	user13887	password	89	80000	F
13888	HKUGKF	AJTTFEAMIU	3777865351 Dell Way	\N	YHIQWKB	\N	0	Australia	2	AJTTFEAMIU@dell.com	3777865351	3	3866220593918115	2012/05	user13888	password	25	40000	M
13889	MDYXIZ	GCTMHTYPOX	1000596158 Dell Way	\N	WXNTHPT	\N	0	Japan	2	GCTMHTYPOX@dell.com	1000596158	1	5229338891804219	2009/03	user13889	password	78	20000	M
13890	ZAOIZV	KSHSMGHADD	6972614925 Dell Way	\N	XRWFGPV	\N	0	Chile	2	KSHSMGHADD@dell.com	6972614925	2	6849584889598191	2012/02	user13890	password	70	60000	F
13891	TBKSWV	KDNXKUYNXW	2815192863 Dell Way	\N	FUBMJXS	\N	0	Australia	2	KDNXKUYNXW@dell.com	2815192863	2	8933575790375472	2009/02	user13891	password	45	60000	M
13892	LVOHQZ	LEWVYUJWQO	2177605402 Dell Way	\N	RSABPTC	\N	0	South Africa	2	LEWVYUJWQO@dell.com	2177605402	5	2228381010703742	2009/05	user13892	password	58	20000	M
13893	JPCAON	EKJDFTAVHR	8261099910 Dell Way	\N	OITECVZ	\N	0	Chile	2	EKJDFTAVHR@dell.com	8261099910	1	5120912344194949	2008/09	user13893	password	55	100000	F
13894	DBBROG	CYJIRKEZCS	9740835514 Dell Way	\N	IVWKQWQ	\N	0	France	2	CYJIRKEZCS@dell.com	9740835514	1	6566503389272839	2011/08	user13894	password	59	80000	M
13895	PSKEZN	DIVUTZUVRC	3232480016 Dell Way	\N	QONHKDT	\N	0	China	2	DIVUTZUVRC@dell.com	3232480016	2	1282030568923801	2012/12	user13895	password	69	80000	M
13896	LASKNW	TJQMIKHANX	3537692800 Dell Way	\N	PAFADYK	\N	0	China	2	TJQMIKHANX@dell.com	3537692800	3	3389577660243958	2009/02	user13896	password	81	80000	M
13897	XMZLIS	UZEDJMEXJT	6822499226 Dell Way	\N	XPUBNFL	\N	0	Russia	2	UZEDJMEXJT@dell.com	6822499226	4	9962358071468772	2011/07	user13897	password	72	40000	F
13898	FJXNCR	MHVWTZTDTQ	8449239417 Dell Way	\N	SNRFSDA	\N	0	China	2	MHVWTZTDTQ@dell.com	8449239417	5	2593056725803762	2009/09	user13898	password	59	100000	M
13899	YTMALZ	IGVBFPEYGX	1871742639 Dell Way	\N	MYCFBCP	\N	0	South Africa	2	IGVBFPEYGX@dell.com	1871742639	4	3635458413511515	2012/05	user13899	password	29	80000	F
13900	XGHIFQ	OBRURWTYTF	8141845775 Dell Way	\N	WVLYYAV	\N	0	Australia	2	OBRURWTYTF@dell.com	8141845775	1	8874988420400769	2008/04	user13900	password	65	60000	F
13901	XSNDIB	FZWXWPVPVR	6130124180 Dell Way	\N	LGQJGLK	\N	0	Australia	2	FZWXWPVPVR@dell.com	6130124180	2	2692268816754222	2012/12	user13901	password	60	20000	M
13902	HNAQPF	PLCLBYBWPM	6313203888 Dell Way	\N	CGWJRHL	\N	0	Chile	2	PLCLBYBWPM@dell.com	6313203888	4	1909948687069118	2010/03	user13902	password	27	60000	F
13903	RKDGQS	STEURGQHSS	2295312816 Dell Way	\N	NPCFXNM	\N	0	France	2	STEURGQHSS@dell.com	2295312816	3	1255117480643093	2009/09	user13903	password	50	100000	F
13904	WZPMRI	GWCYDSFWLT	1145446153 Dell Way	\N	LOZICLV	\N	0	Chile	2	GWCYDSFWLT@dell.com	1145446153	5	6197763708420098	2011/04	user13904	password	49	20000	F
13905	KRQCAX	YCVBVBXHUJ	4534057186 Dell Way	\N	WTSYFNE	\N	0	Chile	2	YCVBVBXHUJ@dell.com	4534057186	4	9427005241159352	2011/03	user13905	password	18	100000	M
13906	RMQRKP	UFRQGPYBZU	6974631116 Dell Way	\N	VRTAFXG	\N	0	Japan	2	UFRQGPYBZU@dell.com	6974631116	1	3745352364145219	2012/03	user13906	password	28	60000	M
13907	QBOARJ	FIAMYYOYTJ	8266800028 Dell Way	\N	PNJVKQL	\N	0	Australia	2	FIAMYYOYTJ@dell.com	8266800028	4	9276003621052952	2012/11	user13907	password	41	100000	M
13908	JKOAUU	JUHITVGMEW	9384105629 Dell Way	\N	ZOSKEEM	\N	0	UK	2	JUHITVGMEW@dell.com	9384105629	3	9804156539030374	2012/09	user13908	password	79	40000	F
13909	GYDASN	VZWOVCBZZB	4434065301 Dell Way	\N	NRMSWZS	\N	0	Russia	2	VZWOVCBZZB@dell.com	4434065301	4	6670928315725178	2008/07	user13909	password	18	40000	M
13910	YKURXQ	RUEMXGLWHZ	1627535316 Dell Way	\N	OTSKTKF	\N	0	Canada	2	RUEMXGLWHZ@dell.com	1627535316	5	3118328389711678	2010/11	user13910	password	52	40000	M
13911	WELUUC	OZPLFAHNAW	4088372858 Dell Way	\N	HSHACMD	\N	0	Canada	2	OZPLFAHNAW@dell.com	4088372858	2	7743102703709156	2008/10	user13911	password	25	100000	M
13912	GLLAOA	ZDLFETSEPZ	5054428274 Dell Way	\N	WXZZKCD	\N	0	Russia	2	ZDLFETSEPZ@dell.com	5054428274	5	9337905480526388	2009/12	user13912	password	84	100000	F
13913	JKHXKG	BWMFPEJEDG	3099621779 Dell Way	\N	CDFMFJF	\N	0	Japan	2	BWMFPEJEDG@dell.com	3099621779	1	9590791354887188	2009/01	user13913	password	84	60000	F
13914	ITHTAI	PMOEQXJUEL	3059167877 Dell Way	\N	YJXESCV	\N	0	UK	2	PMOEQXJUEL@dell.com	3059167877	4	2573013118468225	2009/09	user13914	password	64	80000	F
13915	JYTJHJ	VVNMTWHXIF	1162319993 Dell Way	\N	HFJAIFZ	\N	0	Germany	2	VVNMTWHXIF@dell.com	1162319993	1	8284263970796020	2011/10	user13915	password	52	80000	F
13916	LNNTWI	OKVIGDGOIO	7122282066 Dell Way	\N	USOCYNQ	\N	0	UK	2	OKVIGDGOIO@dell.com	7122282066	3	7130364849232138	2010/11	user13916	password	49	80000	F
13917	YCBVLQ	FHZMKGBTUV	9885823944 Dell Way	\N	LIXKWOJ	\N	0	Germany	2	FHZMKGBTUV@dell.com	9885823944	1	1166722462046891	2012/06	user13917	password	63	40000	F
13918	TIGFZM	MYYXEZQZUC	8846363676 Dell Way	\N	ISMFGVT	\N	0	Chile	2	MYYXEZQZUC@dell.com	8846363676	4	2331594605464488	2009/05	user13918	password	46	80000	F
13919	SAIRMV	QLSVKIUFLC	8362336956 Dell Way	\N	YYHFTBL	\N	0	Japan	2	QLSVKIUFLC@dell.com	8362336956	3	9800723453983664	2009/12	user13919	password	72	40000	M
13920	TRJGMZ	RFUCOOIZRG	5382262218 Dell Way	\N	XZLRAXH	\N	0	South Africa	2	RFUCOOIZRG@dell.com	5382262218	2	1422559776343405	2010/01	user13920	password	46	20000	M
13921	BNBOMT	THVHWEGOKE	4840193195 Dell Way	\N	NWVNTDJ	\N	0	Chile	2	THVHWEGOKE@dell.com	4840193195	3	7429485708009452	2010/10	user13921	password	81	40000	M
13922	KHKXBE	EWLBBSPLXC	4772975465 Dell Way	\N	ISQBWAI	\N	0	Chile	2	EWLBBSPLXC@dell.com	4772975465	1	7724471497349442	2009/11	user13922	password	90	20000	F
13923	HNEIRJ	FDKGVASSDA	5253887273 Dell Way	\N	LTCITLP	\N	0	Canada	2	FDKGVASSDA@dell.com	5253887273	2	4696427550632507	2009/05	user13923	password	54	80000	M
13924	AWZRFF	UQMQQFJUGV	1653324743 Dell Way	\N	NJDHUSM	\N	0	Chile	2	UQMQQFJUGV@dell.com	1653324743	5	6810059191193432	2010/05	user13924	password	41	20000	F
13925	EBCKHX	BTNSZXMFSA	7377069853 Dell Way	\N	OVIJOUQ	\N	0	Japan	2	BTNSZXMFSA@dell.com	7377069853	2	1398934866767376	2008/08	user13925	password	26	60000	M
13926	EPELNG	FAYEYKKQKZ	2932472565 Dell Way	\N	MTIAOYQ	\N	0	Chile	2	FAYEYKKQKZ@dell.com	2932472565	4	4257176303770393	2012/10	user13926	password	82	60000	M
13927	MTLZZR	AYVYIGPTFB	4445305752 Dell Way	\N	MNBBMSH	\N	0	Japan	2	AYVYIGPTFB@dell.com	4445305752	4	5490662136580795	2008/07	user13927	password	23	20000	F
13928	VPAVGB	TCACIPWNQJ	4229211014 Dell Way	\N	BSKOKSG	\N	0	Russia	2	TCACIPWNQJ@dell.com	4229211014	4	9701123029459268	2012/10	user13928	password	26	100000	M
13929	SYMYAG	AAJJPGXGPZ	5471728846 Dell Way	\N	YANISTD	\N	0	Australia	2	AAJJPGXGPZ@dell.com	5471728846	1	9870477065443994	2009/03	user13929	password	84	100000	M
13930	WMWWTX	WCGMJDSYCQ	2975857560 Dell Way	\N	ZPZSJDU	\N	0	South Africa	2	WCGMJDSYCQ@dell.com	2975857560	4	2641039898619056	2010/09	user13930	password	29	40000	M
13931	QFLJDH	MJUVNMUPCU	1788154290 Dell Way	\N	FCMPFHL	\N	0	France	2	MJUVNMUPCU@dell.com	1788154290	4	8903138283640147	2011/10	user13931	password	35	40000	F
13932	MUUPCG	YWCLIWBLQG	9390989200 Dell Way	\N	ODWULHF	\N	0	Germany	2	YWCLIWBLQG@dell.com	9390989200	1	3731369321234524	2011/04	user13932	password	66	20000	M
13933	MYJOFI	LHUUEVFVCU	8824940374 Dell Way	\N	YYOJGUW	\N	0	Canada	2	LHUUEVFVCU@dell.com	8824940374	1	9084384341724218	2009/11	user13933	password	21	20000	F
13934	ZJWFSH	MMBRIHMKCK	8265865777 Dell Way	\N	IQTPKQT	\N	0	Chile	2	MMBRIHMKCK@dell.com	8265865777	4	5450355215463788	2011/09	user13934	password	54	100000	M
13935	WVXPCJ	BEBJMNUOXD	2204257440 Dell Way	\N	FRSQIMY	\N	0	Canada	2	BEBJMNUOXD@dell.com	2204257440	3	7880293931346387	2012/11	user13935	password	69	60000	M
13936	NKJQUL	UWVHJQVHTB	1157877207 Dell Way	\N	YLRGYPJ	\N	0	Australia	2	UWVHJQVHTB@dell.com	1157877207	1	9180078195873648	2012/11	user13936	password	50	80000	F
13937	WCZROU	NJCWZXDTYC	8775522592 Dell Way	\N	FQJDGSF	\N	0	Chile	2	NJCWZXDTYC@dell.com	8775522592	1	2657442646101117	2011/07	user13937	password	83	20000	F
13938	ZCCOXP	XZMXWPQVSV	3422376671 Dell Way	\N	MBYSUEZ	\N	0	Japan	2	XZMXWPQVSV@dell.com	3422376671	1	4183608985040337	2012/01	user13938	password	50	40000	F
13939	NIPKXN	KKKGABCSWP	4749710801 Dell Way	\N	TVHNZGE	\N	0	Chile	2	KKKGABCSWP@dell.com	4749710801	3	1788983688224107	2010/12	user13939	password	41	60000	F
13940	QDXOQH	YBOYCRRZGK	6738280059 Dell Way	\N	UOYUVCB	\N	0	Chile	2	YBOYCRRZGK@dell.com	6738280059	1	7333060302305967	2011/06	user13940	password	34	20000	F
13941	JARZIQ	AWPDOGCUQX	9411382911 Dell Way	\N	JPSESUK	\N	0	China	2	AWPDOGCUQX@dell.com	9411382911	1	9573347227182240	2010/04	user13941	password	21	60000	M
13942	BFRJWS	GLVVRXPIUZ	6716447271 Dell Way	\N	XMDQGNZ	\N	0	Canada	2	GLVVRXPIUZ@dell.com	6716447271	5	6479657006915659	2012/12	user13942	password	29	80000	F
13943	JILFAR	RVMISCQMBO	1927459802 Dell Way	\N	ZFFGTEL	\N	0	China	2	RVMISCQMBO@dell.com	1927459802	1	4061249606311321	2008/03	user13943	password	90	20000	M
13944	IOUIGL	DTUWWLJYZI	1417826394 Dell Way	\N	DEPWJAG	\N	0	France	2	DTUWWLJYZI@dell.com	1417826394	3	5905239252373577	2009/07	user13944	password	67	80000	M
13945	GPFMBJ	GVFCGPAGYD	8558795955 Dell Way	\N	KNAUNGG	\N	0	Germany	2	GVFCGPAGYD@dell.com	8558795955	4	8193041694350541	2010/06	user13945	password	61	40000	M
13946	ENFFWL	BCNHRONPSY	7702767066 Dell Way	\N	DSSQZZF	\N	0	South Africa	2	BCNHRONPSY@dell.com	7702767066	5	3144213458523154	2009/08	user13946	password	57	100000	M
13947	BCAYOB	ABJSQWIIVL	3400267315 Dell Way	\N	BOBBNGW	\N	0	Chile	2	ABJSQWIIVL@dell.com	3400267315	1	5255055434070528	2012/08	user13947	password	45	80000	M
13948	MRQASQ	CBISYRBUCD	2178965538 Dell Way	\N	IEEWLAD	\N	0	Japan	2	CBISYRBUCD@dell.com	2178965538	4	5994818386621774	2011/12	user13948	password	32	60000	F
13949	WCNPSP	RBIPTKKVNT	4079570162 Dell Way	\N	ZRPKSTC	\N	0	South Africa	2	RBIPTKKVNT@dell.com	4079570162	4	6393361001275480	2009/11	user13949	password	22	100000	M
13950	EIHXXY	ZGOSQYNDRN	7049876542 Dell Way	\N	VHXNAAI	\N	0	China	2	ZGOSQYNDRN@dell.com	7049876542	5	7321149592753500	2010/01	user13950	password	55	40000	F
13951	VOBSNA	ZBSQAGUSTP	4539092598 Dell Way	\N	ARCBRLK	\N	0	China	2	ZBSQAGUSTP@dell.com	4539092598	1	8999431096017362	2010/08	user13951	password	28	60000	F
13952	SQEFQE	HJUIPOBIEB	6899863010 Dell Way	\N	AGCSSNB	\N	0	Canada	2	HJUIPOBIEB@dell.com	6899863010	5	5648050666321070	2009/01	user13952	password	23	80000	M
13953	SXZIBG	RWOGKQPORP	3684825354 Dell Way	\N	VUHOIJR	\N	0	UK	2	RWOGKQPORP@dell.com	3684825354	1	3337651962880045	2009/04	user13953	password	90	20000	M
13954	XDHZKZ	VZGGPVUGLQ	1426089634 Dell Way	\N	BTEJCWI	\N	0	France	2	VZGGPVUGLQ@dell.com	1426089634	4	8056280747521669	2009/08	user13954	password	86	40000	M
13955	BPMMOI	LUOAQJHBZJ	6954852356 Dell Way	\N	VESYABI	\N	0	Australia	2	LUOAQJHBZJ@dell.com	6954852356	1	4597994260024280	2009/01	user13955	password	67	80000	F
13956	GGPVOB	PCBFLJHLSD	5487649487 Dell Way	\N	PLBQNJT	\N	0	Canada	2	PCBFLJHLSD@dell.com	5487649487	1	4787328301463276	2010/10	user13956	password	31	80000	F
13957	KHXZIM	BKSNTAYMDO	1764598996 Dell Way	\N	YEFLOYP	\N	0	Australia	2	BKSNTAYMDO@dell.com	1764598996	1	6625896863639355	2012/03	user13957	password	40	100000	M
13958	PWPXJR	HCEBCDOGSM	5962823203 Dell Way	\N	LYYAXNB	\N	0	UK	2	HCEBCDOGSM@dell.com	5962823203	4	8831756340805442	2011/01	user13958	password	79	40000	M
13959	SZNBQV	DVXGYLMRYX	7129907260 Dell Way	\N	PWXMKZL	\N	0	UK	2	DVXGYLMRYX@dell.com	7129907260	2	7475078068673611	2011/03	user13959	password	24	40000	M
13960	BUZRPC	NMJLYVDWTT	1137801648 Dell Way	\N	TRFERRD	\N	0	China	2	NMJLYVDWTT@dell.com	1137801648	5	1184863758739084	2008/12	user13960	password	39	20000	F
13961	CBSREF	DNRBJUYDNS	9048648483 Dell Way	\N	UTWLLAU	\N	0	France	2	DNRBJUYDNS@dell.com	9048648483	5	6813321385998280	2012/02	user13961	password	71	100000	F
13962	UOWYTZ	LLBVFAYTST	8136678521 Dell Way	\N	NPFYQZK	\N	0	Germany	2	LLBVFAYTST@dell.com	8136678521	1	4366434009280056	2012/10	user13962	password	35	20000	M
13963	UYMOYY	AZUFASZSMM	8553864520 Dell Way	\N	IRKYRUM	\N	0	France	2	AZUFASZSMM@dell.com	8553864520	5	4241383004467934	2011/01	user13963	password	50	20000	M
13964	JQLHPL	HJRHCQAOCI	6202890692 Dell Way	\N	GNGXITJ	\N	0	Canada	2	HJRHCQAOCI@dell.com	6202890692	4	7934028753545136	2011/03	user13964	password	85	60000	M
13965	OAWDLD	MDLOULDXTJ	4626582555 Dell Way	\N	KAHTTRX	\N	0	China	2	MDLOULDXTJ@dell.com	4626582555	4	1045147503726184	2010/08	user13965	password	58	20000	F
13966	OZHADU	DOIYZMVTVG	6269936211 Dell Way	\N	UDZOUXX	\N	0	Chile	2	DOIYZMVTVG@dell.com	6269936211	5	8040860312990845	2008/06	user13966	password	84	40000	F
13967	XQAAKE	OTCOGYHCEC	4918946732 Dell Way	\N	FEQACNF	\N	0	Japan	2	OTCOGYHCEC@dell.com	4918946732	5	8678902722429485	2012/11	user13967	password	32	100000	M
13968	VXVGBJ	AEYGCGIGIO	7832045337 Dell Way	\N	LYONMTE	\N	0	UK	2	AEYGCGIGIO@dell.com	7832045337	1	8311238041613252	2011/03	user13968	password	69	60000	F
13969	PHIRRI	VPPXVXEDLP	4155235086 Dell Way	\N	CZDPTIN	\N	0	Germany	2	VPPXVXEDLP@dell.com	4155235086	2	2680593676399439	2010/01	user13969	password	65	80000	M
13970	YZIPID	FXBAUGEGWH	7621037563 Dell Way	\N	GZWZHKN	\N	0	Japan	2	FXBAUGEGWH@dell.com	7621037563	4	3114435745868832	2011/05	user13970	password	82	60000	F
13971	WSXEWC	BYDWEICAPI	5799129839 Dell Way	\N	AMIIXVY	\N	0	Japan	2	BYDWEICAPI@dell.com	5799129839	1	4555978180840612	2012/01	user13971	password	76	20000	M
13972	NCDKFE	IIBNRDNGLN	9972534799 Dell Way	\N	TUVQPUG	\N	0	Canada	2	IIBNRDNGLN@dell.com	9972534799	4	1322275120299309	2008/06	user13972	password	34	20000	M
13973	IDKNIT	WJGNNTUZHO	1923882653 Dell Way	\N	TDEJYLN	\N	0	UK	2	WJGNNTUZHO@dell.com	1923882653	3	1212335945107042	2010/10	user13973	password	21	60000	F
13974	FZPNSM	XYZKSUJZID	5627756800 Dell Way	\N	DMMCYZA	\N	0	Australia	2	XYZKSUJZID@dell.com	5627756800	1	6484435714315624	2009/02	user13974	password	30	40000	F
13975	DYWWKT	UKEMEOMMRQ	8179185742 Dell Way	\N	ZDSYDTZ	\N	0	Japan	2	UKEMEOMMRQ@dell.com	8179185742	3	9218185688834638	2012/10	user13975	password	37	40000	M
13976	FBTQVN	BZAFOMSFDS	2610414972 Dell Way	\N	JVQMOPD	\N	0	China	2	BZAFOMSFDS@dell.com	2610414972	1	3475673770066351	2012/04	user13976	password	53	100000	M
13977	OOEJCF	JDLXPEDSXM	2009003671 Dell Way	\N	ONYDDCN	\N	0	China	2	JDLXPEDSXM@dell.com	2009003671	4	3180773983243853	2010/04	user13977	password	23	100000	M
13978	QCETIO	WULMZOFWBT	2572851343 Dell Way	\N	KAXNCKV	\N	0	Chile	2	WULMZOFWBT@dell.com	2572851343	1	6545030227396638	2010/02	user13978	password	58	40000	M
13979	RLOAAK	ULWUACQCWA	5106864597 Dell Way	\N	CTOEDJK	\N	0	China	2	ULWUACQCWA@dell.com	5106864597	1	7829693505074830	2011/07	user13979	password	19	40000	F
13980	MYGMIB	YFVYILBEMD	7402710217 Dell Way	\N	XAIBKSJ	\N	0	South Africa	2	YFVYILBEMD@dell.com	7402710217	1	5224191292654723	2009/02	user13980	password	81	60000	M
13981	UTCDUA	JPZRBAVODT	3483398934 Dell Way	\N	PMUZEDW	\N	0	South Africa	2	JPZRBAVODT@dell.com	3483398934	2	2436139238066971	2010/03	user13981	password	66	20000	M
13982	KCDFCN	VCEXCALGTA	2571011457 Dell Way	\N	SOZWSWT	\N	0	UK	2	VCEXCALGTA@dell.com	2571011457	5	4625015734694898	2009/08	user13982	password	49	40000	M
13983	NMFQZA	SEXVFIBZJT	3693974667 Dell Way	\N	NIPGFJF	\N	0	China	2	SEXVFIBZJT@dell.com	3693974667	4	7613664757460356	2012/01	user13983	password	24	100000	M
13984	OCGOCZ	TAUYIVYROL	5754990214 Dell Way	\N	AERGOXP	\N	0	South Africa	2	TAUYIVYROL@dell.com	5754990214	2	7567125757224859	2010/06	user13984	password	62	20000	F
13985	SKPUJI	UDHDYFVNRW	1509145716 Dell Way	\N	RICFGSB	\N	0	Russia	2	UDHDYFVNRW@dell.com	1509145716	4	4182032135315240	2010/05	user13985	password	56	60000	F
13986	YBXHKS	LRWKWSXNOP	7020247776 Dell Way	\N	WRUDKWX	\N	0	France	2	LRWKWSXNOP@dell.com	7020247776	2	9470119274221362	2008/10	user13986	password	49	20000	M
13987	NCAXUL	ORWLJTZYIW	2072057942 Dell Way	\N	PDZAAWM	\N	0	Japan	2	ORWLJTZYIW@dell.com	2072057942	3	7921137038618327	2012/11	user13987	password	87	60000	F
13988	APGVAV	MWGWQGUZDK	3610762887 Dell Way	\N	DCKEZWW	\N	0	Canada	2	MWGWQGUZDK@dell.com	3610762887	4	9943181312177332	2008/07	user13988	password	60	60000	M
13989	ESLFNY	CUUTBOSEZW	5203089226 Dell Way	\N	HJAHGWK	\N	0	Germany	2	CUUTBOSEZW@dell.com	5203089226	2	7103079189546407	2008/12	user13989	password	29	80000	F
13990	WCJKAL	FUEGJXLITT	8312751968 Dell Way	\N	STAZPLN	\N	0	Australia	2	FUEGJXLITT@dell.com	8312751968	1	1832086279988289	2011/05	user13990	password	71	100000	F
13991	VGQVSV	QWBAUNINHB	7533146594 Dell Way	\N	GHAVSNX	\N	0	Germany	2	QWBAUNINHB@dell.com	7533146594	5	3905147317331284	2008/09	user13991	password	35	40000	M
13992	NXJFSA	CUAWIJKPKQ	4337205600 Dell Way	\N	XLMQZJE	\N	0	Japan	2	CUAWIJKPKQ@dell.com	4337205600	3	7853733654133976	2008/09	user13992	password	21	80000	F
13993	YAMRAO	MALUJVKUMH	6111596863 Dell Way	\N	FYXEIBW	\N	0	Russia	2	MALUJVKUMH@dell.com	6111596863	4	8158887065015734	2009/09	user13993	password	49	60000	M
13994	LAHLPT	LAOVWYPIFU	4927923415 Dell Way	\N	HDYPFVI	\N	0	Russia	2	LAOVWYPIFU@dell.com	4927923415	1	1755178613588214	2008/07	user13994	password	64	80000	M
13995	QAKFUW	GIRDHGLNBT	8043950494 Dell Way	\N	RAJWVRQ	\N	0	Chile	2	GIRDHGLNBT@dell.com	8043950494	4	4415230591315776	2009/05	user13995	password	25	40000	F
13996	DSGXOM	GGQONBBOVS	9894424326 Dell Way	\N	PEPLVGS	\N	0	Japan	2	GGQONBBOVS@dell.com	9894424326	1	9542707439977676	2009/03	user13996	password	35	40000	F
13997	YPFNCM	TSAGUCVQVK	6416291771 Dell Way	\N	UKVQRNG	\N	0	Japan	2	TSAGUCVQVK@dell.com	6416291771	2	1041286690160632	2011/06	user13997	password	45	20000	F
13998	ZIXCUQ	VUWQXRGSCA	2204004722 Dell Way	\N	CXRTLYK	\N	0	Australia	2	VUWQXRGSCA@dell.com	2204004722	3	8334067525342108	2010/10	user13998	password	84	100000	M
13999	FWWANS	UKISCOKEPN	1948616304 Dell Way	\N	CGHNERN	\N	0	China	2	UKISCOKEPN@dell.com	1948616304	2	9038593283854426	2012/04	user13999	password	81	80000	F
14000	TOMHGH	ROZTDJYSWA	4538349106 Dell Way	\N	YDNDVBL	\N	0	UK	2	ROZTDJYSWA@dell.com	4538349106	2	8545165945310146	2011/03	user14000	password	55	20000	M
14001	BPGIXX	XWRAGPSDPR	6341127964 Dell Way	\N	HCVCEGB	\N	0	Germany	2	XWRAGPSDPR@dell.com	6341127964	5	2779878668952733	2012/05	user14001	password	41	80000	F
14002	YZUVXR	SOSYDLCTCJ	4678100033 Dell Way	\N	WYMAENO	\N	0	Russia	2	SOSYDLCTCJ@dell.com	4678100033	4	6279081936459989	2012/02	user14002	password	43	40000	F
14003	JCWGUO	VMNZXPSAZO	9147702939 Dell Way	\N	YLPDZDY	\N	0	China	2	VMNZXPSAZO@dell.com	9147702939	3	2729030762799084	2012/11	user14003	password	53	20000	F
14004	OWMJKH	VYGTOZUNOS	3945656883 Dell Way	\N	YDWYHVI	\N	0	Canada	2	VYGTOZUNOS@dell.com	3945656883	3	2525490359403193	2008/12	user14004	password	30	60000	M
14005	AXXLET	JLMXKHLYAK	2220026973 Dell Way	\N	BWIIRQN	\N	0	Australia	2	JLMXKHLYAK@dell.com	2220026973	4	2904052230995148	2008/11	user14005	password	63	80000	M
14006	NPJRIS	CVQNCCLCMM	1283050948 Dell Way	\N	ZVVRLJR	\N	0	Germany	2	CVQNCCLCMM@dell.com	1283050948	5	7287111626937986	2012/07	user14006	password	45	80000	F
14007	ZDTHWV	DNJGPUJCHI	6443385272 Dell Way	\N	XCAILSX	\N	0	France	2	DNJGPUJCHI@dell.com	6443385272	4	4461754902265966	2008/12	user14007	password	30	20000	M
14008	IXGETK	SCQIXAKEIH	2697283889 Dell Way	\N	HJQTBOG	\N	0	Japan	2	SCQIXAKEIH@dell.com	2697283889	4	8194900012575091	2008/10	user14008	password	89	20000	F
14009	XKHQVZ	TLHQLSVUZC	7449184018 Dell Way	\N	EQWFFCX	\N	0	China	2	TLHQLSVUZC@dell.com	7449184018	4	6246076935436577	2010/08	user14009	password	71	80000	M
14010	DXFYXY	KFPWXKRXNV	6734091743 Dell Way	\N	OJBTMYD	\N	0	Canada	2	KFPWXKRXNV@dell.com	6734091743	4	7293927593622357	2009/06	user14010	password	41	100000	M
14011	GBODZZ	JPWGANENJS	3907044183 Dell Way	\N	XLLJKPO	\N	0	Australia	2	JPWGANENJS@dell.com	3907044183	2	3960547774564475	2011/07	user14011	password	31	40000	M
14012	GYZFXI	VUOVISIRLG	4633283447 Dell Way	\N	DWPNMEO	\N	0	Russia	2	VUOVISIRLG@dell.com	4633283447	5	6155064126942307	2012/01	user14012	password	87	80000	F
14013	XTNVBI	PQEXJNPUTS	7004499098 Dell Way	\N	RJGDNUY	\N	0	UK	2	PQEXJNPUTS@dell.com	7004499098	3	9035745318513364	2011/06	user14013	password	68	20000	F
14014	LNENWU	EASNOHIHAA	6227520801 Dell Way	\N	QGDEBCC	\N	0	Russia	2	EASNOHIHAA@dell.com	6227520801	5	5030596344266087	2008/08	user14014	password	51	60000	F
14015	ZPPWJT	XCHLJQTKQK	6449104890 Dell Way	\N	RUOSWQL	\N	0	France	2	XCHLJQTKQK@dell.com	6449104890	5	5439642057754100	2009/05	user14015	password	83	40000	F
14016	MZFWTD	ZBOIRITISK	4911937760 Dell Way	\N	CGCZXOL	\N	0	France	2	ZBOIRITISK@dell.com	4911937760	5	7845220129936934	2011/10	user14016	password	26	20000	F
14017	CIFVLE	WANOIGWBQZ	3785089806 Dell Way	\N	HTYFHJS	\N	0	Russia	2	WANOIGWBQZ@dell.com	3785089806	3	5566728632897139	2008/07	user14017	password	64	60000	M
14018	ZRMLVJ	MIXUOTWFSD	5426234981 Dell Way	\N	YRIGBAY	\N	0	China	2	MIXUOTWFSD@dell.com	5426234981	3	5463607993442565	2008/02	user14018	password	87	80000	F
14019	QFNLOZ	ULUJFQOXUM	2347128535 Dell Way	\N	PDSQERZ	\N	0	Japan	2	ULUJFQOXUM@dell.com	2347128535	3	7512572400271893	2009/06	user14019	password	50	40000	F
14020	RVNFVH	RPQWGEUARJ	5095866509 Dell Way	\N	EKZICZZ	\N	0	Chile	2	RPQWGEUARJ@dell.com	5095866509	4	5449041218031198	2012/02	user14020	password	77	100000	M
14021	RLBMTS	CJPJOJKGSO	6358263244 Dell Way	\N	QRXTRWZ	\N	0	Canada	2	CJPJOJKGSO@dell.com	6358263244	3	1069162201136350	2011/04	user14021	password	88	60000	M
14022	KQLDIO	NXXCHIIZWY	2497103916 Dell Way	\N	RTSIQRL	\N	0	Chile	2	NXXCHIIZWY@dell.com	2497103916	3	9941165435127916	2010/05	user14022	password	60	60000	M
14023	FXZOLM	MJOTRXSOWK	6521059006 Dell Way	\N	HOSYGEE	\N	0	China	2	MJOTRXSOWK@dell.com	6521059006	1	8802016832865775	2008/09	user14023	password	39	100000	M
14024	EVNQIZ	AXSRULGQWN	8445010563 Dell Way	\N	EOMKTRU	\N	0	China	2	AXSRULGQWN@dell.com	8445010563	4	4366328753530979	2010/12	user14024	password	33	60000	F
14025	AAUIAU	FSMAESQAGU	6803861511 Dell Way	\N	PTEIKZS	\N	0	Chile	2	FSMAESQAGU@dell.com	6803861511	1	8238415392115713	2011/04	user14025	password	42	80000	F
14026	JORJJX	CWXHPNHWHX	1145924303 Dell Way	\N	PMGAMYG	\N	0	Canada	2	CWXHPNHWHX@dell.com	1145924303	1	7514386809896678	2009/05	user14026	password	53	80000	M
14027	BHCKEF	HBMWPUSXSI	6253881698 Dell Way	\N	KYIWXOZ	\N	0	UK	2	HBMWPUSXSI@dell.com	6253881698	4	2882086049765348	2012/03	user14027	password	78	80000	F
14028	DUQHZX	JMUZGMWYVG	7958909812 Dell Way	\N	XDCURCR	\N	0	Chile	2	JMUZGMWYVG@dell.com	7958909812	5	2942113200202584	2012/09	user14028	password	83	20000	M
14029	RVDRTN	DNMJAIIWPF	6087896420 Dell Way	\N	ZRZRTRY	\N	0	Germany	2	DNMJAIIWPF@dell.com	6087896420	1	5448055434972048	2009/01	user14029	password	67	20000	M
14030	NGKGTN	UFXVOGRDLR	4475344372 Dell Way	\N	VLIPDGD	\N	0	Japan	2	UFXVOGRDLR@dell.com	4475344372	4	9736575127113612	2010/04	user14030	password	25	20000	M
14031	JOCDBW	JZSXGKBRBW	3055536648 Dell Way	\N	DJMGQPY	\N	0	Australia	2	JZSXGKBRBW@dell.com	3055536648	5	4937134012579918	2010/01	user14031	password	60	40000	F
14032	DLMFIV	FBTLLUDMRG	4072599771 Dell Way	\N	WDNNTLN	\N	0	UK	2	FBTLLUDMRG@dell.com	4072599771	5	5565299409441650	2009/07	user14032	password	80	80000	M
14033	HEWQAC	RTNCNQPFXM	5002466538 Dell Way	\N	IKZCVMB	\N	0	Canada	2	RTNCNQPFXM@dell.com	5002466538	3	5693628438282759	2012/06	user14033	password	34	80000	M
14034	KNJKQA	DDDRUSWRFF	9018822247 Dell Way	\N	BEHXRIC	\N	0	Canada	2	DDDRUSWRFF@dell.com	9018822247	4	1872436606790870	2009/10	user14034	password	72	20000	F
14035	HKQXKT	BNLVGHMLMO	2371878447 Dell Way	\N	PTLHCOK	\N	0	UK	2	BNLVGHMLMO@dell.com	2371878447	3	3639227923005819	2012/03	user14035	password	42	40000	M
14036	SVLCPM	QAHWHUHUIX	1383504990 Dell Way	\N	NUEQIOP	\N	0	France	2	QAHWHUHUIX@dell.com	1383504990	5	5198745410423726	2009/03	user14036	password	67	100000	M
14037	MGBCSR	CAOKUVECTS	8486495468 Dell Way	\N	XXIGMYS	\N	0	Germany	2	CAOKUVECTS@dell.com	8486495468	1	8107473397161812	2008/11	user14037	password	61	20000	F
14038	VBLOTO	OHYIDCLWVJ	5503398685 Dell Way	\N	UDPGBIT	\N	0	UK	2	OHYIDCLWVJ@dell.com	5503398685	3	9683921482414008	2009/02	user14038	password	88	80000	M
14039	AENTSB	BQKETWAOFV	4088438488 Dell Way	\N	SUBUDUR	\N	0	Japan	2	BQKETWAOFV@dell.com	4088438488	4	9801710263825954	2010/08	user14039	password	68	60000	M
14040	WZKOAL	FLPYHQNNLF	3616114267 Dell Way	\N	INZLIQB	\N	0	Japan	2	FLPYHQNNLF@dell.com	3616114267	1	2199910933617502	2012/09	user14040	password	60	60000	M
14041	OXEOJJ	AZIIPVVBAE	7280898830 Dell Way	\N	PAPXRRO	\N	0	UK	2	AZIIPVVBAE@dell.com	7280898830	4	8663963844999672	2010/04	user14041	password	45	20000	M
14042	HEJQOK	PWSFSOHTSW	1069359791 Dell Way	\N	TIUKZIJ	\N	0	Japan	2	PWSFSOHTSW@dell.com	1069359791	2	2056820359081030	2009/08	user14042	password	28	20000	M
14043	ILOWWE	TPJMDRFWOZ	9956788401 Dell Way	\N	FIKERTW	\N	0	Japan	2	TPJMDRFWOZ@dell.com	9956788401	5	9499340763781220	2011/02	user14043	password	19	60000	F
14044	MBIIFC	YPOBGUYVTD	2593258595 Dell Way	\N	EDIVXEN	\N	0	South Africa	2	YPOBGUYVTD@dell.com	2593258595	3	5397286092396826	2009/06	user14044	password	90	80000	M
14045	ACHFFF	UTHBNFXGJB	8542174309 Dell Way	\N	KRWHWKE	\N	0	Australia	2	UTHBNFXGJB@dell.com	8542174309	4	4145891598425806	2009/08	user14045	password	26	40000	M
14046	FOXLTS	EBUSHRZQSJ	5584390002 Dell Way	\N	HPREZVF	\N	0	South Africa	2	EBUSHRZQSJ@dell.com	5584390002	3	2217599083669483	2008/09	user14046	password	46	100000	M
14047	YTISLN	TGFAXFRPPZ	9270958943 Dell Way	\N	FGDFCJA	\N	0	Japan	2	TGFAXFRPPZ@dell.com	9270958943	1	8025602680165321	2010/07	user14047	password	63	60000	M
14048	JVFVIZ	BOAYUROJQU	2530599766 Dell Way	\N	QUZTDAJ	\N	0	Australia	2	BOAYUROJQU@dell.com	2530599766	1	6836220808327199	2011/10	user14048	password	28	40000	F
14049	ZLYHKA	WKZQBNZSHQ	8975742986 Dell Way	\N	MHJQHTR	\N	0	France	2	WKZQBNZSHQ@dell.com	8975742986	2	2679668909404427	2011/06	user14049	password	48	80000	F
14050	WTSGTP	RSFTGFLOVY	5817027768 Dell Way	\N	VFODYFP	\N	0	South Africa	2	RSFTGFLOVY@dell.com	5817027768	4	5426269200630486	2012/03	user14050	password	38	60000	F
14051	ADIUTZ	NYSTDEIZDE	6930447133 Dell Way	\N	FRHDXWZ	\N	0	France	2	NYSTDEIZDE@dell.com	6930447133	3	4815723498817533	2012/10	user14051	password	79	100000	M
14052	ZFOTEB	RXVVCEVFIA	6618496531 Dell Way	\N	WPEUMDF	\N	0	Canada	2	RXVVCEVFIA@dell.com	6618496531	4	1034175642766058	2009/06	user14052	password	83	20000	F
14053	CTFHUW	FQSHUNNCNK	1054668981 Dell Way	\N	SREFVJJ	\N	0	France	2	FQSHUNNCNK@dell.com	1054668981	2	8427168425172568	2010/04	user14053	password	90	100000	F
14054	SERNBX	ETEZHSCUCU	7942148806 Dell Way	\N	MHAHQKS	\N	0	Japan	2	ETEZHSCUCU@dell.com	7942148806	3	2243226035963744	2008/07	user14054	password	25	60000	F
14055	GCUIZZ	BEYJWADZVP	2426217981 Dell Way	\N	GVXXFPO	\N	0	Australia	2	BEYJWADZVP@dell.com	2426217981	4	1440823670942336	2011/10	user14055	password	53	100000	F
14056	PTJPSL	TQUQRYQMOW	1204324010 Dell Way	\N	HLUNAIN	\N	0	Canada	2	TQUQRYQMOW@dell.com	1204324010	3	9035135761369020	2012/01	user14056	password	80	100000	M
14057	PGGIRA	ZMRQLHCZEK	1547067449 Dell Way	\N	KYYLHMQ	\N	0	Chile	2	ZMRQLHCZEK@dell.com	1547067449	3	1958488284144550	2008/05	user14057	password	89	80000	M
14058	FAIXAH	KRYVZBUDME	7603940551 Dell Way	\N	BLPJXFQ	\N	0	UK	2	KRYVZBUDME@dell.com	7603940551	4	1787231996189803	2008/09	user14058	password	81	20000	M
14059	WKWXSG	PRBOSWSFAU	5651091553 Dell Way	\N	QQDNWTM	\N	0	Germany	2	PRBOSWSFAU@dell.com	5651091553	3	7209104317706079	2009/06	user14059	password	74	20000	F
14060	EAGXHV	OIKHECMFWC	7347167070 Dell Way	\N	WAQSUDH	\N	0	Chile	2	OIKHECMFWC@dell.com	7347167070	5	5781930803321302	2008/10	user14060	password	69	60000	M
14061	TSVAOK	JYRNBDTYGP	6241400185 Dell Way	\N	YXISAPZ	\N	0	Russia	2	JYRNBDTYGP@dell.com	6241400185	3	8791200250852854	2009/03	user14061	password	43	40000	M
14062	BCZPMI	OEWPIQNOGL	7253818770 Dell Way	\N	LOELDEE	\N	0	Russia	2	OEWPIQNOGL@dell.com	7253818770	1	1575430950615555	2012/05	user14062	password	42	100000	F
14063	LXBYGP	CCFLTSZZEL	1926119645 Dell Way	\N	NIXQNBJ	\N	0	Chile	2	CCFLTSZZEL@dell.com	1926119645	3	2259927392937243	2010/10	user14063	password	22	100000	F
14064	YZEFOH	ITSBMSARDN	9985791433 Dell Way	\N	AAENCOS	\N	0	Chile	2	ITSBMSARDN@dell.com	9985791433	5	7200697956141085	2011/11	user14064	password	62	20000	M
14065	PFBDNK	XGLKYLBCZB	2521384563 Dell Way	\N	DEPFSIL	\N	0	Russia	2	XGLKYLBCZB@dell.com	2521384563	1	5516177303623409	2008/09	user14065	password	55	100000	F
14066	SAMFKK	LWUKIWMHYQ	4645539470 Dell Way	\N	LNWEVHX	\N	0	UK	2	LWUKIWMHYQ@dell.com	4645539470	3	1690275177825242	2008/12	user14066	password	20	60000	M
14067	BYWMII	JDTRZGYXWK	9120849467 Dell Way	\N	KSPGZMF	\N	0	China	2	JDTRZGYXWK@dell.com	9120849467	2	5809456503950060	2012/05	user14067	password	90	60000	F
14068	YIXGRG	JKYIQXGMHQ	4727033252 Dell Way	\N	FXXFKCP	\N	0	China	2	JKYIQXGMHQ@dell.com	4727033252	1	2158860248513520	2011/02	user14068	password	61	20000	F
14069	YBHQIR	AGARDGELXJ	3533216411 Dell Way	\N	JUOTXEB	\N	0	China	2	AGARDGELXJ@dell.com	3533216411	1	1729194307234138	2009/10	user14069	password	36	60000	M
14070	ITJRLJ	YLBBSFNQPX	9112476344 Dell Way	\N	LEQIISR	\N	0	Japan	2	YLBBSFNQPX@dell.com	9112476344	4	1213558609131723	2011/01	user14070	password	52	60000	F
14071	FUZQDX	CFZVLNLBKW	6858574225 Dell Way	\N	FBFOTXF	\N	0	Japan	2	CFZVLNLBKW@dell.com	6858574225	2	4099400085862726	2011/09	user14071	password	74	100000	M
14072	OYORWR	XWMIJYJTVP	6245178475 Dell Way	\N	UBEOYJF	\N	0	Germany	2	XWMIJYJTVP@dell.com	6245178475	3	3248854164499789	2009/04	user14072	password	34	20000	M
14073	ETOBLL	XXTGWDARTV	2127318581 Dell Way	\N	SXJRGPH	\N	0	South Africa	2	XXTGWDARTV@dell.com	2127318581	3	2064688221085816	2010/09	user14073	password	40	40000	M
14074	BVZMHX	KBDGEEYXZR	2145002716 Dell Way	\N	UJIBYPX	\N	0	Australia	2	KBDGEEYXZR@dell.com	2145002716	1	5565938546322287	2012/05	user14074	password	76	100000	F
14075	QUWXRG	ZVNDZLBZCW	8808813814 Dell Way	\N	JLXHAVJ	\N	0	Canada	2	ZVNDZLBZCW@dell.com	8808813814	5	1319914575200527	2009/09	user14075	password	79	60000	F
14076	QMGITF	DGIDSJDUGM	9916580923 Dell Way	\N	FETGZDK	\N	0	South Africa	2	DGIDSJDUGM@dell.com	9916580923	3	1580138122662902	2011/04	user14076	password	66	100000	M
14077	DFGWKK	DTNVDQPJDV	9452928518 Dell Way	\N	NXCNAMJ	\N	0	Australia	2	DTNVDQPJDV@dell.com	9452928518	3	7014671179000289	2009/02	user14077	password	64	20000	F
14078	WKCGUF	ZIADZQMCLA	4013041098 Dell Way	\N	ZNNZAXA	\N	0	UK	2	ZIADZQMCLA@dell.com	4013041098	4	2743066406343132	2010/04	user14078	password	43	80000	F
14079	TTKOZK	WAOVQAXCBX	6180127660 Dell Way	\N	QOXQMXP	\N	0	Russia	2	WAOVQAXCBX@dell.com	6180127660	5	3103151952382177	2012/02	user14079	password	83	20000	M
14080	RMMQXI	QLEHMBJNZA	1601895221 Dell Way	\N	CWROTGJ	\N	0	China	2	QLEHMBJNZA@dell.com	1601895221	3	3100005344022065	2009/06	user14080	password	39	20000	F
14081	TPURYL	CCSOECCDCE	6842261905 Dell Way	\N	ATSUABD	\N	0	Australia	2	CCSOECCDCE@dell.com	6842261905	2	3869599774945527	2008/08	user14081	password	51	40000	F
14082	BBBAME	DFTHIVLLAM	7623180870 Dell Way	\N	FSGFUJI	\N	0	France	2	DFTHIVLLAM@dell.com	7623180870	4	6131696977652610	2009/02	user14082	password	79	80000	F
14083	XWEKBH	PUPYQBJQNO	7525743919 Dell Way	\N	JUUDDCP	\N	0	South Africa	2	PUPYQBJQNO@dell.com	7525743919	1	3414966025855392	2012/12	user14083	password	22	100000	M
14084	YEHZMX	UBVKDFAQTJ	3308606023 Dell Way	\N	KNNOQCL	\N	0	China	2	UBVKDFAQTJ@dell.com	3308606023	4	2526499310042709	2009/10	user14084	password	29	20000	M
14085	ILSUJM	WEWZKXQDHA	7642695634 Dell Way	\N	RVPHXAQ	\N	0	Canada	2	WEWZKXQDHA@dell.com	7642695634	5	4819419415201992	2010/12	user14085	password	59	40000	F
14086	AYCJKY	OHYYFOCNPT	5695964789 Dell Way	\N	IEBFFSK	\N	0	UK	2	OHYYFOCNPT@dell.com	5695964789	5	5125134279485792	2010/05	user14086	password	68	80000	F
14087	QXUBWI	IUHOJJBYCJ	8366266933 Dell Way	\N	CEPIWZG	\N	0	China	2	IUHOJJBYCJ@dell.com	8366266933	4	8912385651841761	2009/05	user14087	password	67	80000	F
14088	OKCKTK	FAZOJAMMKP	9127900111 Dell Way	\N	QZXMZEW	\N	0	Russia	2	FAZOJAMMKP@dell.com	9127900111	4	1082110083196312	2009/06	user14088	password	64	40000	M
14089	BLKVVP	VVEFVQRFGH	4791769113 Dell Way	\N	FEUEIRZ	\N	0	Chile	2	VVEFVQRFGH@dell.com	4791769113	5	6035837949719281	2012/08	user14089	password	84	100000	M
14090	IGMEWI	ZANVREBXMG	4233537689 Dell Way	\N	BHKKYKR	\N	0	China	2	ZANVREBXMG@dell.com	4233537689	2	2990624093450606	2012/02	user14090	password	22	80000	F
14091	IDQELQ	FYMWDNUQUW	2425876368 Dell Way	\N	XFHWPYG	\N	0	UK	2	FYMWDNUQUW@dell.com	2425876368	3	9250347390770912	2009/07	user14091	password	59	80000	M
14092	SKADBG	CNDGBYXVUU	4134472114 Dell Way	\N	ABRPAXN	\N	0	Canada	2	CNDGBYXVUU@dell.com	4134472114	3	5137837116606534	2012/01	user14092	password	33	80000	M
14093	PTWRZZ	EDGFBDBVYB	6713974928 Dell Way	\N	XPQYMEC	\N	0	South Africa	2	EDGFBDBVYB@dell.com	6713974928	3	7364917301107199	2011/10	user14093	password	48	40000	F
14094	EGBEGF	HMLIQMEOOC	7308952083 Dell Way	\N	EEAQJDM	\N	0	Australia	2	HMLIQMEOOC@dell.com	7308952083	1	6949167682789267	2010/08	user14094	password	20	100000	M
14095	HXYODF	APORCSFQVJ	7184552357 Dell Way	\N	VWAFZMF	\N	0	Japan	2	APORCSFQVJ@dell.com	7184552357	5	2502160333562642	2009/11	user14095	password	20	20000	F
14096	YATCFU	STLUMQLIAG	5632516728 Dell Way	\N	EALENRV	\N	0	Chile	2	STLUMQLIAG@dell.com	5632516728	1	5618228554725647	2010/01	user14096	password	60	80000	F
14097	PJDVDV	POQBFCKFIO	6052225161 Dell Way	\N	GUSULOZ	\N	0	UK	2	POQBFCKFIO@dell.com	6052225161	3	4461366304662079	2011/02	user14097	password	90	80000	M
14098	ITMMOB	AFDFHNKQBR	9198366146 Dell Way	\N	LULXIKW	\N	0	South Africa	2	AFDFHNKQBR@dell.com	9198366146	2	5555651189293713	2012/03	user14098	password	26	80000	M
14099	WDBLFB	QIGYWROYIA	1015711206 Dell Way	\N	STXBETY	\N	0	Australia	2	QIGYWROYIA@dell.com	1015711206	3	1714457291178405	2009/07	user14099	password	72	100000	F
14100	XWWCYN	LFLHXAFGAY	4450461574 Dell Way	\N	ZXZERYG	\N	0	Japan	2	LFLHXAFGAY@dell.com	4450461574	2	9146819357294590	2012/01	user14100	password	71	40000	M
14101	QGCOTN	UEVRFBXFZX	6958187243 Dell Way	\N	CZBTXIL	\N	0	Chile	2	UEVRFBXFZX@dell.com	6958187243	2	3149651524145156	2011/01	user14101	password	64	80000	M
14102	XUGQIA	VDSAEPGENI	8877973228 Dell Way	\N	DPCAXOI	\N	0	Germany	2	VDSAEPGENI@dell.com	8877973228	3	3805237990338355	2012/03	user14102	password	20	80000	F
14103	VWSEXO	HPOMFVRSDU	7380151280 Dell Way	\N	HGVEUET	\N	0	Japan	2	HPOMFVRSDU@dell.com	7380151280	1	6590653827413917	2012/02	user14103	password	36	100000	M
14104	DRCAFK	QUXVPONTJV	8382768997 Dell Way	\N	AFZVJTM	\N	0	Australia	2	QUXVPONTJV@dell.com	8382768997	1	9766028807964176	2012/05	user14104	password	86	100000	F
14105	PYNVJE	QGZFVNZFIZ	4752919222 Dell Way	\N	LIVUCHW	\N	0	UK	2	QGZFVNZFIZ@dell.com	4752919222	5	8418066055513919	2011/10	user14105	password	67	40000	F
14106	QVFZZW	GZCCMBHVBS	3161833363 Dell Way	\N	DWNGEKD	\N	0	Japan	2	GZCCMBHVBS@dell.com	3161833363	5	4467839187476784	2008/08	user14106	password	66	60000	F
14107	MRGLNN	KPPXRXSSPW	3003484413 Dell Way	\N	PCDUNGK	\N	0	Russia	2	KPPXRXSSPW@dell.com	3003484413	4	7948453095275909	2012/06	user14107	password	32	20000	M
14108	WKJJYU	YNSQKLJAIY	9415715525 Dell Way	\N	DLTQSDJ	\N	0	UK	2	YNSQKLJAIY@dell.com	9415715525	1	8065520647447557	2009/05	user14108	password	85	40000	F
14109	IROGMN	UFDFQMFYLJ	5646287486 Dell Way	\N	KFZCJJA	\N	0	Chile	2	UFDFQMFYLJ@dell.com	5646287486	4	7097198123577983	2012/09	user14109	password	90	20000	F
14110	RQIEEC	JIIZVNYHWI	3026231256 Dell Way	\N	MWLVGLD	\N	0	Russia	2	JIIZVNYHWI@dell.com	3026231256	5	6567038762383164	2012/10	user14110	password	68	100000	F
14111	IIQNLA	VTAQHYXEHJ	2383764924 Dell Way	\N	ASFGEJA	\N	0	China	2	VTAQHYXEHJ@dell.com	2383764924	4	3982421172317118	2012/04	user14111	password	42	60000	M
14112	QBECBZ	VBQCANGIXH	3090143343 Dell Way	\N	BDOFMPP	\N	0	Japan	2	VBQCANGIXH@dell.com	3090143343	5	6177276446949691	2010/04	user14112	password	90	40000	M
14113	BJZDJV	FZYFNFOKNP	4033135672 Dell Way	\N	OBUARKQ	\N	0	South Africa	2	FZYFNFOKNP@dell.com	4033135672	2	5145384986884892	2011/03	user14113	password	67	60000	F
14114	BNKLIP	KHUYMIIZYW	7731438945 Dell Way	\N	BTXSDNQ	\N	0	France	2	KHUYMIIZYW@dell.com	7731438945	1	1753545957151800	2012/10	user14114	password	61	40000	M
14115	DQGLFR	TAPFJYFHVG	7090288459 Dell Way	\N	BSZEGPR	\N	0	UK	2	TAPFJYFHVG@dell.com	7090288459	4	9633037270046772	2010/05	user14115	password	31	40000	F
14116	VOYAFR	AVWKUBSPIT	4127943521 Dell Way	\N	IHYPXPP	\N	0	Germany	2	AVWKUBSPIT@dell.com	4127943521	3	1100382682401686	2011/09	user14116	password	38	20000	M
14117	VCOBTP	XQZRSSHALP	3810785967 Dell Way	\N	IJEFYUU	\N	0	China	2	XQZRSSHALP@dell.com	3810785967	5	1014167503453791	2008/02	user14117	password	30	60000	M
14118	GDZATW	RTNJLVKWKT	5962707382 Dell Way	\N	FPYEKTM	\N	0	Japan	2	RTNJLVKWKT@dell.com	5962707382	3	7640001782681794	2011/08	user14118	password	41	60000	M
14119	LNYFJQ	YXZJSKGDDM	6587566391 Dell Way	\N	TCRDVDV	\N	0	China	2	YXZJSKGDDM@dell.com	6587566391	3	1245609020348638	2009/11	user14119	password	60	20000	F
14120	CDOMUM	KTWCECGHPZ	5800626676 Dell Way	\N	JGDFJZP	\N	0	UK	2	KTWCECGHPZ@dell.com	5800626676	4	3457184167578816	2010/03	user14120	password	52	80000	F
14121	QIUKUF	ERIIUOPJOZ	4716067548 Dell Way	\N	PREZQUZ	\N	0	Canada	2	ERIIUOPJOZ@dell.com	4716067548	2	6470715657807887	2011/09	user14121	password	45	100000	F
14122	STTNYX	EGFYUVIJUY	2352602525 Dell Way	\N	BZXSUXX	\N	0	Canada	2	EGFYUVIJUY@dell.com	2352602525	3	8264258467592300	2012/11	user14122	password	72	40000	M
14123	MZBKWG	RCFMXNVSMW	9801145910 Dell Way	\N	SJPMHMR	\N	0	France	2	RCFMXNVSMW@dell.com	9801145910	3	3763776734471321	2012/03	user14123	password	57	60000	M
14124	NMCKTU	MYGKMCCYZV	4653771001 Dell Way	\N	IOHPAYB	\N	0	Australia	2	MYGKMCCYZV@dell.com	4653771001	2	8784722724463792	2011/11	user14124	password	39	40000	F
14125	UKUNFG	MLRYNUXNPG	3189549596 Dell Way	\N	BWWCVXC	\N	0	Chile	2	MLRYNUXNPG@dell.com	3189549596	5	8576960394158960	2008/04	user14125	password	28	60000	F
14126	OHOTOB	FGZTAXGQDH	5160767002 Dell Way	\N	MZKIXMO	\N	0	Canada	2	FGZTAXGQDH@dell.com	5160767002	2	3334419276565313	2011/07	user14126	password	75	80000	F
14127	CIWRJC	XJVYGCOKKB	3711582501 Dell Way	\N	KUJHHXL	\N	0	Russia	2	XJVYGCOKKB@dell.com	3711582501	4	5224965009372682	2012/06	user14127	password	34	100000	M
14128	OVFXXD	GTBNVPYGQJ	7794186857 Dell Way	\N	AZQIXBB	\N	0	Chile	2	GTBNVPYGQJ@dell.com	7794186857	3	1432454805821180	2009/10	user14128	password	90	80000	F
14129	VZFSCM	MDAHTZNJIO	5487386555 Dell Way	\N	JYWHAYM	\N	0	Russia	2	MDAHTZNJIO@dell.com	5487386555	3	1058868742082268	2009/07	user14129	password	75	60000	F
14130	UUBWHN	AHVUGJDOXN	8246910660 Dell Way	\N	NUUOTHI	\N	0	Chile	2	AHVUGJDOXN@dell.com	8246910660	2	5683670150581748	2009/02	user14130	password	24	80000	M
14131	XSUEGV	LBPSKTHIGV	1569503348 Dell Way	\N	DBJWISD	\N	0	Canada	2	LBPSKTHIGV@dell.com	1569503348	4	5106901322491467	2008/10	user14131	password	26	20000	M
14132	VXUCSG	DIZNBGWIBZ	6821494726 Dell Way	\N	JKWRDZV	\N	0	Canada	2	DIZNBGWIBZ@dell.com	6821494726	2	4535740788094700	2009/05	user14132	password	54	20000	F
14133	KVICCL	KBZMHVUJUE	9281177723 Dell Way	\N	URVXRQC	\N	0	China	2	KBZMHVUJUE@dell.com	9281177723	3	7310408766381443	2009/12	user14133	password	71	60000	F
14134	OWMRHX	SGJACEJXID	6749672582 Dell Way	\N	OEBFVDN	\N	0	Russia	2	SGJACEJXID@dell.com	6749672582	2	1540829687379300	2011/12	user14134	password	61	20000	M
14135	LMFTKX	ZUYCYHZHLO	5579101315 Dell Way	\N	MMTHQHB	\N	0	Chile	2	ZUYCYHZHLO@dell.com	5579101315	1	9028566126246006	2010/09	user14135	password	83	20000	F
14136	KFXUCX	OAZNIZVTNH	7874245746 Dell Way	\N	GHPWOQD	\N	0	Australia	2	OAZNIZVTNH@dell.com	7874245746	1	5792758830823005	2010/12	user14136	password	56	80000	F
14137	SNDVLS	WKFFJBZWJF	3261459981 Dell Way	\N	DYCSPFT	\N	0	China	2	WKFFJBZWJF@dell.com	3261459981	2	8628085418604315	2008/11	user14137	password	53	60000	M
14138	AQKLIH	WNMGPLCYRG	1321486726 Dell Way	\N	XUZNZTW	\N	0	Chile	2	WNMGPLCYRG@dell.com	1321486726	4	4859494392294437	2012/03	user14138	password	85	60000	F
14139	OVRWCO	KPUZBXYTEV	9533919140 Dell Way	\N	NDINWFT	\N	0	UK	2	KPUZBXYTEV@dell.com	9533919140	1	7982479108497501	2008/02	user14139	password	33	40000	M
14140	BCNEQX	TLWVIVOMQB	5776971859 Dell Way	\N	QZONFIK	\N	0	Canada	2	TLWVIVOMQB@dell.com	5776971859	1	3744444042444229	2011/05	user14140	password	69	40000	F
14141	UVPLTJ	WQEELSRBTI	4592037249 Dell Way	\N	BIVGRFJ	\N	0	Chile	2	WQEELSRBTI@dell.com	4592037249	4	8773475459311158	2011/05	user14141	password	31	40000	F
14142	AVPTEL	JIQUAIWUQX	2655315377 Dell Way	\N	DLDVRNA	\N	0	Australia	2	JIQUAIWUQX@dell.com	2655315377	5	8635840279981495	2010/01	user14142	password	23	80000	F
14143	XJVBUF	JLZKUWFKTJ	1956967974 Dell Way	\N	WWENKFO	\N	0	Germany	2	JLZKUWFKTJ@dell.com	1956967974	3	2246492275036871	2008/06	user14143	password	82	40000	F
14144	FCLAIV	MIGGELRYUN	1022285607 Dell Way	\N	VZAFEPU	\N	0	Chile	2	MIGGELRYUN@dell.com	1022285607	5	5274151525925845	2010/10	user14144	password	72	100000	F
14145	WIBEDN	MKURVMPQZK	3596208131 Dell Way	\N	QAPUPJC	\N	0	Germany	2	MKURVMPQZK@dell.com	3596208131	3	1782403630204498	2008/04	user14145	password	88	20000	F
14146	HDJLRW	VMNRYDHXOX	4394713289 Dell Way	\N	YDSNNVC	\N	0	South Africa	2	VMNRYDHXOX@dell.com	4394713289	2	9085707014426590	2011/02	user14146	password	90	100000	F
14147	DGWVCR	HQIGTQEHOC	9256457433 Dell Way	\N	LHPZCSU	\N	0	France	2	HQIGTQEHOC@dell.com	9256457433	4	2390604088082909	2008/09	user14147	password	20	60000	M
14148	GKQJCY	ZLESBIZQKL	9053743611 Dell Way	\N	XAKZSFL	\N	0	Japan	2	ZLESBIZQKL@dell.com	9053743611	4	7485070428811014	2010/08	user14148	password	35	40000	M
14149	QAGTZF	EDXGLXWWJU	8308234650 Dell Way	\N	WTTPYFF	\N	0	South Africa	2	EDXGLXWWJU@dell.com	8308234650	5	4900867818389088	2010/03	user14149	password	78	40000	M
14150	WOOVUT	ZRZKPVHYQD	9198285273 Dell Way	\N	SJTRPZN	\N	0	China	2	ZRZKPVHYQD@dell.com	9198285273	5	8563074468169362	2008/10	user14150	password	30	100000	M
14151	TNMNGL	FFWUBDSRHL	5900445620 Dell Way	\N	BACQZPB	\N	0	South Africa	2	FFWUBDSRHL@dell.com	5900445620	5	9991097362712028	2009/01	user14151	password	86	100000	M
14152	LLISXN	YTHZXARELT	3705568918 Dell Way	\N	FOJEDKB	\N	0	Japan	2	YTHZXARELT@dell.com	3705568918	1	1037268954794853	2009/01	user14152	password	88	20000	F
14153	KLEHZD	BGDYHUDTNI	7013533239 Dell Way	\N	HXNKIPC	\N	0	Japan	2	BGDYHUDTNI@dell.com	7013533239	1	9805177350062878	2011/01	user14153	password	27	20000	F
14154	PJUOMW	UPUCJYVXGC	7136640350 Dell Way	\N	VUMDJPT	\N	0	Australia	2	UPUCJYVXGC@dell.com	7136640350	4	7591065373737366	2011/11	user14154	password	83	40000	F
14155	GAZSWU	HRXRPSPWUK	1238195838 Dell Way	\N	RHNAWHC	\N	0	Germany	2	HRXRPSPWUK@dell.com	1238195838	5	3751803902443498	2012/09	user14155	password	57	40000	M
14156	OIRLDZ	CARSSGPNRG	2690592654 Dell Way	\N	VFHRMJG	\N	0	Germany	2	CARSSGPNRG@dell.com	2690592654	3	4678402582183480	2012/02	user14156	password	72	100000	M
14157	COCFNE	GFXZMMNDTI	8072023562 Dell Way	\N	IAZVKGJ	\N	0	Germany	2	GFXZMMNDTI@dell.com	8072023562	4	5479020523838699	2012/07	user14157	password	44	60000	M
14158	XPVLUB	QRBDEOGYWP	6015688998 Dell Way	\N	ZWLJCUZ	\N	0	South Africa	2	QRBDEOGYWP@dell.com	6015688998	3	7819971536751837	2008/10	user14158	password	38	80000	M
14159	WMEROV	IQYNEFLBVK	2975796917 Dell Way	\N	XGUABTX	\N	0	Japan	2	IQYNEFLBVK@dell.com	2975796917	4	7091121076140553	2008/12	user14159	password	42	80000	M
14160	VYLKUU	ASIEXUFTED	7131940693 Dell Way	\N	ZZDBSAQ	\N	0	UK	2	ASIEXUFTED@dell.com	7131940693	2	9847434752620758	2011/09	user14160	password	73	60000	M
14161	SWXMRX	FZCDTIWYLW	8917994188 Dell Way	\N	XPXQQOO	\N	0	China	2	FZCDTIWYLW@dell.com	8917994188	3	9190876668784768	2010/04	user14161	password	41	20000	F
14162	EYMVWS	VYVOGRNSNK	2010267725 Dell Way	\N	HKAXZPF	\N	0	South Africa	2	VYVOGRNSNK@dell.com	2010267725	1	4609070857055485	2010/06	user14162	password	51	60000	M
14163	KXMGPH	ELWLCJDQUL	7335639258 Dell Way	\N	BVJAKOW	\N	0	Germany	2	ELWLCJDQUL@dell.com	7335639258	2	9200169374700636	2008/09	user14163	password	42	80000	F
14164	GGJWNO	HKZJTDZOOB	2540400926 Dell Way	\N	JYBTNXG	\N	0	Chile	2	HKZJTDZOOB@dell.com	2540400926	1	4216528641525656	2012/07	user14164	password	27	20000	M
14165	JJPXXW	HXGBBGPQHZ	2446501902 Dell Way	\N	OITBGZG	\N	0	France	2	HXGBBGPQHZ@dell.com	2446501902	4	3760268321260810	2011/09	user14165	password	40	60000	F
14166	RAAPXH	MDJOKZERYS	6643884830 Dell Way	\N	ARTGRAR	\N	0	South Africa	2	MDJOKZERYS@dell.com	6643884830	5	5415612272918225	2009/04	user14166	password	83	60000	M
14167	XNOUUB	YEPIDTZBMA	9689628037 Dell Way	\N	TFHKGZG	\N	0	South Africa	2	YEPIDTZBMA@dell.com	9689628037	4	3140162178780883	2009/08	user14167	password	71	40000	M
14168	FVIAWG	EMOIGOKSPD	5796957556 Dell Way	\N	YWOEVUB	\N	0	Russia	2	EMOIGOKSPD@dell.com	5796957556	2	1616723411716520	2008/01	user14168	password	40	80000	F
14169	DAHAHM	NWUTKEMZIL	9886031090 Dell Way	\N	WWQSRSM	\N	0	Canada	2	NWUTKEMZIL@dell.com	9886031090	3	4195036855060607	2008/11	user14169	password	22	40000	F
14170	COAJAN	FUHQZUQHFN	3325661918 Dell Way	\N	DWFUOSZ	\N	0	Germany	2	FUHQZUQHFN@dell.com	3325661918	2	5984770814888180	2008/05	user14170	password	77	20000	F
14171	JEWJSC	EZTETJLZWP	7663086499 Dell Way	\N	WBKKTKY	\N	0	Australia	2	EZTETJLZWP@dell.com	7663086499	3	2446046836208552	2008/04	user14171	password	40	80000	M
14172	MNBEPF	EIKYSVXPLU	7004449598 Dell Way	\N	QVEKFDL	\N	0	UK	2	EIKYSVXPLU@dell.com	7004449598	3	1980003875214606	2012/11	user14172	password	72	80000	F
14173	GSOWYS	FIQXEOMPID	6125958240 Dell Way	\N	LNORRZQ	\N	0	China	2	FIQXEOMPID@dell.com	6125958240	4	4118677675258368	2010/06	user14173	password	19	100000	M
14174	TKPSDU	BUSGIEVRHG	3373265525 Dell Way	\N	FVYXVOG	\N	0	China	2	BUSGIEVRHG@dell.com	3373265525	3	8735980004537851	2011/08	user14174	password	70	60000	F
14175	DCCGWD	APJJTFBBMG	9878768469 Dell Way	\N	XKDSYKC	\N	0	Chile	2	APJJTFBBMG@dell.com	9878768469	5	9498715494759382	2011/09	user14175	password	48	100000	M
14176	NBBJFC	YOMSUNUGTR	5203458223 Dell Way	\N	RXKPINU	\N	0	Chile	2	YOMSUNUGTR@dell.com	5203458223	4	9104899544268848	2008/03	user14176	password	81	100000	M
14177	YABDDA	RPTMCNSWEJ	5716779028 Dell Way	\N	UPZCCUK	\N	0	Germany	2	RPTMCNSWEJ@dell.com	5716779028	2	7320521708577872	2011/02	user14177	password	65	40000	F
14178	RKFULX	JEJMRCIWMD	9096084883 Dell Way	\N	LLFOGPC	\N	0	Russia	2	JEJMRCIWMD@dell.com	9096084883	4	5087961134035140	2008/06	user14178	password	77	20000	F
14179	GJYRHH	VRUNTDKGGV	3516980099 Dell Way	\N	SLJYBMS	\N	0	UK	2	VRUNTDKGGV@dell.com	3516980099	1	1268069553654640	2011/12	user14179	password	31	100000	F
14180	OUXWCT	NWGHAQNGMF	1176649967 Dell Way	\N	SWETJWT	\N	0	Japan	2	NWGHAQNGMF@dell.com	1176649967	4	4367147992365062	2012/12	user14180	password	35	40000	M
14181	ACJDVW	ACDATRGGWY	2953461081 Dell Way	\N	DBSMXLD	\N	0	UK	2	ACDATRGGWY@dell.com	2953461081	3	9309887535870076	2008/09	user14181	password	27	80000	M
14182	GBXBXX	EBYXSFEPEH	4445647977 Dell Way	\N	QWTOIXM	\N	0	Germany	2	EBYXSFEPEH@dell.com	4445647977	3	7464665657840670	2008/07	user14182	password	47	100000	M
14183	LUWJSA	KRYDWCTAKK	8655397162 Dell Way	\N	XEYFBLU	\N	0	France	2	KRYDWCTAKK@dell.com	8655397162	3	6021397535689176	2009/11	user14183	password	50	20000	F
14184	GARZBC	QAFMCZMNJJ	8722318156 Dell Way	\N	RIPTTJE	\N	0	Germany	2	QAFMCZMNJJ@dell.com	8722318156	4	9958373934961856	2011/03	user14184	password	30	20000	F
14185	FTKGWA	GBNJBZXKJO	2997759875 Dell Way	\N	SYILIMB	\N	0	Canada	2	GBNJBZXKJO@dell.com	2997759875	1	9318876598961652	2010/03	user14185	password	18	100000	F
14186	TGRPGY	RTISTFDCUV	4683022159 Dell Way	\N	BCHJOJO	\N	0	Russia	2	RTISTFDCUV@dell.com	4683022159	3	2817406029440462	2011/06	user14186	password	20	20000	F
14187	HTVNRN	HAGBFJDZFF	6537604544 Dell Way	\N	CNPRWDL	\N	0	Chile	2	HAGBFJDZFF@dell.com	6537604544	4	9092767254915088	2008/09	user14187	password	88	40000	M
14188	SEMKSU	KYVQIZQNES	5093279560 Dell Way	\N	ATJWXUD	\N	0	Germany	2	KYVQIZQNES@dell.com	5093279560	1	6439679188653827	2008/12	user14188	password	86	20000	M
14189	CPCUKN	TFDBFTOJLP	6564249726 Dell Way	\N	DULAPPN	\N	0	Australia	2	TFDBFTOJLP@dell.com	6564249726	1	2828523810952902	2011/01	user14189	password	40	40000	F
14190	XKZIYS	OBTTVIDGXG	9646577555 Dell Way	\N	BJHRYVS	\N	0	Germany	2	OBTTVIDGXG@dell.com	9646577555	5	2632132764440030	2008/03	user14190	password	54	40000	F
14191	XFMWXA	XRUTAXAYDB	4503987435 Dell Way	\N	HKTGGLV	\N	0	Chile	2	XRUTAXAYDB@dell.com	4503987435	1	3150160205084830	2011/06	user14191	password	51	80000	F
14192	RHHPIF	HCYHZYGDAN	6449265852 Dell Way	\N	OTUUFPZ	\N	0	Germany	2	HCYHZYGDAN@dell.com	6449265852	2	2978085109964013	2008/09	user14192	password	19	60000	F
14193	HUYPZF	SXMRWSUWGI	3975803588 Dell Way	\N	PBDUQCJ	\N	0	Chile	2	SXMRWSUWGI@dell.com	3975803588	3	4251837085932493	2008/08	user14193	password	82	40000	M
14194	RHNRMF	PZXLSSHYAX	6912595058 Dell Way	\N	AERQGBX	\N	0	Germany	2	PZXLSSHYAX@dell.com	6912595058	2	6476715357042850	2009/02	user14194	password	88	20000	M
14195	GSNSYC	SVOKNWIOTI	2581273052 Dell Way	\N	SLZZMXP	\N	0	Canada	2	SVOKNWIOTI@dell.com	2581273052	1	4773829518817365	2009/02	user14195	password	62	20000	F
14196	IRDGUV	CJFPFOEYXX	6845754271 Dell Way	\N	KXWWULA	\N	0	UK	2	CJFPFOEYXX@dell.com	6845754271	3	3781554851680994	2012/01	user14196	password	53	40000	F
14197	EIQZDS	IJHNXMMUJW	3202546316 Dell Way	\N	SGTMSUM	\N	0	China	2	IJHNXMMUJW@dell.com	3202546316	4	2481377312447876	2009/04	user14197	password	44	80000	F
14198	SHKVZS	EHGCTSXDPP	4087420854 Dell Way	\N	KJCCEOM	\N	0	France	2	EHGCTSXDPP@dell.com	4087420854	4	7364648832939566	2011/12	user14198	password	45	20000	M
14199	RLNQDS	YKVSCSVSHG	4835178650 Dell Way	\N	CJIGYUR	\N	0	Chile	2	YKVSCSVSHG@dell.com	4835178650	2	8970453511457891	2010/09	user14199	password	85	20000	F
14200	JQBNJZ	XERAWNSETV	1749451757 Dell Way	\N	OCBMWST	\N	0	China	2	XERAWNSETV@dell.com	1749451757	4	7520985035691411	2012/07	user14200	password	79	40000	M
14201	MGLWGI	AXIXLBBEWQ	5608129585 Dell Way	\N	GYCDQWL	\N	0	Russia	2	AXIXLBBEWQ@dell.com	5608129585	1	5996411291882396	2008/12	user14201	password	74	20000	F
14202	BLIHUJ	FDGQEIVBYB	7975613998 Dell Way	\N	ZBEQYQJ	\N	0	France	2	FDGQEIVBYB@dell.com	7975613998	5	5693792082369328	2011/09	user14202	password	57	40000	M
14203	ZOAUXG	XEWBNRDLTC	1059557051 Dell Way	\N	NYTLOCW	\N	0	China	2	XEWBNRDLTC@dell.com	1059557051	3	1949634986929595	2011/12	user14203	password	43	60000	M
14204	XMSVSP	APRNHUYAXM	2790379907 Dell Way	\N	ZQXNSUW	\N	0	Russia	2	APRNHUYAXM@dell.com	2790379907	5	4857063481118530	2008/04	user14204	password	81	20000	F
14205	JTCBJC	RAPYVOZSAY	3875779496 Dell Way	\N	IYMBTIU	\N	0	UK	2	RAPYVOZSAY@dell.com	3875779496	2	1702846955507993	2011/02	user14205	password	28	100000	F
14206	XZMGBE	HQCCFBUFZD	2924762803 Dell Way	\N	ELFXUZW	\N	0	Canada	2	HQCCFBUFZD@dell.com	2924762803	5	7915464698802681	2009/01	user14206	password	66	80000	M
14207	QGGRKN	IMPNNKTNOY	6894119068 Dell Way	\N	ZUWUUSX	\N	0	UK	2	IMPNNKTNOY@dell.com	6894119068	4	3597309782169759	2011/05	user14207	password	20	80000	M
14208	GYRRMZ	DCNRNHFBGE	5932466959 Dell Way	\N	WCZQVWP	\N	0	France	2	DCNRNHFBGE@dell.com	5932466959	5	2845325394533574	2012/12	user14208	password	85	100000	F
14209	WNVINZ	KARYIWZOAV	9642907677 Dell Way	\N	RZMMWBZ	\N	0	France	2	KARYIWZOAV@dell.com	9642907677	1	3731241752859205	2012/02	user14209	password	29	20000	M
14210	RXHEXS	FOQNKQCLMU	4498813701 Dell Way	\N	LYGIAFT	\N	0	UK	2	FOQNKQCLMU@dell.com	4498813701	1	8679980442393572	2010/03	user14210	password	85	60000	M
14211	VSATLF	HBTSSVDFPP	7236412101 Dell Way	\N	DWXDCQD	\N	0	France	2	HBTSSVDFPP@dell.com	7236412101	5	9594898441340776	2012/11	user14211	password	45	80000	M
14212	CTMNZT	PSMIOPNEFQ	9046628201 Dell Way	\N	BDUDUXQ	\N	0	France	2	PSMIOPNEFQ@dell.com	9046628201	3	4225272173527628	2011/12	user14212	password	25	60000	F
14213	WZPWTF	OFNDVAHARJ	7072636967 Dell Way	\N	EMMYKCK	\N	0	Chile	2	OFNDVAHARJ@dell.com	7072636967	4	1737667267210781	2011/11	user14213	password	62	80000	M
14214	PHPIME	OZHJAPKSYO	6859258913 Dell Way	\N	ELMPNXW	\N	0	Chile	2	OZHJAPKSYO@dell.com	6859258913	5	8521847323048861	2010/07	user14214	password	56	40000	F
14215	UVMHZA	HHKHWUAVJE	6376239157 Dell Way	\N	GVTUSQZ	\N	0	China	2	HHKHWUAVJE@dell.com	6376239157	5	9010210101958364	2008/05	user14215	password	28	40000	F
14216	ZUKZVR	GFZDAZYJEF	8238444024 Dell Way	\N	FYZXPZH	\N	0	Canada	2	GFZDAZYJEF@dell.com	8238444024	1	4012204186525196	2008/04	user14216	password	64	40000	F
14217	LSHGKN	MKRNJPWOVB	5142878378 Dell Way	\N	MVZBUHG	\N	0	Germany	2	MKRNJPWOVB@dell.com	5142878378	3	7698640278074891	2011/03	user14217	password	20	20000	M
14218	TJXEXK	OOXXEUMZVY	8426463993 Dell Way	\N	UVAPCGE	\N	0	Germany	2	OOXXEUMZVY@dell.com	8426463993	5	4142058562487364	2008/12	user14218	password	49	80000	M
14219	UQWRAL	GYIKSUKOTF	9012242093 Dell Way	\N	JTUMAZB	\N	0	South Africa	2	GYIKSUKOTF@dell.com	9012242093	2	8850335353054107	2012/10	user14219	password	59	60000	M
14220	ELIFWO	DFZVAJJTOT	6972449709 Dell Way	\N	NJGNIHJ	\N	0	Chile	2	DFZVAJJTOT@dell.com	6972449709	2	1562203930225223	2010/10	user14220	password	64	20000	M
14221	CLEZZI	EZEFIOZXHM	6381794004 Dell Way	\N	GNAOVJU	\N	0	France	2	EZEFIOZXHM@dell.com	6381794004	5	9662544532213360	2009/06	user14221	password	23	40000	M
14222	NONNXS	MBYVPXSXKZ	2529753034 Dell Way	\N	LKOGUIS	\N	0	China	2	MBYVPXSXKZ@dell.com	2529753034	4	7919114858377726	2011/09	user14222	password	28	40000	F
14223	STUPMG	QKBGHUDRTO	2520065176 Dell Way	\N	CHUWQMG	\N	0	South Africa	2	QKBGHUDRTO@dell.com	2520065176	1	5079928232356906	2012/02	user14223	password	67	20000	M
14224	LYMXFC	IHJQBMIVAK	5809430985 Dell Way	\N	DVHTINO	\N	0	France	2	IHJQBMIVAK@dell.com	5809430985	1	4715984534006566	2011/09	user14224	password	61	60000	F
14225	OAATDJ	AMZCZHXARA	4111494669 Dell Way	\N	VZUEMIR	\N	0	Australia	2	AMZCZHXARA@dell.com	4111494669	1	7444784479215742	2008/09	user14225	password	38	20000	F
14226	IEZLNA	YNCYUAYMAU	7141119807 Dell Way	\N	LUYYDPY	\N	0	France	2	YNCYUAYMAU@dell.com	7141119807	4	5633299602195621	2009/12	user14226	password	66	60000	F
14227	VOSJOR	WQQRRODRJP	2413218567 Dell Way	\N	MINQXMC	\N	0	Japan	2	WQQRRODRJP@dell.com	2413218567	4	9560756078921260	2008/04	user14227	password	55	40000	F
14228	BCNQUJ	HKBYZFPIUC	4961287044 Dell Way	\N	QISOUVE	\N	0	UK	2	HKBYZFPIUC@dell.com	4961287044	1	1603196725714951	2011/08	user14228	password	50	100000	M
14229	OJIITP	TUNTZDCTFS	6294288548 Dell Way	\N	CYHWTMV	\N	0	Chile	2	TUNTZDCTFS@dell.com	6294288548	5	9341556549537928	2009/05	user14229	password	74	100000	M
14230	DGGWWZ	QKSQNUJTNM	1710237702 Dell Way	\N	SVIMHER	\N	0	South Africa	2	QKSQNUJTNM@dell.com	1710237702	3	1980310522951185	2010/05	user14230	password	21	40000	M
14231	IOJEOA	OHQCBAWPMO	3742053540 Dell Way	\N	LVASASP	\N	0	Australia	2	OHQCBAWPMO@dell.com	3742053540	4	5539525757078082	2011/10	user14231	password	78	20000	F
14232	JOGYOU	FFXGGTWSIH	3832882940 Dell Way	\N	NJANBPQ	\N	0	China	2	FFXGGTWSIH@dell.com	3832882940	1	1506178824231028	2008/12	user14232	password	35	20000	F
14233	UJGJDL	PBSVVPNDWB	4114940783 Dell Way	\N	NXPONFY	\N	0	South Africa	2	PBSVVPNDWB@dell.com	4114940783	1	8946195147931577	2009/04	user14233	password	18	80000	F
14234	JWLNIA	OAVJQJNNLA	5983722615 Dell Way	\N	KBPXHOS	\N	0	Japan	2	OAVJQJNNLA@dell.com	5983722615	4	9251995398662984	2012/08	user14234	password	57	100000	M
14235	KHMSHB	TDLKNYXZZH	5709499127 Dell Way	\N	AOFHDXX	\N	0	Japan	2	TDLKNYXZZH@dell.com	5709499127	5	5293111558537930	2008/05	user14235	password	42	20000	M
14236	QPNYQH	BCRPAOOAWO	6663146770 Dell Way	\N	PBWSZUJ	\N	0	Germany	2	BCRPAOOAWO@dell.com	6663146770	5	6857153425458819	2008/03	user14236	password	73	80000	M
14237	JHTZPV	BGKCVYDSNS	6606406147 Dell Way	\N	UKKUFUH	\N	0	South Africa	2	BGKCVYDSNS@dell.com	6606406147	5	8468002383597196	2012/09	user14237	password	62	80000	F
14238	XJBMED	TOFPNJHBBB	1739669905 Dell Way	\N	LLWRFDM	\N	0	South Africa	2	TOFPNJHBBB@dell.com	1739669905	2	6855814764276148	2011/12	user14238	password	37	100000	M
14239	PWITZC	IFRVOZXPBJ	8210748238 Dell Way	\N	BXAHAMD	\N	0	Canada	2	IFRVOZXPBJ@dell.com	8210748238	4	9047803184948862	2011/01	user14239	password	70	60000	M
14240	PXKPAT	UROJRMZSVA	2774227749 Dell Way	\N	PVHQILT	\N	0	Canada	2	UROJRMZSVA@dell.com	2774227749	4	8608653262723238	2009/05	user14240	password	48	100000	M
14241	IHNIAI	APRRBQKXRZ	9898798740 Dell Way	\N	SYPAKJD	\N	0	Germany	2	APRRBQKXRZ@dell.com	9898798740	5	8345852632075549	2009/05	user14241	password	68	40000	M
14242	ZVBADC	PUURLEOCDH	5063224444 Dell Way	\N	BTILCLA	\N	0	Australia	2	PUURLEOCDH@dell.com	5063224444	5	4975052849855274	2012/07	user14242	password	71	60000	M
14243	ORORTE	MNVYSKBVSC	5033808067 Dell Way	\N	PAOSMPU	\N	0	UK	2	MNVYSKBVSC@dell.com	5033808067	2	8085214603692294	2012/12	user14243	password	46	60000	M
14244	BBFVGS	JCRBMSXFVM	2979984662 Dell Way	\N	FJERZZQ	\N	0	France	2	JCRBMSXFVM@dell.com	2979984662	3	4780552974436432	2008/10	user14244	password	87	80000	M
14245	AYRGQA	IIBVAYAVLG	9622980775 Dell Way	\N	FQYEPOP	\N	0	South Africa	2	IIBVAYAVLG@dell.com	9622980775	1	1228928240947425	2011/12	user14245	password	72	60000	F
14246	RGGIGP	QILRHMMTTS	5813292515 Dell Way	\N	JRXZFNU	\N	0	Canada	2	QILRHMMTTS@dell.com	5813292515	5	9357852675020696	2010/07	user14246	password	55	60000	F
14247	TUPAKG	JVXQIKJBCT	4211183983 Dell Way	\N	SZSYNND	\N	0	Australia	2	JVXQIKJBCT@dell.com	4211183983	1	5975083400961012	2012/07	user14247	password	23	20000	F
14248	WUJGBT	CZJKJTMMNE	3839314579 Dell Way	\N	MFDZTGA	\N	0	Canada	2	CZJKJTMMNE@dell.com	3839314579	3	1364291417412459	2012/08	user14248	password	35	40000	M
14249	APTCIW	BSGKMSXZXJ	9569718596 Dell Way	\N	FAJYHJB	\N	0	Japan	2	BSGKMSXZXJ@dell.com	9569718596	1	5500106831546873	2010/05	user14249	password	71	20000	F
14250	IWMRSN	JYYWRVVPFB	2350433988 Dell Way	\N	QOZXYBN	\N	0	UK	2	JYYWRVVPFB@dell.com	2350433988	1	5524823115207255	2010/10	user14250	password	62	100000	F
14251	LITEVD	DUZVPVKVWA	5446255031 Dell Way	\N	KWYIXMG	\N	0	Australia	2	DUZVPVKVWA@dell.com	5446255031	4	5897391184233130	2009/05	user14251	password	47	40000	M
14252	TCZOGC	IFXYBITXID	5425766797 Dell Way	\N	TGMRTTS	\N	0	Chile	2	IFXYBITXID@dell.com	5425766797	2	5304609962273389	2012/09	user14252	password	78	80000	F
14253	YQZETI	KRHLZBIHEC	8121513302 Dell Way	\N	ORUHLNN	\N	0	UK	2	KRHLZBIHEC@dell.com	8121513302	5	7888759385328741	2010/10	user14253	password	49	100000	M
14254	BWXVFH	MMSLNBTSEI	2199395501 Dell Way	\N	KZPVMDT	\N	0	Chile	2	MMSLNBTSEI@dell.com	2199395501	3	7761615272611380	2012/12	user14254	password	64	80000	F
14255	NPVSXH	FQTSSNLWVV	9318178210 Dell Way	\N	WLRIOKP	\N	0	Japan	2	FQTSSNLWVV@dell.com	9318178210	2	6870958910323680	2012/01	user14255	password	43	100000	M
14256	ZSGWAL	MTEEGPBBLX	3044794317 Dell Way	\N	NCGBNWT	\N	0	France	2	MTEEGPBBLX@dell.com	3044794317	3	3616034212056547	2009/10	user14256	password	29	80000	M
14257	WZPWKC	QOGWEIYPGL	7376229458 Dell Way	\N	RMNEJHP	\N	0	Germany	2	QOGWEIYPGL@dell.com	7376229458	5	8281410800293089	2010/01	user14257	password	58	40000	M
14258	OVUZXK	OEHSNGHTRZ	7202612449 Dell Way	\N	GFEPNUE	\N	0	Chile	2	OEHSNGHTRZ@dell.com	7202612449	5	7246052945498378	2011/07	user14258	password	84	80000	F
14259	SMAQWO	UEHHKPBCOH	9778457611 Dell Way	\N	HTWUNAA	\N	0	Chile	2	UEHHKPBCOH@dell.com	9778457611	4	9702982508577408	2010/08	user14259	password	65	60000	F
14260	DPZAET	ELBOBCQPJY	5302745194 Dell Way	\N	IFTWGTB	\N	0	Chile	2	ELBOBCQPJY@dell.com	5302745194	1	7393789013847709	2008/09	user14260	password	38	60000	M
14261	XKVBEA	NGOOJFESEN	5443325920 Dell Way	\N	YYJERLK	\N	0	Canada	2	NGOOJFESEN@dell.com	5443325920	1	3415333111304790	2008/05	user14261	password	69	20000	F
14262	DVIIVW	OKLXQPQUDP	3540232776 Dell Way	\N	SNUKZEP	\N	0	France	2	OKLXQPQUDP@dell.com	3540232776	5	6786532375030220	2011/07	user14262	password	65	100000	M
14263	MHAIEO	SPMJFCDISW	7413272592 Dell Way	\N	WMHVRWH	\N	0	UK	2	SPMJFCDISW@dell.com	7413272592	5	6553092298097909	2009/07	user14263	password	59	100000	F
14264	WZJANC	PALVDPEVLA	1257696562 Dell Way	\N	ISVZPCY	\N	0	China	2	PALVDPEVLA@dell.com	1257696562	3	6184133359231055	2010/02	user14264	password	57	80000	M
14265	NAZBCP	BNKECOZOPI	7979347704 Dell Way	\N	HLHWOFE	\N	0	Germany	2	BNKECOZOPI@dell.com	7979347704	4	2542440080549568	2012/04	user14265	password	77	100000	M
14266	VVWXKX	LVBOKBDZJK	2879248281 Dell Way	\N	LRHZXLO	\N	0	Japan	2	LVBOKBDZJK@dell.com	2879248281	4	6153476397506893	2010/07	user14266	password	48	40000	F
14267	GEHQBS	LDHVEKVOUG	5427911898 Dell Way	\N	GCFEOUW	\N	0	Russia	2	LDHVEKVOUG@dell.com	5427911898	3	3337709529791027	2008/11	user14267	password	59	40000	F
14268	SQSUJE	XQACBVQWCX	4046456171 Dell Way	\N	YHBMBXG	\N	0	Germany	2	XQACBVQWCX@dell.com	4046456171	3	6339595664758236	2008/01	user14268	password	89	40000	M
14269	QZOZDM	QEORZFNCCM	7333766368 Dell Way	\N	KEYLBFA	\N	0	France	2	QEORZFNCCM@dell.com	7333766368	4	6337339868303389	2011/08	user14269	password	80	60000	F
14270	VDFZPV	DENDJBFLNP	7442331045 Dell Way	\N	QLBRRCC	\N	0	China	2	DENDJBFLNP@dell.com	7442331045	4	2217706061899662	2009/07	user14270	password	69	60000	F
14271	WTJMON	QCRZDWLQMB	5954418987 Dell Way	\N	COTTRWC	\N	0	China	2	QCRZDWLQMB@dell.com	5954418987	2	7114993930794299	2008/12	user14271	password	33	60000	M
14272	YWHNJX	PAXSXJJKKL	5783931748 Dell Way	\N	YEFPAHZ	\N	0	Germany	2	PAXSXJJKKL@dell.com	5783931748	4	7063776110298932	2010/11	user14272	password	29	40000	M
14273	AOIJLX	KJQHSARCLQ	8840467879 Dell Way	\N	HQGHYFW	\N	0	France	2	KJQHSARCLQ@dell.com	8840467879	3	9602705442346632	2011/09	user14273	password	35	60000	M
14274	UWBGTM	PKTHKLKWBR	4601435777 Dell Way	\N	NIZMNWY	\N	0	France	2	PKTHKLKWBR@dell.com	4601435777	5	2224310733377933	2008/02	user14274	password	66	100000	M
14275	NXEHJT	SCADOKZQCN	8991587311 Dell Way	\N	YBAMXZW	\N	0	Chile	2	SCADOKZQCN@dell.com	8991587311	1	4636522055137903	2008/09	user14275	password	34	100000	F
14276	CDMMWE	PXHDIHTKVS	1624820992 Dell Way	\N	LVEIVBQ	\N	0	Russia	2	PXHDIHTKVS@dell.com	1624820992	1	7639313406310976	2011/04	user14276	password	69	100000	F
14277	VLVSQL	PXOYFIIBAT	7988682458 Dell Way	\N	WFCSGTK	\N	0	China	2	PXOYFIIBAT@dell.com	7988682458	1	1670448636636138	2008/11	user14277	password	20	60000	M
14278	MGKCRZ	AGYFOGGPAD	4252231584 Dell Way	\N	UCVAVFJ	\N	0	Japan	2	AGYFOGGPAD@dell.com	4252231584	3	6923145255539567	2008/06	user14278	password	23	100000	M
14279	IGAAGA	GEGVLNKLQE	9842578923 Dell Way	\N	OMFKSOA	\N	0	Australia	2	GEGVLNKLQE@dell.com	9842578923	4	3403113520238549	2010/09	user14279	password	28	40000	F
14280	KJBRKI	VQDHDNSUSG	3953009753 Dell Way	\N	GXQZMRB	\N	0	France	2	VQDHDNSUSG@dell.com	3953009753	2	8975142511539162	2008/06	user14280	password	36	20000	M
14281	QFMANI	RRPVFIPXOW	2697728474 Dell Way	\N	VFVHWWS	\N	0	Chile	2	RRPVFIPXOW@dell.com	2697728474	4	3451651834882796	2011/11	user14281	password	47	60000	F
14282	PZNDIE	UXAAGPXVMS	3829267012 Dell Way	\N	AIZXFSC	\N	0	China	2	UXAAGPXVMS@dell.com	3829267012	2	1199911278206855	2008/10	user14282	password	54	80000	F
14283	MEOUJI	SJIYZGTLYU	2733468821 Dell Way	\N	UYSZQVJ	\N	0	UK	2	SJIYZGTLYU@dell.com	2733468821	2	2199774472042918	2012/11	user14283	password	75	40000	F
14284	ZXDIGW	SPVRWPDVJX	6555958142 Dell Way	\N	TBWKWGJ	\N	0	Australia	2	SPVRWPDVJX@dell.com	6555958142	3	1504493982065469	2010/04	user14284	password	49	100000	F
14285	JAPQWH	FRZBHCWQAQ	8831340585 Dell Way	\N	SXAPDJR	\N	0	Russia	2	FRZBHCWQAQ@dell.com	8831340585	4	3233460950199515	2008/03	user14285	password	25	60000	M
14286	CZDZHJ	RGLYJIPJYI	3914645618 Dell Way	\N	GZXKJPD	\N	0	Chile	2	RGLYJIPJYI@dell.com	3914645618	2	4392313395161182	2010/06	user14286	password	74	20000	M
14287	TDPBNH	HYFQGVAFDH	2899662573 Dell Way	\N	EAROQVT	\N	0	UK	2	HYFQGVAFDH@dell.com	2899662573	1	4955764087382704	2011/12	user14287	password	51	40000	M
14288	PXTDEA	BKRIFROIYT	2716372416 Dell Way	\N	JPHZLBY	\N	0	Japan	2	BKRIFROIYT@dell.com	2716372416	2	4180229535792023	2008/10	user14288	password	67	100000	F
14289	PNOUOQ	EFZKXNTVGC	4514630679 Dell Way	\N	LNCXPAN	\N	0	Russia	2	EFZKXNTVGC@dell.com	4514630679	5	8942033356986941	2009/07	user14289	password	68	80000	F
14290	FFYUVD	AVNXIGTOJF	5481819312 Dell Way	\N	CLCRLPL	\N	0	South Africa	2	AVNXIGTOJF@dell.com	5481819312	2	1501603432465344	2008/01	user14290	password	69	40000	F
14291	YDATGB	PUYXARMJWP	1404793351 Dell Way	\N	VZGGPSC	\N	0	Australia	2	PUYXARMJWP@dell.com	1404793351	1	2234366284683347	2008/11	user14291	password	43	40000	M
14292	MIOTJD	OIAOANYXCT	3433474106 Dell Way	\N	WJALBDN	\N	0	Canada	2	OIAOANYXCT@dell.com	3433474106	4	2549239321146160	2008/01	user14292	password	53	100000	F
14293	VMGFPU	NQJODILGCH	9313101132 Dell Way	\N	PCTQGGT	\N	0	Germany	2	NQJODILGCH@dell.com	9313101132	5	6720522653777153	2012/05	user14293	password	58	60000	F
14294	ARLQMZ	HVNLDZRGGG	6448370702 Dell Way	\N	JAXPGRC	\N	0	Canada	2	HVNLDZRGGG@dell.com	6448370702	4	2094917328562587	2008/04	user14294	password	58	40000	F
14295	FSYRSG	NFRREJXLPG	6814050775 Dell Way	\N	LNVSFYX	\N	0	South Africa	2	NFRREJXLPG@dell.com	6814050775	1	8457134554628284	2012/08	user14295	password	24	40000	M
14296	UENMKA	SCSXLPJBWV	5572230170 Dell Way	\N	OSOUQMP	\N	0	Chile	2	SCSXLPJBWV@dell.com	5572230170	3	2696335758082568	2008/07	user14296	password	48	100000	F
14297	PKUALN	CDKNTUOPPD	9128940430 Dell Way	\N	HDXXQME	\N	0	Canada	2	CDKNTUOPPD@dell.com	9128940430	2	3009560665115714	2010/10	user14297	password	27	80000	F
14298	OMKZAM	DKAWFPLUST	2816700139 Dell Way	\N	YQROCVS	\N	0	Australia	2	DKAWFPLUST@dell.com	2816700139	5	4770320254843682	2012/01	user14298	password	26	40000	M
14299	PTPPGS	AGPFVBAOUZ	2420327921 Dell Way	\N	ELOHHGH	\N	0	France	2	AGPFVBAOUZ@dell.com	2420327921	4	5287356183398515	2009/11	user14299	password	79	100000	F
14300	PKBWCC	DSIZTJNNIS	1236014037 Dell Way	\N	ZWZGDHT	\N	0	Chile	2	DSIZTJNNIS@dell.com	1236014037	2	5388070395216346	2012/01	user14300	password	39	40000	M
14301	SKOVNR	NVQGFETNWT	9955870361 Dell Way	\N	KWANETV	\N	0	Chile	2	NVQGFETNWT@dell.com	9955870361	2	1650482792407274	2008/08	user14301	password	47	80000	F
14302	UHCIZP	DQWJUQXRJI	9687719255 Dell Way	\N	OJVSDRX	\N	0	Canada	2	DQWJUQXRJI@dell.com	9687719255	5	2803861540276557	2010/05	user14302	password	87	100000	F
14303	GZNGPR	WLAQBXILFW	5422089899 Dell Way	\N	UBPYSNB	\N	0	Japan	2	WLAQBXILFW@dell.com	5422089899	2	3268002877943218	2012/03	user14303	password	26	20000	F
14304	CPSRGO	DHFEEOPKKK	6877904360 Dell Way	\N	LZIEMKW	\N	0	UK	2	DHFEEOPKKK@dell.com	6877904360	1	8816056256648154	2012/03	user14304	password	87	40000	F
14305	OBZUQC	BWHGKXQVHC	2839266083 Dell Way	\N	VQGHACH	\N	0	Japan	2	BWHGKXQVHC@dell.com	2839266083	1	5926311197690666	2010/02	user14305	password	83	80000	M
14306	YSLPVN	MCTWZKSHMN	3339479846 Dell Way	\N	XSVYVCQ	\N	0	Australia	2	MCTWZKSHMN@dell.com	3339479846	1	4937990379054100	2009/01	user14306	password	30	20000	F
14307	XMQSZC	UTYUDQCPDZ	7387941131 Dell Way	\N	HYYCBOD	\N	0	China	2	UTYUDQCPDZ@dell.com	7387941131	3	7222922195214779	2011/09	user14307	password	69	80000	M
14308	EKIEMD	XLYABAQFZX	7371193594 Dell Way	\N	EYAGMDO	\N	0	Canada	2	XLYABAQFZX@dell.com	7371193594	2	9584806600585580	2010/12	user14308	password	72	20000	F
14309	DJIQNF	BLGDLWJLUN	6515860571 Dell Way	\N	JVUVZJA	\N	0	Japan	2	BLGDLWJLUN@dell.com	6515860571	5	2117029535118490	2010/09	user14309	password	31	80000	M
14310	OBMBHO	NNRYKAKFOT	6639876537 Dell Way	\N	AIPASQS	\N	0	China	2	NNRYKAKFOT@dell.com	6639876537	5	9034132774453612	2009/01	user14310	password	64	40000	M
14311	RSQZGD	MYCXYMCNGD	7090505945 Dell Way	\N	WWDONWW	\N	0	Canada	2	MYCXYMCNGD@dell.com	7090505945	4	5324701438657940	2011/05	user14311	password	69	40000	F
14312	KWARAN	PCLOPOBWRY	1814665215 Dell Way	\N	SVMFRII	\N	0	China	2	PCLOPOBWRY@dell.com	1814665215	5	1402729358524084	2010/07	user14312	password	38	60000	M
14313	EPPECF	HOTXCVTTTL	8517587363 Dell Way	\N	PGRHPAR	\N	0	Japan	2	HOTXCVTTTL@dell.com	8517587363	4	2355340009089559	2009/12	user14313	password	68	40000	F
14314	HXIJCQ	YWNASHUMSJ	1285729599 Dell Way	\N	SKRIKIZ	\N	0	Chile	2	YWNASHUMSJ@dell.com	1285729599	1	6471695506479592	2008/11	user14314	password	83	20000	F
14315	UNMXDL	URLNYFZRPS	2631819130 Dell Way	\N	BHBMPAS	\N	0	Japan	2	URLNYFZRPS@dell.com	2631819130	2	6938607473857701	2008/03	user14315	password	78	20000	F
14316	IQYMBT	DMGBSGSIZT	3482760702 Dell Way	\N	PAFFBYV	\N	0	Chile	2	DMGBSGSIZT@dell.com	3482760702	3	3337558378931135	2010/04	user14316	password	46	60000	M
14317	AMDBGG	ONHHTAPTTE	7239888864 Dell Way	\N	TZJVYFB	\N	0	Chile	2	ONHHTAPTTE@dell.com	7239888864	2	7500365633517504	2008/09	user14317	password	37	80000	M
14318	TVUABJ	NJQHJFADJU	9897681248 Dell Way	\N	DTPBYRH	\N	0	Japan	2	NJQHJFADJU@dell.com	9897681248	5	6912877482827753	2011/04	user14318	password	42	60000	F
14319	DGAFPO	OGVYMVBWQE	5515714756 Dell Way	\N	PFGOXNE	\N	0	South Africa	2	OGVYMVBWQE@dell.com	5515714756	5	6301474006380886	2011/03	user14319	password	19	80000	F
14320	HVNWJC	DEAPACLQGB	6582987483 Dell Way	\N	WMPUAUR	\N	0	Germany	2	DEAPACLQGB@dell.com	6582987483	2	3389308429323137	2011/04	user14320	password	21	20000	M
14321	WQLFTO	KUEKWQBDRY	6536005704 Dell Way	\N	QHSQBJD	\N	0	Japan	2	KUEKWQBDRY@dell.com	6536005704	2	5300308327656239	2012/06	user14321	password	61	60000	F
14322	GWNZKY	UPJQFKUWIK	6156426094 Dell Way	\N	EBBFKEX	\N	0	Australia	2	UPJQFKUWIK@dell.com	6156426094	2	9292641740757972	2008/12	user14322	password	43	40000	F
14323	FWFQUA	FDRKOLHXWL	9599267663 Dell Way	\N	YXRJBOK	\N	0	Japan	2	FDRKOLHXWL@dell.com	9599267663	2	6986232202965767	2012/08	user14323	password	90	20000	M
14324	WKNQKS	UBDIMLGJXE	3118324948 Dell Way	\N	GONIDYY	\N	0	Australia	2	UBDIMLGJXE@dell.com	3118324948	4	1233356651850044	2012/08	user14324	password	31	80000	F
14325	OHDZAY	ADHNPNWMRC	1014645598 Dell Way	\N	AFKEDJG	\N	0	China	2	ADHNPNWMRC@dell.com	1014645598	2	3418755253776908	2011/06	user14325	password	21	20000	F
14326	IGAJEA	MLNCYJOQMP	3642717024 Dell Way	\N	VXTZGAI	\N	0	Chile	2	MLNCYJOQMP@dell.com	3642717024	3	9037416703533382	2011/08	user14326	password	18	100000	M
14327	GVIKVV	WJXUSMLFBG	2361274488 Dell Way	\N	CUFJUOQ	\N	0	Australia	2	WJXUSMLFBG@dell.com	2361274488	3	8669050273019821	2011/07	user14327	password	66	80000	M
14328	MDEHYA	QWVJIHOJNR	2425323749 Dell Way	\N	ETAYHQB	\N	0	France	2	QWVJIHOJNR@dell.com	2425323749	5	3299558136612177	2011/07	user14328	password	21	60000	F
14329	EQIDRY	ZNIIUXSHOW	7881563877 Dell Way	\N	BOVJFWV	\N	0	China	2	ZNIIUXSHOW@dell.com	7881563877	1	1270789087284356	2009/02	user14329	password	52	40000	F
14330	CRKTQK	GYSAVLIJHK	6779673681 Dell Way	\N	XDTDZOM	\N	0	Russia	2	GYSAVLIJHK@dell.com	6779673681	3	1691520489752292	2011/12	user14330	password	48	20000	F
14331	BLVRVB	QOCLZKVHUT	8462645056 Dell Way	\N	KOWKDID	\N	0	Russia	2	QOCLZKVHUT@dell.com	8462645056	2	5713404235430062	2011/08	user14331	password	58	100000	M
14332	ZRKVTB	JVMJGIQBBA	8283688934 Dell Way	\N	PYLSGPM	\N	0	Australia	2	JVMJGIQBBA@dell.com	8283688934	1	9006157041061670	2010/07	user14332	password	72	20000	M
14333	KPKEQU	ZDDFMTHNUW	2069247096 Dell Way	\N	MFPSUCV	\N	0	Germany	2	ZDDFMTHNUW@dell.com	2069247096	4	1502781228162348	2011/06	user14333	password	35	40000	M
14334	VRAMLA	POFBIMPCJB	3829022411 Dell Way	\N	HZUCBPS	\N	0	Canada	2	POFBIMPCJB@dell.com	3829022411	4	9039409781806172	2011/12	user14334	password	30	80000	M
14335	VRHHRX	VXZDKPGURO	1827054803 Dell Way	\N	TLQVBIA	\N	0	China	2	VXZDKPGURO@dell.com	1827054803	5	2370236604008823	2008/02	user14335	password	76	100000	M
14336	MFEDCA	BCEMRKGIZA	8102277409 Dell Way	\N	UPVWYWG	\N	0	Australia	2	BCEMRKGIZA@dell.com	8102277409	3	2084102561231702	2012/03	user14336	password	19	80000	M
14337	FZVIAW	KEICPPLOPG	7960957339 Dell Way	\N	EKCCHJD	\N	0	Australia	2	KEICPPLOPG@dell.com	7960957339	2	9584752633702012	2012/04	user14337	password	72	80000	M
14338	TMVTJF	YRINHTCWZG	8076829695 Dell Way	\N	HCJOLNQ	\N	0	Chile	2	YRINHTCWZG@dell.com	8076829695	3	2767354651354253	2008/05	user14338	password	79	60000	F
14339	IKVRQU	JYIQSKMRQT	6208423900 Dell Way	\N	TAIFNZK	\N	0	China	2	JYIQSKMRQT@dell.com	6208423900	4	4425631778780371	2012/06	user14339	password	88	20000	M
14340	KWLAQU	ZYLSJXJZRD	4432679236 Dell Way	\N	ZAINATU	\N	0	Germany	2	ZYLSJXJZRD@dell.com	4432679236	1	5577762167900801	2012/02	user14340	password	56	80000	M
14341	KCOAXO	ZIGIGQIYUI	8246683862 Dell Way	\N	YDVYWQN	\N	0	Chile	2	ZIGIGQIYUI@dell.com	8246683862	1	2001737420912832	2012/07	user14341	password	72	60000	M
14342	VBZSQZ	AXIHOQFIZD	6980307270 Dell Way	\N	LUCIKQP	\N	0	Chile	2	AXIHOQFIZD@dell.com	6980307270	4	2554428389761597	2009/06	user14342	password	67	20000	F
14343	TEZKEA	HNHVDNEDQQ	3303972486 Dell Way	\N	XTYIJON	\N	0	Australia	2	HNHVDNEDQQ@dell.com	3303972486	4	3452688739169389	2011/05	user14343	password	51	100000	F
14344	QZNVZU	IHQMUVPLLN	1519085106 Dell Way	\N	FKVOYJP	\N	0	Chile	2	IHQMUVPLLN@dell.com	1519085106	5	9184655423276128	2010/05	user14344	password	82	60000	M
14345	WBVWWD	DNQYIFJUSO	6786398729 Dell Way	\N	EODDXTI	\N	0	UK	2	DNQYIFJUSO@dell.com	6786398729	2	4528431387152523	2012/02	user14345	password	87	100000	M
14346	AUVWYZ	KOXTUHNNWS	4669327022 Dell Way	\N	BAVYUEX	\N	0	France	2	KOXTUHNNWS@dell.com	4669327022	2	4632144505623728	2010/03	user14346	password	46	60000	F
14347	FJDDJN	SHHMPUZLMA	2704748376 Dell Way	\N	MIZGMXQ	\N	0	South Africa	2	SHHMPUZLMA@dell.com	2704748376	1	4905607298482210	2010/06	user14347	password	88	80000	M
14348	IVUSJM	ZQZOLYAXZM	4884645445 Dell Way	\N	GZTSWJP	\N	0	Australia	2	ZQZOLYAXZM@dell.com	4884645445	1	5362322672270239	2012/01	user14348	password	31	60000	F
14349	AHBJUB	ATQLSRJREP	9734853241 Dell Way	\N	RXINHXO	\N	0	Russia	2	ATQLSRJREP@dell.com	9734853241	1	6176447070203722	2012/03	user14349	password	24	40000	F
14350	JKQEMQ	XCBPTLHYAY	1647287967 Dell Way	\N	VILCGAU	\N	0	Chile	2	XCBPTLHYAY@dell.com	1647287967	2	2797345503233373	2009/06	user14350	password	57	60000	M
14351	YEZLUX	NWMHHUFHSB	3545431321 Dell Way	\N	PEDWFXB	\N	0	Chile	2	NWMHHUFHSB@dell.com	3545431321	2	6233008760493249	2011/10	user14351	password	26	60000	M
14352	HOFBLS	XYAFSGMLHC	3683359171 Dell Way	\N	QLYVJAD	\N	0	Japan	2	XYAFSGMLHC@dell.com	3683359171	4	4341520956251770	2008/10	user14352	password	86	100000	F
14353	MCEYUB	WVHOCTAKWQ	3716344491 Dell Way	\N	VVMEWPV	\N	0	Canada	2	WVHOCTAKWQ@dell.com	3716344491	1	3322750393301249	2008/02	user14353	password	28	40000	M
14354	FJOALK	WSZYMZJIQE	4476382459 Dell Way	\N	EDJASEE	\N	0	Australia	2	WSZYMZJIQE@dell.com	4476382459	3	2270155791658908	2010/07	user14354	password	44	20000	M
14355	TRUEBR	XBQKBZTRDX	5403508741 Dell Way	\N	UNXNSBN	\N	0	Australia	2	XBQKBZTRDX@dell.com	5403508741	4	6516484750900418	2008/01	user14355	password	72	100000	M
14356	KQYMHW	OXGPWZHAXB	8111043832 Dell Way	\N	OVPGXDJ	\N	0	China	2	OXGPWZHAXB@dell.com	8111043832	5	4790051468648017	2012/09	user14356	password	35	60000	F
14357	WOQEKE	BRUYRBZODO	2250524532 Dell Way	\N	JSUGVEQ	\N	0	Japan	2	BRUYRBZODO@dell.com	2250524532	1	4983329568523914	2012/04	user14357	password	20	100000	F
14358	PQIZVK	QPIIQIWUWG	2523147454 Dell Way	\N	MRMIVDY	\N	0	UK	2	QPIIQIWUWG@dell.com	2523147454	2	8553119114134462	2010/05	user14358	password	78	80000	M
14359	MYZHIQ	WRYNAUHXBU	4604234909 Dell Way	\N	ONCKQAK	\N	0	South Africa	2	WRYNAUHXBU@dell.com	4604234909	2	3540518913883716	2012/01	user14359	password	84	100000	M
14360	WUVFKR	WJFXEMUFGJ	4516093255 Dell Way	\N	SITJJEF	\N	0	Russia	2	WJFXEMUFGJ@dell.com	4516093255	3	6202838682569564	2010/05	user14360	password	45	100000	F
14361	EULOMI	XRFBDAGKJZ	1400924734 Dell Way	\N	TDJCHOW	\N	0	Japan	2	XRFBDAGKJZ@dell.com	1400924734	3	2268371007870883	2010/11	user14361	password	27	80000	M
14362	YCOKLM	BROFRUQAUJ	8372151574 Dell Way	\N	EEMLSJD	\N	0	Russia	2	BROFRUQAUJ@dell.com	8372151574	2	2848342121113092	2011/05	user14362	password	82	80000	F
14363	ZFTLRU	CFATAQUVAY	8463267559 Dell Way	\N	ZMKSVOM	\N	0	Japan	2	CFATAQUVAY@dell.com	8463267559	4	3852048497181386	2009/07	user14363	password	88	60000	M
14364	EIZWCC	CDVCTPYTOX	8327010884 Dell Way	\N	GYQCMDT	\N	0	China	2	CDVCTPYTOX@dell.com	8327010884	1	6110820753965527	2009/01	user14364	password	28	100000	F
14365	LYBOAE	SWHLLFFADL	4112498121 Dell Way	\N	YTOLWHU	\N	0	Japan	2	SWHLLFFADL@dell.com	4112498121	2	1733912526629865	2009/06	user14365	password	20	60000	M
14366	ZRNAVF	WCRIHXIKJH	8953041603 Dell Way	\N	EXTBENT	\N	0	Germany	2	WCRIHXIKJH@dell.com	8953041603	5	9182636687997728	2009/11	user14366	password	53	40000	M
14367	DWWYCT	BTBIRKTARY	6194728281 Dell Way	\N	XLZCZTQ	\N	0	South Africa	2	BTBIRKTARY@dell.com	6194728281	3	3040382884442806	2010/01	user14367	password	59	40000	F
14368	KEDNXF	GYNXIHYAFW	2605480625 Dell Way	\N	LFZKYQG	\N	0	Germany	2	GYNXIHYAFW@dell.com	2605480625	3	9813458921853454	2009/01	user14368	password	38	60000	F
14369	LOZITG	HHEQPCRVZD	3674596214 Dell Way	\N	AYOZOUN	\N	0	Russia	2	HHEQPCRVZD@dell.com	3674596214	3	9739199199248106	2009/10	user14369	password	46	100000	F
14370	YUOSBW	AFNQHELHHL	4847492718 Dell Way	\N	FVLUQYN	\N	0	UK	2	AFNQHELHHL@dell.com	4847492718	3	3643773898482323	2008/11	user14370	password	26	60000	M
14371	XZPYVP	EIFMNQTVCY	8017615711 Dell Way	\N	QNTHMHG	\N	0	South Africa	2	EIFMNQTVCY@dell.com	8017615711	3	1827961604110896	2011/08	user14371	password	54	60000	M
14372	MCNISR	QYDEPXZSWQ	7336034352 Dell Way	\N	FPYSWEP	\N	0	Japan	2	QYDEPXZSWQ@dell.com	7336034352	4	3937748637516052	2009/03	user14372	password	80	100000	M
14373	YLZRDQ	PHUFEUXAKD	1844479116 Dell Way	\N	QIVNMKE	\N	0	Canada	2	PHUFEUXAKD@dell.com	1844479116	3	5988474878482521	2009/05	user14373	password	53	100000	F
14374	YXZCOP	JJUODSPNVG	4605264337 Dell Way	\N	VQTIBXN	\N	0	Canada	2	JJUODSPNVG@dell.com	4605264337	1	4950369276572019	2011/07	user14374	password	45	20000	M
14375	HAPWPZ	FKNICDVXJR	6804832538 Dell Way	\N	OCAQAOU	\N	0	France	2	FKNICDVXJR@dell.com	6804832538	2	2428534027189016	2009/08	user14375	password	32	80000	M
14376	FIUVHZ	FUIHYEFHVU	5137610013 Dell Way	\N	KWLKLFV	\N	0	Australia	2	FUIHYEFHVU@dell.com	5137610013	5	3551924605388194	2008/03	user14376	password	18	20000	F
14377	IUFPTL	KCSIGYPCTA	2931282486 Dell Way	\N	YEKJKGL	\N	0	South Africa	2	KCSIGYPCTA@dell.com	2931282486	4	9368524941615760	2009/09	user14377	password	85	80000	F
14378	SAQMLA	OEJUDZWWZV	4040440538 Dell Way	\N	AJEKPQG	\N	0	South Africa	2	OEJUDZWWZV@dell.com	4040440538	1	3039889332838356	2008/02	user14378	password	19	20000	M
14379	ATIMUX	QDRTCOQCJQ	5669689286 Dell Way	\N	MOBCEIX	\N	0	Germany	2	QDRTCOQCJQ@dell.com	5669689286	1	6178301817737520	2011/02	user14379	password	67	60000	F
14380	LVRFSI	JJCMYSOHIA	2473292367 Dell Way	\N	WKCASAO	\N	0	Chile	2	JJCMYSOHIA@dell.com	2473292367	1	9003294143360109	2009/10	user14380	password	45	60000	F
14381	EFLWNV	GQHEIWMRXJ	1398535477 Dell Way	\N	BAJUAYA	\N	0	Canada	2	GQHEIWMRXJ@dell.com	1398535477	5	5657902013510466	2012/04	user14381	password	21	20000	F
14382	GNJUJQ	KQVSMIKJRL	2903191141 Dell Way	\N	JBGKZHP	\N	0	Australia	2	KQVSMIKJRL@dell.com	2903191141	1	8815048668067903	2010/02	user14382	password	87	20000	F
14383	MJEVAP	MVHZERIVDS	8760357579 Dell Way	\N	WKDWRTW	\N	0	South Africa	2	MVHZERIVDS@dell.com	8760357579	4	4608607057016343	2008/09	user14383	password	47	60000	F
14384	UQAUFM	QNLUFUQINM	9737878634 Dell Way	\N	SQJKKFH	\N	0	Chile	2	QNLUFUQINM@dell.com	9737878634	4	3460896705277264	2011/02	user14384	password	69	100000	M
14385	IWROII	BTCGNSPBFI	7195916947 Dell Way	\N	ROSBUAI	\N	0	Russia	2	BTCGNSPBFI@dell.com	7195916947	3	4851830311119557	2011/04	user14385	password	37	80000	M
14386	DIFLQG	FTNTMCURKM	5078856400 Dell Way	\N	GDOBDWV	\N	0	South Africa	2	FTNTMCURKM@dell.com	5078856400	2	6362471756059677	2011/07	user14386	password	36	60000	M
14387	PPBGVG	ZJAMLUEWGK	5539297174 Dell Way	\N	ZULCRGX	\N	0	Canada	2	ZJAMLUEWGK@dell.com	5539297174	3	8883848997298629	2008/10	user14387	password	38	80000	F
14388	WSPSZP	BZBNUFJAQJ	9135307462 Dell Way	\N	VCMNJKQ	\N	0	South Africa	2	BZBNUFJAQJ@dell.com	9135307462	3	8828503596596421	2011/10	user14388	password	55	20000	M
14389	FQJEGL	EIYYNIZERV	5208411236 Dell Way	\N	GDIPNZM	\N	0	France	2	EIYYNIZERV@dell.com	5208411236	2	1922492339275777	2009/11	user14389	password	28	100000	F
14390	UGGBRK	JQJXYJBQEI	7576143004 Dell Way	\N	TNYHMKS	\N	0	UK	2	JQJXYJBQEI@dell.com	7576143004	5	2868377241771668	2010/12	user14390	password	25	80000	M
14391	JWUBHE	RRBQADGFMZ	7919711809 Dell Way	\N	TKHGUZF	\N	0	Germany	2	RRBQADGFMZ@dell.com	7919711809	3	1886327859479934	2011/07	user14391	password	71	60000	M
14392	PGYXLP	PMGPQMVCMP	5095416883 Dell Way	\N	NTVHSBV	\N	0	France	2	PMGPQMVCMP@dell.com	5095416883	5	2803463186137378	2012/08	user14392	password	66	100000	F
14393	YUEJJT	VPJMCFPOUC	2079995437 Dell Way	\N	IQJARFN	\N	0	Canada	2	VPJMCFPOUC@dell.com	2079995437	4	1858839822933077	2011/05	user14393	password	86	20000	F
14394	SEQCYM	SHZUNOJHQR	9450315644 Dell Way	\N	XASPFFS	\N	0	China	2	SHZUNOJHQR@dell.com	9450315644	5	2010992357973009	2009/10	user14394	password	28	80000	F
14395	IGOGTH	OTCBHMJYDH	4679062317 Dell Way	\N	YWWECPN	\N	0	Australia	2	OTCBHMJYDH@dell.com	4679062317	4	4064085086807609	2008/10	user14395	password	87	80000	F
14396	FFJZNY	SPAZBJYFRW	2937661822 Dell Way	\N	BOBDDPE	\N	0	Germany	2	SPAZBJYFRW@dell.com	2937661822	3	7426689949352295	2012/06	user14396	password	43	20000	M
14397	OLRBKJ	RKJSTHXLEZ	8393215145 Dell Way	\N	ZGDCVHR	\N	0	Australia	2	RKJSTHXLEZ@dell.com	8393215145	2	1176779685541987	2009/09	user14397	password	25	100000	F
14398	OQJYAA	IKTCRQNWQM	6812220423 Dell Way	\N	CTPXBHY	\N	0	South Africa	2	IKTCRQNWQM@dell.com	6812220423	5	2675356738734990	2009/01	user14398	password	30	80000	M
14399	VAPVBX	GUAXLOUBBX	7630120927 Dell Way	\N	VRVXYTU	\N	0	Germany	2	GUAXLOUBBX@dell.com	7630120927	5	9567616327200086	2012/02	user14399	password	63	60000	M
14400	QAVSYB	MZZXNTZPRV	5861922909 Dell Way	\N	GMTEGOT	\N	0	UK	2	MZZXNTZPRV@dell.com	5861922909	4	8058069827035070	2011/04	user14400	password	35	80000	M
14401	HMRFOE	FNBTHBIYXO	2886178576 Dell Way	\N	KQTQENQ	\N	0	Russia	2	FNBTHBIYXO@dell.com	2886178576	3	4892726035788655	2010/08	user14401	password	26	60000	M
14402	PEDEIJ	RKCZMKYJZJ	1231182453 Dell Way	\N	ASAFFQY	\N	0	France	2	RKCZMKYJZJ@dell.com	1231182453	2	9794056245125832	2011/06	user14402	password	53	60000	F
14403	RSGABY	LEYXOWHOFI	8802751054 Dell Way	\N	HFNNWMY	\N	0	South Africa	2	LEYXOWHOFI@dell.com	8802751054	5	5897594022098929	2009/06	user14403	password	26	60000	F
14404	VSCXRO	BQLQNTFSBM	9104348094 Dell Way	\N	YPAVCZR	\N	0	UK	2	BQLQNTFSBM@dell.com	9104348094	2	3897540471982211	2009/05	user14404	password	75	60000	F
14405	NNCFCE	VOVIHBBJNA	7649055088 Dell Way	\N	ZOVBNNA	\N	0	France	2	VOVIHBBJNA@dell.com	7649055088	2	7637566546443851	2008/02	user14405	password	29	40000	M
14406	SKWUPR	ILZPMBZABY	4744407500 Dell Way	\N	OWABJBM	\N	0	Canada	2	ILZPMBZABY@dell.com	4744407500	2	2899538823403418	2010/05	user14406	password	54	40000	F
14407	XBWNTE	YSUKUULVTZ	7836695583 Dell Way	\N	STBBVNF	\N	0	Chile	2	YSUKUULVTZ@dell.com	7836695583	3	8167781881988049	2008/11	user14407	password	18	40000	M
14408	BCIUGG	NBRHVCDPCV	5453911883 Dell Way	\N	IDXERCK	\N	0	France	2	NBRHVCDPCV@dell.com	5453911883	2	6130790567025543	2010/03	user14408	password	75	40000	F
14409	WOBDUP	FMXBOAQQVZ	7830320509 Dell Way	\N	UTDLVOW	\N	0	China	2	FMXBOAQQVZ@dell.com	7830320509	3	7503045202232898	2012/03	user14409	password	87	40000	F
14410	MIGHXM	UUNJVEAQDU	6149867615 Dell Way	\N	JHGFVDN	\N	0	Japan	2	UUNJVEAQDU@dell.com	6149867615	2	6160313063301147	2012/03	user14410	password	77	100000	M
14411	DFZART	VFDQJDHNXR	6864265780 Dell Way	\N	VEWRHKG	\N	0	South Africa	2	VFDQJDHNXR@dell.com	6864265780	5	7044766645412893	2012/08	user14411	password	62	60000	M
14412	VNVMHR	SKHCNPPLHK	2696823140 Dell Way	\N	PDCXOJT	\N	0	Chile	2	SKHCNPPLHK@dell.com	2696823140	3	1460113657172769	2012/01	user14412	password	60	80000	M
14413	CLIJCA	TKCHASTHDI	4459064571 Dell Way	\N	LFFZOZF	\N	0	Russia	2	TKCHASTHDI@dell.com	4459064571	2	6327775710262359	2010/10	user14413	password	34	40000	M
14414	ROHUPB	FRIFKBMNKX	3986627462 Dell Way	\N	TQXHPCB	\N	0	UK	2	FRIFKBMNKX@dell.com	3986627462	4	4500289004761726	2008/11	user14414	password	64	20000	M
14415	FJIUKN	MTSWVEKFCD	1765361435 Dell Way	\N	WZKLCLL	\N	0	France	2	MTSWVEKFCD@dell.com	1765361435	5	6088596619665623	2012/06	user14415	password	64	60000	M
14416	ZUKKHX	DZTZEDEGGB	7661883201 Dell Way	\N	GRMIDXT	\N	0	Chile	2	DZTZEDEGGB@dell.com	7661883201	2	2402725304942578	2008/12	user14416	password	63	100000	M
14417	KGIRDM	RXLVBQCIRJ	7724491345 Dell Way	\N	ZESDCLI	\N	0	South Africa	2	RXLVBQCIRJ@dell.com	7724491345	3	1282284251414239	2011/02	user14417	password	81	80000	M
14418	DZFGMW	EXSFOUNGEN	5314219642 Dell Way	\N	LWQNHZJ	\N	0	Australia	2	EXSFOUNGEN@dell.com	5314219642	3	7566331517416985	2010/04	user14418	password	44	20000	F
14419	IIQUEV	SWAHRONVCY	3427739576 Dell Way	\N	RSMZSWA	\N	0	Canada	2	SWAHRONVCY@dell.com	3427739576	4	8094964731018991	2010/02	user14419	password	83	100000	F
14420	FPGKKY	GLFYATUCSL	2628915823 Dell Way	\N	VFLNBLS	\N	0	China	2	GLFYATUCSL@dell.com	2628915823	3	8850923871621490	2009/05	user14420	password	76	80000	M
14421	JYAUXH	FDFFXZIPLD	9059552563 Dell Way	\N	UXRWIKF	\N	0	Germany	2	FDFFXZIPLD@dell.com	9059552563	1	8162081735208631	2009/11	user14421	password	55	100000	F
14422	MYAJGG	NMMKMUAYYV	9456931338 Dell Way	\N	VPRDZWR	\N	0	South Africa	2	NMMKMUAYYV@dell.com	9456931338	3	2721258328761905	2012/12	user14422	password	27	20000	F
14423	CCVIIJ	UVTGPUFOPA	3482279631 Dell Way	\N	DGEDDVA	\N	0	Australia	2	UVTGPUFOPA@dell.com	3482279631	2	8902089523151518	2009/05	user14423	password	86	80000	F
14424	ANTJXO	EQVULAIAAM	8667974476 Dell Way	\N	HEQKZQM	\N	0	Chile	2	EQVULAIAAM@dell.com	8667974476	2	5719571379944683	2008/04	user14424	password	34	80000	F
14425	TJRQXV	HTQSTYSULA	2994745039 Dell Way	\N	YBKYSWF	\N	0	Germany	2	HTQSTYSULA@dell.com	2994745039	4	7723237035796047	2010/12	user14425	password	44	100000	M
14426	TMJQHR	KYJDWCXICW	8112636695 Dell Way	\N	KNVCKBQ	\N	0	Japan	2	KYJDWCXICW@dell.com	8112636695	2	2013077632989734	2011/10	user14426	password	85	60000	F
14427	KWDRNN	QXRNAPVDLF	4134049272 Dell Way	\N	QHHAIYQ	\N	0	Canada	2	QXRNAPVDLF@dell.com	4134049272	4	8785298850387336	2008/09	user14427	password	44	60000	F
14428	FTTTHJ	RYWRNSVZXM	9031356285 Dell Way	\N	GFMOEDR	\N	0	Germany	2	RYWRNSVZXM@dell.com	9031356285	3	6620098975487054	2010/11	user14428	password	34	80000	F
14429	YKWFTN	EQFSIASGMZ	7818407247 Dell Way	\N	LZOQCFD	\N	0	Australia	2	EQFSIASGMZ@dell.com	7818407247	4	6144706340972335	2011/12	user14429	password	32	80000	M
14430	PQEJEJ	ZJBIJUOWTA	5965155891 Dell Way	\N	VHQYNUY	\N	0	Chile	2	ZJBIJUOWTA@dell.com	5965155891	3	9226189651992172	2010/09	user14430	password	68	60000	F
14431	IRRMAQ	WCYGWMCPNX	4024715191 Dell Way	\N	XDWKXVR	\N	0	France	2	WCYGWMCPNX@dell.com	4024715191	3	1122616045176982	2008/04	user14431	password	54	40000	M
14432	EABFRY	HQEEDGUQER	3864257325 Dell Way	\N	TACRWTD	\N	0	Canada	2	HQEEDGUQER@dell.com	3864257325	1	3220973607618362	2010/09	user14432	password	63	20000	M
14433	QGBIEI	YINBOHRTZL	4767978451 Dell Way	\N	UBCQVGV	\N	0	Canada	2	YINBOHRTZL@dell.com	4767978451	1	7454059235285968	2008/09	user14433	password	82	100000	F
14434	DZQHIP	PVQEDIXDTR	2528352192 Dell Way	\N	FWHACCE	\N	0	Germany	2	PVQEDIXDTR@dell.com	2528352192	5	6495543680619449	2012/10	user14434	password	57	20000	M
14435	NVEVKU	RAYVIVYCND	2899057052 Dell Way	\N	YVEBYIO	\N	0	Canada	2	RAYVIVYCND@dell.com	2899057052	1	9569040144328028	2012/09	user14435	password	26	100000	F
14436	YABIUT	JSOSOMUCQT	5600919170 Dell Way	\N	YUUWDIZ	\N	0	China	2	JSOSOMUCQT@dell.com	5600919170	5	3801028062123805	2009/01	user14436	password	30	60000	M
14437	ENIZGR	SUKHHFJXYH	1455541710 Dell Way	\N	SSEVADE	\N	0	Germany	2	SUKHHFJXYH@dell.com	1455541710	3	7914015891030432	2008/08	user14437	password	34	20000	M
14438	TKVZBN	UMUBREZPMS	2693334190 Dell Way	\N	HQNHUSW	\N	0	South Africa	2	UMUBREZPMS@dell.com	2693334190	4	9335875052493068	2012/11	user14438	password	90	80000	M
14439	JMPLAJ	XVLOZLDMDL	2749304449 Dell Way	\N	DRSXJPT	\N	0	Germany	2	XVLOZLDMDL@dell.com	2749304449	4	4544710468035191	2008/09	user14439	password	23	80000	F
14440	OFNOOL	KAZJLDWPOA	4220253312 Dell Way	\N	GHYPWRE	\N	0	Australia	2	KAZJLDWPOA@dell.com	4220253312	3	1938578560948372	2008/08	user14440	password	70	20000	F
14441	XPTMAE	MANYEKNSKU	2193975795 Dell Way	\N	AIKXAOZ	\N	0	China	2	MANYEKNSKU@dell.com	2193975795	1	4640256021171808	2011/10	user14441	password	54	100000	M
14442	CSFDWS	DKQIVEBGYB	1291067136 Dell Way	\N	OJZPYYY	\N	0	Australia	2	DKQIVEBGYB@dell.com	1291067136	2	8440494695678354	2012/11	user14442	password	75	60000	M
14443	NTCKLG	VCOQGPXFRL	4097952254 Dell Way	\N	ORANPZO	\N	0	Japan	2	VCOQGPXFRL@dell.com	4097952254	2	5311817715875805	2008/03	user14443	password	19	20000	M
14444	TGCFMX	HBONRLTIXI	7969743619 Dell Way	\N	ZYVPYKG	\N	0	Chile	2	HBONRLTIXI@dell.com	7969743619	4	5357805212028325	2012/10	user14444	password	64	80000	M
14445	XTTJRA	LGOCSHLPQL	1370795057 Dell Way	\N	OLANVHU	\N	0	Japan	2	LGOCSHLPQL@dell.com	1370795057	2	6085651495493949	2012/11	user14445	password	33	40000	M
14446	YBEQCP	WQSOYDEOOS	3544633996 Dell Way	\N	APFWWAM	\N	0	UK	2	WQSOYDEOOS@dell.com	3544633996	1	7564240060746670	2008/04	user14446	password	23	100000	F
14447	DEVGUR	WMGVPKKDDL	8352813308 Dell Way	\N	SIHPJUN	\N	0	Japan	2	WMGVPKKDDL@dell.com	8352813308	2	8488648100756110	2008/04	user14447	password	78	40000	F
14448	ACSUUP	HBLXLVBOGU	2616621914 Dell Way	\N	XOKGIXX	\N	0	Canada	2	HBLXLVBOGU@dell.com	2616621914	4	2950547812972218	2010/07	user14448	password	54	100000	M
14449	PSJKIQ	LTOXPPLVJJ	2947245410 Dell Way	\N	KTPSRMW	\N	0	South Africa	2	LTOXPPLVJJ@dell.com	2947245410	1	4209577369969338	2011/08	user14449	password	43	40000	F
14450	BSPJIB	DXZSMKOVUY	6468405236 Dell Way	\N	PJRGWNC	\N	0	Australia	2	DXZSMKOVUY@dell.com	6468405236	3	8696757152676583	2008/10	user14450	password	31	40000	M
14451	WAGFBJ	CBBPLPKFNA	8266368121 Dell Way	\N	PEGMSJO	\N	0	China	2	CBBPLPKFNA@dell.com	8266368121	3	5499501838348806	2011/08	user14451	password	82	60000	F
14452	XSSZBV	ACKMRVSFVH	7787098010 Dell Way	\N	JCUBLIK	\N	0	Chile	2	ACKMRVSFVH@dell.com	7787098010	5	8708287843503059	2009/10	user14452	password	41	100000	M
14453	ANQBJQ	ETCVOVBKCK	7873159293 Dell Way	\N	MWMXFWE	\N	0	UK	2	ETCVOVBKCK@dell.com	7873159293	1	3981973486486822	2010/05	user14453	password	30	40000	F
14454	SVLBMP	UPLJKMTNXF	3798847007 Dell Way	\N	KKDQGHP	\N	0	Australia	2	UPLJKMTNXF@dell.com	3798847007	5	6101324288174511	2011/02	user14454	password	74	20000	M
14455	QLWCBR	SMADYTQWZB	2895267979 Dell Way	\N	GCRNKHN	\N	0	Russia	2	SMADYTQWZB@dell.com	2895267979	1	4213535882998258	2009/11	user14455	password	45	20000	F
14456	VZPWQI	JQLHKCEJDK	5663719972 Dell Way	\N	MVXWCKP	\N	0	Chile	2	JQLHKCEJDK@dell.com	5663719972	5	6478362338151783	2009/04	user14456	password	71	100000	F
14457	SMZIUJ	ZFQKHUULFG	6819500374 Dell Way	\N	GCDINSQ	\N	0	Australia	2	ZFQKHUULFG@dell.com	6819500374	2	4772522105369717	2012/12	user14457	password	39	20000	M
14458	TCAOLZ	TCKBXEMCLS	8947422002 Dell Way	\N	EOARHRS	\N	0	UK	2	TCKBXEMCLS@dell.com	8947422002	1	8969281184952707	2012/06	user14458	password	88	60000	F
14459	BMTMMN	OWPMBBOMUT	3592848375 Dell Way	\N	BVLJMDH	\N	0	China	2	OWPMBBOMUT@dell.com	3592848375	1	2708249774295837	2011/02	user14459	password	68	100000	F
14460	ERRRFG	OUSPVHCQAE	9782766311 Dell Way	\N	LLNXPVG	\N	0	South Africa	2	OUSPVHCQAE@dell.com	9782766311	3	6349368079565466	2008/02	user14460	password	56	40000	F
14461	FZZKGO	FZEBGGRHLC	7474216153 Dell Way	\N	SZAHUHE	\N	0	Russia	2	FZEBGGRHLC@dell.com	7474216153	4	8849125965964050	2012/04	user14461	password	31	20000	F
14462	EEXLSD	LWESDVZOYR	9076554382 Dell Way	\N	OYZIFDC	\N	0	UK	2	LWESDVZOYR@dell.com	9076554382	5	8136498549021781	2008/02	user14462	password	88	80000	F
14463	DPTVSF	RWXUSWJQOX	3442362728 Dell Way	\N	PNGURIT	\N	0	Germany	2	RWXUSWJQOX@dell.com	3442362728	3	7792610305827112	2010/07	user14463	password	49	80000	M
14464	AMLSRD	PPXHLHXAFN	6300753510 Dell Way	\N	OLHFTBU	\N	0	Australia	2	PPXHLHXAFN@dell.com	6300753510	3	4980905191041529	2008/12	user14464	password	30	80000	M
14465	RDSJGH	YEOKMMKRZY	5784527613 Dell Way	\N	DHEXIZY	\N	0	UK	2	YEOKMMKRZY@dell.com	5784527613	2	1198166417423635	2010/07	user14465	password	71	60000	F
14466	WFODNM	ICWVOHMOGQ	8285964436 Dell Way	\N	WKNFJLD	\N	0	UK	2	ICWVOHMOGQ@dell.com	8285964436	1	4848546742461622	2009/11	user14466	password	86	60000	M
14467	ECXRPG	UMBJTOXZET	3262097584 Dell Way	\N	KSZUDCS	\N	0	UK	2	UMBJTOXZET@dell.com	3262097584	1	3648344487417489	2008/01	user14467	password	79	100000	F
14468	YVXOBR	ADAURYUWSE	8034109230 Dell Way	\N	ORZRURQ	\N	0	Australia	2	ADAURYUWSE@dell.com	8034109230	5	2544117718469351	2012/10	user14468	password	23	20000	M
14469	XZGYRH	BSCTRWPJBD	4364271578 Dell Way	\N	BAVVSLW	\N	0	France	2	BSCTRWPJBD@dell.com	4364271578	1	3886125254444778	2008/02	user14469	password	46	100000	F
14470	JDZBLA	TNUKKJULNV	6545524034 Dell Way	\N	MIRFUOR	\N	0	Canada	2	TNUKKJULNV@dell.com	6545524034	5	3603591138496995	2011/05	user14470	password	28	80000	M
14471	HSUSTN	FNYPWSBJOO	4802988584 Dell Way	\N	SGTMULQ	\N	0	France	2	FNYPWSBJOO@dell.com	4802988584	5	2412828783970326	2012/01	user14471	password	84	60000	F
14472	QJBJXG	XVWUOYECNW	9104709031 Dell Way	\N	IHJDSZO	\N	0	Canada	2	XVWUOYECNW@dell.com	9104709031	4	9454888203646988	2012/08	user14472	password	54	40000	F
14473	VJQTQN	ONHCMMEZIN	8904499672 Dell Way	\N	GSQZREC	\N	0	Germany	2	ONHCMMEZIN@dell.com	8904499672	1	5899996246211231	2010/07	user14473	password	80	80000	F
14474	FJDWWR	JEUVQZVZMC	3054290012 Dell Way	\N	RDBIHEX	\N	0	Canada	2	JEUVQZVZMC@dell.com	3054290012	3	7024813428521157	2011/04	user14474	password	47	20000	M
14475	THKQZT	UTPKTKKFMB	7944299376 Dell Way	\N	INKQSIV	\N	0	UK	2	UTPKTKKFMB@dell.com	7944299376	3	7458972283639014	2008/11	user14475	password	83	80000	M
14476	FAGEUB	YJLRTVXGXG	2935247533 Dell Way	\N	UHXMPSL	\N	0	China	2	YJLRTVXGXG@dell.com	2935247533	1	5187159994151443	2008/01	user14476	password	25	80000	F
14477	DAKXBJ	HNBBJZHGFB	2331511239 Dell Way	\N	ODODVZN	\N	0	Australia	2	HNBBJZHGFB@dell.com	2331511239	5	2502151867840439	2008/01	user14477	password	84	60000	F
14478	XWCZFK	MHLVHSBMUP	3207400498 Dell Way	\N	QJTMJGN	\N	0	Germany	2	MHLVHSBMUP@dell.com	3207400498	4	7365929705090821	2009/08	user14478	password	27	60000	M
14479	ZQMFAZ	NMUUFWHZMX	6120873438 Dell Way	\N	JFJTMWG	\N	0	Russia	2	NMUUFWHZMX@dell.com	6120873438	5	1472739003598690	2008/02	user14479	password	60	80000	F
14480	FFHGEU	SZPXVWXHTG	2942362088 Dell Way	\N	NCAZZGS	\N	0	Germany	2	SZPXVWXHTG@dell.com	2942362088	4	7529707286041231	2009/05	user14480	password	49	40000	M
14481	QRVUMN	TBLPYIXRPK	9268416385 Dell Way	\N	UPKTWDH	\N	0	Australia	2	TBLPYIXRPK@dell.com	9268416385	1	4420769512187690	2009/06	user14481	password	74	100000	F
14482	MRXYFR	AQGYZDQOOK	5337054134 Dell Way	\N	EZDACLC	\N	0	Australia	2	AQGYZDQOOK@dell.com	5337054134	3	3728437021374703	2012/03	user14482	password	29	20000	M
14483	VXRBPS	RVRRZHFORK	9634215300 Dell Way	\N	NVKQHMQ	\N	0	Russia	2	RVRRZHFORK@dell.com	9634215300	5	7297397186048330	2008/02	user14483	password	71	100000	M
14484	QOZFHR	BYIBFOPWYC	3726408885 Dell Way	\N	SJSZWJT	\N	0	South Africa	2	BYIBFOPWYC@dell.com	3726408885	3	1099051376339048	2010/03	user14484	password	84	40000	M
14485	MIBTAC	RIEXXTUVVM	7002261268 Dell Way	\N	FOMBXFW	\N	0	Chile	2	RIEXXTUVVM@dell.com	7002261268	5	6668528262525798	2012/10	user14485	password	89	80000	F
14486	HSBIVS	QZQNSKJOXO	4058332163 Dell Way	\N	DJPBPMH	\N	0	Chile	2	QZQNSKJOXO@dell.com	4058332163	5	1879305832087993	2008/11	user14486	password	73	60000	F
14487	MLMHED	GURZFAOCPR	8944453116 Dell Way	\N	MFSBRZI	\N	0	Australia	2	GURZFAOCPR@dell.com	8944453116	3	2333977220114320	2011/03	user14487	password	58	100000	M
14488	ZLYEOE	ZGEEHSHWJT	5750334050 Dell Way	\N	CCUTCCU	\N	0	UK	2	ZGEEHSHWJT@dell.com	5750334050	5	7487827308010311	2011/06	user14488	password	66	40000	F
14489	CHQRMQ	XQUEJBASVD	6386981082 Dell Way	\N	VPWXSRW	\N	0	Chile	2	XQUEJBASVD@dell.com	6386981082	3	9559494346845896	2008/04	user14489	password	39	60000	F
14490	OFAAVX	RQBASCTNFO	9350145598 Dell Way	\N	CCMVUIC	\N	0	China	2	RQBASCTNFO@dell.com	9350145598	1	5141960074193776	2008/04	user14490	password	19	60000	M
14491	GNXCLP	SNPKQIXWXA	9865653569 Dell Way	\N	ZJWTRYD	\N	0	Japan	2	SNPKQIXWXA@dell.com	9865653569	3	8187468667514623	2009/08	user14491	password	41	40000	M
14492	WDYHSQ	VHBLQYHNZH	7580497847 Dell Way	\N	WVAOUDE	\N	0	Russia	2	VHBLQYHNZH@dell.com	7580497847	5	1727559031452983	2009/04	user14492	password	39	20000	F
14493	LDLDTH	LUSBTAOSHL	2222041831 Dell Way	\N	OIZILEC	\N	0	Canada	2	LUSBTAOSHL@dell.com	2222041831	1	5778262719046325	2010/06	user14493	password	70	60000	M
14494	VBAPIM	KAODBCWIOK	1282364646 Dell Way	\N	RNTCSWH	\N	0	South Africa	2	KAODBCWIOK@dell.com	1282364646	5	3419934499543160	2010/07	user14494	password	80	40000	F
14495	XLAFXK	GLOHOLQCWH	6031343862 Dell Way	\N	QPKILSE	\N	0	France	2	GLOHOLQCWH@dell.com	6031343862	3	9938996642827988	2008/04	user14495	password	46	60000	F
14496	VNLTYR	ENZTYQVUYM	5060120005 Dell Way	\N	KJVWBAI	\N	0	Japan	2	ENZTYQVUYM@dell.com	5060120005	2	7776156445499510	2011/09	user14496	password	38	100000	M
14497	UKHTBL	GAEERAYPNI	8722829292 Dell Way	\N	YIEAINR	\N	0	Russia	2	GAEERAYPNI@dell.com	8722829292	3	5887118809856475	2010/09	user14497	password	54	20000	F
14498	XKGYWM	ZBRQBQGPZF	3592207545 Dell Way	\N	XEFGRWB	\N	0	Germany	2	ZBRQBQGPZF@dell.com	3592207545	3	2144532235804945	2012/02	user14498	password	36	60000	M
14499	RSYNFX	OWOQNUFMAD	1096214466 Dell Way	\N	QFKICLW	\N	0	China	2	OWOQNUFMAD@dell.com	1096214466	1	4234498599544168	2008/04	user14499	password	78	20000	M
14500	OZLTXZ	QMQDHVQHZG	5201623307 Dell Way	\N	MJPPUMZ	\N	0	Russia	2	QMQDHVQHZG@dell.com	5201623307	2	9047693084459752	2011/03	user14500	password	88	80000	M
14501	ZBMWBC	JRGQMWXMCK	3875490429 Dell Way	\N	VRAPDZK	\N	0	Japan	2	JRGQMWXMCK@dell.com	3875490429	2	4091345827095211	2010/04	user14501	password	89	20000	F
14502	BRDCTM	TZCGVASYKN	8655212635 Dell Way	\N	QKDUKOK	\N	0	Russia	2	TZCGVASYKN@dell.com	8655212635	4	2856243506539613	2008/09	user14502	password	47	40000	M
14503	BMWVYP	VBVRBOPMCG	2569766790 Dell Way	\N	WGAHULA	\N	0	Japan	2	VBVRBOPMCG@dell.com	2569766790	2	7804578221868724	2012/08	user14503	password	26	80000	M
14504	PNNNDI	PZZQNPCPVZ	5274028198 Dell Way	\N	WVGQGGH	\N	0	France	2	PZZQNPCPVZ@dell.com	5274028198	1	4113663063384593	2008/02	user14504	password	19	80000	M
14505	OHGRQV	QPMEFOUAOQ	6087753119 Dell Way	\N	WVGDCNP	\N	0	Germany	2	QPMEFOUAOQ@dell.com	6087753119	5	6817534252069891	2011/12	user14505	password	48	60000	F
14506	SSEIOU	YAYDPTEDJA	6964882586 Dell Way	\N	ZQEBETP	\N	0	Russia	2	YAYDPTEDJA@dell.com	6964882586	2	4954754793085158	2011/09	user14506	password	82	20000	F
14507	PGSDAQ	EZUTTYXCYX	8143127888 Dell Way	\N	SDYXWOQ	\N	0	Germany	2	EZUTTYXCYX@dell.com	8143127888	1	2153499103616923	2010/12	user14507	password	33	100000	M
14508	MORNFV	MZPFXNIWKB	6660881259 Dell Way	\N	ZIYWWOJ	\N	0	Japan	2	MZPFXNIWKB@dell.com	6660881259	3	2280630806926638	2010/09	user14508	password	90	20000	F
14509	OTRTPE	SFKQSTMDUM	3000095954 Dell Way	\N	MSIJHSA	\N	0	UK	2	SFKQSTMDUM@dell.com	3000095954	1	5409693140536547	2012/02	user14509	password	61	20000	M
14510	JVLZAE	EKUXDHAYTN	1529556073 Dell Way	\N	QCWYVXW	\N	0	Australia	2	EKUXDHAYTN@dell.com	1529556073	2	9831312421709300	2009/12	user14510	password	26	100000	F
14511	YJGYNL	IHIMOJKIWB	2882409578 Dell Way	\N	LSAGPWH	\N	0	Japan	2	IHIMOJKIWB@dell.com	2882409578	2	8847134924493731	2008/05	user14511	password	76	60000	F
14512	ESGSDP	ZLBOVMXROI	1935295641 Dell Way	\N	JOOYKWP	\N	0	Japan	2	ZLBOVMXROI@dell.com	1935295641	3	7910386288072915	2010/04	user14512	password	33	80000	F
14513	XADBPD	NRSIDPZRYJ	4597369477 Dell Way	\N	GNIQJXG	\N	0	France	2	NRSIDPZRYJ@dell.com	4597369477	1	9422901955898852	2011/03	user14513	password	70	20000	F
14514	SGFIKS	ZCBDSAURJA	9883513548 Dell Way	\N	ERRNPYZ	\N	0	Australia	2	ZCBDSAURJA@dell.com	9883513548	5	7178118131589145	2009/08	user14514	password	77	60000	F
14515	CQRMJR	PKUILPZVPE	6624893428 Dell Way	\N	NHSCGSD	\N	0	Chile	2	PKUILPZVPE@dell.com	6624893428	5	5261139555834234	2009/08	user14515	password	81	80000	M
14516	MIEVZU	GTCRICMYGZ	1318833418 Dell Way	\N	GZCNRFT	\N	0	Chile	2	GTCRICMYGZ@dell.com	1318833418	2	5951446429826320	2011/02	user14516	password	31	40000	M
14517	NOLMIR	GLJPNWOUWU	3324131697 Dell Way	\N	TYHKEBS	\N	0	Chile	2	GLJPNWOUWU@dell.com	3324131697	2	8892373753245921	2009/06	user14517	password	34	100000	M
14518	TJLCAR	NKHBGVWCQP	9546229180 Dell Way	\N	BXAFZSL	\N	0	Chile	2	NKHBGVWCQP@dell.com	9546229180	2	6140777441207320	2009/07	user14518	password	54	40000	F
14519	WTKXLY	HSZNOVPELR	6962192791 Dell Way	\N	CLWBEIH	\N	0	Canada	2	HSZNOVPELR@dell.com	6962192791	5	5455164906568825	2009/05	user14519	password	77	60000	F
14520	OZDAXK	TXYHTOMFFO	7849570492 Dell Way	\N	RCQVLXY	\N	0	Australia	2	TXYHTOMFFO@dell.com	7849570492	3	3871717353817076	2008/04	user14520	password	81	40000	M
14521	VMVTXP	RVXKKJQQYH	5295932496 Dell Way	\N	SOCELBG	\N	0	Chile	2	RVXKKJQQYH@dell.com	5295932496	3	4066220632288605	2011/06	user14521	password	67	60000	F
14522	DKABZS	WWCHGSXEAQ	6550350690 Dell Way	\N	SCUEEBK	\N	0	Japan	2	WWCHGSXEAQ@dell.com	6550350690	4	4250420305412263	2008/06	user14522	password	84	40000	M
14523	IJQHBN	EEULXSPXII	6904574440 Dell Way	\N	ADNEEXV	\N	0	Russia	2	EEULXSPXII@dell.com	6904574440	1	8524820296093822	2008/02	user14523	password	30	80000	F
14524	OHSPUX	UPIRHXPQGQ	8144851048 Dell Way	\N	TTUXQQR	\N	0	China	2	UPIRHXPQGQ@dell.com	8144851048	3	4513778219465166	2012/09	user14524	password	22	40000	F
14525	JZWEWQ	TFIBDYSJOM	6368230429 Dell Way	\N	CJJTZBB	\N	0	Russia	2	TFIBDYSJOM@dell.com	6368230429	3	6915306176990271	2009/06	user14525	password	86	60000	M
14526	YKAVBU	AJWDHOMWAP	8154685774 Dell Way	\N	FKIFMJZ	\N	0	Australia	2	AJWDHOMWAP@dell.com	8154685774	4	4319381621666253	2009/07	user14526	password	84	20000	M
14527	IEIJYJ	TUMBJZXJOD	9412577693 Dell Way	\N	UWIGGHI	\N	0	Australia	2	TUMBJZXJOD@dell.com	9412577693	4	3860620925202966	2010/08	user14527	password	51	20000	M
14528	PJHOSB	IECREABSDW	2173499062 Dell Way	\N	PLCVTLV	\N	0	Japan	2	IECREABSDW@dell.com	2173499062	1	2860679733566940	2011/08	user14528	password	34	80000	F
14529	OZUGAD	LDVPDWIGTX	7459140449 Dell Way	\N	SWSMHOE	\N	0	France	2	LDVPDWIGTX@dell.com	7459140449	2	2409412697423249	2009/08	user14529	password	78	60000	F
14530	VJLVMX	YHMCEVIXSB	1759195288 Dell Way	\N	TKNBZSL	\N	0	Japan	2	YHMCEVIXSB@dell.com	1759195288	4	1232323879841715	2011/06	user14530	password	61	100000	F
14531	YICKFB	SSDWNLUGNN	6787271126 Dell Way	\N	QAOQTAH	\N	0	South Africa	2	SSDWNLUGNN@dell.com	6787271126	2	5566530187148601	2008/12	user14531	password	45	40000	M
14532	SLHXMA	QPWEARKOEB	3768091717 Dell Way	\N	OTRHUZC	\N	0	France	2	QPWEARKOEB@dell.com	3768091717	4	5755023737438024	2009/01	user14532	password	81	20000	M
14533	HKQTKG	IHKJYVXDWM	5671780953 Dell Way	\N	XNUSNXD	\N	0	South Africa	2	IHKJYVXDWM@dell.com	5671780953	4	1450438522733748	2010/07	user14533	password	30	40000	M
14534	PVPZCY	HNIGIGJFSH	8267902240 Dell Way	\N	SNZGKDB	\N	0	UK	2	HNIGIGJFSH@dell.com	8267902240	1	5038044541142881	2009/04	user14534	password	66	20000	M
14535	NUVPSC	DBILHSQAZJ	7688601037 Dell Way	\N	NZPYCQW	\N	0	UK	2	DBILHSQAZJ@dell.com	7688601037	2	3420877593569458	2008/12	user14535	password	51	100000	F
14536	GRCZUF	ADRHVIHVRV	9238707659 Dell Way	\N	VHTYYPW	\N	0	Japan	2	ADRHVIHVRV@dell.com	9238707659	1	7222471043467522	2012/07	user14536	password	56	40000	M
14537	FMUZSU	CJBYRJUJEP	5486664731 Dell Way	\N	RYNQNJI	\N	0	France	2	CJBYRJUJEP@dell.com	5486664731	1	4113642246928066	2008/07	user14537	password	71	100000	M
14538	FRSXLV	HNUZWOIBEA	9610259972 Dell Way	\N	ZSQNCYZ	\N	0	Germany	2	HNUZWOIBEA@dell.com	9610259972	2	6949954659678043	2010/01	user14538	password	57	40000	F
14539	FYDQTL	DNKZCTBGTA	8242871718 Dell Way	\N	ZKNBIMR	\N	0	China	2	DNKZCTBGTA@dell.com	8242871718	2	8133426103740931	2012/11	user14539	password	19	20000	F
14540	YGRSRV	GBVIUWPOWO	6295845990 Dell Way	\N	YKQHXHP	\N	0	Russia	2	GBVIUWPOWO@dell.com	6295845990	2	5944739834405482	2010/05	user14540	password	64	60000	F
14541	XEBOAH	QVPKREZOTX	2349675598 Dell Way	\N	ZJEWQUP	\N	0	Chile	2	QVPKREZOTX@dell.com	2349675598	1	6978909214958549	2010/10	user14541	password	30	100000	M
14542	JYFJFV	FVGXZFLTDL	1109748004 Dell Way	\N	CHHSBWY	\N	0	Chile	2	FVGXZFLTDL@dell.com	1109748004	3	7898463521152736	2011/10	user14542	password	65	60000	F
14543	PQMUMS	PTPPYBIBML	7075025349 Dell Way	\N	JUDLRBR	\N	0	Japan	2	PTPPYBIBML@dell.com	7075025349	3	5154506136197597	2010/02	user14543	password	83	60000	M
14544	OBMATC	UJRTKAVWLE	7708163406 Dell Way	\N	RPQIRHA	\N	0	China	2	UJRTKAVWLE@dell.com	7708163406	3	8024913633242250	2012/05	user14544	password	43	60000	M
14545	KZYEBT	NTMYUHUGMM	3568304357 Dell Way	\N	VCUMKVV	\N	0	Canada	2	NTMYUHUGMM@dell.com	3568304357	4	9954493641853334	2011/12	user14545	password	55	60000	F
14546	NNOOHB	ITZDAUJNHE	1992963232 Dell Way	\N	PBRAXNE	\N	0	Canada	2	ITZDAUJNHE@dell.com	1992963232	1	8478890031576157	2008/09	user14546	password	47	60000	F
14547	YZTFBC	ZBGAVPNDUD	5578933182 Dell Way	\N	FMDCZIG	\N	0	Australia	2	ZBGAVPNDUD@dell.com	5578933182	1	2285141716711223	2008/06	user14547	password	59	40000	F
14548	ODRPGQ	QMQMCEPWHU	3093331044 Dell Way	\N	ILWHTDJ	\N	0	Chile	2	QMQMCEPWHU@dell.com	3093331044	3	5261024216655642	2011/02	user14548	password	80	20000	M
14549	AWGGMW	TDJVHYRPTA	3007628741 Dell Way	\N	AQIUUSC	\N	0	Australia	2	TDJVHYRPTA@dell.com	3007628741	3	7686807398684324	2009/05	user14549	password	85	100000	F
14550	UFRGCK	KLFSKXHDYI	7926935190 Dell Way	\N	UGDOYFO	\N	0	Canada	2	KLFSKXHDYI@dell.com	7926935190	2	5509700615424663	2008/03	user14550	password	52	60000	F
14551	RGGTRR	EWJPURSSAN	9523804052 Dell Way	\N	ZEBYJQD	\N	0	Canada	2	EWJPURSSAN@dell.com	9523804052	4	3951962388120592	2008/02	user14551	password	84	20000	M
14552	ELNVDS	SNHMFAFFNE	8722444307 Dell Way	\N	JODTFGX	\N	0	Canada	2	SNHMFAFFNE@dell.com	8722444307	2	4010402592830360	2012/02	user14552	password	56	80000	F
14553	ZFECXW	PEJVEOARTK	3973712324 Dell Way	\N	GWEMDCQ	\N	0	UK	2	PEJVEOARTK@dell.com	3973712324	5	9267516105901452	2010/06	user14553	password	63	100000	F
14554	VZOSVE	XFZCTAUNKA	1600429075 Dell Way	\N	KPMNRDM	\N	0	Australia	2	XFZCTAUNKA@dell.com	1600429075	3	5545181463006884	2010/01	user14554	password	41	100000	M
14555	HOPDSM	IRPCRJQCKA	4822195698 Dell Way	\N	SXNKAAK	\N	0	Australia	2	IRPCRJQCKA@dell.com	4822195698	5	6522785536479206	2010/03	user14555	password	61	40000	M
14556	DWRWJA	OYDFHTISTB	7838824645 Dell Way	\N	PHLPIWR	\N	0	Russia	2	OYDFHTISTB@dell.com	7838824645	2	2645856073126197	2012/11	user14556	password	53	60000	F
14557	JFXTGL	RJRZDZRXBH	8527025243 Dell Way	\N	EMWMIOF	\N	0	Australia	2	RJRZDZRXBH@dell.com	8527025243	3	1801329590380191	2011/11	user14557	password	63	80000	F
14558	WQZCBR	MTRPTJMUQR	7975852933 Dell Way	\N	GNDPBJR	\N	0	South Africa	2	MTRPTJMUQR@dell.com	7975852933	4	6552529759239406	2011/05	user14558	password	45	100000	F
14559	AXJCOV	VFKOOXIFOP	6900659371 Dell Way	\N	SSFTCWQ	\N	0	South Africa	2	VFKOOXIFOP@dell.com	6900659371	2	5819140003528446	2008/08	user14559	password	50	40000	M
14560	IRTXMP	DXESVMXKCP	3367446845 Dell Way	\N	CHJFEZC	\N	0	South Africa	2	DXESVMXKCP@dell.com	3367446845	4	9009865710511804	2012/01	user14560	password	32	60000	F
14561	WIIIYL	GCDBPALRQO	5355057561 Dell Way	\N	ZZUEZWZ	\N	0	Chile	2	GCDBPALRQO@dell.com	5355057561	5	2274897052906453	2010/01	user14561	password	69	100000	M
14562	BHHZTN	BWOQXAINOH	3766540474 Dell Way	\N	NILMFLS	\N	0	Japan	2	BWOQXAINOH@dell.com	3766540474	5	3183771347627044	2009/07	user14562	password	33	40000	M
14563	MPPFCQ	CRHARPOGWB	2336438490 Dell Way	\N	PIOUTHM	\N	0	Australia	2	CRHARPOGWB@dell.com	2336438490	4	4969524301588536	2011/12	user14563	password	73	40000	F
14564	IYRLPT	CWUULIAIKQ	6640706651 Dell Way	\N	QYKKGXL	\N	0	China	2	CWUULIAIKQ@dell.com	6640706651	5	2037878376897424	2010/08	user14564	password	51	100000	M
14565	KRKZLN	VFHGOIPYYF	9390064903 Dell Way	\N	XJPDGBO	\N	0	South Africa	2	VFHGOIPYYF@dell.com	9390064903	4	4942201593890786	2010/02	user14565	password	49	60000	M
14566	CZMNMI	TUPHCEGAJE	5600993794 Dell Way	\N	JZIQAWM	\N	0	UK	2	TUPHCEGAJE@dell.com	5600993794	5	5811963795218617	2011/05	user14566	password	24	20000	F
14567	BQZOZT	IOAKSHLCLV	8791571841 Dell Way	\N	CTLCPYB	\N	0	Canada	2	IOAKSHLCLV@dell.com	8791571841	4	7657626389525831	2009/09	user14567	password	82	80000	M
14568	NSHMLP	BMATTMWEHY	7545791554 Dell Way	\N	XSBNQDQ	\N	0	Germany	2	BMATTMWEHY@dell.com	7545791554	2	7716992652043701	2010/04	user14568	password	50	20000	M
14569	DMHPBI	BCCUOYZVXW	4407243567 Dell Way	\N	OYKFBAS	\N	0	Russia	2	BCCUOYZVXW@dell.com	4407243567	3	2959484455641359	2011/11	user14569	password	46	60000	F
14570	WSQYAS	ACMPBLLZIZ	4038047140 Dell Way	\N	XSEZTXU	\N	0	Canada	2	ACMPBLLZIZ@dell.com	4038047140	5	7773085588589311	2009/05	user14570	password	30	40000	F
14571	WYEWQF	ZCUBOFAXFY	7289850543 Dell Way	\N	QKYJHSM	\N	0	Japan	2	ZCUBOFAXFY@dell.com	7289850543	2	8666401679627598	2008/05	user14571	password	28	40000	F
14572	CMDSSD	VMFKSGHYEX	1208966436 Dell Way	\N	ICHPVUF	\N	0	Germany	2	VMFKSGHYEX@dell.com	1208966436	1	6355942471418530	2010/03	user14572	password	85	80000	F
14573	KWZDAV	QFFJMMHQKP	5340331617 Dell Way	\N	TRFOLKC	\N	0	France	2	QFFJMMHQKP@dell.com	5340331617	4	9233841776382180	2011/08	user14573	password	63	100000	F
14574	MZDMUT	SZCEMKVWZP	9210365075 Dell Way	\N	OFEAQGM	\N	0	Canada	2	SZCEMKVWZP@dell.com	9210365075	2	8172036829404534	2010/01	user14574	password	74	60000	M
14575	TRZNKS	NNWZXSWXHK	3667386629 Dell Way	\N	CLKTSXV	\N	0	Japan	2	NNWZXSWXHK@dell.com	3667386629	4	2021236380562186	2009/05	user14575	password	64	100000	F
14576	HVRSNF	GKFDCBBKME	4416286861 Dell Way	\N	WWXOUTE	\N	0	Australia	2	GKFDCBBKME@dell.com	4416286861	2	4524597676470876	2011/12	user14576	password	33	100000	F
14577	AQYOWE	YBIBCKMPOJ	4205006739 Dell Way	\N	LLXGFBI	\N	0	Germany	2	YBIBCKMPOJ@dell.com	4205006739	4	4288218476809561	2009/11	user14577	password	41	60000	M
14578	YLMVPL	WYMZIZOWIA	3280704860 Dell Way	\N	IFGNHOC	\N	0	Japan	2	WYMZIZOWIA@dell.com	3280704860	3	9404286360833796	2008/10	user14578	password	49	20000	M
14579	WPOMAK	KNJSMXPUXX	9872343434 Dell Way	\N	AELISNZ	\N	0	UK	2	KNJSMXPUXX@dell.com	9872343434	5	2177662328351289	2011/05	user14579	password	35	60000	F
14580	VARWLB	JUUWSKRQIS	9661473144 Dell Way	\N	UTAMHAL	\N	0	Chile	2	JUUWSKRQIS@dell.com	9661473144	3	1186221367213875	2009/10	user14580	password	55	60000	M
14581	OFMZHW	TCSMMJCUBW	4641214286 Dell Way	\N	NCJVDVB	\N	0	Canada	2	TCSMMJCUBW@dell.com	4641214286	1	4799795900471509	2009/08	user14581	password	87	100000	F
14582	EJCLGW	NZIAIKUKHI	3759192809 Dell Way	\N	NQDRLFT	\N	0	South Africa	2	NZIAIKUKHI@dell.com	3759192809	1	1832276188768446	2012/02	user14582	password	88	20000	F
14583	JETPAH	OIIXTCIALV	5154574834 Dell Way	\N	RPNDUHZ	\N	0	Canada	2	OIIXTCIALV@dell.com	5154574834	1	1185273767914623	2011/01	user14583	password	23	100000	F
14584	FRAGZO	PHMIKUJWQB	3544269882 Dell Way	\N	LDEGKEJ	\N	0	South Africa	2	PHMIKUJWQB@dell.com	3544269882	2	5256424010265619	2009/06	user14584	password	46	80000	M
14585	BUXBJN	IVWTPFPFHB	1486760347 Dell Way	\N	JMHTRRQ	\N	0	UK	2	IVWTPFPFHB@dell.com	1486760347	1	3634462060872465	2010/06	user14585	password	22	20000	M
14586	VCQEQZ	ZMSPSIVZJF	7344270247 Dell Way	\N	LRZDJPB	\N	0	France	2	ZMSPSIVZJF@dell.com	7344270247	2	9286166070960464	2009/05	user14586	password	25	80000	F
14587	FKLVJK	IBAAKWZUBL	9791154082 Dell Way	\N	MAOVPQG	\N	0	China	2	IBAAKWZUBL@dell.com	9791154082	1	5663428998552263	2009/04	user14587	password	39	80000	F
14588	RBIAMQ	CNQMJQGKCS	9373359497 Dell Way	\N	KQOAGUJ	\N	0	Chile	2	CNQMJQGKCS@dell.com	9373359497	5	6639422137290240	2008/02	user14588	password	36	80000	M
14589	IZWUQY	HGLQXSBZKM	7594680584 Dell Way	\N	QZNWTWD	\N	0	Japan	2	HGLQXSBZKM@dell.com	7594680584	4	8770294577348978	2012/01	user14589	password	57	80000	F
14590	NOCENK	LYBIRDICPY	7144638844 Dell Way	\N	BDVUZYL	\N	0	Russia	2	LYBIRDICPY@dell.com	7144638844	2	6507775681093336	2011/11	user14590	password	42	20000	F
14591	XDOLNZ	KPIBSQDIOE	7513756448 Dell Way	\N	LJYLHKE	\N	0	UK	2	KPIBSQDIOE@dell.com	7513756448	4	7049212855286897	2010/02	user14591	password	67	100000	F
14592	UNLIMV	YUXRKAZZEL	8659060377 Dell Way	\N	IDXQOBQ	\N	0	Chile	2	YUXRKAZZEL@dell.com	8659060377	2	8621235786005855	2012/12	user14592	password	77	100000	M
14593	ILDVHB	PESAESZJDI	8870853652 Dell Way	\N	MAZBCPI	\N	0	UK	2	PESAESZJDI@dell.com	8870853652	1	9267252210061998	2012/12	user14593	password	83	80000	F
14594	ITCPUS	TNTYFTHICU	3598602062 Dell Way	\N	JBVMQDL	\N	0	Germany	2	TNTYFTHICU@dell.com	3598602062	2	4181398329325020	2009/04	user14594	password	89	60000	M
14595	SRFNJY	ADXFWEOYZY	2643083645 Dell Way	\N	AUKQYVD	\N	0	Chile	2	ADXFWEOYZY@dell.com	2643083645	3	5296333495061845	2010/06	user14595	password	19	20000	F
14596	RFSBES	EBXBGMAFKB	3978982982 Dell Way	\N	AURYQVE	\N	0	South Africa	2	EBXBGMAFKB@dell.com	3978982982	4	3198491679504514	2012/09	user14596	password	37	20000	F
14597	MSLRKQ	TISZVSFFTG	1383482652 Dell Way	\N	ZLFQHJL	\N	0	Japan	2	TISZVSFFTG@dell.com	1383482652	4	4744105785619468	2011/12	user14597	password	48	20000	F
14598	DNCODV	XVVSOAXIHX	6627007826 Dell Way	\N	UMNBWYR	\N	0	UK	2	XVVSOAXIHX@dell.com	6627007826	1	6698120923712850	2010/06	user14598	password	71	100000	M
14599	GCEKXB	GSUVTRDAPY	7516659026 Dell Way	\N	NCZJBQH	\N	0	Japan	2	GSUVTRDAPY@dell.com	7516659026	5	3269907514564693	2009/08	user14599	password	36	100000	M
14600	IAHGCO	ZXJTPNUELH	8718172429 Dell Way	\N	HLRICYA	\N	0	South Africa	2	ZXJTPNUELH@dell.com	8718172429	2	1259008225984871	2010/07	user14600	password	82	60000	M
14601	XSCAGC	XQVMDPRPWY	6024578455 Dell Way	\N	ANGCMHX	\N	0	China	2	XQVMDPRPWY@dell.com	6024578455	5	8502441557589919	2008/10	user14601	password	35	100000	M
14602	YBTFDR	VYEZNVOKUP	6104209578 Dell Way	\N	YBSKIQT	\N	0	South Africa	2	VYEZNVOKUP@dell.com	6104209578	3	9715535313822330	2009/10	user14602	password	83	20000	M
14603	YXYBPT	ATTNPHYJXW	6302579763 Dell Way	\N	LPHTFAQ	\N	0	Russia	2	ATTNPHYJXW@dell.com	6302579763	4	2554604895878583	2009/07	user14603	password	40	20000	F
14604	FCNUWN	OPBEXZOUWZ	1156422754 Dell Way	\N	JDTPDKJ	\N	0	Russia	2	OPBEXZOUWZ@dell.com	1156422754	3	2220445489976555	2010/11	user14604	password	38	20000	F
14605	JNWFBK	VCPSCDMYDW	3871401569 Dell Way	\N	CWLGHUZ	\N	0	Chile	2	VCPSCDMYDW@dell.com	3871401569	1	8456015306524933	2008/05	user14605	password	78	40000	M
14606	JBZKMV	NBNPFAOIWR	9883154761 Dell Way	\N	FHXMCWU	\N	0	France	2	NBNPFAOIWR@dell.com	9883154761	4	6150195854716004	2009/06	user14606	password	74	20000	M
14607	VDEIYS	JMIPNXXJOD	9888907458 Dell Way	\N	RLPUIKF	\N	0	China	2	JMIPNXXJOD@dell.com	9888907458	4	7157014699652792	2010/07	user14607	password	78	40000	F
14608	ZKSYCB	LKRYHOIVSA	7895024124 Dell Way	\N	HIUPSZX	\N	0	Japan	2	LKRYHOIVSA@dell.com	7895024124	3	1985645168460905	2009/06	user14608	password	40	80000	F
14609	SKIVMT	FDSNSAJKAR	7804330716 Dell Way	\N	TVGLVED	\N	0	Germany	2	FDSNSAJKAR@dell.com	7804330716	2	9057155180256816	2008/07	user14609	password	62	60000	F
14610	AXBMRH	QJVJJETKVN	3762052258 Dell Way	\N	FCYAGBP	\N	0	Australia	2	QJVJJETKVN@dell.com	3762052258	3	2811405454296619	2012/02	user14610	password	74	20000	F
14611	REPIMG	RHPBMJLIWQ	7792772357 Dell Way	\N	LURSWGS	\N	0	Canada	2	RHPBMJLIWQ@dell.com	7792772357	5	1344225426204502	2012/09	user14611	password	29	100000	F
14612	IOSVUK	DKLPTXYPOJ	7194055884 Dell Way	\N	KFBHMTM	\N	0	Chile	2	DKLPTXYPOJ@dell.com	7194055884	3	1771844460628926	2009/08	user14612	password	20	80000	F
14613	PLVKWY	UHOOFMETVO	8599904005 Dell Way	\N	YWWLQIR	\N	0	China	2	UHOOFMETVO@dell.com	8599904005	4	7491020947229118	2010/10	user14613	password	52	60000	F
14614	YJUUIP	CWDHIHAEWZ	8761094977 Dell Way	\N	BSKSBCB	\N	0	South Africa	2	CWDHIHAEWZ@dell.com	8761094977	4	4684603279456496	2011/03	user14614	password	85	20000	F
14615	HWYPMA	LPHUWIZSHB	6283294400 Dell Way	\N	LSTNVVK	\N	0	Japan	2	LPHUWIZSHB@dell.com	6283294400	5	4049468594137579	2012/09	user14615	password	48	20000	F
14616	HZQTAC	IIXFQWYYXK	1977752948 Dell Way	\N	QRXLMHC	\N	0	Australia	2	IIXFQWYYXK@dell.com	1977752948	3	9258442255668344	2012/11	user14616	password	85	100000	F
14617	XNXXPG	FMLVJKTHUK	4635754071 Dell Way	\N	YSVLZYO	\N	0	Canada	2	FMLVJKTHUK@dell.com	4635754071	3	9568416782189162	2009/05	user14617	password	78	60000	F
14618	IIEYOJ	KAFTLZAFJZ	5118779677 Dell Way	\N	XFLXDZA	\N	0	Germany	2	KAFTLZAFJZ@dell.com	5118779677	5	8348098718095572	2012/10	user14618	password	35	20000	F
14619	OHBDRL	DXFOWGUFGS	6252449294 Dell Way	\N	KSPOSQC	\N	0	Canada	2	DXFOWGUFGS@dell.com	6252449294	5	1056394144427031	2009/02	user14619	password	27	60000	M
14620	LOVCAY	AGNWMHBTAM	1136149344 Dell Way	\N	LPADFCH	\N	0	South Africa	2	AGNWMHBTAM@dell.com	1136149344	2	2725921831093728	2008/06	user14620	password	69	100000	M
14621	GRZHQZ	NEVZMXSMJE	9259538151 Dell Way	\N	BJHHMPD	\N	0	Germany	2	NEVZMXSMJE@dell.com	9259538151	2	6986264376901091	2009/01	user14621	password	56	40000	F
14622	FFOWFB	ABBMZTYIYA	7837703134 Dell Way	\N	SGIFVLS	\N	0	Russia	2	ABBMZTYIYA@dell.com	7837703134	2	2066565092653036	2011/11	user14622	password	43	20000	F
14623	PPZUQZ	WRMVLKDJLW	2470622081 Dell Way	\N	PUBLFUF	\N	0	UK	2	WRMVLKDJLW@dell.com	2470622081	2	7773663684260101	2008/09	user14623	password	75	20000	F
14624	JEBAEX	RQSDBWNMSC	1832550126 Dell Way	\N	HUOMPTM	\N	0	Russia	2	RQSDBWNMSC@dell.com	1832550126	2	8424925214145333	2011/01	user14624	password	18	20000	F
14625	ECKIZC	YSGAOTNHWU	9817753725 Dell Way	\N	CKHRETL	\N	0	Chile	2	YSGAOTNHWU@dell.com	9817753725	2	1436242730356752	2008/04	user14625	password	23	40000	F
14626	EUUDXT	VDTKWGRTAT	2401095121 Dell Way	\N	DILIBXP	\N	0	Australia	2	VDTKWGRTAT@dell.com	2401095121	4	1356759862508624	2010/09	user14626	password	49	100000	M
14627	GRADKW	HEGEKXXLRB	6804415601 Dell Way	\N	TDJVAZW	\N	0	Canada	2	HEGEKXXLRB@dell.com	6804415601	5	6462953126989306	2009/05	user14627	password	54	40000	M
14628	EHTOEA	TKEEIBPZCJ	9653751106 Dell Way	\N	DMFDMBI	\N	0	Canada	2	TKEEIBPZCJ@dell.com	9653751106	5	5518297367729247	2009/05	user14628	password	74	100000	M
14629	CPEGQX	QVBZWRYZBC	5187026872 Dell Way	\N	MGFYHOC	\N	0	Chile	2	QVBZWRYZBC@dell.com	5187026872	3	6063875834923238	2012/05	user14629	password	50	60000	F
14630	BQRRNI	MOHJFGJHIW	5303327920 Dell Way	\N	NOVVCXB	\N	0	Germany	2	MOHJFGJHIW@dell.com	5303327920	4	5036878153216094	2012/01	user14630	password	84	40000	F
14631	NYVBHI	POSVUCCDYQ	2327447948 Dell Way	\N	RTLUQNJ	\N	0	Canada	2	POSVUCCDYQ@dell.com	2327447948	5	9630237789824606	2009/09	user14631	password	35	40000	F
14632	EFHLNX	AGTVIWYGMQ	6165187504 Dell Way	\N	AXKQLUT	\N	0	Germany	2	AGTVIWYGMQ@dell.com	6165187504	4	8261182506103069	2009/12	user14632	password	31	60000	F
14633	JVPXTP	EMKMIJTVZT	8942156177 Dell Way	\N	TKKEEET	\N	0	Russia	2	EMKMIJTVZT@dell.com	8942156177	3	1258398693986237	2012/09	user14633	password	59	100000	F
14634	KPADFF	PQRYZKUYEN	9872581560 Dell Way	\N	JORNSLG	\N	0	Germany	2	PQRYZKUYEN@dell.com	9872581560	2	4786801964044571	2011/11	user14634	password	47	100000	F
14635	ZWJFBZ	VTYUESTIFC	2173700931 Dell Way	\N	WXPOIWD	\N	0	China	2	VTYUESTIFC@dell.com	2173700931	3	1370533441659063	2012/12	user14635	password	82	40000	M
14636	TPEVOZ	ONTTFMBLOY	2642516316 Dell Way	\N	IEMRAQZ	\N	0	Canada	2	ONTTFMBLOY@dell.com	2642516316	1	2012485799379646	2008/11	user14636	password	42	20000	M
14637	YGMMFB	AZVFLWQAVZ	6960826931 Dell Way	\N	EHQEYQH	\N	0	Canada	2	AZVFLWQAVZ@dell.com	6960826931	3	3283289000857621	2010/09	user14637	password	44	40000	M
14638	QSEWUE	VPJHMAHHZL	4059532707 Dell Way	\N	OQQMGXP	\N	0	UK	2	VPJHMAHHZL@dell.com	4059532707	5	5436737430747599	2008/03	user14638	password	71	80000	M
14639	LYSGCN	VMUHMCOMND	1992410789 Dell Way	\N	CEQJCGH	\N	0	France	2	VMUHMCOMND@dell.com	1992410789	4	5564366247970611	2009/07	user14639	password	37	20000	M
14640	FWEHKA	UFIGHXTVBW	3647836175 Dell Way	\N	ZRFBYNM	\N	0	Australia	2	UFIGHXTVBW@dell.com	3647836175	5	4445178925991058	2012/04	user14640	password	59	80000	F
14641	LYTWZN	BHUJEOFFKF	7851569396 Dell Way	\N	XQHWDTX	\N	0	France	2	BHUJEOFFKF@dell.com	7851569396	2	3127289155498147	2008/11	user14641	password	90	60000	F
14642	YGDYUF	FPPKDUQNZN	6144677565 Dell Way	\N	DGJHAHS	\N	0	Russia	2	FPPKDUQNZN@dell.com	6144677565	5	8371416053734721	2010/12	user14642	password	40	80000	M
14643	OWVIBB	XRLBLBOLPS	7156470420 Dell Way	\N	SZATGSN	\N	0	South Africa	2	XRLBLBOLPS@dell.com	7156470420	2	3182016495615244	2011/08	user14643	password	87	60000	F
14644	VJOXLM	OWNZXCLNUD	7816311708 Dell Way	\N	MUWSNKO	\N	0	Chile	2	OWNZXCLNUD@dell.com	7816311708	4	8601004931144417	2010/09	user14644	password	46	80000	M
14645	UELFRZ	BEZZGKMBOY	9997142617 Dell Way	\N	VLRJVFO	\N	0	Germany	2	BEZZGKMBOY@dell.com	9997142617	3	1078961404506117	2011/10	user14645	password	64	40000	M
14646	VTUMSV	RSUYCHZRGV	2521037720 Dell Way	\N	CXEYDTN	\N	0	Canada	2	RSUYCHZRGV@dell.com	2521037720	3	8769641547463835	2012/03	user14646	password	29	60000	F
14647	XIMQDE	IYCLGCCMXE	2345954628 Dell Way	\N	JCCNWQQ	\N	0	Australia	2	IYCLGCCMXE@dell.com	2345954628	3	1024798891507089	2009/08	user14647	password	58	40000	M
14648	WVEAZM	ZCXFEARCFB	6918782135 Dell Way	\N	FHOBYEC	\N	0	Australia	2	ZCXFEARCFB@dell.com	6918782135	1	4526464724447578	2009/08	user14648	password	69	100000	M
14649	NANNMM	QKRUKJXPKC	4407871603 Dell Way	\N	XYEVCHX	\N	0	Russia	2	QKRUKJXPKC@dell.com	4407871603	2	1637899552471935	2008/01	user14649	password	84	60000	M
14650	YCBKPR	VGMGQKWAMT	8311333213 Dell Way	\N	YRPBZNV	\N	0	China	2	VGMGQKWAMT@dell.com	8311333213	5	4328771905507892	2012/10	user14650	password	85	40000	M
14651	AKEPCZ	WOFMYCMLVL	3295736353 Dell Way	\N	DLNCYJL	\N	0	Russia	2	WOFMYCMLVL@dell.com	3295736353	5	6280010244809092	2008/09	user14651	password	87	100000	M
14652	JZIMZE	AFQZHDLDPO	9236785282 Dell Way	\N	OCRNLCH	\N	0	Russia	2	AFQZHDLDPO@dell.com	9236785282	5	7999061111360789	2011/10	user14652	password	61	40000	F
14653	PRQOWR	TMRBPCEERT	4366848561 Dell Way	\N	HIGTLNL	\N	0	China	2	TMRBPCEERT@dell.com	4366848561	2	9984455580357464	2008/10	user14653	password	45	40000	F
14654	BAZXRT	KIUZKYECRM	8629196414 Dell Way	\N	KYFWLQF	\N	0	South Africa	2	KIUZKYECRM@dell.com	8629196414	2	1019631519448012	2011/08	user14654	password	44	20000	M
14655	JAOBTY	JOYUNDWEPH	6282989395 Dell Way	\N	DUEOLJJ	\N	0	Chile	2	JOYUNDWEPH@dell.com	6282989395	2	9516001271549612	2008/10	user14655	password	18	100000	F
14656	AJEUHO	JFIWIFBYNE	5433563706 Dell Way	\N	SRSEBCL	\N	0	Japan	2	JFIWIFBYNE@dell.com	5433563706	2	8278886665590108	2009/05	user14656	password	63	40000	F
14657	ZNGGBP	MKLUQMSDQL	5207682241 Dell Way	\N	VJPWMBN	\N	0	UK	2	MKLUQMSDQL@dell.com	5207682241	2	2872660888824612	2012/12	user14657	password	59	40000	M
14658	COEEDQ	OPKEBDISPD	8439171042 Dell Way	\N	BFAOHNN	\N	0	Russia	2	OPKEBDISPD@dell.com	8439171042	4	6569989988580347	2011/04	user14658	password	86	80000	F
14659	MVOQLC	FWHHAQZPUB	8468462089 Dell Way	\N	VUPCHCV	\N	0	Canada	2	FWHHAQZPUB@dell.com	8468462089	3	8908660721499474	2008/05	user14659	password	57	60000	M
14660	JBNVET	RMARCAHWCC	5535026552 Dell Way	\N	QRFYUBB	\N	0	Japan	2	RMARCAHWCC@dell.com	5535026552	5	7768806958105416	2012/06	user14660	password	36	80000	M
14661	HHQMBI	YBAACIXELN	5247681794 Dell Way	\N	WQMRRNI	\N	0	Canada	2	YBAACIXELN@dell.com	5247681794	1	1826059318613261	2012/04	user14661	password	81	80000	M
14662	ELCFUA	HUBKDYPOML	5845532345 Dell Way	\N	FYDXMMC	\N	0	UK	2	HUBKDYPOML@dell.com	5845532345	1	9175555207766592	2012/01	user14662	password	69	60000	F
14663	DPLYPT	TQDWPSKBEQ	8305552144 Dell Way	\N	AINMUQL	\N	0	China	2	TQDWPSKBEQ@dell.com	8305552144	2	2783631360158324	2012/01	user14663	password	68	20000	F
14664	GODWHW	NLTCEEEJUE	5550592320 Dell Way	\N	RIRMYDV	\N	0	Russia	2	NLTCEEEJUE@dell.com	5550592320	1	6610342071391643	2010/09	user14664	password	71	80000	M
14665	HYVPVJ	AOMESQNNVF	5557855294 Dell Way	\N	VNRTRMN	\N	0	Canada	2	AOMESQNNVF@dell.com	5557855294	1	7593779773451389	2009/11	user14665	password	56	20000	F
14666	LASHJT	VVYOMLBHRW	3451873620 Dell Way	\N	VJQMWDQ	\N	0	China	2	VVYOMLBHRW@dell.com	3451873620	2	6115186803508550	2008/11	user14666	password	71	40000	F
14667	TZQCTL	YRZKDBSUXN	9790569369 Dell Way	\N	ENZARQK	\N	0	UK	2	YRZKDBSUXN@dell.com	9790569369	5	1712156567722559	2012/09	user14667	password	43	40000	F
14668	JVNCHM	TGWXIPRFCW	2928938034 Dell Way	\N	TCWLSGJ	\N	0	Japan	2	TGWXIPRFCW@dell.com	2928938034	3	5979790091048927	2012/10	user14668	password	73	40000	F
14669	OWGWJA	CFXLVPQYLK	6909594387 Dell Way	\N	AIVTOFL	\N	0	Russia	2	CFXLVPQYLK@dell.com	6909594387	5	7233489516191185	2010/10	user14669	password	20	80000	F
14670	XWEGXH	MUSHJJGVTG	5103601886 Dell Way	\N	DPASULM	\N	0	France	2	MUSHJJGVTG@dell.com	5103601886	1	9222855632659048	2009/03	user14670	password	57	60000	F
14671	KSJIZW	CSEMBKIVRL	8669503583 Dell Way	\N	KSEFERQ	\N	0	Japan	2	CSEMBKIVRL@dell.com	8669503583	3	8379420846700669	2008/02	user14671	password	43	40000	M
14672	BPVBLY	TQLVBTQSFB	5409082041 Dell Way	\N	KJGOAXE	\N	0	South Africa	2	TQLVBTQSFB@dell.com	5409082041	1	9514802106190474	2010/05	user14672	password	28	20000	F
14673	TYMEXG	VIBWBSPGUA	7969849923 Dell Way	\N	QBPQZTN	\N	0	France	2	VIBWBSPGUA@dell.com	7969849923	3	1615424753166735	2008/08	user14673	password	31	60000	F
14674	DBNAHJ	JJFLCURWUH	9085365929 Dell Way	\N	YJYXDLK	\N	0	UK	2	JJFLCURWUH@dell.com	9085365929	3	1482476679608225	2010/08	user14674	password	62	100000	M
14675	RJVYSE	HYPKSHGNPF	9716092375 Dell Way	\N	XNDBZNY	\N	0	South Africa	2	HYPKSHGNPF@dell.com	9716092375	1	4319238085765392	2011/08	user14675	password	33	60000	F
14676	OGFHLN	FBXYIEMXJJ	4407630623 Dell Way	\N	LMKKZJH	\N	0	UK	2	FBXYIEMXJJ@dell.com	4407630623	4	6256865383591503	2008/11	user14676	password	90	40000	F
14677	FNTRAY	SYXACJYMTK	7750429639 Dell Way	\N	ZDVZNCY	\N	0	South Africa	2	SYXACJYMTK@dell.com	7750429639	3	9020264517515900	2011/07	user14677	password	30	20000	M
14678	RUKSTC	QQDTZBGSMF	6865260921 Dell Way	\N	WHEJJDG	\N	0	Canada	2	QQDTZBGSMF@dell.com	6865260921	1	7675611594226212	2008/04	user14678	password	75	100000	F
14679	OISHKJ	YNDYPKRBPN	3975287606 Dell Way	\N	JUXTYEW	\N	0	Germany	2	YNDYPKRBPN@dell.com	3975287606	4	7695963865146042	2011/05	user14679	password	65	80000	M
14680	ZKHJUF	XYDNIUPYIY	2557321416 Dell Way	\N	TFSRKOG	\N	0	Russia	2	XYDNIUPYIY@dell.com	2557321416	5	4577282359357923	2010/08	user14680	password	23	60000	M
14681	MVZHAX	FELOYAMGZF	1887146436 Dell Way	\N	MRWXFDQ	\N	0	France	2	FELOYAMGZF@dell.com	1887146436	1	9800519224721940	2011/02	user14681	password	56	40000	M
14682	IIXJGC	NRRMRDTRJG	8189143937 Dell Way	\N	IGDOJTY	\N	0	France	2	NRRMRDTRJG@dell.com	8189143937	5	2920097079593688	2012/06	user14682	password	58	60000	M
14683	XKEDNR	UEEMIXDSDL	9139190031 Dell Way	\N	YGAIAZV	\N	0	South Africa	2	UEEMIXDSDL@dell.com	9139190031	1	7602437885478140	2009/07	user14683	password	35	20000	F
14684	QIPDAJ	HEVQBYIFKH	5044099418 Dell Way	\N	LKPMJKH	\N	0	Chile	2	HEVQBYIFKH@dell.com	5044099418	1	6873043045401574	2008/04	user14684	password	77	60000	M
14685	ECBEMJ	JHZLGHQROC	9145491852 Dell Way	\N	CEOMPWT	\N	0	Australia	2	JHZLGHQROC@dell.com	9145491852	3	1681710985023528	2008/03	user14685	password	60	20000	F
14686	REODNY	LMJSUZKJBM	2177071684 Dell Way	\N	NQYDMSE	\N	0	France	2	LMJSUZKJBM@dell.com	2177071684	2	6291838635690511	2009/10	user14686	password	68	80000	F
14687	WIQJGB	WQURQEARQO	1658203040 Dell Way	\N	IPRVIVF	\N	0	France	2	WQURQEARQO@dell.com	1658203040	5	8314797228202225	2012/06	user14687	password	59	40000	F
14688	XASECP	UWGKAGCRUL	3384122327 Dell Way	\N	HMGPHLA	\N	0	China	2	UWGKAGCRUL@dell.com	3384122327	5	3372901390306652	2011/06	user14688	password	65	20000	F
14689	RVMTKH	PRSQXVHSGP	1437640668 Dell Way	\N	EMEMYFW	\N	0	Chile	2	PRSQXVHSGP@dell.com	1437640668	1	9851116629317404	2010/10	user14689	password	24	80000	F
14690	XHEIPT	ZHKXDSQKHU	3253380035 Dell Way	\N	WLHVQDB	\N	0	Japan	2	ZHKXDSQKHU@dell.com	3253380035	1	2420399277005344	2008/02	user14690	password	87	60000	F
14691	GPKVJK	DTHGLXQSSN	5264231103 Dell Way	\N	DAJUDLM	\N	0	China	2	DTHGLXQSSN@dell.com	5264231103	4	4645262515172362	2011/08	user14691	password	78	80000	M
14692	LBRULU	NTBYRSQKGU	7256889271 Dell Way	\N	KPPOABY	\N	0	Germany	2	NTBYRSQKGU@dell.com	7256889271	2	2072531586978584	2009/03	user14692	password	75	20000	M
14693	WTJIOW	BPVSIMDOGN	3982943172 Dell Way	\N	DWBEXZR	\N	0	Japan	2	BPVSIMDOGN@dell.com	3982943172	5	9004339605569840	2010/08	user14693	password	90	20000	F
14694	TMTIJV	XEOFQRUXEX	6385659503 Dell Way	\N	TGCRGUH	\N	0	Germany	2	XEOFQRUXEX@dell.com	6385659503	1	1640598516911268	2008/03	user14694	password	30	80000	M
14695	QKGAGE	EUKVLETQCN	6904891532 Dell Way	\N	XEEDZMR	\N	0	Germany	2	EUKVLETQCN@dell.com	6904891532	4	7943385254126043	2012/12	user14695	password	48	80000	M
14696	VAPCET	WPPITIZVVW	4699774700 Dell Way	\N	AAZAMRO	\N	0	Canada	2	WPPITIZVVW@dell.com	4699774700	2	9812793562188746	2009/10	user14696	password	72	100000	M
14697	TNRYGO	OVWHEWDZSE	1727902018 Dell Way	\N	ZREMITQ	\N	0	Russia	2	OVWHEWDZSE@dell.com	1727902018	4	1786175763234496	2012/05	user14697	password	18	60000	F
14698	NDCTSQ	PPXTLBTDFT	5399935834 Dell Way	\N	VJGDCWX	\N	0	Canada	2	PPXTLBTDFT@dell.com	5399935834	5	1263204751536250	2012/12	user14698	password	53	100000	M
14699	QBHISW	XPQJRKMWDH	3977918904 Dell Way	\N	GJLIGJN	\N	0	Russia	2	XPQJRKMWDH@dell.com	3977918904	3	6368064534850419	2009/01	user14699	password	60	100000	M
14700	QCZIZX	YPGQATMDBS	1906862700 Dell Way	\N	NMBUVON	\N	0	Canada	2	YPGQATMDBS@dell.com	1906862700	1	5467013883404434	2008/09	user14700	password	41	80000	F
14701	KUSJSR	ZYHASUETMR	2266095153 Dell Way	\N	GOMCCAG	\N	0	Chile	2	ZYHASUETMR@dell.com	2266095153	4	4063450119923800	2012/01	user14701	password	27	40000	F
14702	XXWQOW	PWWHQAACSH	4622296557 Dell Way	\N	RFJUFQZ	\N	0	China	2	PWWHQAACSH@dell.com	4622296557	2	2881447344552725	2010/06	user14702	password	48	100000	F
14703	IWZXTO	TPWJQXMJED	3075443572 Dell Way	\N	POXUFXE	\N	0	Germany	2	TPWJQXMJED@dell.com	3075443572	2	1723189373500645	2011/10	user14703	password	22	20000	F
14704	XBAQQT	GMCXJPHOSW	2976758661 Dell Way	\N	CQRHNVX	\N	0	Russia	2	GMCXJPHOSW@dell.com	2976758661	5	5076400096528232	2008/01	user14704	password	55	20000	M
14705	ODPFWW	RZTBOBPHXS	8614030362 Dell Way	\N	XPZLLWF	\N	0	Japan	2	RZTBOBPHXS@dell.com	8614030362	4	7084251838270575	2012/03	user14705	password	76	100000	M
14706	YKYUGQ	UARJBGQZZO	8710449498 Dell Way	\N	PYZAVFS	\N	0	Japan	2	UARJBGQZZO@dell.com	8710449498	2	5900759058073164	2008/03	user14706	password	44	80000	F
14707	UTXAJS	BBBCIRCHFR	7978473363 Dell Way	\N	FFSBKKS	\N	0	Chile	2	BBBCIRCHFR@dell.com	7978473363	2	3679911413695663	2012/08	user14707	password	24	20000	F
14708	VZKERM	FSONKRUPIA	1354968469 Dell Way	\N	VBBFLUM	\N	0	Chile	2	FSONKRUPIA@dell.com	1354968469	4	2485591377131641	2011/11	user14708	password	33	20000	M
14709	EMWVYC	ONQYELONMJ	8943396656 Dell Way	\N	OOPZICF	\N	0	China	2	ONQYELONMJ@dell.com	8943396656	2	1281213857233524	2011/07	user14709	password	24	60000	M
14710	OIPMLD	ZCCEOQRAAF	7765099642 Dell Way	\N	OPEXSKH	\N	0	Germany	2	ZCCEOQRAAF@dell.com	7765099642	2	4075946887955070	2009/05	user14710	password	75	20000	M
14711	DRLOVL	RXPFOGGOMU	3701891630 Dell Way	\N	ERSWBZL	\N	0	South Africa	2	RXPFOGGOMU@dell.com	3701891630	4	2225622459314763	2011/08	user14711	password	34	80000	M
14712	XBHTNY	RCEFJKUVFY	1771122238 Dell Way	\N	NXVOXHJ	\N	0	Chile	2	RCEFJKUVFY@dell.com	1771122238	3	9095404775813224	2011/09	user14712	password	57	60000	M
14713	PSKDRB	FVHPFCLLAY	4384394126 Dell Way	\N	IWNGDWL	\N	0	Chile	2	FVHPFCLLAY@dell.com	4384394126	2	9257653811946512	2008/11	user14713	password	41	80000	M
14714	ADQRFV	MNLSPWDQVM	5821196394 Dell Way	\N	NISRFEX	\N	0	Germany	2	MNLSPWDQVM@dell.com	5821196394	5	7188105362001807	2010/02	user14714	password	50	100000	F
14715	POVVKI	IVAYSEONQB	4975351698 Dell Way	\N	WJTBOQQ	\N	0	Australia	2	IVAYSEONQB@dell.com	4975351698	2	5626152022276074	2010/10	user14715	password	50	80000	F
14716	ZOEKWN	FXLXBALSCI	4211470288 Dell Way	\N	BVJQLAS	\N	0	South Africa	2	FXLXBALSCI@dell.com	4211470288	2	5078345050103963	2008/08	user14716	password	30	60000	M
14717	SRBPEG	MPENPQFRYH	8292610556 Dell Way	\N	MIXYIPV	\N	0	Japan	2	MPENPQFRYH@dell.com	8292610556	2	8374735823832453	2010/06	user14717	password	40	20000	F
14718	ZETELF	UPSJGYBEFO	6334190669 Dell Way	\N	MCNVRIN	\N	0	Germany	2	UPSJGYBEFO@dell.com	6334190669	2	9759979290887714	2008/08	user14718	password	25	40000	M
14719	GYUSDO	HWYNUASAPE	8359802155 Dell Way	\N	CCZUKMH	\N	0	Australia	2	HWYNUASAPE@dell.com	8359802155	2	1440194034948945	2010/05	user14719	password	36	20000	M
14720	FWIIKQ	FIEAJWAYBD	5502116753 Dell Way	\N	ABYLOFM	\N	0	China	2	FIEAJWAYBD@dell.com	5502116753	3	8404018614441157	2012/10	user14720	password	83	60000	M
14721	TVHEMN	MQNWNOUORV	3327015214 Dell Way	\N	QPHEVTO	\N	0	China	2	MQNWNOUORV@dell.com	3327015214	2	2786240726243704	2008/04	user14721	password	69	100000	F
14722	OHEAUR	RINFWITNDK	5361952933 Dell Way	\N	DLOZECH	\N	0	France	2	RINFWITNDK@dell.com	5361952933	3	5041220419108868	2011/03	user14722	password	49	80000	M
14723	SYUNPM	VDRRLLFPVJ	1859561446 Dell Way	\N	AJIEMPP	\N	0	UK	2	VDRRLLFPVJ@dell.com	1859561446	1	7541910503059626	2009/06	user14723	password	53	20000	F
14724	LVSAHN	EZFPKLFFUF	1551845984 Dell Way	\N	PCKBSAB	\N	0	South Africa	2	EZFPKLFFUF@dell.com	1551845984	4	1980929279234260	2010/04	user14724	password	29	80000	M
14725	ZLTHYX	GENQPSWJYL	3905745378 Dell Way	\N	MINFIOA	\N	0	China	2	GENQPSWJYL@dell.com	3905745378	1	9458039589691908	2010/04	user14725	password	67	40000	F
14726	DAPCXV	GLMVDJFBUS	1589327475 Dell Way	\N	KHXSVYD	\N	0	Canada	2	GLMVDJFBUS@dell.com	1589327475	1	7722789484076203	2009/09	user14726	password	20	80000	M
14727	BFYYBE	JOANXFPSXZ	8876827204 Dell Way	\N	ZVSVTVZ	\N	0	South Africa	2	JOANXFPSXZ@dell.com	8876827204	4	2609935167245567	2011/10	user14727	password	77	60000	M
14728	BKTCPD	RPRPVGHTFG	7954158610 Dell Way	\N	PYBITBE	\N	0	Japan	2	RPRPVGHTFG@dell.com	7954158610	2	3147184834815562	2010/02	user14728	password	70	40000	F
14729	DCHSGZ	IXOEDVYJCN	4343945404 Dell Way	\N	HEWBFAR	\N	0	UK	2	IXOEDVYJCN@dell.com	4343945404	5	5608702496625484	2010/08	user14729	password	79	80000	M
14730	YBMEAV	BOAFKYOMMW	5789031905 Dell Way	\N	QIYWJPV	\N	0	Russia	2	BOAFKYOMMW@dell.com	5789031905	2	3388786006253213	2008/03	user14730	password	90	100000	F
14731	BKHBGI	PGNAFCMRZD	2643004755 Dell Way	\N	ZXZJNVC	\N	0	Australia	2	PGNAFCMRZD@dell.com	2643004755	2	3040265407878905	2009/05	user14731	password	28	60000	F
14732	OULUCB	BQBGTOXSRX	7573872497 Dell Way	\N	QRHENJF	\N	0	Japan	2	BQBGTOXSRX@dell.com	7573872497	3	1566077446565032	2008/08	user14732	password	58	60000	F
14733	IYZLZA	BBHUQFNIDD	9996123336 Dell Way	\N	ZKIMUOE	\N	0	Germany	2	BBHUQFNIDD@dell.com	9996123336	2	6325991542544217	2011/10	user14733	password	23	80000	F
14734	ATOAUQ	BBKSGYAJBZ	9297774281 Dell Way	\N	UKMOYRB	\N	0	UK	2	BBKSGYAJBZ@dell.com	9297774281	4	5836119275074453	2011/09	user14734	password	40	100000	M
14735	BKTVAU	XLMDJMNLMH	5785892078 Dell Way	\N	VZVURXS	\N	0	Germany	2	XLMDJMNLMH@dell.com	5785892078	2	3799553576391190	2009/07	user14735	password	30	100000	M
14736	PSLQNI	BAMLNZXZGT	5078416673 Dell Way	\N	ZCNQZFG	\N	0	Germany	2	BAMLNZXZGT@dell.com	5078416673	3	7936416393145920	2008/09	user14736	password	72	80000	F
14737	MBXZJZ	ZWLMVIMCBL	8970937189 Dell Way	\N	EPCEUIS	\N	0	Chile	2	ZWLMVIMCBL@dell.com	8970937189	3	3239518497139215	2010/03	user14737	password	81	100000	M
14738	XVQHUQ	EFCZOPBQAG	6356159851 Dell Way	\N	FDLZMDG	\N	0	China	2	EFCZOPBQAG@dell.com	6356159851	3	9693225235678256	2012/05	user14738	password	80	60000	F
14739	RDOMUS	RWSGLUWMBB	7954604980 Dell Way	\N	QMBCPHM	\N	0	Chile	2	RWSGLUWMBB@dell.com	7954604980	3	1117889372631907	2008/04	user14739	password	54	40000	M
14740	QZLKSD	HKJTEGGFHW	9191831740 Dell Way	\N	SJZIQMN	\N	0	France	2	HKJTEGGFHW@dell.com	9191831740	3	5875102194957436	2009/01	user14740	password	85	20000	M
14741	XQCPTK	ZDDEJJKRGD	5305153834 Dell Way	\N	AFLRRYC	\N	0	Germany	2	ZDDEJJKRGD@dell.com	5305153834	4	8312880638986827	2010/07	user14741	password	18	20000	F
14742	QHBKRB	NUGXERPKUP	1400622189 Dell Way	\N	QFHIEKX	\N	0	Japan	2	NUGXERPKUP@dell.com	1400622189	4	2456859130878001	2011/09	user14742	password	43	20000	F
14743	QEUHFI	CMFHDUSXKI	3721574623 Dell Way	\N	DSRICOZ	\N	0	Canada	2	CMFHDUSXKI@dell.com	3721574623	1	7998054696246982	2008/06	user14743	password	81	60000	F
14744	AFKGNN	STUVNMTYVX	3727810201 Dell Way	\N	RMFUBEY	\N	0	China	2	STUVNMTYVX@dell.com	3727810201	4	4484399078879506	2011/07	user14744	password	76	100000	M
14745	ZHWNUO	GPKUCESXBK	8373488760 Dell Way	\N	JGEKLCU	\N	0	Russia	2	GPKUCESXBK@dell.com	8373488760	1	5653302427381278	2010/12	user14745	password	47	20000	M
14746	SWMNLS	CVMEZFCAPM	8369617804 Dell Way	\N	HUXSWRL	\N	0	Russia	2	CVMEZFCAPM@dell.com	8369617804	5	1923529071733355	2011/05	user14746	password	26	80000	F
14747	ZFPKXS	FKWFPZGFLN	7263858182 Dell Way	\N	ZIGWZSO	\N	0	South Africa	2	FKWFPZGFLN@dell.com	7263858182	4	6354531562421471	2008/10	user14747	password	42	20000	M
14748	NTELLK	VIPLHVQTJP	7090236973 Dell Way	\N	CQLCJAX	\N	0	Australia	2	VIPLHVQTJP@dell.com	7090236973	3	2124239644035697	2010/10	user14748	password	38	40000	F
14749	AJUMTQ	VIBDESWOHY	4928781307 Dell Way	\N	ETBOUYP	\N	0	France	2	VIBDESWOHY@dell.com	4928781307	4	9180955705698580	2009/12	user14749	password	26	80000	F
14750	MLNFBI	ODLTVIHDHM	3903092032 Dell Way	\N	XIARHPD	\N	0	Russia	2	ODLTVIHDHM@dell.com	3903092032	1	9727195320650936	2009/02	user14750	password	61	40000	M
14751	AWVCFK	FRDBZKFHXC	9945592475 Dell Way	\N	PYUWOYP	\N	0	South Africa	2	FRDBZKFHXC@dell.com	9945592475	3	2637918532360345	2008/02	user14751	password	57	80000	F
14752	KQGQAM	HDOHOTOMWE	2415221138 Dell Way	\N	KRAYPPU	\N	0	Germany	2	HDOHOTOMWE@dell.com	2415221138	5	7785140940453858	2009/07	user14752	password	57	60000	M
14753	ETOFFW	JUDYORKKVU	5884975997 Dell Way	\N	BWTRMOH	\N	0	Japan	2	JUDYORKKVU@dell.com	5884975997	1	9410523448139430	2008/07	user14753	password	47	20000	M
14754	DOYJLH	DOFRGQCCLE	2243835429 Dell Way	\N	YEVKTCB	\N	0	Chile	2	DOFRGQCCLE@dell.com	2243835429	5	4122663982678205	2011/05	user14754	password	43	60000	M
14755	YKXJRA	XXSDNVFYZE	6691856125 Dell Way	\N	DVPWYQD	\N	0	Australia	2	XXSDNVFYZE@dell.com	6691856125	3	8144380509387703	2008/11	user14755	password	35	60000	M
14756	QLDIMB	FFETAKSAOW	4381931192 Dell Way	\N	WESUUWX	\N	0	France	2	FFETAKSAOW@dell.com	4381931192	4	5182915180455893	2009/12	user14756	password	19	20000	M
14757	MDWYEC	EJWFUOFJLB	5021575086 Dell Way	\N	NDWIATT	\N	0	France	2	EJWFUOFJLB@dell.com	5021575086	2	6687313909642399	2009/04	user14757	password	65	100000	M
14758	UVRZYV	JUADJGMUIA	3944242504 Dell Way	\N	YEIZYCJ	\N	0	China	2	JUADJGMUIA@dell.com	3944242504	1	7901569904759527	2010/08	user14758	password	69	40000	F
14759	NZKLVT	GWXPCKKKKI	7087654870 Dell Way	\N	PTHOVRY	\N	0	Canada	2	GWXPCKKKKI@dell.com	7087654870	4	7676429793704302	2009/05	user14759	password	20	80000	M
14760	AEKVYQ	SVGUGQFQZV	1275336638 Dell Way	\N	JHJFYIJ	\N	0	Japan	2	SVGUGQFQZV@dell.com	1275336638	1	9593449696432800	2010/02	user14760	password	70	40000	F
14761	XTAVKS	RQNXGTOGPY	6966018120 Dell Way	\N	NYEMHNC	\N	0	China	2	RQNXGTOGPY@dell.com	6966018120	1	7798174322117121	2012/10	user14761	password	27	20000	M
14762	XAMHTE	XHBEAQKPOX	5963556871 Dell Way	\N	OSKWGME	\N	0	UK	2	XHBEAQKPOX@dell.com	5963556871	5	7704849080648274	2009/01	user14762	password	73	100000	M
14763	UMGOQE	VRIWITMWQB	9827922549 Dell Way	\N	PBXVNBT	\N	0	Australia	2	VRIWITMWQB@dell.com	9827922549	3	4662220421247184	2008/04	user14763	password	46	100000	F
14764	WFPMJL	ESHMLUJCVY	1592988858 Dell Way	\N	DSURUOT	\N	0	Russia	2	ESHMLUJCVY@dell.com	1592988858	1	8132634831126780	2009/07	user14764	password	74	40000	F
14765	AZWKLA	CTNONWQIVT	4035834657 Dell Way	\N	BQLVEEP	\N	0	Chile	2	CTNONWQIVT@dell.com	4035834657	2	6168717132415623	2012/02	user14765	password	88	40000	F
14766	YDOKEQ	DREQOVZJPB	8505153333 Dell Way	\N	AAWEFLL	\N	0	Germany	2	DREQOVZJPB@dell.com	8505153333	5	4722016147337854	2012/12	user14766	password	68	20000	M
14767	VSIAJL	SOCGJCQYDQ	3273555582 Dell Way	\N	YAVEMGR	\N	0	China	2	SOCGJCQYDQ@dell.com	3273555582	1	3627245191950351	2009/10	user14767	password	50	20000	M
14768	DLQNXI	BAPKDFJHWI	3285803282 Dell Way	\N	HSMTYDB	\N	0	Chile	2	BAPKDFJHWI@dell.com	3285803282	2	4833926218096167	2008/10	user14768	password	59	80000	M
14769	AHLYQN	ZFXCLGKIOR	8589784844 Dell Way	\N	AALZEME	\N	0	France	2	ZFXCLGKIOR@dell.com	8589784844	4	5395086190663278	2011/03	user14769	password	29	60000	F
14770	LBDBOD	HLGSSQAHIB	8289518740 Dell Way	\N	ITANGFY	\N	0	Australia	2	HLGSSQAHIB@dell.com	8289518740	3	7542546660173685	2012/08	user14770	password	40	20000	F
14771	JIDXLK	JSCBIDJQER	6447516578 Dell Way	\N	KEFQJES	\N	0	Canada	2	JSCBIDJQER@dell.com	6447516578	3	2564112400636077	2009/10	user14771	password	44	40000	F
14772	SJADUJ	VWLEAUUEME	9835814626 Dell Way	\N	JRVSVNX	\N	0	France	2	VWLEAUUEME@dell.com	9835814626	1	6751849874388427	2011/06	user14772	password	83	100000	F
14773	HWHBGD	YRHYMCCYHL	2734559671 Dell Way	\N	PCELQCW	\N	0	Japan	2	YRHYMCCYHL@dell.com	2734559671	3	4282417508307845	2011/05	user14773	password	34	80000	M
14774	CCSIFQ	ANPMQRKXDA	8409397315 Dell Way	\N	AILRLIH	\N	0	Japan	2	ANPMQRKXDA@dell.com	8409397315	4	3364665290340781	2009/11	user14774	password	21	100000	M
14775	DQHJHH	WWTMOEKREK	9824156786 Dell Way	\N	AQBLYIB	\N	0	Russia	2	WWTMOEKREK@dell.com	9824156786	2	1028156078420579	2012/05	user14775	password	84	80000	F
14776	NCWVJS	RDFFHPXMZX	7372949666 Dell Way	\N	DBIBKKW	\N	0	China	2	RDFFHPXMZX@dell.com	7372949666	5	2955214525572955	2008/10	user14776	password	19	60000	F
14777	CKCMDU	PIZXXXKXUN	3597832259 Dell Way	\N	ZDPJNLT	\N	0	Chile	2	PIZXXXKXUN@dell.com	3597832259	5	3829031401313841	2008/12	user14777	password	82	40000	F
14778	ILOLFE	UFBSCLQXYP	6835375497 Dell Way	\N	BOYPZSV	\N	0	Chile	2	UFBSCLQXYP@dell.com	6835375497	1	3814175710082054	2011/01	user14778	password	65	80000	F
14779	CGUIKO	OLGRXWOWLP	2264609817 Dell Way	\N	KKEJCAQ	\N	0	Russia	2	OLGRXWOWLP@dell.com	2264609817	5	4261829605326057	2008/08	user14779	password	22	60000	M
14780	HGBSUP	DBGBXVXJLI	3728076771 Dell Way	\N	TQSVQJP	\N	0	Russia	2	DBGBXVXJLI@dell.com	3728076771	5	9451256186701358	2012/01	user14780	password	49	80000	F
14781	RRAMHE	NOFLJDUUMN	9220756892 Dell Way	\N	LEJBNZW	\N	0	South Africa	2	NOFLJDUUMN@dell.com	9220756892	4	7612419445533306	2012/03	user14781	password	44	40000	M
14782	BFKIJY	WPJGSDBERM	2868457708 Dell Way	\N	JBOWAKS	\N	0	UK	2	WPJGSDBERM@dell.com	2868457708	3	8765167044475675	2010/10	user14782	password	24	40000	M
14783	ISERQB	HAHAEIFWVO	6111613422 Dell Way	\N	XJLYUDX	\N	0	UK	2	HAHAEIFWVO@dell.com	6111613422	4	4786718274932355	2009/11	user14783	password	73	40000	F
14784	MKVDLC	DSDIBIEWWB	6922850581 Dell Way	\N	GIAALXA	\N	0	Australia	2	DSDIBIEWWB@dell.com	6922850581	3	4453908321913332	2010/03	user14784	password	61	80000	M
14785	ZMUKPY	DSGEAKBXMH	7655435946 Dell Way	\N	FNHRKIR	\N	0	Australia	2	DSGEAKBXMH@dell.com	7655435946	1	6090486973524094	2012/08	user14785	password	33	60000	M
14786	RKBGIF	ZPKZALXNTC	5510286326 Dell Way	\N	AATKJLM	\N	0	Australia	2	ZPKZALXNTC@dell.com	5510286326	1	1087562377098947	2008/04	user14786	password	61	100000	M
14787	ZWFICE	XMEYYBLREL	4666260041 Dell Way	\N	SYWBJJD	\N	0	South Africa	2	XMEYYBLREL@dell.com	4666260041	1	1344246217515319	2011/10	user14787	password	79	80000	M
14788	SVBUAZ	HEXFGJXLUP	9684211726 Dell Way	\N	JRRTAVQ	\N	0	France	2	HEXFGJXLUP@dell.com	9684211726	4	1758208973333239	2011/07	user14788	password	69	60000	F
14789	NNANNI	SLNZULKOBU	8423222686 Dell Way	\N	FSNGNEQ	\N	0	France	2	SLNZULKOBU@dell.com	8423222686	4	2877668837085366	2009/06	user14789	password	66	60000	M
14790	EPMSXF	DLFXWQMXKS	3852183236 Dell Way	\N	QYYECPQ	\N	0	UK	2	DLFXWQMXKS@dell.com	3852183236	5	3336777013726532	2011/07	user14790	password	77	80000	M
14791	KFKHKN	SQLPGXNQQD	8083206450 Dell Way	\N	POHRDYQ	\N	0	France	2	SQLPGXNQQD@dell.com	8083206450	5	2905156064778566	2009/09	user14791	password	84	20000	F
14792	CLKNZC	DKSKIFAYIQ	8263799206 Dell Way	\N	NQIROYD	\N	0	China	2	DKSKIFAYIQ@dell.com	8263799206	2	6951728488318623	2010/04	user14792	password	67	60000	F
14793	CZXCCB	MULVAMUJCH	4999617115 Dell Way	\N	ZKZOICX	\N	0	Canada	2	MULVAMUJCH@dell.com	4999617115	3	6686747716274113	2011/04	user14793	password	34	20000	F
14794	FZLIAY	CLTDXOMZWM	5830592419 Dell Way	\N	JVBSYYV	\N	0	China	2	CLTDXOMZWM@dell.com	5830592419	3	1665246865246445	2011/09	user14794	password	28	20000	M
14795	DPFDOI	PILMWYMSLW	8901293204 Dell Way	\N	OMOMLKW	\N	0	UK	2	PILMWYMSLW@dell.com	8901293204	5	7916861086152495	2010/01	user14795	password	85	60000	F
14796	OSICAX	KMKHLWAWTO	8150799651 Dell Way	\N	IHAUSWT	\N	0	Germany	2	KMKHLWAWTO@dell.com	8150799651	3	2516323809511959	2012/06	user14796	password	65	20000	M
14797	JJCJHM	WRUHOUEHIN	6103663673 Dell Way	\N	PJHHFBX	\N	0	Australia	2	WRUHOUEHIN@dell.com	6103663673	1	8962640052195639	2008/09	user14797	password	86	20000	F
14798	HCLPPI	GJPUDUBMHR	9344034587 Dell Way	\N	VOZBPWB	\N	0	Canada	2	GJPUDUBMHR@dell.com	9344034587	5	2750533361919224	2011/11	user14798	password	33	80000	F
14799	IEUXMB	HBVLWXXDOS	8311885120 Dell Way	\N	ROUHKWM	\N	0	China	2	HBVLWXXDOS@dell.com	8311885120	4	9773581443354488	2011/11	user14799	password	67	100000	F
14800	VSCHTJ	JOUFMRJBKA	5080592020 Dell Way	\N	PEIABUI	\N	0	South Africa	2	JOUFMRJBKA@dell.com	5080592020	2	6056680675130338	2009/01	user14800	password	52	60000	M
14801	EPDXZN	MTTZLCAWDQ	3647595949 Dell Way	\N	BMQCGZY	\N	0	Russia	2	MTTZLCAWDQ@dell.com	3647595949	3	1385383035056293	2009/12	user14801	password	58	20000	F
14802	DHBCVN	WOMIRNFVDG	8409079226 Dell Way	\N	HUJOTIH	\N	0	Australia	2	WOMIRNFVDG@dell.com	8409079226	2	4186707728542388	2012/11	user14802	password	53	100000	F
14803	UADPOA	DBIVONQSUX	1467987067 Dell Way	\N	NDMHLTI	\N	0	Chile	2	DBIVONQSUX@dell.com	1467987067	4	1737590681761503	2012/03	user14803	password	21	100000	M
14804	BBNQBR	RJMGXDZSAM	8013388696 Dell Way	\N	VNTHGCO	\N	0	Chile	2	RJMGXDZSAM@dell.com	8013388696	4	2879073581192642	2012/09	user14804	password	27	100000	M
14805	ELJFCB	PPINSHFTUB	5954716247 Dell Way	\N	GNJMQXU	\N	0	China	2	PPINSHFTUB@dell.com	5954716247	1	4188451172783971	2009/02	user14805	password	36	100000	F
14806	RJOULE	KTRCBXWVZD	4706382892 Dell Way	\N	IIQYFKJ	\N	0	Russia	2	KTRCBXWVZD@dell.com	4706382892	4	1136986344587057	2010/12	user14806	password	18	100000	M
14807	KKLVOW	PGYQDVLDYU	8287039210 Dell Way	\N	LOTRZCL	\N	0	China	2	PGYQDVLDYU@dell.com	8287039210	3	9328992147929968	2011/06	user14807	password	75	60000	M
14808	FXRTTH	ASXENIHMDS	3411013908 Dell Way	\N	AWJZZVJ	\N	0	Russia	2	ASXENIHMDS@dell.com	3411013908	2	5991573504637927	2011/02	user14808	password	90	60000	F
14809	XHAQOB	ILFWUMIXEJ	1228956559 Dell Way	\N	UOJTJSN	\N	0	Japan	2	ILFWUMIXEJ@dell.com	1228956559	1	4383232361637056	2008/01	user14809	password	88	40000	M
14810	GKPUMY	GRVADEYINT	1908505168 Dell Way	\N	WXMGPAX	\N	0	Japan	2	GRVADEYINT@dell.com	1908505168	2	7745075397193433	2008/03	user14810	password	27	20000	F
14811	OTHASN	RNOVSMDFGA	5195835205 Dell Way	\N	CSHSTEJ	\N	0	South Africa	2	RNOVSMDFGA@dell.com	5195835205	1	1175515807699412	2011/03	user14811	password	30	20000	M
14812	XLVQZN	DNIVAMBGNE	4320155619 Dell Way	\N	YUXSZGN	\N	0	France	2	DNIVAMBGNE@dell.com	4320155619	3	2434066569432616	2011/09	user14812	password	43	60000	M
14813	VGGUUK	HCGHPINCMM	3443122175 Dell Way	\N	XKEWQSI	\N	0	Australia	2	HCGHPINCMM@dell.com	3443122175	3	6650632283184678	2012/11	user14813	password	21	80000	M
14814	IXLCIS	EOAUXNWJAT	5197475614 Dell Way	\N	TEQKXZK	\N	0	Canada	2	EOAUXNWJAT@dell.com	5197475614	1	2480396172963083	2009/02	user14814	password	76	100000	F
14815	SJMACR	OCLMQIVQCP	5150985221 Dell Way	\N	VTASSKX	\N	0	Canada	2	OCLMQIVQCP@dell.com	5150985221	1	5329866824205965	2010/11	user14815	password	49	100000	M
14816	VLOXCD	AOPQWLHYBD	8297546714 Dell Way	\N	RBWKMTO	\N	0	UK	2	AOPQWLHYBD@dell.com	8297546714	1	5428631417918951	2011/06	user14816	password	50	40000	F
14817	XUFZYG	OOXLAFJBIB	1857904159 Dell Way	\N	CEMPXBN	\N	0	Russia	2	OOXLAFJBIB@dell.com	1857904159	1	4636053766589612	2010/06	user14817	password	64	100000	F
14818	LDJJJX	YGIYLSZTUC	3073264751 Dell Way	\N	YGSWHFP	\N	0	China	2	YGIYLSZTUC@dell.com	3073264751	5	9700160849839450	2011/08	user14818	password	80	20000	F
14819	ZKLIIK	PQIAJIUDLT	2612974051 Dell Way	\N	JDPRJEB	\N	0	Germany	2	PQIAJIUDLT@dell.com	2612974051	1	3510875097941607	2012/11	user14819	password	42	100000	M
14820	TIEBST	RBUBKPEVIO	3394540140 Dell Way	\N	ZYFIDGX	\N	0	Chile	2	RBUBKPEVIO@dell.com	3394540140	1	1940865877550095	2008/07	user14820	password	89	100000	F
14821	HEHAYZ	BSALIEHRTG	6891167255 Dell Way	\N	PYOSFMA	\N	0	France	2	BSALIEHRTG@dell.com	6891167255	1	6485041994135827	2008/02	user14821	password	61	60000	F
14822	TSKRRM	KSYTXGKQMZ	8376229579 Dell Way	\N	OBSUOSG	\N	0	Canada	2	KSYTXGKQMZ@dell.com	8376229579	5	4232298530172557	2012/06	user14822	password	74	40000	F
14823	MSXDFH	VEASLLJYLY	8456903109 Dell Way	\N	ZDSNVZS	\N	0	Japan	2	VEASLLJYLY@dell.com	8456903109	1	6105625549796969	2009/11	user14823	password	81	60000	F
14824	PKMVRH	ASALDJJPHJ	7348894710 Dell Way	\N	SAXOZQF	\N	0	Russia	2	ASALDJJPHJ@dell.com	7348894710	4	1713696713093668	2010/08	user14824	password	60	100000	F
14825	ZICQQC	JRONBXCIHU	3783307285 Dell Way	\N	IEIHUOC	\N	0	Germany	2	JRONBXCIHU@dell.com	3783307285	1	1572448225226253	2012/10	user14825	password	86	20000	M
14826	HHJYJS	PYGQVIZDDH	8921892427 Dell Way	\N	HMPCASP	\N	0	China	2	PYGQVIZDDH@dell.com	8921892427	4	3632950413972139	2011/08	user14826	password	53	40000	M
14827	USVDLL	CRBYAABEIJ	7817666132 Dell Way	\N	RYMRQCA	\N	0	Germany	2	CRBYAABEIJ@dell.com	7817666132	2	2458728165365755	2009/10	user14827	password	54	40000	M
14828	FCTQNV	IPTIQUNYEE	2867827971 Dell Way	\N	XQWOSXC	\N	0	France	2	IPTIQUNYEE@dell.com	2867827971	2	8560020454693586	2008/10	user14828	password	26	80000	M
14829	FJPTEX	JXGZSUYWYV	7451805643 Dell Way	\N	MUJFRMR	\N	0	South Africa	2	JXGZSUYWYV@dell.com	7451805643	3	9149459392763676	2010/08	user14829	password	55	60000	M
14830	WAPAYY	YFXQZVNXRA	4245872670 Dell Way	\N	SBFKNWH	\N	0	Chile	2	YFXQZVNXRA@dell.com	4245872670	1	7408645212184638	2012/09	user14830	password	28	100000	M
14831	ELPDJN	IHEIDRGVSZ	8229858416 Dell Way	\N	WXJKTQQ	\N	0	Canada	2	IHEIDRGVSZ@dell.com	8229858416	2	1832226815167814	2010/06	user14831	password	84	20000	M
14832	IQUSED	AIMDASYSSV	2811578980 Dell Way	\N	QBFJRWM	\N	0	France	2	AIMDASYSSV@dell.com	2811578980	3	9743094512727112	2011/06	user14832	password	19	40000	M
14833	REOVHO	EUSFNRYFMO	9753813324 Dell Way	\N	GSXXOKK	\N	0	Russia	2	EUSFNRYFMO@dell.com	9753813324	2	5113609770312906	2010/05	user14833	password	77	40000	F
14834	ZVWHKB	BCGOUETGSA	7127650005 Dell Way	\N	ZQXNAIH	\N	0	UK	2	BCGOUETGSA@dell.com	7127650005	4	5099574897903949	2008/07	user14834	password	72	20000	M
14835	PZVAAW	CHLWLFDDFD	7391343136 Dell Way	\N	TDQULYU	\N	0	Canada	2	CHLWLFDDFD@dell.com	7391343136	2	2735736499074846	2009/12	user14835	password	40	100000	M
14836	HRPIOR	PZOAESEKVY	7534782515 Dell Way	\N	NMSZLMC	\N	0	Canada	2	PZOAESEKVY@dell.com	7534782515	2	4903999351896346	2011/08	user14836	password	37	40000	M
14837	YWFMOV	MDWRWABRYP	9365436746 Dell Way	\N	EROPEQT	\N	0	UK	2	MDWRWABRYP@dell.com	9365436746	1	6516378103755415	2010/06	user14837	password	83	60000	F
14838	UQWILI	MHZIIBAHQE	7903391405 Dell Way	\N	ZEUDVOB	\N	0	Russia	2	MHZIIBAHQE@dell.com	7903391405	4	3519054326694459	2009/07	user14838	password	68	80000	F
14839	INRUVD	CVMKXMRNRQ	5486652724 Dell Way	\N	SMUNBVH	\N	0	South Africa	2	CVMKXMRNRQ@dell.com	5486652724	3	1489245204720646	2008/04	user14839	password	67	40000	M
14840	EBKAFM	WRWTEOHVFZ	4382871604 Dell Way	\N	IANJWVF	\N	0	China	2	WRWTEOHVFZ@dell.com	4382871604	2	4767060092650354	2011/12	user14840	password	77	40000	F
14841	WQECCA	TZUXOBTUBB	9171074481 Dell Way	\N	VPLRKRA	\N	0	Russia	2	TZUXOBTUBB@dell.com	9171074481	3	4620225032791495	2012/04	user14841	password	64	100000	F
14842	GDFJDZ	JYWXZQSBSN	6903006853 Dell Way	\N	QEEAVFU	\N	0	Russia	2	JYWXZQSBSN@dell.com	6903006853	1	6131245071534068	2012/10	user14842	password	57	20000	F
14843	RGLVFV	TCTTTLULYK	4542300096 Dell Way	\N	PDLKIFD	\N	0	UK	2	TCTTTLULYK@dell.com	4542300096	4	9190513049252332	2009/04	user14843	password	87	40000	M
14844	FTTLPM	OIFHTASSLI	6434551852 Dell Way	\N	VWTECXE	\N	0	France	2	OIFHTASSLI@dell.com	6434551852	1	7259777385741473	2012/01	user14844	password	18	80000	F
14845	TNRJZG	RFNKGFDROZ	4528215880 Dell Way	\N	OHDQEIC	\N	0	Russia	2	RFNKGFDROZ@dell.com	4528215880	5	6747314870823175	2010/10	user14845	password	48	80000	M
14846	YJXYPP	ECAKIDBWCP	2338001723 Dell Way	\N	EGGIOID	\N	0	UK	2	ECAKIDBWCP@dell.com	2338001723	4	4278726876713336	2012/03	user14846	password	21	60000	F
14847	LLBAAF	DAPMERJGHN	7691910066 Dell Way	\N	MNWAWZZ	\N	0	Australia	2	DAPMERJGHN@dell.com	7691910066	2	9594412760343404	2012/05	user14847	password	53	20000	M
14848	YCVYIZ	ZYMEPVKWJX	3251326696 Dell Way	\N	JFYGFXG	\N	0	UK	2	ZYMEPVKWJX@dell.com	3251326696	1	8866366518195719	2011/09	user14848	password	84	60000	M
14849	AHOIGO	GSSWODSXBC	7775450517 Dell Way	\N	DZIIXOH	\N	0	Canada	2	GSSWODSXBC@dell.com	7775450517	1	8144764765165747	2010/01	user14849	password	34	20000	F
14850	NOKTCR	MVNAYGYZIB	8608307542 Dell Way	\N	ZRKXGRB	\N	0	UK	2	MVNAYGYZIB@dell.com	8608307542	5	4701176208909601	2012/02	user14850	password	49	20000	M
14851	ZLJCCV	YPWWWVWEWW	7073833614 Dell Way	\N	WHTCYVC	\N	0	South Africa	2	YPWWWVWEWW@dell.com	7073833614	3	7527170549146832	2011/12	user14851	password	71	40000	M
14852	ESAGOY	WKVSGSXCOT	5080425266 Dell Way	\N	JHWIDYD	\N	0	Russia	2	WKVSGSXCOT@dell.com	5080425266	5	6018468752037734	2009/08	user14852	password	84	40000	M
14853	QIAEHW	PCPVUMYJGI	7056514155 Dell Way	\N	RDQUCUO	\N	0	Germany	2	PCPVUMYJGI@dell.com	7056514155	1	9234542943537236	2009/01	user14853	password	33	20000	M
14854	OBVVYK	YNGTAECHMT	3049611925 Dell Way	\N	LDNNYCB	\N	0	Japan	2	YNGTAECHMT@dell.com	3049611925	5	8934334264602513	2009/03	user14854	password	85	100000	M
14855	ZTOYEM	LKGMOIUBCF	7508207968 Dell Way	\N	EPSCSTS	\N	0	UK	2	LKGMOIUBCF@dell.com	7508207968	3	2892867411021143	2012/07	user14855	password	28	80000	F
14856	XELBRX	MXJBFECIKG	6996548431 Dell Way	\N	YDJQXCP	\N	0	Japan	2	MXJBFECIKG@dell.com	6996548431	4	5555147206410766	2008/12	user14856	password	26	80000	M
14857	HCXYZJ	VJKBONJYTI	4028657103 Dell Way	\N	BDYYFOO	\N	0	South Africa	2	VJKBONJYTI@dell.com	4028657103	1	1528535874560475	2009/03	user14857	password	71	20000	F
14858	VZKVJG	FUITHSSBAT	3995493140 Dell Way	\N	EZSKNGG	\N	0	South Africa	2	FUITHSSBAT@dell.com	3995493140	2	2032401829957962	2010/01	user14858	password	33	100000	M
14859	FKTPRY	JZSQSKRSEW	8493518770 Dell Way	\N	RWGEDNA	\N	0	France	2	JZSQSKRSEW@dell.com	8493518770	1	9939061908517034	2012/05	user14859	password	90	100000	M
14860	KOECMN	BFDUPVMURE	5811859117 Dell Way	\N	QXJUKKG	\N	0	Chile	2	BFDUPVMURE@dell.com	5811859117	2	2271285529714077	2012/03	user14860	password	87	60000	M
14861	MQSZDU	EHOUCBOTGF	5489067802 Dell Way	\N	RPZBZGI	\N	0	Germany	2	EHOUCBOTGF@dell.com	5489067802	3	4712721236981452	2011/05	user14861	password	82	40000	M
14862	NCXQXB	XLWANLTTQK	3372739053 Dell Way	\N	IQMIXUV	\N	0	China	2	XLWANLTTQK@dell.com	3372739053	2	2167594702914357	2011/02	user14862	password	55	60000	M
14863	PLHMNF	YKFMVZFMKO	9972976689 Dell Way	\N	DXXASTL	\N	0	UK	2	YKFMVZFMKO@dell.com	9972976689	3	6604799001477659	2008/01	user14863	password	31	80000	M
14864	QBEDHC	OMPKMVWWJA	1196258604 Dell Way	\N	THBLAMK	\N	0	Australia	2	OMPKMVWWJA@dell.com	1196258604	1	2391535313334316	2008/03	user14864	password	86	80000	M
14865	AXZHAO	UPYGKVDUVW	7703870036 Dell Way	\N	BWICISC	\N	0	China	2	UPYGKVDUVW@dell.com	7703870036	2	4969459693878889	2012/03	user14865	password	31	80000	F
14866	CUNCII	SGODBSXWPZ	5287367331 Dell Way	\N	TXCCQFL	\N	0	China	2	SGODBSXWPZ@dell.com	5287367331	5	3861640516668558	2011/01	user14866	password	25	100000	F
14867	XLHFTZ	LHDNAAKPAD	5961941771 Dell Way	\N	MDFCIRM	\N	0	South Africa	2	LHDNAAKPAD@dell.com	5961941771	4	5454013308510185	2011/11	user14867	password	47	80000	M
14868	VBZOBL	WEZWFJLGMY	3763062835 Dell Way	\N	JSBSKNN	\N	0	UK	2	WEZWFJLGMY@dell.com	3763062835	1	6075641265138984	2009/05	user14868	password	43	100000	F
14869	KZUMLR	QKOWTACGYM	7346512192 Dell Way	\N	ZZEJNSH	\N	0	South Africa	2	QKOWTACGYM@dell.com	7346512192	5	1219104323536157	2008/03	user14869	password	18	40000	M
14870	ZECKVT	VJQOJSUIFT	3479486660 Dell Way	\N	IJDVBKQ	\N	0	Russia	2	VJQOJSUIFT@dell.com	3479486660	4	9015448125079276	2010/09	user14870	password	35	20000	M
14871	KFCFZX	PPLYIGHNAP	7589441916 Dell Way	\N	XDKYOBT	\N	0	South Africa	2	PPLYIGHNAP@dell.com	7589441916	4	3911856779363006	2010/11	user14871	password	50	20000	F
14872	REMRCB	GOAPUHCVXZ	3686055021 Dell Way	\N	ZHYNJRJ	\N	0	Australia	2	GOAPUHCVXZ@dell.com	3686055021	4	5594495459925384	2008/02	user14872	password	61	60000	M
14873	UXLWZS	KAHFIKAFKZ	5944949595 Dell Way	\N	NINXAWZ	\N	0	China	2	KAHFIKAFKZ@dell.com	5944949595	3	5234995880164206	2011/02	user14873	password	83	60000	M
14874	VYTVQD	WYIEJJKTJY	3936288857 Dell Way	\N	BWVBSVJ	\N	0	Chile	2	WYIEJJKTJY@dell.com	3936288857	5	9531326181720944	2010/09	user14874	password	48	40000	M
14875	JBKAEG	YNLIXWBGVC	4589819570 Dell Way	\N	CREVMOC	\N	0	South Africa	2	YNLIXWBGVC@dell.com	4589819570	1	3095797297544777	2008/06	user14875	password	57	80000	M
14876	PDVUJU	HVCFRDLNGO	5612546035 Dell Way	\N	ELJQZML	\N	0	China	2	HVCFRDLNGO@dell.com	5612546035	4	5803776528220624	2012/03	user14876	password	36	100000	M
14877	JQOTLW	PNBHRNUYBY	7320137310 Dell Way	\N	JLOJXAT	\N	0	France	2	PNBHRNUYBY@dell.com	7320137310	2	4608192865271121	2012/07	user14877	password	32	80000	M
14878	VHRGDG	UFNMTHKVFT	2068902973 Dell Way	\N	GUCEVWP	\N	0	Germany	2	UFNMTHKVFT@dell.com	2068902973	5	4989125826396048	2011/03	user14878	password	29	60000	F
14879	LFHPMC	VZOOHZJNSQ	4058821850 Dell Way	\N	IVUDRJR	\N	0	South Africa	2	VZOOHZJNSQ@dell.com	4058821850	1	5097659419290722	2010/04	user14879	password	18	60000	M
14880	FVHRYD	RMRYLBMERU	7100271210 Dell Way	\N	ALXSVON	\N	0	Canada	2	RMRYLBMERU@dell.com	7100271210	5	7122123049572111	2012/12	user14880	password	34	80000	F
14881	BYXABP	MTNYUADMUE	4441335136 Dell Way	\N	YSWTHKX	\N	0	UK	2	MTNYUADMUE@dell.com	4441335136	3	9124333485495300	2009/10	user14881	password	57	60000	M
14882	MMXOBK	HPICPMPKQN	7749493188 Dell Way	\N	CNGKXEJ	\N	0	Chile	2	HPICPMPKQN@dell.com	7749493188	2	6901693132240326	2010/10	user14882	password	35	60000	F
14883	SIWUSD	KBGANVKEIN	5913132415 Dell Way	\N	RPXOTHV	\N	0	Germany	2	KBGANVKEIN@dell.com	5913132415	3	1734797710087150	2009/09	user14883	password	56	80000	F
14884	WNGPRQ	RXRETBICPA	9192687189 Dell Way	\N	RNOLUKZ	\N	0	China	2	RXRETBICPA@dell.com	9192687189	1	7215402240864933	2011/08	user14884	password	43	20000	F
14885	WJBNAS	LRXETGGIGY	4961162460 Dell Way	\N	WVKQFKZ	\N	0	Canada	2	LRXETGGIGY@dell.com	4961162460	4	8116456207353623	2008/01	user14885	password	84	60000	M
14886	HOJIGV	AEZTLGCRFY	2868178075 Dell Way	\N	NQPTAOW	\N	0	France	2	AEZTLGCRFY@dell.com	2868178075	4	5370958622545004	2009/07	user14886	password	89	20000	M
14887	NMEUHE	YHXKOABTYO	8496871003 Dell Way	\N	KNHKCEW	\N	0	Chile	2	YHXKOABTYO@dell.com	8496871003	2	5545405821409077	2010/04	user14887	password	60	40000	M
14888	BLQIPP	PNZDNBXMQI	9614745706 Dell Way	\N	AYSCCPK	\N	0	UK	2	PNZDNBXMQI@dell.com	9614745706	5	4037105630617589	2009/06	user14888	password	61	20000	M
14889	AUWQKM	DJQRLOEBWE	6287397538 Dell Way	\N	ZPHCERA	\N	0	Canada	2	DJQRLOEBWE@dell.com	6287397538	2	4859079437796027	2008/12	user14889	password	59	80000	M
14890	JMPTYT	DOKODOQZTQ	2286868916 Dell Way	\N	OATTSUW	\N	0	Chile	2	DOKODOQZTQ@dell.com	2286868916	2	4342517694458366	2008/11	user14890	password	89	20000	F
14891	LSZKLD	ZVRCKICDYQ	6111438332 Dell Way	\N	ESJWMGE	\N	0	Japan	2	ZVRCKICDYQ@dell.com	6111438332	3	7455777567345650	2010/07	user14891	password	77	80000	M
14892	NRJYUJ	UMMFUOITEM	1565759013 Dell Way	\N	LOJXVNN	\N	0	China	2	UMMFUOITEM@dell.com	1565759013	2	8565691507887096	2010/01	user14892	password	56	60000	M
14893	FYNZHI	MUNHIWANJM	2217367294 Dell Way	\N	BSJXGXH	\N	0	China	2	MUNHIWANJM@dell.com	2217367294	1	9066841621883214	2008/08	user14893	password	50	80000	M
14894	KHWSQI	MEPUAQHKCJ	7156104512 Dell Way	\N	DMGJJOR	\N	0	Germany	2	MEPUAQHKCJ@dell.com	7156104512	3	7332492583431304	2009/01	user14894	password	51	40000	F
14895	TBDJKP	NAJOQRYTBC	7482550430 Dell Way	\N	FILPWDC	\N	0	Germany	2	NAJOQRYTBC@dell.com	7482550430	5	9076393730938436	2011/04	user14895	password	25	20000	F
14896	EHKOXY	OGNFYMYZOD	6992800769 Dell Way	\N	IZTEDWT	\N	0	South Africa	2	OGNFYMYZOD@dell.com	6992800769	4	6434009246062488	2012/09	user14896	password	75	100000	M
14897	CJMZIB	GVGEHEEVIM	1353774362 Dell Way	\N	VBRYXKU	\N	0	Germany	2	GVGEHEEVIM@dell.com	1353774362	3	5742553041316569	2011/03	user14897	password	54	80000	F
14898	WDGFEM	ALRIQWDYJZ	2048755195 Dell Way	\N	AAXYLSN	\N	0	France	2	ALRIQWDYJZ@dell.com	2048755195	1	3293332079891115	2009/07	user14898	password	86	60000	F
14899	CVPHIQ	SAYIXCHGBH	7927883116 Dell Way	\N	HYFTRSF	\N	0	Russia	2	SAYIXCHGBH@dell.com	7927883116	3	1857343774754554	2009/05	user14899	password	67	80000	F
14900	NITVYM	WXUTZBAAJI	7652791942 Dell Way	\N	ZOBQHGL	\N	0	Australia	2	WXUTZBAAJI@dell.com	7652791942	3	4388902878388763	2008/03	user14900	password	25	80000	M
14901	LKOKWL	HRFGSFHCOG	8978377058 Dell Way	\N	RPXYWJA	\N	0	Japan	2	HRFGSFHCOG@dell.com	8978377058	2	7700345865450800	2008/06	user14901	password	45	100000	M
14902	TKIQVP	HAWAGDCUKT	1970878182 Dell Way	\N	JHSGQSV	\N	0	Germany	2	HAWAGDCUKT@dell.com	1970878182	3	6753872075583786	2011/12	user14902	password	51	60000	M
14903	WWIRLP	SIQYMSSWLC	8049439492 Dell Way	\N	EDJVWFJ	\N	0	UK	2	SIQYMSSWLC@dell.com	8049439492	5	6081222460139543	2011/06	user14903	password	24	60000	F
14904	YUZKKR	SAQETJBEMF	4458703797 Dell Way	\N	IVAEAKD	\N	0	Russia	2	SAQETJBEMF@dell.com	4458703797	4	5852747093420476	2012/10	user14904	password	18	20000	M
14905	UDDFVW	GLBZVCEHHM	5388997496 Dell Way	\N	CIRCSUX	\N	0	Canada	2	GLBZVCEHHM@dell.com	5388997496	3	9550659745465964	2009/06	user14905	password	25	20000	F
14906	GEMBAS	NCSJEWQMJT	2883543256 Dell Way	\N	VAWNUTQ	\N	0	Chile	2	NCSJEWQMJT@dell.com	2883543256	3	6040699411649258	2011/09	user14906	password	60	100000	M
14907	TKAUDO	WVXARONAHI	1765587353 Dell Way	\N	ADWVXMC	\N	0	Canada	2	WVXARONAHI@dell.com	1765587353	4	7943209481425584	2011/03	user14907	password	68	80000	M
14908	CTUFHQ	AFRSTETBMU	4464140702 Dell Way	\N	EIPCVSF	\N	0	UK	2	AFRSTETBMU@dell.com	4464140702	5	7243950860574842	2011/08	user14908	password	48	80000	M
14909	EKYMAZ	RSRLWLMIFR	9288806722 Dell Way	\N	RVTMOYK	\N	0	UK	2	RSRLWLMIFR@dell.com	9288806722	1	6090725949965418	2010/07	user14909	password	32	40000	M
14910	PGEQFV	IXHEITNOKF	2965737259 Dell Way	\N	JESXDCW	\N	0	Australia	2	IXHEITNOKF@dell.com	2965737259	3	6658377664629371	2011/08	user14910	password	87	60000	F
14911	FPWLLE	ISJRLXFWCO	7654045586 Dell Way	\N	BVMEXIG	\N	0	Canada	2	ISJRLXFWCO@dell.com	7654045586	5	8948776627425105	2009/10	user14911	password	41	60000	F
14912	XKLIPU	AZLMWQJZFK	7166427761 Dell Way	\N	URPSAVW	\N	0	Russia	2	AZLMWQJZFK@dell.com	7166427761	4	1923423455562442	2010/01	user14912	password	66	60000	M
14913	BYHRTI	QEUNVEMAOH	6288904529 Dell Way	\N	SEZTZWM	\N	0	Japan	2	QEUNVEMAOH@dell.com	6288904529	3	2560955159831792	2011/04	user14913	password	67	60000	F
14914	QXZJFQ	OADKEQKTXD	9463871332 Dell Way	\N	XXWXTJP	\N	0	China	2	OADKEQKTXD@dell.com	9463871332	4	9904793335590512	2008/06	user14914	password	60	60000	F
14915	MNMRDB	SGLWXVQUZO	8570671058 Dell Way	\N	SVMMEBV	\N	0	Canada	2	SGLWXVQUZO@dell.com	8570671058	5	3847170342691243	2009/05	user14915	password	78	40000	M
14916	IWOMXG	SIDQEUKDID	3239537980 Dell Way	\N	ZUPEWLH	\N	0	Russia	2	SIDQEUKDID@dell.com	3239537980	3	1088572580832988	2011/06	user14916	password	47	60000	M
14917	HCGEJY	NNORHZVQDU	8594009264 Dell Way	\N	LTYHEGA	\N	0	France	2	NNORHZVQDU@dell.com	8594009264	1	1698455102276057	2009/06	user14917	password	62	20000	M
14918	SHWBFK	PUBWUXMYSX	3234321469 Dell Way	\N	RRFWXFH	\N	0	Russia	2	PUBWUXMYSX@dell.com	3234321469	2	1212390046101063	2011/12	user14918	password	22	40000	M
14919	IGTOQI	JRFEPSCHQU	3646697523 Dell Way	\N	YVQWBYP	\N	0	China	2	JRFEPSCHQU@dell.com	3646697523	4	9851832485757768	2009/09	user14919	password	43	100000	F
14920	PRPFAZ	XFEMYHUOBS	8300094992 Dell Way	\N	KSPLQET	\N	0	UK	2	XFEMYHUOBS@dell.com	8300094992	4	2841302839573473	2010/02	user14920	password	28	60000	M
14921	VDWWCU	BGGANBOPTY	9143534556 Dell Way	\N	IJKYNEX	\N	0	China	2	BGGANBOPTY@dell.com	9143534556	1	8611371434293688	2012/03	user14921	password	45	80000	F
14922	NOYQIA	XPAKQOAKNI	3604501497 Dell Way	\N	TXHHBEQ	\N	0	UK	2	XPAKQOAKNI@dell.com	3604501497	3	9622412189375610	2010/11	user14922	password	64	80000	F
14923	FOZNOW	DOHUCIFQQY	4241280271 Dell Way	\N	NYGODWN	\N	0	France	2	DOHUCIFQQY@dell.com	4241280271	3	9540453298948706	2009/02	user14923	password	59	60000	F
14924	CPWQMZ	FUUICZYTYL	1260750635 Dell Way	\N	RFAVBOF	\N	0	France	2	FUUICZYTYL@dell.com	1260750635	1	6886535885278136	2008/09	user14924	password	35	60000	M
14925	VIMHIR	CCAECYYAKQ	8474422376 Dell Way	\N	FKLHYRT	\N	0	UK	2	CCAECYYAKQ@dell.com	8474422376	2	2186031859833747	2010/08	user14925	password	61	60000	F
14926	XXTGPW	IPAKNZLYPR	1721827775 Dell Way	\N	IAZHRSG	\N	0	Germany	2	IPAKNZLYPR@dell.com	1721827775	3	1673006596509367	2011/12	user14926	password	53	20000	M
14927	JYDZUM	OVXCUJAJAI	3682962120 Dell Way	\N	KZQBRXP	\N	0	Russia	2	OVXCUJAJAI@dell.com	3682962120	4	5221372760366649	2009/02	user14927	password	64	40000	M
14928	PJMJWA	FTDZDDJDMT	1689733145 Dell Way	\N	DCVUAKO	\N	0	Chile	2	FTDZDDJDMT@dell.com	1689733145	1	6364480684511364	2009/09	user14928	password	77	80000	F
14929	EFQAGV	UJVXMFBYZE	6185446334 Dell Way	\N	BUZBFOJ	\N	0	Chile	2	UJVXMFBYZE@dell.com	6185446334	5	5616279749665410	2009/10	user14929	password	35	60000	M
14930	LDZRZU	BVSNAUMZYO	9441415484 Dell Way	\N	UYQAMZH	\N	0	Australia	2	BVSNAUMZYO@dell.com	9441415484	5	3861319041345269	2011/01	user14930	password	78	80000	M
14931	ZQFYLG	UDUUXGUWVO	7226044571 Dell Way	\N	VLOHKWJ	\N	0	China	2	UDUUXGUWVO@dell.com	7226044571	4	1504413540940731	2011/07	user14931	password	70	40000	F
14932	JLLUSF	XMAVTUSOJN	9027990427 Dell Way	\N	ZYVKUFT	\N	0	France	2	XMAVTUSOJN@dell.com	9027990427	5	3181743878405541	2010/07	user14932	password	54	100000	M
14933	ZJQROO	DPKWJCLSQL	4304027031 Dell Way	\N	QLVLQOY	\N	0	Germany	2	DPKWJCLSQL@dell.com	4304027031	1	9496603816747666	2012/09	user14933	password	79	80000	M
14934	EKITZM	IJJSMULCFC	7028444544 Dell Way	\N	OAOFPMS	\N	0	UK	2	IJJSMULCFC@dell.com	7028444544	4	8617008419241757	2009/07	user14934	password	61	20000	M
14935	ZIMZUV	JDNVYZYDBN	1932728139 Dell Way	\N	EPSUCLT	\N	0	Russia	2	JDNVYZYDBN@dell.com	1932728139	3	2061915923375636	2011/03	user14935	password	27	40000	F
14936	MUDGPN	KDJICHMDVR	7892047333 Dell Way	\N	TNLVYEP	\N	0	Australia	2	KDJICHMDVR@dell.com	7892047333	4	7065571472048760	2012/11	user14936	password	18	20000	F
14937	UHOKUZ	NDIQLUUGMN	7372996755 Dell Way	\N	TXJSCZT	\N	0	South Africa	2	NDIQLUUGMN@dell.com	7372996755	3	8153016606345774	2010/06	user14937	password	85	100000	F
14938	FLQZLE	CTVOOPUADO	5406073893 Dell Way	\N	XNHZMBV	\N	0	Chile	2	CTVOOPUADO@dell.com	5406073893	4	7856092133093626	2012/07	user14938	password	64	20000	M
14939	CVTNAW	GVKVLFVOTT	3115815306 Dell Way	\N	BBTOCPT	\N	0	Germany	2	GVKVLFVOTT@dell.com	3115815306	3	5665430932305754	2011/02	user14939	password	69	60000	F
14940	NITOEA	KPVVURKOKM	3890611177 Dell Way	\N	PEASTUH	\N	0	UK	2	KPVVURKOKM@dell.com	3890611177	4	8166471027769149	2010/06	user14940	password	44	80000	F
14941	RMPVNZ	KJVFAFTLRJ	2023528525 Dell Way	\N	QSBJNIJ	\N	0	South Africa	2	KJVFAFTLRJ@dell.com	2023528525	1	3849576749373227	2011/07	user14941	password	21	80000	F
14942	OGABFL	LBQLGKXYTN	5187647766 Dell Way	\N	RUXECHA	\N	0	Chile	2	LBQLGKXYTN@dell.com	5187647766	2	8460556806065143	2012/05	user14942	password	52	20000	M
14943	SGZYRK	ZIWGSUFLIW	4525224102 Dell Way	\N	GFBJNBO	\N	0	UK	2	ZIWGSUFLIW@dell.com	4525224102	2	9790309878066184	2011/11	user14943	password	30	80000	M
14944	KSMCCM	KZSCUXOCTU	2035556128 Dell Way	\N	IVDVWSV	\N	0	Chile	2	KZSCUXOCTU@dell.com	2035556128	4	1328702183440327	2012/12	user14944	password	71	60000	F
14945	LALONW	NFZICNKWIT	2536532003 Dell Way	\N	RMOOFJV	\N	0	China	2	NFZICNKWIT@dell.com	2536532003	5	3668632544577122	2008/08	user14945	password	79	60000	F
14946	WYOJUC	PTKSHVOQOG	5236171559 Dell Way	\N	CDUHNQQ	\N	0	Japan	2	PTKSHVOQOG@dell.com	5236171559	5	8478072066791356	2008/10	user14946	password	42	20000	M
14947	HQACTQ	WDIDZWUODW	7455946186 Dell Way	\N	SXEFNUX	\N	0	Australia	2	WDIDZWUODW@dell.com	7455946186	4	1602982257958501	2010/02	user14947	password	28	20000	F
14948	UDLNTI	RCMQYGECCX	8017104800 Dell Way	\N	ZHCNCAO	\N	0	South Africa	2	RCMQYGECCX@dell.com	8017104800	4	3528999890666455	2012/10	user14948	password	47	40000	M
14949	OSBIAS	KMIJSNLVLL	1998529213 Dell Way	\N	CNZEONZ	\N	0	China	2	KMIJSNLVLL@dell.com	1998529213	2	2860632870346308	2012/09	user14949	password	50	40000	F
14950	DLODDY	PMHIASDLEG	6994161655 Dell Way	\N	ZDKOQKX	\N	0	Russia	2	PMHIASDLEG@dell.com	6994161655	1	6362820212729276	2009/07	user14950	password	90	60000	M
14951	LCVOAL	BITCBXOFDO	1852047275 Dell Way	\N	INCYYZR	\N	0	Germany	2	BITCBXOFDO@dell.com	1852047275	2	9384101744741202	2011/04	user14951	password	53	40000	M
14952	PDHQOJ	YILAFZFIOO	5265779437 Dell Way	\N	WQNUQEJ	\N	0	Russia	2	YILAFZFIOO@dell.com	5265779437	2	4236963151488453	2011/10	user14952	password	67	60000	F
14953	UTAJCY	RNZWNEFBTB	5591670578 Dell Way	\N	SGVILFB	\N	0	UK	2	RNZWNEFBTB@dell.com	5591670578	3	6947587979026139	2009/02	user14953	password	26	80000	M
14954	VRGYQY	LQVZUABOCT	5959409665 Dell Way	\N	UXCGCDD	\N	0	Japan	2	LQVZUABOCT@dell.com	5959409665	5	9339284228160978	2011/12	user14954	password	62	60000	M
14955	HURYSD	OODJPEXRYS	9208056133 Dell Way	\N	OAYRDCH	\N	0	Japan	2	OODJPEXRYS@dell.com	9208056133	2	4014397420454770	2012/11	user14955	password	80	80000	F
14956	QHCJLR	YOANSYERRT	9425689588 Dell Way	\N	RQKVSSN	\N	0	Japan	2	YOANSYERRT@dell.com	9425689588	5	5196642495691776	2011/09	user14956	password	22	100000	F
14957	JASURR	JSECQITIBK	6002575423 Dell Way	\N	YMFQESH	\N	0	Canada	2	JSECQITIBK@dell.com	6002575423	4	9117437689565124	2009/10	user14957	password	77	80000	F
14958	VIZMAI	EEKVNDEONC	8020481274 Dell Way	\N	BTTGLAJ	\N	0	Australia	2	EEKVNDEONC@dell.com	8020481274	2	3447023834101856	2010/02	user14958	password	82	80000	M
14959	FTKGBP	KMLXPPMDRN	4886692234 Dell Way	\N	WLUILEJ	\N	0	Chile	2	KMLXPPMDRN@dell.com	4886692234	4	8515177582856269	2010/07	user14959	password	62	60000	M
14960	JWZKLJ	XXHMMTQEHN	8297930659 Dell Way	\N	PCWBGFH	\N	0	Japan	2	XXHMMTQEHN@dell.com	8297930659	1	2714721001684665	2009/09	user14960	password	64	20000	F
14961	MANYKK	WRXJKONSBD	6874766364 Dell Way	\N	UXFACNR	\N	0	UK	2	WRXJKONSBD@dell.com	6874766364	5	2963775650598109	2010/07	user14961	password	37	60000	F
14962	HAYRLU	IJETXRMYVG	8649234821 Dell Way	\N	WBHYOZW	\N	0	Chile	2	IJETXRMYVG@dell.com	8649234821	1	6490558447316290	2009/05	user14962	password	26	40000	M
14963	DIHPDQ	ZHJWZVVVCR	6029384219 Dell Way	\N	WJQKIMP	\N	0	Canada	2	ZHJWZVVVCR@dell.com	6029384219	2	6022346308454872	2012/05	user14963	password	85	60000	F
14964	GVCKLB	RVYRQTMTLI	6090127632 Dell Way	\N	CCSLPIQ	\N	0	Canada	2	RVYRQTMTLI@dell.com	6090127632	2	1304917967412620	2012/02	user14964	password	58	60000	F
14965	JMUUOM	PNDGGPZSYC	4891931624 Dell Way	\N	VROKZFN	\N	0	Germany	2	PNDGGPZSYC@dell.com	4891931624	3	5236815151292831	2010/02	user14965	password	81	100000	F
14966	JTHYFX	LJDSZDLXGG	7438127852 Dell Way	\N	OVQOBEC	\N	0	France	2	LJDSZDLXGG@dell.com	7438127852	3	1568546210415661	2012/06	user14966	password	20	40000	M
14967	UPTAMF	JQXIUIGBOU	1354278714 Dell Way	\N	WFIYJLL	\N	0	Australia	2	JQXIUIGBOU@dell.com	1354278714	3	9121090870816260	2010/07	user14967	password	33	40000	F
14968	UCIHHS	XFARNHSCBP	5195741956 Dell Way	\N	HKORWZT	\N	0	South Africa	2	XFARNHSCBP@dell.com	5195741956	4	4492018656339497	2012/11	user14968	password	69	40000	M
14969	UQYCIV	HINUPGXRWF	3205286284 Dell Way	\N	BKWXJPV	\N	0	South Africa	2	HINUPGXRWF@dell.com	3205286284	2	8424756758846343	2008/11	user14969	password	26	80000	M
14970	TRUBNB	KAWAHURDAT	7161819860 Dell Way	\N	NWRXMMS	\N	0	Russia	2	KAWAHURDAT@dell.com	7161819860	3	8379389800131322	2010/09	user14970	password	58	40000	F
14971	FCMTEW	TBWAWNDWHR	8634945746 Dell Way	\N	TYOFLHY	\N	0	Canada	2	TBWAWNDWHR@dell.com	8634945746	4	7405448505189270	2010/04	user14971	password	19	100000	M
14972	DKHIGA	KCBGQFCXXV	7845849141 Dell Way	\N	WMBHTZK	\N	0	Japan	2	KCBGQFCXXV@dell.com	7845849141	1	2165959481615573	2008/02	user14972	password	22	80000	F
14973	MXPSYZ	VAFMGIJDEG	1578456976 Dell Way	\N	PFOJFYZ	\N	0	UK	2	VAFMGIJDEG@dell.com	1578456976	1	1573869896586984	2009/02	user14973	password	69	60000	M
14974	QBIOBE	PGQVPAZTGP	9932626924 Dell Way	\N	ZUYFTXE	\N	0	South Africa	2	PGQVPAZTGP@dell.com	9932626924	2	1136356863658875	2008/12	user14974	password	53	80000	M
14975	ODDPHT	WXOLXOFEDF	8330445135 Dell Way	\N	ZBKSZON	\N	0	UK	2	WXOLXOFEDF@dell.com	8330445135	3	2001010802108794	2011/01	user14975	password	82	40000	M
14976	ALFHEB	FTNCITHLYH	1746242008 Dell Way	\N	NJZMXNL	\N	0	Russia	2	FTNCITHLYH@dell.com	1746242008	3	5421702655963600	2008/06	user14976	password	76	80000	F
14977	GYTLAY	FOBNHIZGPM	9796685275 Dell Way	\N	PPZNDKG	\N	0	Chile	2	FOBNHIZGPM@dell.com	9796685275	4	4090923848561943	2010/07	user14977	password	23	100000	M
14978	APGANM	OOZWXZDMMS	3344969439 Dell Way	\N	CLGGWNL	\N	0	South Africa	2	OOZWXZDMMS@dell.com	3344969439	4	3388285782653838	2012/11	user14978	password	27	80000	M
14979	SXXGJL	VJISILFUEH	8146533451 Dell Way	\N	GKOCYZY	\N	0	Canada	2	VJISILFUEH@dell.com	8146533451	2	1089472797233611	2011/05	user14979	password	65	60000	F
14980	OLIXXD	GFWPRBKVJQ	9361942477 Dell Way	\N	GXTEXSJ	\N	0	Russia	2	GFWPRBKVJQ@dell.com	9361942477	2	4314885003026575	2009/01	user14980	password	84	40000	M
14981	ISMGWT	LSICUTYDJF	2491453252 Dell Way	\N	BDKZVUR	\N	0	Russia	2	LSICUTYDJF@dell.com	2491453252	1	1379991053137928	2009/12	user14981	password	47	80000	F
14982	CGNZAZ	RICLCAPLGQ	3902739418 Dell Way	\N	OQPKKHE	\N	0	Germany	2	RICLCAPLGQ@dell.com	3902739418	2	7954985171090812	2009/08	user14982	password	58	60000	M
14983	UCRUBJ	DDUFEKRKAG	1223193015 Dell Way	\N	AQRLXVA	\N	0	Chile	2	DDUFEKRKAG@dell.com	1223193015	4	5641071709338576	2011/04	user14983	password	23	40000	F
14984	EBYFKC	IFHMPZWQGX	1977805955 Dell Way	\N	HXIFSIL	\N	0	Russia	2	IFHMPZWQGX@dell.com	1977805955	5	4342993275262416	2010/01	user14984	password	71	60000	F
14985	UMKFOT	LWFBWCSCZZ	6553231169 Dell Way	\N	ZIFRRQK	\N	0	Russia	2	LWFBWCSCZZ@dell.com	6553231169	4	2846406798344105	2011/07	user14985	password	73	100000	F
14986	GGNVZZ	SFAOISQISQ	5507666629 Dell Way	\N	QXHHOSB	\N	0	Canada	2	SFAOISQISQ@dell.com	5507666629	2	8379549383185805	2008/01	user14986	password	67	40000	F
14987	YWDYVV	DWKLOATHQK	1617610849 Dell Way	\N	EYSSRUW	\N	0	Canada	2	DWKLOATHQK@dell.com	1617610849	4	2718417965807020	2008/05	user14987	password	56	60000	F
14988	KOGGJK	CTWRUQYLAD	4416286099 Dell Way	\N	KTVBNSF	\N	0	Germany	2	CTWRUQYLAD@dell.com	4416286099	3	7404081127606333	2011/12	user14988	password	27	20000	F
14989	RIPBSS	VOJPEIBFLL	2194607037 Dell Way	\N	ZGMMYSC	\N	0	China	2	VOJPEIBFLL@dell.com	2194607037	5	1778524535708129	2008/12	user14989	password	28	60000	M
14990	LARESM	SCBXLCDWOC	5454419667 Dell Way	\N	DBPCTSL	\N	0	South Africa	2	SCBXLCDWOC@dell.com	5454419667	3	9749555727932604	2010/08	user14990	password	47	20000	F
14991	LRHEDA	GFYSICOWES	7643585503 Dell Way	\N	XUURMFO	\N	0	UK	2	GFYSICOWES@dell.com	7643585503	3	4651603504549712	2010/12	user14991	password	49	60000	F
14992	DUOGVV	MTNVVBSATQ	4736122664 Dell Way	\N	UOHHTWH	\N	0	Germany	2	MTNVVBSATQ@dell.com	4736122664	4	9177658591885120	2009/02	user14992	password	49	80000	F
14993	GHMBCZ	UQUQRNQLDL	7008718066 Dell Way	\N	ZLSTHZG	\N	0	Russia	2	UQUQRNQLDL@dell.com	7008718066	1	1675232540816068	2011/08	user14993	password	78	20000	M
14994	DNXGMR	WHHNUYZYJZ	2663119746 Dell Way	\N	JBTQBAJ	\N	0	Russia	2	WHHNUYZYJZ@dell.com	2663119746	3	5632818472571672	2011/04	user14994	password	56	80000	F
14995	ANPNFL	VMZQKZOUYY	4356569100 Dell Way	\N	WROXSYR	\N	0	South Africa	2	VMZQKZOUYY@dell.com	4356569100	1	7077255082316697	2011/09	user14995	password	40	20000	M
14996	VQGACC	NCSYBHSAFO	3919266046 Dell Way	\N	SUMKSDH	\N	0	Canada	2	NCSYBHSAFO@dell.com	3919266046	5	7630641074385495	2008/04	user14996	password	72	80000	F
14997	JADLCQ	OVPPDIPIXH	9442758185 Dell Way	\N	DKSWOZZ	\N	0	South Africa	2	OVPPDIPIXH@dell.com	9442758185	4	8982413590420038	2009/06	user14997	password	64	40000	M
14998	QKHTBV	ORLRZAAWIE	7298246922 Dell Way	\N	GBAUAZR	\N	0	UK	2	ORLRZAAWIE@dell.com	7298246922	3	2485956128221005	2008/03	user14998	password	51	100000	M
14999	WHOYCD	POVOOWLXAS	7509881092 Dell Way	\N	YANZAEY	\N	0	Russia	2	POVOOWLXAS@dell.com	7509881092	1	8986283318139614	2012/07	user14999	password	81	80000	F
15000	DIKGMZ	UHOJDZHDSG	3619997775 Dell Way	\N	EFGFJEY	\N	0	Australia	2	UHOJDZHDSG@dell.com	3619997775	5	1036405920516699	2012/09	user15000	password	72	40000	M
15001	BSDNRY	VGHZFPDYWI	3921538946 Dell Way	\N	DCNMGMP	\N	0	Germany	2	VGHZFPDYWI@dell.com	3921538946	3	4709710520226509	2008/05	user15001	password	70	100000	F
15002	KAYCZU	IGTOWWMSEP	3310981128 Dell Way	\N	USCBERP	\N	0	Germany	2	IGTOWWMSEP@dell.com	3310981128	1	5927969297394157	2010/09	user15002	password	51	20000	F
15003	MYGLTO	SMCPIPHNEC	7674849641 Dell Way	\N	FHDKYSX	\N	0	Chile	2	SMCPIPHNEC@dell.com	7674849641	3	8194193267263473	2010/11	user15003	password	76	80000	F
15004	TWVMKO	ZNDICKVHNA	7843744722 Dell Way	\N	OQKNJIS	\N	0	Canada	2	ZNDICKVHNA@dell.com	7843744722	3	6218462005257607	2011/04	user15004	password	32	20000	F
15005	BWPMLO	ZOWCZRKMSZ	7663802649 Dell Way	\N	DDMMLFP	\N	0	Canada	2	ZOWCZRKMSZ@dell.com	7663802649	1	8658183491788805	2008/05	user15005	password	83	20000	F
15006	UTXFHX	UEATWKGOJJ	6723957670 Dell Way	\N	RWWCBLH	\N	0	South Africa	2	UEATWKGOJJ@dell.com	6723957670	1	8969114213250578	2008/01	user15006	password	21	60000	M
15007	UIACGU	HGODQVRAFI	8750129516 Dell Way	\N	WBLYNST	\N	0	Canada	2	HGODQVRAFI@dell.com	8750129516	4	2557643574662506	2012/09	user15007	password	62	80000	F
15008	YTPFOW	LDZCYQCDZZ	3819046576 Dell Way	\N	FKXSDRX	\N	0	Australia	2	LDZCYQCDZZ@dell.com	3819046576	1	9112258251756432	2008/09	user15008	password	62	60000	M
15009	JCVXYH	AYJYOLCOLH	9787168529 Dell Way	\N	ZIADAXD	\N	0	China	2	AYJYOLCOLH@dell.com	9787168529	1	3906249688472599	2011/08	user15009	password	77	40000	F
15010	XDXWKY	UUXJFZXRHX	2484105504 Dell Way	\N	ZHAZFDI	\N	0	Canada	2	UUXJFZXRHX@dell.com	2484105504	4	8583133665844799	2012/06	user15010	password	27	100000	F
15011	GSFRQZ	LNIRNGIUDI	3347931080 Dell Way	\N	CDIHGQM	\N	0	France	2	LNIRNGIUDI@dell.com	3347931080	2	3172696418594569	2011/06	user15011	password	21	20000	M
15012	THKKGV	YOMLVVFYDI	4734056600 Dell Way	\N	BLPICCT	\N	0	China	2	YOMLVVFYDI@dell.com	4734056600	1	1484601416625082	2012/01	user15012	password	27	60000	M
15013	KZFQVE	FIPADVZHDA	2120582569 Dell Way	\N	STJUVDD	\N	0	Chile	2	FIPADVZHDA@dell.com	2120582569	1	2173465832136571	2008/04	user15013	password	70	100000	M
15014	SFJNKP	VZQYVPGZQY	1987807485 Dell Way	\N	TZTOCXV	\N	0	Chile	2	VZQYVPGZQY@dell.com	1987807485	5	4572871827054769	2010/09	user15014	password	46	20000	F
15015	QNXACT	ATSVIYVYXO	9248283003 Dell Way	\N	YQDAOYG	\N	0	Japan	2	ATSVIYVYXO@dell.com	9248283003	4	1950681346002966	2011/01	user15015	password	36	100000	M
15016	UXRXQR	QINZGJXEXW	7580594620 Dell Way	\N	VAWJZCB	\N	0	UK	2	QINZGJXEXW@dell.com	7580594620	1	5552099529653788	2011/05	user15016	password	54	60000	F
15017	KCCBTS	JHRQQPUNLP	2616916923 Dell Way	\N	OIZOLAL	\N	0	Canada	2	JHRQQPUNLP@dell.com	2616916923	5	9227209482342006	2010/06	user15017	password	41	80000	M
15018	KWXEPH	LHYCWTPIJE	2433534972 Dell Way	\N	RITCJFG	\N	0	Germany	2	LHYCWTPIJE@dell.com	2433534972	1	2276472456753254	2011/06	user15018	password	85	60000	M
15019	UKBJRN	QQPNJFWTJN	1084788985 Dell Way	\N	CCPLHWA	\N	0	France	2	QQPNJFWTJN@dell.com	1084788985	1	1797898705583065	2010/01	user15019	password	60	40000	M
15020	ZLFRYV	HNIRSFKCSM	2049395975 Dell Way	\N	FIYNEZZ	\N	0	Canada	2	HNIRSFKCSM@dell.com	2049395975	1	7127511159051210	2008/08	user15020	password	22	20000	M
15021	NGHLBP	ZKHSQSVIFA	6581579323 Dell Way	\N	REOVDOA	\N	0	Chile	2	ZKHSQSVIFA@dell.com	6581579323	4	4807367529254407	2009/10	user15021	password	51	100000	F
15022	SFTUVS	FCKVUGDZGV	4534952143 Dell Way	\N	DVRHJRN	\N	0	UK	2	FCKVUGDZGV@dell.com	4534952143	5	3303742952644825	2008/05	user15022	password	30	60000	F
15023	JEWEXB	HIWCOACUVF	9405304573 Dell Way	\N	QMMZEAZ	\N	0	Germany	2	HIWCOACUVF@dell.com	9405304573	2	7689327686093748	2009/05	user15023	password	31	60000	M
15024	JHYGIG	OFICFKXBQN	7296098389 Dell Way	\N	ODNTDMI	\N	0	Australia	2	OFICFKXBQN@dell.com	7296098389	1	4458272887859494	2008/04	user15024	password	75	100000	M
15025	BUXKAL	PJOVTMXJAM	6743797183 Dell Way	\N	MNFQAOR	\N	0	Russia	2	PJOVTMXJAM@dell.com	6743797183	1	8158276967238636	2012/11	user15025	password	64	60000	M
15026	LLILXX	VLTOYQYYCL	8308159506 Dell Way	\N	MIBMXTF	\N	0	Germany	2	VLTOYQYYCL@dell.com	8308159506	5	4960511391982436	2011/08	user15026	password	89	80000	F
15027	KYNHVI	TPXRFVPIGC	7893026587 Dell Way	\N	RHOOAUC	\N	0	South Africa	2	TPXRFVPIGC@dell.com	7893026587	3	5658877704758198	2009/07	user15027	password	26	60000	M
15028	BZFXIY	MFQRAGZGIR	8476830296 Dell Way	\N	OXFORHK	\N	0	France	2	MFQRAGZGIR@dell.com	8476830296	5	8582140850368888	2009/01	user15028	password	40	40000	F
15029	HMZPKL	UBDVHDCQUQ	5869002910 Dell Way	\N	NZFFHPR	\N	0	Canada	2	UBDVHDCQUQ@dell.com	5869002910	3	5238558595534414	2010/10	user15029	password	71	80000	F
15030	FRRQDM	RHIZKKPFAD	5432436755 Dell Way	\N	FFIMVZQ	\N	0	China	2	RHIZKKPFAD@dell.com	5432436755	1	9636165584903212	2009/10	user15030	password	66	40000	F
15031	IBQMOH	TXGEHWJHZO	7969446694 Dell Way	\N	NIBIHRS	\N	0	Russia	2	TXGEHWJHZO@dell.com	7969446694	4	1813375533558428	2010/04	user15031	password	52	80000	M
15032	OGDDOX	AVCHRLPQZC	8221835467 Dell Way	\N	YBLGSDB	\N	0	France	2	AVCHRLPQZC@dell.com	8221835467	1	1831143605057150	2008/08	user15032	password	69	80000	F
15033	YYHNVH	IXPZJEQJHP	1218395910 Dell Way	\N	KSVCWXP	\N	0	Japan	2	IXPZJEQJHP@dell.com	1218395910	4	8130433018319310	2011/05	user15033	password	60	100000	F
15034	NCWJJF	HZFQDVZLKJ	8242988638 Dell Way	\N	EGMADCS	\N	0	Canada	2	HZFQDVZLKJ@dell.com	8242988638	3	8194543400313706	2009/01	user15034	password	61	60000	M
15035	RMYBRF	BWWFSVQDFU	1280783639 Dell Way	\N	JSVNVNR	\N	0	Japan	2	BWWFSVQDFU@dell.com	1280783639	3	8571196368895472	2008/01	user15035	password	48	80000	M
15036	XQVOVW	LRBDNSGTMP	3212853307 Dell Way	\N	LICHWUX	\N	0	South Africa	2	LRBDNSGTMP@dell.com	3212853307	4	9903531544841828	2009/03	user15036	password	67	20000	F
15037	HXQDTB	VVEINKCAAN	5275354475 Dell Way	\N	IDVFYSC	\N	0	Canada	2	VVEINKCAAN@dell.com	5275354475	1	5362007868941874	2011/09	user15037	password	58	80000	F
15038	LIEFJA	BOIPZKPAYY	3842661599 Dell Way	\N	DUEBNGG	\N	0	UK	2	BOIPZKPAYY@dell.com	3842661599	4	6649213025812060	2008/04	user15038	password	42	20000	M
15039	RHYBHA	PQPOBFPAES	8065462979 Dell Way	\N	UIUIOBH	\N	0	South Africa	2	PQPOBFPAES@dell.com	8065462979	5	9606484917923808	2008/04	user15039	password	23	100000	M
15040	JTZRUO	IJDKPSKTLF	7687035826 Dell Way	\N	CGNRHVO	\N	0	Australia	2	IJDKPSKTLF@dell.com	7687035826	3	2451726099476218	2012/08	user15040	password	88	100000	M
15041	TXQNMY	WPIMITFUZI	1585924929 Dell Way	\N	ANZIIOL	\N	0	Australia	2	WPIMITFUZI@dell.com	1585924929	3	1685062610544264	2011/07	user15041	password	90	80000	F
15042	XGUJER	YNDHHJBGRC	4860117058 Dell Way	\N	TRKCFVE	\N	0	Chile	2	YNDHHJBGRC@dell.com	4860117058	2	9495278076268732	2012/03	user15042	password	58	40000	F
15043	UBMZSL	MWSUGUAXWU	3581266941 Dell Way	\N	PHWVDBD	\N	0	Germany	2	MWSUGUAXWU@dell.com	3581266941	1	5946729631163180	2010/08	user15043	password	77	80000	F
15044	WEJPPW	MIQSCRQZLG	3182705793 Dell Way	\N	HIBKJEZ	\N	0	Japan	2	MIQSCRQZLG@dell.com	3182705793	3	2627745567355305	2012/05	user15044	password	79	40000	F
15045	AQVPNI	YEABWRAHXI	3304423097 Dell Way	\N	QYTZDSQ	\N	0	China	2	YEABWRAHXI@dell.com	3304423097	5	3051707049366087	2011/08	user15045	password	53	100000	M
15046	DRGRZE	VAGRRGZOOP	1311035524 Dell Way	\N	NHPQAFA	\N	0	Chile	2	VAGRRGZOOP@dell.com	1311035524	2	9014449169859292	2011/09	user15046	password	71	40000	M
15047	KQNKVJ	LBBCHARWQE	1554276342 Dell Way	\N	EFVFLVM	\N	0	France	2	LBBCHARWQE@dell.com	1554276342	2	2623564619570970	2011/02	user15047	password	57	80000	M
15048	EEYZOJ	APLIQDFHHJ	5114811345 Dell Way	\N	NDPYYCL	\N	0	Australia	2	APLIQDFHHJ@dell.com	5114811345	4	8136817388236523	2010/02	user15048	password	50	20000	F
15049	QAHEJH	UVQKZVRGFF	2900016709 Dell Way	\N	JUDIWPI	\N	0	China	2	UVQKZVRGFF@dell.com	2900016709	1	9182376484386624	2009/07	user15049	password	18	80000	F
15050	AZJKHE	GXOFTGMYLW	6628321090 Dell Way	\N	TPEQFNZ	\N	0	France	2	GXOFTGMYLW@dell.com	6628321090	5	7973035448696465	2008/11	user15050	password	51	40000	M
15051	LUITYO	QMUKTGIFCC	6719978454 Dell Way	\N	VHTAUTK	\N	0	France	2	QMUKTGIFCC@dell.com	6719978454	1	6532835212070496	2010/08	user15051	password	18	60000	F
15052	UUVSJM	FDWYJFEMHZ	6072500712 Dell Way	\N	UBZOUJZ	\N	0	France	2	FDWYJFEMHZ@dell.com	6072500712	4	9703226128593088	2009/08	user15052	password	48	40000	F
15053	FDCOPH	RLGBQKNYJI	5496502910 Dell Way	\N	AJXVTXG	\N	0	Chile	2	RLGBQKNYJI@dell.com	5496502910	2	5570192693267018	2008/08	user15053	password	77	60000	M
15054	YPJNXB	ZECQOQOYYP	8791091726 Dell Way	\N	HVKASQI	\N	0	Chile	2	ZECQOQOYYP@dell.com	8791091726	5	4070346381049603	2010/08	user15054	password	80	40000	M
15055	MSCJTB	NWRCMGBKWI	5896189864 Dell Way	\N	GGJZXSF	\N	0	Russia	2	NWRCMGBKWI@dell.com	5896189864	3	3378750164993107	2008/05	user15055	password	61	80000	M
15056	HWGBYU	XQWKXXVTGB	8153474358 Dell Way	\N	ZQBWIGQ	\N	0	South Africa	2	XQWKXXVTGB@dell.com	8153474358	5	1653594469185918	2008/07	user15056	password	79	20000	M
15057	SHWRBU	HYEEWZXCBX	4141362235 Dell Way	\N	TCUBILY	\N	0	Canada	2	HYEEWZXCBX@dell.com	4141362235	1	4007244262378663	2012/11	user15057	password	46	80000	M
15058	ROGTIO	SNSOMQQOOK	5006326007 Dell Way	\N	QIMZUKD	\N	0	Canada	2	SNSOMQQOOK@dell.com	5006326007	3	9912149712909014	2009/11	user15058	password	66	100000	M
15059	FDIORA	BKOOBFDPPT	4148953189 Dell Way	\N	YBTTMXW	\N	0	UK	2	BKOOBFDPPT@dell.com	4148953189	5	3093826171476394	2009/07	user15059	password	27	80000	M
15060	HBHZBJ	KQYLVCBKWA	5503530763 Dell Way	\N	MPTYMQW	\N	0	South Africa	2	KQYLVCBKWA@dell.com	5503530763	1	1419136661570519	2008/03	user15060	password	76	80000	M
15061	WCMYLX	OKIJMKUIKH	2539469739 Dell Way	\N	YEFLVCH	\N	0	China	2	OKIJMKUIKH@dell.com	2539469739	2	4128708432894200	2009/02	user15061	password	26	100000	M
15062	FKXRHM	BQWOARXLYV	8737293918 Dell Way	\N	QEHLGOT	\N	0	France	2	BQWOARXLYV@dell.com	8737293918	1	8275674439501018	2012/03	user15062	password	70	100000	F
15063	DWCLJE	BFTCXQNVME	5360291368 Dell Way	\N	ZTPFHJQ	\N	0	Canada	2	BFTCXQNVME@dell.com	5360291368	3	2131299897097051	2011/03	user15063	password	24	20000	F
15064	ZGSIKU	ODWLUKHGOG	6158408736 Dell Way	\N	AEMHNDL	\N	0	Australia	2	ODWLUKHGOG@dell.com	6158408736	3	7617859778460116	2011/08	user15064	password	83	20000	M
15065	DUYOON	SKZNVGTJNT	1472608438 Dell Way	\N	NABBDMB	\N	0	Russia	2	SKZNVGTJNT@dell.com	1472608438	5	5057514859829098	2011/09	user15065	password	53	40000	M
15066	GHKVUD	GUQBAKKNEY	9127681288 Dell Way	\N	NFARSCJ	\N	0	Russia	2	GUQBAKKNEY@dell.com	9127681288	5	5178115451242775	2011/04	user15066	password	75	60000	M
15067	CWKWAQ	RQSRBDFFBT	6685112650 Dell Way	\N	LCKDEUX	\N	0	Australia	2	RQSRBDFFBT@dell.com	6685112650	2	7175191916991026	2012/02	user15067	password	28	60000	F
15068	AYDAPU	RHLSKQYMKJ	7729219623 Dell Way	\N	OUMTPKV	\N	0	Chile	2	RHLSKQYMKJ@dell.com	7729219623	3	2695721779484302	2012/08	user15068	password	71	20000	M
15069	RGRHAJ	OMBZDZLNIA	1522005433 Dell Way	\N	HVTXFOD	\N	0	UK	2	OMBZDZLNIA@dell.com	1522005433	2	8795594593510033	2011/01	user15069	password	90	40000	M
15070	GAAHJP	TLPWLAJTBR	1265455435 Dell Way	\N	PUOVJSU	\N	0	France	2	TLPWLAJTBR@dell.com	1265455435	4	1949096625670790	2008/08	user15070	password	51	100000	M
15071	MWEWMX	IBUTCDNDVD	4296876161 Dell Way	\N	YKYHCSR	\N	0	Canada	2	IBUTCDNDVD@dell.com	4296876161	4	2935177594423294	2008/04	user15071	password	21	100000	M
15072	XCQKAY	LUSOXFSTIQ	4389925726 Dell Way	\N	DHXFZPJ	\N	0	China	2	LUSOXFSTIQ@dell.com	4389925726	3	4331920705735684	2011/08	user15072	password	38	40000	M
15073	JAYJYK	DQYBWRVFHY	1759391144 Dell Way	\N	MEEMUNV	\N	0	Canada	2	DQYBWRVFHY@dell.com	1759391144	1	8055075580719859	2011/06	user15073	password	29	40000	M
15074	EEFCPJ	TOLQFGVMFI	8108041836 Dell Way	\N	RJULWPP	\N	0	UK	2	TOLQFGVMFI@dell.com	8108041836	2	6999346796888859	2009/07	user15074	password	84	20000	M
15075	CIVRSP	FDFLKBXPJP	1531795843 Dell Way	\N	YEBVTRU	\N	0	Germany	2	FDFLKBXPJP@dell.com	1531795843	3	8301257139537484	2011/05	user15075	password	85	40000	F
15076	GEDYTJ	CZUMBSBLHA	2059504839 Dell Way	\N	PIWJARX	\N	0	Australia	2	CZUMBSBLHA@dell.com	2059504839	4	7132204727269710	2010/08	user15076	password	19	100000	M
15077	ECVYMX	YHJAZLMHMB	1464414772 Dell Way	\N	QILQZIS	\N	0	Australia	2	YHJAZLMHMB@dell.com	1464414772	2	6305734452325851	2011/05	user15077	password	58	60000	M
15078	RKODHN	LRNLDZSPBJ	1903282295 Dell Way	\N	XMAXUSZ	\N	0	South Africa	2	LRNLDZSPBJ@dell.com	1903282295	3	5904256088659168	2010/02	user15078	password	26	20000	M
15079	NQYVDJ	NRVQQNFSXD	6686823932 Dell Way	\N	EXBZPBV	\N	0	Russia	2	NRVQQNFSXD@dell.com	6686823932	2	2899696520529687	2011/06	user15079	password	40	60000	F
15080	ZNVDXI	USYLGEDDIH	5054960072 Dell Way	\N	AJGQKCI	\N	0	Australia	2	USYLGEDDIH@dell.com	5054960072	3	8291543821338565	2012/11	user15080	password	45	100000	M
15081	XTYVCS	NBEUFHXNPY	5146350619 Dell Way	\N	XWOHYXI	\N	0	China	2	NBEUFHXNPY@dell.com	5146350619	1	3902028893120587	2009/07	user15081	password	37	20000	F
15082	ACGDVU	EZOJHMXWKU	6305046851 Dell Way	\N	SZCRXLB	\N	0	China	2	EZOJHMXWKU@dell.com	6305046851	2	7180997746996582	2008/08	user15082	password	78	60000	M
15083	XVUTPY	SEHAQFWBZP	6858584446 Dell Way	\N	ACGYNHH	\N	0	Canada	2	SEHAQFWBZP@dell.com	6858584446	5	3161368410568684	2009/10	user15083	password	76	100000	M
15084	QSMFQF	JYFZDCACRB	3609640835 Dell Way	\N	FXASFHV	\N	0	South Africa	2	JYFZDCACRB@dell.com	3609640835	1	2225264962762594	2008/11	user15084	password	22	100000	M
15085	UISKOC	ITCLVDONFT	4796934972 Dell Way	\N	LFMQNIN	\N	0	Russia	2	ITCLVDONFT@dell.com	4796934972	4	9140652690548452	2009/09	user15085	password	73	100000	F
15086	COWQQF	KTQGWFTBZF	9804502787 Dell Way	\N	HLVUUIO	\N	0	Chile	2	KTQGWFTBZF@dell.com	9804502787	3	5774730421602727	2011/03	user15086	password	43	20000	F
15087	XAZOGK	HXQECKGBPN	4293595044 Dell Way	\N	NLIIUXO	\N	0	Russia	2	HXQECKGBPN@dell.com	4293595044	1	4926752853672952	2011/06	user15087	password	61	100000	F
15088	QYWWIE	TYJWJPXYDL	4260591283 Dell Way	\N	JLTDIHX	\N	0	Japan	2	TYJWJPXYDL@dell.com	4260591283	2	3697168863844127	2011/12	user15088	password	35	20000	M
15089	EZLMEE	LNAUCYSGJC	5317524886 Dell Way	\N	RDGALDS	\N	0	Russia	2	LNAUCYSGJC@dell.com	5317524886	1	6151792175602168	2010/03	user15089	password	67	100000	F
15090	RKXVPI	IQCLPVRZXJ	1742947493 Dell Way	\N	CEJNHCI	\N	0	Russia	2	IQCLPVRZXJ@dell.com	1742947493	5	2738646322861314	2009/07	user15090	password	30	80000	F
15091	PQBEZK	VBVKXNKVWM	2911845854 Dell Way	\N	ZGAGIIB	\N	0	China	2	VBVKXNKVWM@dell.com	2911845854	2	7557929753325880	2011/05	user15091	password	52	20000	M
15092	CBECLA	DHLBUVWRIV	4399034893 Dell Way	\N	XICFQDQ	\N	0	South Africa	2	DHLBUVWRIV@dell.com	4399034893	2	6774975147098303	2011/10	user15092	password	65	80000	M
15093	SZAEAE	MLFHGBYPWW	1357290751 Dell Way	\N	XZBOCRK	\N	0	France	2	MLFHGBYPWW@dell.com	1357290751	1	3410304799210280	2012/09	user15093	password	22	80000	F
15094	BUQBZC	MEJTFIICEG	3268385511 Dell Way	\N	BGUEYFQ	\N	0	UK	2	MEJTFIICEG@dell.com	3268385511	5	8481224534101785	2012/12	user15094	password	63	40000	F
15095	LABKDN	ONHUVPXAWY	6771694868 Dell Way	\N	GQCEVTD	\N	0	Australia	2	ONHUVPXAWY@dell.com	6771694868	5	1395577960647642	2011/08	user15095	password	50	80000	F
15096	MQLPEA	CLUYBRYXQE	5170823392 Dell Way	\N	OSJKMMM	\N	0	Canada	2	CLUYBRYXQE@dell.com	5170823392	3	7394523314666004	2008/12	user15096	password	40	20000	F
15097	ZNADND	PIBRZZPQEE	5649986345 Dell Way	\N	JNOVAAX	\N	0	France	2	PIBRZZPQEE@dell.com	5649986345	4	5873224330134690	2010/12	user15097	password	64	100000	M
15098	EXBRAR	ACIACYQGCZ	3995577830 Dell Way	\N	UQUUQSH	\N	0	Canada	2	ACIACYQGCZ@dell.com	3995577830	5	6573083946015686	2009/06	user15098	password	55	20000	M
15099	KGHLXI	NFIQEYWGXQ	5881437019 Dell Way	\N	WRLNJSR	\N	0	Russia	2	NFIQEYWGXQ@dell.com	5881437019	2	9960882999002934	2012/10	user15099	password	31	80000	F
15100	LXQIFE	OOUSMRYJIV	3448985878 Dell Way	\N	BUILNZE	\N	0	Australia	2	OOUSMRYJIV@dell.com	3448985878	1	1364774202462285	2008/05	user15100	password	65	40000	M
15101	OXCUCQ	IXJVPIEXDG	9966646299 Dell Way	\N	RMREMVG	\N	0	Russia	2	IXJVPIEXDG@dell.com	9966646299	2	8303509583231063	2009/12	user15101	password	23	20000	F
15102	ZEHCVQ	ZELOMPMQWE	8584686312 Dell Way	\N	CNIPJOI	\N	0	China	2	ZELOMPMQWE@dell.com	8584686312	1	7369866337161512	2011/03	user15102	password	76	40000	F
15103	ZOHVEH	ZPWMEICBMF	3664351722 Dell Way	\N	OVUYKDI	\N	0	Chile	2	ZPWMEICBMF@dell.com	3664351722	1	1018882738891988	2010/11	user15103	password	36	80000	M
15104	UBQYIQ	NECSNFTZKI	6705762671 Dell Way	\N	VFHFIPL	\N	0	Japan	2	NECSNFTZKI@dell.com	6705762671	3	2457117239013314	2010/09	user15104	password	83	40000	M
15105	YYLHPZ	MSSZXMZHUU	9340466172 Dell Way	\N	NCAVRMM	\N	0	China	2	MSSZXMZHUU@dell.com	9340466172	4	8119456949643792	2011/07	user15105	password	24	20000	F
15106	BPUQPG	IHFFUFNOAA	1002528484 Dell Way	\N	QAWINJR	\N	0	France	2	IHFFUFNOAA@dell.com	1002528484	3	1673874253407120	2010/07	user15106	password	34	20000	M
15107	VVFKBO	SHUMMHBNIS	2317122390 Dell Way	\N	OFBBOSM	\N	0	Germany	2	SHUMMHBNIS@dell.com	2317122390	3	1989688623696565	2011/10	user15107	password	28	40000	M
15108	YMAAAT	HUFUCHHLZV	9213357536 Dell Way	\N	QAWFSJT	\N	0	South Africa	2	HUFUCHHLZV@dell.com	9213357536	5	6014012353960425	2011/01	user15108	password	78	40000	M
15109	IIZJBH	EHBGOIRNDI	2471360225 Dell Way	\N	OZNHIHD	\N	0	Chile	2	EHBGOIRNDI@dell.com	2471360225	4	9554921331349760	2008/07	user15109	password	36	20000	M
15110	OEFQLJ	XMQLUIZXQN	7012428206 Dell Way	\N	XEVGLZN	\N	0	Japan	2	XMQLUIZXQN@dell.com	7012428206	3	8257117195054890	2009/09	user15110	password	88	20000	F
15111	DHXOQU	AGGVPFSFTQ	8783646668 Dell Way	\N	KOXVNKM	\N	0	Canada	2	AGGVPFSFTQ@dell.com	8783646668	2	4529401739127934	2010/03	user15111	password	50	100000	F
15112	STYJOY	QUTFZMKTDU	4497000394 Dell Way	\N	HAQVLDA	\N	0	Chile	2	QUTFZMKTDU@dell.com	4497000394	2	8821443255525083	2011/11	user15112	password	70	20000	M
15113	MYYAWO	UQTUDENGZV	1420932505 Dell Way	\N	HQQSTQA	\N	0	Canada	2	UQTUDENGZV@dell.com	1420932505	5	7869360949844123	2012/08	user15113	password	73	60000	F
15114	SKCOYW	FSRIWEPVAX	5385962036 Dell Way	\N	MRPFHPI	\N	0	China	2	FSRIWEPVAX@dell.com	5385962036	1	3259730241261423	2008/11	user15114	password	70	20000	M
15115	DGDBDI	TURQZHMZEY	6204133879 Dell Way	\N	QTDYJMI	\N	0	South Africa	2	TURQZHMZEY@dell.com	6204133879	3	9517069306224586	2010/04	user15115	password	25	20000	F
15116	IDMMMF	GEWFLIFPGW	7279711144 Dell Way	\N	JKVTWDP	\N	0	France	2	GEWFLIFPGW@dell.com	7279711144	3	9038169318810106	2012/08	user15116	password	83	40000	M
15117	BVLNBS	RYYDGDSMAC	9769698187 Dell Way	\N	XVVTZLF	\N	0	Japan	2	RYYDGDSMAC@dell.com	9769698187	1	6827308225911111	2011/12	user15117	password	19	80000	F
15118	WBOYUG	WSJCWCPWEM	6028161794 Dell Way	\N	SAGRLLI	\N	0	France	2	WSJCWCPWEM@dell.com	6028161794	5	1393981719389557	2010/01	user15118	password	66	60000	M
15119	TEVNKS	GUUCWKZBXR	7120441141 Dell Way	\N	BEINQRY	\N	0	Canada	2	GUUCWKZBXR@dell.com	7120441141	5	7623647943604738	2011/08	user15119	password	42	60000	F
15120	MKXXCD	RXFNIEOFVQ	1539880814 Dell Way	\N	KEDAWCE	\N	0	Germany	2	RXFNIEOFVQ@dell.com	1539880814	5	3294510713778436	2011/04	user15120	password	79	20000	M
15121	GYQJCI	HHVPMKVHBF	3946581466 Dell Way	\N	MFFJHKY	\N	0	China	2	HHVPMKVHBF@dell.com	3946581466	1	1404984182678163	2010/01	user15121	password	26	40000	F
15122	BZQDHY	LCNXNJFPPS	2632909729 Dell Way	\N	UUBBFZK	\N	0	Germany	2	LCNXNJFPPS@dell.com	2632909729	3	2061763875652104	2009/07	user15122	password	50	60000	M
15123	KDUSBG	VPDIYIXNBS	6929755790 Dell Way	\N	IDUODFC	\N	0	Chile	2	VPDIYIXNBS@dell.com	6929755790	2	5525351087097079	2009/08	user15123	password	90	100000	F
15124	DRTEYO	UBXTKVHLNQ	5149391075 Dell Way	\N	OHERMGZ	\N	0	Canada	2	UBXTKVHLNQ@dell.com	5149391075	3	4383077468257398	2008/06	user15124	password	37	20000	M
15125	YYUWNP	YKIIFPUTGJ	5628898587 Dell Way	\N	AKBNRAQ	\N	0	Canada	2	YKIIFPUTGJ@dell.com	5628898587	1	3101219219621271	2012/04	user15125	password	47	60000	F
15126	IJCVYB	GHKMXEFDOG	4491932146 Dell Way	\N	NPTFQJI	\N	0	Canada	2	GHKMXEFDOG@dell.com	4491932146	3	2121584630105644	2011/12	user15126	password	70	100000	F
15127	CADBBK	ILWGPCJEIX	9702793966 Dell Way	\N	TBCJKKN	\N	0	South Africa	2	ILWGPCJEIX@dell.com	9702793966	4	5274455319624394	2012/05	user15127	password	45	40000	F
15128	JJMLUV	WRBMTLQBIJ	9000999886 Dell Way	\N	CLTNWGI	\N	0	South Africa	2	WRBMTLQBIJ@dell.com	9000999886	4	7743954443372787	2009/03	user15128	password	89	80000	M
15129	JEZDAV	UCHONYPWIR	3957464877 Dell Way	\N	IBFEINZ	\N	0	Chile	2	UCHONYPWIR@dell.com	3957464877	4	5047773852013052	2010/09	user15129	password	27	20000	F
15130	HAGHWA	KEOXCEULWC	9877949192 Dell Way	\N	MBGVPGA	\N	0	UK	2	KEOXCEULWC@dell.com	9877949192	3	4806994186714292	2011/08	user15130	password	52	80000	M
15131	NAFJBP	NQNQUHBRKO	9018504296 Dell Way	\N	SRJIXKG	\N	0	UK	2	NQNQUHBRKO@dell.com	9018504296	4	6450824651401491	2010/02	user15131	password	46	60000	M
15132	KPZMFN	CSEXAFOKUH	5314751495 Dell Way	\N	CDPAOVX	\N	0	France	2	CSEXAFOKUH@dell.com	5314751495	3	9532399279065432	2011/11	user15132	password	43	40000	F
15133	ZGUEUW	XYTXEIIYPK	8495148539 Dell Way	\N	CEKQZIC	\N	0	France	2	XYTXEIIYPK@dell.com	8495148539	1	1662807236891240	2011/05	user15133	password	41	20000	F
15134	OVNIRK	HLILTRJICM	3252072597 Dell Way	\N	MNCMVFY	\N	0	Japan	2	HLILTRJICM@dell.com	3252072597	1	4591486877296120	2011/04	user15134	password	50	20000	M
15135	GNFYYN	KHYDYIMAUZ	4455135072 Dell Way	\N	OWLJCJB	\N	0	China	2	KHYDYIMAUZ@dell.com	4455135072	3	9851253266911956	2011/11	user15135	password	90	80000	F
15136	NVCMIM	THQSPCTJCH	2221585370 Dell Way	\N	GNRIXSR	\N	0	Chile	2	THQSPCTJCH@dell.com	2221585370	4	9969399494584652	2008/08	user15136	password	61	20000	F
15137	LGQUTJ	BJBQMVZPCF	8677653198 Dell Way	\N	CTOALFH	\N	0	Germany	2	BJBQMVZPCF@dell.com	8677653198	2	6360897596925498	2010/11	user15137	password	73	80000	F
15138	AGCUQE	DSUQNUFPAI	9084091314 Dell Way	\N	JOIUTQJ	\N	0	Japan	2	DSUQNUFPAI@dell.com	9084091314	5	1887182247824967	2011/09	user15138	password	71	20000	M
15139	ZFNQJR	IDIWYOLYWU	9420971922 Dell Way	\N	MFPGVZW	\N	0	Russia	2	IDIWYOLYWU@dell.com	9420971922	5	5549339452758432	2011/09	user15139	password	62	60000	M
15140	VYHEPQ	IYMGMYFJTR	7824107444 Dell Way	\N	OIYJIUC	\N	0	Chile	2	IYMGMYFJTR@dell.com	7824107444	4	9212593190837652	2010/03	user15140	password	41	20000	F
15141	GLFWCO	UOVGMAPGSE	3315140840 Dell Way	\N	PROXLQD	\N	0	Chile	2	UOVGMAPGSE@dell.com	3315140840	1	6997059870045633	2010/05	user15141	password	76	60000	M
15142	GTMIIG	XDNKEDQXHF	3957360564 Dell Way	\N	OVDAMGF	\N	0	Russia	2	XDNKEDQXHF@dell.com	3957360564	5	2822347450535744	2011/09	user15142	password	71	40000	M
15143	MVHUCE	YQODTEAAKP	7645131255 Dell Way	\N	VNPHUVA	\N	0	Canada	2	YQODTEAAKP@dell.com	7645131255	2	8471674252301455	2010/12	user15143	password	31	40000	F
15144	ARGDVE	TKINPJNZYJ	9431240172 Dell Way	\N	NORHKSK	\N	0	Canada	2	TKINPJNZYJ@dell.com	9431240172	2	6164066777098924	2012/06	user15144	password	88	40000	F
15145	QOPMTJ	WBWLKKLJUZ	9464979407 Dell Way	\N	XLHIERL	\N	0	Australia	2	WBWLKKLJUZ@dell.com	9464979407	1	9943628495093436	2009/12	user15145	password	41	100000	M
15146	XKCQUY	SQKDBWMVVK	2692666923 Dell Way	\N	HCSLUEO	\N	0	Russia	2	SQKDBWMVVK@dell.com	2692666923	3	1987900985870510	2008/11	user15146	password	86	80000	M
15147	JWKDVD	UGGWCTRYEZ	5542479443 Dell Way	\N	BXKVBZO	\N	0	Chile	2	UGGWCTRYEZ@dell.com	5542479443	4	4802339908666909	2009/08	user15147	password	33	20000	M
15148	BODXRX	DYUGSLEWKF	3724567184 Dell Way	\N	UVBVUQC	\N	0	Chile	2	DYUGSLEWKF@dell.com	3724567184	3	6997345734853298	2012/09	user15148	password	76	100000	M
15149	JASAYV	ZSBREGOPLJ	8154227900 Dell Way	\N	KMEFCHM	\N	0	France	2	ZSBREGOPLJ@dell.com	8154227900	1	4026133975014091	2010/12	user15149	password	36	40000	F
15150	HAJGWI	ZXADDPTPYE	1266588785 Dell Way	\N	CDJFKWP	\N	0	Chile	2	ZXADDPTPYE@dell.com	1266588785	5	7483645807020367	2012/03	user15150	password	20	40000	F
15151	BRSXAS	VAVZQPOOTQ	4443248741 Dell Way	\N	SDVCZLH	\N	0	Australia	2	VAVZQPOOTQ@dell.com	4443248741	1	1087441141251474	2010/01	user15151	password	41	20000	F
15152	ATAALV	BHURXJFQZX	4197608858 Dell Way	\N	TVATHIT	\N	0	Japan	2	BHURXJFQZX@dell.com	4197608858	4	3028992129489779	2010/02	user15152	password	37	60000	F
15153	ANCMJD	UDURMAHMYB	3656775366 Dell Way	\N	IZUPING	\N	0	Japan	2	UDURMAHMYB@dell.com	3656775366	3	1729949973523616	2009/09	user15153	password	62	60000	M
15154	DOGNSA	QNRDOYQMAY	3211462997 Dell Way	\N	MUNUIUL	\N	0	Japan	2	QNRDOYQMAY@dell.com	3211462997	3	1024174544494599	2012/02	user15154	password	52	80000	F
15155	BZUTZL	GQPVPFIPEU	6009610450 Dell Way	\N	KSOSMAI	\N	0	Russia	2	GQPVPFIPEU@dell.com	6009610450	2	7275427379645408	2011/10	user15155	password	50	100000	M
15156	KUPKGW	AVRQBZFFUP	9830134931 Dell Way	\N	XJIJJQC	\N	0	UK	2	AVRQBZFFUP@dell.com	9830134931	4	6695550646632910	2011/03	user15156	password	63	80000	M
15157	KGAQDB	MUSNUYSOOQ	8894011451 Dell Way	\N	YWAHNCG	\N	0	France	2	MUSNUYSOOQ@dell.com	8894011451	5	3504193698521704	2008/06	user15157	password	85	80000	M
15158	EUNHWA	CONWMGLAWJ	8193128509 Dell Way	\N	XWRKYYX	\N	0	South Africa	2	CONWMGLAWJ@dell.com	8193128509	1	9469461227767170	2009/02	user15158	password	68	20000	F
15159	MSNITQ	WGNJMYKJIH	7642484770 Dell Way	\N	FAREYOA	\N	0	Russia	2	WGNJMYKJIH@dell.com	7642484770	5	1399994444102048	2012/08	user15159	password	35	20000	F
15160	ZPLSFI	YSSLRCUAJA	2860950816 Dell Way	\N	BBFZQGT	\N	0	China	2	YSSLRCUAJA@dell.com	2860950816	4	2783161797560751	2012/01	user15160	password	37	100000	M
15161	WLRCTQ	VLBMOWNYWO	1856411853 Dell Way	\N	ZCOQIHA	\N	0	Germany	2	VLBMOWNYWO@dell.com	1856411853	2	4600981419440359	2008/06	user15161	password	45	20000	F
15162	VULOLG	ANTOJHMGVM	3944851005 Dell Way	\N	IKCRSDF	\N	0	Russia	2	ANTOJHMGVM@dell.com	3944851005	4	9205126616638156	2012/12	user15162	password	19	20000	M
15163	VPJGWK	UQYDXLKTXT	3200238769 Dell Way	\N	DAKVEQP	\N	0	France	2	UQYDXLKTXT@dell.com	3200238769	3	3560148518066853	2009/07	user15163	password	49	20000	F
15164	ALQXVK	NTOKFYDDRG	2908401847 Dell Way	\N	DCCHSSU	\N	0	UK	2	NTOKFYDDRG@dell.com	2908401847	1	2809446163475513	2011/07	user15164	password	36	20000	M
15165	RUKMEY	GTILRMOJTS	8889165927 Dell Way	\N	LVADNUC	\N	0	Russia	2	GTILRMOJTS@dell.com	8889165927	2	5418473267927766	2009/07	user15165	password	63	100000	F
15166	KITPHZ	IPLACZJVSU	4241916441 Dell Way	\N	RSYENBX	\N	0	France	2	IPLACZJVSU@dell.com	4241916441	3	8128084191121162	2012/01	user15166	password	69	20000	F
15167	BXAIWI	YIIAISVAMM	9852672100 Dell Way	\N	TLRHMPR	\N	0	South Africa	2	YIIAISVAMM@dell.com	9852672100	3	7877768459729851	2008/03	user15167	password	85	60000	F
15168	VLOSUM	ACNIUIJHVC	5913629923 Dell Way	\N	SNJFCBB	\N	0	Australia	2	ACNIUIJHVC@dell.com	5913629923	5	1789067067205906	2011/09	user15168	password	55	100000	M
15169	ZOHTAH	WNQRWZYSBR	7646066299 Dell Way	\N	FLWINYK	\N	0	Australia	2	WNQRWZYSBR@dell.com	7646066299	3	8110138691496105	2010/01	user15169	password	74	20000	M
15170	IISIPO	WFFTFEMGWS	9308642630 Dell Way	\N	STAFRLG	\N	0	France	2	WFFTFEMGWS@dell.com	9308642630	1	8979357301257552	2012/10	user15170	password	85	100000	F
15171	GQMVFI	BKCGPONMGF	7809627438 Dell Way	\N	FHLWSSH	\N	0	Japan	2	BKCGPONMGF@dell.com	7809627438	1	6239260038360954	2010/02	user15171	password	53	80000	F
15172	DEEING	TQNIEBULHA	4147461579 Dell Way	\N	TSXMKEC	\N	0	Canada	2	TQNIEBULHA@dell.com	4147461579	4	7732297801878304	2010/03	user15172	password	51	80000	F
15173	QZQEGJ	UTRZUMKBME	5019282987 Dell Way	\N	UJQEOTJ	\N	0	UK	2	UTRZUMKBME@dell.com	5019282987	1	4252621644642204	2011/07	user15173	password	29	100000	F
15174	DOJJXD	DPCYCNZPSU	4939824104 Dell Way	\N	ZIZNCIL	\N	0	Germany	2	DPCYCNZPSU@dell.com	4939824104	5	2471177512779832	2008/12	user15174	password	25	40000	F
15175	ROMPSP	EVNHJNWBHV	6545103937 Dell Way	\N	JGJMPVZ	\N	0	Australia	2	EVNHJNWBHV@dell.com	6545103937	1	1345743108075112	2010/04	user15175	password	35	80000	M
15176	VDNNTS	JHZSUWTCSD	7832843529 Dell Way	\N	JBPZXPZ	\N	0	Germany	2	JHZSUWTCSD@dell.com	7832843529	1	1707732892595231	2008/04	user15176	password	72	100000	F
15177	XMQQEZ	XESSBMVTQE	2552189005 Dell Way	\N	VFDSVDF	\N	0	Germany	2	XESSBMVTQE@dell.com	2552189005	2	6546130318660290	2010/01	user15177	password	59	60000	M
15178	BEOGEM	KWEMIZFYEA	2995805501 Dell Way	\N	EISALYP	\N	0	Japan	2	KWEMIZFYEA@dell.com	2995805501	2	1698890315834432	2009/10	user15178	password	63	20000	M
15179	VTCZGN	VLZELEDPFH	2355333668 Dell Way	\N	XYIJWYZ	\N	0	Australia	2	VLZELEDPFH@dell.com	2355333668	1	4134034880902618	2012/09	user15179	password	57	80000	M
15180	HXMNKI	ZJNKOQATYX	4255174960 Dell Way	\N	RGHOEHQ	\N	0	China	2	ZJNKOQATYX@dell.com	4255174960	5	3583093194290996	2008/07	user15180	password	24	60000	M
15181	ZBJJKI	TXTHOTBNRT	9479636221 Dell Way	\N	UYHYGYH	\N	0	Japan	2	TXTHOTBNRT@dell.com	9479636221	3	6990918026305736	2010/09	user15181	password	35	40000	M
15182	IRASAT	QTAFMBSDVM	3910318276 Dell Way	\N	CCLIBTX	\N	0	UK	2	QTAFMBSDVM@dell.com	3910318276	3	5279776214621961	2012/10	user15182	password	75	80000	F
15183	LQWMJN	FKSRMLUHXW	7399325977 Dell Way	\N	KJFLCDL	\N	0	France	2	FKSRMLUHXW@dell.com	7399325977	5	4617071513552219	2010/09	user15183	password	20	80000	F
15184	ROQABV	KTNWEIECFO	4297135560 Dell Way	\N	LKZNNLY	\N	0	Chile	2	KTNWEIECFO@dell.com	4297135560	2	7965783388353885	2008/05	user15184	password	51	40000	F
15185	AWBBRM	VFJANNDSBO	4601848602 Dell Way	\N	CBCQMBW	\N	0	South Africa	2	VFJANNDSBO@dell.com	4601848602	4	9407632512971760	2011/02	user15185	password	30	100000	F
15186	AWDSIZ	XRAKEDDGRF	3819514211 Dell Way	\N	HUVUWRR	\N	0	Chile	2	XRAKEDDGRF@dell.com	3819514211	3	1238038724288344	2009/10	user15186	password	79	60000	M
15187	SQNBQK	SQVXTYELEM	5634047293 Dell Way	\N	GAGCRXI	\N	0	Australia	2	SQVXTYELEM@dell.com	5634047293	2	4628418556880206	2009/03	user15187	password	83	20000	M
15188	NOYEZR	UVPNUTZYGF	9821730695 Dell Way	\N	YMHQKQQ	\N	0	UK	2	UVPNUTZYGF@dell.com	9821730695	1	2894169070292264	2008/12	user15188	password	37	20000	F
15189	VAQVSK	QIYLCXJICI	6972962409 Dell Way	\N	VKZGAPE	\N	0	UK	2	QIYLCXJICI@dell.com	6972962409	2	2605357185471803	2011/08	user15189	password	37	20000	F
15190	HSIADZ	IBKKZTSCCN	3696692172 Dell Way	\N	MBTNRXN	\N	0	China	2	IBKKZTSCCN@dell.com	3696692172	4	9349588965065778	2012/12	user15190	password	18	60000	F
15191	STGWSO	YDZXWRAZFM	2818033498 Dell Way	\N	AYARWNZ	\N	0	Canada	2	YDZXWRAZFM@dell.com	2818033498	5	2122386598028242	2008/12	user15191	password	59	40000	M
15192	IQNBFL	EEJBWJABVA	6296048375 Dell Way	\N	AWSXJRB	\N	0	Germany	2	EEJBWJABVA@dell.com	6296048375	1	7449219109490515	2010/10	user15192	password	26	20000	F
15193	TRDZDI	EMKAVKCRLC	3190210116 Dell Way	\N	NDZWUBL	\N	0	China	2	EMKAVKCRLC@dell.com	3190210116	1	9162759201601148	2012/04	user15193	password	23	20000	F
15194	TFAWOF	IYFDIIVULI	8303068980 Dell Way	\N	XLFSMQC	\N	0	Russia	2	IYFDIIVULI@dell.com	8303068980	1	7550640883855522	2008/02	user15194	password	77	20000	M
15195	ADSPIA	NOEWXAQIIO	4706775202 Dell Way	\N	TOHGFKZ	\N	0	Australia	2	NOEWXAQIIO@dell.com	4706775202	4	1870738378725946	2010/07	user15195	password	33	40000	M
15196	JBDSBR	HGNEGEMPTG	2642597625 Dell Way	\N	DANIKMJ	\N	0	South Africa	2	HGNEGEMPTG@dell.com	2642597625	3	3940253179520369	2011/08	user15196	password	66	40000	F
15197	SJTUBA	AOEHTRWMYA	2275557299 Dell Way	\N	NLIYXST	\N	0	Canada	2	AOEHTRWMYA@dell.com	2275557299	1	8206840637139977	2012/09	user15197	password	21	100000	F
15198	LOFMPG	BTOULKHKKV	6110782054 Dell Way	\N	VTTTLMW	\N	0	Japan	2	BTOULKHKKV@dell.com	6110782054	4	4670130842365325	2009/09	user15198	password	35	80000	F
15199	VZPKGR	EUMQFTAPOW	2173679910 Dell Way	\N	JIPVUML	\N	0	China	2	EUMQFTAPOW@dell.com	2173679910	5	7176009571645410	2012/02	user15199	password	50	100000	M
15200	LPIRGM	MSCRMDHBZR	8034187798 Dell Way	\N	JPMEBYO	\N	0	Canada	2	MSCRMDHBZR@dell.com	8034187798	2	1222389597911387	2012/09	user15200	password	18	80000	F
15201	PCVWPH	OSYBVGCVXM	5144237164 Dell Way	\N	KKRLIFQ	\N	0	Canada	2	OSYBVGCVXM@dell.com	5144237164	4	9922991143073888	2008/09	user15201	password	74	40000	F
15202	WCCLJR	EISZPVVMIF	9690536715 Dell Way	\N	WZRFFHI	\N	0	Japan	2	EISZPVVMIF@dell.com	9690536715	2	8297801498789341	2011/02	user15202	password	24	100000	M
15203	EALORP	XKPMGKZOPW	7772266953 Dell Way	\N	NHCTPKK	\N	0	Germany	2	XKPMGKZOPW@dell.com	7772266953	2	2578107215929776	2012/04	user15203	password	23	100000	F
15204	BHBTWZ	EMLKXLYNHM	8365433298 Dell Way	\N	UJFJUPX	\N	0	Germany	2	EMLKXLYNHM@dell.com	8365433298	1	4674752414226532	2008/02	user15204	password	35	60000	F
15205	NRZKQD	WCNUNMHVYB	4340127251 Dell Way	\N	FEKZUHO	\N	0	Germany	2	WCNUNMHVYB@dell.com	4340127251	5	7388895528856666	2010/03	user15205	password	40	80000	M
15206	ZRDPVA	RIUFUBATCF	7187894942 Dell Way	\N	XMFRUTG	\N	0	Canada	2	RIUFUBATCF@dell.com	7187894942	5	7129374569281936	2012/04	user15206	password	47	80000	F
15207	CSVXSN	GNSAOSTQYQ	6009536333 Dell Way	\N	DDIYWPC	\N	0	Germany	2	GNSAOSTQYQ@dell.com	6009536333	4	4885736915748567	2012/03	user15207	password	20	20000	F
15208	TYFMLL	ZDLNWFEUWI	2518586210 Dell Way	\N	XEGUTJI	\N	0	China	2	ZDLNWFEUWI@dell.com	2518586210	4	2281998775433749	2009/10	user15208	password	35	80000	M
15209	EWAPHA	TTOQYTLUBJ	3150279173 Dell Way	\N	ZIDSSMA	\N	0	South Africa	2	TTOQYTLUBJ@dell.com	3150279173	1	3148890665266663	2008/05	user15209	password	83	60000	M
15210	TQEBQY	VFOUYZPZJO	4976962972 Dell Way	\N	IMHAZHX	\N	0	Chile	2	VFOUYZPZJO@dell.com	4976962972	1	3207558832596987	2012/01	user15210	password	78	40000	M
15211	LOWCMR	HBMFBBFKQN	5865121041 Dell Way	\N	XXNWEKC	\N	0	Japan	2	HBMFBBFKQN@dell.com	5865121041	2	5063807665836066	2010/02	user15211	password	79	40000	M
15212	KFSWXZ	YKFZLKKBYH	6114764762 Dell Way	\N	YLEDWGT	\N	0	France	2	YKFZLKKBYH@dell.com	6114764762	2	9817923664115370	2011/01	user15212	password	42	40000	F
15213	OBIMBG	WGGIRQKPYJ	5023167476 Dell Way	\N	BCMYIGI	\N	0	South Africa	2	WGGIRQKPYJ@dell.com	5023167476	2	6612150156870485	2010/08	user15213	password	88	100000	F
15214	AGSBNP	IUXZKHPIQR	3282237206 Dell Way	\N	KDPTJYQ	\N	0	South Africa	2	IUXZKHPIQR@dell.com	3282237206	2	3754973883740604	2012/03	user15214	password	35	20000	F
15215	NWIBLQ	VJQGQGOHXZ	6788424308 Dell Way	\N	KMTUKJP	\N	0	Japan	2	VJQGQGOHXZ@dell.com	6788424308	5	6223257991950960	2012/02	user15215	password	71	20000	M
15216	PLSBBN	KSTBYIIVIT	1117287325 Dell Way	\N	HBNSKDJ	\N	0	Australia	2	KSTBYIIVIT@dell.com	1117287325	5	9451917300932110	2008/09	user15216	password	22	100000	F
15217	MNIOAS	GUUFDDALWI	4017796143 Dell Way	\N	MKAXNKY	\N	0	Germany	2	GUUFDDALWI@dell.com	4017796143	5	7255853506736458	2008/12	user15217	password	54	40000	F
15218	AQABIH	WDMZGMKDUW	6645883520 Dell Way	\N	NVTBFSP	\N	0	Germany	2	WDMZGMKDUW@dell.com	6645883520	2	5963356577791274	2010/10	user15218	password	79	20000	M
15219	LBWUIS	YVREHCHCYV	8324844204 Dell Way	\N	XSXDLNR	\N	0	Australia	2	YVREHCHCYV@dell.com	8324844204	2	7046817328315229	2011/01	user15219	password	70	60000	M
15220	UIIDBG	YSKGVSJUOH	3378553902 Dell Way	\N	NMKZZBB	\N	0	Russia	2	YSKGVSJUOH@dell.com	3378553902	4	4731963006313890	2009/06	user15220	password	80	100000	F
15221	EDIFJH	YUNTNXOCEB	7919248960 Dell Way	\N	OOANQBI	\N	0	South Africa	2	YUNTNXOCEB@dell.com	7919248960	4	2808800115715712	2009/08	user15221	password	20	60000	M
15222	ETZOAY	JOSWLGYQHN	2009034559 Dell Way	\N	EHBVIJS	\N	0	Canada	2	JOSWLGYQHN@dell.com	2009034559	5	3785245520994067	2011/12	user15222	password	70	60000	F
15223	MMQNKZ	CCWNIUEQIJ	7771905098 Dell Way	\N	XJEGSWJ	\N	0	South Africa	2	CCWNIUEQIJ@dell.com	7771905098	4	5923406268935651	2011/05	user15223	password	20	80000	M
15224	NKJYKL	AGZJBEAJNX	2755163604 Dell Way	\N	SRELNNH	\N	0	Chile	2	AGZJBEAJNX@dell.com	2755163604	5	9580066487658770	2010/11	user15224	password	70	60000	F
15225	DVHNHI	THSVLSEYQX	4923806807 Dell Way	\N	QUIDIPL	\N	0	Germany	2	THSVLSEYQX@dell.com	4923806807	2	1891591669525951	2009/02	user15225	password	58	80000	F
15226	KYTSHN	ZZILRMKHKA	9895321382 Dell Way	\N	CSEKIPY	\N	0	Russia	2	ZZILRMKHKA@dell.com	9895321382	1	1640546850860118	2008/07	user15226	password	71	40000	M
15227	RBRZOR	YXCQJMYUNA	4496618757 Dell Way	\N	NSLVHJQ	\N	0	Chile	2	YXCQJMYUNA@dell.com	4496618757	4	4402173501439393	2012/06	user15227	password	68	100000	F
15228	TPCIGA	FJQPWPJJQW	1381584716 Dell Way	\N	BBSJLJQ	\N	0	South Africa	2	FJQPWPJJQW@dell.com	1381584716	1	8054094680119307	2010/09	user15228	password	70	60000	F
15229	IRVPRA	YIQUYAEOXG	3294761961 Dell Way	\N	PPPAYGW	\N	0	UK	2	YIQUYAEOXG@dell.com	3294761961	4	5229106931015849	2012/05	user15229	password	21	60000	M
15230	SGHKHG	TYBRYGFVMV	4111057791 Dell Way	\N	LBWKHSK	\N	0	Germany	2	TYBRYGFVMV@dell.com	4111057791	5	5626486694905907	2011/11	user15230	password	88	60000	M
15231	GSANYU	LALKGRFSMQ	3441659663 Dell Way	\N	TJAABKO	\N	0	France	2	LALKGRFSMQ@dell.com	3441659663	1	1983713391236961	2008/01	user15231	password	55	100000	F
15232	FVVDQH	EBRKSXCFOV	5911073513 Dell Way	\N	OOWQZLA	\N	0	Chile	2	EBRKSXCFOV@dell.com	5911073513	1	4919501794967801	2011/08	user15232	password	35	100000	M
15233	CSASAE	USONPQSDMH	1647084949 Dell Way	\N	SJXRVYY	\N	0	China	2	USONPQSDMH@dell.com	1647084949	2	9854594632983208	2011/08	user15233	password	82	60000	M
15234	POKQTE	IHRXYKBLST	7755930854 Dell Way	\N	VPLROJA	\N	0	Japan	2	IHRXYKBLST@dell.com	7755930854	1	4059018930420280	2009/11	user15234	password	84	20000	M
15235	MMDFRM	NJKMULXMFS	4876302249 Dell Way	\N	CQJQAKH	\N	0	Russia	2	NJKMULXMFS@dell.com	4876302249	4	2221703567542135	2009/07	user15235	password	33	100000	F
15236	SZFJLT	TVFNHCAMVC	6696338516 Dell Way	\N	CFTDQAX	\N	0	Australia	2	TVFNHCAMVC@dell.com	6696338516	1	4529106499161571	2008/03	user15236	password	35	20000	M
15237	FJIRDB	MIPULPGHSJ	4651571594 Dell Way	\N	MLMDMJE	\N	0	Canada	2	MIPULPGHSJ@dell.com	4651571594	3	3331028046552092	2011/10	user15237	password	48	60000	F
15238	UXRXZE	GOYRDFYVOL	3927468933 Dell Way	\N	HAOTKTW	\N	0	South Africa	2	GOYRDFYVOL@dell.com	3927468933	1	5197491008322686	2008/07	user15238	password	21	20000	F
15239	YWGXAM	MZEPFDLTPS	5245038464 Dell Way	\N	UEMFXJA	\N	0	Chile	2	MZEPFDLTPS@dell.com	5245038464	3	4319481559097767	2008/07	user15239	password	56	40000	F
15240	JPKKCW	KHMPKXJAQD	8653255418 Dell Way	\N	EDIBMJI	\N	0	UK	2	KHMPKXJAQD@dell.com	8653255418	4	9570874901022764	2009/03	user15240	password	39	100000	M
15241	XHAZEK	HRASPJSGMW	9515405846 Dell Way	\N	JVYVFGT	\N	0	Australia	2	HRASPJSGMW@dell.com	9515405846	4	4981486438307911	2008/01	user15241	password	42	80000	M
15242	QTXVEF	NEXCNPIAMR	9965480954 Dell Way	\N	WLNBSHC	\N	0	Japan	2	NEXCNPIAMR@dell.com	9965480954	3	8241853489540518	2008/11	user15242	password	57	100000	M
15243	HVJLBW	PYYDOHEAYA	7603973441 Dell Way	\N	LMBETEV	\N	0	Russia	2	PYYDOHEAYA@dell.com	7603973441	4	7827379437629134	2011/02	user15243	password	68	20000	F
15244	NMXOJN	NHQBPUBOVN	2096374761 Dell Way	\N	AXSTBNN	\N	0	South Africa	2	NHQBPUBOVN@dell.com	2096374761	2	4818392531480640	2009/12	user15244	password	59	80000	F
15245	BQBKEO	SVQHPSVLFV	4291195674 Dell Way	\N	IXPKLCF	\N	0	Germany	2	SVQHPSVLFV@dell.com	4291195674	4	8502012542448939	2009/03	user15245	password	60	100000	F
15246	FWRKLK	FBRVTNGZJO	8045544091 Dell Way	\N	XYYIBEW	\N	0	France	2	FBRVTNGZJO@dell.com	8045544091	4	7697602003347129	2012/04	user15246	password	57	40000	M
15247	KXXWHC	XZXRMDRVSO	5320689197 Dell Way	\N	URXWVTH	\N	0	Japan	2	XZXRMDRVSO@dell.com	5320689197	1	6278716963250191	2011/07	user15247	password	77	40000	M
15248	SEVZHT	ZELLICHBQB	3044389136 Dell Way	\N	SOXOIFD	\N	0	Russia	2	ZELLICHBQB@dell.com	3044389136	4	6001085975673050	2011/07	user15248	password	78	80000	F
15249	AQHHJG	MVRUXYVOAO	9784132989 Dell Way	\N	CYCKDGE	\N	0	China	2	MVRUXYVOAO@dell.com	9784132989	4	2583695309236645	2010/07	user15249	password	88	100000	M
15250	PBWZHI	UZDRYYFZNH	6444512554 Dell Way	\N	XPSBVWL	\N	0	Russia	2	UZDRYYFZNH@dell.com	6444512554	4	3963864028453827	2008/07	user15250	password	27	80000	F
15251	FQDNYX	MCPLBVKOCH	4676580591 Dell Way	\N	DUJYRUT	\N	0	Chile	2	MCPLBVKOCH@dell.com	4676580591	1	5111522299237550	2012/03	user15251	password	33	20000	F
15252	VHXUEK	WUVYPFMSNP	4488179958 Dell Way	\N	NXOERHM	\N	0	Australia	2	WUVYPFMSNP@dell.com	4488179958	5	1654009700287133	2010/02	user15252	password	33	20000	M
15253	MYURIR	MEPBJBTXRG	8583032994 Dell Way	\N	UFLMNXO	\N	0	UK	2	MEPBJBTXRG@dell.com	8583032994	4	5546015889849514	2012/11	user15253	password	55	100000	F
15254	LTATKM	YZOIAHFROA	7229068280 Dell Way	\N	XAMKYBI	\N	0	Russia	2	YZOIAHFROA@dell.com	7229068280	5	7733963189646602	2010/05	user15254	password	69	100000	M
15255	LYOVKM	VZUWGAOVAL	1253765060 Dell Way	\N	VNWTPFN	\N	0	Chile	2	VZUWGAOVAL@dell.com	1253765060	2	8385653001256288	2009/12	user15255	password	70	20000	F
15256	QSGBFB	AAYHAMDBXY	5616670124 Dell Way	\N	PUSEZGL	\N	0	UK	2	AAYHAMDBXY@dell.com	5616670124	2	4317306459415704	2010/12	user15256	password	56	100000	M
15257	GESMGT	MEBNQEOODE	1607350742 Dell Way	\N	IWIHCUG	\N	0	Japan	2	MEBNQEOODE@dell.com	1607350742	4	1847183219157159	2008/03	user15257	password	18	80000	F
15258	EKXLDJ	PEWGILUMPC	3492372658 Dell Way	\N	IYJKTQZ	\N	0	South Africa	2	PEWGILUMPC@dell.com	3492372658	1	8803312272764743	2010/02	user15258	password	58	100000	F
15259	YTSBCI	GZPOKJAAMI	8493108601 Dell Way	\N	ZVTSMTN	\N	0	Russia	2	GZPOKJAAMI@dell.com	8493108601	2	2856715642381459	2012/12	user15259	password	23	40000	M
15260	VYYYHF	YWTIFUJSDI	9348855058 Dell Way	\N	OWAAQOU	\N	0	France	2	YWTIFUJSDI@dell.com	9348855058	5	4459306615404785	2012/01	user15260	password	62	80000	M
15261	OSVVXU	SRCYMLQPUE	9639741447 Dell Way	\N	MUECIZO	\N	0	Chile	2	SRCYMLQPUE@dell.com	9639741447	5	2238704787101596	2008/07	user15261	password	83	100000	F
15262	PTYNNQ	EQORCEGWJT	3986013635 Dell Way	\N	ROWANKH	\N	0	France	2	EQORCEGWJT@dell.com	3986013635	3	5466452999971807	2012/04	user15262	password	48	100000	M
15263	EXLSOQ	JCHMHOJQHA	7841524716 Dell Way	\N	EDBSOIE	\N	0	South Africa	2	JCHMHOJQHA@dell.com	7841524716	4	7747111830860377	2008/02	user15263	password	70	20000	F
15264	QLZEBJ	HJVPXEFFFK	9645381621 Dell Way	\N	IGDXPHT	\N	0	China	2	HJVPXEFFFK@dell.com	9645381621	3	4856559200678021	2008/03	user15264	password	49	40000	M
15265	WIBYRI	HNXFSDKXOT	9203940107 Dell Way	\N	ERQTYKC	\N	0	UK	2	HNXFSDKXOT@dell.com	9203940107	3	9644666003994644	2008/12	user15265	password	38	20000	M
15266	PBUHJC	UGHMKRKYLO	9174335749 Dell Way	\N	PBHOLJL	\N	0	China	2	UGHMKRKYLO@dell.com	9174335749	3	5644133262336255	2012/09	user15266	password	56	80000	F
15267	PMPYOJ	FVWPNGOYUD	5956523067 Dell Way	\N	ACRMMDV	\N	0	China	2	FVWPNGOYUD@dell.com	5956523067	2	3121588275302201	2009/11	user15267	password	86	60000	F
15268	KDKZNQ	UJGIPUGKXG	9146352615 Dell Way	\N	MPSYSOH	\N	0	Chile	2	UJGIPUGKXG@dell.com	9146352615	3	5776818839833141	2011/06	user15268	password	23	40000	M
15269	FQWSHQ	BNZRHFBFMO	3976212545 Dell Way	\N	VFMOUUV	\N	0	Japan	2	BNZRHFBFMO@dell.com	3976212545	2	5198858281131834	2012/06	user15269	password	69	80000	M
15270	JOJQEK	DDCLJEQWSL	2392947856 Dell Way	\N	CEZWZUO	\N	0	Chile	2	DDCLJEQWSL@dell.com	2392947856	1	1959317652508616	2010/09	user15270	password	76	40000	F
15271	IOSNZV	RBGBGXXYIA	5239732334 Dell Way	\N	DIXCDLK	\N	0	Chile	2	RBGBGXXYIA@dell.com	5239732334	3	8808411332312972	2009/04	user15271	password	24	40000	M
15272	RZDQUV	SBWYYUWHUA	9695385147 Dell Way	\N	QRCTDMA	\N	0	Germany	2	SBWYYUWHUA@dell.com	9695385147	5	8192974023055286	2009/12	user15272	password	23	100000	M
15273	BAHWWA	XSYWNVEHVU	4965830828 Dell Way	\N	ZYNCKOS	\N	0	China	2	XSYWNVEHVU@dell.com	4965830828	3	6589584765955806	2010/08	user15273	password	54	20000	M
15274	NJMKJK	CIHPDLXZFX	3087890568 Dell Way	\N	XSAHGSR	\N	0	Russia	2	CIHPDLXZFX@dell.com	3087890568	2	2213622465729713	2012/10	user15274	password	32	60000	F
15275	OYSXJV	FQLJBIJGGG	5803065315 Dell Way	\N	ZGOGYGZ	\N	0	Canada	2	FQLJBIJGGG@dell.com	5803065315	1	1116382855456322	2009/04	user15275	password	52	80000	M
15276	KJUUFA	KQJMYTTEZS	1336026994 Dell Way	\N	LOZKUYP	\N	0	China	2	KQJMYTTEZS@dell.com	1336026994	3	7025929969269783	2009/01	user15276	password	42	40000	F
15277	SZHXZR	NJDMCWRCPC	7164482489 Dell Way	\N	QONLNCU	\N	0	Germany	2	NJDMCWRCPC@dell.com	7164482489	3	8947261041030289	2011/10	user15277	password	24	40000	M
15278	BNKBFY	KIKNFCPVFG	9825445106 Dell Way	\N	JSSXUNL	\N	0	France	2	KIKNFCPVFG@dell.com	9825445106	2	3078963749576360	2011/05	user15278	password	52	40000	F
15279	ZSNFQY	NBLTDBOJHY	6265356695 Dell Way	\N	BAVWNHI	\N	0	Germany	2	NBLTDBOJHY@dell.com	6265356695	3	3573918120004237	2012/01	user15279	password	59	60000	F
15280	GZFXXT	YJNCKCMSBN	3406556445 Dell Way	\N	SXJGEST	\N	0	Russia	2	YJNCKCMSBN@dell.com	3406556445	1	7586782770231367	2009/08	user15280	password	31	40000	M
15281	DOUBIT	KWVVYHNZVG	3301559240 Dell Way	\N	WFMBXFU	\N	0	Canada	2	KWVVYHNZVG@dell.com	3301559240	3	5422231554053724	2012/09	user15281	password	78	80000	M
15282	KNXSGI	OCDNKRNFXK	7800756027 Dell Way	\N	LJLJPFO	\N	0	South Africa	2	OCDNKRNFXK@dell.com	7800756027	1	7381289810873569	2010/11	user15282	password	50	40000	F
15283	YGZFOO	HSCSJPYHZJ	3741084596 Dell Way	\N	QKSGQGC	\N	0	France	2	HSCSJPYHZJ@dell.com	3741084596	4	8802331946324558	2008/03	user15283	password	31	60000	F
15284	LKKZZS	SBKCQIJQRA	2091379763 Dell Way	\N	BKGSRIC	\N	0	UK	2	SBKCQIJQRA@dell.com	2091379763	5	2415684925857931	2009/02	user15284	password	61	60000	M
15285	AZPZRH	BBKSKUICUK	2542440834 Dell Way	\N	NACEJFE	\N	0	France	2	BBKSKUICUK@dell.com	2542440834	2	8575593892484904	2009/12	user15285	password	47	100000	M
15286	JNYAVZ	CFSNZAPULC	7980943430 Dell Way	\N	UNHESLQ	\N	0	South Africa	2	CFSNZAPULC@dell.com	7980943430	3	3080410692375153	2011/11	user15286	password	29	80000	F
15287	ROHMNK	RFXRGMLRPG	5932441822 Dell Way	\N	FWKYHBW	\N	0	Australia	2	RFXRGMLRPG@dell.com	5932441822	1	7970836066640914	2010/03	user15287	password	47	80000	M
15288	YZJMJB	SGTYSEQHLW	7744618969 Dell Way	\N	EWVMXRO	\N	0	France	2	SGTYSEQHLW@dell.com	7744618969	2	9037307684309780	2012/09	user15288	password	60	100000	M
15289	OGDXHV	DBUWFLERII	7122835146 Dell Way	\N	NEVLVJX	\N	0	Germany	2	DBUWFLERII@dell.com	7122835146	4	5987787034362555	2010/05	user15289	password	49	20000	M
15290	RFUZBY	AWVGIZXRIL	5642743991 Dell Way	\N	VDWQMTF	\N	0	Canada	2	AWVGIZXRIL@dell.com	5642743991	4	6136199166066945	2012/03	user15290	password	64	80000	M
15291	WOVXNW	UICCHZUQLP	2785137303 Dell Way	\N	THFGALK	\N	0	Germany	2	UICCHZUQLP@dell.com	2785137303	5	4605208974797279	2009/08	user15291	password	30	40000	F
15292	TCKGYE	OAHVABMLQF	8563011771 Dell Way	\N	SWLTHWG	\N	0	France	2	OAHVABMLQF@dell.com	8563011771	4	8992757018189878	2010/10	user15292	password	28	100000	M
15293	FIUENJ	EUFFWRQMWJ	1101492044 Dell Way	\N	JICRFJE	\N	0	Australia	2	EUFFWRQMWJ@dell.com	1101492044	1	5505184684880078	2012/03	user15293	password	49	60000	F
15294	TFOGOT	BUYXLPKIYU	6899268536 Dell Way	\N	RALWKPX	\N	0	China	2	BUYXLPKIYU@dell.com	6899268536	3	3183981075417250	2012/11	user15294	password	65	40000	M
15295	WVWLPY	FOWRDHACBR	9013124820 Dell Way	\N	DNONDMX	\N	0	Russia	2	FOWRDHACBR@dell.com	9013124820	1	6545947492588312	2011/10	user15295	password	82	40000	M
15296	SGDHEJ	VBAZIBBKTE	7633571660 Dell Way	\N	XHRAUPU	\N	0	Japan	2	VBAZIBBKTE@dell.com	7633571660	3	4629129840992391	2010/04	user15296	password	73	40000	M
15297	ZIHESD	FTCOUEYNIV	1441825119 Dell Way	\N	VAWPPQG	\N	0	China	2	FTCOUEYNIV@dell.com	1441825119	4	8900876456405968	2009/05	user15297	password	24	40000	F
15298	LPPDTV	WWJQAHEJDZ	5262571637 Dell Way	\N	JAOYQVH	\N	0	Russia	2	WWJQAHEJDZ@dell.com	5262571637	1	1269925596192479	2012/04	user15298	password	43	40000	M
15299	ZWVSRS	OBJPJNYMNH	7570763356 Dell Way	\N	NCGDXOW	\N	0	China	2	OBJPJNYMNH@dell.com	7570763356	5	3336009495425969	2008/03	user15299	password	58	80000	F
15300	LOXCGM	DPBNDAZQHM	4452854238 Dell Way	\N	SOQQCNA	\N	0	South Africa	2	DPBNDAZQHM@dell.com	4452854238	2	8572310893796385	2011/10	user15300	password	58	100000	F
15301	CTJJFN	ZHACHZTPMM	4551276863 Dell Way	\N	EDDHQDC	\N	0	Australia	2	ZHACHZTPMM@dell.com	4551276863	5	6812393643427641	2009/07	user15301	password	51	60000	M
15302	FUYKHY	SIAAHUQUHU	1981808628 Dell Way	\N	YKBPNEQ	\N	0	UK	2	SIAAHUQUHU@dell.com	1981808628	2	2252758221235126	2011/09	user15302	password	61	40000	M
15303	KEJSCB	ADCIXSDFMB	5790732027 Dell Way	\N	PNQDRHB	\N	0	Russia	2	ADCIXSDFMB@dell.com	5790732027	2	4673857528716326	2009/10	user15303	password	63	20000	F
15304	UNXWPX	ZRFXKICWKS	1929974901 Dell Way	\N	KBVCIXX	\N	0	South Africa	2	ZRFXKICWKS@dell.com	1929974901	2	1951376754790544	2012/12	user15304	password	39	20000	M
15305	VZOLWO	DCLNKOKUGV	2040589662 Dell Way	\N	WCXEZVA	\N	0	Australia	2	DCLNKOKUGV@dell.com	2040589662	1	9869127889163792	2008/05	user15305	password	23	80000	F
15306	BIRYWU	AIILWSGCOC	4351020473 Dell Way	\N	FLGEGGG	\N	0	China	2	AIILWSGCOC@dell.com	4351020473	2	4715667983051390	2011/04	user15306	password	29	20000	F
15307	MSHINI	QVTMOZPCBU	5422496753 Dell Way	\N	OHZVOGE	\N	0	UK	2	QVTMOZPCBU@dell.com	5422496753	3	7374991422519088	2012/09	user15307	password	71	20000	F
15308	LMNYUE	UNRIMHLOBZ	6150233053 Dell Way	\N	VBUKHZI	\N	0	Russia	2	UNRIMHLOBZ@dell.com	6150233053	1	6406538275070489	2009/10	user15308	password	75	60000	F
15309	HBDBGX	PXGCERQGRM	3240995296 Dell Way	\N	HLXPLFK	\N	0	Australia	2	PXGCERQGRM@dell.com	3240995296	5	3938892851117998	2008/10	user15309	password	80	40000	F
15310	YJDEGS	BMVGEMMVYU	7951143497 Dell Way	\N	HVKSBUS	\N	0	China	2	BMVGEMMVYU@dell.com	7951143497	1	3912515094038099	2010/11	user15310	password	57	60000	M
15311	WSADLB	QGIVTUQRPY	5054108198 Dell Way	\N	NARPUKX	\N	0	Germany	2	QGIVTUQRPY@dell.com	5054108198	2	1980131804011762	2009/10	user15311	password	69	40000	M
15312	LFUWHK	DPFWKWOAVC	8610486514 Dell Way	\N	AMSUWPJ	\N	0	China	2	DPFWKWOAVC@dell.com	8610486514	3	7173230434302241	2011/03	user15312	password	83	40000	M
15313	CBMKMQ	ZSNJOBJJEJ	9846012507 Dell Way	\N	WXESNNB	\N	0	China	2	ZSNJOBJJEJ@dell.com	9846012507	4	9684882790315896	2008/08	user15313	password	34	80000	M
15314	HFDTWC	LJMZLWJQFG	7584255177 Dell Way	\N	NKYAXAJ	\N	0	UK	2	LJMZLWJQFG@dell.com	7584255177	2	1499700966756790	2009/07	user15314	password	77	20000	M
15315	BFOXHZ	GUZRQJHWPV	5890004171 Dell Way	\N	GOVEOFB	\N	0	Chile	2	GUZRQJHWPV@dell.com	5890004171	1	6880972594022752	2008/12	user15315	password	72	100000	M
15316	YNWGND	AMUQWCNMXT	2245763351 Dell Way	\N	BTYPYAX	\N	0	Germany	2	AMUQWCNMXT@dell.com	2245763351	3	6478818535804749	2008/04	user15316	password	57	20000	F
15317	BYMOBN	BWEYZRKXLL	5611426573 Dell Way	\N	QJBPJYC	\N	0	Germany	2	BWEYZRKXLL@dell.com	5611426573	4	6301506259944291	2012/04	user15317	password	65	20000	F
15318	OOWQBX	MGWLXGIIRZ	4597395301 Dell Way	\N	STPCSRP	\N	0	Chile	2	MGWLXGIIRZ@dell.com	4597395301	1	1155981832649558	2011/10	user15318	password	23	100000	F
15319	QVARTN	XPZVWIEOHW	7620617202 Dell Way	\N	HWZZOOE	\N	0	UK	2	XPZVWIEOHW@dell.com	7620617202	2	6602118276059628	2010/04	user15319	password	61	100000	M
15320	LZPFNN	VMIRUMFCJN	9129181892 Dell Way	\N	ZINNXSM	\N	0	Japan	2	VMIRUMFCJN@dell.com	9129181892	1	2751758733298629	2008/09	user15320	password	29	20000	F
15321	ERJREE	EMVZZBBJPA	2687716684 Dell Way	\N	SCOPUBG	\N	0	Japan	2	EMVZZBBJPA@dell.com	2687716684	3	8749219073913992	2012/08	user15321	password	87	20000	M
15322	PKLUOP	HKPHMQQBRJ	6899989313 Dell Way	\N	DGZXIFO	\N	0	Germany	2	HKPHMQQBRJ@dell.com	6899989313	3	4701430436223746	2009/05	user15322	password	51	20000	M
15323	WLULBB	VQIIHZJZIM	4598297617 Dell Way	\N	FIKONZB	\N	0	Canada	2	VQIIHZJZIM@dell.com	4598297617	3	4988803408108652	2011/12	user15323	password	51	80000	M
15324	XOGZPC	QYKYXTXGGD	2960825371 Dell Way	\N	OQRCPTH	\N	0	UK	2	QYKYXTXGGD@dell.com	2960825371	4	8027283574454487	2008/03	user15324	password	58	100000	F
15325	CFCSHS	RSQOLOVSRK	5649415215 Dell Way	\N	IJMYCUY	\N	0	China	2	RSQOLOVSRK@dell.com	5649415215	4	5269696515053511	2011/04	user15325	password	49	100000	F
15326	QXDYQU	QGJCUEUMPD	7612263986 Dell Way	\N	VCBYWAG	\N	0	China	2	QGJCUEUMPD@dell.com	7612263986	4	1809680769685655	2008/02	user15326	password	83	60000	M
15327	UNTLIJ	RRLMWGZLJU	7492811795 Dell Way	\N	NLTKMZT	\N	0	Canada	2	RRLMWGZLJU@dell.com	7492811795	5	2918314449954778	2012/10	user15327	password	63	80000	M
15328	DLZLUR	DGEZMDKWYY	9467078541 Dell Way	\N	HRIURCZ	\N	0	China	2	DGEZMDKWYY@dell.com	9467078541	1	3480650780722499	2011/10	user15328	password	88	40000	M
15329	KGKEYN	LCNXGXTEVB	9968524780 Dell Way	\N	WEVNGVX	\N	0	Canada	2	LCNXGXTEVB@dell.com	9968524780	1	8969414817634971	2012/02	user15329	password	29	80000	M
15330	KETJRE	LEBSCVWYXT	4410903987 Dell Way	\N	CTHJOEN	\N	0	Germany	2	LEBSCVWYXT@dell.com	4410903987	3	4205126520711929	2010/07	user15330	password	25	20000	M
15331	GVIYZU	DBMGXJFUDH	6413847344 Dell Way	\N	NKQCOEQ	\N	0	UK	2	DBMGXJFUDH@dell.com	6413847344	1	5415430582594127	2008/02	user15331	password	60	20000	F
15332	KMIKHM	LUSIEXDHFQ	4599539635 Dell Way	\N	RWTGBKE	\N	0	Japan	2	LUSIEXDHFQ@dell.com	4599539635	4	8458633968140931	2010/04	user15332	password	90	100000	M
15333	MGBTSM	OLVSJYZPPQ	7584784893 Dell Way	\N	LIWNSBE	\N	0	Canada	2	OLVSJYZPPQ@dell.com	7584784893	5	6789878493640572	2012/12	user15333	password	57	80000	F
15334	USFMEU	YAMHYLWNBI	9987316311 Dell Way	\N	WYVPZAS	\N	0	Russia	2	YAMHYLWNBI@dell.com	9987316311	2	7405134804081172	2012/11	user15334	password	44	60000	M
15335	BREGLC	GXKFJGTKPP	3693202262 Dell Way	\N	JLFJLYB	\N	0	France	2	GXKFJGTKPP@dell.com	3693202262	4	4832039598375559	2009/02	user15335	password	81	100000	F
15336	NBLZES	WOXFVRQKGA	2994574220 Dell Way	\N	WMJHKLT	\N	0	Japan	2	WOXFVRQKGA@dell.com	2994574220	1	9101845237426460	2009/01	user15336	password	75	60000	M
15337	WAOATL	ORRJIIUPIQ	8953961358 Dell Way	\N	BRYLDSD	\N	0	China	2	ORRJIIUPIQ@dell.com	8953961358	1	7408681451343001	2012/10	user15337	password	38	60000	M
15338	IBRBMG	TDPBLKQUAS	3777623462 Dell Way	\N	LZDPRHY	\N	0	Germany	2	TDPBLKQUAS@dell.com	3777623462	4	5452618698123843	2008/12	user15338	password	18	100000	F
15339	BMIOSB	RICDSTXTLJ	5616795924 Dell Way	\N	SPYKWWZ	\N	0	Canada	2	RICDSTXTLJ@dell.com	5616795924	3	3871760005131364	2010/06	user15339	password	27	80000	M
15340	PZBIBT	REWJYUCKDV	6791218730 Dell Way	\N	ZCFWZEB	\N	0	France	2	REWJYUCKDV@dell.com	6791218730	2	9245626552030444	2008/06	user15340	password	61	80000	F
15341	PRLQKC	VHMTBPDFKC	4593814971 Dell Way	\N	HQZGVAS	\N	0	France	2	VHMTBPDFKC@dell.com	4593814971	4	6020173170138151	2012/03	user15341	password	30	20000	M
15342	WLMGOH	OAAPQDUAGB	7243836476 Dell Way	\N	QGIMGBX	\N	0	Japan	2	OAAPQDUAGB@dell.com	7243836476	3	6034417041111738	2012/08	user15342	password	59	80000	M
15343	AGTPOH	QPXGTRGATX	7937217673 Dell Way	\N	GCJMDHE	\N	0	South Africa	2	QPXGTRGATX@dell.com	7937217673	4	7929101455956698	2010/04	user15343	password	57	100000	F
15344	VRXJZN	ZXUSPBSJYY	3912765683 Dell Way	\N	LILPQPK	\N	0	France	2	ZXUSPBSJYY@dell.com	3912765683	1	8454567571636290	2011/09	user15344	password	72	100000	M
15345	LVXLJX	IDPYEHHDGS	9190123257 Dell Way	\N	LRICHSM	\N	0	Japan	2	IDPYEHHDGS@dell.com	9190123257	2	3014121216721833	2011/01	user15345	password	28	20000	M
15346	ZCZIZH	LPFPXNSDGE	1877070080 Dell Way	\N	VOHCHUS	\N	0	Canada	2	LPFPXNSDGE@dell.com	1877070080	5	8420954119879753	2008/02	user15346	password	19	80000	F
15347	DRKDZV	SELPSESYJN	3583182666 Dell Way	\N	MQQTKJY	\N	0	France	2	SELPSESYJN@dell.com	3583182666	4	7012735269498081	2009/10	user15347	password	44	60000	M
15348	AVAZRS	ECIXHBVQOI	8013265042 Dell Way	\N	GFBQOAD	\N	0	South Africa	2	ECIXHBVQOI@dell.com	8013265042	5	3011985000688583	2010/03	user15348	password	66	60000	F
15349	MMEDFJ	GNGNOCDDKK	9712448765 Dell Way	\N	JMAXMET	\N	0	Chile	2	GNGNOCDDKK@dell.com	9712448765	5	8452227461617441	2008/08	user15349	password	39	40000	F
15350	TNHZXN	NEBBGFFQPO	3169218389 Dell Way	\N	DQMPUGW	\N	0	Russia	2	NEBBGFFQPO@dell.com	3169218389	4	9091652826406064	2012/12	user15350	password	34	20000	M
15351	THTQVG	UWIBBNRRCV	1104150113 Dell Way	\N	HOKCVHW	\N	0	Australia	2	UWIBBNRRCV@dell.com	1104150113	4	9508574130013586	2008/12	user15351	password	88	80000	M
15352	HNJCTE	ZBGBPYSRTA	7207134557 Dell Way	\N	GECBLYC	\N	0	France	2	ZBGBPYSRTA@dell.com	7207134557	1	5295183426700533	2011/01	user15352	password	36	60000	F
15353	UUKNZJ	PFKEDDWWDC	3638039507 Dell Way	\N	AFDMEGY	\N	0	South Africa	2	PFKEDDWWDC@dell.com	3638039507	3	5644820729270578	2009/09	user15353	password	85	60000	F
15354	SZZSJP	XTTBWQXASY	8163665097 Dell Way	\N	FWKJCJF	\N	0	France	2	XTTBWQXASY@dell.com	8163665097	4	7437108261045069	2010/08	user15354	password	40	100000	F
15355	HXBQMZ	KGAHWYHPWN	8697446069 Dell Way	\N	LHXORDZ	\N	0	France	2	KGAHWYHPWN@dell.com	8697446069	4	9331069254782052	2010/01	user15355	password	80	100000	F
15356	TYYFYJ	MYRJWYYTMK	6775659852 Dell Way	\N	AJZRMYD	\N	0	China	2	MYRJWYYTMK@dell.com	6775659852	1	8781278684269638	2011/11	user15356	password	73	100000	M
15357	SXWQHJ	PYSLXQEKBF	1595694561 Dell Way	\N	TAXGZAP	\N	0	Japan	2	PYSLXQEKBF@dell.com	1595694561	3	3384659934788942	2012/03	user15357	password	34	80000	M
15358	DNOLWD	JOPHFURHZL	8215753860 Dell Way	\N	HWSHXIX	\N	0	UK	2	JOPHFURHZL@dell.com	8215753860	1	9391019765287640	2008/05	user15358	password	58	100000	M
15359	BOYYSI	MHPSCHZCTH	6466380705 Dell Way	\N	ZLOWULV	\N	0	Germany	2	MHPSCHZCTH@dell.com	6466380705	4	6457248340826482	2012/04	user15359	password	60	60000	F
15360	DLIVTV	DJNFQNIJVH	7861294243 Dell Way	\N	VJEPVZE	\N	0	France	2	DJNFQNIJVH@dell.com	7861294243	4	4772158678621054	2008/05	user15360	password	84	60000	F
15361	JUHCPL	LDQCQYMLGH	8497436199 Dell Way	\N	VKXRKBC	\N	0	Canada	2	LDQCQYMLGH@dell.com	8497436199	3	3121069301385432	2008/06	user15361	password	69	80000	M
15362	MYWBJI	EALVZXHFFC	4312208229 Dell Way	\N	PCTZEWD	\N	0	UK	2	EALVZXHFFC@dell.com	4312208229	2	2592889833729714	2011/02	user15362	password	79	60000	M
15363	ULQEUV	FGREEYKJBA	5891503898 Dell Way	\N	MVAQREQ	\N	0	Australia	2	FGREEYKJBA@dell.com	5891503898	5	8640681650489570	2011/08	user15363	password	48	40000	F
15364	WWQRSV	YJACIKMJLY	9959191811 Dell Way	\N	FLOXPFY	\N	0	Canada	2	YJACIKMJLY@dell.com	9959191811	4	8059263376519085	2011/03	user15364	password	90	20000	F
15365	VRUNNS	XNVFYHPKFU	4928804525 Dell Way	\N	VUSLZQP	\N	0	UK	2	XNVFYHPKFU@dell.com	4928804525	2	6495409486349673	2011/05	user15365	password	67	80000	F
15366	JOTXGR	KBWJJMTOGP	1339381013 Dell Way	\N	JZBIPQI	\N	0	Australia	2	KBWJJMTOGP@dell.com	1339381013	5	7253773793112487	2010/08	user15366	password	51	80000	M
15367	ZKWGBH	IXRRJKGQAP	2453427139 Dell Way	\N	PCYFTGG	\N	0	Russia	2	IXRRJKGQAP@dell.com	2453427139	5	2653663811739534	2011/05	user15367	password	77	80000	F
15368	FPRGWZ	ENROYYFZNV	3047238866 Dell Way	\N	BMAUSHO	\N	0	South Africa	2	ENROYYFZNV@dell.com	3047238866	4	6712439871393145	2011/07	user15368	password	44	20000	M
15369	YRAVRE	JJSHHXHVSI	4731148473 Dell Way	\N	HTCAARX	\N	0	Chile	2	JJSHHXHVSI@dell.com	4731148473	3	9020927681121976	2012/11	user15369	password	85	80000	M
15370	PTRHXA	RQIZOPVHYD	5974652977 Dell Way	\N	BBDBSAI	\N	0	Canada	2	RQIZOPVHYD@dell.com	5974652977	2	1997280465438962	2010/02	user15370	password	79	40000	M
15371	PZBMAS	DJRRYNZXQA	6877971235 Dell Way	\N	YTCRULV	\N	0	China	2	DJRRYNZXQA@dell.com	6877971235	5	7988963633775712	2012/10	user15371	password	23	60000	F
15372	BPWBIZ	KARJNQHDQF	6760271294 Dell Way	\N	XTXRESA	\N	0	South Africa	2	KARJNQHDQF@dell.com	6760271294	4	6571102367714048	2010/11	user15372	password	31	80000	M
15373	UPZDPK	EGURXBVOHS	2618206538 Dell Way	\N	HFKLXKH	\N	0	Germany	2	EGURXBVOHS@dell.com	2618206538	5	9629193698056044	2008/01	user15373	password	70	100000	M
15374	IYZXIE	ECVCERQMKY	6076481454 Dell Way	\N	RUKOFRD	\N	0	China	2	ECVCERQMKY@dell.com	6076481454	1	4692528641317040	2011/10	user15374	password	43	60000	F
15375	HNBPRF	SNHWEYIOWA	7957451210 Dell Way	\N	JGOOXSY	\N	0	France	2	SNHWEYIOWA@dell.com	7957451210	2	2116794996894896	2010/09	user15375	password	64	80000	M
15376	DTPUYH	HGEMENBBNK	3420359923 Dell Way	\N	HCZFUXS	\N	0	Germany	2	HGEMENBBNK@dell.com	3420359923	5	2197729874402284	2012/06	user15376	password	78	100000	M
15377	OOKNVR	TAEYOFZBQG	1062297296 Dell Way	\N	EPMYNEN	\N	0	Russia	2	TAEYOFZBQG@dell.com	1062297296	4	7923138289246709	2010/06	user15377	password	70	20000	F
15378	GLOCDH	DHFRNFSDMX	9993240640 Dell Way	\N	TYVHDJC	\N	0	Canada	2	DHFRNFSDMX@dell.com	9993240640	5	6449490407481790	2010/07	user15378	password	66	60000	M
15379	CBYGIB	OOSBULFGIZ	2540193055 Dell Way	\N	FEGINIM	\N	0	Germany	2	OOSBULFGIZ@dell.com	2540193055	1	1053505585528910	2011/09	user15379	password	55	60000	M
15380	ONCXPQ	MISGUXMDWR	6141557477 Dell Way	\N	HDAVLMJ	\N	0	Japan	2	MISGUXMDWR@dell.com	6141557477	2	4226244365330786	2009/11	user15380	password	86	20000	F
15381	MGIBXU	JPBDMNHJFO	2304946284 Dell Way	\N	MFKYSUO	\N	0	Chile	2	JPBDMNHJFO@dell.com	2304946284	5	6397265413310379	2008/11	user15381	password	73	60000	F
15382	AUJXPT	MRXZEEJKTV	3054001042 Dell Way	\N	QDUIXIQ	\N	0	Australia	2	MRXZEEJKTV@dell.com	3054001042	2	1851298297755420	2008/12	user15382	password	59	40000	M
15383	JTXZNJ	QKJVPSFIOW	1338860056 Dell Way	\N	MIEKQVM	\N	0	South Africa	2	QKJVPSFIOW@dell.com	1338860056	3	9557785532437266	2008/02	user15383	password	42	20000	F
15384	CXMPHD	ARYQJEYYAL	8917881632 Dell Way	\N	GFVXAIU	\N	0	Australia	2	ARYQJEYYAL@dell.com	8917881632	4	1648327532690018	2008/01	user15384	password	24	60000	F
15385	AZUICV	ZBLJFKHFVO	9573873401 Dell Way	\N	KRLLZFM	\N	0	South Africa	2	ZBLJFKHFVO@dell.com	9573873401	3	8872365777380765	2008/08	user15385	password	45	20000	M
15386	JZZMUY	NFHSQPYLDJ	8319510871 Dell Way	\N	DOUCUGZ	\N	0	Russia	2	NFHSQPYLDJ@dell.com	8319510871	5	7885660050902516	2010/03	user15386	password	88	20000	M
15387	YCBTAO	ZIHPXFAAPD	1593791798 Dell Way	\N	PJGJQFD	\N	0	France	2	ZIHPXFAAPD@dell.com	1593791798	5	9168668577447536	2009/11	user15387	password	19	100000	M
15388	CYNDNM	LVBIBCJQFY	3931972613 Dell Way	\N	AMIQSLC	\N	0	Russia	2	LVBIBCJQFY@dell.com	3931972613	1	1513948726933449	2008/01	user15388	password	86	100000	F
15389	XMGKYR	FAAGCJXIHX	6826524802 Dell Way	\N	UQOMBQG	\N	0	China	2	FAAGCJXIHX@dell.com	6826524802	2	5986115355975926	2011/04	user15389	password	55	80000	F
15390	ZAOYRU	YRBABYJIWD	3011509390 Dell Way	\N	ZKQABXK	\N	0	Russia	2	YRBABYJIWD@dell.com	3011509390	5	4365994491614401	2010/06	user15390	password	29	80000	F
15391	EFJWZH	OBIPARYWVX	3626992217 Dell Way	\N	HMYJJIB	\N	0	Germany	2	OBIPARYWVX@dell.com	3626992217	3	1764024723321199	2011/08	user15391	password	70	20000	M
15392	YOQXWF	ZFUZXTWSRE	9842394316 Dell Way	\N	EPNOYOE	\N	0	Chile	2	ZFUZXTWSRE@dell.com	9842394316	2	9870053079444916	2010/12	user15392	password	31	40000	M
15393	TZVQEU	VZUSTQLKUQ	6420403439 Dell Way	\N	AIFYWJE	\N	0	South Africa	2	VZUSTQLKUQ@dell.com	6420403439	1	4756566829979420	2010/05	user15393	password	73	60000	F
15394	SHTXCO	XWHQNTAIJA	3866212082 Dell Way	\N	QOZNYEJ	\N	0	Germany	2	XWHQNTAIJA@dell.com	3866212082	4	1920624520163983	2011/07	user15394	password	59	80000	F
15395	WMEYBB	VJRJDSSNTI	9861157755 Dell Way	\N	BSWAWFN	\N	0	Canada	2	VJRJDSSNTI@dell.com	9861157755	4	8769444673322142	2010/03	user15395	password	63	80000	F
15396	DYAFZW	PRFSJXFCGH	5073894645 Dell Way	\N	VCHSIVX	\N	0	China	2	PRFSJXFCGH@dell.com	5073894645	4	8360871443524958	2011/05	user15396	password	61	80000	M
15397	NTTNQI	FVAOTFRANM	8878164185 Dell Way	\N	DUFLPCT	\N	0	Australia	2	FVAOTFRANM@dell.com	8878164185	3	7540798580739648	2009/02	user15397	password	51	100000	M
15398	FNFWWK	SWZLCQMPDP	4385478472 Dell Way	\N	KIBALUB	\N	0	China	2	SWZLCQMPDP@dell.com	4385478472	5	6271037539001555	2010/04	user15398	password	46	40000	F
15399	YMIUWA	QWMSNYIQOS	6376292651 Dell Way	\N	ZQSKLUS	\N	0	South Africa	2	QWMSNYIQOS@dell.com	6376292651	2	4093618265818805	2012/09	user15399	password	60	40000	M
15400	BRJYSA	UETHDBYSUX	3744283847 Dell Way	\N	IMHTHAO	\N	0	South Africa	2	UETHDBYSUX@dell.com	3744283847	5	7762425530236215	2012/06	user15400	password	24	80000	M
15401	UZMMZG	QTOUUMNOJV	1445740507 Dell Way	\N	BRPJRDG	\N	0	UK	2	QTOUUMNOJV@dell.com	1445740507	1	9750638460274788	2010/02	user15401	password	59	20000	M
15402	ONIOUZ	HIUCVHQEDS	4154497093 Dell Way	\N	WSCNWIN	\N	0	South Africa	2	HIUCVHQEDS@dell.com	4154497093	3	4912334454711527	2010/01	user15402	password	54	40000	M
15403	AREVRL	DLNYTEDWXZ	5634824178 Dell Way	\N	OZNLIAI	\N	0	Japan	2	DLNYTEDWXZ@dell.com	5634824178	4	2195215412415564	2010/04	user15403	password	51	20000	F
15404	DICUUG	GIFANJWKJL	9725044691 Dell Way	\N	KWXSXFK	\N	0	France	2	GIFANJWKJL@dell.com	9725044691	3	1012763488572090	2009/12	user15404	password	31	60000	F
15405	NQYIXE	QDFDMCOVNY	6439009943 Dell Way	\N	SKRQQBB	\N	0	Japan	2	QDFDMCOVNY@dell.com	6439009943	1	8492552215233446	2010/04	user15405	password	44	80000	M
15406	ZQCXVT	AAXMCLIQKB	8574773832 Dell Way	\N	BBSSDUH	\N	0	Russia	2	AAXMCLIQKB@dell.com	8574773832	1	3964398718439043	2008/06	user15406	password	21	100000	F
15407	SZJNSK	OPWRBFHLHJ	5265056645 Dell Way	\N	MZBQTJJ	\N	0	Germany	2	OPWRBFHLHJ@dell.com	5265056645	4	7159269607625902	2012/09	user15407	password	58	60000	F
15408	NVYGFN	WCEXIMIPVV	5179678630 Dell Way	\N	OXLIGUX	\N	0	Russia	2	WCEXIMIPVV@dell.com	5179678630	3	7007820025086404	2008/02	user15408	password	25	80000	M
15409	YPYDCU	FGSNTADOWS	5457802913 Dell Way	\N	LHASCXK	\N	0	Germany	2	FGSNTADOWS@dell.com	5457802913	1	7720256313681603	2011/03	user15409	password	44	40000	F
15410	YGGBBM	ITABUDQRVC	3340697975 Dell Way	\N	YVUBTEP	\N	0	Chile	2	ITABUDQRVC@dell.com	3340697975	2	8914616466034205	2010/09	user15410	password	33	60000	M
15411	MUSNGA	HGBCKSTFUS	7398953720 Dell Way	\N	BOTUTJA	\N	0	Australia	2	HGBCKSTFUS@dell.com	7398953720	5	5150132375303656	2010/02	user15411	password	18	20000	M
15412	UUCBVK	HXNSPGXJZY	6953044564 Dell Way	\N	YSTSCTT	\N	0	South Africa	2	HXNSPGXJZY@dell.com	6953044564	1	3061972646974027	2011/03	user15412	password	41	40000	F
15413	DMBYWJ	VJBLQYVPXU	4797773359 Dell Way	\N	IQMKKFF	\N	0	Australia	2	VJBLQYVPXU@dell.com	4797773359	3	8527300216257573	2011/10	user15413	password	31	80000	M
15414	QRVNAR	XCDNBYDYSM	5964880642 Dell Way	\N	PFWALCB	\N	0	South Africa	2	XCDNBYDYSM@dell.com	5964880642	5	5262043674010784	2009/02	user15414	password	25	40000	M
15415	UBHVTE	XWSYUVXNIN	5703401653 Dell Way	\N	SENDHPZ	\N	0	South Africa	2	XWSYUVXNIN@dell.com	5703401653	3	2512027690187096	2011/07	user15415	password	46	40000	F
15416	LQEFVB	BNAWJYJRMC	6974286096 Dell Way	\N	WAFEQFA	\N	0	Canada	2	BNAWJYJRMC@dell.com	6974286096	1	7929005483165384	2009/07	user15416	password	28	60000	F
15417	USFPUG	DVDMUMEHPB	4480723471 Dell Way	\N	HVFXAFB	\N	0	Japan	2	DVDMUMEHPB@dell.com	4480723471	5	9154296014923604	2012/12	user15417	password	52	100000	M
15418	FEJALM	VOZQBEXQFF	1260761493 Dell Way	\N	LKDMQEE	\N	0	Australia	2	VOZQBEXQFF@dell.com	1260761493	1	9621012725867332	2008/07	user15418	password	84	80000	M
15419	CDSNQO	BPFCTDTZIF	8997740181 Dell Way	\N	JLRAQVA	\N	0	Japan	2	BPFCTDTZIF@dell.com	8997740181	5	7080072809942067	2010/11	user15419	password	50	20000	M
15420	OWMELN	URQOUKNCPX	9034331568 Dell Way	\N	OHXECXW	\N	0	UK	2	URQOUKNCPX@dell.com	9034331568	3	4704828258603811	2011/12	user15420	password	58	80000	M
15421	LFTXTN	OKCIUPKKNY	5802925727 Dell Way	\N	RLDUJAU	\N	0	Chile	2	OKCIUPKKNY@dell.com	5802925727	1	1235939635895192	2010/09	user15421	password	74	20000	F
15422	ZUBTIQ	EKYYAJJNIA	7990597233 Dell Way	\N	ZLVILPO	\N	0	UK	2	EKYYAJJNIA@dell.com	7990597233	3	5516353499609978	2010/05	user15422	password	58	80000	F
15423	IUCRKH	BIFBRPPZQP	1559684736 Dell Way	\N	LLXXAMX	\N	0	South Africa	2	BIFBRPPZQP@dell.com	1559684736	3	4032506941352040	2010/12	user15423	password	21	80000	F
15424	VXZFEA	OKCGZSGQHR	9177389235 Dell Way	\N	BFPCRNY	\N	0	Russia	2	OKCGZSGQHR@dell.com	9177389235	2	2388612627517432	2012/04	user15424	password	87	20000	F
15425	WDJAEX	LHDLZJBHBD	4858800437 Dell Way	\N	MQGDDEW	\N	0	Australia	2	LHDLZJBHBD@dell.com	4858800437	1	9384758508764208	2011/12	user15425	password	25	100000	M
15426	GFWKDH	RGSRQUYSYL	4900289777 Dell Way	\N	JEOMIKO	\N	0	Russia	2	RGSRQUYSYL@dell.com	4900289777	3	5482889606151730	2009/08	user15426	password	44	40000	M
15427	OBHSIY	YBQPWPHUAQ	2748997742 Dell Way	\N	YODHZSB	\N	0	France	2	YBQPWPHUAQ@dell.com	2748997742	3	8347203447017820	2011/11	user15427	password	19	80000	F
15428	CXELWD	MNTJCBDCRC	1008501219 Dell Way	\N	RVKRNLC	\N	0	Russia	2	MNTJCBDCRC@dell.com	1008501219	5	5737515525892377	2012/12	user15428	password	30	60000	F
15429	CPLZTY	MMHONLRFOJ	1224397197 Dell Way	\N	BYAPKDI	\N	0	China	2	MMHONLRFOJ@dell.com	1224397197	5	3729032031726092	2012/01	user15429	password	69	100000	F
15430	HKBAIO	NQDBCVGQEI	1712882193 Dell Way	\N	OFXYIFJ	\N	0	China	2	NQDBCVGQEI@dell.com	1712882193	4	3735646212473512	2008/05	user15430	password	37	40000	M
15431	RHRAVF	RZGTUNJYVY	9147005209 Dell Way	\N	ETXMZGV	\N	0	Australia	2	RZGTUNJYVY@dell.com	9147005209	1	2363038875162601	2009/05	user15431	password	44	100000	F
15432	QPCMVU	LBNGPXEKWI	8071967818 Dell Way	\N	ETVDAQE	\N	0	UK	2	LBNGPXEKWI@dell.com	8071967818	2	2616362657863647	2008/09	user15432	password	25	40000	F
15433	SJVNDH	PRNEOSPKAT	4436624791 Dell Way	\N	EWWENBC	\N	0	Chile	2	PRNEOSPKAT@dell.com	4436624791	2	5406886342912913	2008/05	user15433	password	73	60000	F
15434	DGPHNE	ZAINSXYTRC	6981267094 Dell Way	\N	QNHDOKL	\N	0	UK	2	ZAINSXYTRC@dell.com	6981267094	5	1271226496901363	2008/09	user15434	password	50	20000	M
15435	RSDFWC	GFQZDOSURI	8461551419 Dell Way	\N	IZMXJXV	\N	0	Australia	2	GFQZDOSURI@dell.com	8461551419	5	1518570231739431	2010/04	user15435	password	30	40000	F
15436	WMFTOL	ZFLDTDXLMG	8636460343 Dell Way	\N	KZDTWZU	\N	0	Russia	2	ZFLDTDXLMG@dell.com	8636460343	5	2972776620183140	2008/01	user15436	password	59	20000	M
15437	BKRPWQ	VHUOLRAYYK	8005442363 Dell Way	\N	XBEUAYM	\N	0	South Africa	2	VHUOLRAYYK@dell.com	8005442363	4	1481000169645994	2011/04	user15437	password	35	80000	F
15438	QIXNZS	UTHFLHEJSB	9897506817 Dell Way	\N	LWVMVHJ	\N	0	Germany	2	UTHFLHEJSB@dell.com	9897506817	3	4432781479321420	2009/08	user15438	password	22	60000	F
15439	KMUJFO	DMUOUYYMAJ	6292192188 Dell Way	\N	JVVEDEU	\N	0	Canada	2	DMUOUYYMAJ@dell.com	6292192188	1	4176570231560618	2009/03	user15439	password	84	60000	M
15440	JHZOWC	BQQVPPIPYR	8155978909 Dell Way	\N	KUWNYQQ	\N	0	Germany	2	BQQVPPIPYR@dell.com	8155978909	5	7972254121210427	2008/11	user15440	password	38	80000	F
15441	OPVKRW	BISRXBGWSR	8441051098 Dell Way	\N	QPFPGVD	\N	0	Australia	2	BISRXBGWSR@dell.com	8441051098	5	1321444054599851	2011/03	user15441	password	65	100000	M
15442	GVEYSF	GKWELDAEUR	3868858068 Dell Way	\N	UAGAVKA	\N	0	Japan	2	GKWELDAEUR@dell.com	3868858068	1	4472965488210321	2010/09	user15442	password	45	40000	M
15443	FLXXRD	IOIURJZMAT	8806460448 Dell Way	\N	MHTIRUZ	\N	0	UK	2	IOIURJZMAT@dell.com	8806460448	2	5584675326943398	2010/09	user15443	password	74	60000	M
15444	FLVXPE	LXYDGXPGQC	8011255741 Dell Way	\N	NKKFFKF	\N	0	Australia	2	LXYDGXPGQC@dell.com	8011255741	4	6947926951572300	2010/06	user15444	password	33	60000	M
15445	RIPGMB	DKEKIURZWF	4029134113 Dell Way	\N	JHKPSQQ	\N	0	France	2	DKEKIURZWF@dell.com	4029134113	2	1043063075281679	2012/07	user15445	password	52	60000	F
15446	UELGFP	RKZZEQYBVI	8701705731 Dell Way	\N	IGXAWON	\N	0	Chile	2	RKZZEQYBVI@dell.com	8701705731	3	1317500599659979	2009/12	user15446	password	61	60000	M
15447	TZAZOS	JORNEQOAYX	9851945913 Dell Way	\N	GWYDKMI	\N	0	Chile	2	JORNEQOAYX@dell.com	9851945913	2	6760398560669274	2012/12	user15447	password	32	80000	M
15448	FURTNA	IEOMVDNUAU	6390796461 Dell Way	\N	QZXALGH	\N	0	France	2	IEOMVDNUAU@dell.com	6390796461	5	4607104856520891	2010/02	user15448	password	29	40000	F
15449	YYCLYK	QNXLQLGRFW	2120419973 Dell Way	\N	QDXBJEM	\N	0	UK	2	QNXLQLGRFW@dell.com	2120419973	5	5540039542596788	2009/01	user15449	password	73	60000	F
15450	SSMQCC	EAOULULRRC	5798823049 Dell Way	\N	UODDTQC	\N	0	South Africa	2	EAOULULRRC@dell.com	5798823049	3	2243778034579009	2010/05	user15450	password	71	60000	F
15451	LBSOEW	OTQAOCRFEL	3379436915 Dell Way	\N	UIPNYRK	\N	0	France	2	OTQAOCRFEL@dell.com	3379436915	3	1684719141107052	2011/04	user15451	password	67	80000	M
15452	TJGXFV	RWVFYMLDYF	7188408518 Dell Way	\N	LOTKFDX	\N	0	France	2	RWVFYMLDYF@dell.com	7188408518	5	1889439460821449	2012/08	user15452	password	73	80000	F
15453	DXHISZ	FOEEBQHAVT	9873988843 Dell Way	\N	OODTSAG	\N	0	China	2	FOEEBQHAVT@dell.com	9873988843	2	4263879408128560	2011/02	user15453	password	20	20000	F
15454	YHORGU	FLYHBGHXZV	2592225165 Dell Way	\N	LDPEDVO	\N	0	Canada	2	FLYHBGHXZV@dell.com	2592225165	5	7778884675353766	2009/12	user15454	password	73	60000	M
15455	BCPIWV	UVCVBJSBFE	8619362648 Dell Way	\N	EUJIQXL	\N	0	Russia	2	UVCVBJSBFE@dell.com	8619362648	2	1685186817776411	2012/12	user15455	password	61	80000	F
15456	RIIODC	JFYLPRNUWS	7138119568 Dell Way	\N	OFAEDMZ	\N	0	UK	2	JFYLPRNUWS@dell.com	7138119568	1	8038213098421694	2011/08	user15456	password	54	80000	F
15457	VAWYDG	EBSUTFOPXD	4310401359 Dell Way	\N	UYIYKIX	\N	0	Australia	2	EBSUTFOPXD@dell.com	4310401359	4	7633224464952946	2008/03	user15457	password	47	40000	F
15458	KFYNMD	PEXIKMYIPT	3316125349 Dell Way	\N	GYRRGOT	\N	0	Japan	2	PEXIKMYIPT@dell.com	3316125349	3	6602261103689671	2010/11	user15458	password	88	60000	F
15459	EKVROL	WLTGYSONLV	7702444073 Dell Way	\N	LCMSRGH	\N	0	UK	2	WLTGYSONLV@dell.com	7702444073	5	4403929627500475	2011/11	user15459	password	79	100000	F
15460	GUTUFP	GZVERKSCGE	1908608634 Dell Way	\N	FTWXZEV	\N	0	Russia	2	GZVERKSCGE@dell.com	1908608634	1	4360286629293114	2012/01	user15460	password	41	20000	F
15461	CVCIKJ	HGOZQGCXLH	2774340603 Dell Way	\N	QIEQMAJ	\N	0	Germany	2	HGOZQGCXLH@dell.com	2774340603	4	6273014813195915	2009/01	user15461	password	65	60000	F
15462	MPMWYT	CNTTTVQFDH	9676665926 Dell Way	\N	NIXAIGQ	\N	0	Germany	2	CNTTTVQFDH@dell.com	9676665926	2	7650003564078362	2008/11	user15462	password	36	20000	F
15463	WQEVJH	IDACYRHBYV	6878677197 Dell Way	\N	JVVRBLF	\N	0	Australia	2	IDACYRHBYV@dell.com	6878677197	5	1432464826386421	2010/03	user15463	password	32	100000	F
15464	VAWFHE	IIGGZNIYIS	5889955610 Dell Way	\N	UEKVQPX	\N	0	Chile	2	IIGGZNIYIS@dell.com	5889955610	5	8165887852665038	2011/02	user15464	password	63	80000	M
15465	QQEYUM	GBTGOBEXUY	6434858517 Dell Way	\N	CEUSURA	\N	0	China	2	GBTGOBEXUY@dell.com	6434858517	5	1523018721491098	2011/06	user15465	password	79	80000	F
15466	MWZGJG	ICMWEQUYPX	5039665898 Dell Way	\N	DJQXAQF	\N	0	Japan	2	ICMWEQUYPX@dell.com	5039665898	2	4391876081936062	2012/02	user15466	password	23	100000	M
15467	YYWHFE	KRBOIVNXSQ	1443962764 Dell Way	\N	GINHZTX	\N	0	France	2	KRBOIVNXSQ@dell.com	1443962764	2	3856694577727467	2008/05	user15467	password	38	80000	F
15468	GQPLVZ	CWOLSBILRO	1734452698 Dell Way	\N	UFWTZUE	\N	0	Australia	2	CWOLSBILRO@dell.com	1734452698	3	2826466347090900	2010/10	user15468	password	89	80000	F
15469	PKLKJO	HYZZZIKRXE	6428682940 Dell Way	\N	WTXWNCX	\N	0	Japan	2	HYZZZIKRXE@dell.com	6428682940	1	1631153511814773	2009/01	user15469	password	79	40000	M
15470	GWCQKJ	OKINSTFPXC	9382510033 Dell Way	\N	JVYXYVN	\N	0	Germany	2	OKINSTFPXC@dell.com	9382510033	3	9209643071051688	2012/06	user15470	password	40	80000	M
15471	ETHPDV	AMJSFOICRS	7103480326 Dell Way	\N	YPPWLCJ	\N	0	China	2	AMJSFOICRS@dell.com	7103480326	2	4310407344251871	2008/08	user15471	password	21	80000	M
15472	UAJYWJ	KGCPULSLDQ	2443131798 Dell Way	\N	BTMMVWW	\N	0	Germany	2	KGCPULSLDQ@dell.com	2443131798	2	6618640176486225	2011/04	user15472	password	45	60000	F
15473	KXAHGK	NIAIUSUXJW	5128959369 Dell Way	\N	RVJNSFA	\N	0	South Africa	2	NIAIUSUXJW@dell.com	5128959369	4	6632123167626560	2011/01	user15473	password	29	100000	F
15474	BVTIGH	QHPLAKIJGA	2694453786 Dell Way	\N	FPNXVNT	\N	0	Chile	2	QHPLAKIJGA@dell.com	2694453786	2	1217972205020487	2009/07	user15474	password	79	80000	M
15475	RLXYSO	FHZGSIPYIU	8324133767 Dell Way	\N	OWRKKLR	\N	0	Germany	2	FHZGSIPYIU@dell.com	8324133767	4	8200525174848736	2009/07	user15475	password	53	100000	F
15476	XWEPLK	XLQQTGPCAD	9306673939 Dell Way	\N	YSNJDFY	\N	0	UK	2	XLQQTGPCAD@dell.com	9306673939	4	3899904537480325	2010/03	user15476	password	38	80000	F
15477	DXSOHQ	ZYGTEVWFZV	8447234638 Dell Way	\N	YNECTCB	\N	0	Japan	2	ZYGTEVWFZV@dell.com	8447234638	2	2172856396529823	2008/08	user15477	password	79	20000	M
15478	SWJANJ	ZTDEPAJPVI	8643864389 Dell Way	\N	CAKVDMM	\N	0	UK	2	ZTDEPAJPVI@dell.com	8643864389	4	9869289077352732	2010/06	user15478	password	27	40000	F
15479	ZRFNBE	GFIWFSLBAO	5389290988 Dell Way	\N	BLJFXWD	\N	0	Russia	2	GFIWFSLBAO@dell.com	5389290988	1	3444168576505035	2012/04	user15479	password	60	20000	F
15480	GIUINB	NWXTPJUQXW	4128028564 Dell Way	\N	BHBZEFT	\N	0	Japan	2	NWXTPJUQXW@dell.com	4128028564	1	6296981729567052	2011/08	user15480	password	70	100000	M
15481	BREPSS	LPLAZFQWCS	4991068495 Dell Way	\N	EDRIILZ	\N	0	Japan	2	LPLAZFQWCS@dell.com	4991068495	3	3769388699438423	2008/04	user15481	password	32	100000	F
15482	WCXOUJ	EFJDLAANSE	1068058639 Dell Way	\N	RKMAVLS	\N	0	Chile	2	EFJDLAANSE@dell.com	1068058639	1	3901490552816540	2009/03	user15482	password	34	80000	F
15483	HNPCWT	IGWTHXHABY	6784974761 Dell Way	\N	KOYGAQN	\N	0	Australia	2	IGWTHXHABY@dell.com	6784974761	5	3608877047430724	2012/01	user15483	password	83	100000	F
15484	KMMHFU	OCOVZWVBUG	9062352081 Dell Way	\N	PTMPKAP	\N	0	Australia	2	OCOVZWVBUG@dell.com	9062352081	5	8811867978889496	2012/10	user15484	password	72	40000	F
15485	FVNLQB	OFXNBSPVYE	3496601123 Dell Way	\N	PLUZMJA	\N	0	China	2	OFXNBSPVYE@dell.com	3496601123	5	4285615765955299	2008/08	user15485	password	71	40000	M
15486	OUHFWV	KTJLMYHLCW	7508475669 Dell Way	\N	XWVJGWT	\N	0	Germany	2	KTJLMYHLCW@dell.com	7508475669	1	6528196029830725	2009/11	user15486	password	84	20000	F
15487	SMQPHA	IRLUPSGSPD	4709784968 Dell Way	\N	PLNWHHK	\N	0	UK	2	IRLUPSGSPD@dell.com	4709784968	1	4118036195635796	2009/12	user15487	password	57	80000	M
15488	AIFIIO	ZUJPNPIDSX	2946029007 Dell Way	\N	OGUVNFV	\N	0	UK	2	ZUJPNPIDSX@dell.com	2946029007	1	2751713039353490	2008/09	user15488	password	83	80000	M
15489	FZAOOA	JXPXMXAFVO	4500939754 Dell Way	\N	LQKYVFW	\N	0	Australia	2	JXPXMXAFVO@dell.com	4500939754	1	2662660649046302	2008/12	user15489	password	88	100000	F
15490	ZWTNWD	KMAXKADGPO	5367614846 Dell Way	\N	WZNSFKT	\N	0	Germany	2	KMAXKADGPO@dell.com	5367614846	5	7218205891083927	2010/11	user15490	password	55	80000	M
15491	JKJFNU	SORCOVIEJF	5966079757 Dell Way	\N	EXXJIQY	\N	0	South Africa	2	SORCOVIEJF@dell.com	5966079757	4	3412453353404999	2010/02	user15491	password	84	40000	M
15492	IQTVLL	JCNYXWDHBH	3217745250 Dell Way	\N	FZQOPPJ	\N	0	Canada	2	JCNYXWDHBH@dell.com	3217745250	4	6323141255415977	2010/07	user15492	password	82	100000	M
15493	NQRYCB	BQAZMDHOKM	1269906091 Dell Way	\N	NBBDRKH	\N	0	UK	2	BQAZMDHOKM@dell.com	1269906091	5	3737272771075368	2010/10	user15493	password	33	60000	F
15494	WCGYEH	OFGBIOPTAD	4825820691 Dell Way	\N	UCHLMOJ	\N	0	Germany	2	OFGBIOPTAD@dell.com	4825820691	4	1712054857518524	2008/11	user15494	password	54	60000	M
15495	QSSUZH	ZGIIUYBVCW	4192550849 Dell Way	\N	XJIKXRX	\N	0	China	2	ZGIIUYBVCW@dell.com	4192550849	5	5627860015258194	2009/06	user15495	password	89	100000	F
15496	RSXRZW	XIFSGGOJDM	7675294096 Dell Way	\N	SLWQDTY	\N	0	France	2	XIFSGGOJDM@dell.com	7675294096	3	7612535648047925	2009/06	user15496	password	70	40000	F
15497	KFTKCR	SHKZOYIRKA	1536608912 Dell Way	\N	DHQHAPU	\N	0	Russia	2	SHKZOYIRKA@dell.com	1536608912	3	1006771752145141	2010/03	user15497	password	41	80000	M
15498	OJBQBT	YLSNKAEVBI	9093989617 Dell Way	\N	CRPDHKX	\N	0	China	2	YLSNKAEVBI@dell.com	9093989617	5	8599545151460917	2008/03	user15498	password	51	80000	M
15499	VWKXPJ	JIWUJBPLJR	6594582144 Dell Way	\N	DZVKJST	\N	0	Chile	2	JIWUJBPLJR@dell.com	6594582144	3	4728037429973483	2012/01	user15499	password	33	80000	M
15500	BBURKE	AGYKINVRFY	7072014791 Dell Way	\N	RBIBTCI	\N	0	China	2	AGYKINVRFY@dell.com	7072014791	4	3081131070852280	2011/12	user15500	password	80	80000	F
15501	XKSHOS	ONCWBYOGWG	4449143876 Dell Way	\N	IFHBHQL	\N	0	UK	2	ONCWBYOGWG@dell.com	4449143876	4	7237177230883390	2009/07	user15501	password	40	40000	F
15502	SBSHUH	UXDVVSCSYK	6506624774 Dell Way	\N	XGMFWYE	\N	0	Chile	2	UXDVVSCSYK@dell.com	6506624774	5	6334116117097438	2008/03	user15502	password	88	60000	M
15503	AHEVPY	SSUOLXGJIE	4610549022 Dell Way	\N	PUJLSNS	\N	0	China	2	SSUOLXGJIE@dell.com	4610549022	2	5326657267753035	2010/04	user15503	password	22	60000	F
15504	JQDYOV	RJKCGQLOUB	5578429765 Dell Way	\N	JENCSFK	\N	0	Australia	2	RJKCGQLOUB@dell.com	5578429765	5	7019039940088988	2011/12	user15504	password	27	20000	F
15505	TEGIAX	RLAYBLNWNW	3439736263 Dell Way	\N	AAYSFJV	\N	0	Russia	2	RLAYBLNWNW@dell.com	3439736263	3	5483631379436702	2009/08	user15505	password	59	60000	F
15506	TURUSJ	FSIHEVDRSE	3153278113 Dell Way	\N	SRXXATQ	\N	0	China	2	FSIHEVDRSE@dell.com	3153278113	1	5802480333950371	2012/09	user15506	password	23	40000	F
15507	WXGPGL	HPSMKWECBW	6368946352 Dell Way	\N	UZUVSLD	\N	0	UK	2	HPSMKWECBW@dell.com	6368946352	4	8391050062607975	2009/09	user15507	password	21	80000	M
15508	YAEFLM	UEZFBDICAC	7060373627 Dell Way	\N	CVXVHAU	\N	0	South Africa	2	UEZFBDICAC@dell.com	7060373627	3	2708682980388403	2009/08	user15508	password	87	100000	M
15509	YEUKQP	PQUQUCTVFV	9973194761 Dell Way	\N	QCQYDKV	\N	0	Russia	2	PQUQUCTVFV@dell.com	9973194761	1	2723099958617240	2011/12	user15509	password	31	40000	M
15510	JAIAPX	QKOKMHFSCW	6710558997 Dell Way	\N	USUXDQS	\N	0	Canada	2	QKOKMHFSCW@dell.com	6710558997	5	7819858242757619	2010/01	user15510	password	89	60000	F
15511	ZWLPUC	ZIMMPSERPZ	5326989300 Dell Way	\N	KKWNAPR	\N	0	Japan	2	ZIMMPSERPZ@dell.com	5326989300	3	3277135020121932	2010/05	user15511	password	74	20000	F
15512	QLYKNY	SAKITPZIOK	1147076328 Dell Way	\N	SLYTAPK	\N	0	France	2	SAKITPZIOK@dell.com	1147076328	4	1556551618967205	2010/05	user15512	password	22	80000	F
15513	NTLARE	BCMURMCFXV	6138559480 Dell Way	\N	RVORLYE	\N	0	France	2	BCMURMCFXV@dell.com	6138559480	2	8766401103697718	2012/04	user15513	password	64	20000	M
15514	JMVBRX	DERURUAOPR	7906133939 Dell Way	\N	KDJWCNI	\N	0	Japan	2	DERURUAOPR@dell.com	7906133939	1	6762153098359705	2008/10	user15514	password	67	100000	F
15515	ESGWPK	AHFSCFHRXS	1475632926 Dell Way	\N	VGOXUWO	\N	0	Germany	2	AHFSCFHRXS@dell.com	1475632926	2	6669322665780783	2012/11	user15515	password	54	20000	F
15516	FIXVSY	DXRFDYXBRS	4839300078 Dell Way	\N	IFQCCFR	\N	0	Canada	2	DXRFDYXBRS@dell.com	4839300078	2	1252325104083865	2009/10	user15516	password	25	40000	F
15517	LHWDGZ	BYEFXBGOUO	6860742237 Dell Way	\N	ULRWQIB	\N	0	Australia	2	BYEFXBGOUO@dell.com	6860742237	1	4515254339668900	2010/03	user15517	password	74	60000	M
15518	BITIIU	GMAEOGSIUM	5371117141 Dell Way	\N	UMJLVKM	\N	0	France	2	GMAEOGSIUM@dell.com	5371117141	5	9391698200721296	2011/08	user15518	password	48	40000	M
15519	TZBBUI	OUMCBFLWSF	1288294809 Dell Way	\N	ICQDNDQ	\N	0	UK	2	OUMCBFLWSF@dell.com	1288294809	3	6761341503821314	2011/12	user15519	password	83	60000	M
15520	WNURVI	MIKNOWJGBR	1121407785 Dell Way	\N	ISVVWLV	\N	0	South Africa	2	MIKNOWJGBR@dell.com	1121407785	3	6208343271166087	2012/05	user15520	password	18	80000	F
15521	NMXJUJ	RFXGBGMDYV	9295866468 Dell Way	\N	VUQRGMO	\N	0	Chile	2	RFXGBGMDYV@dell.com	9295866468	1	3138896171934903	2009/02	user15521	password	86	60000	M
15522	KKAFUS	KRYLYKOXGK	8290575937 Dell Way	\N	RWCXIRE	\N	0	Chile	2	KRYLYKOXGK@dell.com	8290575937	3	5806318042799831	2012/05	user15522	password	20	80000	M
15523	LQZGJJ	YHVWSKUYUL	9638459875 Dell Way	\N	VXJEOOK	\N	0	China	2	YHVWSKUYUL@dell.com	9638459875	5	4034995754715055	2009/12	user15523	password	88	20000	F
15524	QARZKQ	GFNZQHXLTS	3247672068 Dell Way	\N	ICWXRHG	\N	0	Japan	2	GFNZQHXLTS@dell.com	3247672068	3	9331491924822332	2009/07	user15524	password	90	80000	F
15525	AJELZK	RMKHTHSMAA	7895601826 Dell Way	\N	PWXGEEW	\N	0	France	2	RMKHTHSMAA@dell.com	7895601826	5	7012211006600410	2009/10	user15525	password	43	60000	M
15526	SRGSCX	EMFYTXLUYB	9972309335 Dell Way	\N	QVIVAFG	\N	0	Russia	2	EMFYTXLUYB@dell.com	9972309335	5	2002038754522800	2011/04	user15526	password	63	80000	M
15527	HXRKVW	WAVQXGKVIB	1618304284 Dell Way	\N	RQXRVDM	\N	0	South Africa	2	WAVQXGKVIB@dell.com	1618304284	3	6555450077168644	2009/03	user15527	password	36	40000	M
15528	DAXYXT	YSKWZUSHWJ	1901472064 Dell Way	\N	YTBTWNO	\N	0	UK	2	YSKWZUSHWJ@dell.com	1901472064	1	3663795000407845	2009/06	user15528	password	63	100000	M
15529	QSNOMM	GWJGRBNNKL	9642958727 Dell Way	\N	GLFDZUC	\N	0	Australia	2	GWJGRBNNKL@dell.com	9642958727	2	4487462832126767	2009/01	user15529	password	32	100000	M
15530	XMFJZM	GISYJGLUSS	4272523023 Dell Way	\N	GYWFSZH	\N	0	Japan	2	GISYJGLUSS@dell.com	4272523023	4	1489766232203692	2009/11	user15530	password	19	20000	M
15531	NHEMUL	VMJETUYMNE	4265087185 Dell Way	\N	KJKCIRT	\N	0	Russia	2	VMJETUYMNE@dell.com	4265087185	5	1895968690980225	2009/11	user15531	password	30	20000	F
15532	LFVGQQ	TZVMUTYHYJ	1310870049 Dell Way	\N	RILAZFT	\N	0	China	2	TZVMUTYHYJ@dell.com	1310870049	5	6453895969316364	2012/01	user15532	password	64	40000	F
15533	VBSMRL	MMXGGWOEGG	8427787852 Dell Way	\N	NRGNXZW	\N	0	UK	2	MMXGGWOEGG@dell.com	8427787852	3	8286474043969066	2012/02	user15533	password	19	40000	M
15534	BZLTKX	GIDNFSSLYF	1315012431 Dell Way	\N	DESAEOZ	\N	0	Australia	2	GIDNFSSLYF@dell.com	1315012431	4	8487596347928048	2008/10	user15534	password	26	20000	M
15535	CNQNLX	WPKBHCNFHQ	4786253108 Dell Way	\N	KARPOQP	\N	0	Japan	2	WPKBHCNFHQ@dell.com	4786253108	3	7711721926927567	2009/07	user15535	password	79	20000	M
15536	JTEVQB	KBCRDQXLGI	9160003185 Dell Way	\N	LYXAOMQ	\N	0	UK	2	KBCRDQXLGI@dell.com	9160003185	2	2996140697505325	2010/03	user15536	password	41	20000	M
15537	BHKSIV	TLNXBKJISU	8147733463 Dell Way	\N	GQVVCLV	\N	0	Australia	2	TLNXBKJISU@dell.com	8147733463	1	5186867059208453	2008/05	user15537	password	59	60000	F
15538	WAEEVX	PIVRTEALZH	1000056162 Dell Way	\N	CUCFFYF	\N	0	Australia	2	PIVRTEALZH@dell.com	1000056162	4	1097964914049953	2009/03	user15538	password	62	100000	F
15539	PZGLXW	TSOMXOYWVA	1964804982 Dell Way	\N	QYFWXLW	\N	0	South Africa	2	TSOMXOYWVA@dell.com	1964804982	5	3530705084092915	2009/06	user15539	password	26	60000	F
15540	CSNAPG	TDTQSSNOSD	7746483758 Dell Way	\N	NYAKKWI	\N	0	France	2	TDTQSSNOSD@dell.com	7746483758	3	8582035309635104	2009/09	user15540	password	38	40000	M
15541	ZVVOCP	SWGLOTZHXN	8310707123 Dell Way	\N	GXXQUFD	\N	0	Germany	2	SWGLOTZHXN@dell.com	8310707123	5	7863994272891433	2010/03	user15541	password	24	40000	F
15542	XEVAUN	XAYLTYTRLZ	7238414332 Dell Way	\N	OJPJPSX	\N	0	France	2	XAYLTYTRLZ@dell.com	7238414332	4	9278835405129940	2012/09	user15542	password	36	20000	M
15543	LZRFNO	FMAZLTQWSF	2005421112 Dell Way	\N	GIOVBMG	\N	0	Russia	2	FMAZLTQWSF@dell.com	2005421112	1	7234625423327089	2012/05	user15543	password	81	60000	M
15544	WEBJTH	VTHGNXDGDJ	6446571522 Dell Way	\N	OSFQELJ	\N	0	Chile	2	VTHGNXDGDJ@dell.com	6446571522	1	2252604664769023	2008/12	user15544	password	64	100000	M
15545	VYEOFZ	IMGVKKCOUR	7653147666 Dell Way	\N	GZHLLRT	\N	0	Australia	2	IMGVKKCOUR@dell.com	7653147666	5	1522793721873313	2011/07	user15545	password	85	60000	F
15546	WQXBQG	OWCYGEMAVT	8479146081 Dell Way	\N	ACFLUYM	\N	0	Germany	2	OWCYGEMAVT@dell.com	8479146081	3	2732158025726676	2009/06	user15546	password	66	80000	F
15547	HPKYVY	UXWBCJCXCD	6725725456 Dell Way	\N	AHPUGCH	\N	0	Australia	2	UXWBCJCXCD@dell.com	6725725456	3	4943331931252033	2008/02	user15547	password	27	60000	F
15548	SVKOTF	MQHPZJMCNN	1987356757 Dell Way	\N	KCIQEPS	\N	0	South Africa	2	MQHPZJMCNN@dell.com	1987356757	1	9293692198581996	2009/04	user15548	password	44	80000	F
15549	FDPYIC	PPROZEQMRA	6133571037 Dell Way	\N	PZRTPKO	\N	0	Russia	2	PPROZEQMRA@dell.com	6133571037	3	9905108834616840	2012/11	user15549	password	71	100000	F
15550	WMZFOP	VGDUKUHCUW	6838193501 Dell Way	\N	CMQRWEK	\N	0	France	2	VGDUKUHCUW@dell.com	6838193501	2	3834388367831707	2010/02	user15550	password	33	60000	M
15551	SNEHCA	NGUYACAVYC	6273494878 Dell Way	\N	HOUETFP	\N	0	China	2	NGUYACAVYC@dell.com	6273494878	5	8899933450389654	2011/02	user15551	password	47	80000	M
15552	YXDBXQ	HROHTPCSSK	1901976981 Dell Way	\N	HMOAREK	\N	0	Chile	2	HROHTPCSSK@dell.com	1901976981	2	9807595688384028	2009/09	user15552	password	67	20000	M
15553	OERLVZ	DKGXAJPSUX	6337420418 Dell Way	\N	EJXWNID	\N	0	Japan	2	DKGXAJPSUX@dell.com	6337420418	1	8744093934074045	2009/10	user15553	password	86	100000	F
15554	DPVYOY	JVVJFLBZIG	4624498638 Dell Way	\N	IGDWOHM	\N	0	Canada	2	JVVJFLBZIG@dell.com	4624498638	2	4950960418675095	2009/04	user15554	password	43	60000	F
15555	YJJNIT	IECOPEOYLX	6403924793 Dell Way	\N	FOTTVGX	\N	0	Chile	2	IECOPEOYLX@dell.com	6403924793	2	4981018170714379	2012/09	user15555	password	18	40000	M
15556	JRESKN	WNBLRQKCNP	6449517313 Dell Way	\N	RGJNNGT	\N	0	Canada	2	WNBLRQKCNP@dell.com	6449517313	1	9998051618225874	2009/03	user15556	password	39	100000	M
15557	ZDGJQD	XSOOIZRVOI	7878837709 Dell Way	\N	CXVPEPS	\N	0	Russia	2	XSOOIZRVOI@dell.com	7878837709	4	1729846088215708	2012/01	user15557	password	21	60000	M
15558	EUJVXG	OMVWLNSAVV	9052036360 Dell Way	\N	XRLCGEW	\N	0	Australia	2	OMVWLNSAVV@dell.com	9052036360	5	9787981729023160	2012/12	user15558	password	54	100000	F
15559	HHZFOO	RKLDXDDTZA	9075345368 Dell Way	\N	KKCROZR	\N	0	France	2	RKLDXDDTZA@dell.com	9075345368	4	4501799323130399	2012/02	user15559	password	40	20000	F
15560	PAREOI	OZLLDOECPP	6433549297 Dell Way	\N	NSGCRYO	\N	0	Germany	2	OZLLDOECPP@dell.com	6433549297	5	5079810919240117	2011/04	user15560	password	53	40000	M
15561	NWACFO	CQAFFEIVUW	4896806585 Dell Way	\N	NAYFYMU	\N	0	Germany	2	CQAFFEIVUW@dell.com	4896806585	2	4006431804504246	2011/09	user15561	password	58	60000	F
15562	LOJQDL	HDRNIAICWW	2012106966 Dell Way	\N	DUCCHWQ	\N	0	Russia	2	HDRNIAICWW@dell.com	2012106966	5	4614053538069129	2012/07	user15562	password	86	20000	M
15563	MLQQXY	TOLCOUEKRH	9999764191 Dell Way	\N	FTJMPAF	\N	0	Russia	2	TOLCOUEKRH@dell.com	9999764191	4	6060281699988992	2010/07	user15563	password	66	60000	F
15564	CDRZCL	ONNCIRNZZS	1382797372 Dell Way	\N	SJFIKLA	\N	0	China	2	ONNCIRNZZS@dell.com	1382797372	3	9371253154706212	2010/04	user15564	password	50	80000	F
15565	PIJRTX	FGANYNMYGF	2166045790 Dell Way	\N	HMNSXOC	\N	0	UK	2	FGANYNMYGF@dell.com	2166045790	1	5895543804392219	2009/06	user15565	password	31	80000	F
15566	MCTGAY	MAMLOZJUER	5293507808 Dell Way	\N	HSJEGLD	\N	0	China	2	MAMLOZJUER@dell.com	5293507808	4	7744816937018187	2012/11	user15566	password	53	20000	F
15567	PTPPSC	PENDEXYJOF	2627897263 Dell Way	\N	BYJHKNR	\N	0	South Africa	2	PENDEXYJOF@dell.com	2627897263	3	8399323457852007	2008/11	user15567	password	78	40000	F
15568	PZBHCR	MPVQNTZBYB	4491887550 Dell Way	\N	AIIKWZH	\N	0	Australia	2	MPVQNTZBYB@dell.com	4491887550	1	1620713792741298	2009/12	user15568	password	51	80000	M
15569	LVVONH	DIYQCYSBZT	6022101087 Dell Way	\N	JHDGHLG	\N	0	Japan	2	DIYQCYSBZT@dell.com	6022101087	2	9523492983076722	2010/10	user15569	password	70	20000	F
15570	OWUCDY	KCPNAIOZBY	7899411577 Dell Way	\N	HEEOQLF	\N	0	Canada	2	KCPNAIOZBY@dell.com	7899411577	1	7272252385970206	2010/11	user15570	password	71	100000	F
15571	PPNTOY	VDLVLAVMYC	9874125251 Dell Way	\N	RCQIOVN	\N	0	China	2	VDLVLAVMYC@dell.com	9874125251	2	8888276947196574	2012/12	user15571	password	68	40000	M
15572	IVGWTC	AFXMFSYDUQ	7305709745 Dell Way	\N	GLZUGMC	\N	0	Chile	2	AFXMFSYDUQ@dell.com	7305709745	5	1907002934254706	2011/09	user15572	password	46	20000	M
15573	FLWYNW	DLIIDHMYYT	6627400208 Dell Way	\N	JXNQKQW	\N	0	Canada	2	DLIIDHMYYT@dell.com	6627400208	5	7757174758240581	2009/05	user15573	password	85	40000	M
15574	JENWAR	HJALQMKPFU	3606508019 Dell Way	\N	NTLXKIA	\N	0	Australia	2	HJALQMKPFU@dell.com	3606508019	4	3855878951493651	2011/09	user15574	password	62	40000	F
15575	UTYUKG	EKSVXDKDXY	6849137576 Dell Way	\N	WIVGQWG	\N	0	UK	2	EKSVXDKDXY@dell.com	6849137576	3	6396235771942884	2009/03	user15575	password	78	60000	M
15576	PJTAPY	KHTILDLIBI	4623224714 Dell Way	\N	RXOIUVG	\N	0	France	2	KHTILDLIBI@dell.com	4623224714	5	8058408258948476	2010/09	user15576	password	32	60000	F
15577	OIHDGS	LZAXDMFFUX	4059744866 Dell Way	\N	CJFXEMI	\N	0	Germany	2	LZAXDMFFUX@dell.com	4059744866	1	2614618287421763	2008/04	user15577	password	72	40000	M
15578	CPAIIM	IIJLVPRPMU	1926357062 Dell Way	\N	ZSRDEZT	\N	0	Germany	2	IIJLVPRPMU@dell.com	1926357062	5	5923410451505334	2010/08	user15578	password	81	40000	M
15579	MHBUTK	DCWYSNOEHN	3808711006 Dell Way	\N	WYRAYKO	\N	0	Australia	2	DCWYSNOEHN@dell.com	3808711006	1	5158250960987061	2012/12	user15579	password	71	80000	F
15580	ATFUEI	XAGPNUTVIP	3570588362 Dell Way	\N	UZQSKFU	\N	0	Russia	2	XAGPNUTVIP@dell.com	3570588362	2	7046371059026570	2009/12	user15580	password	45	80000	M
15581	DWTHER	IKGVFZRNPL	2354106829 Dell Way	\N	NGDXLXQ	\N	0	Russia	2	IKGVFZRNPL@dell.com	2354106829	2	9800034570507706	2008/08	user15581	password	64	20000	M
15582	MWCRNK	BTGHTXUJII	2248880086 Dell Way	\N	QMGCKWV	\N	0	Germany	2	BTGHTXUJII@dell.com	2248880086	4	7113282740116120	2011/06	user15582	password	75	60000	M
15583	QSPECR	YJYSHTCQBS	4779104334 Dell Way	\N	CHUNEQC	\N	0	Chile	2	YJYSHTCQBS@dell.com	4779104334	4	1820421516429633	2012/07	user15583	password	68	80000	F
15584	JJJMBI	WZADSCTUVW	3241979671 Dell Way	\N	CPKGGMO	\N	0	Japan	2	WZADSCTUVW@dell.com	3241979671	4	5581430071964860	2011/04	user15584	password	39	100000	M
15585	RJFSRB	SRELUYFPUI	7637554380 Dell Way	\N	FFOLRCC	\N	0	UK	2	SRELUYFPUI@dell.com	7637554380	3	7502727867569775	2008/11	user15585	password	70	80000	M
15586	CYHTAA	LFLFDRVYZA	2094599499 Dell Way	\N	DOLURNS	\N	0	China	2	LFLFDRVYZA@dell.com	2094599499	3	5060068008489907	2008/03	user15586	password	33	60000	F
15587	EXAEXL	KJRNANLANP	6122470388 Dell Way	\N	OZKFNDP	\N	0	Japan	2	KJRNANLANP@dell.com	6122470388	1	6718931349460036	2011/04	user15587	password	34	100000	F
15588	DAQAMA	JDNJRZJEOY	8102157330 Dell Way	\N	DYDQCTG	\N	0	Japan	2	JDNJRZJEOY@dell.com	8102157330	5	4478631139267236	2008/02	user15588	password	45	60000	F
15589	KDGWDQ	ARARQKVFIZ	8165987588 Dell Way	\N	EMQGFXX	\N	0	UK	2	ARARQKVFIZ@dell.com	8165987588	2	1390472317114472	2012/08	user15589	password	57	20000	F
15590	QLXUBX	LBOBLKHUJL	8913375399 Dell Way	\N	GZSLXPL	\N	0	Japan	2	LBOBLKHUJL@dell.com	8913375399	3	6456912662368268	2010/01	user15590	password	74	60000	M
15591	FMLGKW	IYYUIGOSRV	2501461094 Dell Way	\N	SKGPZRH	\N	0	South Africa	2	IYYUIGOSRV@dell.com	2501461094	5	4683817283250392	2008/08	user15591	password	90	100000	M
15592	MHDWEL	VDFEJUXBPP	4133851769 Dell Way	\N	LWELOMH	\N	0	Russia	2	VDFEJUXBPP@dell.com	4133851769	4	9059749324806036	2008/09	user15592	password	72	100000	F
15593	AZBFLX	IRCRLZSBOE	6290061349 Dell Way	\N	XTPMFWE	\N	0	Germany	2	IRCRLZSBOE@dell.com	6290061349	1	6184896715916694	2009/10	user15593	password	49	60000	M
15594	KOBVLJ	MOAYNTACXX	6684999288 Dell Way	\N	VNJBKOQ	\N	0	UK	2	MOAYNTACXX@dell.com	6684999288	2	3376283505000174	2010/08	user15594	password	72	40000	F
15595	HIXTRK	HSJVMJXKHT	6791198551 Dell Way	\N	XQUHFLG	\N	0	South Africa	2	HSJVMJXKHT@dell.com	6791198551	3	3571652147918940	2009/04	user15595	password	60	40000	M
15596	XHIPRQ	IALUKJFRCC	2256918536 Dell Way	\N	IXJNIQJ	\N	0	UK	2	IALUKJFRCC@dell.com	2256918536	4	3365682790521532	2010/03	user15596	password	63	100000	F
15597	XHSOYB	PKWZTBQWDZ	5354652610 Dell Way	\N	TNMCDVB	\N	0	Chile	2	PKWZTBQWDZ@dell.com	5354652610	2	7152441709302366	2011/12	user15597	password	65	100000	M
15598	YOKXQZ	HMZBNQXRPR	1957678969 Dell Way	\N	ECTIYUP	\N	0	France	2	HMZBNQXRPR@dell.com	1957678969	2	2038490159437060	2008/12	user15598	password	87	100000	M
15599	NGVDGD	PGEDWCVMUA	3172105926 Dell Way	\N	ONINIYX	\N	0	France	2	PGEDWCVMUA@dell.com	3172105926	1	5151173349004239	2008/12	user15599	password	41	20000	F
15600	PXQVAF	CFJZIELCEA	5309651333 Dell Way	\N	PMNXLLI	\N	0	Japan	2	CFJZIELCEA@dell.com	5309651333	5	8899282587226481	2010/02	user15600	password	89	100000	M
15601	XOOYUQ	DDPLIBOMCD	2991286749 Dell Way	\N	ZPBLBKC	\N	0	Germany	2	DDPLIBOMCD@dell.com	2991286749	5	9996363850776108	2009/12	user15601	password	87	20000	M
15602	NQUIGY	LWJUXXGZBG	7864609617 Dell Way	\N	PDRROUF	\N	0	Russia	2	LWJUXXGZBG@dell.com	7864609617	1	2096942320931703	2011/02	user15602	password	31	60000	M
15603	UJZBHL	XRFUPMURSJ	4795467146 Dell Way	\N	UJAIDFC	\N	0	UK	2	XRFUPMURSJ@dell.com	4795467146	2	6773648803122342	2010/06	user15603	password	35	40000	F
15604	PFHXQE	PWZEIUWADQ	3917389975 Dell Way	\N	KEZOKCL	\N	0	South Africa	2	PWZEIUWADQ@dell.com	3917389975	1	4454309928230941	2011/04	user15604	password	62	100000	M
15605	VGWLLL	HLQPFMQIDA	2238780383 Dell Way	\N	NDPXFBS	\N	0	Germany	2	HLQPFMQIDA@dell.com	2238780383	1	3577426474541426	2010/09	user15605	password	36	60000	M
15606	NHZYTH	JJXPWNYAOL	2632385411 Dell Way	\N	DDJJEBX	\N	0	China	2	JJXPWNYAOL@dell.com	2632385411	1	8199339898303152	2012/06	user15606	password	33	60000	M
15607	MLXFSH	PPXMDVNSGR	2347874696 Dell Way	\N	WPBBRYK	\N	0	South Africa	2	PPXMDVNSGR@dell.com	2347874696	1	7842270441818983	2011/05	user15607	password	32	60000	M
15608	QMDIUT	YRGCMTVTLS	4255344103 Dell Way	\N	JMUAKEX	\N	0	Germany	2	YRGCMTVTLS@dell.com	4255344103	4	2571875673253089	2011/11	user15608	password	72	80000	F
15609	GVVAOU	SUXFOSZZKI	9055568569 Dell Way	\N	LEJWJGL	\N	0	Russia	2	SUXFOSZZKI@dell.com	9055568569	4	5418097515590489	2011/05	user15609	password	30	40000	M
15610	ZBQNVI	ISOWLNVWVH	2630366253 Dell Way	\N	BFDKLOD	\N	0	China	2	ISOWLNVWVH@dell.com	2630366253	4	1713857947383076	2010/10	user15610	password	40	20000	M
15611	JTHECP	XQMIDIFZPG	4561206321 Dell Way	\N	ETRPIUY	\N	0	France	2	XQMIDIFZPG@dell.com	4561206321	1	1254519934765994	2008/04	user15611	password	29	100000	M
15612	XFWZVU	PIDTQISFPW	5077012302 Dell Way	\N	ZGMHALU	\N	0	France	2	PIDTQISFPW@dell.com	5077012302	5	6327787868212909	2011/12	user15612	password	56	60000	M
15613	TIVPCK	XFDOOWUDTT	6479137324 Dell Way	\N	JFAJRUU	\N	0	Canada	2	XFDOOWUDTT@dell.com	6479137324	2	9044272157363594	2010/11	user15613	password	43	60000	M
15614	RGHUQE	AUTORNRKHA	6012676253 Dell Way	\N	QHKHCEK	\N	0	Russia	2	AUTORNRKHA@dell.com	6012676253	2	3492305167485029	2010/08	user15614	password	68	20000	F
15615	XKCOPC	JJRAWIKDIB	1370018532 Dell Way	\N	LSIOXTG	\N	0	France	2	JJRAWIKDIB@dell.com	1370018532	3	9356379291508348	2011/03	user15615	password	22	20000	F
15616	MDSCGC	LXCHGNLOOW	2959850920 Dell Way	\N	HXLFQRR	\N	0	Japan	2	LXCHGNLOOW@dell.com	2959850920	3	4488526608794928	2010/08	user15616	password	48	60000	F
15617	OHFVJQ	SMYYAJNOGV	3487612362 Dell Way	\N	MRADJRV	\N	0	Germany	2	SMYYAJNOGV@dell.com	3487612362	2	1209533828776329	2012/08	user15617	password	62	20000	F
15618	XHAHYS	UWRUGFJMAV	1325622005 Dell Way	\N	EBZOTVD	\N	0	Australia	2	UWRUGFJMAV@dell.com	1325622005	1	9561672979500146	2011/10	user15618	password	19	100000	M
15619	HWZFPT	CGNIMWVNSA	8496247616 Dell Way	\N	OSOHNRI	\N	0	Germany	2	CGNIMWVNSA@dell.com	8496247616	2	3023862459231168	2010/04	user15619	password	24	40000	M
15620	YFVNZX	UMGHJCUCCJ	3314652209 Dell Way	\N	URRIJZW	\N	0	Canada	2	UMGHJCUCCJ@dell.com	3314652209	1	8057914828881622	2010/03	user15620	password	21	20000	F
15621	HZRGXM	TETDGNFJWA	3643623229 Dell Way	\N	BOIKNFP	\N	0	Russia	2	TETDGNFJWA@dell.com	3643623229	2	4009262729436159	2010/06	user15621	password	53	80000	M
15622	LGYJSS	NMVTAADXBE	5904392939 Dell Way	\N	LJOYPET	\N	0	South Africa	2	NMVTAADXBE@dell.com	5904392939	1	4152615624014288	2012/07	user15622	password	87	80000	F
15623	FQJYIX	KDRKEUHGZS	5428291112 Dell Way	\N	QORFSKC	\N	0	Chile	2	KDRKEUHGZS@dell.com	5428291112	3	3024530404713005	2008/05	user15623	password	83	20000	M
15624	NLOWIY	AZJEURLTKB	7919078761 Dell Way	\N	HBGZMIG	\N	0	UK	2	AZJEURLTKB@dell.com	7919078761	3	1312986110802739	2008/05	user15624	password	25	80000	M
15625	NHTWGT	VPYPHJJRKQ	4026094328 Dell Way	\N	TRQGAWF	\N	0	Russia	2	VPYPHJJRKQ@dell.com	4026094328	2	9370587690267712	2011/05	user15625	password	67	60000	M
15626	ZITFCP	VAFCKOTVEM	2820724424 Dell Way	\N	MUSMRYH	\N	0	Australia	2	VAFCKOTVEM@dell.com	2820724424	2	7360877487808467	2010/11	user15626	password	40	60000	M
15627	QEBTUX	UZZENTZSGM	5123459864 Dell Way	\N	NYZEXGE	\N	0	Canada	2	UZZENTZSGM@dell.com	5123459864	5	6986310992855579	2009/03	user15627	password	25	40000	M
15628	HHPBEJ	BDNOXNHDAU	9904598716 Dell Way	\N	CZYZGCC	\N	0	Russia	2	BDNOXNHDAU@dell.com	9904598716	4	1451275045052170	2008/11	user15628	password	36	20000	F
15629	NPGRYH	VMWSADWAXY	8134069293 Dell Way	\N	AWYHZAZ	\N	0	UK	2	VMWSADWAXY@dell.com	8134069293	1	2108725298661738	2011/04	user15629	password	27	100000	M
15630	SCMRJI	DGBEJXEHVF	5445831862 Dell Way	\N	DTMCUMA	\N	0	Germany	2	DGBEJXEHVF@dell.com	5445831862	1	3215785373002291	2011/04	user15630	password	24	60000	F
15631	EBROKU	ULYDJDKEIN	8393658041 Dell Way	\N	YVQTHRI	\N	0	Russia	2	ULYDJDKEIN@dell.com	8393658041	3	6055618159938604	2008/08	user15631	password	28	20000	M
15632	FUJPOD	BNGKRRPAFN	2185127477 Dell Way	\N	VVGDMOX	\N	0	China	2	BNGKRRPAFN@dell.com	2185127477	3	4874529414344579	2011/08	user15632	password	57	60000	M
15633	IYLWBM	KIWBZMBFAX	4655659541 Dell Way	\N	BGAOVYW	\N	0	UK	2	KIWBZMBFAX@dell.com	4655659541	2	7693078759592027	2008/10	user15633	password	41	100000	F
15634	GHAHTL	QQMPCOVCLW	5835761573 Dell Way	\N	JMKFKGE	\N	0	South Africa	2	QQMPCOVCLW@dell.com	5835761573	5	8498878251295538	2009/03	user15634	password	67	60000	F
15635	YOUSZK	IMALAVNMRX	2794013642 Dell Way	\N	YBCJIHE	\N	0	South Africa	2	IMALAVNMRX@dell.com	2794013642	1	3081922875717282	2010/09	user15635	password	72	100000	M
15636	HTIGER	TFCTAQGSNE	7585827610 Dell Way	\N	UQODXSZ	\N	0	Canada	2	TFCTAQGSNE@dell.com	7585827610	2	5953722489532084	2010/12	user15636	password	53	20000	F
15637	GJNKAG	PDAQTGJGLE	5581802936 Dell Way	\N	XAHUSHX	\N	0	France	2	PDAQTGJGLE@dell.com	5581802936	3	8882140824105591	2010/12	user15637	password	85	80000	F
15638	HGPINF	LNWEUFLGKI	5235200029 Dell Way	\N	GSDZZAL	\N	0	France	2	LNWEUFLGKI@dell.com	5235200029	2	9700697161722928	2010/03	user15638	password	69	80000	M
15639	YFWMKH	AGLVMXBWFI	1634457989 Dell Way	\N	OIHNITA	\N	0	South Africa	2	AGLVMXBWFI@dell.com	1634457989	5	3036053493153304	2009/09	user15639	password	78	100000	M
15640	ARDKZD	RLYDIAZNIN	1704144176 Dell Way	\N	VQBEJCZ	\N	0	France	2	RLYDIAZNIN@dell.com	1704144176	2	7851786135695875	2011/01	user15640	password	62	60000	F
15641	HNMHRE	SQHAQHNYVJ	7777207972 Dell Way	\N	PWOZZNK	\N	0	Australia	2	SQHAQHNYVJ@dell.com	7777207972	1	8323717681225390	2011/10	user15641	password	34	100000	F
15642	TJJLNB	BUBRBPQWYG	8151336814 Dell Way	\N	TMFSAQU	\N	0	Russia	2	BUBRBPQWYG@dell.com	8151336814	3	6235728214494885	2010/10	user15642	password	50	80000	M
15643	UAAHBB	CCTERKBQQU	8956350464 Dell Way	\N	DVNELHY	\N	0	Chile	2	CCTERKBQQU@dell.com	8956350464	3	8330075094942004	2011/12	user15643	password	52	40000	M
15644	MHBNJE	QCIINJYDEB	7208227365 Dell Way	\N	YSFKZEQ	\N	0	South Africa	2	QCIINJYDEB@dell.com	7208227365	3	6225616106297821	2011/12	user15644	password	80	60000	F
15645	DMXMRO	PZWCJUFOWE	6925826915 Dell Way	\N	GCPGGFD	\N	0	UK	2	PZWCJUFOWE@dell.com	6925826915	4	6325432318728418	2010/07	user15645	password	19	100000	M
15646	NXFELU	EHXOBDCYIJ	5065368648 Dell Way	\N	AXPGCTE	\N	0	Russia	2	EHXOBDCYIJ@dell.com	5065368648	4	4068439950700849	2008/10	user15646	password	40	80000	F
15647	FYMQTR	XQFZUIXCRX	1805751249 Dell Way	\N	ZHDCAIW	\N	0	France	2	XQFZUIXCRX@dell.com	1805751249	2	5465191481634975	2012/07	user15647	password	34	20000	M
15648	ERIXIG	OOFIWDLOAL	6644014456 Dell Way	\N	VEOWMKI	\N	0	Germany	2	OOFIWDLOAL@dell.com	6644014456	5	5154307506047189	2008/01	user15648	password	64	100000	F
15649	HFDQLR	ERABVMPVXL	5202738347 Dell Way	\N	AMHNXQC	\N	0	Germany	2	ERABVMPVXL@dell.com	5202738347	3	6933351295534522	2010/03	user15649	password	56	80000	F
15650	TWDEOH	WPIRBYNZJN	7196963621 Dell Way	\N	LRAIHDW	\N	0	Russia	2	WPIRBYNZJN@dell.com	7196963621	3	3683988924603909	2012/01	user15650	password	21	40000	M
15651	YNYMUV	CDNECADLOP	3855742913 Dell Way	\N	DPYLSUF	\N	0	France	2	CDNECADLOP@dell.com	3855742913	3	3700389023404568	2009/07	user15651	password	67	20000	F
15652	ECZZXB	DKGFLKRAAU	9458786739 Dell Way	\N	PYGITLT	\N	0	Australia	2	DKGFLKRAAU@dell.com	9458786739	1	4852940045762807	2010/09	user15652	password	58	100000	M
15653	QYXNAA	YGGKQXKQSA	2033218231 Dell Way	\N	PYIJJBL	\N	0	China	2	YGGKQXKQSA@dell.com	2033218231	5	8281312434468419	2012/05	user15653	password	75	80000	F
15654	TQPTQO	AXYRUJIMJY	6395354595 Dell Way	\N	LRHVTTD	\N	0	South Africa	2	AXYRUJIMJY@dell.com	6395354595	5	7358142300974578	2008/09	user15654	password	50	20000	F
15655	CQFTEG	QDXKMGXVEJ	3187740677 Dell Way	\N	NMEGFHD	\N	0	South Africa	2	QDXKMGXVEJ@dell.com	3187740677	5	8381983605213464	2012/04	user15655	password	82	60000	F
15656	NQCSWS	VUDHABDFKQ	8836182161 Dell Way	\N	ROXXWAS	\N	0	Canada	2	VUDHABDFKQ@dell.com	8836182161	3	1784920732490718	2008/05	user15656	password	55	60000	M
15657	EQQBJL	VNTWOXCZNU	8857043444 Dell Way	\N	OLRLMJO	\N	0	China	2	VNTWOXCZNU@dell.com	8857043444	4	5495492334011942	2009/02	user15657	password	20	20000	F
15658	RVJAHE	OBBCYDCMYQ	3491457308 Dell Way	\N	XPCJYQS	\N	0	South Africa	2	OBBCYDCMYQ@dell.com	3491457308	2	1787781983148306	2010/04	user15658	password	38	80000	M
15659	CCYJHM	KJPINSVLJS	1531755589 Dell Way	\N	ALCYBVU	\N	0	China	2	KJPINSVLJS@dell.com	1531755589	5	8019303801469506	2009/02	user15659	password	56	40000	F
15660	PEPXRA	GGJTZEEIXE	8188677472 Dell Way	\N	TADVVYE	\N	0	UK	2	GGJTZEEIXE@dell.com	8188677472	5	2903498027939349	2012/06	user15660	password	49	20000	F
15661	PUZHUG	ODZNHEVEJP	5933023505 Dell Way	\N	FNKBLPY	\N	0	Chile	2	ODZNHEVEJP@dell.com	5933023505	1	2555909451097250	2008/08	user15661	password	43	20000	F
15662	DCMXJA	BINIMJNVYS	8710029200 Dell Way	\N	IJTUYSA	\N	0	France	2	BINIMJNVYS@dell.com	8710029200	1	5723608980420977	2010/07	user15662	password	65	80000	M
15663	TDOCDP	LRYYAMTZEC	1532935698 Dell Way	\N	IYWHRWU	\N	0	Germany	2	LRYYAMTZEC@dell.com	1532935698	2	9677673527970912	2010/12	user15663	password	62	40000	M
15664	TUVWKG	OIEPUYOZBX	3813723590 Dell Way	\N	YYFPVZD	\N	0	South Africa	2	OIEPUYOZBX@dell.com	3813723590	1	5113882458768785	2009/09	user15664	password	68	100000	F
15665	MUIXBW	FGMAEAAGYY	8028639401 Dell Way	\N	EEOZERW	\N	0	France	2	FGMAEAAGYY@dell.com	8028639401	2	7688048020936549	2010/12	user15665	password	71	100000	F
15666	NGJPCP	VOQAPQGOPK	5851774235 Dell Way	\N	SEKWWGJ	\N	0	Japan	2	VOQAPQGOPK@dell.com	5851774235	1	2083435541950166	2010/10	user15666	password	20	20000	F
15667	HKYJAU	YQUOHBDWMV	2476921580 Dell Way	\N	BWSXCBO	\N	0	Japan	2	YQUOHBDWMV@dell.com	2476921580	4	2457978043705225	2012/09	user15667	password	31	40000	M
15668	PHJPCI	GXWNYZKKVL	5970661959 Dell Way	\N	GOJJQXZ	\N	0	Russia	2	GXWNYZKKVL@dell.com	5970661959	1	8064237080514432	2009/04	user15668	password	27	40000	M
15669	LPNNXU	LUIJUSUPEB	5546220772 Dell Way	\N	ENKUKJP	\N	0	UK	2	LUIJUSUPEB@dell.com	5546220772	2	3027191147673875	2012/07	user15669	password	50	80000	M
15670	AHMYBX	SKHMDBCHDG	1530331362 Dell Way	\N	VNBGXRF	\N	0	China	2	SKHMDBCHDG@dell.com	1530331362	3	2995128775481134	2010/11	user15670	password	89	60000	M
15671	GAWIYO	TFBWHDDKKZ	8838978331 Dell Way	\N	XMFUDLE	\N	0	Chile	2	TFBWHDDKKZ@dell.com	8838978331	3	8037295221351088	2011/05	user15671	password	41	80000	M
15672	IOZGDT	MEPTITDTSB	4994352068 Dell Way	\N	FXWJIAO	\N	0	Chile	2	MEPTITDTSB@dell.com	4994352068	2	9802222486119718	2012/08	user15672	password	67	60000	M
15673	GMGJFT	OUMXNQQFRW	1954543001 Dell Way	\N	DNFMOTS	\N	0	Australia	2	OUMXNQQFRW@dell.com	1954543001	4	8477633307687939	2011/05	user15673	password	40	80000	M
15674	UAYZTN	UFKIWBNNXR	5623366967 Dell Way	\N	BDDPXVP	\N	0	UK	2	UFKIWBNNXR@dell.com	5623366967	3	7812082091346384	2012/10	user15674	password	55	60000	M
15675	NKNHXI	NIQJKEXIVY	6428445166 Dell Way	\N	LZOIVEI	\N	0	China	2	NIQJKEXIVY@dell.com	6428445166	1	2744830319192260	2009/08	user15675	password	64	100000	F
15676	ALKYTX	HJHRNEAJCL	2424088039 Dell Way	\N	IQTEVCM	\N	0	France	2	HJHRNEAJCL@dell.com	2424088039	4	7954856936354191	2011/04	user15676	password	66	100000	F
15677	CHHVEP	FLHTPHCSTL	7954303793 Dell Way	\N	JMPEPCP	\N	0	Russia	2	FLHTPHCSTL@dell.com	7954303793	2	5397272253874690	2008/01	user15677	password	44	60000	F
15678	QTZUIF	GQYWXAPQMY	1989812361 Dell Way	\N	DBDSETL	\N	0	UK	2	GQYWXAPQMY@dell.com	1989812361	5	1181164799723774	2008/04	user15678	password	51	40000	M
15679	FGTOMZ	EKWBLLSXKV	9708662484 Dell Way	\N	ZOODHAB	\N	0	France	2	EKWBLLSXKV@dell.com	9708662484	1	6033026307355613	2009/07	user15679	password	79	40000	M
15680	CYHOYM	ZVNKHGIRCH	6226832446 Dell Way	\N	GQLORNY	\N	0	Japan	2	ZVNKHGIRCH@dell.com	6226832446	3	9103767698165030	2008/05	user15680	password	25	100000	F
15681	BEBZQA	UELBLUTNCA	1398031289 Dell Way	\N	DNOVANL	\N	0	Japan	2	UELBLUTNCA@dell.com	1398031289	2	7542679320555181	2010/06	user15681	password	62	100000	F
15682	UYMLZH	QLJBFCOHDS	3821095930 Dell Way	\N	URNVFZK	\N	0	Chile	2	QLJBFCOHDS@dell.com	3821095930	1	6985413907095791	2011/10	user15682	password	58	40000	M
15683	NSAMAQ	XJSCLHKPAF	6239257486 Dell Way	\N	GOAMNLT	\N	0	South Africa	2	XJSCLHKPAF@dell.com	6239257486	2	6284347376786173	2009/12	user15683	password	78	100000	F
15684	OXYONW	XGZJNJZNOG	8625587879 Dell Way	\N	BOSPZLK	\N	0	Germany	2	XGZJNJZNOG@dell.com	8625587879	5	9274374602362514	2012/11	user15684	password	77	40000	F
15685	SFZGBW	MAGZJFNXMP	6177004051 Dell Way	\N	MEEMQPB	\N	0	France	2	MAGZJFNXMP@dell.com	6177004051	5	3465830930508673	2010/10	user15685	password	56	100000	M
15686	TTTUQF	UXFEDTCPIP	1943352503 Dell Way	\N	UMBKBDW	\N	0	Japan	2	UXFEDTCPIP@dell.com	1943352503	1	1503269436303526	2012/09	user15686	password	80	60000	F
15687	QDFHJA	FPFJIHYRWT	2778944250 Dell Way	\N	EYEGBBW	\N	0	Canada	2	FPFJIHYRWT@dell.com	2778944250	5	1540774685330689	2012/10	user15687	password	51	40000	F
15688	PNSZOX	OTGXAFOXZT	8055719750 Dell Way	\N	VDZXEWB	\N	0	China	2	OTGXAFOXZT@dell.com	8055719750	1	3255092408508062	2010/07	user15688	password	59	20000	F
15689	CSDQQS	JXQKCFHCYD	2673589351 Dell Way	\N	FXAJTBS	\N	0	Germany	2	JXQKCFHCYD@dell.com	2673589351	5	2017057373188436	2011/07	user15689	password	26	100000	M
15690	VCHMUR	JLBMQJOONT	8485463078 Dell Way	\N	LODFQWT	\N	0	South Africa	2	JLBMQJOONT@dell.com	8485463078	5	6025712987873704	2009/12	user15690	password	53	20000	M
15691	OHHJYR	UADKKRZXLL	3000295581 Dell Way	\N	LPQBLJW	\N	0	Chile	2	UADKKRZXLL@dell.com	3000295581	3	6743294675368816	2008/12	user15691	password	65	20000	F
15692	YHWXYR	YCCIUBGFMS	1667637882 Dell Way	\N	UDTFNQM	\N	0	Russia	2	YCCIUBGFMS@dell.com	1667637882	1	9325291018001736	2012/10	user15692	password	85	60000	M
15693	FJQEAO	GCXAEDGRVB	9074101770 Dell Way	\N	UPHIGTB	\N	0	China	2	GCXAEDGRVB@dell.com	9074101770	5	3797652585897595	2011/11	user15693	password	76	60000	F
15694	EBHEPO	HMOLQUCLVX	3112338547 Dell Way	\N	BDFHWGP	\N	0	Russia	2	HMOLQUCLVX@dell.com	3112338547	5	5158163303043694	2008/09	user15694	password	81	40000	M
15695	XOBNCI	AQURLWCHUE	1062164975 Dell Way	\N	KAMHHCC	\N	0	Germany	2	AQURLWCHUE@dell.com	1062164975	3	6839542636182160	2011/05	user15695	password	84	80000	F
15696	LRWOZX	ETOQQRYLVI	3331383380 Dell Way	\N	LHQSJSG	\N	0	China	2	ETOQQRYLVI@dell.com	3331383380	5	2086704714689403	2011/10	user15696	password	71	20000	F
15697	KWUJTZ	DHPUZOFUXR	5781456094 Dell Way	\N	CNKMGQW	\N	0	Germany	2	DHPUZOFUXR@dell.com	5781456094	5	2634766991250217	2009/09	user15697	password	31	60000	F
15698	BJMVIQ	DYKCMQXKHZ	3814757116 Dell Way	\N	XSLEIIR	\N	0	South Africa	2	DYKCMQXKHZ@dell.com	3814757116	5	2763786789495498	2008/01	user15698	password	74	20000	F
15699	DQYMGB	LRDYIAIQAG	9538964203 Dell Way	\N	IMKQUCN	\N	0	Canada	2	LRDYIAIQAG@dell.com	9538964203	4	2292266942095011	2012/06	user15699	password	38	20000	M
15700	XACECO	WGMEHVUHBC	9876975068 Dell Way	\N	UMTOOHR	\N	0	Germany	2	WGMEHVUHBC@dell.com	9876975068	5	5615711058489979	2010/02	user15700	password	63	20000	F
15701	RFFTTB	ZGGHBAPDDJ	5086304769 Dell Way	\N	PXYEEQS	\N	0	Canada	2	ZGGHBAPDDJ@dell.com	5086304769	2	6640651536174119	2010/10	user15701	password	71	80000	F
15702	YVGSWG	ZDNAECEHLU	8802792142 Dell Way	\N	EKZJARN	\N	0	France	2	ZDNAECEHLU@dell.com	8802792142	1	1343297717161476	2011/11	user15702	password	64	20000	M
15703	LKNIQM	LENQGSXSMC	1987088641 Dell Way	\N	CLMDCZP	\N	0	UK	2	LENQGSXSMC@dell.com	1987088641	4	6934477881994099	2012/04	user15703	password	79	80000	M
15704	GHBXUN	BIDIABAMDD	5432302301 Dell Way	\N	XPHAPWZ	\N	0	Japan	2	BIDIABAMDD@dell.com	5432302301	4	6985014157369734	2011/06	user15704	password	50	60000	M
15705	TOQOBR	WEZWFAIJEG	9070561166 Dell Way	\N	ZLHOHGG	\N	0	Russia	2	WEZWFAIJEG@dell.com	9070561166	5	6046673072502018	2009/05	user15705	password	21	20000	F
15706	PSRQKN	VKJAKSKPYJ	1467088674 Dell Way	\N	BGXIMDD	\N	0	China	2	VKJAKSKPYJ@dell.com	1467088674	4	7830876719672234	2010/09	user15706	password	80	60000	F
15707	PEZZRU	JBUUTFKSOL	6581073840 Dell Way	\N	YMULQXV	\N	0	Japan	2	JBUUTFKSOL@dell.com	6581073840	3	1701678811572492	2009/06	user15707	password	61	80000	F
15708	TRALLJ	MGEGLOZAZX	7750123503 Dell Way	\N	MTJCREU	\N	0	China	2	MGEGLOZAZX@dell.com	7750123503	5	7059080848935992	2008/06	user15708	password	45	40000	F
15709	BFRMPE	TTKEIJEIHR	4492726285 Dell Way	\N	CQTUVOC	\N	0	Germany	2	TTKEIJEIHR@dell.com	4492726285	4	7855998536571861	2012/02	user15709	password	88	20000	F
15710	ESQUWJ	OGOWQTFYKH	9068233964 Dell Way	\N	PEBKSDZ	\N	0	Canada	2	OGOWQTFYKH@dell.com	9068233964	4	9485731134656818	2008/09	user15710	password	89	20000	M
15711	RVROFG	UUCLNHKYPZ	2507684498 Dell Way	\N	DQKWUKZ	\N	0	Japan	2	UUCLNHKYPZ@dell.com	2507684498	5	7422051907051355	2012/11	user15711	password	84	100000	M
15712	TMDZTY	TVJHDUGSUJ	2126768791 Dell Way	\N	JFGEPFW	\N	0	Russia	2	TVJHDUGSUJ@dell.com	2126768791	3	7058985844254494	2008/06	user15712	password	53	80000	F
15713	ZSFSRY	OAGSVMLPWU	4737844445 Dell Way	\N	UCZKIVE	\N	0	France	2	OAGSVMLPWU@dell.com	4737844445	5	5118566622491926	2012/05	user15713	password	22	20000	F
15714	UIALGP	MNHHZSXVNR	2260849129 Dell Way	\N	YMCGIHR	\N	0	Russia	2	MNHHZSXVNR@dell.com	2260849129	1	6735892549622805	2010/03	user15714	password	73	100000	M
15715	BVLILX	VSFVKCRYUP	7062872800 Dell Way	\N	KXWTENM	\N	0	China	2	VSFVKCRYUP@dell.com	7062872800	1	8136213006917388	2012/11	user15715	password	61	100000	M
15716	LHHWFD	OLZZNQXIGI	6807668563 Dell Way	\N	FCBKQNS	\N	0	China	2	OLZZNQXIGI@dell.com	6807668563	3	2615013695321977	2010/02	user15716	password	21	60000	M
15717	JTJOXY	ZWXNNVVTDB	6815094447 Dell Way	\N	WELMSDU	\N	0	China	2	ZWXNNVVTDB@dell.com	6815094447	5	8799828129354865	2011/01	user15717	password	42	40000	F
15718	CQXAOX	XMLKHHEKIA	3047274870 Dell Way	\N	OUMGYGP	\N	0	Germany	2	XMLKHHEKIA@dell.com	3047274870	3	3895024832338095	2009/10	user15718	password	59	60000	M
15719	FNYTLV	FWGMDKWMKL	8164256772 Dell Way	\N	GXSFDIU	\N	0	China	2	FWGMDKWMKL@dell.com	8164256772	1	6529525496065617	2011/09	user15719	password	33	60000	M
15720	SMQDIW	AOIDYFPJRW	9956422552 Dell Way	\N	GJCKSWU	\N	0	France	2	AOIDYFPJRW@dell.com	9956422552	2	1929905269294977	2011/08	user15720	password	64	60000	F
15721	DFLLBM	AKPYQFIHCO	2048021954 Dell Way	\N	REYJBSV	\N	0	Australia	2	AKPYQFIHCO@dell.com	2048021954	5	7659418708644808	2011/08	user15721	password	40	20000	M
15722	NMEOYE	ZODPTLWWZO	7161429678 Dell Way	\N	BYXCRTE	\N	0	Russia	2	ZODPTLWWZO@dell.com	7161429678	5	5539297827985138	2009/03	user15722	password	56	100000	M
15723	ADHZHH	NKWHWTDWHE	4184964954 Dell Way	\N	UEHMXLG	\N	0	Japan	2	NKWHWTDWHE@dell.com	4184964954	4	8879754475317896	2010/04	user15723	password	81	40000	F
15724	APHIWU	TTCPMGLTLG	7826688517 Dell Way	\N	YSSWEZM	\N	0	Germany	2	TTCPMGLTLG@dell.com	7826688517	2	1828949721530079	2008/03	user15724	password	45	40000	F
15725	ZRNVMH	OOWBUIVFOT	4922535880 Dell Way	\N	YHQDGCQ	\N	0	Australia	2	OOWBUIVFOT@dell.com	4922535880	4	1730391808785498	2011/02	user15725	password	51	100000	F
15726	DKYPRM	ENOYVJEKDD	6740278539 Dell Way	\N	RTGYWXY	\N	0	Chile	2	ENOYVJEKDD@dell.com	6740278539	1	9343159404117616	2011/06	user15726	password	75	100000	M
15727	EUFVGK	JVJFENPHRH	2797238055 Dell Way	\N	BXFXVEE	\N	0	France	2	JVJFENPHRH@dell.com	2797238055	1	2859904302749783	2011/11	user15727	password	22	40000	F
15728	VOXCYG	XHMCVBJNJL	6675487266 Dell Way	\N	KOIFSNR	\N	0	UK	2	XHMCVBJNJL@dell.com	6675487266	5	6617036018520594	2010/12	user15728	password	87	80000	M
15729	NNWLUU	TGWPIGCRRN	3535653126 Dell Way	\N	GATZNKX	\N	0	Canada	2	TGWPIGCRRN@dell.com	3535653126	3	7087147727143020	2009/06	user15729	password	38	100000	M
15730	UWLOQE	UMUDTWVKJB	4883674548 Dell Way	\N	KCAYNXC	\N	0	Russia	2	UMUDTWVKJB@dell.com	4883674548	4	1034803065937012	2012/01	user15730	password	90	100000	M
15731	VHJMME	ZGISCDDMEO	3746996663 Dell Way	\N	PEMCCOW	\N	0	Germany	2	ZGISCDDMEO@dell.com	3746996663	5	4906901250593364	2009/11	user15731	password	40	20000	M
15732	PNECSE	IAXLDAXHOM	3831080064 Dell Way	\N	MBOPPLD	\N	0	South Africa	2	IAXLDAXHOM@dell.com	3831080064	3	3075791224371642	2008/11	user15732	password	45	100000	F
15733	XBOPGW	PDHSDFASSN	7994088828 Dell Way	\N	TGCISFG	\N	0	Australia	2	PDHSDFASSN@dell.com	7994088828	3	2771461712662130	2011/11	user15733	password	23	20000	M
15734	ERIKNY	NVQRARJSED	2374575135 Dell Way	\N	ZGLSMRS	\N	0	Chile	2	NVQRARJSED@dell.com	2374575135	5	9114053932018580	2012/12	user15734	password	18	80000	F
15735	RBNEZB	AQSBHCTMFT	1665954813 Dell Way	\N	TRLFJEM	\N	0	Germany	2	AQSBHCTMFT@dell.com	1665954813	2	5489319100044668	2008/05	user15735	password	34	40000	F
15736	HTGHUG	YNHFPBSVVL	5707936640 Dell Way	\N	MHRVLDI	\N	0	Germany	2	YNHFPBSVVL@dell.com	5707936640	5	6287541271653027	2012/01	user15736	password	76	100000	F
15737	OFQJMO	WUUMWMHRYT	7802365332 Dell Way	\N	ZPPKTYY	\N	0	Chile	2	WUUMWMHRYT@dell.com	7802365332	3	2546319128945470	2012/04	user15737	password	28	20000	M
15738	JVFWKC	QEOMRWEPQD	1445284092 Dell Way	\N	FFOYDNE	\N	0	UK	2	QEOMRWEPQD@dell.com	1445284092	2	7471157119143755	2009/07	user15738	password	83	40000	M
15739	SMSCOJ	HDVYZAOQET	2981271632 Dell Way	\N	VTRZHWX	\N	0	China	2	HDVYZAOQET@dell.com	2981271632	4	7295014764182270	2011/07	user15739	password	87	60000	F
15740	LIIZRP	DNODNCTSWP	1715537462 Dell Way	\N	LNPTKMB	\N	0	Japan	2	DNODNCTSWP@dell.com	1715537462	4	4001729292795062	2010/09	user15740	password	85	80000	F
15741	GCDXSH	KGKYJEQFTC	6819449697 Dell Way	\N	SJVCVXS	\N	0	South Africa	2	KGKYJEQFTC@dell.com	6819449697	1	5318489564117044	2009/12	user15741	password	38	60000	F
15742	KQDCXN	JHMSMCXFFP	5556030822 Dell Way	\N	OBSKYLH	\N	0	Germany	2	JHMSMCXFFP@dell.com	5556030822	4	9505151388235392	2010/01	user15742	password	49	80000	F
15743	BVNYJW	GVOSYMYDBN	9753023363 Dell Way	\N	EUXDGFS	\N	0	Russia	2	GVOSYMYDBN@dell.com	9753023363	4	3182180366013199	2008/02	user15743	password	87	60000	F
15744	UZDDWJ	YLCWXBAZOF	7792346267 Dell Way	\N	UMJARCU	\N	0	Japan	2	YLCWXBAZOF@dell.com	7792346267	1	7067207422573120	2012/12	user15744	password	27	20000	M
15745	DDXZNW	LQTIRTIGZC	9163540554 Dell Way	\N	SICKKXB	\N	0	Canada	2	LQTIRTIGZC@dell.com	9163540554	4	1191235388163477	2012/11	user15745	password	21	80000	M
15746	FNZSJK	JCTAWBGVDZ	2335269881 Dell Way	\N	EGJODKS	\N	0	Australia	2	JCTAWBGVDZ@dell.com	2335269881	4	9430337747558952	2008/10	user15746	password	59	100000	M
15747	CYSMJB	OCCLDIHHHL	5299695354 Dell Way	\N	ORASCTU	\N	0	Chile	2	OCCLDIHHHL@dell.com	5299695354	4	3259001422207803	2009/04	user15747	password	35	40000	F
15748	EZVOBK	QDWUMDCUOR	8729457387 Dell Way	\N	LPJOIDU	\N	0	Russia	2	QDWUMDCUOR@dell.com	8729457387	1	1564479734282940	2008/04	user15748	password	42	60000	F
15749	IIAJTQ	MPLZTOTHFE	6094879367 Dell Way	\N	WOTFSNZ	\N	0	Germany	2	MPLZTOTHFE@dell.com	6094879367	1	7409856250509620	2012/05	user15749	password	34	40000	M
15750	OIBIZO	XKNQYGYELV	1487723880 Dell Way	\N	SEALSAA	\N	0	Chile	2	XKNQYGYELV@dell.com	1487723880	4	2007778350729495	2010/12	user15750	password	48	20000	M
15751	TEVSTT	DGJCNIGYEZ	2464542331 Dell Way	\N	DEKVFLC	\N	0	Chile	2	DGJCNIGYEZ@dell.com	2464542331	2	7092698420397938	2008/08	user15751	password	76	80000	F
15752	ZLCSEG	YOIMXPKBOO	7106004268 Dell Way	\N	GZJLLMR	\N	0	Germany	2	YOIMXPKBOO@dell.com	7106004268	2	7303281085100026	2009/02	user15752	password	41	80000	F
15753	TUVYAU	MJGJYRLNFR	1859189754 Dell Way	\N	NOCYATN	\N	0	Russia	2	MJGJYRLNFR@dell.com	1859189754	2	1244989015161991	2009/07	user15753	password	70	40000	F
15754	MFGNZS	WFCVXNICEV	5708885916 Dell Way	\N	RGUSAHK	\N	0	Canada	2	WFCVXNICEV@dell.com	5708885916	3	4147856002207846	2008/02	user15754	password	70	40000	M
15755	XPEXIB	DLWAZECEAT	3893842426 Dell Way	\N	LUMLCWO	\N	0	Japan	2	DLWAZECEAT@dell.com	3893842426	5	7053194322157652	2010/08	user15755	password	21	20000	M
15756	QHKZJN	LFNKJQOKKZ	8796569568 Dell Way	\N	EWLGTZW	\N	0	Australia	2	LFNKJQOKKZ@dell.com	8796569568	3	5861246137879789	2010/08	user15756	password	67	100000	F
15757	ZKFIXR	NLBXCQIMQM	2471878256 Dell Way	\N	IBTCAQD	\N	0	South Africa	2	NLBXCQIMQM@dell.com	2471878256	4	4195797504391521	2011/05	user15757	password	43	100000	F
15758	TFRRWF	CYDEOLREYA	9102169793 Dell Way	\N	FRCGHFD	\N	0	France	2	CYDEOLREYA@dell.com	9102169793	3	2944883297663182	2009/10	user15758	password	32	60000	M
15759	KGFHMI	FPNUAEYYEE	1122765921 Dell Way	\N	QGKXMOK	\N	0	China	2	FPNUAEYYEE@dell.com	1122765921	4	6603042376693339	2012/10	user15759	password	33	40000	F
15760	MPMYXS	NKMNPLMTQC	1018594091 Dell Way	\N	ZBAMPKV	\N	0	Japan	2	NKMNPLMTQC@dell.com	1018594091	3	4931695075239986	2012/09	user15760	password	78	20000	F
15761	LNCJGP	USDJEPCUSC	8657281192 Dell Way	\N	VSOLCKB	\N	0	Australia	2	USDJEPCUSC@dell.com	8657281192	3	9146608925424516	2010/04	user15761	password	85	80000	M
15762	LTCRJW	KNFOCIJULF	2449569800 Dell Way	\N	NAQPKRS	\N	0	Chile	2	KNFOCIJULF@dell.com	2449569800	4	7946385170798750	2010/07	user15762	password	49	40000	M
15763	EHROEB	BJQESAZDFM	4398385459 Dell Way	\N	EWCOOUV	\N	0	Russia	2	BJQESAZDFM@dell.com	4398385459	3	2531391303054988	2012/01	user15763	password	45	100000	F
15764	ROTVQV	FHZYHYBMLG	2630082588 Dell Way	\N	JNUXHPP	\N	0	Japan	2	FHZYHYBMLG@dell.com	2630082588	4	6160075960215182	2008/02	user15764	password	52	60000	M
15765	AEQRZW	YYUFXWSICB	4142002621 Dell Way	\N	WWZDMOU	\N	0	Japan	2	YYUFXWSICB@dell.com	4142002621	2	8674741446971894	2010/11	user15765	password	37	40000	M
15766	LYOKUM	JOSHKLQNNM	8059629288 Dell Way	\N	JMPWBKN	\N	0	France	2	JOSHKLQNNM@dell.com	8059629288	2	9077557809650900	2011/08	user15766	password	33	60000	F
15767	DBLYNV	NGCYRSLEEV	5688631352 Dell Way	\N	QURSFEC	\N	0	UK	2	NGCYRSLEEV@dell.com	5688631352	5	6434336094185711	2008/03	user15767	password	25	20000	F
15768	DQHRLV	XNTOFFSKAJ	2273044790 Dell Way	\N	ESBJWDJ	\N	0	China	2	XNTOFFSKAJ@dell.com	2273044790	5	5663322003558279	2009/01	user15768	password	68	80000	F
15769	IZWTVU	HPIMUBXVKC	7855716975 Dell Way	\N	NMLJQUT	\N	0	Russia	2	HPIMUBXVKC@dell.com	7855716975	2	1902746071573347	2012/12	user15769	password	75	20000	F
15770	UXAPRH	EAUZBSUMUH	7123261634 Dell Way	\N	YFROAKI	\N	0	Russia	2	EAUZBSUMUH@dell.com	7123261634	3	6570718937553466	2011/03	user15770	password	65	100000	F
15771	OYPFGU	GBTHTNUNVT	1617550634 Dell Way	\N	TMHUWQP	\N	0	Germany	2	GBTHTNUNVT@dell.com	1617550634	2	2851215797942132	2009/11	user15771	password	27	40000	F
15772	CXQJSW	KLEEZYSURM	1573014389 Dell Way	\N	HZGDQWS	\N	0	Japan	2	KLEEZYSURM@dell.com	1573014389	5	9874235682655128	2012/01	user15772	password	38	40000	F
15773	FYMXVX	JZCIYUDQGK	2577234974 Dell Way	\N	PNOGJGY	\N	0	France	2	JZCIYUDQGK@dell.com	2577234974	5	4069244496058673	2009/03	user15773	password	66	40000	F
15774	QWHLTQ	LVZKQDAWNQ	7501301598 Dell Way	\N	JBWSIUD	\N	0	Germany	2	LVZKQDAWNQ@dell.com	7501301598	3	7545980273280293	2012/02	user15774	password	24	40000	M
15775	YQGSHS	OHCEKCBXTL	8095155121 Dell Way	\N	ZPDHKHU	\N	0	Canada	2	OHCEKCBXTL@dell.com	8095155121	3	1567245280370116	2012/08	user15775	password	46	80000	M
15776	AZHIRV	PTAZWBWPMW	5400873303 Dell Way	\N	FQDQYYT	\N	0	Russia	2	PTAZWBWPMW@dell.com	5400873303	5	7090393388643861	2008/03	user15776	password	48	80000	F
15777	KZOBUD	VVDSXZHJVN	7532072168 Dell Way	\N	AZDYYXR	\N	0	France	2	VVDSXZHJVN@dell.com	7532072168	2	5980561645235867	2012/10	user15777	password	35	20000	F
15778	FTGAXB	VATSABCWPC	2065213250 Dell Way	\N	WSBVQTG	\N	0	China	2	VATSABCWPC@dell.com	2065213250	5	3629012264776975	2012/01	user15778	password	53	20000	F
15779	GHGDJC	EDUFEWCUZY	8614086391 Dell Way	\N	MAUCUAL	\N	0	UK	2	EDUFEWCUZY@dell.com	8614086391	4	8214849072042853	2012/03	user15779	password	81	20000	F
15780	EKQOMV	RGAWDCQCBD	4928399981 Dell Way	\N	DVFYWRV	\N	0	Russia	2	RGAWDCQCBD@dell.com	4928399981	4	6381704904604704	2011/07	user15780	password	72	20000	M
15781	DUFQPW	XQTBSJDUMH	7292959555 Dell Way	\N	PSFLKBE	\N	0	South Africa	2	XQTBSJDUMH@dell.com	7292959555	4	5674746512435377	2009/07	user15781	password	67	100000	M
15782	LCHBZF	RSGKCJEPRU	2529660917 Dell Way	\N	IXGTYKP	\N	0	Japan	2	RSGKCJEPRU@dell.com	2529660917	1	8773335095960648	2011/10	user15782	password	72	40000	F
15783	VQHVVZ	OBJRLOGCJP	9893996518 Dell Way	\N	ZPIYAXQ	\N	0	Canada	2	OBJRLOGCJP@dell.com	9893996518	3	8720998081844301	2011/03	user15783	password	31	100000	F
15784	VHXQGL	RPDCEJFNYF	3381496851 Dell Way	\N	CGEDEUH	\N	0	Canada	2	RPDCEJFNYF@dell.com	3381496851	1	9121948410756888	2010/05	user15784	password	82	60000	F
15785	EMUKYM	ZBPDKURJAU	4227486647 Dell Way	\N	QEXUYFY	\N	0	Chile	2	ZBPDKURJAU@dell.com	4227486647	5	7427201983053238	2011/09	user15785	password	38	100000	M
15786	TRHREH	STKDOCNOWD	7498252471 Dell Way	\N	STYRYWX	\N	0	Chile	2	STKDOCNOWD@dell.com	7498252471	4	1090880688745528	2010/11	user15786	password	82	40000	M
15787	OQHSXA	MIDAKQOGUH	5496146843 Dell Way	\N	ZSZYPWF	\N	0	China	2	MIDAKQOGUH@dell.com	5496146843	2	8042102355975658	2009/02	user15787	password	26	20000	M
15788	TIKQJX	YNXIDMOYUO	9495112801 Dell Way	\N	RTMHQSP	\N	0	Canada	2	YNXIDMOYUO@dell.com	9495112801	2	5769167306367308	2008/07	user15788	password	59	80000	F
15789	XEWGCV	TZDXMSWGHN	7996295611 Dell Way	\N	ATUQMKU	\N	0	France	2	TZDXMSWGHN@dell.com	7996295611	2	5386463228147477	2009/11	user15789	password	36	60000	M
15790	LKBNGV	NJTZCPGJCG	9831789708 Dell Way	\N	DXXQHRB	\N	0	Australia	2	NJTZCPGJCG@dell.com	9831789708	3	4154922583606094	2012/10	user15790	password	82	80000	F
15791	HRSNNG	XGFAVLKYSO	7758007370 Dell Way	\N	VPEDHFE	\N	0	Chile	2	XGFAVLKYSO@dell.com	7758007370	3	2066965206991881	2010/06	user15791	password	73	80000	M
15792	LMGYSE	EXEAJPYCDU	6520600642 Dell Way	\N	SHXZNCG	\N	0	Chile	2	EXEAJPYCDU@dell.com	6520600642	2	8246030300855637	2008/02	user15792	password	58	80000	M
15793	AZNSES	QISAXRCBLU	4314437786 Dell Way	\N	JJTWLAD	\N	0	Australia	2	QISAXRCBLU@dell.com	4314437786	5	1699049634858966	2010/07	user15793	password	78	20000	M
15794	VOGZGW	IZWGQZHCTQ	6507703860 Dell Way	\N	LNNWORY	\N	0	UK	2	IZWGQZHCTQ@dell.com	6507703860	1	4547554808203131	2008/10	user15794	password	49	80000	M
15795	ZWQGTZ	FQFWPMYJDK	2893493065 Dell Way	\N	XQHLIFI	\N	0	UK	2	FQFWPMYJDK@dell.com	2893493065	4	1347033749334514	2008/03	user15795	password	66	80000	F
15796	OIKHHQ	XNMMALWDVT	3425491449 Dell Way	\N	UCEDHNB	\N	0	Germany	2	XNMMALWDVT@dell.com	3425491449	1	6034551017452032	2010/10	user15796	password	36	80000	F
15797	PAOXQM	KDZLOVPJOK	6694986821 Dell Way	\N	MTNUHOH	\N	0	Germany	2	KDZLOVPJOK@dell.com	6694986821	5	1045601752586662	2009/02	user15797	password	63	80000	M
15798	QGPHTA	KSLYNAHCKU	7212247225 Dell Way	\N	WXOEMVS	\N	0	Australia	2	KSLYNAHCKU@dell.com	7212247225	4	5336782615166158	2011/05	user15798	password	29	60000	M
15799	KCGEDR	WOPKPXMZRJ	9495414357 Dell Way	\N	XFNJBFM	\N	0	Russia	2	WOPKPXMZRJ@dell.com	9495414357	5	5968455293681473	2009/02	user15799	password	21	40000	M
15800	ENRHEO	VUYLRLLJUI	2082071433 Dell Way	\N	PHSQNEK	\N	0	France	2	VUYLRLLJUI@dell.com	2082071433	5	7804987317416818	2009/01	user15800	password	18	80000	F
15801	NLLSZH	MYSDJDMDMB	1531341934 Dell Way	\N	LFSZJCM	\N	0	France	2	MYSDJDMDMB@dell.com	1531341934	2	7484721104614437	2008/03	user15801	password	53	40000	M
15802	YRLYYY	WRBFVOJHQV	5641288729 Dell Way	\N	MJVWMHJ	\N	0	Germany	2	WRBFVOJHQV@dell.com	5641288729	1	6354784838389606	2011/07	user15802	password	77	60000	F
15803	MZLKXH	CZNXOWFFSS	1103484950 Dell Way	\N	ONOAVYO	\N	0	China	2	CZNXOWFFSS@dell.com	1103484950	1	1853467576205730	2010/12	user15803	password	62	20000	F
15804	PMWMUY	LHWAEBFWUT	5745206378 Dell Way	\N	KJUGHJP	\N	0	Chile	2	LHWAEBFWUT@dell.com	5745206378	4	8798861968331040	2010/04	user15804	password	86	100000	M
15805	LVJFUU	MRVQSANMUY	4699817799 Dell Way	\N	WOEDYTK	\N	0	France	2	MRVQSANMUY@dell.com	4699817799	2	9672760098241272	2011/03	user15805	password	85	60000	M
15806	TXWOSJ	FNZYNNLILH	2091475312 Dell Way	\N	WPKUIVG	\N	0	Russia	2	FNZYNNLILH@dell.com	2091475312	2	4977188533637673	2009/02	user15806	password	90	20000	M
15807	XWLPFR	DFPRSAZEIW	2338854305 Dell Way	\N	TSRCOXW	\N	0	Japan	2	DFPRSAZEIW@dell.com	2338854305	2	1177477273624390	2009/04	user15807	password	19	40000	F
15808	WRUCIX	HYPAYOEGKY	2658914407 Dell Way	\N	ZBBNZXF	\N	0	Canada	2	HYPAYOEGKY@dell.com	2658914407	2	4860271063633263	2010/04	user15808	password	64	80000	F
15809	HLFQJN	OYONNSUXRT	7647411871 Dell Way	\N	ZSHYPNC	\N	0	Russia	2	OYONNSUXRT@dell.com	7647411871	3	3278230316936970	2012/02	user15809	password	84	20000	F
15810	JICTWQ	SKDFDYDURC	6746581751 Dell Way	\N	MZBCMDW	\N	0	Chile	2	SKDFDYDURC@dell.com	6746581751	1	2996701346244663	2011/01	user15810	password	43	40000	F
15811	RIDOYV	YCACADWSGJ	4835614874 Dell Way	\N	SHLFKIL	\N	0	Australia	2	YCACADWSGJ@dell.com	4835614874	4	8566560187377036	2010/12	user15811	password	23	100000	M
15812	KZGJVF	LWHMADFGMX	2722209465 Dell Way	\N	OYCYGNA	\N	0	Japan	2	LWHMADFGMX@dell.com	2722209465	5	2199792430270463	2008/12	user15812	password	90	100000	F
15813	ZCRUHD	ROPRSUXFSL	3535854229 Dell Way	\N	EVKKJLC	\N	0	Germany	2	ROPRSUXFSL@dell.com	3535854229	2	7590115498751403	2009/03	user15813	password	62	60000	F
15814	SFZAIQ	PYIHSFNLRR	4300180282 Dell Way	\N	GCBPNDD	\N	0	South Africa	2	PYIHSFNLRR@dell.com	4300180282	5	1254593029152602	2010/06	user15814	password	58	80000	F
15815	TTFCJU	ARCTXPEPGL	1620986372 Dell Way	\N	SIAGMEB	\N	0	South Africa	2	ARCTXPEPGL@dell.com	1620986372	1	4820653809700161	2010/08	user15815	password	30	80000	F
15816	XYMHTN	ZVGXLKMSVF	6469939275 Dell Way	\N	AWLNBNJ	\N	0	Canada	2	ZVGXLKMSVF@dell.com	6469939275	4	7193882748018951	2009/12	user15816	password	50	80000	M
15817	KEEDRE	ZXBKIOCETD	8437736228 Dell Way	\N	BFRDSAG	\N	0	China	2	ZXBKIOCETD@dell.com	8437736228	5	6251154931262136	2012/05	user15817	password	36	80000	M
15818	LWYCAX	ABIJPLOJOP	9216513536 Dell Way	\N	OFSGGZP	\N	0	Australia	2	ABIJPLOJOP@dell.com	9216513536	1	8837725177872927	2009/06	user15818	password	58	20000	M
15819	LAZLXA	NGJCRXMFNA	1509536878 Dell Way	\N	LGHRFWT	\N	0	Canada	2	NGJCRXMFNA@dell.com	1509536878	4	4775582920759916	2010/03	user15819	password	54	40000	M
15820	MIBKIO	QSRIQDNDEZ	1256283692 Dell Way	\N	KLRPIKS	\N	0	China	2	QSRIQDNDEZ@dell.com	1256283692	1	8884944235440344	2009/08	user15820	password	34	100000	F
15821	OWOXKF	PCNGFBKJAU	3264865481 Dell Way	\N	VRJECCO	\N	0	Canada	2	PCNGFBKJAU@dell.com	3264865481	3	3887670961208642	2012/08	user15821	password	27	20000	F
15822	ZPDKUS	MHZSJJCJDY	1427591273 Dell Way	\N	BNCDQQG	\N	0	South Africa	2	MHZSJJCJDY@dell.com	1427591273	3	7995630796533079	2011/09	user15822	password	77	100000	M
15823	KACETP	MTIVCLFGJH	3018348654 Dell Way	\N	ULKKCRH	\N	0	Canada	2	MTIVCLFGJH@dell.com	3018348654	1	8461405100766570	2012/11	user15823	password	72	80000	F
15824	UTLNJY	GSUJDAPNHJ	2380617524 Dell Way	\N	YSUBJCE	\N	0	Germany	2	GSUJDAPNHJ@dell.com	2380617524	1	5579893941525370	2008/09	user15824	password	27	40000	M
15825	WTBGSH	YNRBNHOVRN	7616737772 Dell Way	\N	NLOWNTM	\N	0	Japan	2	YNRBNHOVRN@dell.com	7616737772	5	7481538441497833	2010/02	user15825	password	20	100000	M
15826	UAFNIE	AAFOHUJYIX	2978813279 Dell Way	\N	KWUXPGP	\N	0	China	2	AAFOHUJYIX@dell.com	2978813279	2	8418759502936155	2009/05	user15826	password	77	40000	F
15827	VORESS	EXGLSQKAOU	6707458300 Dell Way	\N	XISNPHW	\N	0	South Africa	2	EXGLSQKAOU@dell.com	6707458300	4	2178731431718915	2012/06	user15827	password	50	20000	F
15828	ZVNRNR	PTDHKNIYHF	3508963730 Dell Way	\N	HZTWHPR	\N	0	UK	2	PTDHKNIYHF@dell.com	3508963730	5	9339356237091124	2011/04	user15828	password	23	20000	F
15829	WQXKIN	DLVOZDNHJU	2314079164 Dell Way	\N	GCROSIN	\N	0	UK	2	DLVOZDNHJU@dell.com	2314079164	3	7869091949425638	2009/06	user15829	password	81	80000	F
15830	MOTUBX	GXMFBZMKUT	3276767725 Dell Way	\N	NLIGUVG	\N	0	UK	2	GXMFBZMKUT@dell.com	3276767725	5	3971667538397014	2011/11	user15830	password	88	20000	F
15831	NXEPVK	MHQNHDYBWM	9406786234 Dell Way	\N	NFSHAYF	\N	0	Chile	2	MHQNHDYBWM@dell.com	9406786234	3	1229492548387497	2012/07	user15831	password	29	20000	F
15832	BIPWTC	EKPLNNMKZZ	1574161771 Dell Way	\N	PRHPQNW	\N	0	Germany	2	EKPLNNMKZZ@dell.com	1574161771	5	4278461983427405	2010/01	user15832	password	56	80000	F
15833	WFZQHE	AXPOKCYKCN	9353833967 Dell Way	\N	BKDSXAG	\N	0	UK	2	AXPOKCYKCN@dell.com	9353833967	4	5927326547913254	2012/02	user15833	password	29	20000	F
15834	JDRRHR	OXGZZEJCSL	1160361682 Dell Way	\N	MVDKWKJ	\N	0	Russia	2	OXGZZEJCSL@dell.com	1160361682	5	7953980138991029	2008/01	user15834	password	83	40000	F
15835	AWCHOR	EUQEZZGRKT	4754202693 Dell Way	\N	MNDIYND	\N	0	UK	2	EUQEZZGRKT@dell.com	4754202693	5	2078029340133071	2010/10	user15835	password	42	100000	M
15836	FACUSG	PILOHRFSLS	1656589193 Dell Way	\N	GPBECEC	\N	0	Germany	2	PILOHRFSLS@dell.com	1656589193	2	9958375452086330	2012/07	user15836	password	84	80000	M
15837	YTOQZD	YKRGCXZOPF	7098531244 Dell Way	\N	DRJFVLT	\N	0	UK	2	YKRGCXZOPF@dell.com	7098531244	4	7979027729947121	2009/08	user15837	password	49	100000	M
15838	EOGDRF	OJLRGKFWQI	1287287560 Dell Way	\N	NZOJLHH	\N	0	Canada	2	OJLRGKFWQI@dell.com	1287287560	1	4091804333962500	2011/06	user15838	password	42	40000	M
15839	WNUOSJ	XEADPFZFON	2974234878 Dell Way	\N	ECWQKET	\N	0	France	2	XEADPFZFON@dell.com	2974234878	1	2090203333646059	2011/05	user15839	password	47	40000	F
15840	XDVQMS	UNWJSWPHJT	2724759805 Dell Way	\N	KGJUKCG	\N	0	Japan	2	UNWJSWPHJT@dell.com	2724759805	2	4083950008731335	2011/10	user15840	password	68	100000	M
15841	VTHIMB	VILOEAVOUF	6390126881 Dell Way	\N	VEAGHGX	\N	0	France	2	VILOEAVOUF@dell.com	6390126881	2	1753447599709034	2009/12	user15841	password	89	20000	M
15842	SHBEJX	NVLSVHGQNC	5062707071 Dell Way	\N	UNICUFO	\N	0	China	2	NVLSVHGQNC@dell.com	5062707071	4	7512495446018875	2009/08	user15842	password	71	20000	F
15843	BENKCA	GOTCVZSJCN	8454835671 Dell Way	\N	WLPRREA	\N	0	Canada	2	GOTCVZSJCN@dell.com	8454835671	4	5290177033282817	2010/06	user15843	password	61	100000	M
15844	UIYWJE	KCGGCZQFMN	9500269621 Dell Way	\N	QCEHHEK	\N	0	Canada	2	KCGGCZQFMN@dell.com	9500269621	5	6056525224354119	2010/06	user15844	password	45	100000	F
15845	SXCBCN	EJUHIKMVXC	6687680156 Dell Way	\N	XBJEGTH	\N	0	Chile	2	EJUHIKMVXC@dell.com	6687680156	5	6793426632881165	2008/03	user15845	password	62	40000	M
15846	NLAQZE	ZTLIEYDCAB	4183628628 Dell Way	\N	DKFKENQ	\N	0	Russia	2	ZTLIEYDCAB@dell.com	4183628628	2	8984200804959984	2010/11	user15846	password	33	60000	F
15847	RMBQRA	KDIOBMQCNU	1901181861 Dell Way	\N	MTFQGVL	\N	0	Germany	2	KDIOBMQCNU@dell.com	1901181861	2	2506429681088775	2012/07	user15847	password	66	40000	F
15848	ELVVLF	ZUUAGLCUGP	9784101963 Dell Way	\N	NLFTHQI	\N	0	China	2	ZUUAGLCUGP@dell.com	9784101963	3	4253845054656267	2010/03	user15848	password	72	80000	F
15849	EOEQUD	LOESZGMFVZ	6188526913 Dell Way	\N	RBSYSBI	\N	0	Japan	2	LOESZGMFVZ@dell.com	6188526913	4	2878788940142840	2011/06	user15849	password	85	20000	M
15850	MGHGKS	VOKVVWBRVS	7502118813 Dell Way	\N	TORLPAD	\N	0	Canada	2	VOKVVWBRVS@dell.com	7502118813	2	9475869833957404	2008/04	user15850	password	20	100000	M
15851	HCASUV	GEQCBRUWKN	5270937338 Dell Way	\N	KCZACDF	\N	0	South Africa	2	GEQCBRUWKN@dell.com	5270937338	1	9972481239587070	2011/03	user15851	password	77	60000	F
15852	XNERJL	WZNXRIUCVF	6555995433 Dell Way	\N	EUFGXLB	\N	0	China	2	WZNXRIUCVF@dell.com	6555995433	1	2276493084616959	2012/11	user15852	password	66	40000	M
15853	EMLOXI	OLFFTAHPFL	8662195389 Dell Way	\N	JLSHWUR	\N	0	France	2	OLFFTAHPFL@dell.com	8662195389	5	3794508119113743	2011/06	user15853	password	62	60000	M
15854	CYFAHT	MNZGNHVSTF	9725420708 Dell Way	\N	DLMAFEN	\N	0	Australia	2	MNZGNHVSTF@dell.com	9725420708	5	8311171133071185	2010/06	user15854	password	41	20000	M
15855	HINOCZ	BBGOJBGCGK	7617394578 Dell Way	\N	OTKTXXW	\N	0	South Africa	2	BBGOJBGCGK@dell.com	7617394578	4	3767150450497866	2008/12	user15855	password	48	80000	F
15856	TFVVFW	WLLGNSITCW	2298823840 Dell Way	\N	MMQKKMG	\N	0	Canada	2	WLLGNSITCW@dell.com	2298823840	3	3834809508174658	2008/12	user15856	password	90	40000	M
15857	FENLBK	WMQJFZDHVQ	8355071623 Dell Way	\N	UMAFYGJ	\N	0	Australia	2	WMQJFZDHVQ@dell.com	8355071623	4	2939668978564441	2011/08	user15857	password	61	60000	M
15858	UAHWLE	ICONBRVXHP	8427272172 Dell Way	\N	JIVIOEK	\N	0	China	2	ICONBRVXHP@dell.com	8427272172	4	2623897104524076	2010/03	user15858	password	67	40000	F
15859	SRWEWF	GKTICOFKEP	9289985855 Dell Way	\N	SZXHDHR	\N	0	UK	2	GKTICOFKEP@dell.com	9289985855	5	5027085366193205	2008/07	user15859	password	77	20000	F
15860	MZKJER	TXZWMFHQUZ	8512462152 Dell Way	\N	PRHTZZS	\N	0	UK	2	TXZWMFHQUZ@dell.com	8512462152	1	1397938447073102	2009/12	user15860	password	31	80000	F
15861	EBUJSO	HSLTXSKSSA	6397583607 Dell Way	\N	KZTJYLH	\N	0	Russia	2	HSLTXSKSSA@dell.com	6397583607	2	2585590222850442	2010/07	user15861	password	77	20000	M
15862	WVBPKI	IVCGNMYGMJ	4227943431 Dell Way	\N	FGTESAZ	\N	0	China	2	IVCGNMYGMJ@dell.com	4227943431	1	8792109176050872	2012/12	user15862	password	82	60000	M
15863	SQLCZU	YBAMOZSBIY	3392040636 Dell Way	\N	HBDABCI	\N	0	France	2	YBAMOZSBIY@dell.com	3392040636	1	3785543870646507	2009/01	user15863	password	82	20000	M
15864	NOWMIV	OIHCHZEPYM	9617519265 Dell Way	\N	RBMTEUE	\N	0	France	2	OIHCHZEPYM@dell.com	9617519265	3	6977052933536471	2008/05	user15864	password	73	80000	M
15865	HRIPMW	YUZGUDVSPN	8895453805 Dell Way	\N	TBGXWKI	\N	0	South Africa	2	YUZGUDVSPN@dell.com	8895453805	5	8459802933502943	2009/09	user15865	password	63	20000	F
15866	HLRUIP	OHVILRABEU	1131183720 Dell Way	\N	CKRZVAU	\N	0	Russia	2	OHVILRABEU@dell.com	1131183720	4	9413839333225044	2011/03	user15866	password	20	100000	M
15867	MMIUBW	CXFOPGPUAS	1445245426 Dell Way	\N	FSRATLS	\N	0	Russia	2	CXFOPGPUAS@dell.com	1445245426	4	5711418746970594	2009/09	user15867	password	42	80000	F
15868	UCZWZB	UFQJLFDMXJ	7740836538 Dell Way	\N	FPJYBCS	\N	0	Australia	2	UFQJLFDMXJ@dell.com	7740836538	2	4276880343444646	2010/07	user15868	password	29	80000	F
15869	HOGGQB	MGKXMOKKXP	5540148507 Dell Way	\N	ZHOAJGC	\N	0	Canada	2	MGKXMOKKXP@dell.com	5540148507	3	6120896723587067	2008/08	user15869	password	30	60000	M
15870	TSEJTQ	QEOCTYMROM	1739505804 Dell Way	\N	YCMIJPL	\N	0	South Africa	2	QEOCTYMROM@dell.com	1739505804	1	9641989117488266	2011/03	user15870	password	48	80000	M
15871	DVIWLY	AABUYOLNAK	2818178329 Dell Way	\N	QNSADEX	\N	0	Chile	2	AABUYOLNAK@dell.com	2818178329	5	9453359256498516	2010/04	user15871	password	59	40000	F
15872	JRGVQH	VRBUGMHHWY	7128787588 Dell Way	\N	UPYYTVE	\N	0	UK	2	VRBUGMHHWY@dell.com	7128787588	1	4323452779091895	2012/09	user15872	password	70	40000	F
15873	JOWAWS	SXMYKUFHSA	2819828567 Dell Way	\N	WRYQMCP	\N	0	Canada	2	SXMYKUFHSA@dell.com	2819828567	5	2081336273346096	2012/09	user15873	password	50	100000	F
15874	AUBWNT	UASEUXLNXH	5221007166 Dell Way	\N	FWXSYNW	\N	0	Canada	2	UASEUXLNXH@dell.com	5221007166	5	1280152117367833	2008/06	user15874	password	87	40000	F
15875	TGIGAC	GSGBQSPNZU	4202317824 Dell Way	\N	JXMILJM	\N	0	South Africa	2	GSGBQSPNZU@dell.com	4202317824	3	1336013637948781	2011/06	user15875	password	35	40000	F
15876	NOMNRT	GXUWPKKPEU	2267086221 Dell Way	\N	NRCYBPV	\N	0	China	2	GXUWPKKPEU@dell.com	2267086221	5	2690301282331347	2011/02	user15876	password	49	100000	M
15877	ZIERBK	OVHEFRUKLI	9806923824 Dell Way	\N	COGDECN	\N	0	China	2	OVHEFRUKLI@dell.com	9806923824	4	9503644301090390	2008/02	user15877	password	75	80000	F
15878	CWUEHJ	AOOGGJQSRT	1840041204 Dell Way	\N	GYWLAJU	\N	0	Australia	2	AOOGGJQSRT@dell.com	1840041204	4	1923171302769333	2009/07	user15878	password	77	40000	M
15879	REUZOU	NCATMRMDKS	7114366071 Dell Way	\N	BHECRYC	\N	0	Russia	2	NCATMRMDKS@dell.com	7114366071	1	9942279599606992	2008/01	user15879	password	45	100000	M
15880	OPRCKF	FLZRCLUNEW	3218578394 Dell Way	\N	UJYMIBF	\N	0	UK	2	FLZRCLUNEW@dell.com	3218578394	2	2660294295288622	2009/08	user15880	password	90	100000	F
15881	PRGZWL	KWDNHYBMUV	7783075031 Dell Way	\N	VTIDUND	\N	0	Australia	2	KWDNHYBMUV@dell.com	7783075031	2	3744091088883579	2009/04	user15881	password	38	60000	M
15882	YSXUEI	QHVYFWKASF	8274399262 Dell Way	\N	UAJOOMP	\N	0	China	2	QHVYFWKASF@dell.com	8274399262	5	7000756603665651	2008/03	user15882	password	28	20000	F
15883	WYXBGO	JBNOYXPRDJ	4998806237 Dell Way	\N	SMYHZNP	\N	0	Russia	2	JBNOYXPRDJ@dell.com	4998806237	2	9268642834853382	2011/05	user15883	password	87	80000	F
15884	WRIDGR	FTGDRWVUFN	7011435739 Dell Way	\N	HEUHSKC	\N	0	Canada	2	FTGDRWVUFN@dell.com	7011435739	5	7955195167101920	2008/12	user15884	password	56	40000	M
15885	FSYLKD	FQHWNCQTQY	3623867976 Dell Way	\N	XLFPVHT	\N	0	France	2	FQHWNCQTQY@dell.com	3623867976	3	6220478821080179	2009/01	user15885	password	87	20000	F
15886	RARBDW	SKSFNJYDIW	7232679849 Dell Way	\N	ONLKVEX	\N	0	Canada	2	SKSFNJYDIW@dell.com	7232679849	3	4159316725097597	2011/06	user15886	password	47	100000	F
15887	KQDONW	ZGBMQAQYWE	9527649841 Dell Way	\N	LIPHMMK	\N	0	Canada	2	ZGBMQAQYWE@dell.com	9527649841	4	9238700644113124	2009/02	user15887	password	82	60000	M
15888	NPCBLB	HNOXNEVKJH	7496444839 Dell Way	\N	SYPFLZJ	\N	0	China	2	HNOXNEVKJH@dell.com	7496444839	2	7692541282624007	2012/03	user15888	password	32	60000	M
15889	UOTGQA	TEYHJURSCJ	3200125429 Dell Way	\N	RROCQYM	\N	0	China	2	TEYHJURSCJ@dell.com	3200125429	2	3087024378590286	2010/06	user15889	password	67	20000	F
15890	GWMWXG	BVNLPEEROV	6647339347 Dell Way	\N	JDYZBKI	\N	0	China	2	BVNLPEEROV@dell.com	6647339347	3	7655406073667110	2008/03	user15890	password	80	40000	F
15891	STJQZK	LNVBSATGVC	9938982904 Dell Way	\N	KUCLELU	\N	0	South Africa	2	LNVBSATGVC@dell.com	9938982904	3	8774236548691989	2009/05	user15891	password	27	80000	F
15892	WBSWME	JIGBIAIEDS	5274813687 Dell Way	\N	YGEDRYY	\N	0	Japan	2	JIGBIAIEDS@dell.com	5274813687	5	9050862906500698	2012/12	user15892	password	62	100000	M
15893	RRSEWC	MDDVEMZHFY	8531542653 Dell Way	\N	OJBFIAW	\N	0	South Africa	2	MDDVEMZHFY@dell.com	8531542653	4	6990433992352337	2011/05	user15893	password	63	80000	F
15894	IIFEKS	IONMANUGLI	2510125048 Dell Way	\N	QNOYNKT	\N	0	China	2	IONMANUGLI@dell.com	2510125048	3	2322733215522021	2010/01	user15894	password	74	60000	F
15895	CUONMW	BAJCNEIYMY	1783729211 Dell Way	\N	LAXZLRI	\N	0	Japan	2	BAJCNEIYMY@dell.com	1783729211	3	2318496976513415	2008/03	user15895	password	71	60000	F
15896	NBVAYX	BIZOMINYGY	7486947711 Dell Way	\N	ZDXLUGB	\N	0	South Africa	2	BIZOMINYGY@dell.com	7486947711	1	1312949683051556	2012/12	user15896	password	57	40000	F
15897	PDMOBN	WACIIPHPNH	9388745943 Dell Way	\N	TLSOSTL	\N	0	France	2	WACIIPHPNH@dell.com	9388745943	3	4448454234283418	2012/01	user15897	password	68	40000	M
15898	VUEWIB	XKJGZRVNYP	1406842945 Dell Way	\N	ZQDRKOB	\N	0	China	2	XKJGZRVNYP@dell.com	1406842945	3	2586728946305811	2008/02	user15898	password	53	80000	M
15899	GWWPXU	ZHAYYWMXLL	6619858469 Dell Way	\N	NOCXDEG	\N	0	Canada	2	ZHAYYWMXLL@dell.com	6619858469	3	3260841891169548	2011/11	user15899	password	86	80000	F
15900	VQTTKT	AKRZHEWSPK	9815281579 Dell Way	\N	HRILVOQ	\N	0	France	2	AKRZHEWSPK@dell.com	9815281579	5	3141265765298158	2012/10	user15900	password	90	20000	M
15901	QVJAOK	LGJSKFLZPT	7180753665 Dell Way	\N	RXEMMVY	\N	0	France	2	LGJSKFLZPT@dell.com	7180753665	1	4022676423192024	2010/03	user15901	password	46	20000	M
15902	FNVTXH	ZHAJMMJCFA	7038143307 Dell Way	\N	AKNMFMY	\N	0	UK	2	ZHAJMMJCFA@dell.com	7038143307	2	4711098169442266	2012/09	user15902	password	58	80000	M
15903	BNQZVQ	GVATIJWNKX	6544578895 Dell Way	\N	YXKEJIB	\N	0	Australia	2	GVATIJWNKX@dell.com	6544578895	3	9227132574189456	2009/01	user15903	password	61	20000	F
15904	DVCYLJ	ULCCVZQFWP	3559047601 Dell Way	\N	CGTMPUN	\N	0	Canada	2	ULCCVZQFWP@dell.com	3559047601	3	5379628339316696	2009/01	user15904	password	66	60000	F
15905	MNDXWX	JZAEYRJUGM	9403801497 Dell Way	\N	BZYQUMV	\N	0	Australia	2	JZAEYRJUGM@dell.com	9403801497	2	4547123312018812	2012/12	user15905	password	77	20000	F
15906	IHJFFS	EGWCXGXDSY	7256527763 Dell Way	\N	DROYEKA	\N	0	Australia	2	EGWCXGXDSY@dell.com	7256527763	2	1621198518201708	2011/03	user15906	password	34	20000	M
15907	NLTSDX	YAAWGXAYWD	5181504548 Dell Way	\N	QLBUVBW	\N	0	Germany	2	YAAWGXAYWD@dell.com	5181504548	5	2648332108277827	2011/03	user15907	password	38	40000	M
15908	TZKXWJ	XWFEUFCRJT	4118994787 Dell Way	\N	CLNXNKL	\N	0	UK	2	XWFEUFCRJT@dell.com	4118994787	4	6880753264762462	2010/11	user15908	password	82	20000	M
15909	WPNSYL	PEPKKSBTLD	2086702195 Dell Way	\N	FZBSJMR	\N	0	Russia	2	PEPKKSBTLD@dell.com	2086702195	2	3119660165160894	2008/03	user15909	password	49	80000	F
15910	AFUZQK	DFUNXVHJZM	3127584244 Dell Way	\N	IAFSNXK	\N	0	Japan	2	DFUNXVHJZM@dell.com	3127584244	4	7129559725522996	2010/01	user15910	password	43	60000	F
15911	OIBESF	JMTHIAQHNY	7339354265 Dell Way	\N	ITQWQBN	\N	0	South Africa	2	JMTHIAQHNY@dell.com	7339354265	1	3925070589873940	2011/07	user15911	password	79	100000	F
15912	EYGWEQ	IXXQYOYMMG	8328700555 Dell Way	\N	FDCWFQS	\N	0	South Africa	2	IXXQYOYMMG@dell.com	8328700555	1	7124178501777352	2009/11	user15912	password	59	60000	F
15913	NSXSIG	PGXOUVBHCG	8747348333 Dell Way	\N	KFCPVVN	\N	0	Japan	2	PGXOUVBHCG@dell.com	8747348333	1	9947648158296944	2011/10	user15913	password	49	80000	F
15914	DSZLYP	SVDMRETTLE	5350354219 Dell Way	\N	YOUUJHK	\N	0	Chile	2	SVDMRETTLE@dell.com	5350354219	3	9835205115843564	2009/11	user15914	password	74	60000	M
15915	MMKKCC	GGPXLJQWNP	2614109673 Dell Way	\N	KIJUPUA	\N	0	Australia	2	GGPXLJQWNP@dell.com	2614109673	1	3933969949837774	2008/10	user15915	password	79	100000	F
15916	IKRKNY	QCWBLNYZCJ	2699896767 Dell Way	\N	HMEXGEZ	\N	0	France	2	QCWBLNYZCJ@dell.com	2699896767	2	4946426379028708	2012/02	user15916	password	48	40000	F
15917	VYXIWO	LSQWGOVIYD	3569940194 Dell Way	\N	UCABHZM	\N	0	France	2	LSQWGOVIYD@dell.com	3569940194	5	4970361481886357	2010/04	user15917	password	67	100000	F
15918	PUMMJX	FZULOQUMTP	9913778090 Dell Way	\N	OTQWTCI	\N	0	Australia	2	FZULOQUMTP@dell.com	9913778090	4	5077777423430234	2009/06	user15918	password	44	60000	F
15919	EYONVT	MPFAFZNYOC	1018418264 Dell Way	\N	SEYLHGM	\N	0	Chile	2	MPFAFZNYOC@dell.com	1018418264	5	6163878909312189	2010/04	user15919	password	20	60000	F
15920	YAZUUL	JZMPZZONCG	2106487091 Dell Way	\N	SASZGFG	\N	0	Chile	2	JZMPZZONCG@dell.com	2106487091	5	7252373478841037	2010/11	user15920	password	31	100000	M
15921	FVPAHY	AUOZUCMWJF	3232249702 Dell Way	\N	WCEDHLJ	\N	0	France	2	AUOZUCMWJF@dell.com	3232249702	1	8366702188737691	2008/04	user15921	password	68	100000	F
15922	NMMVLM	PZMKCZGMED	7363343100 Dell Way	\N	OJGVUQG	\N	0	Australia	2	PZMKCZGMED@dell.com	7363343100	1	2234418315347284	2012/09	user15922	password	20	60000	F
15923	NYCYLS	XXCAWJMBMA	2465689411 Dell Way	\N	KTWFKCG	\N	0	Australia	2	XXCAWJMBMA@dell.com	2465689411	2	1537349894177168	2012/06	user15923	password	55	20000	M
15924	LGWXYU	VBURKGSXHD	9791641167 Dell Way	\N	QDIAGPD	\N	0	France	2	VBURKGSXHD@dell.com	9791641167	1	3880054376088083	2009/09	user15924	password	54	40000	F
15925	TEBSYW	TSOEZGBGKS	1512107738 Dell Way	\N	KTTRIWB	\N	0	China	2	TSOEZGBGKS@dell.com	1512107738	2	7329830884933472	2011/11	user15925	password	19	100000	M
15926	EYJDVD	WJIVQJCACN	6807025168 Dell Way	\N	UWECSGK	\N	0	Russia	2	WJIVQJCACN@dell.com	6807025168	1	5783331251703203	2010/02	user15926	password	49	20000	F
15927	KOLFRH	OZDFJFGMTA	6908922159 Dell Way	\N	IXDBENV	\N	0	South Africa	2	OZDFJFGMTA@dell.com	6908922159	2	4144500064197928	2011/10	user15927	password	56	20000	F
15928	COKUWZ	TZEDFKQYKY	2731900625 Dell Way	\N	WNZBBVW	\N	0	Russia	2	TZEDFKQYKY@dell.com	2731900625	2	5641648899763823	2012/09	user15928	password	64	20000	M
15929	FPPBOJ	BSNGDDFNBC	2783013366 Dell Way	\N	BBDDXZW	\N	0	Australia	2	BSNGDDFNBC@dell.com	2783013366	2	1774340222589671	2012/12	user15929	password	37	80000	F
15930	VJGKSH	CFOFJTTLVV	2546525847 Dell Way	\N	NZYKZUN	\N	0	Canada	2	CFOFJTTLVV@dell.com	2546525847	3	1898876138497144	2008/11	user15930	password	81	40000	M
15931	FPCYXF	ELKNEEYAAL	9550807639 Dell Way	\N	ZZWYUJC	\N	0	UK	2	ELKNEEYAAL@dell.com	9550807639	2	2066026903223246	2012/01	user15931	password	52	60000	F
15932	CPGZUL	KFYPJXPKJP	8853779263 Dell Way	\N	JFODPRC	\N	0	Germany	2	KFYPJXPKJP@dell.com	8853779263	2	4105183582287282	2012/09	user15932	password	79	40000	M
15933	KNTFYE	KXTUUIEEYO	9991738125 Dell Way	\N	KMRZDUN	\N	0	Australia	2	KXTUUIEEYO@dell.com	9991738125	5	9616832754574716	2011/09	user15933	password	33	60000	F
15934	SFIRJT	OCNJLRNJFX	3985503080 Dell Way	\N	WXXZSLZ	\N	0	Russia	2	OCNJLRNJFX@dell.com	3985503080	5	4558294788002968	2008/02	user15934	password	81	40000	M
15935	COOMHC	PULAMYKSWG	2826599585 Dell Way	\N	QUGIGGA	\N	0	Germany	2	PULAMYKSWG@dell.com	2826599585	3	6683836140669883	2009/04	user15935	password	78	40000	F
15936	JUWQXL	LILXHWQEDG	1214460007 Dell Way	\N	YKOFQPU	\N	0	South Africa	2	LILXHWQEDG@dell.com	1214460007	3	2938026523683220	2009/03	user15936	password	52	80000	M
15937	GOHDZS	MLQTHGYLMX	3677775423 Dell Way	\N	VBCMRWI	\N	0	Japan	2	MLQTHGYLMX@dell.com	3677775423	3	9998953846283258	2010/01	user15937	password	68	20000	F
15938	GLLFDX	QURYAPJNME	5610979574 Dell Way	\N	PPRGMZY	\N	0	Russia	2	QURYAPJNME@dell.com	5610979574	5	3835610524751246	2010/08	user15938	password	53	80000	M
15939	XFBBCS	WUQWJZKWEZ	1932175402 Dell Way	\N	LVGYUES	\N	0	China	2	WUQWJZKWEZ@dell.com	1932175402	1	8507402215152980	2011/07	user15939	password	63	60000	F
15940	VRMYJI	SZFCYQZDPL	1831094260 Dell Way	\N	YWJTABB	\N	0	Canada	2	SZFCYQZDPL@dell.com	1831094260	5	8730988170485944	2010/07	user15940	password	50	20000	F
15941	CMHMVA	LBDKRCNHNM	2895924777 Dell Way	\N	DXFEZHH	\N	0	Australia	2	LBDKRCNHNM@dell.com	2895924777	1	6918975526932628	2011/08	user15941	password	66	20000	M
15942	EKEALQ	BOATROAFAE	8338217929 Dell Way	\N	CGJBORD	\N	0	Russia	2	BOATROAFAE@dell.com	8338217929	4	5423345425166190	2010/06	user15942	password	61	20000	M
15943	ZIQLZR	ZZKQNLVOQY	9314079635 Dell Way	\N	UZAIQDB	\N	0	France	2	ZZKQNLVOQY@dell.com	9314079635	3	8970355024095626	2009/02	user15943	password	20	20000	F
15944	JQPIIO	ITFWFBKVZF	2396420160 Dell Way	\N	VZNLDPX	\N	0	Australia	2	ITFWFBKVZF@dell.com	2396420160	5	4945996362250298	2009/11	user15944	password	50	60000	F
15945	CBOKQX	DVTIXEEXJZ	2494281424 Dell Way	\N	XWLAMJC	\N	0	Japan	2	DVTIXEEXJZ@dell.com	2494281424	3	9449962016660720	2008/12	user15945	password	47	40000	F
15946	LULCRP	XLXVQCSZBP	3170432403 Dell Way	\N	WNQIWSY	\N	0	Australia	2	XLXVQCSZBP@dell.com	3170432403	5	1456917088478803	2009/04	user15946	password	38	40000	M
15947	BSVTHT	EFOUHHUJXQ	8602659590 Dell Way	\N	WNZTGYU	\N	0	France	2	EFOUHHUJXQ@dell.com	8602659590	5	7273824164643884	2008/02	user15947	password	87	100000	F
15948	QTYYNC	DCXLJSUGJR	1503150526 Dell Way	\N	UIKBHFN	\N	0	Canada	2	DCXLJSUGJR@dell.com	1503150526	2	3485612490214407	2008/03	user15948	password	31	40000	M
15949	YHTLKX	OIIXACEJTZ	8023340308 Dell Way	\N	SEAZJOC	\N	0	France	2	OIIXACEJTZ@dell.com	8023340308	2	6532550541684032	2012/07	user15949	password	89	80000	M
15950	GOZRLN	ZUKZWPIQPB	5561405541 Dell Way	\N	VPAFDDQ	\N	0	UK	2	ZUKZWPIQPB@dell.com	5561405541	2	9020321879070252	2008/03	user15950	password	67	60000	F
15951	GODSBC	MMCJCLZRMU	8858539907 Dell Way	\N	GNZKQQJ	\N	0	Canada	2	MMCJCLZRMU@dell.com	8858539907	2	2951988008338958	2008/12	user15951	password	76	60000	F
15952	JSWLVI	XYRAJRRWMY	9647313683 Dell Way	\N	JLJZCSD	\N	0	UK	2	XYRAJRRWMY@dell.com	9647313683	2	1502348709385842	2012/02	user15952	password	64	20000	M
15953	JXYEFW	DXXMOPJANS	2854159258 Dell Way	\N	MXSOQWN	\N	0	Germany	2	DXXMOPJANS@dell.com	2854159258	3	5259224014356733	2009/03	user15953	password	55	100000	M
15954	KWTQTW	NQJCFSCTLO	2960030331 Dell Way	\N	RDDHAQW	\N	0	Chile	2	NQJCFSCTLO@dell.com	2960030331	2	6202213652431965	2010/11	user15954	password	52	100000	F
15955	ITYBQL	SZNYSQREEI	8823296226 Dell Way	\N	IHQIYNN	\N	0	Canada	2	SZNYSQREEI@dell.com	8823296226	1	6305409029126168	2011/07	user15955	password	60	20000	M
15956	IYZYKR	YYPROHVTQD	1890203156 Dell Way	\N	BGMZUZE	\N	0	Japan	2	YYPROHVTQD@dell.com	1890203156	4	4544442188460380	2011/05	user15956	password	49	60000	M
15957	KOQUGP	TWGIDCBUGD	1387418773 Dell Way	\N	BSDVSHM	\N	0	South Africa	2	TWGIDCBUGD@dell.com	1387418773	5	5462251130957157	2009/04	user15957	password	23	20000	M
15958	QRMXGG	TNOXQQRXUS	9108667477 Dell Way	\N	QXOIFAE	\N	0	Chile	2	TNOXQQRXUS@dell.com	9108667477	4	6542245683725924	2009/09	user15958	password	66	100000	F
15959	IJGPPA	DEXTVOQPHH	4777245291 Dell Way	\N	MVPRWTX	\N	0	Russia	2	DEXTVOQPHH@dell.com	4777245291	3	9629746052902192	2008/03	user15959	password	79	60000	M
15960	FUDVUG	ASAVHRKOYW	1052920629 Dell Way	\N	KNOGHMA	\N	0	Russia	2	ASAVHRKOYW@dell.com	1052920629	5	8901050657499582	2008/10	user15960	password	47	80000	F
15961	FWWACW	SCRATCORYZ	2724141523 Dell Way	\N	FNFNZFG	\N	0	UK	2	SCRATCORYZ@dell.com	2724141523	1	2732708909548819	2008/07	user15961	password	85	20000	M
15962	UXTWUM	ZMMSOBKNAQ	6077349815 Dell Way	\N	AFEALLA	\N	0	Japan	2	ZMMSOBKNAQ@dell.com	6077349815	1	6808506992645562	2008/02	user15962	password	68	100000	M
15963	PPTJCS	VOLKQWXQNY	2309418998 Dell Way	\N	WRYICYY	\N	0	Japan	2	VOLKQWXQNY@dell.com	2309418998	3	8052684219554067	2009/04	user15963	password	64	20000	M
15964	GXGIQC	XBMOYKELIB	9028727662 Dell Way	\N	DHJGFHX	\N	0	China	2	XBMOYKELIB@dell.com	9028727662	4	6684046903625131	2008/05	user15964	password	74	20000	M
15965	RHYHKW	JXKHHPTQQW	7472055302 Dell Way	\N	XZCDHAM	\N	0	Canada	2	JXKHHPTQQW@dell.com	7472055302	1	4038747255690396	2008/11	user15965	password	45	80000	M
15966	ROWBKG	YVOGKHWAET	5400243818 Dell Way	\N	ZHWHHJL	\N	0	Australia	2	YVOGKHWAET@dell.com	5400243818	4	1626637614797800	2009/02	user15966	password	69	100000	M
15967	HWXSCW	NRDXYZYDTY	4771164790 Dell Way	\N	KQFSAQS	\N	0	France	2	NRDXYZYDTY@dell.com	4771164790	4	8932076632510872	2010/06	user15967	password	80	60000	M
15968	SIMUFZ	MIXLIVOBUY	2486214483 Dell Way	\N	SZRSQJF	\N	0	Australia	2	MIXLIVOBUY@dell.com	2486214483	1	6636021138168872	2011/12	user15968	password	21	60000	M
15969	JXLOXX	XUIFQXHLWZ	9800101064 Dell Way	\N	KNSBXXC	\N	0	Australia	2	XUIFQXHLWZ@dell.com	9800101064	4	7433237091638149	2012/10	user15969	password	28	60000	F
15970	BZSYXP	TFVKCDVYCG	1892348094 Dell Way	\N	MUHJSJK	\N	0	Japan	2	TFVKCDVYCG@dell.com	1892348094	1	6290142276789994	2012/04	user15970	password	27	100000	F
15971	CSHZIB	FDLIGHHJNT	6490185037 Dell Way	\N	EVCWFMO	\N	0	China	2	FDLIGHHJNT@dell.com	6490185037	1	2485647263471037	2012/04	user15971	password	29	40000	F
15972	WMJENP	IZXOGEYUYD	7081196106 Dell Way	\N	QAZVMND	\N	0	Canada	2	IZXOGEYUYD@dell.com	7081196106	2	9902226055040956	2012/06	user15972	password	32	40000	F
15973	RSMFHV	FFKMKIGILX	2432454687 Dell Way	\N	ILSVZWY	\N	0	Japan	2	FFKMKIGILX@dell.com	2432454687	5	6309047571383417	2011/02	user15973	password	84	100000	M
15974	QLBYGG	DQSOYYXKWG	9865610125 Dell Way	\N	VOCULBL	\N	0	Germany	2	DQSOYYXKWG@dell.com	9865610125	1	2821627109777182	2008/12	user15974	password	28	100000	M
15975	OZMVFQ	LXFKWCUSIQ	9096066724 Dell Way	\N	HLKSMWH	\N	0	France	2	LXFKWCUSIQ@dell.com	9096066724	3	6173954447265715	2012/08	user15975	password	56	60000	F
15976	NYATOL	QUVNWQGFGO	1625398082 Dell Way	\N	QRGCNOO	\N	0	France	2	QUVNWQGFGO@dell.com	1625398082	1	3511620311997831	2011/08	user15976	password	69	100000	F
15977	QYXFKO	ZGBVXIBDWR	5089297439 Dell Way	\N	UDUISIT	\N	0	Russia	2	ZGBVXIBDWR@dell.com	5089297439	1	5332389986608178	2008/09	user15977	password	47	40000	F
15978	JDOURN	ATJXBKBYCV	9626783926 Dell Way	\N	BWEUFYO	\N	0	Japan	2	ATJXBKBYCV@dell.com	9626783926	1	7898473189678044	2011/06	user15978	password	19	20000	M
15979	EQOWDP	PNNRYOQAKS	1264093581 Dell Way	\N	XOMDMAU	\N	0	France	2	PNNRYOQAKS@dell.com	1264093581	3	2310942752752453	2010/07	user15979	password	32	40000	M
15980	VVPZKF	MXXKMNLWGJ	8407020664 Dell Way	\N	LSMXSHJ	\N	0	Russia	2	MXXKMNLWGJ@dell.com	8407020664	3	2795530238654464	2010/09	user15980	password	50	20000	M
15981	GTNRZA	PXLBLWXRGI	2157264170 Dell Way	\N	JSGBZQV	\N	0	South Africa	2	PXLBLWXRGI@dell.com	2157264170	1	2954585534986108	2012/06	user15981	password	44	40000	M
15982	DXKDXZ	AIBLFYCLHM	4260542283 Dell Way	\N	ENNEDJZ	\N	0	Chile	2	AIBLFYCLHM@dell.com	4260542283	1	2116614354308694	2012/07	user15982	password	55	60000	M
15983	KYVIYV	RZHWYJIFVM	8588992155 Dell Way	\N	TJRXTQE	\N	0	Australia	2	RZHWYJIFVM@dell.com	8588992155	2	9281962709967048	2010/10	user15983	password	52	20000	F
15984	LYOKUF	JBCILLOHXI	7510786761 Dell Way	\N	RPFKFKM	\N	0	Australia	2	JBCILLOHXI@dell.com	7510786761	3	5358183323871345	2010/11	user15984	password	61	80000	F
15985	NJSHPC	JRKUDZBBHS	1044881726 Dell Way	\N	QNCWYPY	\N	0	Japan	2	JRKUDZBBHS@dell.com	1044881726	3	2818122858181596	2012/01	user15985	password	90	40000	M
15986	JXWYAF	QLZTKBUSUK	6438263489 Dell Way	\N	FXGENFV	\N	0	Germany	2	QLZTKBUSUK@dell.com	6438263489	1	4527841418515891	2011/01	user15986	password	61	20000	F
15987	NAHNFX	YFRJHLBBWH	3424766524 Dell Way	\N	ZDLMIGZ	\N	0	UK	2	YFRJHLBBWH@dell.com	3424766524	2	5948029044084251	2009/12	user15987	password	69	80000	F
15988	SXZYVY	DNILYKMVRL	3243543164 Dell Way	\N	ZDXHKXG	\N	0	Japan	2	DNILYKMVRL@dell.com	3243543164	4	9444913139566780	2009/06	user15988	password	59	80000	F
15989	MRDIQH	VYSUJFPBRP	9156154781 Dell Way	\N	EOWOLDG	\N	0	Russia	2	VYSUJFPBRP@dell.com	9156154781	1	9268136785831304	2010/09	user15989	password	61	80000	F
15990	HTNXBI	WTDFYSGQHL	4925764187 Dell Way	\N	EEAQHGJ	\N	0	Chile	2	WTDFYSGQHL@dell.com	4925764187	2	6489965394139290	2008/11	user15990	password	34	40000	F
15991	ZYCAHY	UKETDLJLWO	8452211192 Dell Way	\N	PXFXEOD	\N	0	Germany	2	UKETDLJLWO@dell.com	8452211192	4	7934598081745208	2011/12	user15991	password	30	100000	M
15992	CYYJXS	TCMWNVHKJX	7021748476 Dell Way	\N	IOVMCYB	\N	0	UK	2	TCMWNVHKJX@dell.com	7021748476	5	6843371711671353	2011/12	user15992	password	55	60000	F
15993	MMLJFF	LSCZNJJXHR	1367345036 Dell Way	\N	LCEOBFN	\N	0	Russia	2	LSCZNJJXHR@dell.com	1367345036	1	4022151707671583	2008/09	user15993	password	82	20000	F
15994	JONPUZ	IWYVGISNAE	4904051625 Dell Way	\N	QETRJHK	\N	0	France	2	IWYVGISNAE@dell.com	4904051625	4	5074346350040287	2008/08	user15994	password	59	40000	M
15995	DUPYTX	URTAZMOZRE	9623772065 Dell Way	\N	EKVOSGY	\N	0	Canada	2	URTAZMOZRE@dell.com	9623772065	3	3175795597955584	2010/12	user15995	password	54	60000	F
15996	HEBACV	RVWRIKRZOV	7644962968 Dell Way	\N	KKJCQIG	\N	0	Germany	2	RVWRIKRZOV@dell.com	7644962968	3	2513560283463448	2011/12	user15996	password	71	100000	F
15997	XXHZTY	VPQEAHEODO	4606755570 Dell Way	\N	ZNRQVXF	\N	0	Germany	2	VPQEAHEODO@dell.com	4606755570	2	3707008396741003	2009/02	user15997	password	29	80000	F
15998	BXAVWW	KMAKUEZYTZ	2592877273 Dell Way	\N	LLPHJUW	\N	0	Russia	2	KMAKUEZYTZ@dell.com	2592877273	1	2334183913655579	2009/04	user15998	password	75	40000	F
15999	SIEOEP	BFAVKATDZF	5569054908 Dell Way	\N	POMYJJS	\N	0	Germany	2	BFAVKATDZF@dell.com	5569054908	5	8381299629341812	2012/08	user15999	password	27	40000	F
16000	LKXQAY	WAUGBOJAUZ	5713429376 Dell Way	\N	PGYYPQM	\N	0	Canada	2	WAUGBOJAUZ@dell.com	5713429376	2	9451650810893626	2008/06	user16000	password	28	60000	M
16001	NLNNKJ	OFPQTZQNZG	9248454082 Dell Way	\N	UXEKOQN	\N	0	Australia	2	OFPQTZQNZG@dell.com	9248454082	3	3312776351813227	2009/08	user16001	password	75	40000	F
16002	GTRQCF	VSVPSMDRSX	3625715389 Dell Way	\N	PXIDNVF	\N	0	France	2	VSVPSMDRSX@dell.com	3625715389	3	7935400116723032	2012/04	user16002	password	89	20000	F
16003	SRDVXY	NTNGGQYZON	3754085372 Dell Way	\N	WWQJSVV	\N	0	UK	2	NTNGGQYZON@dell.com	3754085372	3	8919305876828731	2010/07	user16003	password	83	20000	F
16004	PECMCQ	GQWMHVLVII	1646289866 Dell Way	\N	SYRKUMK	\N	0	Canada	2	GQWMHVLVII@dell.com	1646289866	2	6969103645533324	2011/03	user16004	password	69	100000	M
16005	WAGZQM	QNZXILTRTL	5483718752 Dell Way	\N	QLVKXFN	\N	0	UK	2	QNZXILTRTL@dell.com	5483718752	1	6634591902140529	2011/11	user16005	password	57	60000	M
16006	ORTFDJ	TDHCOATILJ	5283184824 Dell Way	\N	THURNHR	\N	0	Australia	2	TDHCOATILJ@dell.com	5283184824	2	7247276728507132	2009/10	user16006	password	26	20000	F
16007	UXPYGI	BNKQODYAMS	3995059364 Dell Way	\N	IGJVOBW	\N	0	Australia	2	BNKQODYAMS@dell.com	3995059364	3	4615455017425120	2008/09	user16007	password	57	60000	F
16008	KDJRLL	FVBUYAULTC	4321634618 Dell Way	\N	SDYGEUH	\N	0	France	2	FVBUYAULTC@dell.com	4321634618	4	6939984260126949	2008/03	user16008	password	32	60000	M
16009	IWITHO	OJIMKCYDFQ	8797015912 Dell Way	\N	GDXLYEY	\N	0	China	2	OJIMKCYDFQ@dell.com	8797015912	3	4148710059467703	2008/10	user16009	password	79	80000	F
16010	SBVAQK	JYXUAVXGLE	2339413969 Dell Way	\N	JIQHNOP	\N	0	China	2	JYXUAVXGLE@dell.com	2339413969	5	5331290226429701	2012/10	user16010	password	34	20000	M
16011	HXNXHW	WERXAPDMUM	4091827803 Dell Way	\N	VKUJYKT	\N	0	Australia	2	WERXAPDMUM@dell.com	4091827803	2	1352414939552545	2008/06	user16011	password	24	80000	M
16012	ZDRGAN	LSKMHNYBAU	1719842093 Dell Way	\N	LUDKEWM	\N	0	Germany	2	LSKMHNYBAU@dell.com	1719842093	3	7040631886105985	2010/08	user16012	password	40	40000	M
16013	LXWMLI	EVUMJTNJNZ	4496084528 Dell Way	\N	ERJJNWX	\N	0	Japan	2	EVUMJTNJNZ@dell.com	4496084528	3	2184763158205896	2008/11	user16013	password	46	80000	F
16014	IMVTUA	OPMYIAIWZN	4166554670 Dell Way	\N	OIWBFUR	\N	0	Germany	2	OPMYIAIWZN@dell.com	4166554670	5	6320383856538684	2009/03	user16014	password	32	60000	M
16015	RLGLLV	AYUJZCGYPU	4020988936 Dell Way	\N	HMVMGNB	\N	0	Japan	2	AYUJZCGYPU@dell.com	4020988936	4	8667793188709767	2010/11	user16015	password	49	20000	M
16016	WHYIDZ	GXIFAOEPIM	7041618394 Dell Way	\N	CEYJSAZ	\N	0	Australia	2	GXIFAOEPIM@dell.com	7041618394	5	6232816957402975	2010/04	user16016	password	64	20000	F
16017	YZLBZS	ZHYZWCOFOR	8272085090 Dell Way	\N	KNACNZD	\N	0	Canada	2	ZHYZWCOFOR@dell.com	8272085090	4	7486882315482945	2008/05	user16017	password	72	20000	F
16018	TPJSHI	AFHWIWCXON	5377227485 Dell Way	\N	KOPYOTD	\N	0	China	2	AFHWIWCXON@dell.com	5377227485	5	4829806005582214	2012/08	user16018	password	62	20000	F
16019	FNBNWB	TDYCABZPOK	3962513083 Dell Way	\N	DEISXMB	\N	0	China	2	TDYCABZPOK@dell.com	3962513083	3	3220842158421874	2012/02	user16019	password	46	40000	F
16020	XJVTKP	XJRYKQNYBR	9209057603 Dell Way	\N	CJJAVLK	\N	0	Canada	2	XJRYKQNYBR@dell.com	9209057603	4	2023269624914974	2008/01	user16020	password	47	40000	M
16021	TDSESQ	NJPXACWBUZ	1496679068 Dell Way	\N	LDZHOKL	\N	0	France	2	NJPXACWBUZ@dell.com	1496679068	3	5309028951916844	2008/12	user16021	password	75	20000	M
16022	YUXQLK	AAIBCECWEO	8617554910 Dell Way	\N	ADVPOHB	\N	0	Germany	2	AAIBCECWEO@dell.com	8617554910	3	7366526362486184	2012/04	user16022	password	74	60000	F
16023	OLXAVX	ADZCIBZNQA	2484436505 Dell Way	\N	QLPESQU	\N	0	Germany	2	ADZCIBZNQA@dell.com	2484436505	3	4546044343151152	2010/04	user16023	password	86	80000	M
16024	JQWFOW	INZRPYEFZV	3860530681 Dell Way	\N	ROAKEVY	\N	0	China	2	INZRPYEFZV@dell.com	3860530681	2	8471016981173308	2010/04	user16024	password	59	60000	M
16025	EHWTEE	GDWVCBABXR	4465974167 Dell Way	\N	PYBUTAD	\N	0	Australia	2	GDWVCBABXR@dell.com	4465974167	5	6973160847090185	2011/07	user16025	password	26	40000	M
16026	KELOJR	SGNUINVFFL	3662834199 Dell Way	\N	DHFXIIY	\N	0	Russia	2	SGNUINVFFL@dell.com	3662834199	4	4398013843689114	2012/09	user16026	password	69	60000	F
16027	WZSGQK	MDEURAAXLE	6704295318 Dell Way	\N	ERBMAAF	\N	0	China	2	MDEURAAXLE@dell.com	6704295318	3	2082366342190653	2009/04	user16027	password	64	60000	F
16028	PFKGQX	KUSBVTZGXD	4829845702 Dell Way	\N	YYQYYWG	\N	0	Germany	2	KUSBVTZGXD@dell.com	4829845702	2	9561111077666284	2011/01	user16028	password	51	100000	M
16029	RHWHFG	CYIXRHEOLD	7248093306 Dell Way	\N	MCBLYIA	\N	0	China	2	CYIXRHEOLD@dell.com	7248093306	5	1799478283617645	2011/06	user16029	password	88	40000	F
16030	GFKMMN	KVLBCPQOSC	5947545739 Dell Way	\N	RUOQCOA	\N	0	South Africa	2	KVLBCPQOSC@dell.com	5947545739	1	5648512450512499	2012/01	user16030	password	80	20000	F
16031	BNUNAF	ILHLBXAUZS	4864948714 Dell Way	\N	POIRDIM	\N	0	Japan	2	ILHLBXAUZS@dell.com	4864948714	1	6899696877226234	2010/11	user16031	password	73	100000	M
16032	HQLIVT	UCFVZFQZXF	4570121837 Dell Way	\N	NGXQOJI	\N	0	Australia	2	UCFVZFQZXF@dell.com	4570121837	5	5495445051696152	2009/09	user16032	password	41	20000	F
16033	YPIUJC	WPYWVOVTTJ	3588980823 Dell Way	\N	ZQAOAIO	\N	0	France	2	WPYWVOVTTJ@dell.com	3588980823	1	7045049769338221	2008/05	user16033	password	79	20000	F
16034	LICVLZ	KJVGXRZQBY	2196625671 Dell Way	\N	HBNHJBS	\N	0	Japan	2	KJVGXRZQBY@dell.com	2196625671	2	7131598535459489	2010/03	user16034	password	69	100000	M
16035	BYNMYY	VUETLDKNCR	1505051139 Dell Way	\N	OPZYRRP	\N	0	Russia	2	VUETLDKNCR@dell.com	1505051139	2	3837360749952495	2009/12	user16035	password	29	100000	F
16036	CMNBKJ	VOCHSNUUEJ	2705532759 Dell Way	\N	JDHBVXV	\N	0	South Africa	2	VOCHSNUUEJ@dell.com	2705532759	1	2421371607109904	2008/04	user16036	password	26	40000	F
16037	PTMZDH	OGPGTJBXSK	5276676058 Dell Way	\N	BAMXXIT	\N	0	Australia	2	OGPGTJBXSK@dell.com	5276676058	5	3483712107408792	2011/01	user16037	password	54	40000	M
16038	GSQJAE	PPLJZMHRXI	9233112944 Dell Way	\N	RJFPRZR	\N	0	Canada	2	PPLJZMHRXI@dell.com	9233112944	5	9613399577327074	2012/06	user16038	password	31	60000	M
16039	XFCXKS	NVBMHIEFRV	1289532154 Dell Way	\N	OXKGXCK	\N	0	South Africa	2	NVBMHIEFRV@dell.com	1289532154	2	7904217136092485	2010/07	user16039	password	43	20000	F
16040	OHKYZX	UAKBJOHAJV	8924285259 Dell Way	\N	YUCVWNQ	\N	0	UK	2	UAKBJOHAJV@dell.com	8924285259	3	4449676755815745	2010/10	user16040	password	59	100000	F
16041	VHGVFA	VPCEDJFMFD	1090940447 Dell Way	\N	HIZDVPB	\N	0	Japan	2	VPCEDJFMFD@dell.com	1090940447	3	2268028887920081	2011/01	user16041	password	21	20000	M
16042	IJROKM	DMRGWXTCAA	6935845427 Dell Way	\N	KAEFPFX	\N	0	Japan	2	DMRGWXTCAA@dell.com	6935845427	1	4460971537977457	2011/02	user16042	password	52	60000	F
16043	VEZFRC	SJJPGCRHDB	3307924508 Dell Way	\N	HIHXOFN	\N	0	Chile	2	SJJPGCRHDB@dell.com	3307924508	5	8817120967898519	2009/05	user16043	password	45	100000	F
16044	OUKGXD	PHSWKKDNLL	7755398544 Dell Way	\N	VTIKYWP	\N	0	Canada	2	PHSWKKDNLL@dell.com	7755398544	3	6030659245327116	2008/11	user16044	password	44	40000	F
16045	ETQBWG	IOCSYGGKRC	5849107398 Dell Way	\N	EAMCWCH	\N	0	Japan	2	IOCSYGGKRC@dell.com	5849107398	5	7614160312339664	2009/03	user16045	password	21	80000	F
16046	ULLQRU	FTNEZUPRWT	1036109481 Dell Way	\N	RJWOLDE	\N	0	UK	2	FTNEZUPRWT@dell.com	1036109481	5	4256264386232942	2009/12	user16046	password	28	80000	M
16047	PBKGWP	AJUADKRADJ	9682391701 Dell Way	\N	KZXVDBV	\N	0	Canada	2	AJUADKRADJ@dell.com	9682391701	1	4338292335160077	2012/04	user16047	password	89	80000	M
16048	AADXQD	GLEKVVLZFV	6915734383 Dell Way	\N	YCRCEMG	\N	0	Canada	2	GLEKVVLZFV@dell.com	6915734383	4	1538816438056528	2012/08	user16048	password	69	100000	M
16049	TANKEU	VIFRERQJNP	6028553702 Dell Way	\N	MERRRYV	\N	0	China	2	VIFRERQJNP@dell.com	6028553702	5	3643970361910760	2008/08	user16049	password	30	80000	F
16050	FISJCO	SIFXZWGMLT	1915119022 Dell Way	\N	QDKIBFQ	\N	0	Japan	2	SIFXZWGMLT@dell.com	1915119022	5	8053309383802117	2011/02	user16050	password	59	20000	F
16051	XTRZHJ	INGHJNUVHL	3558040905 Dell Way	\N	YRTAXJQ	\N	0	Australia	2	INGHJNUVHL@dell.com	3558040905	3	7359062545932830	2009/12	user16051	password	70	80000	M
16052	MIXUSF	HZNRNHMUSL	5496120427 Dell Way	\N	MLLKVCK	\N	0	Canada	2	HZNRNHMUSL@dell.com	5496120427	1	5321582892909646	2010/11	user16052	password	28	40000	F
16053	MGCEMK	EZBRGOLZZY	8645975233 Dell Way	\N	LLIGNTJ	\N	0	Australia	2	EZBRGOLZZY@dell.com	8645975233	5	5588796189054847	2011/12	user16053	password	83	20000	F
16054	ECQQMV	POMWDYVDWG	7123589937 Dell Way	\N	OENCXWC	\N	0	Russia	2	POMWDYVDWG@dell.com	7123589937	4	5098316082730890	2011/06	user16054	password	51	20000	M
16055	OTHBOX	QATTZPWVWL	2925706010 Dell Way	\N	AJNYFPS	\N	0	South Africa	2	QATTZPWVWL@dell.com	2925706010	1	5906480901408941	2011/08	user16055	password	65	40000	F
16056	KQFYOW	ZIPZXMUTYV	6315704416 Dell Way	\N	DLTIBLF	\N	0	Chile	2	ZIPZXMUTYV@dell.com	6315704416	4	9813363678287716	2009/05	user16056	password	42	40000	M
16057	ZPUNLT	VBSTONNMJQ	9445955751 Dell Way	\N	XCYZOEG	\N	0	Canada	2	VBSTONNMJQ@dell.com	9445955751	2	4024906311184168	2009/07	user16057	password	69	20000	M
16058	IYCTSY	VLRJZEVIVS	2363130640 Dell Way	\N	KUSZYYC	\N	0	South Africa	2	VLRJZEVIVS@dell.com	2363130640	3	3195510165300220	2011/02	user16058	password	48	40000	F
16059	JJFBHB	MZKMEFUZYF	7368993043 Dell Way	\N	TQESPHP	\N	0	Russia	2	MZKMEFUZYF@dell.com	7368993043	5	4957244570367038	2012/04	user16059	password	69	40000	M
16060	BNRIOE	HZQLEKKDQE	3770596405 Dell Way	\N	UUWJBMC	\N	0	Russia	2	HZQLEKKDQE@dell.com	3770596405	3	6661922744475306	2010/03	user16060	password	86	20000	F
16061	MVPBZX	AQIEBTIRYC	1449482625 Dell Way	\N	MVLNHNI	\N	0	Germany	2	AQIEBTIRYC@dell.com	1449482625	5	2307846586685627	2009/11	user16061	password	40	60000	F
16062	DDKDAK	UJPVDXMBAY	7699393090 Dell Way	\N	WLMDZUS	\N	0	Australia	2	UJPVDXMBAY@dell.com	7699393090	5	3744576757308096	2011/03	user16062	password	79	100000	F
16063	ZJLAUG	JJBMHONHMJ	1894204203 Dell Way	\N	TZNSUGT	\N	0	Germany	2	JJBMHONHMJ@dell.com	1894204203	1	2492988213896751	2009/11	user16063	password	28	60000	M
16064	NBXHHG	QITXWHFJQY	5259998384 Dell Way	\N	JEREKKS	\N	0	Germany	2	QITXWHFJQY@dell.com	5259998384	5	7981473296880723	2009/01	user16064	password	44	40000	M
16065	KEVSKL	BEJYLOHCMR	4889191051 Dell Way	\N	GEVQOOD	\N	0	Australia	2	BEJYLOHCMR@dell.com	4889191051	5	4780136527959258	2010/04	user16065	password	68	100000	M
16066	VULGGM	LPKWESYRJE	9212495579 Dell Way	\N	VFVJUZL	\N	0	Chile	2	LPKWESYRJE@dell.com	9212495579	5	6984886186663062	2009/07	user16066	password	64	100000	F
16067	LJQRVB	GFXLYWCIAX	5925248929 Dell Way	\N	OWHIWSO	\N	0	Russia	2	GFXLYWCIAX@dell.com	5925248929	2	9755021621473136	2008/11	user16067	password	83	60000	F
16068	GCYCDF	IBQGXSOYPC	2620258465 Dell Way	\N	VXLRPZL	\N	0	Canada	2	IBQGXSOYPC@dell.com	2620258465	3	2960055200383067	2008/04	user16068	password	66	40000	M
16069	TGQXLY	ZCFXUUVKWQ	2263539025 Dell Way	\N	HIIXHTA	\N	0	France	2	ZCFXUUVKWQ@dell.com	2263539025	2	5474555458873511	2010/12	user16069	password	76	100000	M
16070	BQPNPO	PVLKPHULXC	3334398393 Dell Way	\N	UFZBZAN	\N	0	Canada	2	PVLKPHULXC@dell.com	3334398393	1	5938131818547845	2008/10	user16070	password	58	100000	M
16071	ELKUZZ	PLJESEQQGK	1322811838 Dell Way	\N	VFMVGAX	\N	0	France	2	PLJESEQQGK@dell.com	1322811838	3	7013532296288759	2012/01	user16071	password	56	80000	F
16072	YDZYDP	JMUBQKRXVN	7434317296 Dell Way	\N	CHIIIGV	\N	0	China	2	JMUBQKRXVN@dell.com	7434317296	3	2968688657041639	2011/01	user16072	password	88	100000	M
16073	CYXGNH	SHJJSBGOOJ	1299344965 Dell Way	\N	WXSEENN	\N	0	South Africa	2	SHJJSBGOOJ@dell.com	1299344965	4	6374010795261711	2008/09	user16073	password	56	20000	M
16074	LYBZGU	HPDZQKOFUK	8332239553 Dell Way	\N	CMOGACD	\N	0	Australia	2	HPDZQKOFUK@dell.com	8332239553	4	1871279732324183	2010/04	user16074	password	27	40000	M
16075	BKRHEZ	XIYNTMSNXV	9247596416 Dell Way	\N	ALBANFB	\N	0	China	2	XIYNTMSNXV@dell.com	9247596416	1	8744181449525059	2008/04	user16075	password	33	100000	F
16076	POQUNN	DMBXZTKWPL	6800613855 Dell Way	\N	HQLVVME	\N	0	Russia	2	DMBXZTKWPL@dell.com	6800613855	1	9346264149062336	2012/03	user16076	password	76	40000	M
16077	JXQWLU	JMRIGCEVNM	5627341238 Dell Way	\N	MZIILMC	\N	0	Canada	2	JMRIGCEVNM@dell.com	5627341238	1	1242653770837932	2011/10	user16077	password	39	60000	F
16078	FGBQAL	DSTKVYGJLT	2970775692 Dell Way	\N	ITCUGFX	\N	0	Russia	2	DSTKVYGJLT@dell.com	2970775692	5	5630564553663135	2008/03	user16078	password	25	40000	F
16079	IHBJSF	CMQXKXGWRP	2729045535 Dell Way	\N	QTJWYHQ	\N	0	Canada	2	CMQXKXGWRP@dell.com	2729045535	1	2862025251146406	2010/04	user16079	password	49	100000	M
16080	TXZLDB	YTYJRFFIUV	5908984391 Dell Way	\N	BESALJE	\N	0	Japan	2	YTYJRFFIUV@dell.com	5908984391	2	1389759830199182	2012/10	user16080	password	81	60000	M
16081	UKAXLY	RKHIPNRKJT	3924340174 Dell Way	\N	OBTALYR	\N	0	UK	2	RKHIPNRKJT@dell.com	3924340174	4	8335076547227801	2008/07	user16081	password	35	80000	F
16082	QSGCRX	MYGCLXMVRB	4932501795 Dell Way	\N	XLCIJTI	\N	0	Japan	2	MYGCLXMVRB@dell.com	4932501795	1	8524171042256058	2008/05	user16082	password	57	40000	F
16083	GPCYNP	WURIREDJFA	8799983093 Dell Way	\N	UHJDASV	\N	0	France	2	WURIREDJFA@dell.com	8799983093	4	5337718970142305	2009/03	user16083	password	78	40000	F
16084	LKKYZH	SRQKVUTAVO	2577445074 Dell Way	\N	IERJXNV	\N	0	Russia	2	SRQKVUTAVO@dell.com	2577445074	2	1233430982567369	2009/02	user16084	password	40	100000	M
16085	SGOSNG	JDREXLFTZN	1530426387 Dell Way	\N	XRXVETP	\N	0	China	2	JDREXLFTZN@dell.com	1530426387	4	7559555394109339	2009/12	user16085	password	60	100000	M
16086	VJIJPR	NHWLSBEROB	1788783599 Dell Way	\N	IMXNFMW	\N	0	Chile	2	NHWLSBEROB@dell.com	1788783599	3	5309727218933404	2008/03	user16086	password	38	80000	F
16087	QZJGRW	NNHFOLXDNG	2773231308 Dell Way	\N	PKTUXPB	\N	0	UK	2	NNHFOLXDNG@dell.com	2773231308	3	9980639576446266	2009/10	user16087	password	65	40000	F
16088	QSSHPF	UXLJIIMWPC	5497632401 Dell Way	\N	HIXEYYE	\N	0	Canada	2	UXLJIIMWPC@dell.com	5497632401	1	5521073927637190	2009/10	user16088	password	81	80000	F
16089	PNSESN	BEWKMJHCLO	2010927192 Dell Way	\N	KITJHYM	\N	0	South Africa	2	BEWKMJHCLO@dell.com	2010927192	5	2190062520094216	2012/11	user16089	password	85	40000	F
16090	LCQEPS	IMDVWKXIZH	2036756052 Dell Way	\N	RTQYRDT	\N	0	South Africa	2	IMDVWKXIZH@dell.com	2036756052	5	7575499999336899	2012/10	user16090	password	25	60000	F
16091	FBKUTS	HXOEHLMHTD	7579038570 Dell Way	\N	BKCSNVN	\N	0	Japan	2	HXOEHLMHTD@dell.com	7579038570	2	6408100900705904	2010/05	user16091	password	19	100000	M
16092	BFJVYR	TMVBXHIRKJ	9023093485 Dell Way	\N	BMCOIQF	\N	0	Australia	2	TMVBXHIRKJ@dell.com	9023093485	4	6387854417786003	2009/10	user16092	password	47	100000	M
16093	QESOVL	BQMYXVQIFR	2958068416 Dell Way	\N	UHFCYKD	\N	0	South Africa	2	BQMYXVQIFR@dell.com	2958068416	4	1658849788364023	2008/02	user16093	password	82	100000	M
16094	BQIWCJ	NPIKLYTQPN	5685072828 Dell Way	\N	YVQWGUR	\N	0	France	2	NPIKLYTQPN@dell.com	5685072828	4	5612728773150594	2011/08	user16094	password	49	60000	M
16095	BUOEDB	UMMFKFVAST	1455676097 Dell Way	\N	WIQDCHP	\N	0	Japan	2	UMMFKFVAST@dell.com	1455676097	1	3780123629141599	2011/07	user16095	password	72	40000	M
16096	NXVRYP	DLUOQQOJKL	3756680799 Dell Way	\N	SAOVIEL	\N	0	China	2	DLUOQQOJKL@dell.com	3756680799	4	1548602754250168	2012/07	user16096	password	48	60000	F
16097	IHRHXV	SSJIIXRTJJ	4411857759 Dell Way	\N	UYECCQM	\N	0	France	2	SSJIIXRTJJ@dell.com	4411857759	3	3484568616375327	2012/12	user16097	password	74	100000	F
16098	BPOZKG	RUPASGUBQO	7398353500 Dell Way	\N	ZVRCLEM	\N	0	South Africa	2	RUPASGUBQO@dell.com	7398353500	4	7312079581432045	2011/07	user16098	password	62	100000	M
16099	FNPQUH	KJHCQBDGQD	5416888241 Dell Way	\N	BHFNLSI	\N	0	Canada	2	KJHCQBDGQD@dell.com	5416888241	1	8573253862094135	2008/08	user16099	password	77	80000	M
16100	IGMDNX	MVZDXDKNHM	4087857203 Dell Way	\N	VMZHFIL	\N	0	Russia	2	MVZDXDKNHM@dell.com	4087857203	2	7646339540835471	2012/01	user16100	password	47	100000	F
16101	RIOEGB	AGEYKOLRAH	3200740577 Dell Way	\N	EAOJIZC	\N	0	Japan	2	AGEYKOLRAH@dell.com	3200740577	5	6914189665578306	2009/03	user16101	password	55	80000	M
16102	WHBCIC	INATBMKCTO	8630170387 Dell Way	\N	CHYLGAC	\N	0	France	2	INATBMKCTO@dell.com	8630170387	4	8391842211131007	2008/04	user16102	password	59	100000	F
16103	WZFFCO	SCHUOSWHHZ	3725116258 Dell Way	\N	OFLVGNI	\N	0	Canada	2	SCHUOSWHHZ@dell.com	3725116258	1	2539724042173475	2010/09	user16103	password	25	80000	M
16104	CYTFMM	HUGWNDDUDS	9908581746 Dell Way	\N	AONHCWJ	\N	0	China	2	HUGWNDDUDS@dell.com	9908581746	3	9693236111197622	2011/08	user16104	password	66	40000	M
16105	PAYCNG	XTCKXGEAYE	4399177038 Dell Way	\N	OMLQIVA	\N	0	China	2	XTCKXGEAYE@dell.com	4399177038	1	1199909149203449	2008/09	user16105	password	39	80000	F
16106	ITJVAG	PCQMIUMHZB	7698478037 Dell Way	\N	TLSCGTK	\N	0	Japan	2	PCQMIUMHZB@dell.com	7698478037	3	7086036031134427	2010/09	user16106	password	52	80000	F
16107	FBXFHM	IXZQSMYSNR	6830737430 Dell Way	\N	DGUKZFB	\N	0	Russia	2	IXZQSMYSNR@dell.com	6830737430	4	2254383204039186	2009/03	user16107	password	77	60000	F
16108	WIQDVZ	BUQUHOMVGP	7953708976 Dell Way	\N	BAAAFBT	\N	0	South Africa	2	BUQUHOMVGP@dell.com	7953708976	5	3261760950088501	2012/09	user16108	password	68	40000	M
16109	AASVAU	QQOXEASKQT	4921378804 Dell Way	\N	LQURSON	\N	0	France	2	QQOXEASKQT@dell.com	4921378804	4	4909861939959228	2008/06	user16109	password	77	80000	F
16110	WLIWFY	NTWRUPCKJN	5581702936 Dell Way	\N	BDFTSSF	\N	0	Canada	2	NTWRUPCKJN@dell.com	5581702936	4	3484997526742518	2012/06	user16110	password	90	60000	F
16111	LUFQTS	KQJEFMPOAQ	3294631744 Dell Way	\N	SFKKYPN	\N	0	France	2	KQJEFMPOAQ@dell.com	3294631744	5	4876704627182335	2011/10	user16111	password	83	20000	F
16112	RGWLZH	BILHVBVWRO	3520031903 Dell Way	\N	BBYARML	\N	0	UK	2	BILHVBVWRO@dell.com	3520031903	5	6848418158013374	2008/10	user16112	password	69	40000	F
16113	ZFXYMZ	HYGCZCYQQA	4303985922 Dell Way	\N	SOAJBMH	\N	0	China	2	HYGCZCYQQA@dell.com	4303985922	5	4622453805990517	2008/08	user16113	password	70	80000	M
16114	XOOKNV	IUYHWXYMXQ	3271375588 Dell Way	\N	BYACKHK	\N	0	Russia	2	IUYHWXYMXQ@dell.com	3271375588	5	9453597319312396	2012/07	user16114	password	59	60000	F
16115	CCVQYE	KWLGUJTRAU	1655146881 Dell Way	\N	QAWBIGV	\N	0	Germany	2	KWLGUJTRAU@dell.com	1655146881	4	5437566266860813	2010/05	user16115	password	19	20000	F
16116	DWCBBN	XMTRWNJWHA	6960878957 Dell Way	\N	XEBGLXV	\N	0	Germany	2	XMTRWNJWHA@dell.com	6960878957	2	1914155082311481	2008/05	user16116	password	28	60000	F
16117	AONBBL	OVDKINHQNF	6098253645 Dell Way	\N	UOLFLGS	\N	0	Canada	2	OVDKINHQNF@dell.com	6098253645	5	2054832779336720	2012/12	user16117	password	59	40000	M
16118	DWBEHP	ZLAIYIYLNS	5110394669 Dell Way	\N	ZYYLEQO	\N	0	Russia	2	ZLAIYIYLNS@dell.com	5110394669	4	6941603392362595	2010/04	user16118	password	20	60000	F
16119	XLOFBN	QCVOKUZXMZ	7060640926 Dell Way	\N	VKLABZT	\N	0	Germany	2	QCVOKUZXMZ@dell.com	7060640926	3	9362596467603000	2012/06	user16119	password	42	40000	F
16120	UVOWJF	YFTIZTFMSB	3292548376 Dell Way	\N	XEBYEVM	\N	0	South Africa	2	YFTIZTFMSB@dell.com	3292548376	2	7817134710960091	2011/09	user16120	password	22	20000	M
16121	XQJHVI	MPQMIWZBXW	7144308400 Dell Way	\N	FYVJUHF	\N	0	Australia	2	MPQMIWZBXW@dell.com	7144308400	5	7769868433941156	2010/01	user16121	password	77	100000	M
16122	LHFHPS	WGFFCEGZBM	1453521361 Dell Way	\N	YWWTECU	\N	0	South Africa	2	WGFFCEGZBM@dell.com	1453521361	3	3293593230657279	2008/05	user16122	password	31	20000	M
16123	MFCCYZ	IDELHLLIXJ	5007429195 Dell Way	\N	FUDJWXF	\N	0	UK	2	IDELHLLIXJ@dell.com	5007429195	3	9844733629841358	2012/08	user16123	password	90	80000	F
16124	FSGDRP	GVAOGLXEVC	2567602423 Dell Way	\N	YYMUWSS	\N	0	China	2	GVAOGLXEVC@dell.com	2567602423	4	1924959213007241	2012/09	user16124	password	70	100000	M
16125	KFACUG	XVVEGSICUH	4927725116 Dell Way	\N	AHBWZTE	\N	0	Canada	2	XVVEGSICUH@dell.com	4927725116	2	9913574481382968	2008/01	user16125	password	88	100000	F
16126	EZNZGL	UCPBUYDPFE	5671584292 Dell Way	\N	WHBWBGA	\N	0	France	2	UCPBUYDPFE@dell.com	5671584292	1	6234005511272699	2010/12	user16126	password	59	100000	F
16127	OLDVWY	XMARKDHQID	1066105182 Dell Way	\N	XJZYPAL	\N	0	Canada	2	XMARKDHQID@dell.com	1066105182	1	6750823778565974	2012/07	user16127	password	60	20000	F
16128	AHZXGW	KGOVKVLSZJ	7962048688 Dell Way	\N	CZIRZTU	\N	0	UK	2	KGOVKVLSZJ@dell.com	7962048688	3	9575174871832132	2009/01	user16128	password	24	60000	F
16129	JMYPII	WXDGSPZRZB	9876992729 Dell Way	\N	QHTPBOP	\N	0	South Africa	2	WXDGSPZRZB@dell.com	9876992729	3	2600341408513486	2008/08	user16129	password	67	20000	F
16130	DAQMJM	JNTCCSUBTL	2621730281 Dell Way	\N	JNBKBQG	\N	0	Australia	2	JNTCCSUBTL@dell.com	2621730281	3	1382773790508508	2012/02	user16130	password	25	100000	F
16131	CLSMXC	ZQFCJZEDKN	6454288259 Dell Way	\N	QLYRCES	\N	0	Chile	2	ZQFCJZEDKN@dell.com	6454288259	4	1811386352870613	2011/11	user16131	password	84	100000	M
16132	JRLGTK	XZMGYRJJEZ	2080098174 Dell Way	\N	VDRXIJF	\N	0	UK	2	XZMGYRJJEZ@dell.com	2080098174	2	6695197802037001	2012/03	user16132	password	59	100000	M
16133	GJUZTS	ZGZXXJHCJC	5402554701 Dell Way	\N	GAAOKFM	\N	0	Germany	2	ZGZXXJHCJC@dell.com	5402554701	1	5370039584580809	2011/09	user16133	password	48	40000	M
16134	TAYNTX	USVRCCULEA	3002984194 Dell Way	\N	MEPWKCJ	\N	0	South Africa	2	USVRCCULEA@dell.com	3002984194	5	6050990251358599	2012/04	user16134	password	75	100000	F
16135	VUOOSJ	HNBJPVVTWH	4663126890 Dell Way	\N	YLEIONF	\N	0	Russia	2	HNBJPVVTWH@dell.com	4663126890	4	7312044913880528	2011/07	user16135	password	59	80000	F
16136	JHYBRG	OSQEOMYKTW	2915090526 Dell Way	\N	WXFKLLF	\N	0	South Africa	2	OSQEOMYKTW@dell.com	2915090526	5	5878693467471749	2011/06	user16136	password	38	20000	M
16137	PDXGKM	YAQMMOXGLT	3564883233 Dell Way	\N	EREPCKM	\N	0	China	2	YAQMMOXGLT@dell.com	3564883233	1	1889817564282566	2011/04	user16137	password	37	60000	M
16138	KMCUYB	VOOIDLOOFS	8239209003 Dell Way	\N	GKIJUUR	\N	0	Australia	2	VOOIDLOOFS@dell.com	8239209003	4	8353320501279087	2008/01	user16138	password	46	100000	F
16139	WBFUDA	IRIMDXBIQH	1732379049 Dell Way	\N	TYQNTIP	\N	0	Germany	2	IRIMDXBIQH@dell.com	1732379049	3	6756626297719777	2008/10	user16139	password	61	60000	M
16140	RTLUUU	MCGPZHYPOR	2481198622 Dell Way	\N	OFEINTW	\N	0	Japan	2	MCGPZHYPOR@dell.com	2481198622	3	7476024502888323	2012/02	user16140	password	37	80000	M
16141	ABOUVA	XCPXJNNYEC	7943447967 Dell Way	\N	DJKRCGH	\N	0	Chile	2	XCPXJNNYEC@dell.com	7943447967	5	3124598581343889	2012/04	user16141	password	79	80000	F
16142	XECSEA	UUXEHLDMNH	2881171165 Dell Way	\N	VYYYFFF	\N	0	UK	2	UUXEHLDMNH@dell.com	2881171165	3	8538209124933929	2010/04	user16142	password	51	80000	F
16143	QVXVWS	PTXWFAJSHE	7677331388 Dell Way	\N	RFCWLHV	\N	0	Japan	2	PTXWFAJSHE@dell.com	7677331388	4	2114129861816764	2008/02	user16143	password	82	40000	M
16144	SDOOWE	ITBNTKGBOX	3096227004 Dell Way	\N	HRTSYPJ	\N	0	Russia	2	ITBNTKGBOX@dell.com	3096227004	3	7600099032744766	2009/05	user16144	password	87	20000	F
16145	CRRYWA	RXOLHUNWSU	4658704728 Dell Way	\N	NMNMBXE	\N	0	Chile	2	RXOLHUNWSU@dell.com	4658704728	5	6658468407113106	2011/11	user16145	password	72	100000	M
16146	LPXHPO	EDAMYOIQIW	4863084059 Dell Way	\N	CWIDTNL	\N	0	Canada	2	EDAMYOIQIW@dell.com	4863084059	1	9561653194017708	2009/10	user16146	password	80	40000	F
16147	LDNASR	ETECHMTQIW	5319537373 Dell Way	\N	MRAFELJ	\N	0	Japan	2	ETECHMTQIW@dell.com	5319537373	2	9239164787810296	2009/03	user16147	password	29	60000	M
16148	HZQARV	TVYAIRQRNC	1367228515 Dell Way	\N	IOINZSD	\N	0	France	2	TVYAIRQRNC@dell.com	1367228515	1	7478164486587048	2009/03	user16148	password	33	100000	M
16149	FMNWIG	SGHAYXSLAA	8034304633 Dell Way	\N	ZJOZBSK	\N	0	Canada	2	SGHAYXSLAA@dell.com	8034304633	1	3960450075101107	2008/05	user16149	password	30	60000	M
16150	RBLZHD	GPEENWQNXQ	2211349922 Dell Way	\N	XMPYEAB	\N	0	UK	2	GPEENWQNXQ@dell.com	2211349922	2	9828096583019944	2010/07	user16150	password	55	20000	F
16151	OMFWQL	LUQYRGMPWJ	7900238426 Dell Way	\N	BLIGLJG	\N	0	Germany	2	LUQYRGMPWJ@dell.com	7900238426	2	1653622938320040	2009/09	user16151	password	25	60000	F
16152	PUDFFP	AWNSCAHYKJ	1644335626 Dell Way	\N	KSQWCWM	\N	0	South Africa	2	AWNSCAHYKJ@dell.com	1644335626	3	2771209865808487	2011/08	user16152	password	72	20000	F
16153	NFLTUL	PIDSILRSUB	9447643238 Dell Way	\N	LKYOGKL	\N	0	China	2	PIDSILRSUB@dell.com	9447643238	4	2192700418177992	2010/05	user16153	password	32	100000	M
16154	KGQERG	MVYVGPOBRZ	6338992716 Dell Way	\N	LPOSAZB	\N	0	UK	2	MVYVGPOBRZ@dell.com	6338992716	1	5838265930768103	2012/05	user16154	password	43	100000	M
16155	PNZHTM	CSIIIWKZWV	8187003450 Dell Way	\N	PKOQJPO	\N	0	UK	2	CSIIIWKZWV@dell.com	8187003450	1	9447482653893532	2008/06	user16155	password	76	100000	F
16156	HZIBLK	UTTCQDCMZR	9794228057 Dell Way	\N	XNHGDWG	\N	0	UK	2	UTTCQDCMZR@dell.com	9794228057	1	2140634403564036	2010/12	user16156	password	26	60000	F
16157	CUJNED	HYFXBHJBZH	9590418444 Dell Way	\N	PHNSDUR	\N	0	Canada	2	HYFXBHJBZH@dell.com	9590418444	4	6052020932082087	2012/11	user16157	password	20	40000	M
16158	VONASU	YYSAGCBFJR	8288737803 Dell Way	\N	NXJRRAU	\N	0	Japan	2	YYSAGCBFJR@dell.com	8288737803	2	5977303834166378	2011/05	user16158	password	74	80000	F
16159	IEFBZE	ZREFTGLDYY	7871993529 Dell Way	\N	AHQRIKH	\N	0	Canada	2	ZREFTGLDYY@dell.com	7871993529	5	8539942217525096	2008/08	user16159	password	55	40000	M
16160	SOARTZ	JYFDFQGDPG	1848265959 Dell Way	\N	KFYTQGW	\N	0	China	2	JYFDFQGDPG@dell.com	1848265959	4	5924589659553022	2011/03	user16160	password	84	80000	M
16161	MRQFRZ	EWCJNJMDPX	3326584862 Dell Way	\N	JORZUOK	\N	0	South Africa	2	EWCJNJMDPX@dell.com	3326584862	5	6438581591006369	2010/11	user16161	password	38	60000	F
16162	ZBORAS	ODBBMOFCMO	8829279748 Dell Way	\N	QDOLRYI	\N	0	UK	2	ODBBMOFCMO@dell.com	8829279748	5	4892660757526756	2011/03	user16162	password	80	20000	F
16163	XPVYHJ	BJLNYRQKFG	9536541980 Dell Way	\N	OUSFSAE	\N	0	Germany	2	BJLNYRQKFG@dell.com	9536541980	3	3668941275216639	2008/06	user16163	password	41	40000	F
16164	XFHEPJ	OAXMSNWXUL	4758655562 Dell Way	\N	SMRKNVA	\N	0	France	2	OAXMSNWXUL@dell.com	4758655562	2	6627862621098757	2012/08	user16164	password	89	40000	M
16165	EOSTXH	UUTMIQKCBC	8510197441 Dell Way	\N	PSNDONP	\N	0	UK	2	UUTMIQKCBC@dell.com	8510197441	2	8557181541807950	2010/03	user16165	password	24	20000	F
16166	QTCNAW	IUJRKTUMWK	3901198150 Dell Way	\N	FJNTXCS	\N	0	Russia	2	IUJRKTUMWK@dell.com	3901198150	3	2779772700741887	2010/08	user16166	password	32	100000	F
16167	YZVYWD	SFVDYPPUZV	8449121488 Dell Way	\N	EMOBPHU	\N	0	UK	2	SFVDYPPUZV@dell.com	8449121488	5	4890185828786344	2010/03	user16167	password	40	80000	F
16168	HOBDRU	INXHCNCBIG	2023941153 Dell Way	\N	OXIEEDC	\N	0	Australia	2	INXHCNCBIG@dell.com	2023941153	3	5201408408116549	2009/10	user16168	password	32	60000	F
16169	TNFLHO	YFVATXCBER	4820681817 Dell Way	\N	ZMVDQXD	\N	0	Russia	2	YFVATXCBER@dell.com	4820681817	4	1357068257872015	2009/10	user16169	password	52	40000	M
16170	ZOZHCY	NYZGVCIATH	2639913060 Dell Way	\N	NPLDNOW	\N	0	UK	2	NYZGVCIATH@dell.com	2639913060	5	2520848440472036	2012/05	user16170	password	54	60000	F
16171	BORDME	BMKXOSXIAL	3963165836 Dell Way	\N	XLOKALJ	\N	0	Canada	2	BMKXOSXIAL@dell.com	3963165836	3	2677879591006785	2011/01	user16171	password	72	20000	F
16172	HTFUXG	HIEVBBEBNC	4393934555 Dell Way	\N	MCNNNWS	\N	0	South Africa	2	HIEVBBEBNC@dell.com	4393934555	5	5897403920534999	2009/08	user16172	password	63	60000	M
16173	JQSHXZ	PBVQDZSQBE	3344866086 Dell Way	\N	SORGLJB	\N	0	South Africa	2	PBVQDZSQBE@dell.com	3344866086	4	2842393735889345	2012/03	user16173	password	66	100000	M
16174	INWFNM	HICLIUCKZU	7561888517 Dell Way	\N	ZRBKBCF	\N	0	China	2	HICLIUCKZU@dell.com	7561888517	3	2787955579813570	2012/02	user16174	password	18	60000	F
16175	NLQAXX	JAISUKCUFC	2309384971 Dell Way	\N	MHNNKSV	\N	0	Canada	2	JAISUKCUFC@dell.com	2309384971	1	1730278288479894	2009/01	user16175	password	65	80000	M
16176	CGPZEY	ANRVYUPEWB	5192361849 Dell Way	\N	LJPVCLY	\N	0	Chile	2	ANRVYUPEWB@dell.com	5192361849	1	5125092604663223	2010/09	user16176	password	24	20000	M
16177	JQTNPT	BHPZBEEXGP	4442955349 Dell Way	\N	GVLIHJO	\N	0	Russia	2	BHPZBEEXGP@dell.com	4442955349	1	3187037079595029	2008/02	user16177	password	40	100000	F
16178	YOAOIB	VXBXCGUJVB	1043405061 Dell Way	\N	EGKMQZF	\N	0	Australia	2	VXBXCGUJVB@dell.com	1043405061	3	1523419091477990	2008/10	user16178	password	81	80000	M
16179	LQHUSD	RUAUAUDVWI	4870086435 Dell Way	\N	CHUSGZS	\N	0	Chile	2	RUAUAUDVWI@dell.com	4870086435	4	4416250572539866	2008/08	user16179	password	90	100000	F
16180	QEWIHO	CHICCLYZTA	3356543410 Dell Way	\N	GNTMNMT	\N	0	UK	2	CHICCLYZTA@dell.com	3356543410	1	2128540260251611	2012/02	user16180	password	19	20000	M
16181	EWAMKD	TTFWEDVYEB	4607432270 Dell Way	\N	LXOZJHX	\N	0	Japan	2	TTFWEDVYEB@dell.com	4607432270	1	6032295074313880	2010/01	user16181	password	59	40000	F
16182	LGSWJM	PPJUTESXGE	1868081470 Dell Way	\N	UUDECBV	\N	0	France	2	PPJUTESXGE@dell.com	1868081470	2	9986650402657688	2008/12	user16182	password	34	40000	F
16183	MCGWPW	MYQFDICJNX	3316291118 Dell Way	\N	EQBHSWT	\N	0	Russia	2	MYQFDICJNX@dell.com	3316291118	4	9572301274631172	2009/12	user16183	password	43	60000	F
16184	LWIBSU	ZIZCRCMFZR	5169849821 Dell Way	\N	VAYOXSI	\N	0	Canada	2	ZIZCRCMFZR@dell.com	5169849821	2	4381052802782506	2010/08	user16184	password	89	100000	F
16185	VGDOBD	XBFODSTCJP	8059285370 Dell Way	\N	DHDBZMF	\N	0	France	2	XBFODSTCJP@dell.com	8059285370	4	9053301080595704	2010/07	user16185	password	77	60000	F
16186	CRYDUV	FAKISELBUP	5419744928 Dell Way	\N	JYRIKXU	\N	0	Canada	2	FAKISELBUP@dell.com	5419744928	4	6630663094576449	2008/06	user16186	password	28	60000	M
16187	VKSPGX	QQGIVSKPHT	5952330104 Dell Way	\N	NZCYWWD	\N	0	China	2	QQGIVSKPHT@dell.com	5952330104	4	4698295570909977	2008/11	user16187	password	82	80000	M
16188	HIIOGY	FMHAFSQNMD	9846041416 Dell Way	\N	MPCIMFR	\N	0	Australia	2	FMHAFSQNMD@dell.com	9846041416	1	1497306994628161	2012/12	user16188	password	66	80000	F
16189	ZYVFXA	SFBXYSKKVW	9363068067 Dell Way	\N	AYFMDWM	\N	0	Canada	2	SFBXYSKKVW@dell.com	9363068067	3	1269437920302152	2012/03	user16189	password	65	20000	F
16190	PZKNAD	TBARTLCPIC	6239759784 Dell Way	\N	ONOSJBV	\N	0	China	2	TBARTLCPIC@dell.com	6239759784	5	2756627114489674	2011/07	user16190	password	43	100000	F
16191	IKQINK	KOBEZEUIGI	7465232521 Dell Way	\N	VVAFWWN	\N	0	France	2	KOBEZEUIGI@dell.com	7465232521	4	3020328648854047	2009/01	user16191	password	32	40000	F
16192	PASCKC	QLHQPBYWJU	3202402222 Dell Way	\N	RKANGNZ	\N	0	UK	2	QLHQPBYWJU@dell.com	3202402222	1	2781738546211272	2009/05	user16192	password	58	80000	M
16193	OKCYNT	KUKAVIXFDO	3448369020 Dell Way	\N	PDCVRBU	\N	0	UK	2	KUKAVIXFDO@dell.com	3448369020	5	2954525248147547	2011/07	user16193	password	84	80000	F
16194	HTBVNM	PXMKGJPJYE	8199707641 Dell Way	\N	NBAEDUB	\N	0	China	2	PXMKGJPJYE@dell.com	8199707641	2	1581798552535474	2009/03	user16194	password	70	60000	M
16195	MNIZZX	WMICWXMUCZ	5567458156 Dell Way	\N	VCDZXFJ	\N	0	Russia	2	WMICWXMUCZ@dell.com	5567458156	3	1497940180357545	2011/02	user16195	password	55	40000	M
16196	ANPZLM	MTPIQBCTAY	7293918059 Dell Way	\N	VEXTJHL	\N	0	South Africa	2	MTPIQBCTAY@dell.com	7293918059	3	6378595868125558	2012/01	user16196	password	77	60000	F
16197	JCAUOM	NEVEFXXGWT	5282595538 Dell Way	\N	KUNUBZR	\N	0	Russia	2	NEVEFXXGWT@dell.com	5282595538	2	6526629217434675	2010/02	user16197	password	24	60000	F
16198	EOFTBT	XWYCUWIRPT	5308180380 Dell Way	\N	MDNNCFH	\N	0	Germany	2	XWYCUWIRPT@dell.com	5308180380	5	1487465802114456	2010/01	user16198	password	60	100000	F
16199	EFYFZV	CXYXTHPJAB	8090019131 Dell Way	\N	MOOOTWD	\N	0	Chile	2	CXYXTHPJAB@dell.com	8090019131	1	8309205119963736	2011/10	user16199	password	77	100000	M
16200	AXDZSG	XRDQYSAZTM	3964836387 Dell Way	\N	NIAHFEO	\N	0	Australia	2	XRDQYSAZTM@dell.com	3964836387	2	8173432558774949	2008/03	user16200	password	74	20000	F
16201	RDFKKC	BNTAGTZAFN	7574311282 Dell Way	\N	JGVPKJP	\N	0	Russia	2	BNTAGTZAFN@dell.com	7574311282	2	8449248344637454	2012/02	user16201	password	78	20000	M
16202	ZHFJKH	XDHEWGECTO	2146297598 Dell Way	\N	IPDTYTM	\N	0	Japan	2	XDHEWGECTO@dell.com	2146297598	2	6266017227433622	2009/02	user16202	password	68	20000	F
16203	ZIMKQK	NXOKETMYIV	4054513209 Dell Way	\N	NLOMFAD	\N	0	China	2	NXOKETMYIV@dell.com	4054513209	4	6494075724389405	2010/06	user16203	password	70	80000	F
16204	BCVRMJ	PBTTVGRDBF	5834237986 Dell Way	\N	PPRUQUC	\N	0	UK	2	PBTTVGRDBF@dell.com	5834237986	4	5109453612007201	2012/06	user16204	password	22	40000	M
16205	EFEQOU	SINNOFRPKG	8686051471 Dell Way	\N	FBAVWDV	\N	0	France	2	SINNOFRPKG@dell.com	8686051471	2	4325930595397949	2009/04	user16205	password	72	100000	F
16206	YZDNTW	VHJJMAZXHE	1811970454 Dell Way	\N	ZHAVLVG	\N	0	Chile	2	VHJJMAZXHE@dell.com	1811970454	4	6286268626339734	2010/05	user16206	password	46	100000	F
16207	JBVDXR	LGBYHAVOEU	5337078957 Dell Way	\N	WFQHAWP	\N	0	Canada	2	LGBYHAVOEU@dell.com	5337078957	1	5752696581650526	2012/07	user16207	password	49	20000	M
16208	MACJRN	QTMXTHMYCJ	4970947150 Dell Way	\N	DSREPGG	\N	0	Australia	2	QTMXTHMYCJ@dell.com	4970947150	4	9207552724983544	2008/03	user16208	password	24	100000	M
16209	CBBUPR	NCPGJCFMLI	6040058141 Dell Way	\N	ECMTJTV	\N	0	South Africa	2	NCPGJCFMLI@dell.com	6040058141	4	8389953982084990	2011/10	user16209	password	75	60000	M
16210	WOSMFF	OVMYXRKJAO	9010501968 Dell Way	\N	LNIVHEQ	\N	0	South Africa	2	OVMYXRKJAO@dell.com	9010501968	3	6729207851924003	2011/03	user16210	password	26	80000	F
16211	RIPWOD	SABPSLZTAK	3960016005 Dell Way	\N	GJGONWK	\N	0	China	2	SABPSLZTAK@dell.com	3960016005	1	1948234563693404	2010/02	user16211	password	71	80000	M
16212	BGSPJK	QLAIXZBXKI	3723794247 Dell Way	\N	GQWTNGE	\N	0	South Africa	2	QLAIXZBXKI@dell.com	3723794247	2	4744352213572711	2010/01	user16212	password	24	40000	F
16213	JZRTJH	EJQBISZTAG	4880976803 Dell Way	\N	JXAXEET	\N	0	France	2	EJQBISZTAG@dell.com	4880976803	1	9373082995414736	2010/03	user16213	password	32	60000	M
16214	EEINMM	XCOGVNZWTJ	2246098832 Dell Way	\N	TTGYYZK	\N	0	China	2	XCOGVNZWTJ@dell.com	2246098832	2	8152052327059210	2009/07	user16214	password	39	100000	M
16215	LHFYUD	BJKWWJSQTM	2098566268 Dell Way	\N	KZKIZUS	\N	0	Canada	2	BJKWWJSQTM@dell.com	2098566268	3	5443209093995393	2011/10	user16215	password	52	40000	F
16216	TPEOSF	XCCUMVLFHV	4398515865 Dell Way	\N	EREEMWH	\N	0	Germany	2	XCCUMVLFHV@dell.com	4398515865	4	3184718406293541	2008/03	user16216	password	61	60000	F
16217	EPOXVL	ZYGMTRRAMW	1656463774 Dell Way	\N	SRAEOHT	\N	0	UK	2	ZYGMTRRAMW@dell.com	1656463774	5	1898179728072136	2009/08	user16217	password	55	40000	M
16218	DWQYIQ	WOCQGUQTQI	3246749950 Dell Way	\N	KRMZZGX	\N	0	Australia	2	WOCQGUQTQI@dell.com	3246749950	5	4177946661598981	2012/07	user16218	password	66	80000	M
16219	NGPWXM	LACRUTKKBU	6932532982 Dell Way	\N	COTBVRC	\N	0	Australia	2	LACRUTKKBU@dell.com	6932532982	3	9180302579421552	2008/02	user16219	password	55	100000	M
16220	TKNRWY	RYPLSAWTUY	5811619952 Dell Way	\N	IOZDGCF	\N	0	South Africa	2	RYPLSAWTUY@dell.com	5811619952	1	1649833911564201	2011/08	user16220	password	82	40000	F
16221	HUBDTS	CJEUJAOEYX	4547201368 Dell Way	\N	TYBZAGW	\N	0	Germany	2	CJEUJAOEYX@dell.com	4547201368	5	2840618729591369	2008/10	user16221	password	54	60000	F
16222	HMGBFJ	KJETKSXIPQ	4907966607 Dell Way	\N	GRPHYMV	\N	0	China	2	KJETKSXIPQ@dell.com	4907966607	1	4158897432964295	2009/07	user16222	password	75	40000	M
16223	HPXNZH	WDBGVYPLPW	1371836555 Dell Way	\N	CFDASZJ	\N	0	Canada	2	WDBGVYPLPW@dell.com	1371836555	4	4567718151025474	2010/06	user16223	password	73	60000	M
16224	JJHIQE	LSKHRATGWW	9451024468 Dell Way	\N	MAXEAGI	\N	0	Australia	2	LSKHRATGWW@dell.com	9451024468	4	6840873330365867	2010/06	user16224	password	24	40000	M
16225	LMECQQ	UBXMBRTYNF	4839874372 Dell Way	\N	ZKKZQSB	\N	0	Germany	2	UBXMBRTYNF@dell.com	4839874372	4	1060414017178118	2012/10	user16225	password	33	80000	F
16226	RXIIOD	KMPMDIKQOJ	2096726746 Dell Way	\N	BYJRRLG	\N	0	Australia	2	KMPMDIKQOJ@dell.com	2096726746	2	9864434191025796	2012/06	user16226	password	71	20000	F
16227	QMMEQX	QFJUOTKCDL	6928294262 Dell Way	\N	BNDSYKU	\N	0	Australia	2	QFJUOTKCDL@dell.com	6928294262	4	9771632801741364	2008/07	user16227	password	27	40000	F
16228	PUIFRZ	LATAUEDYQE	5409662948 Dell Way	\N	LTXJESL	\N	0	South Africa	2	LATAUEDYQE@dell.com	5409662948	3	9553070996887984	2008/07	user16228	password	36	20000	F
16229	BNJTMV	TGVOLYMBDX	2484815816 Dell Way	\N	VAHZTTV	\N	0	Chile	2	TGVOLYMBDX@dell.com	2484815816	4	3039107510820031	2011/01	user16229	password	46	100000	F
16230	XFUKBO	RWCCVPEYNA	6140841851 Dell Way	\N	ZVASOVY	\N	0	Russia	2	RWCCVPEYNA@dell.com	6140841851	1	4866321314126253	2010/07	user16230	password	38	80000	F
16231	NLVOZN	LCPGRUFEUF	1444757876 Dell Way	\N	AUYOPWH	\N	0	Canada	2	LCPGRUFEUF@dell.com	1444757876	4	7685555364470930	2011/12	user16231	password	46	20000	M
16232	VXBVKN	XAUPUAUOFU	4130478359 Dell Way	\N	IDJXAQC	\N	0	Australia	2	XAUPUAUOFU@dell.com	4130478359	5	7186671616509557	2009/03	user16232	password	72	100000	F
16233	QYWBLU	BFJVFEKKZS	5984221674 Dell Way	\N	OIQPZTR	\N	0	China	2	BFJVFEKKZS@dell.com	5984221674	2	6885248039383442	2011/02	user16233	password	54	80000	M
16234	LRVWLX	BVTHZDSYWH	9397207818 Dell Way	\N	HNWGGOO	\N	0	South Africa	2	BVTHZDSYWH@dell.com	9397207818	2	6167370537761599	2008/09	user16234	password	45	100000	F
16235	ARALOB	GHJGLBFIIM	5234583226 Dell Way	\N	VFSCTGX	\N	0	Russia	2	GHJGLBFIIM@dell.com	5234583226	3	7784047990571708	2008/11	user16235	password	60	40000	M
16236	GIIUKP	CTWNUBWDNS	2864598797 Dell Way	\N	IGUCNSV	\N	0	UK	2	CTWNUBWDNS@dell.com	2864598797	3	2456365751102567	2008/02	user16236	password	53	100000	F
16237	VHEFXG	ZTUTVRXIJG	7562087147 Dell Way	\N	PEJCXEB	\N	0	Australia	2	ZTUTVRXIJG@dell.com	7562087147	2	2465664290823042	2012/09	user16237	password	26	40000	M
16238	KKTIRS	CMMXDJGMQV	2933569505 Dell Way	\N	RZXODZQ	\N	0	South Africa	2	CMMXDJGMQV@dell.com	2933569505	5	7596944792661817	2012/12	user16238	password	89	60000	F
16239	KFRBXT	OJQRTWEJRV	8261685956 Dell Way	\N	IPJMPAI	\N	0	Russia	2	OJQRTWEJRV@dell.com	8261685956	1	7559941820800305	2011/01	user16239	password	31	20000	F
16240	KSNHMB	RDSLZXURSD	9930041119 Dell Way	\N	HBPWCYR	\N	0	South Africa	2	RDSLZXURSD@dell.com	9930041119	2	6511398083996028	2008/07	user16240	password	67	60000	M
16241	KZHWBY	ZUKZRERJIY	8859487402 Dell Way	\N	LXVNWMK	\N	0	South Africa	2	ZUKZRERJIY@dell.com	8859487402	1	8893854454159738	2010/09	user16241	password	43	60000	F
16242	ISZKRZ	EBZVFRFOQR	6761894642 Dell Way	\N	MLFIYPE	\N	0	South Africa	2	EBZVFRFOQR@dell.com	6761894642	1	3355599235277623	2009/05	user16242	password	68	60000	M
16243	KLDBLH	CLDICIWTAI	8503975081 Dell Way	\N	EFQDVUY	\N	0	France	2	CLDICIWTAI@dell.com	8503975081	1	8217144460417331	2009/11	user16243	password	37	100000	F
16244	SBIEJL	QMTSUQLUZQ	8951448409 Dell Way	\N	APTVKSH	\N	0	Chile	2	QMTSUQLUZQ@dell.com	8951448409	1	5216103875078261	2011/05	user16244	password	48	20000	F
16245	MJGVUW	HOPCEBXDRX	1922347575 Dell Way	\N	TLTEDAL	\N	0	Australia	2	HOPCEBXDRX@dell.com	1922347575	5	8173234498593957	2010/04	user16245	password	79	60000	M
16246	FTQAPX	OEATFXXXVR	2690208540 Dell Way	\N	JOWNPHO	\N	0	Japan	2	OEATFXXXVR@dell.com	2690208540	2	2245114218909293	2010/03	user16246	password	65	40000	F
16247	KXKAVZ	EVSKTQIPHS	2326450996 Dell Way	\N	EDGTLUL	\N	0	Japan	2	EVSKTQIPHS@dell.com	2326450996	3	2133947120048105	2009/03	user16247	password	48	80000	M
16248	IDQECV	AVFULOJTHN	3395699680 Dell Way	\N	XNGIHRY	\N	0	France	2	AVFULOJTHN@dell.com	3395699680	1	8090037772897632	2010/06	user16248	password	56	20000	M
16249	RTATOA	PUUBIDUQRR	1124713591 Dell Way	\N	DXZLPYW	\N	0	South Africa	2	PUUBIDUQRR@dell.com	1124713591	4	4269359626341611	2010/03	user16249	password	52	40000	M
16250	FJQTJF	NEGWIAMZSQ	6317756243 Dell Way	\N	WSBMQYJ	\N	0	Japan	2	NEGWIAMZSQ@dell.com	6317756243	4	2456413712352514	2011/03	user16250	password	55	80000	F
16251	WGEGLS	KSPSTCRLSO	2277898704 Dell Way	\N	DTBURKL	\N	0	Chile	2	KSPSTCRLSO@dell.com	2277898704	3	1371521328575909	2009/02	user16251	password	67	80000	M
16252	XYFJQP	CFHVHZHZOK	2949080020 Dell Way	\N	TPFKAQR	\N	0	Canada	2	CFHVHZHZOK@dell.com	2949080020	4	5403741628862918	2009/05	user16252	password	35	40000	F
16253	EMRUBU	AJPIJWIXHB	8487999898 Dell Way	\N	MMLMCDQ	\N	0	China	2	AJPIJWIXHB@dell.com	8487999898	1	6774375866167248	2009/05	user16253	password	85	60000	M
16254	KFJMZJ	VORFLZCTBO	8244624374 Dell Way	\N	FMBIQRQ	\N	0	France	2	VORFLZCTBO@dell.com	8244624374	2	6973764230962843	2008/03	user16254	password	31	80000	M
16255	JBCILX	XDDJCFCEUI	6215087371 Dell Way	\N	RVQHNHS	\N	0	China	2	XDDJCFCEUI@dell.com	6215087371	2	5493497218936682	2011/07	user16255	password	33	60000	M
16256	GMHRKF	UNOXTQCNYT	2065420124 Dell Way	\N	JPAWWTF	\N	0	France	2	UNOXTQCNYT@dell.com	2065420124	4	3211451765615493	2011/11	user16256	password	65	80000	F
16257	DXWNCR	BRPUHRHGKQ	4944066726 Dell Way	\N	VKNSDTE	\N	0	Chile	2	BRPUHRHGKQ@dell.com	4944066726	3	9608594496268780	2009/01	user16257	password	60	60000	F
16258	MKSPBU	GROOJWVTNQ	9492838615 Dell Way	\N	EBJIUNP	\N	0	Chile	2	GROOJWVTNQ@dell.com	9492838615	3	6143472738564015	2008/02	user16258	password	25	20000	M
16259	MXGOSN	GGBPDWIQNN	1317620515 Dell Way	\N	SXWMLMS	\N	0	China	2	GGBPDWIQNN@dell.com	1317620515	2	4399181970860809	2008/05	user16259	password	59	100000	M
16260	MBLEOR	LQGPNPFBDY	4414105006 Dell Way	\N	YZKJLCT	\N	0	France	2	LQGPNPFBDY@dell.com	4414105006	1	7043193751946092	2011/09	user16260	password	54	80000	F
16261	OBJDSV	TZKHOQISOG	5407060045 Dell Way	\N	RYQDBJQ	\N	0	France	2	TZKHOQISOG@dell.com	5407060045	2	2722122578416019	2008/10	user16261	password	77	40000	F
16262	WTMPOG	OYNDOVVCCN	5835063721 Dell Way	\N	BSQDBGO	\N	0	Germany	2	OYNDOVVCCN@dell.com	5835063721	4	7717609103303403	2009/07	user16262	password	26	80000	F
16263	VDAKKP	IXSXSOAUBC	5796834066 Dell Way	\N	NRFPXUD	\N	0	France	2	IXSXSOAUBC@dell.com	5796834066	5	8024314377456904	2008/01	user16263	password	50	60000	M
16264	POGZDP	WVMPJNKLPX	5990299396 Dell Way	\N	CUNAORM	\N	0	Australia	2	WVMPJNKLPX@dell.com	5990299396	2	2777305684518069	2010/09	user16264	password	71	60000	F
16265	HRHKGE	GTTQGEBVCE	9297326482 Dell Way	\N	PPEEGRG	\N	0	South Africa	2	GTTQGEBVCE@dell.com	9297326482	3	4412387546151877	2011/03	user16265	password	75	100000	F
16266	LFWSJD	LDURIVMKAC	9758130963 Dell Way	\N	AEGHWNC	\N	0	Russia	2	LDURIVMKAC@dell.com	9758130963	3	4590394430328161	2008/04	user16266	password	42	80000	M
16267	ONKXQW	BLNJGAUGCU	6614669958 Dell Way	\N	LIBHWEB	\N	0	South Africa	2	BLNJGAUGCU@dell.com	6614669958	3	9961218794807792	2012/10	user16267	password	63	80000	F
16268	DAGUXI	FKSMLMTNHF	1136841530 Dell Way	\N	WIMSMOO	\N	0	Canada	2	FKSMLMTNHF@dell.com	1136841530	3	1005266974214464	2012/03	user16268	password	62	20000	F
16269	QKDNTI	YLVJXOWETT	6203411506 Dell Way	\N	NGMAUAD	\N	0	South Africa	2	YLVJXOWETT@dell.com	6203411506	1	6651839809492231	2011/09	user16269	password	74	20000	F
16270	FFXYOV	JJFHYCMRVA	3555475648 Dell Way	\N	YHATIEO	\N	0	UK	2	JJFHYCMRVA@dell.com	3555475648	1	7005882359575481	2008/12	user16270	password	72	40000	F
16271	YHCMDM	WIUULGMGHL	9353143985 Dell Way	\N	OIEXMTU	\N	0	Russia	2	WIUULGMGHL@dell.com	9353143985	3	7937119299545885	2012/03	user16271	password	30	20000	F
16272	LERPQO	YLIJSVQZGF	4428221883 Dell Way	\N	HKCTEXN	\N	0	Australia	2	YLIJSVQZGF@dell.com	4428221883	2	9837149977218360	2011/06	user16272	password	21	80000	M
16273	FMNWAL	HIVZELZKRH	8456734289 Dell Way	\N	VTAZROB	\N	0	Australia	2	HIVZELZKRH@dell.com	8456734289	1	6855385543778539	2009/02	user16273	password	49	20000	F
16274	XREXDM	GYMKKLVBTQ	7491575234 Dell Way	\N	VTQMIRN	\N	0	Canada	2	GYMKKLVBTQ@dell.com	7491575234	1	4767075113020837	2012/08	user16274	password	61	20000	M
16275	HHKLTR	JGCUSXVLOQ	8311152273 Dell Way	\N	FEDNVQR	\N	0	Germany	2	JGCUSXVLOQ@dell.com	8311152273	1	4329833033494651	2010/09	user16275	password	53	100000	M
16276	UJKOAT	UCOMAJYOAD	4317214539 Dell Way	\N	SDQOUHC	\N	0	Germany	2	UCOMAJYOAD@dell.com	4317214539	3	1130393596366047	2008/12	user16276	password	87	20000	M
16277	HKHIEC	LSPLCNACQS	8617162214 Dell Way	\N	GHGAOJQ	\N	0	UK	2	LSPLCNACQS@dell.com	8617162214	4	9861920948605984	2012/08	user16277	password	90	60000	M
16278	KWFOYR	HOCJBCMSVS	1166242267 Dell Way	\N	ZCTOLJM	\N	0	China	2	HOCJBCMSVS@dell.com	1166242267	3	2058767378795892	2011/06	user16278	password	67	60000	M
16279	NSLMJS	AMCCOPUKIU	3462418196 Dell Way	\N	MBIYLUG	\N	0	France	2	AMCCOPUKIU@dell.com	3462418196	2	1633819841314107	2011/01	user16279	password	58	80000	M
16280	GBCQUD	CWFRLABTUO	2195430743 Dell Way	\N	VCNHXTT	\N	0	Canada	2	CWFRLABTUO@dell.com	2195430743	5	9209796220995488	2008/05	user16280	password	56	80000	M
16281	OWGJZI	FEARFBLZPH	2328482149 Dell Way	\N	BCOYWID	\N	0	Australia	2	FEARFBLZPH@dell.com	2328482149	1	2687301851809025	2010/07	user16281	password	88	20000	F
16282	VLMUUS	ZUKEVWDLDF	4051924772 Dell Way	\N	OSELBHL	\N	0	Canada	2	ZUKEVWDLDF@dell.com	4051924772	4	7503755949903280	2012/07	user16282	password	83	20000	F
16283	IOECGE	WRISNMERRT	3004206079 Dell Way	\N	KVELDPQ	\N	0	France	2	WRISNMERRT@dell.com	3004206079	2	4317968470510095	2012/04	user16283	password	48	40000	M
16284	YKRFOO	WXHKJMCAFM	9254043872 Dell Way	\N	VJYZZOL	\N	0	Canada	2	WXHKJMCAFM@dell.com	9254043872	5	1006192638073116	2008/03	user16284	password	33	80000	F
16285	PLKEAH	BHRKUTKZGG	5102270098 Dell Way	\N	IEFISRN	\N	0	Japan	2	BHRKUTKZGG@dell.com	5102270098	3	8359919033013285	2011/09	user16285	password	59	100000	F
16286	AGMANN	IEXCYIBFOK	7730789185 Dell Way	\N	JUSCLGT	\N	0	UK	2	IEXCYIBFOK@dell.com	7730789185	3	6199282584711910	2010/02	user16286	password	48	80000	F
16287	RGEEUM	IROHZPNOAW	3786740395 Dell Way	\N	JTZVZTS	\N	0	Russia	2	IROHZPNOAW@dell.com	3786740395	2	2703922826331109	2010/09	user16287	password	89	60000	F
16288	GTNAFW	SUESKRGKOQ	5124263244 Dell Way	\N	DOLDHEW	\N	0	Germany	2	SUESKRGKOQ@dell.com	5124263244	1	1382970769423991	2008/01	user16288	password	64	60000	F
16289	KCGPYY	KDQUVXEJOI	4129588147 Dell Way	\N	YZMFDIU	\N	0	Japan	2	KDQUVXEJOI@dell.com	4129588147	5	8037952899001540	2009/06	user16289	password	42	80000	M
16290	KWMJVW	NMRIKVSYEQ	5639174503 Dell Way	\N	XQWBZRR	\N	0	China	2	NMRIKVSYEQ@dell.com	5639174503	3	7045542943757028	2012/10	user16290	password	38	100000	F
16291	DJOZFC	LWLVSDTXUR	8640038766 Dell Way	\N	ORTNIKW	\N	0	South Africa	2	LWLVSDTXUR@dell.com	8640038766	3	8640913137700410	2011/10	user16291	password	70	100000	M
16292	CKXIMI	FXEXBYVWPK	3828337392 Dell Way	\N	OIYWSUS	\N	0	Germany	2	FXEXBYVWPK@dell.com	3828337392	3	2855005113873631	2008/04	user16292	password	20	20000	F
16293	LZRYHW	WMUXKQUZBI	5608199087 Dell Way	\N	IZFBUYQ	\N	0	Canada	2	WMUXKQUZBI@dell.com	5608199087	5	2913488330319524	2012/11	user16293	password	37	20000	F
16294	FWFNTB	ANZKEUKFDS	3081065256 Dell Way	\N	FIUZHKC	\N	0	Russia	2	ANZKEUKFDS@dell.com	3081065256	2	6409901962149889	2008/07	user16294	password	75	40000	M
16295	QQIJRJ	XRTCMEHPXN	9119969766 Dell Way	\N	YRNFBPA	\N	0	China	2	XRTCMEHPXN@dell.com	9119969766	4	4618647017981857	2010/05	user16295	password	76	40000	F
16296	KQLCZJ	USLGXTWUGV	7206957561 Dell Way	\N	MTBOIBW	\N	0	Chile	2	USLGXTWUGV@dell.com	7206957561	2	7442128748632968	2008/01	user16296	password	90	20000	F
16297	PPOOYJ	HJQFCMZIHM	2072217655 Dell Way	\N	BJAKKWQ	\N	0	Canada	2	HJQFCMZIHM@dell.com	2072217655	2	2778439131565392	2008/05	user16297	password	43	80000	M
16298	XFOWOW	FEBHRBQZNS	2115909390 Dell Way	\N	INCTKTV	\N	0	Germany	2	FEBHRBQZNS@dell.com	2115909390	1	7106332679744811	2010/05	user16298	password	40	60000	F
16299	NZDBWJ	GXQYYHXMZF	8466649259 Dell Way	\N	ZBYJVUX	\N	0	UK	2	GXQYYHXMZF@dell.com	8466649259	3	4977295298129320	2009/11	user16299	password	83	60000	F
16300	XQMTAS	QQRPXOBXUB	8935565934 Dell Way	\N	ZTLUOIT	\N	0	China	2	QQRPXOBXUB@dell.com	8935565934	1	6200738307554275	2011/02	user16300	password	24	20000	M
16301	TQTTJK	KAZIOBFJCE	9338578098 Dell Way	\N	CNZQVSA	\N	0	Russia	2	KAZIOBFJCE@dell.com	9338578098	3	5279712034389377	2008/09	user16301	password	63	20000	F
16302	GTDPDO	PDWEEBNGFP	8576214861 Dell Way	\N	TEGPXGI	\N	0	South Africa	2	PDWEEBNGFP@dell.com	8576214861	4	8802602891344578	2010/06	user16302	password	82	100000	M
16303	QBHTPW	WLBBNOHTEB	7909976584 Dell Way	\N	XKRVRZR	\N	0	Germany	2	WLBBNOHTEB@dell.com	7909976584	3	1277179001830518	2008/06	user16303	password	87	100000	F
16304	ADVPAS	BBTOPBIUCF	3779048017 Dell Way	\N	FTBWTTK	\N	0	Germany	2	BBTOPBIUCF@dell.com	3779048017	3	7305673255119473	2011/05	user16304	password	58	100000	F
16305	RQASJB	TCQJEYDHEI	1239136397 Dell Way	\N	BGFUAPH	\N	0	China	2	TCQJEYDHEI@dell.com	1239136397	5	1574655490461737	2010/07	user16305	password	81	80000	F
16306	NUYWWR	ZNADMEKQML	5703523618 Dell Way	\N	XRFYHNG	\N	0	China	2	ZNADMEKQML@dell.com	5703523618	2	7422334557399154	2008/03	user16306	password	54	40000	M
16307	HHOEYN	RZRDDBUQNS	2639979793 Dell Way	\N	ITQPHWX	\N	0	Russia	2	RZRDDBUQNS@dell.com	2639979793	4	8851099480874837	2009/02	user16307	password	32	20000	F
16308	MPPLDG	KUKOWEFJXN	7032436823 Dell Way	\N	CNDJKBE	\N	0	Germany	2	KUKOWEFJXN@dell.com	7032436823	1	9443918433971704	2012/03	user16308	password	90	40000	M
16309	PVDSCO	MMDJRISOWV	4881699386 Dell Way	\N	CZFMAKB	\N	0	Japan	2	MMDJRISOWV@dell.com	4881699386	5	5454194236081094	2011/12	user16309	password	71	40000	M
16310	OOHQCU	CGDUOWILRL	9582758394 Dell Way	\N	KXXLHYD	\N	0	Russia	2	CGDUOWILRL@dell.com	9582758394	4	4515703974291682	2012/05	user16310	password	75	60000	M
16311	IUNLOQ	RSKGOTRGEC	3202055522 Dell Way	\N	DBNLAQD	\N	0	UK	2	RSKGOTRGEC@dell.com	3202055522	3	9212868280708792	2010/04	user16311	password	48	60000	M
16312	FZCUPT	MAZBTRIXTM	6195036438 Dell Way	\N	ZGXZWBZ	\N	0	Canada	2	MAZBTRIXTM@dell.com	6195036438	5	7327925531659276	2012/04	user16312	password	31	60000	M
16313	EQHUJU	UJWOAELTQK	3234098481 Dell Way	\N	ZOKWPJZ	\N	0	Canada	2	UJWOAELTQK@dell.com	3234098481	4	1583681207615882	2010/11	user16313	password	62	20000	F
16314	GJVPDQ	ZAEZFQTVAT	3409915044 Dell Way	\N	KLPZUPD	\N	0	Australia	2	ZAEZFQTVAT@dell.com	3409915044	2	6375091101042927	2008/10	user16314	password	65	20000	F
16315	AAREQQ	EUPJKIFLBP	9570131246 Dell Way	\N	WRPRGTT	\N	0	Germany	2	EUPJKIFLBP@dell.com	9570131246	2	6846905220299960	2011/12	user16315	password	78	100000	M
16316	VMDLCI	GSSRBXDCNA	7743355996 Dell Way	\N	UCRAVKO	\N	0	Russia	2	GSSRBXDCNA@dell.com	7743355996	1	6121695791371167	2011/01	user16316	password	47	80000	M
16317	XWHZFO	SXGTVJWIJQ	4455462951 Dell Way	\N	LBRGMFB	\N	0	Chile	2	SXGTVJWIJQ@dell.com	4455462951	4	9558946078177542	2009/01	user16317	password	67	40000	M
16318	ONXTCQ	RIJMRFUBWF	2602414772 Dell Way	\N	CNMOSOU	\N	0	Australia	2	RIJMRFUBWF@dell.com	2602414772	4	5407390979584307	2009/05	user16318	password	71	20000	M
16319	GBSJRK	RAWJGQLCWN	6564835222 Dell Way	\N	QJCIXWL	\N	0	Australia	2	RAWJGQLCWN@dell.com	6564835222	5	3587161128874868	2008/08	user16319	password	48	20000	M
16320	LTGDDY	DZIKQTNMHD	8238244367 Dell Way	\N	VJMTGXV	\N	0	South Africa	2	DZIKQTNMHD@dell.com	8238244367	1	9173801659140736	2010/07	user16320	password	84	40000	M
16321	QPCTOG	TXQJQEWYHS	4472345621 Dell Way	\N	HTLOQHL	\N	0	France	2	TXQJQEWYHS@dell.com	4472345621	2	9056442630477252	2012/04	user16321	password	36	100000	M
16322	WARLGK	IXTZBQXJIF	5861656331 Dell Way	\N	CTTTAFF	\N	0	France	2	IXTZBQXJIF@dell.com	5861656331	1	4033437311649323	2011/05	user16322	password	35	80000	F
16323	GJQMTY	KNXLDVULAX	9579209287 Dell Way	\N	FTRGZWR	\N	0	Germany	2	KNXLDVULAX@dell.com	9579209287	1	3680895101279020	2009/03	user16323	password	90	60000	F
16324	IDZCCJ	PZUSVPEVNJ	3454986151 Dell Way	\N	PEPOAHB	\N	0	UK	2	PZUSVPEVNJ@dell.com	3454986151	2	3438043643254787	2010/05	user16324	password	74	100000	M
16325	XYTZHJ	ZCBUSFPFPE	2221486631 Dell Way	\N	JETKLUJ	\N	0	Russia	2	ZCBUSFPFPE@dell.com	2221486631	4	3192560749594122	2010/05	user16325	password	34	20000	F
16326	EXHMHG	PIBHORMEWW	3357964264 Dell Way	\N	JPGUJQO	\N	0	Germany	2	PIBHORMEWW@dell.com	3357964264	4	9824077984318138	2011/01	user16326	password	27	100000	F
16327	BHRING	RPNFGAKCWT	8768578432 Dell Way	\N	RDOBTCO	\N	0	UK	2	RPNFGAKCWT@dell.com	8768578432	3	7041351455729455	2012/08	user16327	password	65	20000	M
16328	YTALZR	BNXHNHJJAB	2720681406 Dell Way	\N	MPCFRRF	\N	0	Germany	2	BNXHNHJJAB@dell.com	2720681406	5	4577177803497762	2012/07	user16328	password	51	60000	F
16329	FPYEHZ	RFHENROOSB	4530729537 Dell Way	\N	DVHUMMH	\N	0	Japan	2	RFHENROOSB@dell.com	4530729537	4	5751403685659171	2012/02	user16329	password	24	60000	F
16330	RINZIF	EPKRGYFZZI	2011205296 Dell Way	\N	UHCHTKY	\N	0	Canada	2	EPKRGYFZZI@dell.com	2011205296	3	1896063624415546	2009/07	user16330	password	55	80000	F
16331	WEGEJK	UTCBSHASQV	5808764133 Dell Way	\N	ZTCTEBX	\N	0	Chile	2	UTCBSHASQV@dell.com	5808764133	1	5981979004107416	2008/07	user16331	password	31	40000	F
16332	JPOSAJ	MCKFKKXBGX	6126635041 Dell Way	\N	UIQZKOG	\N	0	UK	2	MCKFKKXBGX@dell.com	6126635041	5	1355060486122965	2008/12	user16332	password	48	60000	F
16333	AABBKO	DUTOFRPLOK	4755032581 Dell Way	\N	UFJEUQC	\N	0	China	2	DUTOFRPLOK@dell.com	4755032581	1	4955849209800363	2010/07	user16333	password	84	80000	M
16334	YUQIIU	DBIITYUHJO	1057254676 Dell Way	\N	NSTHIWQ	\N	0	Russia	2	DBIITYUHJO@dell.com	1057254676	1	2409891622606665	2010/12	user16334	password	83	20000	M
16335	RUHAPK	CYTVWNDFBQ	7081492025 Dell Way	\N	YVYHRPB	\N	0	Japan	2	CYTVWNDFBQ@dell.com	7081492025	1	3177140503656119	2011/02	user16335	password	47	80000	M
16336	FXUUHW	SBSPOVVQMU	3652897834 Dell Way	\N	LKBCZCT	\N	0	Japan	2	SBSPOVVQMU@dell.com	3652897834	1	4085347012151033	2009/05	user16336	password	88	20000	M
16337	WYKEVC	FNSTINJUHU	6830087933 Dell Way	\N	EJXELQW	\N	0	Russia	2	FNSTINJUHU@dell.com	6830087933	1	2149879546370357	2008/02	user16337	password	38	80000	F
16338	FBEAEK	NWEWKNQRIV	1353581750 Dell Way	\N	AFZMWWF	\N	0	Germany	2	NWEWKNQRIV@dell.com	1353581750	2	6078423893544823	2008/08	user16338	password	34	40000	M
16339	HKXLUK	HYGRMXJUSK	5085357886 Dell Way	\N	ASWWOCK	\N	0	Germany	2	HYGRMXJUSK@dell.com	5085357886	5	8135071592871101	2008/03	user16339	password	18	100000	F
16340	KVXEGF	DNWPKGKDQK	6789327123 Dell Way	\N	WNHKQRA	\N	0	Australia	2	DNWPKGKDQK@dell.com	6789327123	5	2508403803687542	2012/10	user16340	password	26	40000	F
16341	YEJFJN	SGCDMNHDXD	4167622411 Dell Way	\N	RFNHXOJ	\N	0	Germany	2	SGCDMNHDXD@dell.com	4167622411	3	4308448497671634	2008/08	user16341	password	65	40000	M
16342	VTUEGN	LJQXWXBUBS	9004708291 Dell Way	\N	APZXDJL	\N	0	France	2	LJQXWXBUBS@dell.com	9004708291	5	6733556320425124	2010/06	user16342	password	90	20000	F
16343	TXMZKX	JBVFZWAAPA	2510341691 Dell Way	\N	PPXSYJF	\N	0	South Africa	2	JBVFZWAAPA@dell.com	2510341691	5	4356008669361472	2011/10	user16343	password	54	100000	M
16344	KJOVHX	WCDVZDWODL	2789408645 Dell Way	\N	DBECKJY	\N	0	Germany	2	WCDVZDWODL@dell.com	2789408645	2	2775439633987844	2008/10	user16344	password	25	80000	F
16345	MEATBX	VFSVIOJMAN	9071768726 Dell Way	\N	NEQXOPM	\N	0	Russia	2	VFSVIOJMAN@dell.com	9071768726	4	7923851442523301	2011/10	user16345	password	44	100000	F
16346	NYAPVW	UORDDBPDPD	2873716333 Dell Way	\N	IFAWUNP	\N	0	Russia	2	UORDDBPDPD@dell.com	2873716333	2	4695299975108355	2012/09	user16346	password	42	40000	F
16347	HHWCER	RWUVYKZNNH	2355700384 Dell Way	\N	TOEOCUG	\N	0	Chile	2	RWUVYKZNNH@dell.com	2355700384	4	3587344290222973	2012/12	user16347	password	58	20000	F
16348	WBJASB	XNWVYVILDB	5791770399 Dell Way	\N	AHQCBWJ	\N	0	Chile	2	XNWVYVILDB@dell.com	5791770399	4	2030183584429323	2010/03	user16348	password	39	80000	F
16349	IECBGZ	PCVNYDYBFY	1510134261 Dell Way	\N	JVALSKQ	\N	0	Chile	2	PCVNYDYBFY@dell.com	1510134261	4	7870292858220638	2009/01	user16349	password	58	40000	F
16350	TLLZLA	CGNAKMCPLL	3587193654 Dell Way	\N	LLWDWNK	\N	0	UK	2	CGNAKMCPLL@dell.com	3587193654	1	2716148783452809	2009/09	user16350	password	57	80000	F
16351	ZEKLEM	RSNCFPSQBD	8355461176 Dell Way	\N	CYHYMRW	\N	0	Russia	2	RSNCFPSQBD@dell.com	8355461176	1	1859920183196664	2010/08	user16351	password	77	100000	M
16352	ZKAEWS	XKUCAMSBQV	7331939281 Dell Way	\N	AXUMPQG	\N	0	China	2	XKUCAMSBQV@dell.com	7331939281	2	9299560796469452	2009/02	user16352	password	83	100000	F
16353	HXIEQF	OLHOYAQOVR	7756485899 Dell Way	\N	MPEBGKL	\N	0	UK	2	OLHOYAQOVR@dell.com	7756485899	2	3354747956618667	2012/04	user16353	password	29	20000	M
16354	BJSSPG	DXVCXMQTDD	1090675814 Dell Way	\N	JHEQSQP	\N	0	France	2	DXVCXMQTDD@dell.com	1090675814	5	4374782619532198	2009/12	user16354	password	49	100000	F
16355	UNUKUY	HQAEDRYHUI	4320758630 Dell Way	\N	PYYHPNT	\N	0	Japan	2	HQAEDRYHUI@dell.com	4320758630	1	8906663376837970	2009/07	user16355	password	69	60000	F
16356	FFTADA	REFUVEBPMQ	8219046368 Dell Way	\N	OLXDYRT	\N	0	China	2	REFUVEBPMQ@dell.com	8219046368	4	7239786341320724	2009/04	user16356	password	27	80000	M
16357	JMONNF	RTAMXBBKRP	1855837328 Dell Way	\N	VPTUHMD	\N	0	Australia	2	RTAMXBBKRP@dell.com	1855837328	5	5070225353818387	2010/12	user16357	password	31	100000	F
16358	RNUETM	YTYWVZGNPC	8658104944 Dell Way	\N	CIXKVAM	\N	0	UK	2	YTYWVZGNPC@dell.com	8658104944	5	3861891600769013	2012/02	user16358	password	38	20000	M
16359	UXZOJX	HHUCHBQWET	6156988213 Dell Way	\N	FBDACQY	\N	0	UK	2	HHUCHBQWET@dell.com	6156988213	2	7775425333995373	2011/07	user16359	password	80	60000	F
16360	TMWDKE	LEHTFXQKQV	1415952707 Dell Way	\N	LUWOKUN	\N	0	UK	2	LEHTFXQKQV@dell.com	1415952707	2	7038837861269713	2010/02	user16360	password	30	100000	M
16361	QUABYM	FGFLDVVURH	6440813742 Dell Way	\N	ONVYIJX	\N	0	China	2	FGFLDVVURH@dell.com	6440813742	3	9487468141596764	2011/10	user16361	password	79	80000	F
16362	PQLOCR	UHDYDZSUGG	7506518260 Dell Way	\N	ICFRLDA	\N	0	Australia	2	UHDYDZSUGG@dell.com	7506518260	5	7928305527195335	2010/10	user16362	password	45	100000	F
16363	AIZCZT	KDSOCKJIRR	4027111242 Dell Way	\N	LXIWAJY	\N	0	Russia	2	KDSOCKJIRR@dell.com	4027111242	4	3067673120647669	2008/01	user16363	password	25	60000	F
16364	LOELIP	OADQLMZDEK	9486845123 Dell Way	\N	ANHBWGU	\N	0	Chile	2	OADQLMZDEK@dell.com	9486845123	1	4175868242979050	2008/02	user16364	password	85	20000	M
16365	MHZUWO	UAFFNEIRPJ	2872544724 Dell Way	\N	EXKBDEG	\N	0	Australia	2	UAFFNEIRPJ@dell.com	2872544724	3	1973703827243298	2009/07	user16365	password	33	100000	M
16366	MXTJLO	JQUWVDOLMS	6439059082 Dell Way	\N	IWTMBAO	\N	0	Chile	2	JQUWVDOLMS@dell.com	6439059082	4	6551810332108290	2008/11	user16366	password	55	20000	F
16367	KWTWLD	NFAJIOUVGD	8867403049 Dell Way	\N	SAQUAFB	\N	0	Japan	2	NFAJIOUVGD@dell.com	8867403049	4	7798018406145275	2011/03	user16367	password	81	20000	M
16368	TXMEAA	JAKSOEOVIG	7864218099 Dell Way	\N	VYAWDCN	\N	0	Australia	2	JAKSOEOVIG@dell.com	7864218099	2	8033036858309061	2012/02	user16368	password	85	60000	M
16369	VBAVCK	VMCKRQFAXB	7111066196 Dell Way	\N	ZXXCALD	\N	0	Russia	2	VMCKRQFAXB@dell.com	7111066196	5	7543124303221703	2011/11	user16369	password	40	80000	M
16370	JRMMBH	ZERRVXRSYQ	8070543976 Dell Way	\N	QWTQHWK	\N	0	UK	2	ZERRVXRSYQ@dell.com	8070543976	1	7946563567034901	2011/06	user16370	password	49	40000	M
16371	CSHEAG	ISXDPPVOFM	6449716865 Dell Way	\N	KZCSVMR	\N	0	Japan	2	ISXDPPVOFM@dell.com	6449716865	3	3250376112759113	2008/11	user16371	password	55	100000	M
16372	GCDGJM	ZHQOWMDCYO	4675656301 Dell Way	\N	BAGXNYN	\N	0	Canada	2	ZHQOWMDCYO@dell.com	4675656301	4	2255516860634088	2009/04	user16372	password	88	40000	M
16373	CLULXT	SNIPZMRYAS	9227371429 Dell Way	\N	YHPLFDO	\N	0	Japan	2	SNIPZMRYAS@dell.com	9227371429	4	9368179976008832	2009/09	user16373	password	33	80000	M
16374	QNFOHY	CQNBCEADXY	6879657775 Dell Way	\N	KMKQQYG	\N	0	Germany	2	CQNBCEADXY@dell.com	6879657775	1	7779808998107911	2009/05	user16374	password	53	20000	F
16375	AHPIFR	YSTBXTEUSP	7142404849 Dell Way	\N	HCFXBML	\N	0	Russia	2	YSTBXTEUSP@dell.com	7142404849	2	1212212140206247	2008/09	user16375	password	25	20000	M
16376	JSAPKZ	HDBEWGYOVF	8121631986 Dell Way	\N	RBDSOPK	\N	0	Chile	2	HDBEWGYOVF@dell.com	8121631986	3	3810212050564587	2010/07	user16376	password	50	40000	M
16377	EGMOFU	RHZONYDIDV	4425909647 Dell Way	\N	KHNYWYE	\N	0	Japan	2	RHZONYDIDV@dell.com	4425909647	3	2249942061025649	2012/12	user16377	password	42	100000	F
16378	OIQUDI	BCXOAAXEVI	9081220424 Dell Way	\N	LJGIIKY	\N	0	Japan	2	BCXOAAXEVI@dell.com	9081220424	1	6502482873853297	2012/06	user16378	password	50	100000	F
16379	UNUXWW	ATLAUJFQRR	1277486902 Dell Way	\N	ZXZIIYA	\N	0	Chile	2	ATLAUJFQRR@dell.com	1277486902	4	1510517599061131	2010/01	user16379	password	87	60000	M
16380	MHTJET	CPUXYANQRN	5011191802 Dell Way	\N	OQVWOVD	\N	0	Japan	2	CPUXYANQRN@dell.com	5011191802	1	1671622895170003	2010/02	user16380	password	58	40000	M
16381	WCZAWC	PRZORNEJBT	9192344055 Dell Way	\N	ZWPOSTE	\N	0	Canada	2	PRZORNEJBT@dell.com	9192344055	2	6923865009564907	2008/10	user16381	password	18	80000	M
16382	CRRZUH	RTWIHBSIUS	7235435752 Dell Way	\N	FKHXDLB	\N	0	Australia	2	RTWIHBSIUS@dell.com	7235435752	4	1789111478719860	2010/09	user16382	password	73	20000	M
16383	LVVFDM	ZZVGBNPVFU	5143259445 Dell Way	\N	GNRJYTK	\N	0	Japan	2	ZZVGBNPVFU@dell.com	5143259445	3	2257162509020418	2008/04	user16383	password	40	20000	M
16384	DVXHIW	HDDIRSEXMK	7037220770 Dell Way	\N	KETJYEZ	\N	0	China	2	HDDIRSEXMK@dell.com	7037220770	1	6175097416155041	2012/06	user16384	password	61	80000	M
16385	LNWTKD	XOMPGQMTBX	4314385181 Dell Way	\N	YVGWZGG	\N	0	Japan	2	XOMPGQMTBX@dell.com	4314385181	5	6410152727738023	2012/06	user16385	password	34	40000	M
16386	TGQEKO	SWDZNQSOOR	6627063737 Dell Way	\N	KUNKAUB	\N	0	France	2	SWDZNQSOOR@dell.com	6627063737	4	2812774432823062	2008/11	user16386	password	60	100000	M
16387	VOVFDO	CGNQXFFLXP	7518868102 Dell Way	\N	FKZGFBR	\N	0	South Africa	2	CGNQXFFLXP@dell.com	7518868102	5	9007516837213188	2011/06	user16387	password	77	40000	F
16388	KCMNRP	TEFRKKCHZI	2018740983 Dell Way	\N	SZPXAGT	\N	0	Russia	2	TEFRKKCHZI@dell.com	2018740983	4	4425450419541448	2010/06	user16388	password	66	100000	M
16389	UIILXC	PDTZNWHNEZ	3136179668 Dell Way	\N	MTWNAPH	\N	0	Canada	2	PDTZNWHNEZ@dell.com	3136179668	4	7217651914339513	2011/04	user16389	password	56	60000	F
16390	WWNTYD	WSCKOJXTJJ	8306554866 Dell Way	\N	NFXNVER	\N	0	Australia	2	WSCKOJXTJJ@dell.com	8306554866	2	7759948606602848	2008/11	user16390	password	37	40000	M
16391	DTMBWJ	UZUIJRCSBP	2277966933 Dell Way	\N	YYDTCUV	\N	0	UK	2	UZUIJRCSBP@dell.com	2277966933	3	1337780006695538	2008/11	user16391	password	36	80000	M
16392	AGAWQU	VKDFBFXDVV	9774592162 Dell Way	\N	BYPDTKB	\N	0	South Africa	2	VKDFBFXDVV@dell.com	9774592162	1	9113301031757148	2012/05	user16392	password	65	80000	F
16393	XUFNPB	XTHZZECUAD	5197215365 Dell Way	\N	TPHMZJJ	\N	0	UK	2	XTHZZECUAD@dell.com	5197215365	2	8042244085576386	2012/12	user16393	password	58	20000	M
16394	JKIZMG	STFSYINYLG	4814569386 Dell Way	\N	NTTNDDM	\N	0	Germany	2	STFSYINYLG@dell.com	4814569386	2	4695081593003124	2009/11	user16394	password	61	20000	F
16395	ANEMTW	GZOEHBDTIR	9726367079 Dell Way	\N	MCFPGRF	\N	0	Japan	2	GZOEHBDTIR@dell.com	9726367079	4	1181596601847559	2012/03	user16395	password	32	100000	F
16396	SDSMAY	LPDSRHMAYY	4381873114 Dell Way	\N	CDOIVTA	\N	0	South Africa	2	LPDSRHMAYY@dell.com	4381873114	1	6465460539795459	2010/03	user16396	password	61	80000	M
16397	TMKULW	JPPAWBAVAD	5602518361 Dell Way	\N	ZPMVJMP	\N	0	Russia	2	JPPAWBAVAD@dell.com	5602518361	2	3725941896438599	2011/10	user16397	password	24	80000	M
16398	PCIBYS	QNSNPTJPXI	9801569665 Dell Way	\N	EJDNWTG	\N	0	China	2	QNSNPTJPXI@dell.com	9801569665	3	1897571926936507	2011/08	user16398	password	74	40000	F
16399	WSHVKY	IDMXXVNUER	9689696772 Dell Way	\N	EIEABLJ	\N	0	Australia	2	IDMXXVNUER@dell.com	9689696772	3	8645196604542435	2011/04	user16399	password	34	100000	F
16400	YCYJAH	MMFKISFMJJ	3147863781 Dell Way	\N	UOKWZTY	\N	0	UK	2	MMFKISFMJJ@dell.com	3147863781	4	5934875139035285	2010/12	user16400	password	45	80000	M
16401	MOHNVU	AAEISJVCTQ	2876176359 Dell Way	\N	QDNQXLO	\N	0	Canada	2	AAEISJVCTQ@dell.com	2876176359	1	6634661543183029	2009/07	user16401	password	35	20000	M
16402	UKMQEN	QJVJTRLMHC	4832493440 Dell Way	\N	QUSNFHQ	\N	0	France	2	QJVJTRLMHC@dell.com	4832493440	2	6795612084213645	2012/07	user16402	password	74	100000	F
16403	EKYJXO	STYMLJYSMO	9828877562 Dell Way	\N	NFBTNSF	\N	0	UK	2	STYMLJYSMO@dell.com	9828877562	5	8721264588646592	2010/08	user16403	password	74	80000	M
16404	ESECHX	WFJHPIABWO	4236152583 Dell Way	\N	HYIURNS	\N	0	Japan	2	WFJHPIABWO@dell.com	4236152583	3	2255569519940763	2012/05	user16404	password	86	80000	M
16405	RYQYWM	EGUTOVVLKD	2780721163 Dell Way	\N	KSXBFQS	\N	0	Germany	2	EGUTOVVLKD@dell.com	2780721163	5	6049820192158223	2010/10	user16405	password	43	20000	F
16406	HRJEEO	KZIYUEKEHU	4309298087 Dell Way	\N	XFVDVNS	\N	0	Australia	2	KZIYUEKEHU@dell.com	4309298087	2	6005049928557128	2008/08	user16406	password	63	60000	M
16407	HYCMNM	MVLGZVLGPJ	4774452721 Dell Way	\N	LLMHZEH	\N	0	China	2	MVLGZVLGPJ@dell.com	4774452721	5	5284041815437377	2008/06	user16407	password	21	100000	M
16408	AAGNNS	IZZIULPKUB	5236086625 Dell Way	\N	WGIVKQD	\N	0	South Africa	2	IZZIULPKUB@dell.com	5236086625	4	8753587826620788	2012/09	user16408	password	76	80000	M
16409	VZFISO	HSWCDLNYNJ	9735460166 Dell Way	\N	FVFQLIL	\N	0	UK	2	HSWCDLNYNJ@dell.com	9735460166	2	8780106957070530	2011/02	user16409	password	60	40000	M
16410	OOHHCP	ZYSDKFCXPH	7168652364 Dell Way	\N	TUXFDJD	\N	0	Canada	2	ZYSDKFCXPH@dell.com	7168652364	5	7799690688028932	2012/07	user16410	password	24	80000	F
16411	QAKSQK	RINCNPADXU	2015390744 Dell Way	\N	XUZBEDE	\N	0	South Africa	2	RINCNPADXU@dell.com	2015390744	5	6856586217880250	2011/01	user16411	password	47	100000	M
16412	LGJBQB	JEEXTFARZY	1733419561 Dell Way	\N	LYAPBEL	\N	0	Canada	2	JEEXTFARZY@dell.com	1733419561	1	8896535037085415	2008/07	user16412	password	69	80000	M
16413	YDZPFI	TJGNOGEOFQ	8184784061 Dell Way	\N	MFGOJRT	\N	0	France	2	TJGNOGEOFQ@dell.com	8184784061	4	5867741739843041	2009/05	user16413	password	38	40000	F
16414	KFXPOQ	ZUEOBICGYP	5912204437 Dell Way	\N	LFDVWXG	\N	0	Japan	2	ZUEOBICGYP@dell.com	5912204437	5	9880558152217420	2012/02	user16414	password	34	20000	M
16415	LBDASC	UWQWFSCEIO	5008434722 Dell Way	\N	JLJGJQY	\N	0	UK	2	UWQWFSCEIO@dell.com	5008434722	5	8254953758791090	2010/02	user16415	password	90	20000	M
16416	BEPUGJ	QXFWQIAYWJ	5059773556 Dell Way	\N	KGQTXOR	\N	0	China	2	QXFWQIAYWJ@dell.com	5059773556	3	8867008291184903	2010/06	user16416	password	85	20000	M
16417	CTIIDZ	GJVWRWVOFF	2415814878 Dell Way	\N	VVZSKRB	\N	0	South Africa	2	GJVWRWVOFF@dell.com	2415814878	5	4809295911807567	2011/11	user16417	password	61	20000	M
16418	INGMMN	VIJNEFCKKX	6000074393 Dell Way	\N	GKPQBQM	\N	0	Chile	2	VIJNEFCKKX@dell.com	6000074393	5	8642090359237046	2009/06	user16418	password	20	40000	M
16419	OOHBCD	JLQOQSZBPG	3266305764 Dell Way	\N	LFWMWJS	\N	0	France	2	JLQOQSZBPG@dell.com	3266305764	3	8177949511911721	2011/08	user16419	password	25	60000	F
16420	RWFTAP	FQDWJDYZJJ	2038866787 Dell Way	\N	EGWAPOL	\N	0	South Africa	2	FQDWJDYZJJ@dell.com	2038866787	2	6211679335683585	2011/05	user16420	password	29	100000	F
16421	ABUAQZ	RUWAYUZHDE	9051671223 Dell Way	\N	NAFCORY	\N	0	Japan	2	RUWAYUZHDE@dell.com	9051671223	3	4553118568845093	2009/09	user16421	password	36	40000	M
16422	HASYAK	TWKRRKYUPM	1268482077 Dell Way	\N	VVOKMNB	\N	0	China	2	TWKRRKYUPM@dell.com	1268482077	3	6400258004199714	2011/09	user16422	password	80	40000	F
16423	XCZXNS	UXKLIIGXVB	9966532431 Dell Way	\N	SJLFXNO	\N	0	UK	2	UXKLIIGXVB@dell.com	9966532431	1	6594818979501725	2011/01	user16423	password	19	80000	M
16424	DSVQLQ	OVCWEJUZKN	4882719300 Dell Way	\N	JWSGKHE	\N	0	China	2	OVCWEJUZKN@dell.com	4882719300	4	2006307791918516	2010/10	user16424	password	80	40000	M
16425	OFOZVC	VYZZHTYSHH	5185875107 Dell Way	\N	OANZHRJ	\N	0	Russia	2	VYZZHTYSHH@dell.com	5185875107	3	2424511732067913	2009/04	user16425	password	56	20000	M
16426	STXOWS	MVRTPPLWXA	8497224493 Dell Way	\N	WKZDCJW	\N	0	Germany	2	MVRTPPLWXA@dell.com	8497224493	1	8467815609648825	2008/07	user16426	password	19	20000	F
16427	TYVQQI	LIBAYNXVOU	8276505400 Dell Way	\N	GNYIWUX	\N	0	Russia	2	LIBAYNXVOU@dell.com	8276505400	4	8904947743751110	2009/10	user16427	password	86	80000	M
16428	WLDNTP	VVPTINOWHV	8225961007 Dell Way	\N	KFEHABA	\N	0	South Africa	2	VVPTINOWHV@dell.com	8225961007	5	2472626542672515	2010/10	user16428	password	74	20000	M
16429	FGFZVA	ULUCYJZGEK	6100857546 Dell Way	\N	LIRLKRH	\N	0	Canada	2	ULUCYJZGEK@dell.com	6100857546	3	7802715180441738	2009/03	user16429	password	79	20000	F
16430	CGKXHE	IBHHLHNPRZ	2236454124 Dell Way	\N	YJLIBSN	\N	0	Japan	2	IBHHLHNPRZ@dell.com	2236454124	2	9881517150904984	2009/02	user16430	password	21	80000	F
16431	IECPJL	RRSDYFSPFQ	7760350531 Dell Way	\N	ZQZAIMP	\N	0	France	2	RRSDYFSPFQ@dell.com	7760350531	3	8431308389641345	2012/08	user16431	password	62	20000	M
16432	UDPDOH	UHKTNCJSTI	5810150881 Dell Way	\N	ISIRFYD	\N	0	UK	2	UHKTNCJSTI@dell.com	5810150881	5	8399704155512155	2008/08	user16432	password	82	20000	F
16433	ATNPAI	WKCJNLCHTL	3142203951 Dell Way	\N	ZCCFAGE	\N	0	Germany	2	WKCJNLCHTL@dell.com	3142203951	5	7659406320191921	2012/11	user16433	password	83	40000	M
16434	QTMRCJ	BETPPVWJGW	2859613329 Dell Way	\N	LJBLQFA	\N	0	South Africa	2	BETPPVWJGW@dell.com	2859613329	4	7256370745599271	2008/08	user16434	password	83	100000	F
16435	QLYSVA	WOPMKLVRHH	5487011147 Dell Way	\N	AJTRPTN	\N	0	Russia	2	WOPMKLVRHH@dell.com	5487011147	2	8712926782667638	2008/02	user16435	password	77	60000	M
16436	GKMCKJ	QZVBLRSSYT	2441338469 Dell Way	\N	CRKRLYL	\N	0	UK	2	QZVBLRSSYT@dell.com	2441338469	2	1737402105703950	2009/02	user16436	password	56	20000	F
16437	XOMHXD	HTESLWLKPN	9398583929 Dell Way	\N	CAENYQL	\N	0	Australia	2	HTESLWLKPN@dell.com	9398583929	3	4465458618011326	2008/01	user16437	password	50	60000	M
16438	ZYGXBO	QFGCCRMRFO	1415841291 Dell Way	\N	RJBQANS	\N	0	UK	2	QFGCCRMRFO@dell.com	1415841291	1	1003196866251528	2008/07	user16438	password	50	20000	M
16439	JILLWC	QCESUQKZFC	6001486043 Dell Way	\N	JHSKULI	\N	0	South Africa	2	QCESUQKZFC@dell.com	6001486043	2	9403793333098292	2008/10	user16439	password	90	80000	F
16440	HBPDEF	GIYBZIAELK	5030553533 Dell Way	\N	LEUGQDC	\N	0	Canada	2	GIYBZIAELK@dell.com	5030553533	1	3515548918396235	2009/01	user16440	password	85	40000	F
16441	ZYLEES	MCTMLTQXEC	5030796763 Dell Way	\N	BZISCLW	\N	0	Germany	2	MCTMLTQXEC@dell.com	5030796763	1	7834984204266221	2010/01	user16441	password	28	80000	F
16442	CFFHXS	KQEWKVTPXV	5832320772 Dell Way	\N	OGNQRKE	\N	0	Canada	2	KQEWKVTPXV@dell.com	5832320772	5	6282130690291525	2011/01	user16442	password	42	80000	F
16443	OXLLPV	CTRMOLBMHQ	4135929031 Dell Way	\N	TUGLEKO	\N	0	Russia	2	CTRMOLBMHQ@dell.com	4135929031	1	3963721569627524	2010/06	user16443	password	90	60000	F
16444	XAMMWO	GOBVZDIGTB	2773987993 Dell Way	\N	BZMGKBZ	\N	0	Russia	2	GOBVZDIGTB@dell.com	2773987993	2	2600635311566293	2011/04	user16444	password	73	80000	F
16445	UFRQTX	EUTEXBKRCM	9729805755 Dell Way	\N	QOSBQRV	\N	0	South Africa	2	EUTEXBKRCM@dell.com	9729805755	1	5565935721620918	2009/10	user16445	password	34	60000	M
16446	LCEEAJ	ZTNXUYOXLF	1954490112 Dell Way	\N	MDHCVCX	\N	0	Russia	2	ZTNXUYOXLF@dell.com	1954490112	3	1463739932514727	2012/08	user16446	password	54	60000	F
16447	PPGQZG	JNDEMSBXXN	9364460531 Dell Way	\N	BEPWHNQ	\N	0	China	2	JNDEMSBXXN@dell.com	9364460531	4	3406046146992594	2010/03	user16447	password	67	80000	M
16448	HXKGDU	UHYGZADXOF	4741133596 Dell Way	\N	CDBJRSU	\N	0	Germany	2	UHYGZADXOF@dell.com	4741133596	1	2512854418251663	2011/09	user16448	password	77	60000	F
16449	SVHVQB	CPICPMZDRB	3320788064 Dell Way	\N	HSLYLFO	\N	0	South Africa	2	CPICPMZDRB@dell.com	3320788064	4	5110100573394448	2012/07	user16449	password	81	100000	F
16450	SHCIIF	XQHNCHRTJY	2804487236 Dell Way	\N	MUXXAMT	\N	0	Chile	2	XQHNCHRTJY@dell.com	2804487236	2	3264882500749081	2011/01	user16450	password	36	100000	M
16451	NBCWGA	NOOQVFKEEW	7623072961 Dell Way	\N	YCUZONG	\N	0	Russia	2	NOOQVFKEEW@dell.com	7623072961	3	5490154989529401	2012/09	user16451	password	52	60000	F
16452	NSDUTQ	IHGDMQIRNH	9765982862 Dell Way	\N	THGIVMC	\N	0	Germany	2	IHGDMQIRNH@dell.com	9765982862	3	4311761545483023	2011/01	user16452	password	88	100000	M
16453	RCJKTS	SAWFQEWELQ	6459443280 Dell Way	\N	LRYGEAV	\N	0	Canada	2	SAWFQEWELQ@dell.com	6459443280	1	8582217905204744	2011/02	user16453	password	77	40000	M
16454	YQGRIY	REDIIAMUQY	2882913930 Dell Way	\N	LPFPQAS	\N	0	Chile	2	REDIIAMUQY@dell.com	2882913930	3	9025506241247060	2009/05	user16454	password	28	20000	F
16455	ULZCKR	HNZQOMKFKV	7572170925 Dell Way	\N	UPLLQER	\N	0	South Africa	2	HNZQOMKFKV@dell.com	7572170925	3	2819108850788325	2008/09	user16455	password	46	60000	F
16456	VLOFCW	TCMIOWNZSI	9734407613 Dell Way	\N	PDTFHKB	\N	0	Australia	2	TCMIOWNZSI@dell.com	9734407613	2	2351313937921077	2011/08	user16456	password	61	20000	F
16457	ASSDOM	FAUUXHUPQJ	9127167025 Dell Way	\N	SKPAVQB	\N	0	Russia	2	FAUUXHUPQJ@dell.com	9127167025	2	5090664134360850	2010/10	user16457	password	60	20000	M
16458	HTYVFE	WZYTHSIYCB	3948317660 Dell Way	\N	IRBDIDY	\N	0	Chile	2	WZYTHSIYCB@dell.com	3948317660	2	8001824473962189	2008/12	user16458	password	78	100000	F
16459	PWCUBY	UZRCSZAVAJ	8541712617 Dell Way	\N	MCMVGLA	\N	0	Germany	2	UZRCSZAVAJ@dell.com	8541712617	5	7130332788452507	2012/08	user16459	password	63	20000	F
16460	NEAOCU	OUWHUWCVGP	3028971317 Dell Way	\N	XSKDEKS	\N	0	Australia	2	OUWHUWCVGP@dell.com	3028971317	2	8458032151684166	2012/01	user16460	password	84	20000	M
16461	CBBFWP	ZSWTPZOVOM	7722712982 Dell Way	\N	OYQTJJT	\N	0	Germany	2	ZSWTPZOVOM@dell.com	7722712982	3	4996689010411501	2011/06	user16461	password	55	40000	M
16462	PITLYT	EVMTUBPIOE	3374486777 Dell Way	\N	HEYQORG	\N	0	Chile	2	EVMTUBPIOE@dell.com	3374486777	4	1421914265025407	2011/03	user16462	password	41	40000	M
16463	RCFPVJ	KIDFKTOYXV	4400652810 Dell Way	\N	DVMRNSY	\N	0	Russia	2	KIDFKTOYXV@dell.com	4400652810	1	5900781320407987	2010/04	user16463	password	81	40000	M
16464	ZNPVWA	EZFOSTMQPQ	3246655788 Dell Way	\N	MBHATGU	\N	0	Canada	2	EZFOSTMQPQ@dell.com	3246655788	2	7366078098304570	2010/03	user16464	password	20	60000	F
16465	ODALEE	KJSDDFUSVH	4987975644 Dell Way	\N	UDHOJCS	\N	0	Japan	2	KJSDDFUSVH@dell.com	4987975644	3	2828899739310145	2011/06	user16465	password	73	100000	M
16466	XWKBAV	LTZOZUHUBC	7935851570 Dell Way	\N	YJQIMJY	\N	0	UK	2	LTZOZUHUBC@dell.com	7935851570	1	6151137599255890	2009/11	user16466	password	49	40000	M
16467	HQWIMI	CMWBGEWIHU	2776731549 Dell Way	\N	RYCEHBB	\N	0	Australia	2	CMWBGEWIHU@dell.com	2776731549	4	3408675801474601	2008/01	user16467	password	52	100000	F
16468	CUSPCU	BZWHESQLNI	2530624928 Dell Way	\N	JQMQRNS	\N	0	South Africa	2	BZWHESQLNI@dell.com	2530624928	5	9782233956269920	2009/06	user16468	password	83	80000	M
16469	SIDUDE	UZMYRCKFLT	1567193182 Dell Way	\N	VXKMLCJ	\N	0	Germany	2	UZMYRCKFLT@dell.com	1567193182	2	8524022041354329	2010/03	user16469	password	50	20000	M
16470	TFTWJN	WWMOZXTKQO	8057388994 Dell Way	\N	HBBSDLI	\N	0	Chile	2	WWMOZXTKQO@dell.com	8057388994	1	7438449696637691	2008/08	user16470	password	74	100000	F
16471	ZSGJGC	FSQFPJPGYX	1929525338 Dell Way	\N	HAQLLYR	\N	0	Chile	2	FSQFPJPGYX@dell.com	1929525338	2	3353646260220557	2011/02	user16471	password	34	20000	F
16472	YHMEKR	WAWMKMTIJB	5744661848 Dell Way	\N	JAMUYDA	\N	0	Australia	2	WAWMKMTIJB@dell.com	5744661848	2	7792292543686927	2011/07	user16472	password	78	80000	F
16473	DGPNYM	OVZYISHSUQ	7784734091 Dell Way	\N	SGKQKLR	\N	0	UK	2	OVZYISHSUQ@dell.com	7784734091	3	6609319315757603	2009/04	user16473	password	48	80000	F
16474	RIYQVM	LUKUNRMHHE	9577260754 Dell Way	\N	OSVZENY	\N	0	UK	2	LUKUNRMHHE@dell.com	9577260754	3	2881401918828487	2009/12	user16474	password	85	80000	M
16475	GOHBAS	WKNKCZRKDG	7405543908 Dell Way	\N	DZFHMEG	\N	0	France	2	WKNKCZRKDG@dell.com	7405543908	3	6795647774357349	2011/05	user16475	password	37	40000	M
16476	VPSVIP	GVZJVRTYXW	8782238885 Dell Way	\N	XDEKHKU	\N	0	Australia	2	GVZJVRTYXW@dell.com	8782238885	3	7189292029943318	2009/09	user16476	password	19	100000	M
16477	PPJYEP	UEYPVSNSOL	1887263321 Dell Way	\N	WTVEEQE	\N	0	Australia	2	UEYPVSNSOL@dell.com	1887263321	5	3482128891628236	2012/11	user16477	password	29	40000	F
16478	TSKYIE	CGUXZHQOTM	7083200885 Dell Way	\N	HPRLGVM	\N	0	China	2	CGUXZHQOTM@dell.com	7083200885	4	2489789101295173	2010/12	user16478	password	55	20000	M
16479	FLPNQS	UKPTSGIMSP	3897418238 Dell Way	\N	BJBIFOR	\N	0	South Africa	2	UKPTSGIMSP@dell.com	3897418238	5	4837214547675103	2009/05	user16479	password	50	100000	M
16480	XNCNFX	YVRQBZDUPF	1378295159 Dell Way	\N	EQNJFFG	\N	0	Germany	2	YVRQBZDUPF@dell.com	1378295159	4	7910637774504722	2009/02	user16480	password	68	100000	F
16481	FCOLZM	HRDIQGDFLH	6497296600 Dell Way	\N	WZRBEYP	\N	0	Chile	2	HRDIQGDFLH@dell.com	6497296600	2	6556434996891767	2011/01	user16481	password	61	80000	F
16482	RISQVZ	IZIYFLERTB	1449811627 Dell Way	\N	RKCVISB	\N	0	UK	2	IZIYFLERTB@dell.com	1449811627	4	7223094522953034	2008/04	user16482	password	52	40000	M
16483	UCPQCX	PKWVWANPBE	7628658569 Dell Way	\N	AEAJWBH	\N	0	UK	2	PKWVWANPBE@dell.com	7628658569	5	1112288936972618	2008/06	user16483	password	45	100000	F
16484	MNXOKN	ZGIWHVLIAM	2129547597 Dell Way	\N	NAVJBDH	\N	0	South Africa	2	ZGIWHVLIAM@dell.com	2129547597	2	8287964229006321	2010/09	user16484	password	72	100000	F
16485	GTSRGS	YPOFKAOLMB	1431841925 Dell Way	\N	LILNLTI	\N	0	Germany	2	YPOFKAOLMB@dell.com	1431841925	1	2468204996548593	2011/11	user16485	password	18	100000	F
16486	TPUAHT	PVYAVMLIOW	8389077390 Dell Way	\N	QAJCTSR	\N	0	South Africa	2	PVYAVMLIOW@dell.com	8389077390	5	5840731434058399	2011/11	user16486	password	49	100000	M
16487	BQQIJF	EHFAUQJJNA	6514574393 Dell Way	\N	JXCDPUY	\N	0	France	2	EHFAUQJJNA@dell.com	6514574393	3	1881559918634593	2010/11	user16487	password	84	20000	M
16488	NSHXXM	EDMZUWIHWS	2980147016 Dell Way	\N	EYVUSTE	\N	0	China	2	EDMZUWIHWS@dell.com	2980147016	2	8178020062390716	2008/03	user16488	password	81	20000	M
16489	OIQMUU	PHUKDCRZUW	2087516229 Dell Way	\N	YQRQJVZ	\N	0	Germany	2	PHUKDCRZUW@dell.com	2087516229	4	7430351173039526	2009/08	user16489	password	74	20000	F
16490	CRSXMI	EGSIIKIDHG	7010882537 Dell Way	\N	TYXDUWT	\N	0	South Africa	2	EGSIIKIDHG@dell.com	7010882537	3	2919623238034546	2009/03	user16490	password	37	60000	F
16491	YGFKPK	RHSZSADZHX	2976778438 Dell Way	\N	XEASBTP	\N	0	Russia	2	RHSZSADZHX@dell.com	2976778438	5	1484440437983721	2010/01	user16491	password	62	80000	F
16492	WZKMJC	UCBMDFMLCK	5281379102 Dell Way	\N	PDCRXRK	\N	0	Canada	2	UCBMDFMLCK@dell.com	5281379102	3	6060006802901626	2010/01	user16492	password	41	60000	M
16493	HZKRBE	UDRYIDJLNZ	5296623148 Dell Way	\N	OQQMHAP	\N	0	Russia	2	UDRYIDJLNZ@dell.com	5296623148	1	3869190826080740	2010/06	user16493	password	81	60000	M
16494	WWLXBG	ATEJWOUKNJ	6368767319 Dell Way	\N	BEVIFLC	\N	0	Japan	2	ATEJWOUKNJ@dell.com	6368767319	3	2925252515822649	2008/04	user16494	password	67	100000	F
16495	OIBQOC	JTLGIGRWPS	6256825339 Dell Way	\N	ALAFWDX	\N	0	France	2	JTLGIGRWPS@dell.com	6256825339	1	5964730124454946	2012/10	user16495	password	47	20000	F
16496	SCZHEJ	BPPJVGFLYG	5555617825 Dell Way	\N	XZMTDKG	\N	0	Russia	2	BPPJVGFLYG@dell.com	5555617825	4	6477185456082225	2009/03	user16496	password	65	80000	M
16497	TRFXAH	NQRJWXVVDS	5513247501 Dell Way	\N	VQMYASR	\N	0	Germany	2	NQRJWXVVDS@dell.com	5513247501	2	8388775662519039	2011/12	user16497	password	54	80000	M
16498	EWPFDC	VUMSRHNUZI	2875106246 Dell Way	\N	LMHLEYY	\N	0	Japan	2	VUMSRHNUZI@dell.com	2875106246	4	4402235716115683	2008/04	user16498	password	18	80000	F
16499	WJQZML	UYDLGRGFZR	8238120659 Dell Way	\N	RGCWFBO	\N	0	France	2	UYDLGRGFZR@dell.com	8238120659	5	5824166467413307	2008/12	user16499	password	42	60000	M
16500	SDUEOO	DSZJJFOJXG	6368286118 Dell Way	\N	QADVBRF	\N	0	South Africa	2	DSZJJFOJXG@dell.com	6368286118	4	9234960705973208	2010/02	user16500	password	47	40000	M
16501	NBZCQC	UPLEVANSHE	9688477776 Dell Way	\N	SKZUCFQ	\N	0	Japan	2	UPLEVANSHE@dell.com	9688477776	3	2784912571776658	2008/12	user16501	password	54	100000	F
16502	PVPFXJ	UIOQICIPGB	1160380353 Dell Way	\N	ZGWBLMT	\N	0	France	2	UIOQICIPGB@dell.com	1160380353	5	5159112201537937	2012/06	user16502	password	40	60000	F
16503	DAGAKA	IZQRBZGIBG	1298836607 Dell Way	\N	OXIAKCK	\N	0	France	2	IZQRBZGIBG@dell.com	1298836607	5	4437615947332233	2010/03	user16503	password	78	60000	F
16504	WTIGUR	GLIHLOQNVE	5219008640 Dell Way	\N	LEEVGPG	\N	0	Chile	2	GLIHLOQNVE@dell.com	5219008640	4	7905448534060270	2011/06	user16504	password	39	100000	F
16505	BHOVYU	HGCSVTGQXR	4092825593 Dell Way	\N	VCMBSSI	\N	0	Canada	2	HGCSVTGQXR@dell.com	4092825593	1	8472054618876428	2011/05	user16505	password	75	20000	F
16506	BRHZMP	FPHAIORGFM	9837921296 Dell Way	\N	IROBKWG	\N	0	Russia	2	FPHAIORGFM@dell.com	9837921296	1	5944537449162454	2009/11	user16506	password	65	100000	M
16507	ICWUSC	JZDROVXTIG	6588409887 Dell Way	\N	LWIVTOP	\N	0	Russia	2	JZDROVXTIG@dell.com	6588409887	1	1842000030446797	2010/10	user16507	password	84	40000	F
16508	AGXSJG	SMYGHWAPCL	1151131803 Dell Way	\N	MKHFZWY	\N	0	Germany	2	SMYGHWAPCL@dell.com	1151131803	1	1501316364854574	2012/12	user16508	password	49	100000	M
16509	RVRBCK	NARVWRLZCY	1650032784 Dell Way	\N	JKDIGBY	\N	0	Chile	2	NARVWRLZCY@dell.com	1650032784	5	1763905352447182	2008/05	user16509	password	18	100000	F
16510	VRDXBR	YTNVLZUOXE	4785777594 Dell Way	\N	YANECLM	\N	0	Canada	2	YTNVLZUOXE@dell.com	4785777594	3	2493458375800401	2012/07	user16510	password	27	100000	F
16511	UCHWTG	QHBBGVPEZN	7551619144 Dell Way	\N	FNSHYEL	\N	0	China	2	QHBBGVPEZN@dell.com	7551619144	4	2788106537889689	2009/09	user16511	password	28	80000	M
16512	FYKZFB	HGCOBSSBFX	3352817130 Dell Way	\N	OYFNDQW	\N	0	South Africa	2	HGCOBSSBFX@dell.com	3352817130	1	2238041275646537	2008/03	user16512	password	76	60000	F
16513	TZLYAS	FCGHVZIAXX	4486127016 Dell Way	\N	ZCLCTIZ	\N	0	UK	2	FCGHVZIAXX@dell.com	4486127016	1	1070389642845839	2011/11	user16513	password	59	20000	M
16514	OMQOEV	RLCMLLNIJM	7062570830 Dell Way	\N	KUPDCOD	\N	0	France	2	RLCMLLNIJM@dell.com	7062570830	1	1878511252813041	2010/09	user16514	password	28	40000	F
16515	PWUUSM	GUYRGMZPZJ	8025196304 Dell Way	\N	KONNDQA	\N	0	South Africa	2	GUYRGMZPZJ@dell.com	8025196304	1	4547541300766170	2010/04	user16515	password	64	80000	M
16516	NNRFAY	AZPGLPWKZH	9410553966 Dell Way	\N	ZMUCDVY	\N	0	UK	2	AZPGLPWKZH@dell.com	9410553966	2	4532869512680918	2008/12	user16516	password	26	20000	F
16517	QSRRQR	QGYBVVLUCK	8013013497 Dell Way	\N	HXNKTLI	\N	0	Japan	2	QGYBVVLUCK@dell.com	8013013497	4	8690886186901481	2011/11	user16517	password	84	40000	F
16518	QXDHOT	NNVJIGELRL	9289060057 Dell Way	\N	JFWCRFT	\N	0	France	2	NNVJIGELRL@dell.com	9289060057	4	2731087535154074	2011/07	user16518	password	47	40000	F
16519	HKLWEZ	JZISGNEYZN	9807278332 Dell Way	\N	EVPVBJH	\N	0	UK	2	JZISGNEYZN@dell.com	9807278332	3	7488021835219116	2010/11	user16519	password	88	80000	F
16520	JCAOBK	NKDUXITWVX	5363283938 Dell Way	\N	SLSTVAS	\N	0	Russia	2	NKDUXITWVX@dell.com	5363283938	3	3615326444152743	2009/05	user16520	password	86	60000	M
16521	AOHCZV	MDQKLJGGGY	8313829080 Dell Way	\N	SZRNZKI	\N	0	France	2	MDQKLJGGGY@dell.com	8313829080	4	8440065479371698	2009/07	user16521	password	44	100000	M
16522	YHRXDE	BTOMCUTITL	9247520283 Dell Way	\N	ILZHVHT	\N	0	Japan	2	BTOMCUTITL@dell.com	9247520283	3	8699956449680031	2010/12	user16522	password	78	20000	M
16523	CTUFXV	ZLHBGBKAMS	4175555853 Dell Way	\N	LMAHUUY	\N	0	Russia	2	ZLHBGBKAMS@dell.com	4175555853	5	2566662070807069	2009/08	user16523	password	34	20000	M
16524	ZYYWTY	IBZPCKPPDB	1931626677 Dell Way	\N	CDJWXHO	\N	0	Chile	2	IBZPCKPPDB@dell.com	1931626677	4	6061021352652461	2011/12	user16524	password	71	60000	M
16525	RLVLJD	NJSPTIFWKH	5484152821 Dell Way	\N	ATEYBTF	\N	0	Canada	2	NJSPTIFWKH@dell.com	5484152821	4	8936085332185031	2010/06	user16525	password	43	60000	F
16526	UGPDKD	MCTGLYDVGD	1444071805 Dell Way	\N	OLCQEHT	\N	0	Japan	2	MCTGLYDVGD@dell.com	1444071805	4	2343802197836339	2010/01	user16526	password	60	80000	M
16527	VIXFLK	IEQTDUPJXE	2842227003 Dell Way	\N	UZUZHOQ	\N	0	China	2	IEQTDUPJXE@dell.com	2842227003	4	8789903088472784	2009/05	user16527	password	60	100000	F
16528	XXKIIS	NZMQTBARGU	2713624254 Dell Way	\N	QATXPKG	\N	0	Russia	2	NZMQTBARGU@dell.com	2713624254	1	9938000147696584	2010/09	user16528	password	89	80000	M
16529	XDXFVK	EIBXKBOQVF	5400719349 Dell Way	\N	RPDGAJA	\N	0	Chile	2	EIBXKBOQVF@dell.com	5400719349	1	7822816191241146	2008/01	user16529	password	54	80000	M
16530	QRCMCH	UDFEEUVAAM	8131268052 Dell Way	\N	QDTQNTW	\N	0	Australia	2	UDFEEUVAAM@dell.com	8131268052	4	2703499787487089	2012/02	user16530	password	86	80000	M
16531	PUFRCZ	VHEZCAACMR	8028002117 Dell Way	\N	GFITZEU	\N	0	Russia	2	VHEZCAACMR@dell.com	8028002117	5	6184103213716299	2012/11	user16531	password	38	80000	M
16532	CVFEVA	MAAOABQMSX	4696187258 Dell Way	\N	SAQSELM	\N	0	UK	2	MAAOABQMSX@dell.com	4696187258	1	8682757765054704	2009/04	user16532	password	52	100000	F
16533	IBODBB	DBPDCGQVDJ	6265410549 Dell Way	\N	VUBAFNZ	\N	0	Japan	2	DBPDCGQVDJ@dell.com	6265410549	5	9602440180256964	2012/04	user16533	password	76	40000	M
16534	VXTXYX	ZNBCUSXXBS	5866300588 Dell Way	\N	SDTXRSO	\N	0	Chile	2	ZNBCUSXXBS@dell.com	5866300588	3	2389844800811261	2012/04	user16534	password	52	60000	F
16535	JFAHDZ	VEBPWZMYRE	2308440088 Dell Way	\N	BLCSDQZ	\N	0	Japan	2	VEBPWZMYRE@dell.com	2308440088	1	5754876764956862	2010/08	user16535	password	90	60000	M
16536	FPFIPA	NRPJQCHIHJ	2460459359 Dell Way	\N	TJCXABO	\N	0	Canada	2	NRPJQCHIHJ@dell.com	2460459359	1	6500418842770160	2011/02	user16536	password	31	80000	F
16537	UXQJXD	ANNRQVZXET	3462912779 Dell Way	\N	HHQHIEM	\N	0	France	2	ANNRQVZXET@dell.com	3462912779	1	3000693034846335	2009/04	user16537	password	83	80000	F
16538	UILSLM	GZDWUDTZWB	9174994839 Dell Way	\N	GMJORVB	\N	0	UK	2	GZDWUDTZWB@dell.com	9174994839	2	3606991236563772	2008/03	user16538	password	87	40000	M
16539	GRRSDX	RHUMKNMGPT	6671363009 Dell Way	\N	SYIJTJI	\N	0	Japan	2	RHUMKNMGPT@dell.com	6671363009	3	8530184659641237	2012/07	user16539	password	23	80000	M
16540	TLNWJF	DESOSFUHYN	8281882898 Dell Way	\N	FGXYPFP	\N	0	Chile	2	DESOSFUHYN@dell.com	8281882898	3	1394318311475217	2009/07	user16540	password	77	20000	F
16541	HSDRYH	VRVNWQUUDZ	9972798046 Dell Way	\N	BBYRGOX	\N	0	Australia	2	VRVNWQUUDZ@dell.com	9972798046	5	4942036826629192	2010/10	user16541	password	63	80000	F
16542	IXSHEN	YAAVQVQUVR	2729527394 Dell Way	\N	VTICIGE	\N	0	China	2	YAAVQVQUVR@dell.com	2729527394	4	8450527159031481	2012/03	user16542	password	61	20000	M
16543	NSWRGU	SGQICGDXXZ	9065879463 Dell Way	\N	RGCZMHI	\N	0	Japan	2	SGQICGDXXZ@dell.com	9065879463	1	6718775303568692	2008/09	user16543	password	64	80000	F
16544	JPYPJQ	WZZYFCWDBO	9962245867 Dell Way	\N	JEOWLWN	\N	0	China	2	WZZYFCWDBO@dell.com	9962245867	1	5154617540072650	2011/10	user16544	password	31	100000	F
16545	TXTDNP	DMOJPKMQYW	4849053935 Dell Way	\N	UMSFJGO	\N	0	China	2	DMOJPKMQYW@dell.com	4849053935	1	1727030728477984	2009/03	user16545	password	21	40000	M
16546	YDCMTF	YHPORCEQYZ	7978329597 Dell Way	\N	DRFMYTV	\N	0	China	2	YHPORCEQYZ@dell.com	7978329597	5	6479380140081049	2012/12	user16546	password	18	100000	M
16547	DZJWFI	DVWVXBLWBP	8001039986 Dell Way	\N	NGBMAWW	\N	0	South Africa	2	DVWVXBLWBP@dell.com	8001039986	3	7958824082743377	2011/06	user16547	password	68	80000	M
16548	RAMXJQ	SGLPIXLJMZ	8080059238 Dell Way	\N	QNMRKIM	\N	0	Canada	2	SGLPIXLJMZ@dell.com	8080059238	2	9267518482171000	2009/12	user16548	password	59	100000	M
16549	PINYZG	FKWNIIXUHN	9365250505 Dell Way	\N	IUFTCRX	\N	0	South Africa	2	FKWNIIXUHN@dell.com	9365250505	5	2304955911356956	2012/05	user16549	password	18	60000	M
16550	IAYIGD	SDRBLOVTCE	6850119491 Dell Way	\N	NHXQZVN	\N	0	UK	2	SDRBLOVTCE@dell.com	6850119491	4	8046318658627570	2008/09	user16550	password	37	20000	F
16551	HZIODB	RUCCJYWMCJ	2806550337 Dell Way	\N	UZAUVNR	\N	0	France	2	RUCCJYWMCJ@dell.com	2806550337	3	5580341677647085	2012/09	user16551	password	57	100000	F
16552	NFPQGH	LJKVHGHKQC	1328673986 Dell Way	\N	KQWFEOR	\N	0	China	2	LJKVHGHKQC@dell.com	1328673986	1	3236108990386128	2011/09	user16552	password	28	100000	F
16553	JKWQSI	ZCEHIMRZOB	2027566150 Dell Way	\N	PLHUZYE	\N	0	Australia	2	ZCEHIMRZOB@dell.com	2027566150	3	8360460759606213	2012/07	user16553	password	64	20000	M
16554	BYNTHN	VLUEXMDMOT	2095460857 Dell Way	\N	XVOXTSY	\N	0	South Africa	2	VLUEXMDMOT@dell.com	2095460857	4	7319144784007222	2011/05	user16554	password	74	60000	F
16555	SCFAPB	LKGJWKWKEU	4798627245 Dell Way	\N	FSSZLQW	\N	0	Germany	2	LKGJWKWKEU@dell.com	4798627245	3	3025427381508052	2012/04	user16555	password	76	40000	F
16556	XNBMPN	XWWTHTELNK	8338999822 Dell Way	\N	EFKPWGE	\N	0	Chile	2	XWWTHTELNK@dell.com	8338999822	2	2065685059875250	2008/03	user16556	password	48	20000	F
16557	YGOOTL	KQFSJKDWVH	4887061168 Dell Way	\N	CFXYMBG	\N	0	Chile	2	KQFSJKDWVH@dell.com	4887061168	2	4826880968641490	2011/10	user16557	password	63	80000	M
16558	WGHQSS	GYKQIONDWP	2420163091 Dell Way	\N	JTOVUUC	\N	0	Chile	2	GYKQIONDWP@dell.com	2420163091	3	8570683652069420	2012/02	user16558	password	55	80000	F
16559	TZQLSW	JDMSRZWNPF	6913310349 Dell Way	\N	HDABYDH	\N	0	Canada	2	JDMSRZWNPF@dell.com	6913310349	1	1404254533816129	2012/08	user16559	password	71	100000	F
16560	SLWKIG	NVZFVVSKAZ	5722323510 Dell Way	\N	OBBMFJP	\N	0	South Africa	2	NVZFVVSKAZ@dell.com	5722323510	4	6880741010420025	2008/05	user16560	password	51	80000	F
16561	XMMFTA	ASGVNZGOZU	5931835965 Dell Way	\N	PAHVKXR	\N	0	UK	2	ASGVNZGOZU@dell.com	5931835965	2	2134072995278984	2012/10	user16561	password	71	20000	M
16562	FNXYNY	QUUETASSVI	1903062115 Dell Way	\N	TDDEAUC	\N	0	Germany	2	QUUETASSVI@dell.com	1903062115	2	5423570688813925	2012/12	user16562	password	54	60000	F
16563	ZLCNKT	HEXBEPTZYM	9567232746 Dell Way	\N	DBQDVTS	\N	0	UK	2	HEXBEPTZYM@dell.com	9567232746	2	8345321571454407	2012/09	user16563	password	45	20000	M
16564	VEFFXN	JVOOKIOIUR	7535057605 Dell Way	\N	KLVGENE	\N	0	Canada	2	JVOOKIOIUR@dell.com	7535057605	5	1321235705632716	2010/05	user16564	password	25	20000	F
16565	GIKEWU	ZLIKTWTOOE	6007165856 Dell Way	\N	AJKFXOI	\N	0	Japan	2	ZLIKTWTOOE@dell.com	6007165856	2	1343652581796050	2012/06	user16565	password	29	20000	M
16566	NNXJHX	VQIPNCDBGE	1586493809 Dell Way	\N	LQJIFSY	\N	0	Russia	2	VQIPNCDBGE@dell.com	1586493809	5	7194746369030327	2010/02	user16566	password	76	40000	M
16567	IEAQCV	GLLUNPWTTH	5956186421 Dell Way	\N	KDQQVOK	\N	0	South Africa	2	GLLUNPWTTH@dell.com	5956186421	1	4703640417195857	2011/11	user16567	password	67	40000	F
16568	WJVYEC	JPWXFTRYBB	2560052152 Dell Way	\N	BRSWGCT	\N	0	South Africa	2	JPWXFTRYBB@dell.com	2560052152	1	5393437294289470	2008/11	user16568	password	77	40000	M
16569	ECRJEB	ZBYEVPCWRE	9666724063 Dell Way	\N	NJBULUP	\N	0	Japan	2	ZBYEVPCWRE@dell.com	9666724063	1	7194238019175828	2012/11	user16569	password	87	60000	F
16570	BEKFFJ	HDOCTQZKVN	9569952627 Dell Way	\N	UWHGRWW	\N	0	Japan	2	HDOCTQZKVN@dell.com	9569952627	3	4828959207050502	2012/07	user16570	password	86	100000	M
16571	CIUISB	MGEFXDQSQK	1508345181 Dell Way	\N	OYQFVMV	\N	0	Russia	2	MGEFXDQSQK@dell.com	1508345181	2	6446144691202790	2010/03	user16571	password	55	20000	F
16572	VWQNYC	TDHQGXIXHX	3012292922 Dell Way	\N	VYDQLYK	\N	0	France	2	TDHQGXIXHX@dell.com	3012292922	1	1488391101360321	2010/07	user16572	password	29	80000	F
16573	BJVZLP	CTGJRPGZMC	2133647860 Dell Way	\N	XPSIODV	\N	0	Russia	2	CTGJRPGZMC@dell.com	2133647860	5	2957895062398165	2011/01	user16573	password	87	100000	F
16574	HVCTKE	NQOEFVDSXA	1795186166 Dell Way	\N	IQJXTFR	\N	0	South Africa	2	NQOEFVDSXA@dell.com	1795186166	5	5620443778578193	2008/11	user16574	password	52	40000	F
16575	HHXSMK	IBPOWSHTTP	1504132684 Dell Way	\N	KDMDIEA	\N	0	France	2	IBPOWSHTTP@dell.com	1504132684	3	5978350985329599	2012/01	user16575	password	74	20000	F
16576	CZZOKI	QZXMREGLTQ	3683260164 Dell Way	\N	OGTXKUI	\N	0	France	2	QZXMREGLTQ@dell.com	3683260164	5	4125784401781857	2009/08	user16576	password	47	80000	M
16577	JPHTYX	TVKLAQWTGL	5438793029 Dell Way	\N	ZZIJTQV	\N	0	Australia	2	TVKLAQWTGL@dell.com	5438793029	1	4348560049198568	2008/07	user16577	password	89	100000	M
16578	PESNCM	JMXJCTDJED	5633188453 Dell Way	\N	JMNDDIE	\N	0	Japan	2	JMXJCTDJED@dell.com	5633188453	3	7767403031233699	2008/07	user16578	password	62	20000	F
16579	UUQWGZ	IDILWMUBPD	9947271496 Dell Way	\N	OCGRLLH	\N	0	UK	2	IDILWMUBPD@dell.com	9947271496	1	1582537702284753	2010/08	user16579	password	26	80000	F
16580	XGHDGQ	HOCDBWFQAT	7771056828 Dell Way	\N	THLFSSE	\N	0	Russia	2	HOCDBWFQAT@dell.com	7771056828	2	3110193953849375	2010/05	user16580	password	81	100000	F
16581	DDKJTR	YVVZSBQSUK	1423602107 Dell Way	\N	AFPSYUL	\N	0	Japan	2	YVVZSBQSUK@dell.com	1423602107	4	1883246558718383	2010/07	user16581	password	86	80000	M
16582	BCAVUY	QQXJROCMYC	9049678815 Dell Way	\N	SOUQIGI	\N	0	China	2	QQXJROCMYC@dell.com	9049678815	3	8218738622963429	2010/05	user16582	password	53	20000	F
16583	PBGKAX	AXGSLJEKLW	3816502777 Dell Way	\N	YGNGMWQ	\N	0	China	2	AXGSLJEKLW@dell.com	3816502777	3	8166099818423391	2011/12	user16583	password	81	20000	M
16584	YJYYHY	WNQIXVSISQ	1157717502 Dell Way	\N	PGXBCOL	\N	0	France	2	WNQIXVSISQ@dell.com	1157717502	2	1938466025516390	2012/02	user16584	password	34	60000	F
16585	PLZWJW	KAEHVXQNOF	9214706880 Dell Way	\N	TLGWARH	\N	0	Australia	2	KAEHVXQNOF@dell.com	9214706880	2	9988932635635140	2008/08	user16585	password	54	20000	F
16586	YABHXL	HBTDZJRNOK	9486902342 Dell Way	\N	ZVHZNOA	\N	0	France	2	HBTDZJRNOK@dell.com	9486902342	1	4807795270346105	2010/07	user16586	password	52	80000	F
16587	NVTKGB	LAEKJVYYGX	9175977173 Dell Way	\N	TNWGCXR	\N	0	Australia	2	LAEKJVYYGX@dell.com	9175977173	1	6217013176530600	2010/07	user16587	password	41	100000	F
16588	DPLKRX	KVIURGTYEN	5975686407 Dell Way	\N	MAUOXLP	\N	0	South Africa	2	KVIURGTYEN@dell.com	5975686407	1	3288779792841524	2008/06	user16588	password	27	20000	M
16589	TQAKOL	GXGYEZWINI	6465980284 Dell Way	\N	JHWGSLC	\N	0	Chile	2	GXGYEZWINI@dell.com	6465980284	2	4623914247844368	2008/06	user16589	password	61	80000	F
16590	GTPVFW	SLUWLQFYZO	3412392203 Dell Way	\N	FVVYHXG	\N	0	UK	2	SLUWLQFYZO@dell.com	3412392203	4	9950596371199936	2011/03	user16590	password	69	100000	F
16591	LOHRLA	CFXOWCNVQS	5934807530 Dell Way	\N	RLRZJXW	\N	0	Japan	2	CFXOWCNVQS@dell.com	5934807530	5	4478923491667956	2011/08	user16591	password	43	40000	F
16592	XOSJOU	OLJLOWHEOZ	7257408819 Dell Way	\N	QGYAEVR	\N	0	Russia	2	OLJLOWHEOZ@dell.com	7257408819	1	5488675524946302	2009/05	user16592	password	73	40000	F
16593	IARWVG	IERWAZBPYS	4643712361 Dell Way	\N	WWSASJT	\N	0	China	2	IERWAZBPYS@dell.com	4643712361	2	7096393569838256	2011/01	user16593	password	90	20000	F
16594	ATFVAN	ARKARLQPDM	5353882686 Dell Way	\N	MWNEFGO	\N	0	Japan	2	ARKARLQPDM@dell.com	5353882686	2	4791495896875858	2010/04	user16594	password	56	80000	F
16595	HZCHND	ZXDQJUGNGS	7509656671 Dell Way	\N	JTXPZMG	\N	0	France	2	ZXDQJUGNGS@dell.com	7509656671	4	9618785888887944	2012/03	user16595	password	73	40000	F
16596	TJTGMT	EQKOKQBQIL	9478372284 Dell Way	\N	KGBJSHW	\N	0	France	2	EQKOKQBQIL@dell.com	9478372284	5	4644177968148142	2008/07	user16596	password	65	60000	F
16597	AIOMCT	CMHNCJDLUN	6040609469 Dell Way	\N	RWXJDTV	\N	0	Australia	2	CMHNCJDLUN@dell.com	6040609469	2	2828968508634716	2008/11	user16597	password	75	60000	M
16598	DAJFTM	RBZUKDFFQX	3762310370 Dell Way	\N	BOHFHCH	\N	0	South Africa	2	RBZUKDFFQX@dell.com	3762310370	3	9901296619325876	2008/04	user16598	password	48	20000	F
16599	LKQEXI	FWCPZIVQFW	8388836716 Dell Way	\N	FNBNPIJ	\N	0	UK	2	FWCPZIVQFW@dell.com	8388836716	2	1748255086131394	2008/10	user16599	password	27	60000	F
16600	OCJLKP	INFIVAZBWE	4756877949 Dell Way	\N	PYREHBC	\N	0	Canada	2	INFIVAZBWE@dell.com	4756877949	1	2757179905194789	2009/04	user16600	password	68	60000	M
16601	UUIFKQ	TPZPQYQNCF	6992620696 Dell Way	\N	LUKSWMV	\N	0	Chile	2	TPZPQYQNCF@dell.com	6992620696	1	5231376260053367	2012/09	user16601	password	82	100000	M
16602	RDTBUM	RTBHRSUUYG	8407468702 Dell Way	\N	PIYLVUS	\N	0	Germany	2	RTBHRSUUYG@dell.com	8407468702	1	5301991229411215	2010/01	user16602	password	40	20000	M
16603	LUVGHM	ZITRBNMZTC	5165023371 Dell Way	\N	ISOENHR	\N	0	China	2	ZITRBNMZTC@dell.com	5165023371	1	8960375282913447	2010/06	user16603	password	86	40000	M
16604	TCEAOE	JIWLVJKPLT	8077019315 Dell Way	\N	IAYWHQF	\N	0	Russia	2	JIWLVJKPLT@dell.com	8077019315	1	3465758121106774	2009/01	user16604	password	58	20000	M
16605	QJUFOE	NLPJUAZGUH	5052565823 Dell Way	\N	GSENIJG	\N	0	Canada	2	NLPJUAZGUH@dell.com	5052565823	3	4455594299826771	2010/02	user16605	password	60	40000	M
16606	YBYNFL	YVUSVTZPBF	5846888440 Dell Way	\N	IFTQPAU	\N	0	Australia	2	YVUSVTZPBF@dell.com	5846888440	1	5579516625963152	2011/09	user16606	password	73	40000	M
16607	VHFBSD	WNWRHVHIAP	2395332231 Dell Way	\N	OUGDUAD	\N	0	China	2	WNWRHVHIAP@dell.com	2395332231	4	9469346923753620	2012/06	user16607	password	40	60000	F
16608	PUHIXD	WUVDPCLQRZ	9268243856 Dell Way	\N	KXCEXGM	\N	0	Australia	2	WUVDPCLQRZ@dell.com	9268243856	3	9521054750308396	2009/09	user16608	password	56	60000	F
16609	HWRFZN	AUQPWBGOBQ	7705743425 Dell Way	\N	LEVJLIK	\N	0	China	2	AUQPWBGOBQ@dell.com	7705743425	2	7287577765528113	2010/11	user16609	password	38	100000	F
16610	DMKDZK	XPAURGJTXU	9296505881 Dell Way	\N	XSDJAOS	\N	0	Russia	2	XPAURGJTXU@dell.com	9296505881	3	3264575647655874	2012/09	user16610	password	22	100000	M
16611	NKYMVW	CVRTCAMZUK	8784555803 Dell Way	\N	RYTSNLM	\N	0	France	2	CVRTCAMZUK@dell.com	8784555803	4	3198731665965170	2010/10	user16611	password	35	40000	F
16612	QIVMEX	HVRJVEJQOA	9625935379 Dell Way	\N	PITDTFO	\N	0	Japan	2	HVRJVEJQOA@dell.com	9625935379	5	2654338408261537	2011/01	user16612	password	58	20000	M
16613	WXDBVL	WMVSQEJFFZ	5067280103 Dell Way	\N	NYCHEQY	\N	0	Canada	2	WMVSQEJFFZ@dell.com	5067280103	1	8908166143111885	2010/09	user16613	password	87	20000	M
16614	WIPRUL	EPEVTOAZNO	9115673944 Dell Way	\N	XQWBHUF	\N	0	Russia	2	EPEVTOAZNO@dell.com	9115673944	1	3009880581405014	2010/01	user16614	password	47	20000	M
16615	SRONDT	CIOWXPVLES	1605351247 Dell Way	\N	BAUIVZB	\N	0	Russia	2	CIOWXPVLES@dell.com	1605351247	2	3572018030565232	2008/09	user16615	password	46	100000	F
16616	BOXFHA	OWWLMSWQLX	6486879864 Dell Way	\N	RGGMFIF	\N	0	Chile	2	OWWLMSWQLX@dell.com	6486879864	3	4560722463764250	2009/11	user16616	password	46	80000	M
16617	YQEGRS	DODPGAFRYW	1235676456 Dell Way	\N	XEJDNOL	\N	0	Canada	2	DODPGAFRYW@dell.com	1235676456	5	4790887144394219	2012/03	user16617	password	28	100000	F
16618	UZLLSO	ZWDFWIXUFV	3416377584 Dell Way	\N	ZOZNDLQ	\N	0	Canada	2	ZWDFWIXUFV@dell.com	3416377584	1	1379836935084313	2010/03	user16618	password	82	80000	M
16619	WCKOQK	LTPHCNCIJC	3339072934 Dell Way	\N	XIPATFE	\N	0	Australia	2	LTPHCNCIJC@dell.com	3339072934	2	5754506418947131	2010/02	user16619	password	32	60000	M
16620	HVNYFZ	SVGUIJDSLA	4794876997 Dell Way	\N	AABUGFV	\N	0	France	2	SVGUIJDSLA@dell.com	4794876997	2	9479661060962828	2010/07	user16620	password	43	60000	M
16621	EAUJZM	EFHNPLGALG	3304957901 Dell Way	\N	ANBHSXU	\N	0	Canada	2	EFHNPLGALG@dell.com	3304957901	4	6792213733773679	2012/01	user16621	password	26	80000	F
16622	DMPCZU	IGIXSOXDVY	7407827913 Dell Way	\N	QXFJUZM	\N	0	Australia	2	IGIXSOXDVY@dell.com	7407827913	1	8859208557289095	2011/04	user16622	password	57	20000	F
16623	AQMZLU	GTSYIPCEOT	7567224625 Dell Way	\N	BUCWUPY	\N	0	Germany	2	GTSYIPCEOT@dell.com	7567224625	5	3602398158982396	2012/05	user16623	password	40	40000	F
16624	YVJJPP	DINMYQQMJS	4017523732 Dell Way	\N	HLPCBNP	\N	0	Russia	2	DINMYQQMJS@dell.com	4017523732	5	7802080636844040	2011/03	user16624	password	26	20000	F
16625	YKMOAQ	WOCUESHNLO	2374134323 Dell Way	\N	ZARAOGU	\N	0	South Africa	2	WOCUESHNLO@dell.com	2374134323	3	6160769147798420	2009/09	user16625	password	64	60000	M
16626	BZEBPA	QRUUKCIVQH	7225616578 Dell Way	\N	VIIJODG	\N	0	Russia	2	QRUUKCIVQH@dell.com	7225616578	5	1639645347837358	2009/06	user16626	password	57	100000	M
16627	NDPCDF	TYZDAIZRQU	3595105228 Dell Way	\N	ZYEOCLG	\N	0	Russia	2	TYZDAIZRQU@dell.com	3595105228	2	2297392706386745	2011/11	user16627	password	26	40000	F
16628	GWNJCG	ICKIKJAAEZ	2209695435 Dell Way	\N	ZJNCVUW	\N	0	Canada	2	ICKIKJAAEZ@dell.com	2209695435	1	8829558383673430	2008/02	user16628	password	29	60000	F
16629	BYSDEA	FPJQZJREJR	6529300542 Dell Way	\N	OWTJRPM	\N	0	South Africa	2	FPJQZJREJR@dell.com	6529300542	2	8431049581617118	2011/06	user16629	password	36	20000	M
16630	EVRJVX	ZFNYPFDYWR	8447934062 Dell Way	\N	VPAMFMH	\N	0	South Africa	2	ZFNYPFDYWR@dell.com	8447934062	1	6001319658942521	2009/05	user16630	password	64	100000	M
16631	LNXHLW	NZVCEYAAQW	7556533097 Dell Way	\N	QQIWDQR	\N	0	UK	2	NZVCEYAAQW@dell.com	7556533097	2	3593344169668853	2008/11	user16631	password	28	80000	F
16632	RNPDJD	CFFGDGHUCY	7159838391 Dell Way	\N	KLUOBLN	\N	0	Russia	2	CFFGDGHUCY@dell.com	7159838391	5	8894491357263179	2010/12	user16632	password	54	100000	M
16633	AMTKPW	PVDTCLNFJY	8400217383 Dell Way	\N	QEMSQAM	\N	0	China	2	PVDTCLNFJY@dell.com	8400217383	2	8790381146129222	2011/11	user16633	password	71	60000	M
16634	FEHVBX	QEQSPEXZCO	1919077141 Dell Way	\N	EPGUQTC	\N	0	France	2	QEQSPEXZCO@dell.com	1919077141	5	3044045901857316	2012/09	user16634	password	65	100000	M
16635	VDSXAJ	BRCRVARYOV	7522799244 Dell Way	\N	OUQEOTQ	\N	0	Japan	2	BRCRVARYOV@dell.com	7522799244	5	6518421951215715	2010/06	user16635	password	51	40000	F
16636	PCFPLH	GNZBNQACMO	2826334181 Dell Way	\N	XDTLWJC	\N	0	Germany	2	GNZBNQACMO@dell.com	2826334181	4	1231184892356395	2011/02	user16636	password	45	20000	M
16637	LGIXOP	LNRYERAQGY	2270404989 Dell Way	\N	UZJQILG	\N	0	Germany	2	LNRYERAQGY@dell.com	2270404989	2	3080634472426027	2009/08	user16637	password	37	20000	F
16638	NJZCZK	PQJUIKKOIF	3907156417 Dell Way	\N	NSVWDBJ	\N	0	Chile	2	PQJUIKKOIF@dell.com	3907156417	4	6182370448019356	2012/11	user16638	password	62	20000	F
16639	ZBMYLC	PVWXGHLOMZ	8451873954 Dell Way	\N	GIVKJFR	\N	0	Russia	2	PVWXGHLOMZ@dell.com	8451873954	2	6962244403082878	2011/11	user16639	password	69	20000	M
16640	TPVFSK	AOIGWTVITC	4859487535 Dell Way	\N	RPMBUET	\N	0	Japan	2	AOIGWTVITC@dell.com	4859487535	3	3963191971648485	2009/02	user16640	password	50	20000	M
16641	BZBUJC	IRJFLFOFIF	4615221480 Dell Way	\N	UVGOZZE	\N	0	France	2	IRJFLFOFIF@dell.com	4615221480	3	7375686781015248	2010/12	user16641	password	81	40000	F
16642	VMUFOD	XYIJEXOMCI	6251538013 Dell Way	\N	HIXHIBR	\N	0	Russia	2	XYIJEXOMCI@dell.com	6251538013	2	3328677698038518	2010/04	user16642	password	65	60000	F
16643	DJHRNF	QWOVTCHVKP	9301545807 Dell Way	\N	EHWNJNG	\N	0	UK	2	QWOVTCHVKP@dell.com	9301545807	3	5433719744440168	2008/03	user16643	password	22	40000	F
16644	LOZYTQ	VHLOJSKUHP	9084277526 Dell Way	\N	CDDLRJK	\N	0	Japan	2	VHLOJSKUHP@dell.com	9084277526	5	8038027246482671	2008/12	user16644	password	21	40000	F
16645	PIIJYE	RJSBCDVKSX	6667865991 Dell Way	\N	OVJGFTW	\N	0	Canada	2	RJSBCDVKSX@dell.com	6667865991	4	2583668797276914	2010/09	user16645	password	56	100000	F
16646	WIQUMH	EEIHHESACG	9820088848 Dell Way	\N	WLNBEJE	\N	0	South Africa	2	EEIHHESACG@dell.com	9820088848	2	4570528276264668	2011/11	user16646	password	44	100000	M
16647	RPNDWS	IFAQJSQLZN	1694418365 Dell Way	\N	XMOCVTX	\N	0	South Africa	2	IFAQJSQLZN@dell.com	1694418365	2	5129961442667991	2012/09	user16647	password	46	80000	F
16648	ZFMWYV	BYLLRCXQPU	1818537859 Dell Way	\N	CEWYXUT	\N	0	UK	2	BYLLRCXQPU@dell.com	1818537859	2	9363585134036840	2011/08	user16648	password	62	20000	M
16649	VPKTKM	SWXKZVAPPD	1239433020 Dell Way	\N	TMCQHVQ	\N	0	China	2	SWXKZVAPPD@dell.com	1239433020	3	2184837375767529	2011/03	user16649	password	35	20000	M
16650	VPTGCM	CAWCVXRKBK	3171493602 Dell Way	\N	XDBFZRO	\N	0	UK	2	CAWCVXRKBK@dell.com	3171493602	4	6540328511968256	2010/12	user16650	password	76	60000	M
16651	KEANQD	NNFILWTMHQ	2048168147 Dell Way	\N	QIWPAKP	\N	0	Chile	2	NNFILWTMHQ@dell.com	2048168147	2	7015679765027017	2008/01	user16651	password	23	100000	F
16652	GVYWYL	KETVAMIHDY	3965313628 Dell Way	\N	QZORKDX	\N	0	Germany	2	KETVAMIHDY@dell.com	3965313628	3	6117836909834296	2009/08	user16652	password	46	80000	M
16653	FSUEDE	IWAJJJRNHI	5293354378 Dell Way	\N	MVZXZXK	\N	0	China	2	IWAJJJRNHI@dell.com	5293354378	5	6771247517783195	2008/05	user16653	password	47	20000	M
16654	CVTFZC	CALMJDZRLM	7578748405 Dell Way	\N	NKJMHTU	\N	0	Russia	2	CALMJDZRLM@dell.com	7578748405	3	9110563858412208	2008/11	user16654	password	86	80000	M
16655	TKETNH	TYTDCTUNFI	1472040292 Dell Way	\N	XOVFIPY	\N	0	Australia	2	TYTDCTUNFI@dell.com	1472040292	5	2224636181723326	2012/10	user16655	password	76	100000	M
16656	FAHTHA	SBEUUZHZHE	2794780879 Dell Way	\N	NCJVSIX	\N	0	Russia	2	SBEUUZHZHE@dell.com	2794780879	1	7052200211677701	2012/10	user16656	password	55	60000	F
16657	NUUVVM	WZGQYOPGSD	8971791250 Dell Way	\N	JCZBLWW	\N	0	Japan	2	WZGQYOPGSD@dell.com	8971791250	3	6765589079353959	2011/01	user16657	password	30	80000	M
16658	YOJUBF	TIVSWLYPOH	7820747642 Dell Way	\N	SOJEKGV	\N	0	Chile	2	TIVSWLYPOH@dell.com	7820747642	3	1058671926613897	2011/08	user16658	password	75	40000	M
16659	JSJKYD	TTWQFUGUCY	4463359299 Dell Way	\N	IMCSSYA	\N	0	France	2	TTWQFUGUCY@dell.com	4463359299	1	3522700240835547	2008/10	user16659	password	63	60000	F
16660	IYPGCI	AYYGTEAWDI	1922769629 Dell Way	\N	JGBCECO	\N	0	Germany	2	AYYGTEAWDI@dell.com	1922769629	5	6116385336034000	2012/06	user16660	password	29	20000	M
16661	CQCEZD	DYJWDJSGSB	6025000823 Dell Way	\N	NUDRWSG	\N	0	UK	2	DYJWDJSGSB@dell.com	6025000823	5	8918363164179028	2008/12	user16661	password	87	100000	F
16662	PYGOBK	MKGQUZWNBJ	1932512623 Dell Way	\N	HEBEXHD	\N	0	France	2	MKGQUZWNBJ@dell.com	1932512623	1	5395194484852255	2008/12	user16662	password	42	20000	M
16663	GKDIUQ	SBGNADBBMI	7314300676 Dell Way	\N	GNNDVRP	\N	0	UK	2	SBGNADBBMI@dell.com	7314300676	1	1039646158926188	2011/06	user16663	password	28	40000	M
16664	OJAJAT	KGGLJHNWQT	6519962373 Dell Way	\N	KEXFVNE	\N	0	Germany	2	KGGLJHNWQT@dell.com	6519962373	1	3013668229337782	2008/04	user16664	password	52	80000	M
16665	VTFWNQ	CUCMCPITJS	3556098487 Dell Way	\N	XHYTUDH	\N	0	France	2	CUCMCPITJS@dell.com	3556098487	3	5088476147502661	2010/12	user16665	password	32	60000	M
16666	YSRMIU	GLHIAPBKIZ	5931679664 Dell Way	\N	RHSMKAW	\N	0	Japan	2	GLHIAPBKIZ@dell.com	5931679664	2	3646739235613495	2010/07	user16666	password	73	40000	F
16667	MBYUWE	GDNGTORBOI	1041645397 Dell Way	\N	JGUUHRM	\N	0	South Africa	2	GDNGTORBOI@dell.com	1041645397	4	4421783362049610	2010/07	user16667	password	73	20000	M
16668	VZUREB	URIOGZPUHZ	9958525551 Dell Way	\N	BCTJTFF	\N	0	Russia	2	URIOGZPUHZ@dell.com	9958525551	3	3753799377940595	2010/05	user16668	password	41	60000	F
16669	HIVLJQ	DREKQUFYUG	4729752451 Dell Way	\N	ANQUTVO	\N	0	Russia	2	DREKQUFYUG@dell.com	4729752451	5	3481038125231862	2011/03	user16669	password	76	100000	M
16670	DTYMKC	EOMUJRTDYU	1284541502 Dell Way	\N	RPOKKDE	\N	0	South Africa	2	EOMUJRTDYU@dell.com	1284541502	3	6200711837504060	2009/03	user16670	password	53	80000	F
16671	GSVQUA	FHUOZNSYIJ	4645947744 Dell Way	\N	NWUXAZT	\N	0	Australia	2	FHUOZNSYIJ@dell.com	4645947744	2	3728443320374936	2011/10	user16671	password	21	20000	F
16672	TWROWW	VQLVEETMNG	3133843812 Dell Way	\N	JIEKHXM	\N	0	Japan	2	VQLVEETMNG@dell.com	3133843812	4	4094223921187222	2008/10	user16672	password	43	20000	M
16673	FUDBRY	SCUXHNKVUT	4922611514 Dell Way	\N	DYELWRD	\N	0	Canada	2	SCUXHNKVUT@dell.com	4922611514	3	2436163352802396	2009/10	user16673	password	36	100000	F
16674	AYCRXU	URRBFBXZVA	1723115126 Dell Way	\N	YAMVRPY	\N	0	Canada	2	URRBFBXZVA@dell.com	1723115126	1	4297078211326152	2012/05	user16674	password	32	100000	F
16675	DACBVW	TMYYOWYKWX	7857317982 Dell Way	\N	KJSBYRE	\N	0	Australia	2	TMYYOWYKWX@dell.com	7857317982	3	9439292013179512	2008/09	user16675	password	81	60000	M
16676	XPYSMR	ELQTHPDEMO	4107139327 Dell Way	\N	NFQLWUM	\N	0	Japan	2	ELQTHPDEMO@dell.com	4107139327	3	7752134606707842	2008/04	user16676	password	36	100000	F
16677	VYXIQC	TGVAVZEINR	1121360779 Dell Way	\N	NDDKXPA	\N	0	Chile	2	TGVAVZEINR@dell.com	1121360779	4	4214914077427238	2009/01	user16677	password	42	60000	M
16678	GKEXMY	DHYZGCHUUV	1573353445 Dell Way	\N	XXGVMHC	\N	0	Germany	2	DHYZGCHUUV@dell.com	1573353445	3	8282541171181948	2008/10	user16678	password	40	100000	F
16679	REYECC	MBBSEJNYFK	7835704490 Dell Way	\N	VLFISIV	\N	0	Russia	2	MBBSEJNYFK@dell.com	7835704490	4	9037276176735760	2010/12	user16679	password	82	60000	M
16680	BNUEQG	FRZJBMIGWD	9075432054 Dell Way	\N	SCLKLHF	\N	0	Canada	2	FRZJBMIGWD@dell.com	9075432054	1	7552404758986086	2012/12	user16680	password	41	60000	F
16681	WGFMML	ELVFYDLVGD	8850941930 Dell Way	\N	YSOJZUN	\N	0	South Africa	2	ELVFYDLVGD@dell.com	8850941930	2	7370500185061247	2012/08	user16681	password	29	100000	F
16682	KCYWOC	IJHGMTBTWZ	2314556082 Dell Way	\N	MLJLFWI	\N	0	Australia	2	IJHGMTBTWZ@dell.com	2314556082	1	9464356845710428	2011/03	user16682	password	79	20000	M
16683	YCLNFU	WMAJFCCCCP	4483356525 Dell Way	\N	NLATIJV	\N	0	France	2	WMAJFCCCCP@dell.com	4483356525	4	2914687638171017	2010/08	user16683	password	47	20000	M
16684	NQBSKY	EKHKNKMQZA	4073038434 Dell Way	\N	BATKJOW	\N	0	Russia	2	EKHKNKMQZA@dell.com	4073038434	1	3965560982469469	2012/06	user16684	password	53	60000	F
16685	COSNNX	YUHLFTBEUD	5813405918 Dell Way	\N	FNOOCLH	\N	0	France	2	YUHLFTBEUD@dell.com	5813405918	4	4405151667073369	2008/02	user16685	password	82	20000	F
16686	LTTYQR	TYDYRFDLII	8520130265 Dell Way	\N	ZXXBIFM	\N	0	South Africa	2	TYDYRFDLII@dell.com	8520130265	5	9078977796249092	2012/10	user16686	password	85	40000	F
16687	RYEIQY	GTWYYAKGJJ	8122201784 Dell Way	\N	EGLMLXJ	\N	0	Chile	2	GTWYYAKGJJ@dell.com	8122201784	2	3158538927324116	2010/03	user16687	password	50	80000	M
16688	KYEAWL	TTJRTTYCCC	3130635064 Dell Way	\N	INPULZB	\N	0	Chile	2	TTJRTTYCCC@dell.com	3130635064	2	8169960321858526	2010/09	user16688	password	58	40000	F
16689	MMDJXX	CHOWANYDPH	4914245708 Dell Way	\N	RFCDEDJ	\N	0	France	2	CHOWANYDPH@dell.com	4914245708	1	8723177179694177	2008/09	user16689	password	29	40000	F
16690	RLPOJR	WXNWKMAATR	4161387587 Dell Way	\N	GWULZEW	\N	0	France	2	WXNWKMAATR@dell.com	4161387587	4	6393519645556808	2008/11	user16690	password	84	40000	M
16691	JWDSOZ	QBVBOWCINJ	4364647163 Dell Way	\N	EIUDNQO	\N	0	South Africa	2	QBVBOWCINJ@dell.com	4364647163	1	9547844947315752	2009/02	user16691	password	36	80000	F
16692	DXESWV	USXIPZQCJU	7177269975 Dell Way	\N	LDYZUNV	\N	0	Canada	2	USXIPZQCJU@dell.com	7177269975	4	4808049359358847	2011/01	user16692	password	34	40000	F
16693	DKWAGQ	TDYIDPLMJW	5070644926 Dell Way	\N	QIVLVRP	\N	0	Germany	2	TDYIDPLMJW@dell.com	5070644926	1	3711518271360546	2010/03	user16693	password	56	80000	F
16694	YNKFED	JDMMSXZCUQ	7008717714 Dell Way	\N	LQBHHQV	\N	0	Russia	2	JDMMSXZCUQ@dell.com	7008717714	1	3097075818572193	2012/08	user16694	password	83	40000	M
16695	LRUPVD	THQMEQPZHB	3363952748 Dell Way	\N	PIIWZDQ	\N	0	Japan	2	THQMEQPZHB@dell.com	3363952748	5	6123707422986627	2012/10	user16695	password	79	60000	F
16696	NIUIMO	QCBVTQUBRJ	7362842004 Dell Way	\N	KAGJDWB	\N	0	France	2	QCBVTQUBRJ@dell.com	7362842004	4	3952374379616231	2010/06	user16696	password	79	80000	M
16697	DLIQAY	TBUMRONJXX	9761706222 Dell Way	\N	JDHNZJY	\N	0	Japan	2	TBUMRONJXX@dell.com	9761706222	2	2375032636802643	2010/02	user16697	password	76	60000	F
16698	GTWGSP	HMCZAQIYOS	5036561660 Dell Way	\N	BWGBFET	\N	0	Chile	2	HMCZAQIYOS@dell.com	5036561660	5	6764615475200117	2010/09	user16698	password	23	100000	M
16699	VSFOIM	BKMCBUAQNC	8426730919 Dell Way	\N	MTESYXX	\N	0	China	2	BKMCBUAQNC@dell.com	8426730919	3	9463985988404604	2010/08	user16699	password	73	60000	F
16700	MRAUEC	FQEGLFXYIJ	6295557958 Dell Way	\N	SMCQKAA	\N	0	Chile	2	FQEGLFXYIJ@dell.com	6295557958	5	7780937638133765	2009/09	user16700	password	34	80000	F
16701	XSYBVE	SZKDFIBNRT	4274716580 Dell Way	\N	AUKKVKQ	\N	0	France	2	SZKDFIBNRT@dell.com	4274716580	2	6669749585445971	2008/08	user16701	password	41	40000	M
16702	BFPWKH	WUKCDMPUGQ	1350670644 Dell Way	\N	PQAKBRV	\N	0	France	2	WUKCDMPUGQ@dell.com	1350670644	3	5379342181142420	2011/10	user16702	password	72	20000	M
16703	ZUSJBO	EMQHYGCEWR	4345777311 Dell Way	\N	UXCWOXG	\N	0	Germany	2	EMQHYGCEWR@dell.com	4345777311	4	3290559434331954	2008/06	user16703	password	49	100000	F
16704	FRVGGZ	SXGREJVBAQ	5370085915 Dell Way	\N	YDMNBTD	\N	0	France	2	SXGREJVBAQ@dell.com	5370085915	2	6102653997484595	2012/10	user16704	password	57	60000	F
16705	GGGMGZ	KNQOWMQWCO	6271426132 Dell Way	\N	APCBIFM	\N	0	South Africa	2	KNQOWMQWCO@dell.com	6271426132	1	8221021719276906	2009/08	user16705	password	35	40000	M
16706	MRHTQS	GHGCTWZWLZ	5881486518 Dell Way	\N	MOAUTNQ	\N	0	China	2	GHGCTWZWLZ@dell.com	5881486518	3	7685568130109460	2008/09	user16706	password	28	100000	F
16707	UGXLYE	SFGMCFJOFV	7022851547 Dell Way	\N	CGPWTGF	\N	0	Chile	2	SFGMCFJOFV@dell.com	7022851547	5	4753168722614646	2009/02	user16707	password	44	60000	M
16708	PKIOOB	TVOVBXJGSM	5700567782 Dell Way	\N	NIIGOON	\N	0	Chile	2	TVOVBXJGSM@dell.com	5700567782	5	6081788557115943	2011/04	user16708	password	23	60000	M
16709	MWMBYF	XMBYJLFCXS	5096684805 Dell Way	\N	KGYYVME	\N	0	China	2	XMBYJLFCXS@dell.com	5096684805	4	9700198870152236	2011/10	user16709	password	53	80000	F
16710	JEKHJH	ULGEWMGUEQ	5866626649 Dell Way	\N	ADPWQUF	\N	0	Australia	2	ULGEWMGUEQ@dell.com	5866626649	1	8760006784461440	2009/08	user16710	password	58	80000	F
16711	SCHCJB	NQFJCMDHDE	4857388384 Dell Way	\N	KTBBNGD	\N	0	Australia	2	NQFJCMDHDE@dell.com	4857388384	5	4877846795599908	2008/07	user16711	password	26	20000	F
16712	FKIPMW	FSFIEJPHOZ	2450397718 Dell Way	\N	AQAOWEQ	\N	0	China	2	FSFIEJPHOZ@dell.com	2450397718	1	4564405111595988	2011/03	user16712	password	54	100000	F
16713	XIYJEE	CKMGUBOIBP	8414664000 Dell Way	\N	ZCDVGUD	\N	0	France	2	CKMGUBOIBP@dell.com	8414664000	3	2062668995466083	2012/01	user16713	password	24	40000	M
16714	KIIONK	ZZRTBFCCUB	6383709499 Dell Way	\N	EYXLSBV	\N	0	Germany	2	ZZRTBFCCUB@dell.com	6383709499	5	5825194503646344	2011/01	user16714	password	84	60000	F
16715	GXATIZ	SZSUEUWZWB	3706650552 Dell Way	\N	YTNQUIF	\N	0	China	2	SZSUEUWZWB@dell.com	3706650552	4	1371264616027474	2009/08	user16715	password	64	80000	M
16716	OVPWUI	VNCAIZAEBZ	5843821711 Dell Way	\N	XOQSXVC	\N	0	Chile	2	VNCAIZAEBZ@dell.com	5843821711	1	6054833592846990	2008/10	user16716	password	44	20000	F
16717	ERFYZB	MCCUCCYEBW	8230277796 Dell Way	\N	TRORMRW	\N	0	Australia	2	MCCUCCYEBW@dell.com	8230277796	3	2820916165132075	2010/10	user16717	password	36	100000	M
16718	XCXXDJ	AFECICHKYA	9872972286 Dell Way	\N	CMROEOP	\N	0	UK	2	AFECICHKYA@dell.com	9872972286	4	5876579958014191	2011/01	user16718	password	51	80000	M
16719	OQWSAW	YEYHHGRFGT	7472400251 Dell Way	\N	SYIWMXV	\N	0	France	2	YEYHHGRFGT@dell.com	7472400251	2	3242515262216329	2011/11	user16719	password	89	80000	F
16720	QODRKB	WJIDPAJWUC	2841862025 Dell Way	\N	UCZHAVT	\N	0	Russia	2	WJIDPAJWUC@dell.com	2841862025	5	5541384691372514	2008/12	user16720	password	34	60000	M
16721	UOHFQD	OZHEZQATTU	8445116070 Dell Way	\N	WSCWOVQ	\N	0	Russia	2	OZHEZQATTU@dell.com	8445116070	1	8123811691999436	2012/05	user16721	password	35	60000	F
16722	USIKVX	JCBJTBDNWZ	6518590377 Dell Way	\N	GYWUUMN	\N	0	Japan	2	JCBJTBDNWZ@dell.com	6518590377	2	4732871466316283	2012/07	user16722	password	79	20000	F
16723	OKTJHD	MJNGKQTHQZ	6532868919 Dell Way	\N	GNUAAHQ	\N	0	Japan	2	MJNGKQTHQZ@dell.com	6532868919	1	6200696854852141	2008/11	user16723	password	66	60000	F
16724	CHUJLH	TYODPHLGHR	4250416592 Dell Way	\N	TBSTJIK	\N	0	UK	2	TYODPHLGHR@dell.com	4250416592	5	2365478738211095	2009/08	user16724	password	66	80000	M
16725	YLCJTV	IHZXPKDXCX	1172545122 Dell Way	\N	YURIDBI	\N	0	France	2	IHZXPKDXCX@dell.com	1172545122	3	7460762197151781	2011/02	user16725	password	45	40000	F
16726	VLLOGT	VGRKRVITSH	4489715430 Dell Way	\N	OKPRLXD	\N	0	France	2	VGRKRVITSH@dell.com	4489715430	5	1985107419081032	2010/03	user16726	password	51	60000	F
16727	XAQEUL	KLWBGEVZLJ	1480421730 Dell Way	\N	JBAUZEG	\N	0	China	2	KLWBGEVZLJ@dell.com	1480421730	2	8954479942563922	2009/11	user16727	password	52	40000	M
16728	NZXHKI	THJAMEZYOI	8000664380 Dell Way	\N	ZPDZUKI	\N	0	South Africa	2	THJAMEZYOI@dell.com	8000664380	2	2078871340025216	2011/09	user16728	password	52	40000	F
16729	LGNWOG	EYGQDGOROO	1401825072 Dell Way	\N	HSNBCVW	\N	0	South Africa	2	EYGQDGOROO@dell.com	1401825072	5	5539833368733526	2011/06	user16729	password	80	100000	M
16730	DLUSRY	QYOUEDMTRT	7148481641 Dell Way	\N	LEUOARL	\N	0	Australia	2	QYOUEDMTRT@dell.com	7148481641	5	8227591769304127	2008/10	user16730	password	71	20000	M
16731	EVQWUH	UICZMOSEIE	2247713832 Dell Way	\N	IDSJUEL	\N	0	France	2	UICZMOSEIE@dell.com	2247713832	2	6773617111146451	2012/12	user16731	password	69	100000	F
16732	OOAIVU	RXUDMMIURR	7445930457 Dell Way	\N	XKASOME	\N	0	Russia	2	RXUDMMIURR@dell.com	7445930457	5	6986507879570127	2011/07	user16732	password	59	100000	F
16733	CWLYRC	VLGHYOCPFZ	7178676584 Dell Way	\N	ZGROSWG	\N	0	France	2	VLGHYOCPFZ@dell.com	7178676584	5	2149411010555923	2009/06	user16733	password	89	40000	M
16734	VTNNVJ	YCRXRTMWSM	3170760291 Dell Way	\N	DKBVGIG	\N	0	UK	2	YCRXRTMWSM@dell.com	3170760291	2	2472489469218999	2011/05	user16734	password	52	40000	F
16735	FWSBFR	DXOVQBRJOU	3501871064 Dell Way	\N	TPQAXXY	\N	0	Canada	2	DXOVQBRJOU@dell.com	3501871064	1	8791355215478689	2011/08	user16735	password	32	100000	M
16736	BOWHGA	EUVVWNEKIY	1177307435 Dell Way	\N	ZYYWVXZ	\N	0	Canada	2	EUVVWNEKIY@dell.com	1177307435	5	7779544590972365	2011/01	user16736	password	62	60000	F
16737	EHKKIP	FDKCQPMYNM	2779479925 Dell Way	\N	XMISJIV	\N	0	China	2	FDKCQPMYNM@dell.com	2779479925	3	1104422235861420	2009/03	user16737	password	49	40000	F
16738	SUUAJZ	ETBVJOTWAQ	8084963268 Dell Way	\N	IJJSRFD	\N	0	South Africa	2	ETBVJOTWAQ@dell.com	8084963268	1	2269141409546137	2012/07	user16738	password	56	40000	F
16739	ICIRCM	LEHUSBRTSA	9821422023 Dell Way	\N	CCSUHWR	\N	0	Australia	2	LEHUSBRTSA@dell.com	9821422023	4	1548357135150581	2010/04	user16739	password	47	100000	M
16740	NEHQRT	UZONAFHTFJ	6350571934 Dell Way	\N	WYDDUUG	\N	0	Russia	2	UZONAFHTFJ@dell.com	6350571934	2	3791197862476111	2012/09	user16740	password	29	60000	F
16741	IWVZPQ	YDDZIKTOUP	3565837952 Dell Way	\N	MXTGSZA	\N	0	China	2	YDDZIKTOUP@dell.com	3565837952	2	3051519747357815	2012/06	user16741	password	74	20000	M
16742	QAUFQT	JUTSFNHZCT	4582562069 Dell Way	\N	XWAQWBY	\N	0	Canada	2	JUTSFNHZCT@dell.com	4582562069	1	2095939145423472	2012/12	user16742	password	40	80000	M
16743	INUZGE	TAWYNDYQXV	6025284970 Dell Way	\N	MYLJZKM	\N	0	China	2	TAWYNDYQXV@dell.com	6025284970	4	3535388124641031	2010/12	user16743	password	90	20000	F
16744	MWFTAZ	TXXHBWXYRK	9045063538 Dell Way	\N	XDUXOHH	\N	0	Canada	2	TXXHBWXYRK@dell.com	9045063538	3	6390842796768994	2012/07	user16744	password	65	20000	F
16745	NHUNGO	KEVMATKSEI	1367960528 Dell Way	\N	WZFKGMN	\N	0	Canada	2	KEVMATKSEI@dell.com	1367960528	1	9585873105563224	2010/10	user16745	password	20	80000	F
16746	IKUPZF	UVRUPCNUKK	5202832996 Dell Way	\N	TQVZCIC	\N	0	Canada	2	UVRUPCNUKK@dell.com	5202832996	1	7583068916574121	2009/02	user16746	password	43	60000	F
16747	UIATOU	OGPDIDXTNQ	7900534349 Dell Way	\N	JIPMRSQ	\N	0	Canada	2	OGPDIDXTNQ@dell.com	7900534349	2	4609706435818225	2012/09	user16747	password	85	40000	F
16748	GHFVBU	BQYJTVDHMN	9774953322 Dell Way	\N	QCZIVQM	\N	0	Germany	2	BQYJTVDHMN@dell.com	9774953322	5	4911375841591507	2011/10	user16748	password	69	20000	F
16749	ZKWAEY	RCILYLSLZJ	1157430778 Dell Way	\N	NYRJPDY	\N	0	Germany	2	RCILYLSLZJ@dell.com	1157430778	2	3160279098432511	2012/01	user16749	password	47	100000	F
16750	UUCZST	CAFAMYMLHA	6973129955 Dell Way	\N	KYJZCHN	\N	0	Canada	2	CAFAMYMLHA@dell.com	6973129955	4	9393059195484968	2011/03	user16750	password	78	80000	M
16751	PWYHQB	IVCUTOGAOQ	9057805548 Dell Way	\N	ZXPBFDE	\N	0	South Africa	2	IVCUTOGAOQ@dell.com	9057805548	1	6471267333719880	2008/12	user16751	password	46	20000	M
16752	GAVWBD	RDYLRELGUL	7875211656 Dell Way	\N	EKMJNRG	\N	0	France	2	RDYLRELGUL@dell.com	7875211656	5	5528301672078670	2011/03	user16752	password	58	40000	F
16753	OBJQFB	TDMLIYRDJV	3534707501 Dell Way	\N	OWFCNLN	\N	0	Chile	2	TDMLIYRDJV@dell.com	3534707501	1	9693685791920872	2010/07	user16753	password	31	20000	F
16754	GJTLLN	PXYXWQBFLP	2952345429 Dell Way	\N	BQRPCFW	\N	0	China	2	PXYXWQBFLP@dell.com	2952345429	5	8972348156850786	2011/01	user16754	password	83	100000	F
16755	GRRREG	PDELTGREVT	9931424573 Dell Way	\N	VNIYSEH	\N	0	UK	2	PDELTGREVT@dell.com	9931424573	1	7570193106308580	2012/01	user16755	password	65	40000	F
16756	IXAMEQ	QJBJPTOLMK	8076907106 Dell Way	\N	YUIRZPQ	\N	0	UK	2	QJBJPTOLMK@dell.com	8076907106	2	9706089948303998	2012/01	user16756	password	32	20000	F
16757	CFVHVL	QXUFRIQDSP	3358894412 Dell Way	\N	YBHXQXX	\N	0	France	2	QXUFRIQDSP@dell.com	3358894412	5	3645821584854275	2009/01	user16757	password	53	60000	F
16758	SKLOWC	LRHCAYGTOF	8836717270 Dell Way	\N	UVDLTAW	\N	0	Australia	2	LRHCAYGTOF@dell.com	8836717270	1	3546241033822298	2012/08	user16758	password	82	20000	F
16759	HOXEQJ	VYMVXSPMXJ	8563279787 Dell Way	\N	HAVBARC	\N	0	UK	2	VYMVXSPMXJ@dell.com	8563279787	2	8560905512422324	2010/03	user16759	password	87	100000	M
16760	NTSDCN	CPJZHZLFJT	3412444120 Dell Way	\N	GEVHVXE	\N	0	Japan	2	CPJZHZLFJT@dell.com	3412444120	1	2499509544111788	2010/12	user16760	password	19	20000	F
16761	UTQXHS	MRSUQEZZYF	7343396827 Dell Way	\N	DTNZRRQ	\N	0	UK	2	MRSUQEZZYF@dell.com	7343396827	5	4998566594440490	2011/10	user16761	password	53	20000	M
16762	GTMNMY	EESUJSUHYX	4023334519 Dell Way	\N	BLWSDNR	\N	0	South Africa	2	EESUJSUHYX@dell.com	4023334519	1	5484828386455775	2008/08	user16762	password	64	80000	M
16763	KGIXFN	CYILQCSPAU	3603542942 Dell Way	\N	AXNDLEZ	\N	0	Russia	2	CYILQCSPAU@dell.com	3603542942	3	9314252282027156	2012/02	user16763	password	68	80000	M
16764	YBKDOM	BXXSZQHZLH	8845296131 Dell Way	\N	XYLIDKC	\N	0	France	2	BXXSZQHZLH@dell.com	8845296131	1	3731756024528295	2012/09	user16764	password	19	60000	M
16765	BXTQJV	NHNNYVNJDK	8478739345 Dell Way	\N	IOTLZVW	\N	0	South Africa	2	NHNNYVNJDK@dell.com	8478739345	1	8451943989843131	2010/03	user16765	password	41	20000	F
16766	FXXPTL	XGYVCMFFWN	1006053494 Dell Way	\N	UQZTLVP	\N	0	Chile	2	XGYVCMFFWN@dell.com	1006053494	3	8146148717962206	2008/10	user16766	password	86	60000	M
16767	WJOPUL	WTHYFMDCZY	7578049711 Dell Way	\N	SYRDUHK	\N	0	Russia	2	WTHYFMDCZY@dell.com	7578049711	2	9758263838011772	2010/02	user16767	password	48	60000	F
16768	UAPOML	ITKNFOPFMI	1552865999 Dell Way	\N	EELYMWT	\N	0	Chile	2	ITKNFOPFMI@dell.com	1552865999	4	7204417589120568	2009/02	user16768	password	28	40000	M
16769	EVMRGU	KRIQFYWSGA	4684146880 Dell Way	\N	WSZJOSO	\N	0	Japan	2	KRIQFYWSGA@dell.com	4684146880	2	8409923254512251	2010/05	user16769	password	20	60000	M
16770	WYFCTQ	UBHZADSGDP	7598491710 Dell Way	\N	YCYMUMC	\N	0	Chile	2	UBHZADSGDP@dell.com	7598491710	5	7796123509295286	2008/12	user16770	password	33	80000	M
16771	DXYXOS	ZVSZYKFCZD	7079070380 Dell Way	\N	EXQZKTF	\N	0	Canada	2	ZVSZYKFCZD@dell.com	7079070380	5	3414292896166444	2011/02	user16771	password	88	60000	F
16772	XJFLCE	GUDFEJHEMM	6560382219 Dell Way	\N	CDLMWRQ	\N	0	Germany	2	GUDFEJHEMM@dell.com	6560382219	5	2784365120343864	2011/11	user16772	password	65	20000	M
16773	AIFDMM	XQRCZZGMLJ	4604914434 Dell Way	\N	PXWMOMA	\N	0	Canada	2	XQRCZZGMLJ@dell.com	4604914434	2	9666328760329636	2009/11	user16773	password	22	20000	M
16774	JGBWSY	MJALIHXUQN	3468277021 Dell Way	\N	RMAGZAK	\N	0	China	2	MJALIHXUQN@dell.com	3468277021	2	6940938828978688	2008/06	user16774	password	68	20000	M
16775	YDRQBE	ACQIKODABU	8552545113 Dell Way	\N	NBANCLX	\N	0	China	2	ACQIKODABU@dell.com	8552545113	3	5881548217963428	2009/04	user16775	password	63	20000	F
16776	TUUVYU	XPDIDGIFBW	8594768606 Dell Way	\N	GCKJOHT	\N	0	France	2	XPDIDGIFBW@dell.com	8594768606	2	7171986241359264	2008/12	user16776	password	75	40000	M
16777	PCMOXK	DASGHBLJYS	2197140438 Dell Way	\N	MICAPVL	\N	0	France	2	DASGHBLJYS@dell.com	2197140438	1	5978962298482657	2008/11	user16777	password	78	80000	M
16778	XFBUQE	VJLDLXNJQZ	6320620276 Dell Way	\N	SSAIOMT	\N	0	Japan	2	VJLDLXNJQZ@dell.com	6320620276	2	7696568837389351	2010/02	user16778	password	52	20000	F
16779	RBWIFS	RRWCOJMEJE	5944003429 Dell Way	\N	XJMMWGE	\N	0	France	2	RRWCOJMEJE@dell.com	5944003429	5	9550751724280418	2011/05	user16779	password	87	80000	F
16780	AQJGIB	XEDMNPRXTO	1886331698 Dell Way	\N	HGADMFO	\N	0	Australia	2	XEDMNPRXTO@dell.com	1886331698	3	7391371501144022	2010/06	user16780	password	52	60000	F
16781	CXSKYQ	OCCCRTZLIG	5112461281 Dell Way	\N	RJJDOYE	\N	0	Japan	2	OCCCRTZLIG@dell.com	5112461281	5	2262762684840709	2012/05	user16781	password	66	60000	F
16782	ODVNTK	PWNHQNTZTL	6562248810 Dell Way	\N	JDPYCTP	\N	0	Germany	2	PWNHQNTZTL@dell.com	6562248810	4	5292163016274572	2012/05	user16782	password	82	40000	M
16783	AFMUQB	QDIHRCGKNQ	8879182724 Dell Way	\N	OCORVDF	\N	0	France	2	QDIHRCGKNQ@dell.com	8879182724	4	4637755900621414	2009/07	user16783	password	75	40000	M
16784	ASJQUA	UDILFPWSFL	1093238019 Dell Way	\N	UTCQWIB	\N	0	Russia	2	UDILFPWSFL@dell.com	1093238019	3	1324490595608949	2010/04	user16784	password	38	20000	F
16785	ZOYUPS	XXECMBVSNP	7855835483 Dell Way	\N	LQFIYHC	\N	0	UK	2	XXECMBVSNP@dell.com	7855835483	1	5903897728770972	2008/05	user16785	password	71	40000	F
16786	HGEWYB	UDEHFZZSPL	9831250269 Dell Way	\N	JVUHDWG	\N	0	South Africa	2	UDEHFZZSPL@dell.com	9831250269	5	9210961242672056	2009/07	user16786	password	33	80000	M
16787	LYSKAN	OFUTFUMUGW	3033570366 Dell Way	\N	QAETWKR	\N	0	South Africa	2	OFUTFUMUGW@dell.com	3033570366	3	3156679632607847	2011/10	user16787	password	19	60000	F
16788	ZHQAUE	FPYKKLFQHW	8705868708 Dell Way	\N	QLQNWHJ	\N	0	Canada	2	FPYKKLFQHW@dell.com	8705868708	4	8754845497664065	2011/08	user16788	password	50	100000	M
16789	TMQNRW	DQGNCMDKJU	4014011261 Dell Way	\N	WZISHSV	\N	0	Canada	2	DQGNCMDKJU@dell.com	4014011261	4	7887965799309314	2012/02	user16789	password	64	80000	M
16790	DGKVCN	LJAOVEYEZU	1171425862 Dell Way	\N	EINLAIO	\N	0	China	2	LJAOVEYEZU@dell.com	1171425862	2	4026848318520933	2008/12	user16790	password	86	20000	F
16791	EKXGYJ	PYXLDVQCQU	2316249268 Dell Way	\N	KDGLMVU	\N	0	France	2	PYXLDVQCQU@dell.com	2316249268	1	6697079845238478	2008/01	user16791	password	65	40000	F
16792	BDNZMC	YKOBFEEWZP	9955986626 Dell Way	\N	ZFBLAWY	\N	0	Canada	2	YKOBFEEWZP@dell.com	9955986626	3	3477194603532553	2008/03	user16792	password	53	40000	F
16793	PVGCYF	MMHSQMOPBN	5076995882 Dell Way	\N	UDZVZXZ	\N	0	UK	2	MMHSQMOPBN@dell.com	5076995882	2	1482822252903133	2011/09	user16793	password	45	100000	F
16794	FFKDKW	PROFDDUFQP	6748091303 Dell Way	\N	IPKINKH	\N	0	UK	2	PROFDDUFQP@dell.com	6748091303	2	6570901428349317	2009/09	user16794	password	58	80000	M
16795	TDBDAQ	VOVYSQEIGM	5392398474 Dell Way	\N	YQVLBDK	\N	0	Japan	2	VOVYSQEIGM@dell.com	5392398474	1	1464878102764487	2009/07	user16795	password	73	20000	F
16796	WFMWVH	LRFDIJMOWL	3774292804 Dell Way	\N	FRWGVHY	\N	0	China	2	LRFDIJMOWL@dell.com	3774292804	5	5724061402026564	2012/10	user16796	password	67	40000	M
16797	XRNSYZ	KEDTNQHKBN	7529533814 Dell Way	\N	CYUXFTF	\N	0	Germany	2	KEDTNQHKBN@dell.com	7529533814	4	4682069417554885	2010/05	user16797	password	62	20000	F
16798	HQAFPL	KTEYJMIKZK	3296939252 Dell Way	\N	IUIONNB	\N	0	Chile	2	KTEYJMIKZK@dell.com	3296939252	3	7504282086156309	2011/02	user16798	password	78	100000	F
16799	LZPBKZ	UOYDAGOARX	9964868690 Dell Way	\N	VZLINNP	\N	0	Russia	2	UOYDAGOARX@dell.com	9964868690	2	4884369588457048	2008/02	user16799	password	46	60000	M
16800	JCRUCL	IAPJGEKYBF	5033318828 Dell Way	\N	XMOLZDF	\N	0	UK	2	IAPJGEKYBF@dell.com	5033318828	4	1749651775229722	2010/01	user16800	password	59	20000	F
16801	RWETHN	TXWABHYCNW	2135026730 Dell Way	\N	PBHPFMO	\N	0	Japan	2	TXWABHYCNW@dell.com	2135026730	4	3168736451305449	2008/03	user16801	password	49	60000	M
16802	HRQPEJ	MBKOJJRWGG	1694827062 Dell Way	\N	XOWDBKU	\N	0	Canada	2	MBKOJJRWGG@dell.com	1694827062	1	3782399437390268	2009/06	user16802	password	79	20000	M
16803	NUHSEU	UPIDYAZEHX	8264079660 Dell Way	\N	SDATOUY	\N	0	Japan	2	UPIDYAZEHX@dell.com	8264079660	2	9385012610349804	2009/01	user16803	password	25	100000	M
16804	XGIBAD	QJGPKGURDN	4867904823 Dell Way	\N	VEGJYFA	\N	0	Russia	2	QJGPKGURDN@dell.com	4867904823	5	1099690777249634	2010/01	user16804	password	88	20000	M
16805	FLAGOQ	QVGABASFNN	8689380478 Dell Way	\N	KUXIZXC	\N	0	France	2	QVGABASFNN@dell.com	8689380478	1	9303857481572778	2012/02	user16805	password	20	100000	F
16806	MVOBMF	XTGZTYEHMO	2175687405 Dell Way	\N	CKXBHAM	\N	0	Canada	2	XTGZTYEHMO@dell.com	2175687405	3	1453407153952866	2009/06	user16806	password	82	60000	M
16807	SCZFIW	YOVSNAZZPB	1201142722 Dell Way	\N	JNDRNQV	\N	0	Japan	2	YOVSNAZZPB@dell.com	1201142722	5	8836560709401966	2010/10	user16807	password	47	40000	F
16808	NJSVGQ	JCJXDIXSKH	7116454527 Dell Way	\N	FOYTEUK	\N	0	Canada	2	JCJXDIXSKH@dell.com	7116454527	2	6910295651294292	2010/09	user16808	password	21	100000	F
16809	LQZRHJ	UQHXZEQKLW	3462602200 Dell Way	\N	YKPDFAI	\N	0	South Africa	2	UQHXZEQKLW@dell.com	3462602200	5	3966864334885031	2012/01	user16809	password	37	20000	F
16810	XDDFNY	VUWVYMGKIE	6248331818 Dell Way	\N	UYHZYPW	\N	0	Chile	2	VUWVYMGKIE@dell.com	6248331818	2	2451752330642193	2011/06	user16810	password	38	20000	F
16811	KFPXDL	RZHQLNAURV	9273742103 Dell Way	\N	TZVRPSX	\N	0	Canada	2	RZHQLNAURV@dell.com	9273742103	1	8132933071814478	2009/05	user16811	password	79	80000	M
16812	BKREVJ	ECZQQAKHWD	7929279034 Dell Way	\N	HRVXKSC	\N	0	China	2	ECZQQAKHWD@dell.com	7929279034	5	7338974439073355	2008/09	user16812	password	54	100000	M
16813	XNZSWD	VWTLWETSIB	9551711929 Dell Way	\N	KEZUXBB	\N	0	Japan	2	VWTLWETSIB@dell.com	9551711929	4	7854070832952858	2011/04	user16813	password	62	60000	F
16814	DLXZPS	VJESNYKWAU	4800248632 Dell Way	\N	AZOXAQP	\N	0	UK	2	VJESNYKWAU@dell.com	4800248632	2	7075149330310524	2011/12	user16814	password	28	100000	F
16815	PTBEMX	NRPBQAYQUZ	8269313023 Dell Way	\N	PJXQAMQ	\N	0	France	2	NRPBQAYQUZ@dell.com	8269313023	2	2126546741928905	2011/06	user16815	password	90	100000	F
16816	TXFGUT	YKVOKTEFSU	4343818888 Dell Way	\N	OPLOBBZ	\N	0	South Africa	2	YKVOKTEFSU@dell.com	4343818888	1	6760780507232994	2012/02	user16816	password	53	100000	M
16817	KCCEWA	PRPZKTEDOS	4352571808 Dell Way	\N	SZHUBGR	\N	0	France	2	PRPZKTEDOS@dell.com	4352571808	2	3148331470787525	2010/10	user16817	password	26	40000	F
16818	FLJCMY	TBYEUDHJWA	8432855475 Dell Way	\N	IDVJKNU	\N	0	Russia	2	TBYEUDHJWA@dell.com	8432855475	1	3203395905904472	2011/02	user16818	password	59	100000	F
16819	AELMDE	NCJIFRRBRZ	2155547087 Dell Way	\N	ENJOADJ	\N	0	South Africa	2	NCJIFRRBRZ@dell.com	2155547087	3	5198851345106960	2009/02	user16819	password	38	80000	F
16820	LBQPFE	RPMWGDXYDC	6403750956 Dell Way	\N	LMRLPAH	\N	0	Russia	2	RPMWGDXYDC@dell.com	6403750956	4	9768006953876468	2011/01	user16820	password	60	100000	F
16821	QPCWTU	LFQRJOPMQA	5792846987 Dell Way	\N	YHMOIUG	\N	0	UK	2	LFQRJOPMQA@dell.com	5792846987	2	7123725418001414	2010/10	user16821	password	63	20000	F
16822	FDHYXS	EOKNDAATBZ	1296718894 Dell Way	\N	BNNJIUH	\N	0	South Africa	2	EOKNDAATBZ@dell.com	1296718894	5	4680895561352372	2012/08	user16822	password	52	40000	M
16823	QPTNIX	CSLFTLZULB	7277666294 Dell Way	\N	IYLQTSM	\N	0	Russia	2	CSLFTLZULB@dell.com	7277666294	5	6637023680843414	2009/05	user16823	password	85	20000	M
16824	NVNVTP	OEVHQUBBVK	4319505045 Dell Way	\N	ZGATZMN	\N	0	Japan	2	OEVHQUBBVK@dell.com	4319505045	1	9811289593111724	2011/01	user16824	password	22	80000	M
16825	XEKQUY	VPGLKIMGSM	8574933821 Dell Way	\N	NTFNFSE	\N	0	Germany	2	VPGLKIMGSM@dell.com	8574933821	1	3765238697640598	2012/03	user16825	password	90	60000	F
16826	EWUYVP	OBAZKNFCZT	6367304933 Dell Way	\N	WFGBXLR	\N	0	Russia	2	OBAZKNFCZT@dell.com	6367304933	5	6807379245292396	2012/12	user16826	password	26	100000	F
16827	ZTCUIR	WJQHWWKWPG	9445315596 Dell Way	\N	BVIYGZS	\N	0	South Africa	2	WJQHWWKWPG@dell.com	9445315596	2	7078141221310944	2012/06	user16827	password	65	20000	F
16828	KDGSUC	CKKYGUUVAW	8750958431 Dell Way	\N	QIUXHNT	\N	0	Chile	2	CKKYGUUVAW@dell.com	8750958431	3	2217773959506303	2009/01	user16828	password	29	80000	F
16829	HZEBCG	LNFSHANIWE	3074289795 Dell Way	\N	QRCYEVE	\N	0	Australia	2	LNFSHANIWE@dell.com	3074289795	2	4301527556031942	2009/06	user16829	password	27	80000	M
16830	DXUGEG	TKZAKMIHRZ	4720677968 Dell Way	\N	YTXDPCE	\N	0	South Africa	2	TKZAKMIHRZ@dell.com	4720677968	3	1952405381947755	2012/09	user16830	password	79	80000	M
16831	TLAYST	IRUTECAWCZ	8450990544 Dell Way	\N	QZCFCHA	\N	0	Germany	2	IRUTECAWCZ@dell.com	8450990544	1	4581167639698833	2010/12	user16831	password	21	40000	M
16832	MIRFBA	WWTBZUXBTO	9392161845 Dell Way	\N	BWTDDUQ	\N	0	UK	2	WWTBZUXBTO@dell.com	9392161845	1	5121366400271654	2012/02	user16832	password	72	80000	M
16833	BJUDJR	ZDTYXQAQFB	8853191448 Dell Way	\N	NYEQTVP	\N	0	Japan	2	ZDTYXQAQFB@dell.com	8853191448	1	6386831511277706	2012/10	user16833	password	36	60000	M
16834	PIZZAZ	CTYAKYRPZE	4937693894 Dell Way	\N	OEUHAKZ	\N	0	South Africa	2	CTYAKYRPZE@dell.com	4937693894	3	8574352276977152	2009/10	user16834	password	46	20000	F
16835	SCKSCN	MANWZELZIZ	8329838788 Dell Way	\N	DDHDNGA	\N	0	UK	2	MANWZELZIZ@dell.com	8329838788	5	2683302690740675	2011/04	user16835	password	38	20000	M
16836	JMSMAE	MNALRMLAMO	6640596995 Dell Way	\N	DTSRZTP	\N	0	Russia	2	MNALRMLAMO@dell.com	6640596995	4	4933793903794140	2012/01	user16836	password	55	100000	F
16837	AOYATK	NUWFHHGTWJ	4939239332 Dell Way	\N	MPALIQG	\N	0	UK	2	NUWFHHGTWJ@dell.com	4939239332	4	8657761421054603	2010/03	user16837	password	70	100000	F
16838	HXFBIT	VFZDNFWJOI	7207881025 Dell Way	\N	ZPUHGAG	\N	0	Japan	2	VFZDNFWJOI@dell.com	7207881025	1	2885106288362294	2012/11	user16838	password	31	20000	F
16839	CIELBA	QADDFZNUIM	2494392308 Dell Way	\N	KCURCBJ	\N	0	Russia	2	QADDFZNUIM@dell.com	2494392308	3	7086357162799687	2012/10	user16839	password	74	20000	M
16840	CHHDIX	EMBKLOFUBQ	2931324492 Dell Way	\N	WVHYXQT	\N	0	Australia	2	EMBKLOFUBQ@dell.com	2931324492	3	1548785454593598	2012/03	user16840	password	31	100000	F
16841	MCLVAQ	HCATRGNSWJ	5560187408 Dell Way	\N	ODILUCN	\N	0	Australia	2	HCATRGNSWJ@dell.com	5560187408	3	9853573398664596	2011/10	user16841	password	77	100000	F
16842	XKCYBJ	ABCRHQKEZY	5479164931 Dell Way	\N	IIKCKXD	\N	0	UK	2	ABCRHQKEZY@dell.com	5479164931	1	6555233865976334	2009/12	user16842	password	62	60000	M
16843	APUBZU	DCMLSWPSVX	3367667491 Dell Way	\N	AFALDEI	\N	0	Japan	2	DCMLSWPSVX@dell.com	3367667491	5	9202953528612852	2008/07	user16843	password	49	20000	M
16844	AURAPU	CCGUZVMUTM	2963668521 Dell Way	\N	AUXEYGV	\N	0	Chile	2	CCGUZVMUTM@dell.com	2963668521	4	4491839241702110	2011/02	user16844	password	47	40000	F
16845	FAFVVH	XBCWXORQBR	4618640216 Dell Way	\N	LZWJGRP	\N	0	France	2	XBCWXORQBR@dell.com	4618640216	5	3062075438443571	2010/05	user16845	password	61	80000	M
16846	QZKLHI	MJFJXWAYOL	4198911163 Dell Way	\N	YKVECKP	\N	0	France	2	MJFJXWAYOL@dell.com	4198911163	5	1503293328918516	2011/06	user16846	password	78	40000	F
16847	USMBBZ	KGJIDJHSUF	8107859442 Dell Way	\N	CQJFAYR	\N	0	China	2	KGJIDJHSUF@dell.com	8107859442	4	1820225669071078	2009/07	user16847	password	47	40000	F
16848	DTLFTW	LCEPLLHGQK	1173739694 Dell Way	\N	WZPWYHG	\N	0	Russia	2	LCEPLLHGQK@dell.com	1173739694	2	9653550138231368	2010/09	user16848	password	35	100000	M
16849	ZJBTGN	VKDHWKNMUK	8451681057 Dell Way	\N	MJGLRNE	\N	0	Japan	2	VKDHWKNMUK@dell.com	8451681057	1	3344109364319593	2010/05	user16849	password	33	60000	F
16850	PNCVAY	GDFCOTPIDB	8605904312 Dell Way	\N	SKNJXSB	\N	0	Russia	2	GDFCOTPIDB@dell.com	8605904312	2	3673924061004072	2009/07	user16850	password	71	80000	F
16851	GSYHQE	LWHZPWITYB	8201731016 Dell Way	\N	DLLBDMU	\N	0	UK	2	LWHZPWITYB@dell.com	8201731016	1	2940403300337493	2009/10	user16851	password	77	60000	F
16852	NKIEOT	BWTQSCJQDN	4920818344 Dell Way	\N	COOFBJF	\N	0	South Africa	2	BWTQSCJQDN@dell.com	4920818344	3	2560993142426014	2009/03	user16852	password	63	40000	M
16853	AQYPKZ	LEQDGATJOW	7470803163 Dell Way	\N	YDBZMHV	\N	0	UK	2	LEQDGATJOW@dell.com	7470803163	1	2527834589127451	2012/08	user16853	password	52	80000	M
16854	DSFNSR	SIUYJOIXKH	1997562252 Dell Way	\N	BMGNUCL	\N	0	France	2	SIUYJOIXKH@dell.com	1997562252	4	5137840108945966	2011/02	user16854	password	32	40000	F
16855	XPTPHL	YBKHQTFBAG	8548145787 Dell Way	\N	OHUIJFV	\N	0	France	2	YBKHQTFBAG@dell.com	8548145787	2	3073056754190475	2012/06	user16855	password	62	20000	F
16856	FXYMJX	OUEFNJGNQU	2783196226 Dell Way	\N	VKDFQYR	\N	0	France	2	OUEFNJGNQU@dell.com	2783196226	5	4538204434793443	2011/07	user16856	password	57	20000	M
16857	LAGVXU	PBZDLGRBBM	3474065504 Dell Way	\N	MERCCJO	\N	0	Chile	2	PBZDLGRBBM@dell.com	3474065504	5	9701714653521776	2012/06	user16857	password	18	60000	M
16858	AUTXPI	YPLKVDLXPX	5305863656 Dell Way	\N	BGZEQOM	\N	0	South Africa	2	YPLKVDLXPX@dell.com	5305863656	3	7244503186084331	2012/06	user16858	password	35	100000	F
16859	AQIQZH	FLRBODYDBA	1659004916 Dell Way	\N	KBEAPQX	\N	0	Australia	2	FLRBODYDBA@dell.com	1659004916	4	1275827181059867	2010/11	user16859	password	85	100000	M
16860	OHNOPS	ZGTOKSSLSC	6836182406 Dell Way	\N	MXDCOBE	\N	0	Japan	2	ZGTOKSSLSC@dell.com	6836182406	1	2182568268850446	2010/02	user16860	password	24	40000	M
16861	JXFYPF	FJTPCLBUOO	1044237178 Dell Way	\N	SRQGSVW	\N	0	China	2	FJTPCLBUOO@dell.com	1044237178	1	8867671182379127	2008/02	user16861	password	37	80000	F
16862	DALTFQ	DZGFLIAZWS	8797730034 Dell Way	\N	RNZKIWT	\N	0	China	2	DZGFLIAZWS@dell.com	8797730034	4	5033541497774422	2012/11	user16862	password	35	60000	F
16863	GWVMMY	LTDWBEWXWN	3804233402 Dell Way	\N	LWXTSRC	\N	0	Germany	2	LTDWBEWXWN@dell.com	3804233402	3	5882336963433773	2009/10	user16863	password	89	40000	F
16864	VBNIAY	BEVDIRAFFL	8399816074 Dell Way	\N	BCFUUHJ	\N	0	Australia	2	BEVDIRAFFL@dell.com	8399816074	5	3743617796339095	2010/11	user16864	password	59	80000	M
16865	QDAQBC	UXFDPFIURJ	4627172058 Dell Way	\N	XXDRFNU	\N	0	Australia	2	UXFDPFIURJ@dell.com	4627172058	1	6526878164149821	2009/08	user16865	password	35	100000	F
16866	JZYLBT	IGWXMESEOP	2037802617 Dell Way	\N	CSHHFBI	\N	0	Japan	2	IGWXMESEOP@dell.com	2037802617	5	9078036093618722	2011/02	user16866	password	81	20000	M
16867	WYYXSH	EOFRTXWHNZ	5484369917 Dell Way	\N	AUGGVOW	\N	0	UK	2	EOFRTXWHNZ@dell.com	5484369917	4	7283266810234637	2011/08	user16867	password	71	20000	F
16868	SDKKLP	YRHRPDZCDZ	8400443619 Dell Way	\N	WJFSYBQ	\N	0	France	2	YRHRPDZCDZ@dell.com	8400443619	2	1962021030019968	2010/01	user16868	password	39	100000	M
16869	LIEWXC	NEUCITFLSB	7969083725 Dell Way	\N	VYUTZLF	\N	0	South Africa	2	NEUCITFLSB@dell.com	7969083725	2	3308639274910092	2012/08	user16869	password	30	80000	F
16870	MUXKXL	ORNXKSICUD	4820947930 Dell Way	\N	AOXAZCV	\N	0	Russia	2	ORNXKSICUD@dell.com	4820947930	1	6632270420901478	2008/04	user16870	password	36	20000	M
16871	BZDYKS	PXPZQYCKBD	1632856043 Dell Way	\N	ZZDZBZT	\N	0	Germany	2	PXPZQYCKBD@dell.com	1632856043	2	5768990687094629	2009/08	user16871	password	61	20000	M
16872	OGPYZE	WOEMNGXOJW	1057429020 Dell Way	\N	ONWQMQD	\N	0	Germany	2	WOEMNGXOJW@dell.com	1057429020	4	9091744516044856	2011/03	user16872	password	90	40000	M
16873	GXTFCP	UGBHNYWWVK	8023487469 Dell Way	\N	KSAWIDL	\N	0	China	2	UGBHNYWWVK@dell.com	8023487469	2	9823890652973206	2008/05	user16873	password	39	100000	M
16874	FOUIDO	OFWBESYADI	9949305855 Dell Way	\N	SDFBHRK	\N	0	Australia	2	OFWBESYADI@dell.com	9949305855	2	1721292272210121	2009/09	user16874	password	83	100000	M
16875	LSEPHT	UDVYWUZACR	5569773547 Dell Way	\N	DITLZDM	\N	0	UK	2	UDVYWUZACR@dell.com	5569773547	3	3701117624528706	2008/06	user16875	password	33	20000	M
16876	XGMEZH	IVGFPFFSXJ	8482501064 Dell Way	\N	ARUZUGZ	\N	0	Chile	2	IVGFPFFSXJ@dell.com	8482501064	2	5268925614655018	2009/06	user16876	password	56	40000	F
16877	USOTZX	PGCELHWJQW	1895629173 Dell Way	\N	ALWVSVC	\N	0	Germany	2	PGCELHWJQW@dell.com	1895629173	3	8358521086629481	2010/02	user16877	password	19	100000	M
16878	SNQSLF	YNKJVGTMDT	3369253196 Dell Way	\N	XAOPVRD	\N	0	UK	2	YNKJVGTMDT@dell.com	3369253196	5	5594223601277918	2009/12	user16878	password	51	40000	M
16879	ZXJKDI	YNSUTLGWFE	8555050870 Dell Way	\N	XUTSMXR	\N	0	Russia	2	YNSUTLGWFE@dell.com	8555050870	1	1943890139460563	2012/08	user16879	password	44	60000	M
16880	GWBJEZ	WWTQIANOEK	9654101168 Dell Way	\N	IYDUVUN	\N	0	Japan	2	WWTQIANOEK@dell.com	9654101168	4	5258905711583793	2011/12	user16880	password	88	40000	F
16881	VHPAGM	XACFAQUEAC	1580538224 Dell Way	\N	DDXYYLQ	\N	0	South Africa	2	XACFAQUEAC@dell.com	1580538224	1	5449142312165350	2008/01	user16881	password	70	40000	M
16882	ZXXGKU	GNAHDUMEXP	3189518596 Dell Way	\N	HUNGFDD	\N	0	Chile	2	GNAHDUMEXP@dell.com	3189518596	4	4034700380638242	2009/05	user16882	password	64	20000	F
16883	OBPYVW	MWEQQQUNFC	1602857350 Dell Way	\N	ITINXLV	\N	0	Canada	2	MWEQQQUNFC@dell.com	1602857350	1	4932631145231426	2010/10	user16883	password	62	80000	F
16884	RJHNGU	JKKAAEOGGW	4002783019 Dell Way	\N	ZOJWAEA	\N	0	Australia	2	JKKAAEOGGW@dell.com	4002783019	3	5441870742943138	2008/01	user16884	password	36	60000	M
16885	QTGWOQ	GYQHDENJAM	8845879017 Dell Way	\N	YKJYPKA	\N	0	UK	2	GYQHDENJAM@dell.com	8845879017	3	1435159759130328	2012/10	user16885	password	55	80000	F
16886	HYGVON	TEUWJIGKVE	7094452329 Dell Way	\N	UFDKPEI	\N	0	France	2	TEUWJIGKVE@dell.com	7094452329	2	4829507362563163	2010/11	user16886	password	25	100000	F
16887	BCZPQT	ULQDTWOPBI	4923346716 Dell Way	\N	UFTKJBW	\N	0	Australia	2	ULQDTWOPBI@dell.com	4923346716	2	5376585486344993	2009/05	user16887	password	42	60000	F
16888	LLBCFV	NVZHSNWUWR	3244581032 Dell Way	\N	ZQBIRYJ	\N	0	Canada	2	NVZHSNWUWR@dell.com	3244581032	5	4908895192202181	2011/03	user16888	password	84	20000	M
16889	JETPAG	KZODNLXKCX	5332446803 Dell Way	\N	AEGSCQV	\N	0	China	2	KZODNLXKCX@dell.com	5332446803	2	1095110859256237	2011/02	user16889	password	27	40000	M
16890	HBCHIN	HWRVHPFKNG	1062219382 Dell Way	\N	OTYQJTA	\N	0	South Africa	2	HWRVHPFKNG@dell.com	1062219382	1	5761940408498049	2008/02	user16890	password	80	80000	F
16891	XVTGJA	DAVLQBVDHJ	1375038412 Dell Way	\N	WGAGAAC	\N	0	Australia	2	DAVLQBVDHJ@dell.com	1375038412	4	2636369938030839	2008/06	user16891	password	82	80000	F
16892	SIQBJT	CFESHZVPJR	6661261286 Dell Way	\N	VKYVLAW	\N	0	France	2	CFESHZVPJR@dell.com	6661261286	1	6907196333631874	2008/11	user16892	password	37	60000	M
16893	PDRZWT	EBLMBHBKYW	6188355114 Dell Way	\N	VXSGXOS	\N	0	Germany	2	EBLMBHBKYW@dell.com	6188355114	2	6663251774851233	2010/08	user16893	password	26	20000	F
16894	GUGDNL	EZXFGYPFVL	8184301087 Dell Way	\N	CNRZBKN	\N	0	Japan	2	EZXFGYPFVL@dell.com	8184301087	1	2135006043594330	2010/04	user16894	password	34	80000	M
16895	AZQOKU	NIZUGPZBBC	7816204420 Dell Way	\N	OSCQDPH	\N	0	UK	2	NIZUGPZBBC@dell.com	7816204420	2	4512448681984097	2008/08	user16895	password	26	60000	M
16896	CEEMZS	UZMBPLCQNR	9877048708 Dell Way	\N	JQIMFPL	\N	0	UK	2	UZMBPLCQNR@dell.com	9877048708	5	1075965955387800	2011/12	user16896	password	58	40000	F
16897	TLMSDH	SPJHBMXPDG	9895860213 Dell Way	\N	FMTLBEK	\N	0	Australia	2	SPJHBMXPDG@dell.com	9895860213	3	6948935642372817	2012/12	user16897	password	84	100000	M
16898	ILLMSD	BBKDNISROX	2312479205 Dell Way	\N	EHIFMTG	\N	0	France	2	BBKDNISROX@dell.com	2312479205	5	4432719897478819	2008/11	user16898	password	40	100000	F
16899	TGQLJS	NUVBCOTRMX	3781581665 Dell Way	\N	ZVDLOKX	\N	0	Japan	2	NUVBCOTRMX@dell.com	3781581665	2	8256934599485249	2008/08	user16899	password	63	40000	F
16900	XZUGSI	BOKECDVOBU	4789820128 Dell Way	\N	KEFYODQ	\N	0	South Africa	2	BOKECDVOBU@dell.com	4789820128	3	1116360249463468	2008/01	user16900	password	42	40000	M
16901	IDFALH	OVLRZGGAAQ	6710288869 Dell Way	\N	FGOTKFQ	\N	0	South Africa	2	OVLRZGGAAQ@dell.com	6710288869	4	8507667397614569	2011/12	user16901	password	31	80000	F
16902	IWITDX	POOPVVPWLV	8423208143 Dell Way	\N	DAONFEI	\N	0	South Africa	2	POOPVVPWLV@dell.com	8423208143	1	6013315444812179	2012/05	user16902	password	32	20000	M
16903	BKLFHA	UWQPRGLDBP	6390193559 Dell Way	\N	DPCJULG	\N	0	Japan	2	UWQPRGLDBP@dell.com	6390193559	4	4790735486429185	2012/12	user16903	password	55	80000	F
16904	YBGFCB	CSQTYCXZRB	4947173403 Dell Way	\N	PUKJFQA	\N	0	South Africa	2	CSQTYCXZRB@dell.com	4947173403	3	7781386401038618	2010/12	user16904	password	44	60000	M
16905	KTCMUE	FLYDOVCFWS	5638421552 Dell Way	\N	AHCFYCA	\N	0	China	2	FLYDOVCFWS@dell.com	5638421552	4	8298055604565889	2010/02	user16905	password	40	40000	M
16906	BLBWPG	IOJWKMCHEC	2015648945 Dell Way	\N	OHINJIX	\N	0	South Africa	2	IOJWKMCHEC@dell.com	2015648945	4	4047074047848582	2009/01	user16906	password	66	80000	F
16907	CVYSBG	GLDRYGYDJN	6506191966 Dell Way	\N	KRATAXQ	\N	0	Canada	2	GLDRYGYDJN@dell.com	6506191966	5	4398327444214374	2011/08	user16907	password	30	80000	M
16908	AQLCXS	NAJMHIPQWZ	4410573404 Dell Way	\N	HWTHUKL	\N	0	China	2	NAJMHIPQWZ@dell.com	4410573404	5	1127499182708561	2008/12	user16908	password	69	80000	F
16909	IFCFYQ	GICNQRDMRL	9891402696 Dell Way	\N	JKTEVEO	\N	0	Canada	2	GICNQRDMRL@dell.com	9891402696	3	2952490013092756	2012/04	user16909	password	90	100000	M
16910	FBVDRB	LUPCLSPDEZ	3311475153 Dell Way	\N	NXDICRN	\N	0	Australia	2	LUPCLSPDEZ@dell.com	3311475153	4	1386750605423003	2010/09	user16910	password	19	20000	M
16911	CYCUAO	OPRAIGDMGR	3568617178 Dell Way	\N	KJAMBNO	\N	0	China	2	OPRAIGDMGR@dell.com	3568617178	3	8549253849778325	2008/08	user16911	password	88	100000	M
16912	XBMXPA	NGAVNEITVS	3804772237 Dell Way	\N	DVEEJSM	\N	0	Japan	2	NGAVNEITVS@dell.com	3804772237	2	7110886203125120	2012/04	user16912	password	65	80000	F
16913	SBCHCQ	ODLBHUVCNY	9475696022 Dell Way	\N	YSDILPZ	\N	0	Russia	2	ODLBHUVCNY@dell.com	9475696022	4	6838089050725103	2009/04	user16913	password	36	60000	M
16914	INHKEV	NPXUKSXXRW	8084353392 Dell Way	\N	PUEAKDT	\N	0	China	2	NPXUKSXXRW@dell.com	8084353392	3	6136461008340121	2008/08	user16914	password	18	20000	M
16915	NJJSEX	ICSSVQPMMF	4344735361 Dell Way	\N	GQFQUZZ	\N	0	Germany	2	ICSSVQPMMF@dell.com	4344735361	3	6759879347868264	2008/07	user16915	password	69	100000	F
16916	BJUGHC	IZUDPKQBPW	1605698283 Dell Way	\N	SVNMUNA	\N	0	Canada	2	IZUDPKQBPW@dell.com	1605698283	4	2791642338968813	2011/05	user16916	password	32	80000	F
16917	ONSVPB	VKFKVVMLSE	3798031456 Dell Way	\N	HFQBSQG	\N	0	Russia	2	VKFKVVMLSE@dell.com	3798031456	3	4793351348489523	2011/08	user16917	password	28	20000	F
16918	QVBGWW	RBGMWSYPWF	9852169865 Dell Way	\N	UMHNDNI	\N	0	France	2	RBGMWSYPWF@dell.com	9852169865	4	2287543924059719	2011/11	user16918	password	37	100000	M
16919	CWUZTL	AZYXSWMPCH	9072551881 Dell Way	\N	CJVGXDR	\N	0	South Africa	2	AZYXSWMPCH@dell.com	9072551881	5	5540208287071437	2011/02	user16919	password	42	40000	F
16920	FCEYOF	YNDRJQGLYI	1843048644 Dell Way	\N	VTOSXGP	\N	0	Russia	2	YNDRJQGLYI@dell.com	1843048644	1	6197565308772028	2008/06	user16920	password	83	60000	M
16921	APPOUO	BXFLOMXMVS	2138328479 Dell Way	\N	FJLCQAX	\N	0	Russia	2	BXFLOMXMVS@dell.com	2138328479	3	9401279914658518	2010/05	user16921	password	42	40000	F
16922	XVYSKA	QQLECJQXCW	4279621720 Dell Way	\N	HNZXOWR	\N	0	Japan	2	QQLECJQXCW@dell.com	4279621720	3	3281628667376935	2011/12	user16922	password	52	20000	M
16923	HBOSCE	INIKXZHZVP	7737131431 Dell Way	\N	NVNCREU	\N	0	Australia	2	INIKXZHZVP@dell.com	7737131431	1	8194917518179864	2011/07	user16923	password	85	60000	M
16924	ZBNCFV	QOGNOONKDA	9471929132 Dell Way	\N	FQDXUXY	\N	0	Germany	2	QOGNOONKDA@dell.com	9471929132	4	2900743541773408	2010/09	user16924	password	71	40000	M
16925	UUTAPJ	PVWDJKNMLS	3762368453 Dell Way	\N	DOQXLOL	\N	0	China	2	PVWDJKNMLS@dell.com	3762368453	4	8609548185952009	2012/05	user16925	password	25	80000	F
16926	WKFMTU	IQYSALELEI	4151621873 Dell Way	\N	AUGLJRW	\N	0	Japan	2	IQYSALELEI@dell.com	4151621873	4	6829006541986019	2011/10	user16926	password	39	100000	M
16927	RCELXM	CVECHJOLRO	6122615596 Dell Way	\N	GYAQPWH	\N	0	UK	2	CVECHJOLRO@dell.com	6122615596	5	7325275810901076	2009/03	user16927	password	63	20000	M
16928	TFJQSL	LXOTGDEYRL	3625372393 Dell Way	\N	WSBMOJL	\N	0	Canada	2	LXOTGDEYRL@dell.com	3625372393	1	5625563319306821	2010/10	user16928	password	59	60000	M
16929	UUDNGP	KUIRYNQPZN	6782347931 Dell Way	\N	HAAWKMA	\N	0	Japan	2	KUIRYNQPZN@dell.com	6782347931	3	2864452176727354	2010/02	user16929	password	65	100000	M
16930	LCKSSV	NBNLOEBORI	7871406360 Dell Way	\N	PSFZEGR	\N	0	South Africa	2	NBNLOEBORI@dell.com	7871406360	5	3241319516673684	2012/07	user16930	password	32	80000	M
16931	HFRZAE	BOQQSREJAT	3412288259 Dell Way	\N	CGTGMKC	\N	0	Chile	2	BOQQSREJAT@dell.com	3412288259	2	1884537929203361	2011/07	user16931	password	81	80000	M
16932	BLVCQW	QGMIYQSYKU	5343517859 Dell Way	\N	EDBQNDW	\N	0	Russia	2	QGMIYQSYKU@dell.com	5343517859	5	6180009500589222	2008/11	user16932	password	42	100000	M
16933	UQZKMQ	RZZPPRNZMS	2663176651 Dell Way	\N	COIQSFK	\N	0	Canada	2	RZZPPRNZMS@dell.com	2663176651	5	2745572767220437	2008/04	user16933	password	19	100000	F
16934	RYNEOE	DNUSFHSSAV	8849045491 Dell Way	\N	GJLZOWD	\N	0	Russia	2	DNUSFHSSAV@dell.com	8849045491	2	7934376388788224	2009/05	user16934	password	69	40000	F
16935	QVEEAH	SUAYCSQCOX	4078567343 Dell Way	\N	LAWAXAT	\N	0	Russia	2	SUAYCSQCOX@dell.com	4078567343	3	9667432300746442	2011/03	user16935	password	38	80000	M
16936	DXADFT	YFRBYHDNEP	9302396327 Dell Way	\N	NBQKBKE	\N	0	China	2	YFRBYHDNEP@dell.com	9302396327	1	1856494897510856	2008/05	user16936	password	77	20000	M
16937	SBQYUP	DLQCTUPYKC	8056886599 Dell Way	\N	ZANAKRL	\N	0	China	2	DLQCTUPYKC@dell.com	8056886599	3	5342133978381753	2008/05	user16937	password	53	80000	F
16938	NJZIYD	TOGNJWLTYL	4778221325 Dell Way	\N	TMMEDXM	\N	0	UK	2	TOGNJWLTYL@dell.com	4778221325	5	1922736554406583	2011/06	user16938	password	76	100000	M
16939	DVICZC	QFPZBBSAMM	1802976336 Dell Way	\N	NYQQWDO	\N	0	Chile	2	QFPZBBSAMM@dell.com	1802976336	4	1371379892341792	2010/06	user16939	password	81	60000	M
16940	SWRRYI	XOIZPBACNN	4280615952 Dell Way	\N	BEDXHSE	\N	0	China	2	XOIZPBACNN@dell.com	4280615952	2	9283007765654476	2012/02	user16940	password	51	60000	M
16941	ICMGLJ	VTJKUJMIWN	8335439906 Dell Way	\N	MAKTSPD	\N	0	Australia	2	VTJKUJMIWN@dell.com	8335439906	1	9099089414346964	2012/07	user16941	password	41	80000	M
16942	LECWOX	QXILHUTDIG	2930562183 Dell Way	\N	DTAWIEY	\N	0	Canada	2	QXILHUTDIG@dell.com	2930562183	5	1540376540739089	2011/02	user16942	password	73	60000	M
16943	YSMMQC	KYNRTHVBOY	6133376794 Dell Way	\N	VOVDSTH	\N	0	UK	2	KYNRTHVBOY@dell.com	6133376794	2	6989436881151051	2011/02	user16943	password	36	40000	F
16944	YUOPXZ	NLRHTMJHLE	9971883396 Dell Way	\N	VGIOZQM	\N	0	Germany	2	NLRHTMJHLE@dell.com	9971883396	1	3483062652405351	2008/05	user16944	password	61	20000	F
16945	KTYHTL	SKTLWCTHHO	7408642626 Dell Way	\N	NPCNFOB	\N	0	Chile	2	SKTLWCTHHO@dell.com	7408642626	2	4137447644025087	2008/12	user16945	password	57	60000	F
16946	HJQBVI	LPUIRNQYCE	1699006044 Dell Way	\N	OFRTUTZ	\N	0	France	2	LPUIRNQYCE@dell.com	1699006044	2	6325714705046267	2008/11	user16946	password	20	40000	F
16947	KZGGIR	VCANQQLTUZ	1826027622 Dell Way	\N	YMTSFTF	\N	0	Chile	2	VCANQQLTUZ@dell.com	1826027622	5	3702626958023757	2012/11	user16947	password	65	20000	F
16948	PKNYCI	BCVRTHLNGJ	2014526009 Dell Way	\N	AACFUHM	\N	0	South Africa	2	BCVRTHLNGJ@dell.com	2014526009	4	8612904350273312	2012/06	user16948	password	18	40000	F
16949	KSZNBA	QWSJDDXKNX	4831740439 Dell Way	\N	LPDFXQC	\N	0	Australia	2	QWSJDDXKNX@dell.com	4831740439	5	9845850895624608	2012/12	user16949	password	32	100000	F
16950	XXXYYN	VQXZUUKHSV	1753567871 Dell Way	\N	XWBVMDW	\N	0	UK	2	VQXZUUKHSV@dell.com	1753567871	5	7957712889648975	2008/01	user16950	password	69	60000	M
16951	QHXOVS	FSSANCHFXF	7575793219 Dell Way	\N	BZBODXL	\N	0	Chile	2	FSSANCHFXF@dell.com	7575793219	2	3125811849255115	2011/12	user16951	password	64	80000	M
16952	YPCTII	LAIYCQEAVG	5450209202 Dell Way	\N	ZWVCUGH	\N	0	Germany	2	LAIYCQEAVG@dell.com	5450209202	3	3416031416039914	2010/03	user16952	password	88	100000	F
16953	OBWWKI	WSHZIMZESY	8882524585 Dell Way	\N	BOBVUII	\N	0	China	2	WSHZIMZESY@dell.com	8882524585	3	7529857439454646	2008/07	user16953	password	68	20000	F
16954	UAAEIX	WQWECVIUUK	2201574364 Dell Way	\N	JVFDENL	\N	0	Australia	2	WQWECVIUUK@dell.com	2201574364	1	1821645902935415	2011/11	user16954	password	36	100000	M
16955	HVUPSR	GOWIKEDEPM	3299647202 Dell Way	\N	ZUQEIBF	\N	0	France	2	GOWIKEDEPM@dell.com	3299647202	2	2402755073271692	2008/07	user16955	password	89	80000	M
16956	VPLNGR	CCZNHCRWOR	4171144675 Dell Way	\N	QEWZGBL	\N	0	Germany	2	CCZNHCRWOR@dell.com	4171144675	3	6850341653916985	2012/07	user16956	password	49	80000	F
16957	AEYGVA	JVOQYFNMXD	2219881513 Dell Way	\N	RTDYVOM	\N	0	Canada	2	JVOQYFNMXD@dell.com	2219881513	1	1697012731805443	2011/07	user16957	password	76	20000	M
16958	ZAVVBE	QPVOVIBTMT	3336005845 Dell Way	\N	NPRIDDN	\N	0	Chile	2	QPVOVIBTMT@dell.com	3336005845	3	9876513837836684	2012/05	user16958	password	23	40000	F
16959	CEEDJV	SEJOMLHYEU	2709344061 Dell Way	\N	OWCSAPZ	\N	0	Chile	2	SEJOMLHYEU@dell.com	2709344061	5	1617055167444050	2010/01	user16959	password	49	100000	F
16960	PCGYXZ	CHOPSVOXPC	7569981823 Dell Way	\N	TSUTITA	\N	0	Germany	2	CHOPSVOXPC@dell.com	7569981823	1	1805037413258105	2011/07	user16960	password	19	100000	F
16961	DEBAEE	ISUANIYDKR	6085106219 Dell Way	\N	VFLEZMR	\N	0	Japan	2	ISUANIYDKR@dell.com	6085106219	4	5206040143035352	2008/10	user16961	password	44	40000	M
16962	NHYSLH	KFHYOGBYXX	5713638547 Dell Way	\N	EJBDVTV	\N	0	China	2	KFHYOGBYXX@dell.com	5713638547	2	5311394903343171	2009/08	user16962	password	68	40000	F
16963	ZEXKLH	QTFEAHDXEH	5818482225 Dell Way	\N	HGLCZGM	\N	0	Germany	2	QTFEAHDXEH@dell.com	5818482225	5	8435249304864556	2008/08	user16963	password	22	40000	M
16964	GHBSOR	MUWMBAKGIR	3308372810 Dell Way	\N	MTULZHY	\N	0	Germany	2	MUWMBAKGIR@dell.com	3308372810	4	7458959593437613	2012/11	user16964	password	25	60000	F
16965	JPUYHH	TDTUEDAMVN	7215679627 Dell Way	\N	FPYFWXT	\N	0	Canada	2	TDTUEDAMVN@dell.com	7215679627	3	1493055311962962	2010/07	user16965	password	61	80000	M
16966	ELXMSQ	PLLUPMGLZM	9011714192 Dell Way	\N	AYSXVLA	\N	0	Germany	2	PLLUPMGLZM@dell.com	9011714192	1	1530097553040832	2010/09	user16966	password	68	40000	M
16967	DHIVXY	HJSXVZIVLI	4284369003 Dell Way	\N	TDGOPHC	\N	0	France	2	HJSXVZIVLI@dell.com	4284369003	1	9294672131072732	2008/11	user16967	password	40	100000	M
16968	PHUNGC	WYZSYHNKQG	1722291017 Dell Way	\N	NWVDDYP	\N	0	Germany	2	WYZSYHNKQG@dell.com	1722291017	3	6090354828629643	2012/10	user16968	password	54	100000	F
16969	URYATV	ZSOXACHQJV	1373451400 Dell Way	\N	NEYRCNE	\N	0	Canada	2	ZSOXACHQJV@dell.com	1373451400	4	2042597291991114	2012/03	user16969	password	90	40000	F
16970	RGALBZ	EPXESEVBAI	9284341267 Dell Way	\N	FYAIMEO	\N	0	Germany	2	EPXESEVBAI@dell.com	9284341267	4	4581386130768806	2008/08	user16970	password	68	20000	F
16971	XFTZFX	PCCHHXIIGO	1937051252 Dell Way	\N	HHXTLLH	\N	0	China	2	PCCHHXIIGO@dell.com	1937051252	4	5834800805896521	2011/05	user16971	password	70	20000	F
16972	YVHDTX	GWFOUNWBCD	9262382060 Dell Way	\N	IAXTLFD	\N	0	Germany	2	GWFOUNWBCD@dell.com	9262382060	4	3899514355696738	2009/05	user16972	password	47	80000	F
16973	GXMAUT	WZHQNERQIZ	6237886906 Dell Way	\N	QGTCMXR	\N	0	China	2	WZHQNERQIZ@dell.com	6237886906	5	7170784020796419	2012/05	user16973	password	39	40000	M
16974	FUQANN	AVDOZVEIUV	6166398014 Dell Way	\N	OOXALPK	\N	0	Australia	2	AVDOZVEIUV@dell.com	6166398014	1	1169364362489432	2012/05	user16974	password	42	80000	M
16975	DHPRUQ	MYEMTIVODJ	9339632341 Dell Way	\N	CBKOQVP	\N	0	Chile	2	MYEMTIVODJ@dell.com	9339632341	4	2711114499252289	2009/12	user16975	password	76	100000	F
16976	BNTWEF	UISNQNBUXE	9209625582 Dell Way	\N	WISMDHS	\N	0	Australia	2	UISNQNBUXE@dell.com	9209625582	5	4634274162817747	2012/09	user16976	password	41	100000	M
16977	WRQAXL	IPZZDAUBFQ	7693247508 Dell Way	\N	JYDNFVQ	\N	0	Canada	2	IPZZDAUBFQ@dell.com	7693247508	1	9965727617498488	2010/05	user16977	password	85	40000	F
16978	PXGMIO	CHOFIIHNYR	8522805542 Dell Way	\N	LBFRXVV	\N	0	Japan	2	CHOFIIHNYR@dell.com	8522805542	5	1993247839622199	2008/09	user16978	password	44	40000	F
16979	GQUPFX	WTDFCKSABE	5538403457 Dell Way	\N	CGWACRR	\N	0	UK	2	WTDFCKSABE@dell.com	5538403457	4	1899847806431353	2009/02	user16979	password	54	60000	F
16980	DJZIHV	CKAEUTFWYI	7978952896 Dell Way	\N	DUIFMZC	\N	0	UK	2	CKAEUTFWYI@dell.com	7978952896	2	3023464184720069	2012/09	user16980	password	76	40000	M
16981	EGELCG	WDLQXQMVYP	2163331285 Dell Way	\N	QHUCHXB	\N	0	Australia	2	WDLQXQMVYP@dell.com	2163331285	2	9657238464802504	2012/02	user16981	password	37	80000	F
16982	NWTQDP	UOFRFSMDID	6096114549 Dell Way	\N	LDFSBHT	\N	0	Canada	2	UOFRFSMDID@dell.com	6096114549	4	1087448915466666	2011/12	user16982	password	68	100000	M
16983	ORDRGX	FMPKECONFZ	2409518996 Dell Way	\N	QKRRRLV	\N	0	Chile	2	FMPKECONFZ@dell.com	2409518996	5	9139682258944960	2008/07	user16983	password	79	80000	F
16984	NUTURZ	GGJLJYYOYP	9583441733 Dell Way	\N	YQGQBCW	\N	0	Chile	2	GGJLJYYOYP@dell.com	9583441733	4	4204074109904468	2010/08	user16984	password	90	60000	F
16985	TIXLHE	SRPBQOPODO	8495169791 Dell Way	\N	EKEGNBM	\N	0	France	2	SRPBQOPODO@dell.com	8495169791	5	9564822060521692	2010/10	user16985	password	57	60000	M
16986	WMBERT	WHVMVLBZAG	8508904403 Dell Way	\N	JFNWGZI	\N	0	Australia	2	WHVMVLBZAG@dell.com	8508904403	2	5862190740648658	2011/10	user16986	password	27	40000	M
16987	QIWHCT	OXFKJHJJOT	3021694672 Dell Way	\N	OBPVBYX	\N	0	South Africa	2	OXFKJHJJOT@dell.com	3021694672	3	6001478646881879	2008/08	user16987	password	77	80000	F
16988	DPNFIB	DOLMWVWKOL	6848384228 Dell Way	\N	MEGNCEK	\N	0	China	2	DOLMWVWKOL@dell.com	6848384228	5	4355108046438545	2009/10	user16988	password	25	60000	M
16989	SYDBAG	PLSLHPWVAI	3060916514 Dell Way	\N	ZHWCMGK	\N	0	Canada	2	PLSLHPWVAI@dell.com	3060916514	4	4323619172442705	2008/11	user16989	password	77	100000	M
16990	UBQUHG	GASNPOIQXI	6527398319 Dell Way	\N	XTKKAVN	\N	0	Chile	2	GASNPOIQXI@dell.com	6527398319	5	3241857773158699	2010/09	user16990	password	30	20000	F
16991	FTGNAN	NSACHJSERQ	5194909784 Dell Way	\N	XBBYXOE	\N	0	Germany	2	NSACHJSERQ@dell.com	5194909784	3	1167534542735666	2008/08	user16991	password	27	80000	M
16992	XYIXLV	PMYXVRBMHZ	5508863879 Dell Way	\N	OJYLXCY	\N	0	China	2	PMYXVRBMHZ@dell.com	5508863879	5	6082334202248604	2008/02	user16992	password	35	100000	F
16993	EFXQAN	CYKXQMJYMY	3769173054 Dell Way	\N	HKJEMIO	\N	0	UK	2	CYKXQMJYMY@dell.com	3769173054	1	1750133772380650	2010/05	user16993	password	89	60000	M
16994	EIEFVG	EGDUSNSFMA	9122849578 Dell Way	\N	PWFCFTC	\N	0	Germany	2	EGDUSNSFMA@dell.com	9122849578	1	9236664721742272	2009/02	user16994	password	42	100000	F
16995	QZOMGT	SKOLYHRKHH	6995071087 Dell Way	\N	GMJLGMY	\N	0	Canada	2	SKOLYHRKHH@dell.com	6995071087	5	4733378072734922	2012/03	user16995	password	35	20000	M
16996	FTILNA	VBMTIDEPKK	7141725249 Dell Way	\N	BUWIHVL	\N	0	UK	2	VBMTIDEPKK@dell.com	7141725249	5	7961635431740434	2012/02	user16996	password	87	80000	F
16997	SAUFBQ	GOJPSOEDYG	9097197476 Dell Way	\N	XVPEQAD	\N	0	China	2	GOJPSOEDYG@dell.com	9097197476	5	2812097216956317	2008/11	user16997	password	85	40000	M
16998	YCUASB	PCQHQVKPCI	5781686868 Dell Way	\N	LRMBRQK	\N	0	Germany	2	PCQHQVKPCI@dell.com	5781686868	3	6310959542170168	2009/07	user16998	password	84	100000	F
16999	ATMTUB	VKJMGTBIBN	5957028634 Dell Way	\N	ZOOREYG	\N	0	Russia	2	VKJMGTBIBN@dell.com	5957028634	5	1985780871473252	2008/09	user16999	password	23	60000	M
17000	VAMPCI	ALVGEWOGJN	3406387462 Dell Way	\N	UYEZXLS	\N	0	France	2	ALVGEWOGJN@dell.com	3406387462	5	5708666305989028	2008/11	user17000	password	21	80000	M
17001	BHIDPI	PKPTHEARSV	4021404532 Dell Way	\N	QXVOINA	\N	0	Germany	2	PKPTHEARSV@dell.com	4021404532	3	6488933657296003	2009/08	user17001	password	46	100000	M
17002	RGUHPJ	SEDAJESBZI	4903605494 Dell Way	\N	YUXHHXW	\N	0	Japan	2	SEDAJESBZI@dell.com	4903605494	3	8762575360015036	2008/11	user17002	password	76	80000	M
17003	BLVQVN	VZNFDFGCOF	8545759224 Dell Way	\N	XLMEJJV	\N	0	Russia	2	VZNFDFGCOF@dell.com	8545759224	4	8204045440070332	2011/06	user17003	password	51	40000	M
17004	YCETPA	SDFWJMZYRW	5862512693 Dell Way	\N	JEATNWN	\N	0	China	2	SDFWJMZYRW@dell.com	5862512693	2	1602541164495051	2008/10	user17004	password	41	60000	M
17005	KTLATE	DZBNLALDWV	4555395311 Dell Way	\N	HXOUTCE	\N	0	Chile	2	DZBNLALDWV@dell.com	4555395311	2	3858413504902273	2008/07	user17005	password	81	100000	M
17006	PIYJNC	JPPUPBYMWF	4642630991 Dell Way	\N	JLADNEK	\N	0	UK	2	JPPUPBYMWF@dell.com	4642630991	4	1864792847540229	2012/08	user17006	password	89	100000	F
17007	IWPWYY	LOTBPRNMWW	2213612860 Dell Way	\N	XXZLBKJ	\N	0	France	2	LOTBPRNMWW@dell.com	2213612860	3	4891658696811646	2011/06	user17007	password	42	100000	M
17008	EOPDNB	RGCGXPSUMQ	9280886155 Dell Way	\N	SMCUWLG	\N	0	Australia	2	RGCGXPSUMQ@dell.com	9280886155	4	7785747408866883	2009/01	user17008	password	70	20000	F
17009	HTIUUZ	AXFYMYTZPL	2564930382 Dell Way	\N	LRFIDMI	\N	0	Australia	2	AXFYMYTZPL@dell.com	2564930382	1	4859352109488100	2008/10	user17009	password	57	40000	F
17010	HSWBRX	YXVLVPKLBW	6681568928 Dell Way	\N	DHFHTNJ	\N	0	UK	2	YXVLVPKLBW@dell.com	6681568928	4	2091718065086752	2010/04	user17010	password	55	60000	M
17011	FKRWHQ	UCBQSMBTIE	6351825515 Dell Way	\N	AOMTBVR	\N	0	Russia	2	UCBQSMBTIE@dell.com	6351825515	5	2343967954162508	2012/04	user17011	password	67	60000	M
17012	BEKIUE	LWUDIWWRBX	2420187784 Dell Way	\N	FNRHIIA	\N	0	UK	2	LWUDIWWRBX@dell.com	2420187784	1	8571827656123788	2010/11	user17012	password	44	20000	M
17013	OLFJQR	FLVOHSGIPM	9620128648 Dell Way	\N	VGUEPUC	\N	0	Russia	2	FLVOHSGIPM@dell.com	9620128648	5	3104957967530936	2011/04	user17013	password	36	80000	M
17014	RXFHPL	SKAADGISTE	4244080707 Dell Way	\N	ZNIOILI	\N	0	Chile	2	SKAADGISTE@dell.com	4244080707	3	1745415905024856	2011/10	user17014	password	74	60000	F
17015	RSUHDM	SEMVKVNEAN	9337551936 Dell Way	\N	SJBAUJI	\N	0	Canada	2	SEMVKVNEAN@dell.com	9337551936	3	8153284877538682	2011/03	user17015	password	39	20000	M
17016	AZEELW	IYRTUFXUSQ	4581798193 Dell Way	\N	DURYEZB	\N	0	Australia	2	IYRTUFXUSQ@dell.com	4581798193	5	8239982062019409	2010/02	user17016	password	18	60000	F
17017	ZPILMR	KDKEJIZBYD	9659978077 Dell Way	\N	VPBZPCC	\N	0	UK	2	KDKEJIZBYD@dell.com	9659978077	5	6104189285542816	2008/11	user17017	password	19	40000	M
17018	QQHCHR	FRWPAVQYYM	4998224554 Dell Way	\N	OZMDCOD	\N	0	Australia	2	FRWPAVQYYM@dell.com	4998224554	4	2490888002328574	2009/09	user17018	password	51	20000	F
17019	CMLJDQ	BAFBVWATJO	5792098009 Dell Way	\N	TVSVKVW	\N	0	South Africa	2	BAFBVWATJO@dell.com	5792098009	1	2582249133381992	2009/06	user17019	password	44	60000	M
17020	VAYZRZ	ZXBUUBODPI	1602866566 Dell Way	\N	ZIDJDAF	\N	0	Japan	2	ZXBUUBODPI@dell.com	1602866566	2	9397812166251244	2010/10	user17020	password	56	20000	M
17021	NCOFBO	CCJWEYAUGZ	9706816588 Dell Way	\N	CKJGLOY	\N	0	France	2	CCJWEYAUGZ@dell.com	9706816588	5	1503329630941152	2011/05	user17021	password	32	40000	M
17022	HXDILF	LUCPTCKZCM	5699308782 Dell Way	\N	JLSVARH	\N	0	UK	2	LUCPTCKZCM@dell.com	5699308782	2	7309532844927163	2012/07	user17022	password	19	100000	M
17023	XYEIEQ	DHGWKQWMCG	7424213176 Dell Way	\N	XVBYMJX	\N	0	Australia	2	DHGWKQWMCG@dell.com	7424213176	4	9267909820657224	2009/08	user17023	password	72	20000	M
17024	SGWWXA	EDXOTTBWZZ	4609504897 Dell Way	\N	RBXEKUE	\N	0	Canada	2	EDXOTTBWZZ@dell.com	4609504897	1	4524627172388137	2008/11	user17024	password	53	60000	M
17025	TKLQLP	TIENBFJBEA	5341111981 Dell Way	\N	DBFNWJR	\N	0	Chile	2	TIENBFJBEA@dell.com	5341111981	1	3481827863957733	2009/07	user17025	password	78	100000	F
17026	GHYRXS	ZBFBGODLPG	5236691589 Dell Way	\N	MUTIELP	\N	0	Japan	2	ZBFBGODLPG@dell.com	5236691589	5	9896756905131044	2008/09	user17026	password	80	40000	M
17027	EFPBXO	DDQKRTVGZH	1781304372 Dell Way	\N	BTQGEFX	\N	0	Japan	2	DDQKRTVGZH@dell.com	1781304372	5	6884027521125973	2011/09	user17027	password	87	80000	M
17028	EHZCWC	FMMWGHDFPF	3049138620 Dell Way	\N	ZGLELIV	\N	0	Germany	2	FMMWGHDFPF@dell.com	3049138620	3	3868485300336033	2012/05	user17028	password	19	100000	M
17029	IWREZW	RMTYUXEJCD	6154961289 Dell Way	\N	POHBXCP	\N	0	Canada	2	RMTYUXEJCD@dell.com	6154961289	5	1848424172494560	2012/12	user17029	password	90	60000	F
17030	WGLVCD	IWBCTFLWJB	7076205567 Dell Way	\N	KRDITTL	\N	0	China	2	IWBCTFLWJB@dell.com	7076205567	3	3886932989116758	2011/07	user17030	password	82	100000	F
17031	DIFGMN	CNPWTBTCDE	4870395966 Dell Way	\N	TGMNZXW	\N	0	Japan	2	CNPWTBTCDE@dell.com	4870395966	1	3695136801339686	2012/01	user17031	password	31	40000	F
17032	NNKZAN	NQKHRDJVHD	7062794052 Dell Way	\N	BUQBRMT	\N	0	Canada	2	NQKHRDJVHD@dell.com	7062794052	1	1432368501555174	2011/03	user17032	password	44	100000	M
17033	WITXWH	OGOGJXBRAC	9553377217 Dell Way	\N	LRECEXF	\N	0	South Africa	2	OGOGJXBRAC@dell.com	9553377217	2	6266098188236356	2008/08	user17033	password	54	100000	M
17034	VRKSYZ	YMFHKGYLJK	9773095334 Dell Way	\N	DOMHMSD	\N	0	France	2	YMFHKGYLJK@dell.com	9773095334	4	6311863702256233	2010/03	user17034	password	55	20000	F
17035	FNUDMS	QSABYZNIJQ	8566932373 Dell Way	\N	WWYIOCT	\N	0	Germany	2	QSABYZNIJQ@dell.com	8566932373	2	2241464520338923	2008/11	user17035	password	35	20000	F
17036	TYFGRW	YRYXQLFACC	5801150063 Dell Way	\N	WBLLDEZ	\N	0	UK	2	YRYXQLFACC@dell.com	5801150063	1	1598478787112981	2009/05	user17036	password	35	60000	F
17037	ERIWNG	NMDEXJEALB	5918282185 Dell Way	\N	BXMECLE	\N	0	Japan	2	NMDEXJEALB@dell.com	5918282185	2	1082880271133035	2012/06	user17037	password	52	100000	M
17038	DINRPA	DTFBCKBOLC	7028212617 Dell Way	\N	LXHNJLD	\N	0	South Africa	2	DTFBCKBOLC@dell.com	7028212617	1	8083144898060710	2008/08	user17038	password	74	80000	M
17039	CHLRIP	KNQNYSCJUO	4287135966 Dell Way	\N	HBBQNFN	\N	0	Canada	2	KNQNYSCJUO@dell.com	4287135966	2	3894619408063591	2012/02	user17039	password	26	80000	F
17040	KEWSUH	GLUFDWOYKV	3848701967 Dell Way	\N	AMMNSAS	\N	0	Australia	2	GLUFDWOYKV@dell.com	3848701967	1	1475236923899501	2010/02	user17040	password	76	60000	M
17041	ZLGUSN	FNSIJHGUDG	5458382409 Dell Way	\N	HPTZPMB	\N	0	UK	2	FNSIJHGUDG@dell.com	5458382409	1	3969610275700688	2011/11	user17041	password	84	20000	M
17042	JLRBZW	OSFYZLSDSA	2391135031 Dell Way	\N	TMZIYBH	\N	0	France	2	OSFYZLSDSA@dell.com	2391135031	4	1591548780445009	2008/07	user17042	password	35	100000	M
17043	RQXQNM	ISKIEDLWEE	4647469285 Dell Way	\N	IENHFUS	\N	0	China	2	ISKIEDLWEE@dell.com	4647469285	4	4778923289384693	2012/01	user17043	password	45	80000	M
17044	ASINEQ	GPZKSLGWQP	3993532030 Dell Way	\N	AEWGZOP	\N	0	China	2	GPZKSLGWQP@dell.com	3993532030	1	3570407401770353	2009/05	user17044	password	22	20000	F
17045	TIYYZE	NYOGKVDAKE	1037144626 Dell Way	\N	EHKDVZN	\N	0	Canada	2	NYOGKVDAKE@dell.com	1037144626	4	5537695853505284	2010/11	user17045	password	55	100000	M
17046	VTOVYB	UNIEILETPJ	8071581756 Dell Way	\N	AZMWZZA	\N	0	UK	2	UNIEILETPJ@dell.com	8071581756	3	4350866484921426	2011/01	user17046	password	31	40000	M
17047	YUSXWM	KERTQWNFFO	9811360504 Dell Way	\N	ESKDSLD	\N	0	France	2	KERTQWNFFO@dell.com	9811360504	3	2115687361918389	2008/09	user17047	password	45	100000	M
17048	EQNBDX	GVRWRECWSH	1402360718 Dell Way	\N	ODLHOOT	\N	0	Germany	2	GVRWRECWSH@dell.com	1402360718	5	6140382251236588	2011/04	user17048	password	54	40000	F
17049	EXNHUT	DMQUQSQJZF	2267403824 Dell Way	\N	MKNAZGO	\N	0	Australia	2	DMQUQSQJZF@dell.com	2267403824	1	7678589491639287	2010/08	user17049	password	25	100000	M
17050	ZJCUDF	GUZXMQGMWS	5109301585 Dell Way	\N	XJTWQIX	\N	0	Russia	2	GUZXMQGMWS@dell.com	5109301585	4	2578531470149755	2008/09	user17050	password	19	100000	M
17051	KZNNFU	HESUVZHSSF	6440887963 Dell Way	\N	BLCSUZM	\N	0	Chile	2	HESUVZHSSF@dell.com	6440887963	4	3909404083620757	2009/09	user17051	password	33	20000	F
17052	FPPKKX	OCRKBZCTEE	1022712614 Dell Way	\N	FGWZGJF	\N	0	South Africa	2	OCRKBZCTEE@dell.com	1022712614	3	2629624542780220	2011/09	user17052	password	36	80000	M
17053	WJIGGX	JYHKXKECOJ	1856372546 Dell Way	\N	JLJPUOK	\N	0	Russia	2	JYHKXKECOJ@dell.com	1856372546	4	5213530932553113	2012/11	user17053	password	34	80000	M
17054	OCZVZI	THTRRXTGHC	7410958738 Dell Way	\N	RQRLFCG	\N	0	China	2	THTRRXTGHC@dell.com	7410958738	4	2310725125018507	2010/12	user17054	password	84	40000	F
17055	AGIAPB	HISYFLFNOW	3299869067 Dell Way	\N	EGIJJOR	\N	0	Australia	2	HISYFLFNOW@dell.com	3299869067	5	6750009631738067	2008/10	user17055	password	85	80000	M
17056	EZTTBB	BTAHFFVUBZ	8874323492 Dell Way	\N	AJJJYBL	\N	0	Canada	2	BTAHFFVUBZ@dell.com	8874323492	1	4286309322342277	2011/01	user17056	password	21	40000	F
17057	AEYCFA	VFIBKDVMDW	8068797099 Dell Way	\N	WMGUNSZ	\N	0	China	2	VFIBKDVMDW@dell.com	8068797099	2	1207042576279491	2011/05	user17057	password	48	100000	F
17058	OYNUZJ	ZIKKMGXPDT	8749789621 Dell Way	\N	BJOPBNZ	\N	0	South Africa	2	ZIKKMGXPDT@dell.com	8749789621	1	6855871283449233	2009/06	user17058	password	65	80000	M
17059	PETPNT	XYEJEBYHVA	6501017851 Dell Way	\N	RJPSXPP	\N	0	Russia	2	XYEJEBYHVA@dell.com	6501017851	2	9941002197563648	2008/11	user17059	password	66	20000	F
17060	VUBINZ	HRILTHTOHK	9609634937 Dell Way	\N	XXDVNSO	\N	0	Canada	2	HRILTHTOHK@dell.com	9609634937	3	2350570475682616	2012/03	user17060	password	30	40000	F
17061	YJJMIR	ERCXYWMGGK	3852864458 Dell Way	\N	DKFQDTT	\N	0	Australia	2	ERCXYWMGGK@dell.com	3852864458	5	9281376454513520	2010/02	user17061	password	35	60000	F
17062	PYNYPS	PSQOOCUVMY	3275261019 Dell Way	\N	FSPJMIL	\N	0	Russia	2	PSQOOCUVMY@dell.com	3275261019	2	3838311982806772	2009/08	user17062	password	82	40000	F
17063	VXDLPT	DGISIDNVBT	9070251979 Dell Way	\N	OQCAZOU	\N	0	Chile	2	DGISIDNVBT@dell.com	9070251979	1	6061574918683619	2010/12	user17063	password	86	80000	M
17064	WVGLPK	SYCABQWCJK	3948222206 Dell Way	\N	TMKSAFY	\N	0	UK	2	SYCABQWCJK@dell.com	3948222206	3	4628992985468358	2009/06	user17064	password	24	20000	F
17065	YKTOVL	MXMOOIQXTJ	5674150089 Dell Way	\N	KDCKJAI	\N	0	Japan	2	MXMOOIQXTJ@dell.com	5674150089	4	1081242258660495	2012/10	user17065	password	29	40000	M
17066	OZIJKU	HWJVFZTYJD	6451240674 Dell Way	\N	CMOLMWD	\N	0	Australia	2	HWJVFZTYJD@dell.com	6451240674	1	9766793765593320	2010/04	user17066	password	33	20000	M
17067	FNGPIN	MRISRCQBFT	5098147644 Dell Way	\N	NTEAQIB	\N	0	Chile	2	MRISRCQBFT@dell.com	5098147644	1	7097513081971557	2011/03	user17067	password	81	80000	F
17068	KWASJN	JSGBUWCAPQ	7567842866 Dell Way	\N	UURKCSR	\N	0	Germany	2	JSGBUWCAPQ@dell.com	7567842866	2	3853735904209316	2012/03	user17068	password	86	40000	M
17069	ULIEYR	WETRBVRRMM	9093615247 Dell Way	\N	MDXPVOD	\N	0	Germany	2	WETRBVRRMM@dell.com	9093615247	3	5844001206103713	2008/05	user17069	password	85	80000	F
17070	JAIISF	NMWPIOGUAT	9507294024 Dell Way	\N	YXIUMMI	\N	0	China	2	NMWPIOGUAT@dell.com	9507294024	5	5371830617077649	2009/10	user17070	password	33	60000	F
17071	GWMZCZ	LZPTNWOOPM	5317962564 Dell Way	\N	MXGYKPI	\N	0	China	2	LZPTNWOOPM@dell.com	5317962564	4	7213587026577444	2009/01	user17071	password	34	60000	F
17072	CYGEYR	DNLRJZGZMS	7893727771 Dell Way	\N	XSRHIZQ	\N	0	South Africa	2	DNLRJZGZMS@dell.com	7893727771	2	1854622933547943	2011/07	user17072	password	58	20000	M
17073	NGVMYZ	AJRKJXJWPG	5639298375 Dell Way	\N	OHOXGES	\N	0	Australia	2	AJRKJXJWPG@dell.com	5639298375	4	8022389729041607	2008/05	user17073	password	76	80000	M
17074	BNIANJ	JETTBCPRJE	6200709838 Dell Way	\N	YXCECUF	\N	0	Japan	2	JETTBCPRJE@dell.com	6200709838	5	7002518366556615	2012/10	user17074	password	45	100000	M
17075	XDWLMG	PFZRIPIRUH	6882794597 Dell Way	\N	OWMRQRG	\N	0	Chile	2	PFZRIPIRUH@dell.com	6882794597	5	2447439590003341	2010/04	user17075	password	88	40000	F
17076	CDQPJG	VJXDZGVTNK	3259268213 Dell Way	\N	QZBHRIN	\N	0	China	2	VJXDZGVTNK@dell.com	3259268213	4	7812753045931459	2010/08	user17076	password	21	80000	M
17077	ELIORE	YOIXUDRHOH	7556586850 Dell Way	\N	HPOYYBH	\N	0	Canada	2	YOIXUDRHOH@dell.com	7556586850	1	7683725645300002	2009/01	user17077	password	55	20000	F
17078	YLVPPU	EXSYBJGPRO	8370142607 Dell Way	\N	FFNEHUI	\N	0	Australia	2	EXSYBJGPRO@dell.com	8370142607	1	4362493500579149	2012/08	user17078	password	51	20000	M
17079	XAEMUI	KMHMWNCNCH	9114553702 Dell Way	\N	TPMAKVB	\N	0	Chile	2	KMHMWNCNCH@dell.com	9114553702	3	1950531188398599	2010/11	user17079	password	38	20000	M
17080	HFGBNR	OVDKJFXLNQ	2144685737 Dell Way	\N	AZRLUSQ	\N	0	Russia	2	OVDKJFXLNQ@dell.com	2144685737	4	2922773153055459	2008/01	user17080	password	38	80000	F
17081	MAJASY	VVJEBHQOXR	5136548415 Dell Way	\N	OPCJISB	\N	0	France	2	VVJEBHQOXR@dell.com	5136548415	2	4975988919846714	2010/07	user17081	password	33	80000	F
17082	GDCZCX	ULCWSSLQKZ	7491768717 Dell Way	\N	FMJNFLZ	\N	0	Japan	2	ULCWSSLQKZ@dell.com	7491768717	3	2158835572190583	2009/08	user17082	password	83	40000	M
17083	BKVDIQ	OLMGEYWOYC	1008318070 Dell Way	\N	AHQFSPW	\N	0	France	2	OLMGEYWOYC@dell.com	1008318070	5	7538691877387465	2011/11	user17083	password	22	60000	M
17084	MJBUZQ	FMXJLUXJWY	1202993563 Dell Way	\N	QNDJCAU	\N	0	Canada	2	FMXJLUXJWY@dell.com	1202993563	3	7557822930160911	2012/08	user17084	password	35	100000	F
17085	PYWPOB	CLLNGJWCHM	2733657284 Dell Way	\N	QLWSMRV	\N	0	Germany	2	CLLNGJWCHM@dell.com	2733657284	3	4830454572103918	2011/10	user17085	password	39	100000	F
17086	FRZUTB	GFOMOKPWXF	3819905553 Dell Way	\N	ITYVKTI	\N	0	Japan	2	GFOMOKPWXF@dell.com	3819905553	4	4525479926262051	2008/01	user17086	password	34	60000	F
17087	XLBRMI	WBVLMLIJQQ	5680686654 Dell Way	\N	DPMNJUD	\N	0	Japan	2	WBVLMLIJQQ@dell.com	5680686654	3	7894604849163444	2010/10	user17087	password	35	100000	M
17088	RWJEFG	GASSLABCRE	4607804183 Dell Way	\N	RDSAXWS	\N	0	France	2	GASSLABCRE@dell.com	4607804183	3	9878469935152680	2008/09	user17088	password	76	100000	F
17089	RFPXMV	XENJEPLWTD	4117228465 Dell Way	\N	ZMEXIWI	\N	0	Russia	2	XENJEPLWTD@dell.com	4117228465	2	9210312009789052	2008/02	user17089	password	74	60000	M
17090	ZBSMWQ	QKZVZLSSPS	3504538265 Dell Way	\N	FTPOQYH	\N	0	UK	2	QKZVZLSSPS@dell.com	3504538265	1	1419047084171325	2010/12	user17090	password	55	40000	M
17091	OYLKOC	UOXUZQMOIR	7372509264 Dell Way	\N	IXFZWNY	\N	0	Canada	2	UOXUZQMOIR@dell.com	7372509264	1	6012583210133017	2011/07	user17091	password	75	80000	F
17092	SBMHEH	VBBUSOJAGS	6833483622 Dell Way	\N	YMRUZQY	\N	0	Japan	2	VBBUSOJAGS@dell.com	6833483622	3	4371468130033463	2008/04	user17092	password	18	40000	F
17093	CSHGAC	ICXARHAXZY	2596048700 Dell Way	\N	JRTJIRB	\N	0	UK	2	ICXARHAXZY@dell.com	2596048700	3	2186486163176596	2010/06	user17093	password	44	60000	M
17094	CTUCWD	FUDWBETBDD	1426381534 Dell Way	\N	TWNBOPA	\N	0	Russia	2	FUDWBETBDD@dell.com	1426381534	1	2624174725729972	2010/07	user17094	password	64	20000	M
17095	KWTGZY	ADUCHODKSX	2347267624 Dell Way	\N	HGYVVZO	\N	0	South Africa	2	ADUCHODKSX@dell.com	2347267624	4	4575830923859030	2011/05	user17095	password	51	40000	M
17096	IAAIZA	LUCTIGEBDL	5732080871 Dell Way	\N	HCGDCUA	\N	0	Chile	2	LUCTIGEBDL@dell.com	5732080871	3	9154608886223288	2012/11	user17096	password	32	80000	F
17097	GRNFRY	ZUSIBWJEHR	3382901470 Dell Way	\N	HNVJIVP	\N	0	South Africa	2	ZUSIBWJEHR@dell.com	3382901470	3	7823328069876880	2008/09	user17097	password	48	40000	M
17098	BWDTVC	ONKPJUURLB	5333373523 Dell Way	\N	FGKNCZK	\N	0	China	2	ONKPJUURLB@dell.com	5333373523	1	5681291257496924	2008/07	user17098	password	82	20000	M
17099	TFKPIY	CSOMNIDYJI	4892550355 Dell Way	\N	FUWIUHS	\N	0	Chile	2	CSOMNIDYJI@dell.com	4892550355	2	4887395103462041	2008/02	user17099	password	56	80000	M
17100	TBLBZO	UNAHWEGFNL	7340153508 Dell Way	\N	AKUURMB	\N	0	Canada	2	UNAHWEGFNL@dell.com	7340153508	3	1997738217934966	2011/01	user17100	password	72	80000	M
17101	UCVUQP	HQWEVCJJOJ	7147234451 Dell Way	\N	TJELWFO	\N	0	Germany	2	HQWEVCJJOJ@dell.com	7147234451	4	4176039879210293	2011/05	user17101	password	90	60000	F
17102	CGZSVH	JSLEVVOKFH	9381689822 Dell Way	\N	TJTPOHE	\N	0	Chile	2	JSLEVVOKFH@dell.com	9381689822	3	9436500403564424	2009/07	user17102	password	45	60000	M
17103	PNHLUQ	DGVZBJJGRC	4364515672 Dell Way	\N	PKSERWL	\N	0	Germany	2	DGVZBJJGRC@dell.com	4364515672	2	9422240443527700	2012/09	user17103	password	52	60000	F
17104	ZTUUKY	AFXCOGIFJY	9456754208 Dell Way	\N	QCDHYOW	\N	0	China	2	AFXCOGIFJY@dell.com	9456754208	5	2798593623097986	2011/04	user17104	password	66	20000	F
17105	KVBVUC	ARFPYOVIML	4802470712 Dell Way	\N	KQSIFPQ	\N	0	Canada	2	ARFPYOVIML@dell.com	4802470712	5	8397450781427325	2011/07	user17105	password	80	100000	M
17106	RBTLET	DKJCYEKLPU	6435337714 Dell Way	\N	BICGYTK	\N	0	China	2	DKJCYEKLPU@dell.com	6435337714	2	1702666543424129	2008/01	user17106	password	23	20000	M
17107	DUFIOJ	SXLQCVBSPD	1049790772 Dell Way	\N	BSKZMUI	\N	0	Australia	2	SXLQCVBSPD@dell.com	1049790772	3	2775589079130441	2008/06	user17107	password	36	100000	M
17108	BBZQLS	NXIQSKIIOJ	2107279998 Dell Way	\N	BYJNSSP	\N	0	Russia	2	NXIQSKIIOJ@dell.com	2107279998	5	8207117470446975	2011/01	user17108	password	65	40000	F
17109	SGTEYG	BHXUSFDGPE	2197040739 Dell Way	\N	EYSWQIP	\N	0	Russia	2	BHXUSFDGPE@dell.com	2197040739	3	4557479002512992	2008/01	user17109	password	66	40000	M
17110	XAYWHA	DFUWLXCACG	2287607069 Dell Way	\N	ZVDQDTK	\N	0	Chile	2	DFUWLXCACG@dell.com	2287607069	4	5303669617511332	2008/06	user17110	password	75	100000	F
17111	VXFDXJ	ISFTQITTOT	5991622065 Dell Way	\N	OSJSLTA	\N	0	Germany	2	ISFTQITTOT@dell.com	5991622065	3	8133349459618331	2008/04	user17111	password	73	40000	F
17112	RPFPZN	HFHYNBRCUF	4789082235 Dell Way	\N	UEYGXYW	\N	0	France	2	HFHYNBRCUF@dell.com	4789082235	4	5343489256687463	2011/05	user17112	password	80	80000	F
17113	MZRLNZ	QUXEVOGQUB	8115837694 Dell Way	\N	USHRRDE	\N	0	Australia	2	QUXEVOGQUB@dell.com	8115837694	4	7915656849741936	2008/07	user17113	password	57	40000	M
17114	NYLAXB	UUGQJMGDNA	5691119370 Dell Way	\N	WVSNYWP	\N	0	Russia	2	UUGQJMGDNA@dell.com	5691119370	2	9535694900900126	2008/11	user17114	password	34	20000	F
17115	ELLCNG	WTWGFDJTDG	7800142254 Dell Way	\N	OWTNTJH	\N	0	Chile	2	WTWGFDJTDG@dell.com	7800142254	2	3583322141785175	2011/06	user17115	password	39	20000	M
17116	SNSGUP	ZQVFUFYXLN	5960084060 Dell Way	\N	UFBNPIU	\N	0	China	2	ZQVFUFYXLN@dell.com	5960084060	1	1149598347023129	2008/05	user17116	password	26	80000	F
17117	QIILXH	CSNWYLUJZO	9251295689 Dell Way	\N	PABEJWN	\N	0	South Africa	2	CSNWYLUJZO@dell.com	9251295689	3	9113687139935792	2009/08	user17117	password	56	40000	F
17118	VRSTZU	MMQKXLTXZI	6195245457 Dell Way	\N	XBNHXAE	\N	0	South Africa	2	MMQKXLTXZI@dell.com	6195245457	1	1891924657393247	2009/08	user17118	password	51	60000	F
17119	DGECBQ	OSAMDUJCDH	8310200001 Dell Way	\N	EQOBRTX	\N	0	Chile	2	OSAMDUJCDH@dell.com	8310200001	5	5280420736875385	2010/06	user17119	password	18	100000	M
17120	GARHRF	ZRSDLCGPJK	4288292078 Dell Way	\N	FYMWRJD	\N	0	France	2	ZRSDLCGPJK@dell.com	4288292078	4	9129740927834064	2012/08	user17120	password	72	40000	M
17121	TBDKHD	CZHOBNDLXJ	9682203443 Dell Way	\N	KJGBTJO	\N	0	Canada	2	CZHOBNDLXJ@dell.com	9682203443	3	9374118085019292	2010/03	user17121	password	41	60000	M
17122	KOKRSN	RABTNFEKOO	7103091846 Dell Way	\N	UUQODFR	\N	0	Canada	2	RABTNFEKOO@dell.com	7103091846	3	7173584481701256	2012/12	user17122	password	26	100000	F
17123	RHZKUQ	KWKYBOJQDD	9520733924 Dell Way	\N	LUSOZJR	\N	0	Japan	2	KWKYBOJQDD@dell.com	9520733924	2	5981013165786863	2012/06	user17123	password	49	20000	F
17124	SDPNUA	JFYLTHBXKM	2264916624 Dell Way	\N	RDBQMTH	\N	0	France	2	JFYLTHBXKM@dell.com	2264916624	5	3533349260222167	2011/04	user17124	password	50	100000	F
17125	PKNKKW	PIIJPKGAXY	7699185558 Dell Way	\N	DZPPTXA	\N	0	South Africa	2	PIIJPKGAXY@dell.com	7699185558	2	5523254991043360	2008/09	user17125	password	40	20000	F
17126	ROTBLJ	KTTZEZZBYC	1106583367 Dell Way	\N	ANSUKSQ	\N	0	Canada	2	KTTZEZZBYC@dell.com	1106583367	1	2507854897994548	2011/06	user17126	password	33	20000	F
17127	TWFFGP	ZZPDZOFXRG	8202316538 Dell Way	\N	KJAUCQX	\N	0	Canada	2	ZZPDZOFXRG@dell.com	8202316538	1	8777239834889770	2009/04	user17127	password	89	40000	F
17128	VPGCFG	BUJAJPXAVH	1419970639 Dell Way	\N	KVBMMZP	\N	0	Chile	2	BUJAJPXAVH@dell.com	1419970639	3	5798948174808175	2009/06	user17128	password	85	40000	F
17129	NQJTWK	NGLWVIXRPI	8986041009 Dell Way	\N	MRVZQKG	\N	0	Japan	2	NGLWVIXRPI@dell.com	8986041009	4	1180520151741802	2009/09	user17129	password	47	80000	F
17130	BZZYKN	FVKADHSTPE	2832728316 Dell Way	\N	KKEBVKT	\N	0	Russia	2	FVKADHSTPE@dell.com	2832728316	4	1483937414828687	2012/03	user17130	password	66	20000	F
17131	QDEBQJ	WAKZICTYHE	7453221849 Dell Way	\N	ILFEWYX	\N	0	Australia	2	WAKZICTYHE@dell.com	7453221849	5	9742868033703418	2012/08	user17131	password	27	20000	F
17132	GGIXQE	XAEGCXEJBN	5995416498 Dell Way	\N	VHRRGPS	\N	0	UK	2	XAEGCXEJBN@dell.com	5995416498	4	8595439540222288	2008/10	user17132	password	87	60000	F
17133	FUZVYX	WDDZBIIDVE	3380388743 Dell Way	\N	KNVRDOP	\N	0	Japan	2	WDDZBIIDVE@dell.com	3380388743	3	8679708872921766	2008/05	user17133	password	40	20000	M
17134	CEMBBI	EFHGOQJJUU	5527722537 Dell Way	\N	XQLAFBR	\N	0	France	2	EFHGOQJJUU@dell.com	5527722537	3	6031746839173139	2012/11	user17134	password	71	60000	M
17135	XAZZIE	FQKTHTCBOZ	2689168371 Dell Way	\N	SZZXARJ	\N	0	Germany	2	FQKTHTCBOZ@dell.com	2689168371	5	4916231155395508	2008/09	user17135	password	89	100000	M
17136	ZYOICT	ZNMGGPHUOA	3326603344 Dell Way	\N	UOYUFII	\N	0	France	2	ZNMGGPHUOA@dell.com	3326603344	4	4975703654345125	2012/09	user17136	password	47	60000	M
17137	IBBLVA	YHGFXOAMPU	6922952220 Dell Way	\N	ANPGVXR	\N	0	Australia	2	YHGFXOAMPU@dell.com	6922952220	1	1219717669300735	2009/07	user17137	password	57	20000	M
17138	PEHLEF	TLKQZKCOFD	2738795298 Dell Way	\N	CUKXRBZ	\N	0	China	2	TLKQZKCOFD@dell.com	2738795298	1	7623521104454995	2011/07	user17138	password	79	60000	F
17139	AWPFBJ	QMZQXBEDFH	2813926680 Dell Way	\N	XPEPREY	\N	0	South Africa	2	QMZQXBEDFH@dell.com	2813926680	4	6244816548656673	2011/07	user17139	password	28	100000	M
17140	ZOSBXJ	OWZMYEPELM	7074482248 Dell Way	\N	TQBLUAI	\N	0	UK	2	OWZMYEPELM@dell.com	7074482248	5	7871501340065152	2008/01	user17140	password	69	80000	F
17141	GLCDUR	AUDZYSDJEX	6069536603 Dell Way	\N	ZGJUGRU	\N	0	UK	2	AUDZYSDJEX@dell.com	6069536603	3	2192783973179757	2011/04	user17141	password	80	80000	M
17142	HTRCKR	XNRVGUFLSE	3739194686 Dell Way	\N	RBZYSTX	\N	0	Chile	2	XNRVGUFLSE@dell.com	3739194686	1	9007540402933956	2010/11	user17142	password	57	20000	F
17143	HSHSKE	FBAMWFXPJO	4868013259 Dell Way	\N	QJNJCKQ	\N	0	France	2	FBAMWFXPJO@dell.com	4868013259	3	9726879565976560	2009/01	user17143	password	20	60000	F
17144	TUBEYH	GYTDEQSNFJ	8928978417 Dell Way	\N	XTSZDJK	\N	0	Germany	2	GYTDEQSNFJ@dell.com	8928978417	2	8895937252324075	2012/05	user17144	password	44	40000	F
17145	DJJCQP	BJSFALTFUQ	4925613522 Dell Way	\N	YNQCWBR	\N	0	Russia	2	BJSFALTFUQ@dell.com	4925613522	3	7167267921380699	2012/11	user17145	password	90	20000	F
17146	IJEZZG	JSMJDGPYXO	8837250053 Dell Way	\N	LORHPIA	\N	0	Australia	2	JSMJDGPYXO@dell.com	8837250053	4	8961960673797877	2011/09	user17146	password	84	100000	F
17147	HAAGHJ	YTTCZJAWXL	5270522949 Dell Way	\N	KOTAWTB	\N	0	Russia	2	YTTCZJAWXL@dell.com	5270522949	5	5848700658418239	2008/11	user17147	password	46	40000	F
17148	KGJRPI	LJKKSKHPVS	7351884631 Dell Way	\N	EOSBIUU	\N	0	South Africa	2	LJKKSKHPVS@dell.com	7351884631	2	9843850541859866	2010/09	user17148	password	32	80000	F
17149	LBVBJG	KTRCDYSZRW	1703860746 Dell Way	\N	OJYXDTS	\N	0	South Africa	2	KTRCDYSZRW@dell.com	1703860746	4	4619260711595416	2012/11	user17149	password	23	100000	F
17150	DUJMAU	FRWJQPJHMY	2873967669 Dell Way	\N	RKVVDNR	\N	0	Chile	2	FRWJQPJHMY@dell.com	2873967669	1	1345641246996820	2008/02	user17150	password	90	60000	F
17151	TUTUOZ	MLJDBSLNRC	7176169309 Dell Way	\N	YMYCAPI	\N	0	Chile	2	MLJDBSLNRC@dell.com	7176169309	2	3777600232046098	2012/05	user17151	password	70	20000	F
17152	NWXBWK	NFNOYYBPBA	8167077286 Dell Way	\N	BZCCPLH	\N	0	Chile	2	NFNOYYBPBA@dell.com	8167077286	4	2036910107824951	2008/04	user17152	password	34	40000	M
17153	CEXYOK	DBYCAARBBT	7698485942 Dell Way	\N	BDVQPDX	\N	0	China	2	DBYCAARBBT@dell.com	7698485942	1	5776763712055982	2008/04	user17153	password	75	100000	F
17154	YVHNFL	PENPFFRGYS	3797061175 Dell Way	\N	KUJZXHJ	\N	0	Japan	2	PENPFFRGYS@dell.com	3797061175	5	7626809735782445	2010/09	user17154	password	65	100000	M
17155	MFERRT	WEJBJBIIUS	9704816624 Dell Way	\N	CDSAKBR	\N	0	Russia	2	WEJBJBIIUS@dell.com	9704816624	3	3718813787680119	2011/01	user17155	password	34	40000	M
17156	LMFCGB	HPDQRLZLEB	2457252615 Dell Way	\N	OWBZXTS	\N	0	South Africa	2	HPDQRLZLEB@dell.com	2457252615	1	5912254729308189	2009/04	user17156	password	80	80000	M
17157	JYUPAB	FESWPRHTSW	6753739482 Dell Way	\N	QUWNOPK	\N	0	Russia	2	FESWPRHTSW@dell.com	6753739482	5	9460693643894048	2012/10	user17157	password	68	60000	F
17158	QJTRLZ	VEVLVDFOAV	7807402784 Dell Way	\N	JXJXNUQ	\N	0	Canada	2	VEVLVDFOAV@dell.com	7807402784	3	1383329108357429	2010/04	user17158	password	64	80000	M
17159	ANPMML	QIXLMCANYJ	5263843176 Dell Way	\N	KIHXCXB	\N	0	South Africa	2	QIXLMCANYJ@dell.com	5263843176	1	4987175013870001	2011/09	user17159	password	32	80000	M
17160	SFFFRV	OOHAQHNPQY	9917749260 Dell Way	\N	XXVAVXW	\N	0	Chile	2	OOHAQHNPQY@dell.com	9917749260	2	1285814851522445	2011/07	user17160	password	67	60000	F
17161	XSLOOZ	CVZTDNITLG	4854597680 Dell Way	\N	RHGNEDV	\N	0	Canada	2	CVZTDNITLG@dell.com	4854597680	5	8967212376184762	2012/07	user17161	password	44	20000	F
17162	BPZPOB	LOVOCEINKA	2710307011 Dell Way	\N	UQNZTID	\N	0	Canada	2	LOVOCEINKA@dell.com	2710307011	1	2149926049169153	2011/05	user17162	password	39	20000	F
17163	XCBLEM	AZBDDJQOJL	6295705031 Dell Way	\N	EXLYGOD	\N	0	France	2	AZBDDJQOJL@dell.com	6295705031	2	2320411499589681	2012/07	user17163	password	37	60000	F
17164	JMXOYY	NZBRJSFTEK	8085360436 Dell Way	\N	QPJXDNI	\N	0	Russia	2	NZBRJSFTEK@dell.com	8085360436	3	7428216641768814	2009/09	user17164	password	27	80000	F
17165	PSROQF	OSWYKCRONH	9782566181 Dell Way	\N	DXEHKNB	\N	0	Chile	2	OSWYKCRONH@dell.com	9782566181	4	5991285104304553	2011/11	user17165	password	43	100000	M
17166	BMBSRQ	KOOVRFKFNO	6733286859 Dell Way	\N	CRVNFWT	\N	0	Canada	2	KOOVRFKFNO@dell.com	6733286859	2	8994759081862868	2010/08	user17166	password	70	20000	M
17167	FCKXTV	MHRENBJAPM	1377845118 Dell Way	\N	SLAXITB	\N	0	UK	2	MHRENBJAPM@dell.com	1377845118	5	5315249522682280	2011/09	user17167	password	55	40000	M
17168	PVUIQH	QILDJVDYHV	7623385585 Dell Way	\N	KISSBUQ	\N	0	Canada	2	QILDJVDYHV@dell.com	7623385585	1	8179060155991466	2010/08	user17168	password	31	40000	F
17169	ACPQJF	YVJIQMHYIR	2309240853 Dell Way	\N	GBJIVAL	\N	0	Germany	2	YVJIQMHYIR@dell.com	2309240853	2	9873220252804460	2011/06	user17169	password	38	20000	F
17170	JQCTVB	PEJGRQEAHL	5206882235 Dell Way	\N	BRUXRFM	\N	0	South Africa	2	PEJGRQEAHL@dell.com	5206882235	3	6504900340456516	2012/09	user17170	password	65	40000	F
17171	GKXCMM	HVSZMXZTIA	8759080269 Dell Way	\N	LCXCIKY	\N	0	Russia	2	HVSZMXZTIA@dell.com	8759080269	3	7303016967140139	2011/03	user17171	password	20	80000	F
17172	LQOXCW	TVVFSUZAVK	1228423239 Dell Way	\N	DTNMDMH	\N	0	Australia	2	TVVFSUZAVK@dell.com	1228423239	5	6574124601203949	2009/01	user17172	password	43	80000	F
17173	ZGKCDD	XYJPTIQPTU	5530497403 Dell Way	\N	IHGMTNM	\N	0	Russia	2	XYJPTIQPTU@dell.com	5530497403	1	9969402893446388	2010/06	user17173	password	68	100000	F
17174	YJOBNL	AWBUESJXMS	8364561211 Dell Way	\N	FTFYGSS	\N	0	Russia	2	AWBUESJXMS@dell.com	8364561211	4	3552113143727183	2009/05	user17174	password	37	80000	F
17175	QHKDTL	ZUGEMQCYIH	6858405162 Dell Way	\N	SOFZGYT	\N	0	Australia	2	ZUGEMQCYIH@dell.com	6858405162	1	4212558477651328	2008/04	user17175	password	25	40000	M
17176	KVBDGA	XNFKDHJMOB	7888847558 Dell Way	\N	AUAGSTI	\N	0	China	2	XNFKDHJMOB@dell.com	7888847558	4	4707714713644236	2008/10	user17176	password	76	100000	F
17177	QAHXBF	KGPNNZZBAA	3770487336 Dell Way	\N	VAHOUQX	\N	0	Germany	2	KGPNNZZBAA@dell.com	3770487336	2	6321736104786397	2008/02	user17177	password	58	40000	M
17178	OPQPVA	VLOJKOKKOG	1271584592 Dell Way	\N	LWUFMST	\N	0	Russia	2	VLOJKOKKOG@dell.com	1271584592	2	8864525248762221	2008/11	user17178	password	29	100000	F
17179	TOBOOX	ZDGJRRUGYF	5879073557 Dell Way	\N	CTLOLEI	\N	0	France	2	ZDGJRRUGYF@dell.com	5879073557	2	6680972446687520	2010/05	user17179	password	57	100000	F
17180	CZRRXR	UEAMWUSUAU	8873539185 Dell Way	\N	NLJYQRL	\N	0	Canada	2	UEAMWUSUAU@dell.com	8873539185	1	6708610414527357	2009/08	user17180	password	57	40000	M
17181	NAJLRD	PSPLNHFNCT	2667256379 Dell Way	\N	ZLSQDDV	\N	0	UK	2	PSPLNHFNCT@dell.com	2667256379	3	3079432612285018	2011/12	user17181	password	59	60000	M
17182	PVYGYO	YOZLWFZZYY	8529754198 Dell Way	\N	KROOUKO	\N	0	UK	2	YOZLWFZZYY@dell.com	8529754198	4	7767035669181497	2012/05	user17182	password	34	40000	M
17183	BIEAWD	OWOLCNKAMV	7201694229 Dell Way	\N	RBJMLXL	\N	0	Chile	2	OWOLCNKAMV@dell.com	7201694229	1	2017955154646188	2008/05	user17183	password	52	100000	F
17184	UDMQGB	NVMPJXQWTI	4738766877 Dell Way	\N	XDUJBFQ	\N	0	Russia	2	NVMPJXQWTI@dell.com	4738766877	4	7850345068611205	2012/03	user17184	password	70	40000	F
17185	WURDVE	ZITIFJEZRC	8495700252 Dell Way	\N	CMLDSCW	\N	0	Canada	2	ZITIFJEZRC@dell.com	8495700252	4	9538523918949068	2008/05	user17185	password	35	20000	F
17186	ASIVWH	DQQJZVIRXK	9994796330 Dell Way	\N	EJNWLKZ	\N	0	Chile	2	DQQJZVIRXK@dell.com	9994796330	5	4006146228872240	2009/03	user17186	password	46	60000	F
17187	CWAZEE	PUOPQWHNHL	2998433068 Dell Way	\N	XVIJFHQ	\N	0	Chile	2	PUOPQWHNHL@dell.com	2998433068	5	5950446020346135	2009/05	user17187	password	24	60000	F
17188	YQLDUA	XIQOFXBNJZ	9172437064 Dell Way	\N	IRIOYYT	\N	0	Canada	2	XIQOFXBNJZ@dell.com	9172437064	2	6094382110983134	2009/05	user17188	password	29	80000	F
17189	UDMOEK	XUYCSAQBZY	6085962489 Dell Way	\N	SHMQGGV	\N	0	Canada	2	XUYCSAQBZY@dell.com	6085962489	2	4708222225308418	2012/07	user17189	password	27	40000	F
17190	HUWLEU	FDXXDNZCLR	5338217341 Dell Way	\N	KYHQFCU	\N	0	Russia	2	FDXXDNZCLR@dell.com	5338217341	2	7503676631953568	2008/05	user17190	password	20	40000	M
17191	VEBAYH	DVFGJEJUVU	5125017561 Dell Way	\N	TDLYFGS	\N	0	Russia	2	DVFGJEJUVU@dell.com	5125017561	3	7478702843654902	2012/06	user17191	password	20	60000	F
17192	FMHETL	AYSJCBEYWX	9628042045 Dell Way	\N	BHWGOOZ	\N	0	Australia	2	AYSJCBEYWX@dell.com	9628042045	4	8210227173287422	2010/09	user17192	password	33	80000	M
17193	RZDKKE	JCOMESKBQL	4368865586 Dell Way	\N	IMSXARX	\N	0	UK	2	JCOMESKBQL@dell.com	4368865586	4	4532984847668559	2008/11	user17193	password	24	20000	M
17194	BFZMJJ	PXVUQFVGQE	6850263044 Dell Way	\N	TIBTAYT	\N	0	China	2	PXVUQFVGQE@dell.com	6850263044	1	5527033775113524	2010/03	user17194	password	59	20000	F
17195	TDUDMK	BHERMAYDFR	3653748887 Dell Way	\N	MHLNGEX	\N	0	South Africa	2	BHERMAYDFR@dell.com	3653748887	3	4979226538911462	2010/12	user17195	password	59	100000	M
17196	SPWEZX	MEPZFNCKEP	4649639348 Dell Way	\N	RPCXUAV	\N	0	Australia	2	MEPZFNCKEP@dell.com	4649639348	2	6192412776872516	2009/10	user17196	password	45	20000	M
17197	ZZSZXE	DMDIZGTEVK	4589953089 Dell Way	\N	UYIOYDP	\N	0	China	2	DMDIZGTEVK@dell.com	4589953089	1	7429054710548372	2009/07	user17197	password	78	80000	M
17198	VLNSPQ	ETZEZSIVDC	5032971561 Dell Way	\N	TLRRPGA	\N	0	Australia	2	ETZEZSIVDC@dell.com	5032971561	4	3034963736776262	2008/07	user17198	password	89	60000	F
17199	KBBASG	URLTKTONWI	7953991370 Dell Way	\N	ZNAOUAO	\N	0	Chile	2	URLTKTONWI@dell.com	7953991370	4	3354040079750121	2009/10	user17199	password	77	80000	F
17200	XUFPBZ	HMTRGIEDQD	1598240338 Dell Way	\N	QRSLSHS	\N	0	France	2	HMTRGIEDQD@dell.com	1598240338	5	8220819686073811	2012/10	user17200	password	55	20000	M
17201	HGGIFO	VYFBHJEXNV	9202294438 Dell Way	\N	PFGHMYT	\N	0	Germany	2	VYFBHJEXNV@dell.com	9202294438	3	4520075790584088	2011/01	user17201	password	48	40000	F
17202	QPSWEN	VJOCTSAGOP	2266634298 Dell Way	\N	MVWZTPN	\N	0	Japan	2	VJOCTSAGOP@dell.com	2266634298	5	4300335624255240	2008/04	user17202	password	70	60000	M
17203	IGVMTQ	WHTPATVPJI	7438579632 Dell Way	\N	KFHEVUV	\N	0	UK	2	WHTPATVPJI@dell.com	7438579632	2	2478530855849385	2008/12	user17203	password	69	20000	F
17204	YVTRMP	ZGEAAAPJIA	2992344319 Dell Way	\N	PQELLAK	\N	0	Canada	2	ZGEAAAPJIA@dell.com	2992344319	3	2664528279565275	2008/04	user17204	password	31	60000	F
17205	AEXNTX	TYYTYODHOT	2240573507 Dell Way	\N	YSEJTON	\N	0	UK	2	TYYTYODHOT@dell.com	2240573507	4	1958884899038821	2010/11	user17205	password	55	80000	M
17206	RNLKLE	JJYIXCPLVO	2006309300 Dell Way	\N	EZXXOKW	\N	0	Japan	2	JJYIXCPLVO@dell.com	2006309300	5	1990258798468858	2012/06	user17206	password	71	100000	F
17207	HIPSNY	BMGZPWLKKQ	4622387400 Dell Way	\N	KIOYSKR	\N	0	South Africa	2	BMGZPWLKKQ@dell.com	4622387400	4	8546614702790976	2012/07	user17207	password	72	20000	M
17208	CRMQPO	DVNSRYDCPN	9173291079 Dell Way	\N	KDMDNDZ	\N	0	UK	2	DVNSRYDCPN@dell.com	9173291079	5	8557628087699414	2010/07	user17208	password	84	20000	M
17209	ORHEGL	ZTDRSGUHUE	1950544704 Dell Way	\N	KHIYKHX	\N	0	China	2	ZTDRSGUHUE@dell.com	1950544704	4	7602410958614201	2011/08	user17209	password	85	40000	F
17210	PQJVBJ	PFAILUQGZA	6466485826 Dell Way	\N	NHZYPWG	\N	0	Japan	2	PFAILUQGZA@dell.com	6466485826	5	4329683395568282	2009/11	user17210	password	69	60000	M
17211	IVJKEY	PFGBZWHZXU	9625731016 Dell Way	\N	HXTWUZP	\N	0	China	2	PFGBZWHZXU@dell.com	9625731016	5	6724078018218280	2012/08	user17211	password	24	40000	M
17212	XTJBRZ	GYAGVHGTCN	9383075175 Dell Way	\N	QVKLVZV	\N	0	Russia	2	GYAGVHGTCN@dell.com	9383075175	3	6793538807891310	2010/07	user17212	password	19	60000	F
17213	TYNLXT	JXAFFGZIUQ	3992127135 Dell Way	\N	EEBZEWT	\N	0	Australia	2	JXAFFGZIUQ@dell.com	3992127135	3	7107658319640905	2012/06	user17213	password	36	40000	F
17214	FVQCPZ	AQFFWEOQUS	8648186894 Dell Way	\N	VVRZSLC	\N	0	Australia	2	AQFFWEOQUS@dell.com	8648186894	4	9366012432612480	2009/01	user17214	password	36	60000	F
17215	CBISBI	IHOELCVGVR	5770747567 Dell Way	\N	CMRVYTW	\N	0	Russia	2	IHOELCVGVR@dell.com	5770747567	4	1626774629577994	2010/01	user17215	password	56	80000	F
17216	PBVRKE	YYIKBERWWT	3122533410 Dell Way	\N	JNOHHLC	\N	0	South Africa	2	YYIKBERWWT@dell.com	3122533410	1	4305900499690324	2009/09	user17216	password	27	60000	F
17217	FHYPLX	OUHPZZLVSU	4261467871 Dell Way	\N	JHCQTFM	\N	0	UK	2	OUHPZZLVSU@dell.com	4261467871	5	3410317426547408	2008/12	user17217	password	69	40000	F
17218	ZHTKEH	EMWDLIZEDI	3374163457 Dell Way	\N	MFZGKLF	\N	0	Russia	2	EMWDLIZEDI@dell.com	3374163457	3	8518708338029683	2009/03	user17218	password	30	40000	F
17219	LCOQKT	DGXPPWTSFG	2607689424 Dell Way	\N	YEMJPSD	\N	0	South Africa	2	DGXPPWTSFG@dell.com	2607689424	5	1844747488386929	2009/02	user17219	password	51	60000	M
17220	PCGZVJ	GTYVPSNVZL	9094145243 Dell Way	\N	ZLUPDYM	\N	0	China	2	GTYVPSNVZL@dell.com	9094145243	3	7207709615118802	2008/01	user17220	password	33	80000	M
17221	HWPDFV	WEQMXEHWQG	9238232393 Dell Way	\N	HLWLJIU	\N	0	Chile	2	WEQMXEHWQG@dell.com	9238232393	3	3634305788669735	2012/09	user17221	password	85	60000	M
17222	UDCAZY	FQKCURYKYG	9714354094 Dell Way	\N	VVSFEML	\N	0	Australia	2	FQKCURYKYG@dell.com	9714354094	4	1314183126203715	2011/09	user17222	password	61	80000	F
17223	TSMSRR	IBUDTSOSYK	8002277599 Dell Way	\N	NRPSEAU	\N	0	Canada	2	IBUDTSOSYK@dell.com	8002277599	5	7972920805215836	2010/06	user17223	password	47	100000	F
17224	CKXUCF	VWJPOXHNIV	2234025220 Dell Way	\N	FXNJYIM	\N	0	Russia	2	VWJPOXHNIV@dell.com	2234025220	2	2394135388080030	2010/08	user17224	password	22	80000	M
17225	MPNOVJ	KFZZCHNKCS	8146620216 Dell Way	\N	IQBGYOY	\N	0	Australia	2	KFZZCHNKCS@dell.com	8146620216	1	6770787481218577	2010/03	user17225	password	44	40000	M
17226	ZTEUCP	ACOCJCNLVW	2504014435 Dell Way	\N	CWCAKBD	\N	0	Chile	2	ACOCJCNLVW@dell.com	2504014435	4	6919243911281229	2009/02	user17226	password	80	100000	F
17227	PEXSTX	UIADLOPGKS	6516736492 Dell Way	\N	DNSNOWT	\N	0	Russia	2	UIADLOPGKS@dell.com	6516736492	3	1601390081923455	2011/04	user17227	password	21	100000	M
17228	FSPZPK	HQOTEDZOVC	8079248645 Dell Way	\N	BOQQLJJ	\N	0	Australia	2	HQOTEDZOVC@dell.com	8079248645	3	7969472720753402	2008/06	user17228	password	61	100000	M
17229	INQYXY	OLRSPRHLTJ	7741229021 Dell Way	\N	AJZLTIM	\N	0	Germany	2	OLRSPRHLTJ@dell.com	7741229021	2	6389547243714333	2009/11	user17229	password	56	100000	F
17230	BNDYMR	KEKAVRMPBM	7142865527 Dell Way	\N	ZAYSJKG	\N	0	Canada	2	KEKAVRMPBM@dell.com	7142865527	5	3931373496074230	2010/05	user17230	password	33	80000	F
17231	TWKFNU	KYVGQHVRUU	6485063221 Dell Way	\N	SSMBDTE	\N	0	South Africa	2	KYVGQHVRUU@dell.com	6485063221	3	4261071533430368	2012/09	user17231	password	24	60000	F
17232	YVRMQC	KLIATDRNYJ	2059597296 Dell Way	\N	GKLJEPE	\N	0	Russia	2	KLIATDRNYJ@dell.com	2059597296	3	8025127816013993	2012/08	user17232	password	33	40000	M
17233	AZBRBL	DKLWODJMMP	7346114198 Dell Way	\N	XYZBOEW	\N	0	Japan	2	DKLWODJMMP@dell.com	7346114198	4	5466124999336899	2009/11	user17233	password	75	100000	M
17234	UZOVKR	GVNUYXGLND	7197690546 Dell Way	\N	JMFYQBP	\N	0	China	2	GVNUYXGLND@dell.com	7197690546	1	7249886090401561	2010/11	user17234	password	62	60000	M
17235	OYMZPT	VDNUBTFOXP	2869946090 Dell Way	\N	BCNREDB	\N	0	South Africa	2	VDNUBTFOXP@dell.com	2869946090	4	4437112329062075	2008/05	user17235	password	75	80000	M
17236	TFXJYS	MMMNFSCDHD	6277399512 Dell Way	\N	GVVKYWG	\N	0	Canada	2	MMMNFSCDHD@dell.com	6277399512	4	3210557605139911	2012/06	user17236	password	89	100000	F
17237	FTNDLA	QYOVQQZYTF	5352715485 Dell Way	\N	UOPSLWX	\N	0	Australia	2	QYOVQQZYTF@dell.com	5352715485	1	9536086054984480	2012/02	user17237	password	76	20000	F
17238	OPMAPC	YDYPUXOOCI	1632396937 Dell Way	\N	DSBOOYO	\N	0	Australia	2	YDYPUXOOCI@dell.com	1632396937	3	9624791044741870	2008/04	user17238	password	19	60000	M
17239	PYXFAW	JYLDWZRZIU	4786131118 Dell Way	\N	RJJGHXI	\N	0	China	2	JYLDWZRZIU@dell.com	4786131118	2	5873653412330896	2011/04	user17239	password	20	80000	M
17240	ZNCAJM	ZVPWVHVDCN	4132868874 Dell Way	\N	MLTTJCD	\N	0	Russia	2	ZVPWVHVDCN@dell.com	4132868874	4	5569084458984435	2011/09	user17240	password	26	60000	M
17241	QRSZDS	VTOQAJTDWG	8170030189 Dell Way	\N	OQAXSDR	\N	0	Australia	2	VTOQAJTDWG@dell.com	8170030189	1	7450700866524131	2010/04	user17241	password	37	20000	M
17242	YXYBQT	UEJVODZLJN	3852705910 Dell Way	\N	CJLVMDX	\N	0	Chile	2	UEJVODZLJN@dell.com	3852705910	4	8129280879627914	2011/11	user17242	password	90	60000	M
17243	XNWNGR	SQNHTMTDAV	2529793620 Dell Way	\N	MLRZOOH	\N	0	South Africa	2	SQNHTMTDAV@dell.com	2529793620	1	5622263925615699	2008/01	user17243	password	24	100000	M
17244	PSMVKF	MXNGKGJKCW	2637964733 Dell Way	\N	VTVKICH	\N	0	France	2	MXNGKGJKCW@dell.com	2637964733	5	5757432725746185	2009/11	user17244	password	46	40000	F
17245	CSINYU	LLAVSJFUFB	6147443753 Dell Way	\N	OBMWETI	\N	0	China	2	LLAVSJFUFB@dell.com	6147443753	5	6373139638919384	2010/03	user17245	password	76	100000	F
17246	NGWLBI	WCDOMJJRLX	9413397724 Dell Way	\N	TXTYRBH	\N	0	Chile	2	WCDOMJJRLX@dell.com	9413397724	5	7394948905799539	2008/09	user17246	password	65	60000	F
17247	XKQZSM	BWBNFLFRIY	1494112730 Dell Way	\N	OBXGDEM	\N	0	Australia	2	BWBNFLFRIY@dell.com	1494112730	2	3356224307324737	2011/11	user17247	password	76	100000	M
17248	FOTXBU	UDHZOMRWLF	2532279051 Dell Way	\N	YIMCNZE	\N	0	Germany	2	UDHZOMRWLF@dell.com	2532279051	3	3664690141566098	2008/03	user17248	password	34	80000	F
17249	UNJVID	ZPDNCUKNAJ	1680919108 Dell Way	\N	WMLJLQX	\N	0	Japan	2	ZPDNCUKNAJ@dell.com	1680919108	2	6892967579420657	2009/06	user17249	password	50	80000	F
17250	ZDBHHA	XKOZFYNGHJ	8920383676 Dell Way	\N	TTTEJRV	\N	0	France	2	XKOZFYNGHJ@dell.com	8920383676	3	7843401571270079	2009/12	user17250	password	56	60000	M
17251	QQEYQB	IEBODOULYN	1079606303 Dell Way	\N	ERSNINZ	\N	0	Chile	2	IEBODOULYN@dell.com	1079606303	4	5823648042511195	2012/04	user17251	password	24	100000	M
17252	SAVJCE	ODTRRNCPBG	5413588018 Dell Way	\N	HUUPITV	\N	0	China	2	ODTRRNCPBG@dell.com	5413588018	2	3254056090954691	2011/06	user17252	password	23	80000	F
17253	CMNERB	IKSZYVPZCX	7195247363 Dell Way	\N	TWNCQIK	\N	0	Canada	2	IKSZYVPZCX@dell.com	7195247363	4	8800397763494403	2008/09	user17253	password	56	40000	M
17254	AUARVI	COIAKXAMUU	9164257579 Dell Way	\N	JIWZQGC	\N	0	China	2	COIAKXAMUU@dell.com	9164257579	5	5165830816607923	2011/06	user17254	password	73	60000	F
17255	OMEKUG	YCHJAHVVBE	2976315275 Dell Way	\N	DXDTEGC	\N	0	Australia	2	YCHJAHVVBE@dell.com	2976315275	3	7510422366671265	2011/04	user17255	password	31	40000	M
17256	QJGLQF	NXONFJIGOL	8416505906 Dell Way	\N	ESFJZHL	\N	0	Canada	2	NXONFJIGOL@dell.com	8416505906	1	9003714038990439	2008/05	user17256	password	24	100000	F
17257	MFLCKY	AZMFJUMXGQ	6613295187 Dell Way	\N	PLAOSLT	\N	0	Germany	2	AZMFJUMXGQ@dell.com	6613295187	4	6907945105805994	2012/09	user17257	password	63	100000	F
17258	VKIGJI	FVOOPAMVRC	1552523481 Dell Way	\N	HRQZDKN	\N	0	Russia	2	FVOOPAMVRC@dell.com	1552523481	1	7641757594421507	2012/10	user17258	password	70	20000	M
17259	DIXMRC	IGRXGDTYFA	7434102481 Dell Way	\N	PWATGON	\N	0	China	2	IGRXGDTYFA@dell.com	7434102481	2	2183483652304858	2010/12	user17259	password	28	20000	F
17260	MAPEDX	KUVQXPPDQE	7241121943 Dell Way	\N	ZQYGELO	\N	0	South Africa	2	KUVQXPPDQE@dell.com	7241121943	4	4696568316314370	2011/11	user17260	password	59	80000	F
17261	PINTGX	NBOLQDOGIO	1441649083 Dell Way	\N	XGUBSJY	\N	0	China	2	NBOLQDOGIO@dell.com	1441649083	2	1522485569585114	2012/12	user17261	password	77	40000	M
17262	DTHJQU	LEGBIVHQJE	6278075965 Dell Way	\N	XDGPMFZ	\N	0	Germany	2	LEGBIVHQJE@dell.com	6278075965	1	4968090593814850	2010/11	user17262	password	67	20000	F
17263	KIKADV	FKWNFEDPJA	7075718327 Dell Way	\N	SPQFVQT	\N	0	France	2	FKWNFEDPJA@dell.com	7075718327	2	9439092641230674	2010/11	user17263	password	90	60000	F
17264	IYIMTN	WQBBVFQEFJ	6087374881 Dell Way	\N	UWPQMJA	\N	0	Canada	2	WQBBVFQEFJ@dell.com	6087374881	5	7251107895281167	2010/12	user17264	password	35	80000	F
17265	EBTYOP	PPRKUIOASJ	9699810683 Dell Way	\N	XHZJRZN	\N	0	Chile	2	PPRKUIOASJ@dell.com	9699810683	2	7038018588908017	2012/06	user17265	password	46	40000	M
17266	LZPAPE	QHOKPDLHMJ	5297681937 Dell Way	\N	PLSHLGN	\N	0	France	2	QHOKPDLHMJ@dell.com	5297681937	1	4153838447295129	2012/07	user17266	password	59	80000	F
17267	OFADKQ	KZBACMIPWY	8898418874 Dell Way	\N	BOFNVSX	\N	0	China	2	KZBACMIPWY@dell.com	8898418874	2	3237246251199394	2010/11	user17267	password	80	60000	F
17268	BLOLBY	KDZNQHDMFE	8799914693 Dell Way	\N	BLRWDPE	\N	0	Australia	2	KDZNQHDMFE@dell.com	8799914693	3	5144960619509220	2011/04	user17268	password	84	20000	F
17269	JRTLPE	OPSEWVQCZR	2114855353 Dell Way	\N	ORORGSS	\N	0	Canada	2	OPSEWVQCZR@dell.com	2114855353	1	8561293322127313	2009/01	user17269	password	87	80000	F
17270	PMWFRL	VJPREGUEYI	8755919332 Dell Way	\N	WMACESG	\N	0	China	2	VJPREGUEYI@dell.com	8755919332	1	7300199775956572	2012/01	user17270	password	47	40000	M
17271	XFWOQR	XGJCMEHKND	6053344334 Dell Way	\N	XNGCFMK	\N	0	Australia	2	XGJCMEHKND@dell.com	6053344334	1	1142018981743603	2010/07	user17271	password	44	40000	F
17272	PCYFUW	MDZYIGJVKH	8727552948 Dell Way	\N	IQJODTR	\N	0	Japan	2	MDZYIGJVKH@dell.com	8727552948	4	3499170264694840	2009/01	user17272	password	55	80000	M
17273	PSVJOI	NNGVUQQEXZ	9027233684 Dell Way	\N	VHOYAFQ	\N	0	South Africa	2	NNGVUQQEXZ@dell.com	9027233684	5	3357679057866335	2012/05	user17273	password	19	60000	F
17274	SKKHSY	VZTPPKUNKP	1388653167 Dell Way	\N	UZNVEDT	\N	0	Australia	2	VZTPPKUNKP@dell.com	1388653167	5	1057527763303369	2010/01	user17274	password	58	60000	M
17275	YWBRUW	QOLGZGUKVP	2355436312 Dell Way	\N	JIKNMDP	\N	0	Germany	2	QOLGZGUKVP@dell.com	2355436312	4	9787726148031652	2008/03	user17275	password	50	100000	F
17276	IYUDVL	RHSRNMBIBK	2707291249 Dell Way	\N	RMYDQOR	\N	0	Russia	2	RHSRNMBIBK@dell.com	2707291249	4	9451237373519690	2009/02	user17276	password	80	60000	F
17277	VIOQTG	XLXLXZTZKK	8844797580 Dell Way	\N	LJOBYFV	\N	0	Canada	2	XLXLXZTZKK@dell.com	8844797580	4	5379770907107741	2012/08	user17277	password	90	40000	F
17278	IXBBDZ	NBKLAEKKPV	5000082004 Dell Way	\N	UEWSKRV	\N	0	Chile	2	NBKLAEKKPV@dell.com	5000082004	2	3021107214502990	2008/04	user17278	password	61	60000	M
17279	NORROF	SZQTDAETWY	8103684605 Dell Way	\N	XTQHLMO	\N	0	South Africa	2	SZQTDAETWY@dell.com	8103684605	4	9430293629411608	2008/05	user17279	password	49	80000	M
17280	ZKONPH	NFARGFKDDI	9578998268 Dell Way	\N	WUPHHEE	\N	0	Australia	2	NFARGFKDDI@dell.com	9578998268	1	2386605890933424	2009/07	user17280	password	81	40000	M
17281	GVBVCO	BDGIIQLLYI	9300900748 Dell Way	\N	GOQNSUO	\N	0	Japan	2	BDGIIQLLYI@dell.com	9300900748	4	1165895767509937	2010/08	user17281	password	36	20000	M
17282	BBREQT	HWBPNNBMVH	1861944056 Dell Way	\N	ALUTGJL	\N	0	Canada	2	HWBPNNBMVH@dell.com	1861944056	3	6715544788166881	2011/09	user17282	password	64	60000	M
17283	SFYJYF	FAUTOVFJDF	8532530867 Dell Way	\N	UYZBHKF	\N	0	China	2	FAUTOVFJDF@dell.com	8532530867	5	1667452236171811	2010/06	user17283	password	61	40000	F
17284	VGOULT	UGNICSSFYN	6700068236 Dell Way	\N	DXOLHUV	\N	0	Canada	2	UGNICSSFYN@dell.com	6700068236	5	6949405456427485	2008/06	user17284	password	89	40000	F
17285	FWCRPX	XDFAVYFTLJ	5474138069 Dell Way	\N	QAUXUPA	\N	0	France	2	XDFAVYFTLJ@dell.com	5474138069	4	5836807399988175	2012/09	user17285	password	80	40000	M
17286	SKOIHM	LMMGLSZWBQ	3593871441 Dell Way	\N	WVOQLPB	\N	0	UK	2	LMMGLSZWBQ@dell.com	3593871441	4	9383262728806586	2012/06	user17286	password	35	100000	F
17287	QKMXWX	KJEVBERCUO	8824448934 Dell Way	\N	YJFKYGI	\N	0	Chile	2	KJEVBERCUO@dell.com	8824448934	2	2693893418181687	2009/06	user17287	password	20	60000	F
17288	LYAIWK	RAFTEXWZLU	7887019872 Dell Way	\N	IQEHXNN	\N	0	Russia	2	RAFTEXWZLU@dell.com	7887019872	4	1893976605962962	2009/09	user17288	password	60	40000	F
17289	NJNKUE	KZXPWTPIOY	4743014126 Dell Way	\N	YTFWGSQ	\N	0	Australia	2	KZXPWTPIOY@dell.com	4743014126	4	3438604828435928	2008/04	user17289	password	64	40000	M
17290	AVGUAR	UYHQSWZGVY	2631490953 Dell Way	\N	ZAUGTLG	\N	0	Canada	2	UYHQSWZGVY@dell.com	2631490953	3	3910425376612693	2010/03	user17290	password	65	40000	F
17291	MPZMHT	KOKCLKJGIJ	4580527677 Dell Way	\N	HDPBOWF	\N	0	Russia	2	KOKCLKJGIJ@dell.com	4580527677	3	3158908565063029	2010/03	user17291	password	61	80000	M
17292	FTDMNO	AXRLHASQJA	8654690492 Dell Way	\N	TZBHWHB	\N	0	Chile	2	AXRLHASQJA@dell.com	8654690492	2	8364786886144430	2008/11	user17292	password	60	80000	F
17293	IWOVLO	TCABCTRMTL	1449796422 Dell Way	\N	MVTICUO	\N	0	UK	2	TCABCTRMTL@dell.com	1449796422	2	1114491529297083	2012/12	user17293	password	71	100000	F
17294	PNDACW	DDYFWQSPBE	4718000964 Dell Way	\N	KUMNOAM	\N	0	Japan	2	DDYFWQSPBE@dell.com	4718000964	3	5862752634100617	2009/03	user17294	password	56	80000	M
17295	BUWERZ	HPFDFXTHCD	7032755847 Dell Way	\N	CORRPEH	\N	0	Australia	2	HPFDFXTHCD@dell.com	7032755847	5	4439273858442903	2012/05	user17295	password	20	80000	F
17296	VQOMQW	BWZHUSPWWR	4768057710 Dell Way	\N	KOIASPA	\N	0	China	2	BWZHUSPWWR@dell.com	4768057710	3	3602406947407872	2011/06	user17296	password	21	20000	F
17297	RTTIPV	EODYHSUDKF	7111299250 Dell Way	\N	RTGKJGU	\N	0	Russia	2	EODYHSUDKF@dell.com	7111299250	1	5806771432515234	2008/02	user17297	password	69	60000	M
17298	LECBZG	PDFXWZBGFT	9849854226 Dell Way	\N	ALDJSXD	\N	0	China	2	PDFXWZBGFT@dell.com	9849854226	4	5717195806093514	2008/05	user17298	password	85	100000	M
17299	CZWBGM	ELJBKKHQDH	4872243480 Dell Way	\N	BHQUFUE	\N	0	Canada	2	ELJBKKHQDH@dell.com	4872243480	4	3506110036280006	2011/08	user17299	password	29	80000	M
17300	DMUJYZ	VIAFTIWXPY	6338323032 Dell Way	\N	FGSKAXO	\N	0	France	2	VIAFTIWXPY@dell.com	6338323032	5	3351454296149313	2009/01	user17300	password	81	100000	F
17301	JTNISI	QTOKBKHRJM	3809144133 Dell Way	\N	YBWZYLL	\N	0	Germany	2	QTOKBKHRJM@dell.com	3809144133	4	7912777892313898	2009/07	user17301	password	69	60000	M
17302	LAGEJW	XYGZJOQSBO	7032278636 Dell Way	\N	TYOSKZG	\N	0	Russia	2	XYGZJOQSBO@dell.com	7032278636	1	1397582652047276	2009/09	user17302	password	56	20000	F
17303	OKJXHG	WOFFCWXELR	7001971107 Dell Way	\N	CZKNYQG	\N	0	Japan	2	WOFFCWXELR@dell.com	7001971107	2	8761228287592531	2010/10	user17303	password	20	60000	F
17304	LYHSFD	GLIJHGNSXQ	7034065792 Dell Way	\N	SHDQYKH	\N	0	Japan	2	GLIJHGNSXQ@dell.com	7034065792	1	1034002363681793	2010/02	user17304	password	61	100000	M
17305	NCHTGN	EOWLUKERAW	9496023227 Dell Way	\N	ZENXOUN	\N	0	Chile	2	EOWLUKERAW@dell.com	9496023227	3	7479823265224696	2008/02	user17305	password	58	80000	M
17306	RZJXNN	LKZGUEYVBX	8790431311 Dell Way	\N	ZOVOJJU	\N	0	China	2	LKZGUEYVBX@dell.com	8790431311	3	4916088608559221	2012/02	user17306	password	27	80000	M
17307	DZRQNC	ANJVRHQSFQ	5741293186 Dell Way	\N	HAFRJAA	\N	0	Chile	2	ANJVRHQSFQ@dell.com	5741293186	3	2990722069516778	2011/07	user17307	password	79	40000	M
17308	VAIJDJ	XMFOTVHZMP	7553690178 Dell Way	\N	ARHJRHQ	\N	0	Chile	2	XMFOTVHZMP@dell.com	7553690178	5	8296713653486223	2009/09	user17308	password	30	20000	M
17309	FJXISU	UYJOTROGGO	4594513406 Dell Way	\N	XNYPVOU	\N	0	Germany	2	UYJOTROGGO@dell.com	4594513406	3	8622649222146721	2008/10	user17309	password	80	80000	M
17310	FNHYHC	WRRQIFWOTU	7684272954 Dell Way	\N	CRJXGDL	\N	0	Japan	2	WRRQIFWOTU@dell.com	7684272954	2	7539326240774245	2010/02	user17310	password	42	60000	F
17311	WTHEWD	VNUDTQSMKV	5321193063 Dell Way	\N	EUSKXEB	\N	0	Japan	2	VNUDTQSMKV@dell.com	5321193063	4	2600007947068661	2011/02	user17311	password	65	100000	M
17312	KHDHLZ	UFCOVVBGQF	5485611218 Dell Way	\N	AJQYOSQ	\N	0	Australia	2	UFCOVVBGQF@dell.com	5485611218	4	6921098830644042	2011/06	user17312	password	65	80000	M
17313	YTDJSY	OVNKQORHUR	1464395095 Dell Way	\N	QKQFDGF	\N	0	Japan	2	OVNKQORHUR@dell.com	1464395095	5	3292101046536118	2010/07	user17313	password	81	40000	F
17314	QNVJMK	EZUVNLDHDU	1611782543 Dell Way	\N	SUZVBEM	\N	0	Canada	2	EZUVNLDHDU@dell.com	1611782543	4	6457598318811507	2010/08	user17314	password	89	20000	F
17315	MWOZHT	YBOMNSURMM	5809739761 Dell Way	\N	MLIOQVQ	\N	0	Russia	2	YBOMNSURMM@dell.com	5809739761	2	3690491278190166	2008/03	user17315	password	44	40000	M
17316	GXSNQR	PFEDYYVKLH	7661483188 Dell Way	\N	VUVMPME	\N	0	Canada	2	PFEDYYVKLH@dell.com	7661483188	3	3301488019526005	2012/11	user17316	password	61	80000	F
17317	NKPEBE	KGIIEDSQLO	7135365429 Dell Way	\N	KHAZTFD	\N	0	Germany	2	KGIIEDSQLO@dell.com	7135365429	2	5305904014967382	2010/12	user17317	password	30	60000	F
17318	PEQRJA	XRIBVBRGPC	6358537315 Dell Way	\N	NQCHVFV	\N	0	Germany	2	XRIBVBRGPC@dell.com	6358537315	2	1278764413669705	2010/06	user17318	password	63	20000	F
17319	VSSETP	WCRRDJYTLM	8993198291 Dell Way	\N	JNUFTPS	\N	0	China	2	WCRRDJYTLM@dell.com	8993198291	4	9204377111047508	2009/05	user17319	password	89	60000	F
17320	RDJLSG	NKXRTWLEIU	5433689393 Dell Way	\N	SCALSTU	\N	0	Germany	2	NKXRTWLEIU@dell.com	5433689393	4	9584280426613988	2012/09	user17320	password	44	20000	F
17321	MLUFRI	POAILLNTGF	2236729759 Dell Way	\N	WGRPZLE	\N	0	France	2	POAILLNTGF@dell.com	2236729759	1	4165986704174429	2012/06	user17321	password	47	20000	M
17322	VZEMHT	BICMTPGZVD	1284792527 Dell Way	\N	GMSFYXS	\N	0	Australia	2	BICMTPGZVD@dell.com	1284792527	1	8850227968301625	2010/06	user17322	password	21	60000	F
17323	ARUILW	QOJJDQJZTP	6236853380 Dell Way	\N	LMVJJNL	\N	0	France	2	QOJJDQJZTP@dell.com	6236853380	2	9439665221609176	2008/05	user17323	password	50	40000	F
17324	DDROAH	DJRGABFTQR	8087885794 Dell Way	\N	GMBQZMA	\N	0	Germany	2	DJRGABFTQR@dell.com	8087885794	5	6581284783314914	2008/06	user17324	password	88	60000	M
17325	DEDDMG	NEMNFSHWKO	2636951688 Dell Way	\N	ILEIXFW	\N	0	Japan	2	NEMNFSHWKO@dell.com	2636951688	3	8539727062452585	2010/06	user17325	password	42	20000	M
17326	NGTAMG	EZUKSBGCQP	3530717803 Dell Way	\N	OUXLZUE	\N	0	Canada	2	EZUKSBGCQP@dell.com	3530717803	5	7985142248682679	2011/04	user17326	password	85	40000	M
17327	ECWRIB	RDLKFSNVHB	6865856355 Dell Way	\N	PENPYRU	\N	0	Chile	2	RDLKFSNVHB@dell.com	6865856355	3	9875553816556932	2012/06	user17327	password	42	100000	M
17328	LSIUTA	XEKCWXXEZN	4782834230 Dell Way	\N	IMCHDWN	\N	0	Russia	2	XEKCWXXEZN@dell.com	4782834230	3	7917151468805970	2012/11	user17328	password	62	60000	F
17329	HWBBWY	FHACFYGELP	8859918525 Dell Way	\N	QOWUKJO	\N	0	South Africa	2	FHACFYGELP@dell.com	8859918525	2	7481071774847806	2011/12	user17329	password	36	100000	F
17330	DAHAYN	HZQNXXRIMI	1251406677 Dell Way	\N	WJDHTRD	\N	0	Japan	2	HZQNXXRIMI@dell.com	1251406677	5	3902043041773141	2012/02	user17330	password	39	40000	F
17331	HNGGAO	FQBDNTMACJ	6560542577 Dell Way	\N	JFQDXUT	\N	0	UK	2	FQBDNTMACJ@dell.com	6560542577	1	9090691476594658	2011/05	user17331	password	26	100000	M
17332	PFXQTD	HVGUOSVQBF	1988111292 Dell Way	\N	WSITMBS	\N	0	Canada	2	HVGUOSVQBF@dell.com	1988111292	3	8439549305010588	2010/09	user17332	password	75	20000	F
17333	ZAYTDF	OKADDVTEBQ	7109503247 Dell Way	\N	XJKKKCM	\N	0	Germany	2	OKADDVTEBQ@dell.com	7109503247	2	9835498817730696	2009/02	user17333	password	25	80000	F
17334	DRVGWJ	RXMUTGZUXW	1632668067 Dell Way	\N	EHGOJTC	\N	0	Australia	2	RXMUTGZUXW@dell.com	1632668067	1	4913242311216891	2008/02	user17334	password	28	40000	F
17335	UCORMF	PYAIFZDCWH	1110744332 Dell Way	\N	KCWUWYV	\N	0	UK	2	PYAIFZDCWH@dell.com	1110744332	2	1950632529798895	2008/05	user17335	password	44	60000	F
17336	LAWXGL	WGUCFYFCFQ	5257574594 Dell Way	\N	ECKBAFZ	\N	0	Australia	2	WGUCFYFCFQ@dell.com	5257574594	1	3028683411423117	2012/06	user17336	password	68	20000	M
17337	SYVYKS	FEVLDBNJRS	8676381948 Dell Way	\N	LBUMGTN	\N	0	Russia	2	FEVLDBNJRS@dell.com	8676381948	4	6476629073731602	2009/06	user17337	password	66	40000	F
17338	PBDZUI	EPUHQHRHAC	8723293583 Dell Way	\N	IUPPOCJ	\N	0	China	2	EPUHQHRHAC@dell.com	8723293583	5	7356761474628002	2009/08	user17338	password	86	60000	F
17339	ZOFUXK	JRSAZJHZMQ	5978545210 Dell Way	\N	TBGHEPS	\N	0	Australia	2	JRSAZJHZMQ@dell.com	5978545210	3	3962717560119927	2008/05	user17339	password	75	60000	F
17340	JQCGBM	YTMXDTXPKR	1635938170 Dell Way	\N	RQZWGRW	\N	0	South Africa	2	YTMXDTXPKR@dell.com	1635938170	2	9852687024977060	2010/12	user17340	password	46	80000	F
17341	AVQCIO	VUMZOJPYAG	2739773387 Dell Way	\N	PZCWRZR	\N	0	Russia	2	VUMZOJPYAG@dell.com	2739773387	4	2295028510969132	2008/01	user17341	password	82	60000	F
17342	SEDBSZ	VEZJOOIPVY	1693648613 Dell Way	\N	PYUGXLZ	\N	0	Canada	2	VEZJOOIPVY@dell.com	1693648613	1	3658290910534561	2008/01	user17342	password	78	20000	M
17343	ZIUSIP	WHZLWHARFP	9642136337 Dell Way	\N	PZWNLVQ	\N	0	Germany	2	WHZLWHARFP@dell.com	9642136337	5	6615516580641270	2012/09	user17343	password	77	80000	M
17344	DMLMCI	TBTQJUHOJW	9309267438 Dell Way	\N	OGKZBAN	\N	0	Australia	2	TBTQJUHOJW@dell.com	9309267438	1	9979759049136192	2011/12	user17344	password	69	60000	F
17345	FVOHEI	JXYSSFGCCV	5246293989 Dell Way	\N	IMVJMIK	\N	0	France	2	JXYSSFGCCV@dell.com	5246293989	3	1827612179331481	2010/02	user17345	password	54	60000	F
17346	IBPNKY	LIQDOXFRTN	7418395385 Dell Way	\N	EPXRXIC	\N	0	China	2	LIQDOXFRTN@dell.com	7418395385	1	8245580276474357	2012/09	user17346	password	40	20000	F
17347	JSNTRZ	CICRGHJZVN	4888986231 Dell Way	\N	OTEMBGW	\N	0	Russia	2	CICRGHJZVN@dell.com	4888986231	4	6266360214911402	2008/12	user17347	password	70	20000	F
17348	LRDDQF	LSXRAGRWUG	3499323301 Dell Way	\N	PYSQFPK	\N	0	Japan	2	LSXRAGRWUG@dell.com	3499323301	5	7782801157329232	2009/09	user17348	password	82	80000	F
17349	NTHDZS	WWKWDBTXHI	4139344644 Dell Way	\N	WAZCQJT	\N	0	South Africa	2	WWKWDBTXHI@dell.com	4139344644	3	2467017205432057	2008/05	user17349	password	75	40000	M
17350	NMBNFX	JPUNRNKZWH	6349538056 Dell Way	\N	AVJQFCN	\N	0	Germany	2	JPUNRNKZWH@dell.com	6349538056	4	6359878005459905	2012/06	user17350	password	76	100000	F
17351	HXNMVW	CQKUEVTACU	6642009706 Dell Way	\N	WMKBPYP	\N	0	Canada	2	CQKUEVTACU@dell.com	6642009706	1	2311223772820085	2008/12	user17351	password	18	20000	F
17352	XQTSNV	JXPNSJNVDJ	2682482965 Dell Way	\N	IOKXMAC	\N	0	Canada	2	JXPNSJNVDJ@dell.com	2682482965	2	2866622800473124	2008/03	user17352	password	41	60000	F
17353	YEWLAF	IPSBZGWCQF	4744123676 Dell Way	\N	QACDAEF	\N	0	Chile	2	IPSBZGWCQF@dell.com	4744123676	3	4519368890207261	2011/09	user17353	password	77	80000	M
17354	ZRDZXM	PQNOWKRMPI	1787911169 Dell Way	\N	NSLOXRU	\N	0	China	2	PQNOWKRMPI@dell.com	1787911169	1	9637522229459138	2012/12	user17354	password	73	60000	M
17355	LRZIDO	YRDVCVISDV	3974329224 Dell Way	\N	KOKIFEQ	\N	0	China	2	YRDVCVISDV@dell.com	3974329224	3	2339199698995799	2009/05	user17355	password	67	40000	M
17356	IHCMWB	DZWGVEZYAJ	9024245452 Dell Way	\N	NKSTOIB	\N	0	South Africa	2	DZWGVEZYAJ@dell.com	9024245452	1	2954101635143161	2009/11	user17356	password	55	100000	F
17357	UCRQDV	QACLFBKFLX	8761105651 Dell Way	\N	QDQFLRC	\N	0	China	2	QACLFBKFLX@dell.com	8761105651	2	5994203410577030	2011/10	user17357	password	58	100000	M
17358	QQGULX	UNJAPTFAQW	4991004445 Dell Way	\N	DHBOYDX	\N	0	South Africa	2	UNJAPTFAQW@dell.com	4991004445	3	5820148656610400	2009/01	user17358	password	52	100000	M
17359	CDLNBG	BKGRDMRUIU	7383653386 Dell Way	\N	BJJANGV	\N	0	UK	2	BKGRDMRUIU@dell.com	7383653386	2	3008148285094648	2011/10	user17359	password	25	40000	M
17360	GULIAN	SHEWTVRCQT	9276996042 Dell Way	\N	MATZGOY	\N	0	UK	2	SHEWTVRCQT@dell.com	9276996042	1	7142145425546915	2011/04	user17360	password	20	80000	M
17361	VCVWQO	DUKXQCZHVL	5590136656 Dell Way	\N	HOLODJN	\N	0	Australia	2	DUKXQCZHVL@dell.com	5590136656	1	8192975653335453	2011/03	user17361	password	51	40000	F
17362	ODXERB	ZCZPEYWAKD	4558562216 Dell Way	\N	PVRSEFT	\N	0	Japan	2	ZCZPEYWAKD@dell.com	4558562216	3	5206757939886302	2011/01	user17362	password	73	80000	M
17363	XPTORS	RQIVPFWZJL	5319427369 Dell Way	\N	VBDAGXS	\N	0	Japan	2	RQIVPFWZJL@dell.com	5319427369	1	3407311349175870	2010/12	user17363	password	87	20000	M
17364	OVJGOA	WWWMBTLKEH	2277791110 Dell Way	\N	LHHSFZI	\N	0	Japan	2	WWWMBTLKEH@dell.com	2277791110	4	2772568727377802	2008/07	user17364	password	37	100000	F
17365	CGJQHG	NESOXEZBML	2042794258 Dell Way	\N	JTEPSNH	\N	0	South Africa	2	NESOXEZBML@dell.com	2042794258	3	9362938206177206	2011/10	user17365	password	77	100000	M
17366	BFMJLA	NEOLJONVAW	3159213087 Dell Way	\N	PEMHRTE	\N	0	Russia	2	NEOLJONVAW@dell.com	3159213087	1	5321857563685626	2012/11	user17366	password	40	100000	M
17367	NIIZIW	DXHNMVJNSY	5374491288 Dell Way	\N	REGJYKD	\N	0	Canada	2	DXHNMVJNSY@dell.com	5374491288	4	2511241995729506	2009/12	user17367	password	19	40000	F
17368	JRKSOO	PWBCRLPJJH	4801244540 Dell Way	\N	OPQMAUQ	\N	0	France	2	PWBCRLPJJH@dell.com	4801244540	5	8934354184195400	2009/11	user17368	password	35	80000	F
17369	XFXLTN	HVPZGFIQMW	8489659511 Dell Way	\N	GCJGXAT	\N	0	China	2	HVPZGFIQMW@dell.com	8489659511	4	7132362633943558	2011/11	user17369	password	52	100000	M
17370	RTGKGN	GVNMAWDNTJ	9929552081 Dell Way	\N	QCPNCJW	\N	0	UK	2	GVNMAWDNTJ@dell.com	9929552081	3	6462122312746943	2012/01	user17370	password	51	80000	M
17371	FWCLKI	HXVITYVMHM	4401734817 Dell Way	\N	PXZSHVQ	\N	0	Chile	2	HXVITYVMHM@dell.com	4401734817	2	2098511027637869	2009/09	user17371	password	73	20000	M
17372	QEJAMQ	YIZRGUEOGT	4122970320 Dell Way	\N	MGMTCCA	\N	0	France	2	YIZRGUEOGT@dell.com	4122970320	1	8813640952575953	2008/11	user17372	password	86	100000	M
17373	CINPYL	YXDESITZCF	2060614180 Dell Way	\N	GOZJRZV	\N	0	Australia	2	YXDESITZCF@dell.com	2060614180	4	1611135033424943	2008/08	user17373	password	20	60000	M
17374	JBIHNG	FRLYZFYCKE	1604948438 Dell Way	\N	QKOIJJI	\N	0	France	2	FRLYZFYCKE@dell.com	1604948438	3	5479462958406657	2011/06	user17374	password	19	60000	M
17375	BUCOBI	FNHFSFHDKY	1090721440 Dell Way	\N	NYHXIPJ	\N	0	China	2	FNHFSFHDKY@dell.com	1090721440	5	1746737777255475	2010/11	user17375	password	56	40000	M
17376	IINJQT	WXZODGRNFF	4072517155 Dell Way	\N	MMCUCME	\N	0	Canada	2	WXZODGRNFF@dell.com	4072517155	2	5962270702235401	2009/10	user17376	password	74	20000	F
17377	CSLSLH	QKWTROHXTT	9441788718 Dell Way	\N	JWNMIRP	\N	0	Japan	2	QKWTROHXTT@dell.com	9441788718	1	9071388666052372	2011/11	user17377	password	23	80000	F
17378	UFTFNJ	QKCIYKFSDP	8159503424 Dell Way	\N	PRBXJRO	\N	0	Chile	2	QKCIYKFSDP@dell.com	8159503424	3	1021081567741930	2011/07	user17378	password	75	80000	F
17379	ALOOVF	YYNXISQLHF	2320052213 Dell Way	\N	CJCMART	\N	0	South Africa	2	YYNXISQLHF@dell.com	2320052213	4	5831086419988424	2011/07	user17379	password	36	20000	M
17380	SODNUB	LHYTZPFHUI	3834344346 Dell Way	\N	RXUSOON	\N	0	Russia	2	LHYTZPFHUI@dell.com	3834344346	1	4652139208745212	2012/04	user17380	password	49	60000	F
17381	AOOUQZ	BPTBEYJYHA	4094339595 Dell Way	\N	VBTKPHC	\N	0	UK	2	BPTBEYJYHA@dell.com	4094339595	3	8147498422302306	2011/12	user17381	password	35	80000	M
17382	UGSKGT	ZZVEYECFFY	9596706593 Dell Way	\N	GYIWFLU	\N	0	Germany	2	ZZVEYECFFY@dell.com	9596706593	3	3076865583192557	2012/10	user17382	password	85	100000	M
17383	EOBKIB	KDFIHHONGV	1688490896 Dell Way	\N	LORRAMF	\N	0	UK	2	KDFIHHONGV@dell.com	1688490896	3	8747628406621517	2012/05	user17383	password	68	60000	M
17384	GPZOQJ	RVSZDGMJBY	3414352843 Dell Way	\N	YTPYFVX	\N	0	China	2	RVSZDGMJBY@dell.com	3414352843	4	2895182157400995	2011/06	user17384	password	72	40000	M
17385	IFHYOY	UHYXNLHPJF	8720918080 Dell Way	\N	IYEOTCW	\N	0	Australia	2	UHYXNLHPJF@dell.com	8720918080	1	7084510478656740	2009/10	user17385	password	83	20000	F
17386	CICRHW	YGUMRBBAGK	9323181766 Dell Way	\N	YLZSNVS	\N	0	China	2	YGUMRBBAGK@dell.com	9323181766	3	7252169123850764	2011/04	user17386	password	72	100000	F
17387	BZBJWZ	PQLGRNGYXF	1506248850 Dell Way	\N	JXYWTQF	\N	0	Japan	2	PQLGRNGYXF@dell.com	1506248850	5	4704771521501243	2009/08	user17387	password	40	80000	M
17388	HUCETS	UFYMSFKQLU	8018490425 Dell Way	\N	NJQGAWY	\N	0	Australia	2	UFYMSFKQLU@dell.com	8018490425	2	4833558822516352	2010/08	user17388	password	29	20000	M
17389	YHDRZY	XYKPEVGQPT	3540094818 Dell Way	\N	ZFAZBYB	\N	0	South Africa	2	XYKPEVGQPT@dell.com	3540094818	3	3724834424909204	2012/08	user17389	password	53	100000	M
17390	UAHUYE	SIUXDANSUN	1694447261 Dell Way	\N	YUNATPW	\N	0	Australia	2	SIUXDANSUN@dell.com	1694447261	1	9559572378173472	2011/09	user17390	password	78	40000	F
17391	VQGTUZ	COWGOKZIXX	1051088206 Dell Way	\N	DKYWZVX	\N	0	Australia	2	COWGOKZIXX@dell.com	1051088206	5	8180207588244230	2011/09	user17391	password	27	20000	M
17392	TJHOIK	CFQRPPAMNE	8124819247 Dell Way	\N	XMBWHYY	\N	0	China	2	CFQRPPAMNE@dell.com	8124819247	4	9880623593926432	2010/11	user17392	password	26	100000	M
17393	MHEVRG	AIYPYZBMDY	5425083203 Dell Way	\N	YFVGDTO	\N	0	UK	2	AIYPYZBMDY@dell.com	5425083203	3	4615905938670039	2009/09	user17393	password	47	100000	F
17394	RDYJKZ	SJOQIQCMPB	4676601068 Dell Way	\N	RKHVEWT	\N	0	Japan	2	SJOQIQCMPB@dell.com	4676601068	1	1192824387457221	2008/07	user17394	password	90	40000	F
17395	CEPNDH	WSXEIARXBI	1152013881 Dell Way	\N	IJDNFWE	\N	0	Japan	2	WSXEIARXBI@dell.com	1152013881	1	7368248793296517	2010/03	user17395	password	86	80000	F
17396	DJUHRQ	ZPVHPMFRVO	4601693692 Dell Way	\N	AZBGWFX	\N	0	South Africa	2	ZPVHPMFRVO@dell.com	4601693692	3	4860849062912166	2010/07	user17396	password	33	100000	M
17397	PRYGIX	WDFLQKDMYE	9108971066 Dell Way	\N	LZKIFHF	\N	0	Japan	2	WDFLQKDMYE@dell.com	9108971066	4	2681504265405237	2010/10	user17397	password	22	20000	F
17398	SARBXN	FDZVNCIMGU	9217060397 Dell Way	\N	MRCSZHI	\N	0	South Africa	2	FDZVNCIMGU@dell.com	9217060397	3	3833200874272734	2011/07	user17398	password	47	20000	F
17399	KVIIJN	LIJZLRMSLZ	5190078656 Dell Way	\N	JORJWZG	\N	0	Russia	2	LIJZLRMSLZ@dell.com	5190078656	3	5537574869114906	2008/12	user17399	password	66	40000	F
17400	NQRWDD	FMCQEOIQNS	8837159730 Dell Way	\N	EEBAEIU	\N	0	Japan	2	FMCQEOIQNS@dell.com	8837159730	2	6806026607286186	2012/12	user17400	password	86	20000	F
17401	OWIRAN	ECEJRMZEFE	3492273978 Dell Way	\N	JHEOPZE	\N	0	France	2	ECEJRMZEFE@dell.com	3492273978	5	3603647858835757	2009/10	user17401	password	53	80000	F
17402	JAAJOE	LSODFNIKRS	3036543264 Dell Way	\N	RWGHWKT	\N	0	Canada	2	LSODFNIKRS@dell.com	3036543264	1	4286521753296256	2012/07	user17402	password	22	40000	M
17403	CIFQNR	JBUOOCYGUQ	7211498302 Dell Way	\N	CBXYLRC	\N	0	Japan	2	JBUOOCYGUQ@dell.com	7211498302	3	6971877146046609	2009/07	user17403	password	88	20000	M
17404	HHGUZP	VUDJXCPRTS	2847143458 Dell Way	\N	TRREITW	\N	0	Australia	2	VUDJXCPRTS@dell.com	2847143458	3	3017858648672700	2011/06	user17404	password	39	40000	M
17405	PPOOEJ	IITFLIXEBQ	3121608572 Dell Way	\N	WTVEMSF	\N	0	Japan	2	IITFLIXEBQ@dell.com	3121608572	3	4766881239600480	2011/09	user17405	password	72	60000	F
17406	IBWMKF	VDLGMJLOAH	2295843554 Dell Way	\N	HVMUOSM	\N	0	Russia	2	VDLGMJLOAH@dell.com	2295843554	5	5611631678417326	2012/08	user17406	password	18	20000	M
17407	BBMLHH	PSOCCZQCHX	1429210833 Dell Way	\N	YURMMEG	\N	0	Japan	2	PSOCCZQCHX@dell.com	1429210833	4	5511759051587433	2011/10	user17407	password	68	80000	M
17408	TCHBKX	UYZWYPYFNW	4354575192 Dell Way	\N	ZEJMIPC	\N	0	China	2	UYZWYPYFNW@dell.com	4354575192	4	1681874511763453	2008/04	user17408	password	70	100000	F
17409	VHDGEX	EDUCTSIGPI	5580975315 Dell Way	\N	LYUUOXE	\N	0	UK	2	EDUCTSIGPI@dell.com	5580975315	2	1822872414253652	2012/12	user17409	password	23	100000	M
17410	JZANXF	RRILKQRAZC	3601244226 Dell Way	\N	ZUWORBM	\N	0	Canada	2	RRILKQRAZC@dell.com	3601244226	3	9948650642298164	2009/08	user17410	password	81	20000	F
17411	WCOUHG	LQRWHIWGLW	5023763697 Dell Way	\N	AIKRJWW	\N	0	Japan	2	LQRWHIWGLW@dell.com	5023763697	5	9241505731828512	2008/09	user17411	password	88	20000	M
17412	BRJJXV	ZORGXOMIKN	9490591921 Dell Way	\N	RUFARBR	\N	0	Canada	2	ZORGXOMIKN@dell.com	9490591921	4	2971653813961893	2011/07	user17412	password	42	40000	M
17413	ZRZXMZ	LEFITSRDFI	6914248825 Dell Way	\N	YKJQMBT	\N	0	France	2	LEFITSRDFI@dell.com	6914248825	5	2010025023482740	2009/04	user17413	password	47	100000	F
17414	BWEOVQ	TBZMUQQZZP	9336655051 Dell Way	\N	KIFXKZI	\N	0	Australia	2	TBZMUQQZZP@dell.com	9336655051	3	3565991769079119	2009/11	user17414	password	29	60000	M
17415	ASMWIF	XISSZJRYZC	7626176218 Dell Way	\N	HFZREHT	\N	0	Australia	2	XISSZJRYZC@dell.com	7626176218	1	3751753791235387	2010/03	user17415	password	77	60000	F
17416	NYBVEZ	EXRDHJBGLJ	8057810784 Dell Way	\N	LLAPSTR	\N	0	France	2	EXRDHJBGLJ@dell.com	8057810784	5	1328207965474575	2012/10	user17416	password	55	20000	F
17417	MFEQEI	OVLVENCPWN	8363977102 Dell Way	\N	AWDTQVG	\N	0	France	2	OVLVENCPWN@dell.com	8363977102	2	4505231947172433	2011/10	user17417	password	57	100000	F
17418	TDXXLL	SXHXKJNGXO	8344978998 Dell Way	\N	DAIUWOF	\N	0	Japan	2	SXHXKJNGXO@dell.com	8344978998	3	3684769824612886	2010/02	user17418	password	36	100000	M
17419	JTUVFM	SMKDVXJTLM	1600741691 Dell Way	\N	TTGPIMH	\N	0	Canada	2	SMKDVXJTLM@dell.com	1600741691	3	7579904400277884	2009/10	user17419	password	60	20000	F
17420	IVBNIT	ZTXVQGOCTI	7946864116 Dell Way	\N	WAYEMFI	\N	0	Germany	2	ZTXVQGOCTI@dell.com	7946864116	1	7662590953055770	2010/08	user17420	password	77	100000	M
17421	RWLZQL	TNHJTVMMDI	8955597744 Dell Way	\N	MBNYHVM	\N	0	Australia	2	TNHJTVMMDI@dell.com	8955597744	2	6804011379834265	2010/01	user17421	password	51	60000	M
17422	HXSXJL	KQVEMHRQQD	8564626159 Dell Way	\N	SECZAPA	\N	0	South Africa	2	KQVEMHRQQD@dell.com	8564626159	4	4555570359341800	2012/02	user17422	password	80	80000	F
17423	TIIDTT	UOYGWPWNTP	3263653164 Dell Way	\N	RVORLPO	\N	0	Chile	2	UOYGWPWNTP@dell.com	3263653164	5	2620448647066951	2009/10	user17423	password	74	80000	M
17424	CDSVXM	KWTHLQUEFM	7338574291 Dell Way	\N	AUEMJTU	\N	0	Japan	2	KWTHLQUEFM@dell.com	7338574291	5	9803240292239936	2010/09	user17424	password	74	20000	M
17425	XVRVHC	RBJDREIWRJ	6070448785 Dell Way	\N	QVVZOPP	\N	0	Chile	2	RBJDREIWRJ@dell.com	6070448785	3	8162951759994031	2009/05	user17425	password	83	20000	F
17426	SUCAWU	BFXSKGPBPF	4485592837 Dell Way	\N	XLFMBVT	\N	0	Japan	2	BFXSKGPBPF@dell.com	4485592837	3	9095569165889176	2011/06	user17426	password	19	20000	F
17427	UCEQXF	WVXHBMJQSG	1212824513 Dell Way	\N	BXSCSMS	\N	0	Canada	2	WVXHBMJQSG@dell.com	1212824513	4	8681733014527709	2010/08	user17427	password	81	80000	F
17428	ZUBWZY	RXGSJPJCVK	8398400907 Dell Way	\N	ZONSBFV	\N	0	Australia	2	RXGSJPJCVK@dell.com	8398400907	4	5773445199243725	2010/07	user17428	password	28	100000	M
17429	XYKXWC	UCVDREFNPF	5243182212 Dell Way	\N	CCYDIUF	\N	0	Canada	2	UCVDREFNPF@dell.com	5243182212	4	6203683515544981	2008/11	user17429	password	49	60000	M
17430	JZRGBL	IWPAAVOPBQ	7288788330 Dell Way	\N	SZUAUZE	\N	0	Chile	2	IWPAAVOPBQ@dell.com	7288788330	4	3494453897699714	2010/03	user17430	password	78	40000	M
17431	UATWMC	SCDTXRJZIB	9760516005 Dell Way	\N	ZCCTBGZ	\N	0	Russia	2	SCDTXRJZIB@dell.com	9760516005	2	3995164364110679	2008/02	user17431	password	68	80000	M
17432	SLTFNM	HRFFIOEQQD	2387744534 Dell Way	\N	TSXUYWO	\N	0	UK	2	HRFFIOEQQD@dell.com	2387744534	5	1535853276029229	2009/08	user17432	password	71	20000	F
17433	EXNSKV	JPBREGIUJB	3907375181 Dell Way	\N	MGWLDLJ	\N	0	China	2	JPBREGIUJB@dell.com	3907375181	3	6058257922995836	2012/02	user17433	password	71	40000	F
17434	QTAAPJ	QQBUWJPGLC	3449617857 Dell Way	\N	NHNRTWY	\N	0	Australia	2	QQBUWJPGLC@dell.com	3449617857	3	9687255246099086	2010/03	user17434	password	31	80000	M
17435	YTYNCO	EDJBNYHYBU	9429177566 Dell Way	\N	GOLZKKB	\N	0	Japan	2	EDJBNYHYBU@dell.com	9429177566	1	1918101931922137	2008/03	user17435	password	78	20000	F
17436	OARQPW	UZXHYEGZZN	5898504401 Dell Way	\N	NLMYWNQ	\N	0	Russia	2	UZXHYEGZZN@dell.com	5898504401	4	9749197443481536	2011/07	user17436	password	22	100000	F
17437	BOTRKO	QHWOMCNLQA	3822051031 Dell Way	\N	XCZTQPN	\N	0	Canada	2	QHWOMCNLQA@dell.com	3822051031	3	9418948031961920	2012/07	user17437	password	77	100000	M
17438	JSHUHY	CDMOGAAWBX	7175287785 Dell Way	\N	ZARQPEV	\N	0	UK	2	CDMOGAAWBX@dell.com	7175287785	4	7999053098261357	2009/07	user17438	password	72	100000	M
17439	METTCV	XOKDPLAQJZ	2600051159 Dell Way	\N	QAPGFKD	\N	0	South Africa	2	XOKDPLAQJZ@dell.com	2600051159	5	2091134026646614	2011/09	user17439	password	90	80000	F
17440	ELXGHU	VSYKDYAMXR	9641337030 Dell Way	\N	MNXRYAO	\N	0	Canada	2	VSYKDYAMXR@dell.com	9641337030	4	8788390494417400	2011/09	user17440	password	59	80000	M
17441	ARCIMX	AKIDIIPGAC	1083282405 Dell Way	\N	TXUSXIU	\N	0	South Africa	2	AKIDIIPGAC@dell.com	1083282405	4	5627420166507364	2011/03	user17441	password	39	60000	F
17442	ZPPLNP	WVTEEJLELE	4241639243 Dell Way	\N	BFWZORW	\N	0	Germany	2	WVTEEJLELE@dell.com	4241639243	2	3246654254384339	2011/09	user17442	password	73	100000	M
17443	JMCWBY	RUDWEOAQTB	3601829874 Dell Way	\N	VQBKIXZ	\N	0	Japan	2	RUDWEOAQTB@dell.com	3601829874	2	3579948228783906	2012/12	user17443	password	29	60000	F
17444	QRFSQW	MTSRHTHBVD	7570075030 Dell Way	\N	RWNAUNR	\N	0	Australia	2	MTSRHTHBVD@dell.com	7570075030	5	1276586011517792	2011/02	user17444	password	63	20000	M
17445	IGLYDY	RVQZPXBKAS	4635279614 Dell Way	\N	HOTBBLD	\N	0	Russia	2	RVQZPXBKAS@dell.com	4635279614	1	5490296941250563	2010/10	user17445	password	58	40000	F
17446	UUAXTS	TJSIGTTHMA	4454451259 Dell Way	\N	VFCWQFR	\N	0	Australia	2	TJSIGTTHMA@dell.com	4454451259	1	6202855634968728	2008/09	user17446	password	83	40000	M
17447	RILKAE	TTNAMHHYHD	8462825523 Dell Way	\N	DKZUPRV	\N	0	UK	2	TTNAMHHYHD@dell.com	8462825523	2	2531459577847272	2010/04	user17447	password	50	20000	M
17448	TMIURC	NFCAMKZUNC	1860568611 Dell Way	\N	ENXUESU	\N	0	Australia	2	NFCAMKZUNC@dell.com	1860568611	5	6020135430619121	2009/05	user17448	password	62	40000	F
17449	CRZTUN	ZWNLHMFUPK	9352896086 Dell Way	\N	IMFNFZN	\N	0	Chile	2	ZWNLHMFUPK@dell.com	9352896086	1	7015697957947851	2009/09	user17449	password	90	60000	M
17450	RMOLZN	INYPZEKPPS	8607977459 Dell Way	\N	CUGHTTO	\N	0	Japan	2	INYPZEKPPS@dell.com	8607977459	2	1185310417786240	2010/03	user17450	password	56	40000	M
17451	ZWIZKQ	MJGMNQBDJE	3314698305 Dell Way	\N	XPLRJAJ	\N	0	Chile	2	MJGMNQBDJE@dell.com	3314698305	2	7819712230004371	2010/11	user17451	password	24	40000	M
17452	ZSWJIJ	SPVGFXJPBH	7321156222 Dell Way	\N	FNYONIU	\N	0	Russia	2	SPVGFXJPBH@dell.com	7321156222	3	3449800959788263	2011/08	user17452	password	65	60000	M
17453	JJYSTR	HOXNMHCNOH	2489123875 Dell Way	\N	BNVOVQJ	\N	0	Germany	2	HOXNMHCNOH@dell.com	2489123875	4	2340771632734686	2011/04	user17453	password	65	40000	M
17454	AIJTAQ	IYDUFFIUMJ	9293785338 Dell Way	\N	HIYDZHR	\N	0	Canada	2	IYDUFFIUMJ@dell.com	9293785338	5	9302217101212592	2009/06	user17454	password	40	100000	M
17455	RFHRVP	PZKVETPRCX	5881470605 Dell Way	\N	ABAZJSD	\N	0	Chile	2	PZKVETPRCX@dell.com	5881470605	1	5299449371173978	2008/05	user17455	password	41	60000	F
17456	NVRJKH	IVCNORFROG	4491742120 Dell Way	\N	SPFBIIJ	\N	0	South Africa	2	IVCNORFROG@dell.com	4491742120	5	8977830793242902	2011/02	user17456	password	49	80000	M
17457	GLARSJ	MVWBMBSBHL	7184929052 Dell Way	\N	RNNZWWW	\N	0	Chile	2	MVWBMBSBHL@dell.com	7184929052	4	9964863363653422	2012/02	user17457	password	72	60000	F
17458	ENCXXO	STQFVIHDTY	5687468485 Dell Way	\N	QGYNDUT	\N	0	South Africa	2	STQFVIHDTY@dell.com	5687468485	4	6846467550843955	2011/07	user17458	password	29	20000	M
17459	SEPPTH	IJNESUHLSX	9284043768 Dell Way	\N	SQKVLER	\N	0	UK	2	IJNESUHLSX@dell.com	9284043768	2	6781552740838379	2010/06	user17459	password	71	20000	F
17460	XSTRZC	ANGTHNFZLX	7462924916 Dell Way	\N	QVTCAKB	\N	0	UK	2	ANGTHNFZLX@dell.com	7462924916	4	4130356151610613	2008/06	user17460	password	51	40000	F
17461	ECAEEB	RLUYYZYJXP	4473979346 Dell Way	\N	FQRFBSD	\N	0	Russia	2	RLUYYZYJXP@dell.com	4473979346	3	9682141333818436	2012/12	user17461	password	40	20000	F
17462	KEGPFY	BZWZYUJVJP	5049881272 Dell Way	\N	MBVOTYI	\N	0	Canada	2	BZWZYUJVJP@dell.com	5049881272	2	9438168494496496	2010/08	user17462	password	24	60000	F
17463	GUQLSR	LORJJBFTQS	9254028391 Dell Way	\N	UMHNKPQ	\N	0	South Africa	2	LORJJBFTQS@dell.com	9254028391	3	3459851896855980	2010/09	user17463	password	75	60000	M
17464	OFJGXU	VOEEQKYHCS	5266020820 Dell Way	\N	TKGEAWB	\N	0	UK	2	VOEEQKYHCS@dell.com	5266020820	2	5063561367802322	2008/02	user17464	password	19	20000	M
17465	FKYDFT	SJYITWQWOJ	9382101135 Dell Way	\N	GUOGRPE	\N	0	Canada	2	SJYITWQWOJ@dell.com	9382101135	4	3828798665199429	2008/08	user17465	password	45	80000	M
17466	UQZAJR	JIADEQZTAG	3440512578 Dell Way	\N	OOMGEQL	\N	0	Canada	2	JIADEQZTAG@dell.com	3440512578	4	2255220551975071	2012/02	user17466	password	79	80000	M
17467	MTYWKH	ELLJBKDBRS	2267088325 Dell Way	\N	QDZUUKX	\N	0	Australia	2	ELLJBKDBRS@dell.com	2267088325	1	9759551570750774	2009/11	user17467	password	72	20000	F
17468	MDFXLJ	IWTKHWLYOB	8037888161 Dell Way	\N	BOWWYTY	\N	0	Australia	2	IWTKHWLYOB@dell.com	8037888161	5	4100963264703751	2011/08	user17468	password	56	20000	F
17469	RFBCPJ	YIUFEFDTHF	9368908225 Dell Way	\N	HDCGXAI	\N	0	Japan	2	YIUFEFDTHF@dell.com	9368908225	4	3987101987469941	2010/03	user17469	password	42	80000	M
17470	OTYDDW	LXCQDGKLLS	9416885589 Dell Way	\N	OOYLOGD	\N	0	France	2	LXCQDGKLLS@dell.com	9416885589	3	1694538477808237	2008/10	user17470	password	76	100000	F
17471	OYLSVX	QXNUDXFPPT	8399731916 Dell Way	\N	EOFSVJF	\N	0	Russia	2	QXNUDXFPPT@dell.com	8399731916	2	8947353975381703	2011/02	user17471	password	82	100000	M
17472	VLJQIZ	OVUSTZIJSM	7378716801 Dell Way	\N	XYESHKL	\N	0	Canada	2	OVUSTZIJSM@dell.com	7378716801	2	7768111997749657	2012/03	user17472	password	70	60000	F
17473	DVRMVG	IPYBOGLHTI	8621225933 Dell Way	\N	GYBOINR	\N	0	Australia	2	IPYBOGLHTI@dell.com	8621225933	3	8630559563636781	2008/02	user17473	password	40	20000	F
17474	DUTYBB	OZDCGOKZXQ	3513633477 Dell Way	\N	XYEGMWH	\N	0	China	2	OZDCGOKZXQ@dell.com	3513633477	1	4448852831497789	2010/06	user17474	password	54	80000	M
17475	HMNJNB	IREPGOPEFN	3227580462 Dell Way	\N	DKUPGCX	\N	0	Germany	2	IREPGOPEFN@dell.com	3227580462	2	9502954164519908	2011/10	user17475	password	65	40000	F
17476	DVLRXU	ICJPQZTWNW	6634101053 Dell Way	\N	GHLMJIA	\N	0	Japan	2	ICJPQZTWNW@dell.com	6634101053	5	4002461950760335	2010/08	user17476	password	63	60000	M
17477	LXKJRS	LBHBBBYOXE	6847315837 Dell Way	\N	VJRFRRV	\N	0	China	2	LBHBBBYOXE@dell.com	6847315837	1	7499108725227416	2009/10	user17477	password	33	100000	F
17478	DKPVDA	WLCXMALJFH	5487794653 Dell Way	\N	SXMKPIS	\N	0	Chile	2	WLCXMALJFH@dell.com	5487794653	3	5460517594125122	2009/08	user17478	password	54	60000	M
17479	XDPADM	LFJXGVHMCZ	6201924074 Dell Way	\N	JPKYYDE	\N	0	France	2	LFJXGVHMCZ@dell.com	6201924074	4	7517311079893262	2009/03	user17479	password	36	20000	F
17480	KPBNBM	TLKAHRMKQV	6753533698 Dell Way	\N	ZBUYEZJ	\N	0	Russia	2	TLKAHRMKQV@dell.com	6753533698	1	1017380949109792	2012/05	user17480	password	19	100000	M
17481	QXGSKA	DUALLNVCJV	2712631007 Dell Way	\N	EDTJCCD	\N	0	Russia	2	DUALLNVCJV@dell.com	2712631007	1	5947985324077309	2010/02	user17481	password	47	40000	M
17482	INMTNQ	NNBZBWBKSG	8381825484 Dell Way	\N	NLPQOSJ	\N	0	Russia	2	NNBZBWBKSG@dell.com	8381825484	5	3541567842010409	2012/04	user17482	password	57	80000	M
17483	BFKOVX	CWWDTYNLEB	9829677175 Dell Way	\N	XURMMBF	\N	0	Chile	2	CWWDTYNLEB@dell.com	9829677175	3	3288180201780051	2009/01	user17483	password	89	100000	F
17484	EJRZGU	WDYQCMCHOA	2798760691 Dell Way	\N	BGMOHSV	\N	0	Chile	2	WDYQCMCHOA@dell.com	2798760691	1	6285379922483117	2009/01	user17484	password	58	40000	F
17485	XAGEVC	ITTLGVSUVU	3378536170 Dell Way	\N	AHIIAEP	\N	0	Chile	2	ITTLGVSUVU@dell.com	3378536170	1	5024296262767166	2009/09	user17485	password	76	60000	M
17486	VVVQYE	KRPRMILIDM	6425871461 Dell Way	\N	QLVQQKV	\N	0	South Africa	2	KRPRMILIDM@dell.com	6425871461	2	3045932814944535	2009/01	user17486	password	77	20000	M
17487	QVOOAZ	FQQSYCBBPR	4670351064 Dell Way	\N	NKHEVDB	\N	0	France	2	FQQSYCBBPR@dell.com	4670351064	2	7886176539584995	2010/02	user17487	password	74	40000	M
17488	PYHQXN	GNFFQHHFYV	3625280406 Dell Way	\N	PGZKKAV	\N	0	Russia	2	GNFFQHHFYV@dell.com	3625280406	4	3496945426799357	2009/05	user17488	password	66	20000	M
17489	PJQMWW	ACCQJJVIEL	3914284228 Dell Way	\N	PDWZESU	\N	0	France	2	ACCQJJVIEL@dell.com	3914284228	1	8483497018925846	2011/09	user17489	password	85	80000	F
17490	HIUEFU	HHLRQHZVTP	4608969415 Dell Way	\N	ZQODIIP	\N	0	Japan	2	HHLRQHZVTP@dell.com	4608969415	3	4244362142402679	2008/05	user17490	password	21	60000	M
17491	JFVOAC	VLTMTTIMIH	5054243239 Dell Way	\N	CXLLGAC	\N	0	Japan	2	VLTMTTIMIH@dell.com	5054243239	3	7820867440663279	2011/07	user17491	password	30	60000	M
17492	KGLKIH	WCUPVDCDKF	3281942775 Dell Way	\N	BWRHWUY	\N	0	China	2	WCUPVDCDKF@dell.com	3281942775	4	2097295429557562	2011/11	user17492	password	59	80000	F
17493	VDQDLN	GFDBIGFTLG	2391795521 Dell Way	\N	PDNMXMU	\N	0	Canada	2	GFDBIGFTLG@dell.com	2391795521	5	9512784209102392	2008/06	user17493	password	62	40000	F
17494	TXLELR	KOSTUYMGEC	3535204611 Dell Way	\N	KSOIEJM	\N	0	China	2	KOSTUYMGEC@dell.com	3535204611	3	4197590896394104	2011/01	user17494	password	63	20000	M
17495	OMYZEJ	OXCJVOQARA	3213189619 Dell Way	\N	SFIXPVG	\N	0	South Africa	2	OXCJVOQARA@dell.com	3213189619	3	6713723304215819	2009/03	user17495	password	68	20000	M
17496	EATJJI	GLRCAHCSIV	6342729511 Dell Way	\N	YRTNMZK	\N	0	Russia	2	GLRCAHCSIV@dell.com	6342729511	1	1097896978724747	2012/09	user17496	password	24	60000	M
17497	CJHMRN	YIQZQTRZPP	5702940041 Dell Way	\N	QJDCINV	\N	0	UK	2	YIQZQTRZPP@dell.com	5702940041	5	7776086766738445	2009/11	user17497	password	43	20000	F
17498	SKNJYM	SPLJIDIYSY	7126265252 Dell Way	\N	HVAQJWO	\N	0	South Africa	2	SPLJIDIYSY@dell.com	7126265252	2	1940720535349100	2010/08	user17498	password	35	80000	F
17499	QDSPPL	EBUNECMXAT	3192113147 Dell Way	\N	TBJCXYZ	\N	0	Germany	2	EBUNECMXAT@dell.com	3192113147	1	2696938178036362	2012/04	user17499	password	77	40000	M
17500	YZOOKT	QEHUHTSINM	6795472885 Dell Way	\N	JWPHUOW	\N	0	Australia	2	QEHUHTSINM@dell.com	6795472885	1	9544160011224450	2012/11	user17500	password	32	100000	M
17501	ENKPHA	UOVBINJVAT	9827681750 Dell Way	\N	RPAMEXO	\N	0	South Africa	2	UOVBINJVAT@dell.com	9827681750	3	7944764571730048	2012/09	user17501	password	70	80000	M
17502	GCMNCG	CXIKLRFLLX	5057382911 Dell Way	\N	BMKFJYA	\N	0	China	2	CXIKLRFLLX@dell.com	5057382911	4	2998234262224287	2008/06	user17502	password	84	20000	M
17503	ZNGCTI	ABTLTYXFWY	9564042526 Dell Way	\N	RHEBGEK	\N	0	Japan	2	ABTLTYXFWY@dell.com	9564042526	4	8521335251629353	2010/07	user17503	password	81	20000	M
17504	JLQDUQ	FNCZMZEIYV	9360999245 Dell Way	\N	PCXWGHN	\N	0	Chile	2	FNCZMZEIYV@dell.com	9360999245	2	6982112564612181	2010/03	user17504	password	80	20000	M
17505	HRTBHZ	OKYBJDJIZZ	7615895655 Dell Way	\N	KWVREJW	\N	0	Australia	2	OKYBJDJIZZ@dell.com	7615895655	3	6118926289025695	2012/05	user17505	password	60	60000	M
17506	GJTOII	YHJIKTQJTA	2211353388 Dell Way	\N	GPSKYPN	\N	0	Japan	2	YHJIKTQJTA@dell.com	2211353388	1	6885491877328605	2010/09	user17506	password	35	40000	M
17507	PZLXIK	ERSPLIZEJF	3123764137 Dell Way	\N	TBQSQEJ	\N	0	Russia	2	ERSPLIZEJF@dell.com	3123764137	1	3829106272663921	2012/04	user17507	password	57	100000	M
17508	NGUVRZ	NJOYRNDATW	1007945667 Dell Way	\N	CKPTOZN	\N	0	Russia	2	NJOYRNDATW@dell.com	1007945667	5	7238763300701977	2009/05	user17508	password	55	20000	M
17509	UYSLXG	ULELZIMSFO	6774049290 Dell Way	\N	DUHRTVM	\N	0	Russia	2	ULELZIMSFO@dell.com	6774049290	1	1273015697952359	2008/09	user17509	password	31	100000	F
17510	CQWZWR	LBCKJPDOEG	6179049194 Dell Way	\N	JLYCHKW	\N	0	UK	2	LBCKJPDOEG@dell.com	6179049194	5	9325277590192856	2009/01	user17510	password	77	80000	F
17511	LOEHFP	IIZSXDGBKP	4979233173 Dell Way	\N	NISVTOS	\N	0	China	2	IIZSXDGBKP@dell.com	4979233173	4	6113850003108383	2010/06	user17511	password	36	80000	M
17512	VVFBKN	JKFHNMJYCX	1809307519 Dell Way	\N	GVSAJLI	\N	0	South Africa	2	JKFHNMJYCX@dell.com	1809307519	5	3864427759312093	2010/02	user17512	password	89	60000	M
17513	URAFFK	PLRDYBCAYJ	6374343699 Dell Way	\N	VRJFCSA	\N	0	Canada	2	PLRDYBCAYJ@dell.com	6374343699	2	7770973076578230	2011/04	user17513	password	34	80000	F
17514	XUICEY	NWCLYFMWOI	9257936416 Dell Way	\N	OXNQPOV	\N	0	Canada	2	NWCLYFMWOI@dell.com	9257936416	3	9572392063215376	2009/10	user17514	password	69	40000	M
17515	MSURRI	NUULZHINPW	9421136240 Dell Way	\N	LDNASJF	\N	0	Japan	2	NUULZHINPW@dell.com	9421136240	1	8778288838453592	2011/11	user17515	password	36	60000	F
17516	ZGAQPN	LJZLQIYGFJ	8073898242 Dell Way	\N	JTKBCQR	\N	0	Australia	2	LJZLQIYGFJ@dell.com	8073898242	3	7898110378999264	2011/10	user17516	password	33	100000	M
17517	MZLBNW	LNHCWGIBQS	1264814747 Dell Way	\N	UAUXQMX	\N	0	France	2	LNHCWGIBQS@dell.com	1264814747	4	1775831874459982	2012/11	user17517	password	24	80000	F
17518	CAKPXV	DEYZLGBBZW	4132002269 Dell Way	\N	CTTTGRE	\N	0	Chile	2	DEYZLGBBZW@dell.com	4132002269	2	1897716988343745	2009/05	user17518	password	69	60000	F
17519	SABQWE	VUEGBGIACK	6279645615 Dell Way	\N	UWDANIH	\N	0	South Africa	2	VUEGBGIACK@dell.com	6279645615	3	2086056676227599	2012/02	user17519	password	70	40000	M
17520	TKLPPG	JTNLAVLCFG	1046470976 Dell Way	\N	ZJHNSPJ	\N	0	Chile	2	JTNLAVLCFG@dell.com	1046470976	3	2957614218350500	2008/03	user17520	password	60	100000	M
17521	ZKOORX	IEIIZULFBK	8053591430 Dell Way	\N	PJXHYHO	\N	0	UK	2	IEIIZULFBK@dell.com	8053591430	4	1603012889623642	2008/05	user17521	password	18	100000	F
17522	KNXBKF	FTNFOZKQJZ	6672055895 Dell Way	\N	ZGHYOWW	\N	0	China	2	FTNFOZKQJZ@dell.com	6672055895	5	3993343119043857	2012/12	user17522	password	39	40000	F
17523	UFLFLR	ZZWOYHEHHD	9180938719 Dell Way	\N	OPCCLYL	\N	0	Australia	2	ZZWOYHEHHD@dell.com	9180938719	4	1412444063927978	2012/01	user17523	password	45	40000	M
17524	PRBAJB	AFPYNTGVXU	1774530395 Dell Way	\N	KZXVYIX	\N	0	South Africa	2	AFPYNTGVXU@dell.com	1774530395	5	7555182831827552	2008/04	user17524	password	88	100000	M
17525	QBYZCY	FRXTLDPJYZ	6770813008 Dell Way	\N	IVVHESD	\N	0	Chile	2	FRXTLDPJYZ@dell.com	6770813008	5	4414608042221517	2012/11	user17525	password	44	100000	F
17526	KUMNTS	EQMPTBYRAH	6346421631 Dell Way	\N	NWPROSX	\N	0	Chile	2	EQMPTBYRAH@dell.com	6346421631	2	2388825473375618	2010/08	user17526	password	18	100000	F
17527	UKONDT	DPJXQIORQB	9290194635 Dell Way	\N	NFTCXQH	\N	0	Germany	2	DPJXQIORQB@dell.com	9290194635	3	9558465749025346	2010/06	user17527	password	81	80000	F
17528	HFUKYX	ZHVQQJIGLV	7345907266 Dell Way	\N	LFYJVGW	\N	0	Russia	2	ZHVQQJIGLV@dell.com	7345907266	5	3907996213063598	2008/09	user17528	password	87	60000	M
17529	DFKCDK	KYAAHIGTES	7984937780 Dell Way	\N	YDBUJYO	\N	0	Australia	2	KYAAHIGTES@dell.com	7984937780	5	3125189404934645	2010/10	user17529	password	66	60000	M
17530	WWBZGL	XHMFQTZULY	2227071719 Dell Way	\N	XMSHLGJ	\N	0	Chile	2	XHMFQTZULY@dell.com	2227071719	3	7301328625530005	2012/03	user17530	password	30	100000	F
17531	BZCHLZ	PXFFREACCY	2413114355 Dell Way	\N	PVFACOG	\N	0	Chile	2	PXFFREACCY@dell.com	2413114355	5	2690385415684432	2010/02	user17531	password	26	60000	F
17532	CPMOOB	MTHDYHFAGU	1194333213 Dell Way	\N	WMVYBCE	\N	0	Chile	2	MTHDYHFAGU@dell.com	1194333213	2	6442848608363420	2008/06	user17532	password	25	40000	M
17533	STEGVQ	ACUYKZZRUW	4354951547 Dell Way	\N	DQVESZK	\N	0	Russia	2	ACUYKZZRUW@dell.com	4354951547	5	8887416670564563	2012/02	user17533	password	30	60000	M
17534	YQBTGC	WBBHBBZWXC	7169028271 Dell Way	\N	MSHFSRY	\N	0	Australia	2	WBBHBBZWXC@dell.com	7169028271	5	9546684531494976	2011/12	user17534	password	48	60000	M
17535	BQSHTP	JUWKVVGSYS	7247453444 Dell Way	\N	LGYDYWG	\N	0	Japan	2	JUWKVVGSYS@dell.com	7247453444	1	4612668424379081	2011/08	user17535	password	90	80000	M
17536	QIYJXH	EURZPYSORD	7200701443 Dell Way	\N	UPHSMNI	\N	0	Canada	2	EURZPYSORD@dell.com	7200701443	4	8653602345846594	2009/09	user17536	password	52	100000	F
17537	UWTRDX	LVWBTOPLSK	2236401490 Dell Way	\N	AZCMMKQ	\N	0	Canada	2	LVWBTOPLSK@dell.com	2236401490	3	5089753226842731	2012/12	user17537	password	45	40000	M
17538	GYLKVX	FSZZGPKZZL	1663731450 Dell Way	\N	YCYKNOP	\N	0	Japan	2	FSZZGPKZZL@dell.com	1663731450	1	5381604213733226	2008/05	user17538	password	68	100000	M
17539	QGBLEH	DDGKSRJSDI	4305129117 Dell Way	\N	UBTHQIY	\N	0	Japan	2	DDGKSRJSDI@dell.com	4305129117	3	7693432375323028	2011/02	user17539	password	58	60000	M
17540	UMEZTI	CATVSDOVLI	9650786004 Dell Way	\N	XFQNNOF	\N	0	South Africa	2	CATVSDOVLI@dell.com	9650786004	5	7018458822742105	2008/07	user17540	password	25	80000	F
17541	PZHIIK	JBGBFUXQCU	5433926563 Dell Way	\N	VTIJHNG	\N	0	Chile	2	JBGBFUXQCU@dell.com	5433926563	5	3763333398848772	2008/01	user17541	password	25	40000	M
17542	BPYKAI	LGJQAHHDCD	6895495967 Dell Way	\N	WKMEYTK	\N	0	France	2	LGJQAHHDCD@dell.com	6895495967	4	4987259817775339	2011/10	user17542	password	73	40000	M
17543	JFHJNS	QXJRFQUHUR	9690264739 Dell Way	\N	SHWRAGC	\N	0	Japan	2	QXJRFQUHUR@dell.com	9690264739	3	4199164074845612	2011/04	user17543	password	64	80000	M
17544	WYBKRR	IAINRDVMVO	9024984224 Dell Way	\N	TRFUYIL	\N	0	South Africa	2	IAINRDVMVO@dell.com	9024984224	5	7081115124747158	2009/06	user17544	password	42	100000	F
17545	HYSYQA	YZOQCJCYYV	8901002792 Dell Way	\N	QEQOMBL	\N	0	China	2	YZOQCJCYYV@dell.com	8901002792	1	6336148657370359	2009/06	user17545	password	53	80000	M
17546	LIRBJQ	AXHDHJCFFS	8530094055 Dell Way	\N	JVGWXSG	\N	0	Russia	2	AXHDHJCFFS@dell.com	8530094055	5	1981921742670238	2009/04	user17546	password	72	20000	M
17547	CTVLKW	JRZQBCWHUF	2870821543 Dell Way	\N	DBCATJV	\N	0	Germany	2	JRZQBCWHUF@dell.com	2870821543	5	9054823058191688	2010/08	user17547	password	87	40000	M
17548	SDECZN	UZEVBACVGG	9994543565 Dell Way	\N	WJGQSBF	\N	0	UK	2	UZEVBACVGG@dell.com	9994543565	1	5108979192096740	2011/01	user17548	password	73	60000	M
17549	WPWWDQ	VHLWHOSOUP	5811196260 Dell Way	\N	XBFPDLN	\N	0	Canada	2	VHLWHOSOUP@dell.com	5811196260	5	8075894618872554	2010/09	user17549	password	32	40000	M
17550	UFMXVI	FGFNVXBPMZ	1928068945 Dell Way	\N	RRPUCCX	\N	0	Japan	2	FGFNVXBPMZ@dell.com	1928068945	4	3160378746688366	2012/11	user17550	password	61	60000	M
17551	UZPPHU	WMHSJJHWIY	3875196882 Dell Way	\N	OXTRAQH	\N	0	Canada	2	WMHSJJHWIY@dell.com	3875196882	3	9703612253535540	2008/02	user17551	password	50	100000	M
17552	KLOSFK	ENCOWKLEJZ	5324530686 Dell Way	\N	BCQCTYF	\N	0	Australia	2	ENCOWKLEJZ@dell.com	5324530686	1	3393786645494401	2011/08	user17552	password	27	60000	F
17553	OCTUNY	HQMEAYIKXK	8411725359 Dell Way	\N	NOMHMRI	\N	0	UK	2	HQMEAYIKXK@dell.com	8411725359	4	6256610330659897	2010/09	user17553	password	27	60000	F
17554	FFCSDK	IQOJOXULHI	5836674735 Dell Way	\N	ATPMKYM	\N	0	Chile	2	IQOJOXULHI@dell.com	5836674735	1	6931137701962144	2009/03	user17554	password	26	60000	F
17555	ISCLDL	BSVPPPBWXC	1834126581 Dell Way	\N	PNOALBF	\N	0	UK	2	BSVPPPBWXC@dell.com	1834126581	5	3213816505856812	2009/01	user17555	password	79	80000	F
17556	OTURFV	JALYQNVNPK	5785610442 Dell Way	\N	AEKMFQL	\N	0	China	2	JALYQNVNPK@dell.com	5785610442	4	6185995549894870	2010/07	user17556	password	35	100000	F
17557	AQTFMC	GYBWLWKAHL	1170228197 Dell Way	\N	FRXKIIS	\N	0	South Africa	2	GYBWLWKAHL@dell.com	1170228197	2	4641946378629655	2010/07	user17557	password	38	80000	M
17558	XITKLZ	IMWTJGUQRA	4969959745 Dell Way	\N	IPKQYDN	\N	0	UK	2	IMWTJGUQRA@dell.com	4969959745	5	5359933000057936	2012/03	user17558	password	24	60000	F
17559	LHNXHV	JDPTKJJCJR	7725419532 Dell Way	\N	RUIPYVO	\N	0	China	2	JDPTKJJCJR@dell.com	7725419532	1	4256604477763176	2012/02	user17559	password	82	20000	M
17560	EOLLJV	PZOZIYCSPT	9479569501 Dell Way	\N	NYJMTXW	\N	0	Germany	2	PZOZIYCSPT@dell.com	9479569501	2	4979924629908055	2008/02	user17560	password	53	80000	F
17561	ABSKXI	JMHSKKLZDZ	5545547282 Dell Way	\N	XNLRLHE	\N	0	China	2	JMHSKKLZDZ@dell.com	5545547282	4	4909316864795983	2011/02	user17561	password	22	100000	F
17562	DPOBXY	NFRXPCXTBV	3638762161 Dell Way	\N	GNMRURB	\N	0	China	2	NFRXPCXTBV@dell.com	3638762161	3	9184567346237600	2010/07	user17562	password	74	60000	M
17563	JDSGBF	LSDBVAUWVB	3265706948 Dell Way	\N	KISEZTM	\N	0	Chile	2	LSDBVAUWVB@dell.com	3265706948	3	7152920072898269	2011/03	user17563	password	35	60000	M
17564	JFUKLG	COIXPCUKDE	3490910615 Dell Way	\N	SWJSQWZ	\N	0	South Africa	2	COIXPCUKDE@dell.com	3490910615	4	7051682201679797	2010/11	user17564	password	29	20000	F
17565	JVRUBU	JJSYMNJPSC	5197255636 Dell Way	\N	MBUCYUZ	\N	0	Chile	2	JJSYMNJPSC@dell.com	5197255636	4	7136346037033946	2009/10	user17565	password	68	80000	F
17566	MIYOCH	YVGLIPBARN	2758316457 Dell Way	\N	CMPBGOG	\N	0	Russia	2	YVGLIPBARN@dell.com	2758316457	5	1894503328949213	2012/08	user17566	password	72	20000	F
17567	BBSEJR	APCIFDJWQL	7351098463 Dell Way	\N	IFMOUTH	\N	0	UK	2	APCIFDJWQL@dell.com	7351098463	2	9683577007148416	2009/02	user17567	password	25	60000	F
17568	EEKOVK	DXSIBBFRNN	8043715641 Dell Way	\N	XACRUKR	\N	0	France	2	DXSIBBFRNN@dell.com	8043715641	4	8433636253699661	2012/09	user17568	password	39	20000	M
17569	MNLHYP	FQXGSDYGQV	8212157722 Dell Way	\N	HTNBDEO	\N	0	UK	2	FQXGSDYGQV@dell.com	8212157722	2	8500362665392459	2010/08	user17569	password	88	60000	F
17570	MWLLLR	BJYUMWBCSI	3509055491 Dell Way	\N	WFJZJXX	\N	0	Canada	2	BJYUMWBCSI@dell.com	3509055491	4	7398158273659647	2012/09	user17570	password	27	20000	F
17571	ZNPKER	UDMGZNJRWF	8133129857 Dell Way	\N	XFEHDBL	\N	0	France	2	UDMGZNJRWF@dell.com	8133129857	1	4231069508474320	2010/04	user17571	password	50	80000	F
17572	ZHSEZM	HLSGZCYVHV	7616438308 Dell Way	\N	BMCEOOP	\N	0	China	2	HLSGZCYVHV@dell.com	7616438308	5	8441094001755119	2008/05	user17572	password	54	40000	F
17573	UANTNU	EGBEIZZPVA	8049058862 Dell Way	\N	CYFQMVZ	\N	0	Chile	2	EGBEIZZPVA@dell.com	8049058862	5	3404776867013425	2008/04	user17573	password	61	60000	F
17574	QBVDWA	JXFRXEHTFJ	8263419133 Dell Way	\N	RLAEGZK	\N	0	Australia	2	JXFRXEHTFJ@dell.com	8263419133	4	3064823210705072	2008/04	user17574	password	74	40000	M
17575	VBZSBJ	QGAOLHHRRZ	2920825622 Dell Way	\N	CRDJROK	\N	0	France	2	QGAOLHHRRZ@dell.com	2920825622	4	6298479051794857	2010/06	user17575	password	76	40000	F
17576	VIZXSP	ESEQALHRKK	8355471452 Dell Way	\N	IOTACEM	\N	0	China	2	ESEQALHRKK@dell.com	8355471452	1	8097978213801981	2009/11	user17576	password	27	60000	M
17577	MMPECU	XGKXSROCCX	5120043748 Dell Way	\N	RVXUAKC	\N	0	South Africa	2	XGKXSROCCX@dell.com	5120043748	5	1599916249979287	2009/01	user17577	password	59	20000	F
17578	BQRDKO	KVLCNAFPYW	6632622750 Dell Way	\N	KWQLGTG	\N	0	Japan	2	KVLCNAFPYW@dell.com	6632622750	2	1139321559574455	2011/11	user17578	password	20	20000	M
17579	RVCCJM	XVOKWUZUQK	4596567312 Dell Way	\N	QHVWBBO	\N	0	Japan	2	XVOKWUZUQK@dell.com	4596567312	3	3871438751928508	2009/08	user17579	password	51	40000	F
17580	HIJQVG	MKQIEQDVAT	8044255340 Dell Way	\N	DVQEXFW	\N	0	China	2	MKQIEQDVAT@dell.com	8044255340	1	6431893414817751	2010/08	user17580	password	79	80000	M
17581	EBOAHB	KYKPONLPHO	8343518066 Dell Way	\N	KXTICQQ	\N	0	South Africa	2	KYKPONLPHO@dell.com	8343518066	2	3601218858733773	2010/01	user17581	password	89	40000	F
17582	AYHIAS	HKIVXTKEIV	1193082952 Dell Way	\N	CCEESUC	\N	0	Germany	2	HKIVXTKEIV@dell.com	1193082952	2	1011831999290734	2008/05	user17582	password	45	40000	F
17583	IRRIJY	SSUQLFVUBX	5829277835 Dell Way	\N	WFCPZED	\N	0	Australia	2	SSUQLFVUBX@dell.com	5829277835	1	2058070050552487	2012/07	user17583	password	54	40000	M
17584	EYEOXX	GRORXJLYGI	2453189558 Dell Way	\N	DJXDNAE	\N	0	Australia	2	GRORXJLYGI@dell.com	2453189558	2	9391023583244532	2011/10	user17584	password	30	60000	M
17585	CSMZPS	RDKONVNTDR	3074160998 Dell Way	\N	CBUQCYR	\N	0	Chile	2	RDKONVNTDR@dell.com	3074160998	4	9286803430877628	2012/10	user17585	password	50	100000	M
17586	DKWTCO	XMDKIQDMHG	2504309189 Dell Way	\N	NCWQBOW	\N	0	Chile	2	XMDKIQDMHG@dell.com	2504309189	4	3586005071643740	2012/03	user17586	password	33	100000	F
17587	PSCSHA	FKKOAOAIUO	8678014119 Dell Way	\N	KREMGBT	\N	0	France	2	FKKOAOAIUO@dell.com	8678014119	1	4197473373729736	2008/04	user17587	password	32	60000	M
17588	XOPEOV	OYJPMKXHYI	6604488037 Dell Way	\N	ZDUFFOQ	\N	0	Australia	2	OYJPMKXHYI@dell.com	6604488037	5	2314545885659754	2012/02	user17588	password	61	80000	F
17589	EJGSEV	ROLEYIMXRL	3241374024 Dell Way	\N	BMRGAHI	\N	0	Japan	2	ROLEYIMXRL@dell.com	3241374024	3	5910045293159783	2010/01	user17589	password	41	60000	F
17590	RTYWPQ	LAUJJHGASH	4018393857 Dell Way	\N	MKONRWE	\N	0	UK	2	LAUJJHGASH@dell.com	4018393857	4	3983577372040600	2009/01	user17590	password	78	80000	M
17591	POPEEB	FZKPGRPZZC	5640096039 Dell Way	\N	JOQBKUY	\N	0	Russia	2	FZKPGRPZZC@dell.com	5640096039	2	2298697722610086	2010/02	user17591	password	73	40000	M
17592	IXXMYC	MJSTAHSAKC	4492740300 Dell Way	\N	OADYVCS	\N	0	China	2	MJSTAHSAKC@dell.com	4492740300	5	8965351409278811	2010/08	user17592	password	30	40000	M
17593	BCKAFX	JXQJFJJQMX	4798935426 Dell Way	\N	QPWMSOU	\N	0	Australia	2	JXQJFJJQMX@dell.com	4798935426	4	6438576892949641	2008/11	user17593	password	77	100000	M
17594	YJXDHH	BXQHHAYTYO	5509937819 Dell Way	\N	JUACJVE	\N	0	Russia	2	BXQHHAYTYO@dell.com	5509937819	4	8394343857187779	2009/08	user17594	password	74	40000	M
17595	DERLLT	ICBQDZKBOT	8247314718 Dell Way	\N	WPVFKAA	\N	0	UK	2	ICBQDZKBOT@dell.com	8247314718	5	3264698740094900	2010/08	user17595	password	55	100000	M
17596	SPEEJN	GKEKKOLYIH	4097426939 Dell Way	\N	NENXENV	\N	0	UK	2	GKEKKOLYIH@dell.com	4097426939	1	4520674677565694	2012/08	user17596	password	41	80000	F
17597	YXLHKS	SPCCDNBLVO	4269223030 Dell Way	\N	PIMUVHU	\N	0	Canada	2	SPCCDNBLVO@dell.com	4269223030	1	2139342077542096	2012/06	user17597	password	78	40000	F
17598	SRTDKL	SMOWAQHVEX	6772969609 Dell Way	\N	DRSZYME	\N	0	China	2	SMOWAQHVEX@dell.com	6772969609	2	3403190072160214	2008/02	user17598	password	54	60000	M
17599	EHZOTS	BIOBYWXDUB	5474628557 Dell Way	\N	UMBTYFC	\N	0	Germany	2	BIOBYWXDUB@dell.com	5474628557	2	7548894296400250	2011/11	user17599	password	39	60000	F
17600	PLPJDR	RSTQOQUISP	7884600716 Dell Way	\N	VTIUZKJ	\N	0	France	2	RSTQOQUISP@dell.com	7884600716	1	1748238703701645	2011/05	user17600	password	57	80000	M
17601	ZGIDXA	VQQKHLTZAO	8003088913 Dell Way	\N	TJISURE	\N	0	Germany	2	VQQKHLTZAO@dell.com	8003088913	2	2364136120770126	2008/10	user17601	password	75	20000	M
17602	ALYYLT	OCEWNXVOLP	7813444552 Dell Way	\N	XTHRLMF	\N	0	Chile	2	OCEWNXVOLP@dell.com	7813444552	2	4536916421260685	2010/02	user17602	password	56	40000	F
17603	ZHDLBR	OFNCDJQOYN	8110667970 Dell Way	\N	IGFUTKA	\N	0	Germany	2	OFNCDJQOYN@dell.com	8110667970	3	1740910049527883	2012/12	user17603	password	50	20000	M
17604	TGJVYY	AMAEVQTUEB	3862020744 Dell Way	\N	BJWVUXI	\N	0	Germany	2	AMAEVQTUEB@dell.com	3862020744	3	5764525362290443	2009/11	user17604	password	66	20000	M
17605	YOLWML	IMQEDJZHLB	6885710020 Dell Way	\N	RHXLFFA	\N	0	Germany	2	IMQEDJZHLB@dell.com	6885710020	3	8002005401533098	2010/03	user17605	password	89	20000	F
17606	OOAAAJ	NQORANYLPQ	7173324265 Dell Way	\N	TMCYSDL	\N	0	China	2	NQORANYLPQ@dell.com	7173324265	2	8980592190288008	2012/03	user17606	password	20	20000	M
17607	PCTQMH	HAYHOXTDOM	1408148531 Dell Way	\N	PQKITVR	\N	0	France	2	HAYHOXTDOM@dell.com	1408148531	3	4205780690535903	2009/08	user17607	password	49	100000	F
17608	NSVAAD	AZLOXESLQI	8933060387 Dell Way	\N	CAQVWIH	\N	0	South Africa	2	AZLOXESLQI@dell.com	8933060387	4	2173026934731751	2010/01	user17608	password	25	80000	M
17609	VNPWRP	VCETGWEXEH	9991059690 Dell Way	\N	XVCTDJR	\N	0	Australia	2	VCETGWEXEH@dell.com	9991059690	4	5531858297996223	2008/11	user17609	password	31	80000	M
17610	SGOJWK	MBDTXIQCPO	7926685757 Dell Way	\N	YSIBBZC	\N	0	Australia	2	MBDTXIQCPO@dell.com	7926685757	4	2151317281648516	2011/10	user17610	password	75	40000	M
17611	AYWXIJ	YMCWUSZKHX	7137915732 Dell Way	\N	CPZDOCF	\N	0	China	2	YMCWUSZKHX@dell.com	7137915732	2	9980978901032360	2010/02	user17611	password	45	100000	F
17612	HWBQFA	CIWXBVHITJ	1842455783 Dell Way	\N	XSNMUTV	\N	0	France	2	CIWXBVHITJ@dell.com	1842455783	5	9579372751060874	2009/03	user17612	password	86	40000	F
17613	UMDAMG	IIDJELSXUP	7638088257 Dell Way	\N	QICLBXX	\N	0	Canada	2	IIDJELSXUP@dell.com	7638088257	5	4511396438814700	2012/10	user17613	password	75	60000	M
17614	GOQSVY	BYIGKAEFQU	1225206508 Dell Way	\N	NSGPQET	\N	0	China	2	BYIGKAEFQU@dell.com	1225206508	1	3726167633663863	2012/12	user17614	password	71	60000	F
17615	HBXCZY	BIFMIJRYEF	7394211009 Dell Way	\N	RKUIOOR	\N	0	Germany	2	BIFMIJRYEF@dell.com	7394211009	5	4609452904202044	2011/09	user17615	password	78	100000	F
17616	WSDWRF	EXRNGIMKND	2318140745 Dell Way	\N	UIMIWDX	\N	0	Germany	2	EXRNGIMKND@dell.com	2318140745	2	3053847850300372	2012/02	user17616	password	22	100000	F
17617	UAWMFB	JWOPEAASEU	4269574077 Dell Way	\N	AQDXUBM	\N	0	UK	2	JWOPEAASEU@dell.com	4269574077	4	8320129983592779	2010/10	user17617	password	69	60000	M
17618	SKAXLJ	UAZYBZRGUR	7648500936 Dell Way	\N	WXORYBQ	\N	0	China	2	UAZYBZRGUR@dell.com	7648500936	3	8444220992270858	2010/02	user17618	password	43	20000	M
17619	TBTFKN	FKMHJENDVK	2202556844 Dell Way	\N	BKBALSI	\N	0	Canada	2	FKMHJENDVK@dell.com	2202556844	1	7146421248093248	2009/07	user17619	password	70	20000	F
17620	TWMEKS	PXZZBNCXXE	7044864529 Dell Way	\N	HZETRNY	\N	0	South Africa	2	PXZZBNCXXE@dell.com	7044864529	4	1690164972562343	2008/05	user17620	password	31	60000	F
17621	BXHMPW	JPVKCYHZDP	8956242162 Dell Way	\N	ZHIQVGL	\N	0	France	2	JPVKCYHZDP@dell.com	8956242162	3	6948287591338158	2009/09	user17621	password	25	40000	M
17622	AQGQMP	FIZHHHHKWG	8822727015 Dell Way	\N	SFXNMIZ	\N	0	China	2	FIZHHHHKWG@dell.com	8822727015	4	6144934986718000	2010/10	user17622	password	83	40000	M
17623	NPKAEP	JEXQMEBILU	9644394262 Dell Way	\N	OIHARHJ	\N	0	Germany	2	JEXQMEBILU@dell.com	9644394262	5	2207410369068384	2011/10	user17623	password	54	60000	F
17624	CXJHMS	MKJYPLHAFV	2056012997 Dell Way	\N	JNVBUEP	\N	0	Russia	2	MKJYPLHAFV@dell.com	2056012997	4	5380184147506953	2012/03	user17624	password	90	40000	F
17625	WQPJIB	USZJDHKICU	2411796485 Dell Way	\N	VXVQCKK	\N	0	Chile	2	USZJDHKICU@dell.com	2411796485	5	2435155458282679	2009/11	user17625	password	50	80000	M
17626	CHDKJX	DJHGQROSLJ	3486590859 Dell Way	\N	QHATSKY	\N	0	South Africa	2	DJHGQROSLJ@dell.com	3486590859	1	3185055375564843	2008/07	user17626	password	87	100000	M
17627	GABQXE	ZFKQWZIIJZ	8013627958 Dell Way	\N	PJSITRE	\N	0	Australia	2	ZFKQWZIIJZ@dell.com	8013627958	3	2548542227596044	2009/05	user17627	password	22	100000	M
17628	BAFZEF	EPVBOEJXDZ	8870459137 Dell Way	\N	GWHAOMB	\N	0	China	2	EPVBOEJXDZ@dell.com	8870459137	2	6880247123539448	2009/04	user17628	password	63	100000	F
17629	QBIVGM	KCOZGYWKXD	4918694064 Dell Way	\N	HFEVRFD	\N	0	Germany	2	KCOZGYWKXD@dell.com	4918694064	4	8053552815224976	2011/05	user17629	password	63	20000	F
17630	RJWYWH	ALHHJERHHZ	7438576225 Dell Way	\N	MMUERXS	\N	0	Canada	2	ALHHJERHHZ@dell.com	7438576225	3	8487176184076817	2008/02	user17630	password	82	20000	M
17631	HBTEJU	PQBYUTFCSS	2011706211 Dell Way	\N	OMWGKPJ	\N	0	Canada	2	PQBYUTFCSS@dell.com	2011706211	2	3329538104590029	2009/02	user17631	password	49	20000	F
17632	MUNWOC	MQBHJHKBZY	8193513310 Dell Way	\N	OWFZMPD	\N	0	Germany	2	MQBHJHKBZY@dell.com	8193513310	2	8519260894041509	2012/10	user17632	password	82	40000	F
17633	RUEGXQ	WYXGFHIFGW	4224816835 Dell Way	\N	CMWPCZE	\N	0	South Africa	2	WYXGFHIFGW@dell.com	4224816835	1	7955403356812895	2008/11	user17633	password	20	60000	M
17634	VQVSHR	RFXXNFDUCF	9960718860 Dell Way	\N	GYUIYZF	\N	0	Chile	2	RFXXNFDUCF@dell.com	9960718860	5	5203094436321408	2012/01	user17634	password	86	60000	M
17635	PGOWYG	BVDOBGIDMO	1943293368 Dell Way	\N	CGXAGDI	\N	0	Chile	2	BVDOBGIDMO@dell.com	1943293368	5	2193372164852917	2008/09	user17635	password	61	100000	F
17636	WNEUTF	QXUSDCVPRY	2054277574 Dell Way	\N	WPZDSIJ	\N	0	South Africa	2	QXUSDCVPRY@dell.com	2054277574	3	9417164828162640	2012/02	user17636	password	84	20000	M
17637	LJTFPK	CJCGMYWDWS	7295310582 Dell Way	\N	SWVLEFG	\N	0	Chile	2	CJCGMYWDWS@dell.com	7295310582	1	2352140360046178	2011/01	user17637	password	42	80000	M
17638	SMSHWV	RYBDWXGTQZ	8362855012 Dell Way	\N	PMKTRQB	\N	0	China	2	RYBDWXGTQZ@dell.com	8362855012	1	2589722170028835	2012/07	user17638	password	84	60000	F
17639	JDNGYF	EAIBYPUOOJ	4490807177 Dell Way	\N	BZDTQED	\N	0	France	2	EAIBYPUOOJ@dell.com	4490807177	2	4091232788749039	2012/03	user17639	password	72	20000	M
17640	WSVVXA	WFBUVWJKFK	6608754274 Dell Way	\N	JJEAOHL	\N	0	UK	2	WFBUVWJKFK@dell.com	6608754274	4	8828846265561880	2012/07	user17640	password	20	60000	F
17641	THGQIC	WKXRGGBMRL	7230111001 Dell Way	\N	VVLKDXI	\N	0	Russia	2	WKXRGGBMRL@dell.com	7230111001	2	6341353727038950	2009/03	user17641	password	21	80000	M
17642	IYQRBM	BYEHEGTWRP	5625957796 Dell Way	\N	RDZUAIN	\N	0	Russia	2	BYEHEGTWRP@dell.com	5625957796	1	9707717114593836	2011/03	user17642	password	64	80000	M
17643	PJEQWF	OAMTHGQZVH	7549390706 Dell Way	\N	CUBDCPW	\N	0	Japan	2	OAMTHGQZVH@dell.com	7549390706	5	4441656100098044	2012/06	user17643	password	26	60000	F
17644	MPRIVG	JIAROQQKYT	6449380407 Dell Way	\N	EZXHPTY	\N	0	China	2	JIAROQQKYT@dell.com	6449380407	2	3038249308709055	2008/06	user17644	password	64	20000	M
17645	GVGBCQ	JDHXUXHSRM	1233079382 Dell Way	\N	SOUHISQ	\N	0	UK	2	JDHXUXHSRM@dell.com	1233079382	5	1108401644974946	2010/06	user17645	password	29	40000	M
17646	ZQTCGC	FOAZMIRDUJ	2144892879 Dell Way	\N	SPRAHHY	\N	0	China	2	FOAZMIRDUJ@dell.com	2144892879	5	8020821311511100	2011/02	user17646	password	29	40000	F
17647	UCEBFK	PFJCNBFIKX	8449846397 Dell Way	\N	XCYFJWN	\N	0	France	2	PFJCNBFIKX@dell.com	8449846397	2	1932303641922772	2012/06	user17647	password	49	20000	F
17648	NFHTPX	ZZZNAFVLDT	8230725557 Dell Way	\N	NBYWXMJ	\N	0	Russia	2	ZZZNAFVLDT@dell.com	8230725557	3	7179100595414639	2009/11	user17648	password	70	60000	F
17649	YVEOSD	NSROXMAAGN	3335000163 Dell Way	\N	BFKZRUT	\N	0	France	2	NSROXMAAGN@dell.com	3335000163	3	7864703415427358	2008/02	user17649	password	38	80000	F
17650	CVRVZE	OQTMCTMJHO	7643822928 Dell Way	\N	OSOGMIS	\N	0	Russia	2	OQTMCTMJHO@dell.com	7643822928	3	9194911670871080	2012/10	user17650	password	56	100000	M
17651	IQSHVH	XPTAJGJQUY	4392627121 Dell Way	\N	IJEVRXO	\N	0	France	2	XPTAJGJQUY@dell.com	4392627121	3	3762147334404290	2008/12	user17651	password	39	20000	F
17652	YTQUBO	JUPTAYJVXS	5593185414 Dell Way	\N	EBNWYBH	\N	0	China	2	JUPTAYJVXS@dell.com	5593185414	3	5134972182102502	2010/11	user17652	password	54	100000	M
17653	GLQHAA	CPTCOCXLUC	8473811373 Dell Way	\N	MIZKJGS	\N	0	South Africa	2	CPTCOCXLUC@dell.com	8473811373	1	4411389680579305	2011/09	user17653	password	33	60000	M
17654	REGREI	HXLVAIHVLT	1656452304 Dell Way	\N	DKEMRXJ	\N	0	France	2	HXLVAIHVLT@dell.com	1656452304	4	2892782108392566	2011/12	user17654	password	73	80000	M
17655	XYHCGO	ZRKZARUMLX	5923278231 Dell Way	\N	XPKOMUB	\N	0	Germany	2	ZRKZARUMLX@dell.com	5923278231	2	3885461135301739	2010/01	user17655	password	18	20000	M
17656	YLAFAA	XKZXCUKNSH	2798192138 Dell Way	\N	DDWQXYF	\N	0	France	2	XKZXCUKNSH@dell.com	2798192138	3	9670453771483154	2009/07	user17656	password	25	20000	F
17657	NFROFO	ZFMBZXPRFS	1540397080 Dell Way	\N	VBJSZOE	\N	0	Canada	2	ZFMBZXPRFS@dell.com	1540397080	1	4769540498964489	2010/03	user17657	password	61	20000	M
17658	UTIAIH	FVIFSYXXRS	7430698208 Dell Way	\N	ZAKZOPE	\N	0	Japan	2	FVIFSYXXRS@dell.com	7430698208	3	2750826468691230	2012/03	user17658	password	36	80000	M
17659	AAZIIE	DRJWPGUGYU	5439221072 Dell Way	\N	GJTUYXK	\N	0	Japan	2	DRJWPGUGYU@dell.com	5439221072	3	6499115041922779	2011/11	user17659	password	41	80000	M
17660	JPFRUJ	IEFYLAEKUL	2984193329 Dell Way	\N	TNFSLQJ	\N	0	UK	2	IEFYLAEKUL@dell.com	2984193329	5	6405775421299041	2008/04	user17660	password	35	100000	M
17661	WDIQMR	VSPGSUQNFK	5153748428 Dell Way	\N	BKCMBMK	\N	0	Chile	2	VSPGSUQNFK@dell.com	5153748428	1	4077210971154273	2011/04	user17661	password	38	60000	F
17662	LUTXLO	QBUJVLWAVX	8439403208 Dell Way	\N	LYKMKVT	\N	0	South Africa	2	QBUJVLWAVX@dell.com	8439403208	1	6743496306240559	2008/05	user17662	password	23	20000	M
17663	WYSHMI	IHSDSOEOMP	8876373311 Dell Way	\N	MWBWSUT	\N	0	Germany	2	IHSDSOEOMP@dell.com	8876373311	2	6428064356092364	2009/06	user17663	password	75	20000	F
17664	SSPFBY	MTCFIGTUVF	3133664757 Dell Way	\N	RXCKRWX	\N	0	Germany	2	MTCFIGTUVF@dell.com	3133664757	3	8198448830749840	2011/04	user17664	password	78	20000	F
17665	OQFPOS	JRXRXRMTXE	9942426957 Dell Way	\N	QZOIWMX	\N	0	Australia	2	JRXRXRMTXE@dell.com	9942426957	4	8088955363258720	2009/07	user17665	password	76	40000	F
17666	KNRZFB	QDTOUFIRKY	8594265185 Dell Way	\N	RZHOLEQ	\N	0	France	2	QDTOUFIRKY@dell.com	8594265185	3	7725736133754254	2009/03	user17666	password	21	60000	M
17667	PCQUDH	YWVTCDLNCD	7499779344 Dell Way	\N	MJRYNHK	\N	0	China	2	YWVTCDLNCD@dell.com	7499779344	1	7570440217386932	2012/03	user17667	password	28	60000	M
17668	GFPKMN	HIHJMSXOVK	9445712517 Dell Way	\N	YMJMUUW	\N	0	Germany	2	HIHJMSXOVK@dell.com	9445712517	3	5054787023924291	2008/09	user17668	password	20	100000	M
17669	GOJSCQ	BJANBYCWIA	9345611207 Dell Way	\N	JRMDMJQ	\N	0	France	2	BJANBYCWIA@dell.com	9345611207	1	6040427854750306	2011/02	user17669	password	55	80000	F
17670	BACDQD	MRQNPTKYTT	7014152318 Dell Way	\N	QGXCPOM	\N	0	Germany	2	MRQNPTKYTT@dell.com	7014152318	1	2726195378694683	2012/07	user17670	password	78	20000	M
17671	VHTMKG	DBUTUEROYH	9294175209 Dell Way	\N	VWJLLWZ	\N	0	Australia	2	DBUTUEROYH@dell.com	9294175209	1	9082259956747294	2010/12	user17671	password	23	20000	M
17672	JVHTBL	VVEQAWFZEA	6370092402 Dell Way	\N	VNMGKLJ	\N	0	China	2	VVEQAWFZEA@dell.com	6370092402	2	8273412339854986	2010/04	user17672	password	83	40000	M
17673	TRLVDH	RHXREDRIDM	4258683780 Dell Way	\N	WPTGBCP	\N	0	Japan	2	RHXREDRIDM@dell.com	4258683780	2	3015717960894108	2011/04	user17673	password	63	40000	F
17674	IVWLCN	TAFXDWFGJB	3700940665 Dell Way	\N	WDIXGXO	\N	0	Japan	2	TAFXDWFGJB@dell.com	3700940665	4	3615894192364067	2010/05	user17674	password	66	80000	M
17675	MMDOAW	OGUSDZYMBV	1949184543 Dell Way	\N	QJTWHIL	\N	0	Germany	2	OGUSDZYMBV@dell.com	1949184543	4	2649982915725559	2010/05	user17675	password	77	40000	M
17676	IJLIGA	PASSARFBNV	8957690274 Dell Way	\N	LHRTPDI	\N	0	Japan	2	PASSARFBNV@dell.com	8957690274	3	2869186409749091	2009/04	user17676	password	49	20000	M
17677	UQZBQO	CJHCAMEOHQ	2893688053 Dell Way	\N	VZJKCSC	\N	0	UK	2	CJHCAMEOHQ@dell.com	2893688053	2	3491103814449161	2010/09	user17677	password	51	20000	M
17678	CEPTTS	CAUDNZRUPM	3798293097 Dell Way	\N	TZXWRAV	\N	0	South Africa	2	CAUDNZRUPM@dell.com	3798293097	1	4767148416955024	2008/07	user17678	password	62	80000	M
17679	UFKOXM	PSQCRHXHUR	5251894044 Dell Way	\N	GSNXSJU	\N	0	Australia	2	PSQCRHXHUR@dell.com	5251894044	2	1579577134456485	2008/10	user17679	password	66	80000	M
17680	XCEUPT	NFVENTLHKS	6282834434 Dell Way	\N	ZXPSGKS	\N	0	Russia	2	NFVENTLHKS@dell.com	6282834434	4	8007041441742332	2009/06	user17680	password	53	20000	F
17681	PEDEXQ	JTUWMGEXYE	4182968968 Dell Way	\N	UOWBYPU	\N	0	Germany	2	JTUWMGEXYE@dell.com	4182968968	3	9308937690220774	2011/01	user17681	password	85	20000	M
17682	CGUAWE	TRBGYFDXKY	4198371331 Dell Way	\N	LHAJWUX	\N	0	Chile	2	TRBGYFDXKY@dell.com	4198371331	5	1158717907965183	2010/10	user17682	password	28	20000	M
17683	KVWGZQ	YBXWHBURZF	3791845301 Dell Way	\N	ZZPVUMB	\N	0	Canada	2	YBXWHBURZF@dell.com	3791845301	1	5904055731836707	2008/03	user17683	password	60	100000	M
17684	KUWKKV	LHSSIMKIRJ	4057269610 Dell Way	\N	IGFCTGG	\N	0	Australia	2	LHSSIMKIRJ@dell.com	4057269610	4	2140144410077482	2010/05	user17684	password	20	20000	M
17685	VAEFWQ	MOIVATDSCL	6385993191 Dell Way	\N	ZIOSOVU	\N	0	UK	2	MOIVATDSCL@dell.com	6385993191	5	5215621601324529	2012/12	user17685	password	64	80000	M
17686	RXYNNL	BWGCPKUSWT	2438687722 Dell Way	\N	ALMPGGN	\N	0	South Africa	2	BWGCPKUSWT@dell.com	2438687722	5	8268090510275216	2008/08	user17686	password	57	100000	F
17687	LVUZGW	WNYMYTEVMF	3463455084 Dell Way	\N	GYUMFHI	\N	0	China	2	WNYMYTEVMF@dell.com	3463455084	1	5280669344123453	2012/09	user17687	password	42	20000	F
17688	EYDLUA	YTMXMRSZWZ	9384433613 Dell Way	\N	YRLDZUN	\N	0	Chile	2	YTMXMRSZWZ@dell.com	9384433613	5	2095308210235089	2011/04	user17688	password	37	80000	F
17689	FXXAXW	TKTGBMGYLE	8305927728 Dell Way	\N	PXIOSVU	\N	0	Japan	2	TKTGBMGYLE@dell.com	8305927728	5	3209048078861087	2008/03	user17689	password	18	80000	F
17690	XNLVKF	FDLHQRFCWU	1891789645 Dell Way	\N	ZEJRZEI	\N	0	South Africa	2	FDLHQRFCWU@dell.com	1891789645	3	9488480633590372	2009/07	user17690	password	58	80000	F
17691	CDIMIO	QUVGMAIJVI	8851886415 Dell Way	\N	NFANJII	\N	0	France	2	QUVGMAIJVI@dell.com	8851886415	2	7944647790864111	2010/10	user17691	password	53	100000	M
17692	QGKZUA	UQHHRPQMYD	3332573862 Dell Way	\N	SYRBHZO	\N	0	Canada	2	UQHHRPQMYD@dell.com	3332573862	2	6275465849321336	2008/10	user17692	password	55	20000	F
17693	TKKOKE	ERLVHCIGFA	9784669192 Dell Way	\N	EXCMWRP	\N	0	Canada	2	ERLVHCIGFA@dell.com	9784669192	1	3089877461083233	2011/09	user17693	password	35	40000	F
17694	QQAAVE	SGAZJJFOKK	7140367250 Dell Way	\N	MMWJEMM	\N	0	Canada	2	SGAZJJFOKK@dell.com	7140367250	4	9200238596647980	2009/12	user17694	password	27	100000	M
17695	TWPOBI	VBHELNTVXF	8066114945 Dell Way	\N	IUOMHBP	\N	0	UK	2	VBHELNTVXF@dell.com	8066114945	3	4154768339823932	2011/08	user17695	password	33	40000	F
17696	CYYDGU	FOYQBRLZXT	4097232307 Dell Way	\N	UMGBNVA	\N	0	China	2	FOYQBRLZXT@dell.com	4097232307	2	1487486270722001	2012/07	user17696	password	46	40000	M
17697	IIUPCA	DAQFSCFPWA	5175491609 Dell Way	\N	BCBPYCX	\N	0	Chile	2	DAQFSCFPWA@dell.com	5175491609	5	3278271438553929	2008/05	user17697	password	63	80000	M
17698	YMHAML	ADQTFWJCWK	8864863404 Dell Way	\N	EYACAXJ	\N	0	France	2	ADQTFWJCWK@dell.com	8864863404	4	5844311034772546	2009/04	user17698	password	35	100000	F
17699	TEEFPF	JGZPDIRZTW	9848332831 Dell Way	\N	YTZZRJL	\N	0	Germany	2	JGZPDIRZTW@dell.com	9848332831	5	7855194020550699	2009/03	user17699	password	66	60000	M
17700	VPFLVO	RUDVCVUVRT	2350470349 Dell Way	\N	PQSGZEU	\N	0	UK	2	RUDVCVUVRT@dell.com	2350470349	3	2822983326856047	2009/03	user17700	password	63	40000	F
17701	GONBCE	WGAZBUVTOK	1429874382 Dell Way	\N	JGRJKMI	\N	0	Germany	2	WGAZBUVTOK@dell.com	1429874382	3	9404990461654962	2009/02	user17701	password	38	40000	F
17702	VVLYAI	EAHGVCZKNJ	6072987361 Dell Way	\N	QESARBP	\N	0	Russia	2	EAHGVCZKNJ@dell.com	6072987361	3	9918751450721176	2011/10	user17702	password	42	20000	M
17703	EOPFWU	GDACGAMTKC	3100991386 Dell Way	\N	YDDQESI	\N	0	Russia	2	GDACGAMTKC@dell.com	3100991386	2	4892539270222187	2008/08	user17703	password	56	80000	M
17704	BGAXAH	BBJIBVBMYA	3682709955 Dell Way	\N	PCQTUZM	\N	0	Australia	2	BBJIBVBMYA@dell.com	3682709955	5	1666257001925259	2012/06	user17704	password	72	80000	F
17705	ZVKACL	BLTDHVPGWF	3932150259 Dell Way	\N	INYDMKE	\N	0	Russia	2	BLTDHVPGWF@dell.com	3932150259	2	7588978933636100	2011/12	user17705	password	55	40000	M
17706	IQAKCB	WWFESVKOAT	3840497455 Dell Way	\N	CZXOKBI	\N	0	Russia	2	WWFESVKOAT@dell.com	3840497455	1	5242529786191881	2009/08	user17706	password	69	40000	M
17707	JIILKF	IPKALUPLOR	6850757656 Dell Way	\N	KLGVNPN	\N	0	South Africa	2	IPKALUPLOR@dell.com	6850757656	1	2220140120480209	2009/09	user17707	password	50	20000	F
17708	TMNDSV	TCWEXMPLDA	4545775045 Dell Way	\N	WJWKYKF	\N	0	Japan	2	TCWEXMPLDA@dell.com	4545775045	2	8590039968490601	2008/10	user17708	password	90	20000	M
17709	MSRENK	GKPDWEOZFL	4712306399 Dell Way	\N	JCWIMBY	\N	0	South Africa	2	GKPDWEOZFL@dell.com	4712306399	4	9731612277682872	2009/10	user17709	password	28	80000	F
17710	VLKJVR	UKUQPJQVVZ	1604216317 Dell Way	\N	XRIJSHG	\N	0	Canada	2	UKUQPJQVVZ@dell.com	1604216317	2	4088982163928449	2012/05	user17710	password	24	20000	F
17711	NNOJEI	TZZJIPFEPD	9437913198 Dell Way	\N	VYMOFTR	\N	0	Chile	2	TZZJIPFEPD@dell.com	9437913198	1	2095376237761229	2009/02	user17711	password	33	60000	M
17712	TBZXKT	WJDFZIJOLF	5278487639 Dell Way	\N	MYTSRLZ	\N	0	Japan	2	WJDFZIJOLF@dell.com	5278487639	1	9153198400512340	2010/04	user17712	password	46	40000	F
17713	MFZWZW	GCBFKLUWQH	1795998741 Dell Way	\N	VKAMVZC	\N	0	China	2	GCBFKLUWQH@dell.com	1795998741	1	9173260213341564	2010/05	user17713	password	28	60000	M
17714	JLTIHZ	KJFVUARLIM	1811518602 Dell Way	\N	VIZRHCZ	\N	0	China	2	KJFVUARLIM@dell.com	1811518602	5	8189009889960290	2010/01	user17714	password	37	40000	F
17715	SCSZCC	IIXDIPPQCL	9784387594 Dell Way	\N	YCCGECQ	\N	0	Chile	2	IIXDIPPQCL@dell.com	9784387594	3	7748347084503622	2008/09	user17715	password	26	40000	F
17716	FCKHFT	PCWYSMPVXO	9081994841 Dell Way	\N	XZVBBLI	\N	0	Australia	2	PCWYSMPVXO@dell.com	9081994841	1	1524380960967391	2011/03	user17716	password	50	20000	F
17717	OKRTEH	WBGONVJKKH	7681806445 Dell Way	\N	KFJMQRN	\N	0	Germany	2	WBGONVJKKH@dell.com	7681806445	3	2414999851956963	2012/01	user17717	password	31	40000	M
17718	PAHTID	UOSIKCSUJC	7112704078 Dell Way	\N	ZTPQKCE	\N	0	Canada	2	UOSIKCSUJC@dell.com	7112704078	2	1613517103251069	2011/07	user17718	password	45	40000	F
17719	KPWSTR	GLZQOSLYVK	6189317239 Dell Way	\N	RKBBNGF	\N	0	Canada	2	GLZQOSLYVK@dell.com	6189317239	2	9072354026604444	2008/08	user17719	password	30	40000	F
17720	TCTMUZ	YUQMMCKINB	6591940365 Dell Way	\N	SODGUIK	\N	0	China	2	YUQMMCKINB@dell.com	6591940365	2	5283372130710632	2009/06	user17720	password	68	40000	F
17721	UBTOBR	ISDUUODIQV	8342541403 Dell Way	\N	WUBRDMB	\N	0	Russia	2	ISDUUODIQV@dell.com	8342541403	3	1214780837297439	2009/03	user17721	password	43	60000	F
17722	KHOMYW	ECRZRUHIQE	5314156036 Dell Way	\N	CSWFFYY	\N	0	Australia	2	ECRZRUHIQE@dell.com	5314156036	5	4044151542242617	2011/04	user17722	password	83	80000	M
17723	EHFDEK	GVKYQSGHXI	5357824645 Dell Way	\N	ATOFSNG	\N	0	Canada	2	GVKYQSGHXI@dell.com	5357824645	3	9036780659575016	2012/06	user17723	password	62	60000	M
17724	XUUBFB	WPZNIFVFOV	8716677173 Dell Way	\N	ZCARPHW	\N	0	Australia	2	WPZNIFVFOV@dell.com	8716677173	4	9048933019395920	2009/05	user17724	password	51	100000	F
17725	GUHLWE	BVSJBNPPIO	9025661214 Dell Way	\N	SJGHQDJ	\N	0	France	2	BVSJBNPPIO@dell.com	9025661214	2	8420120216906072	2009/09	user17725	password	78	60000	M
17726	QVKMAL	ISVKGKZOZS	6825479474 Dell Way	\N	YGZOJJB	\N	0	Chile	2	ISVKGKZOZS@dell.com	6825479474	5	5664481023792178	2009/09	user17726	password	21	40000	F
17727	WTVXFD	QANWLNLKFJ	8763434144 Dell Way	\N	QFYAPZG	\N	0	Chile	2	QANWLNLKFJ@dell.com	8763434144	4	6459209370892496	2010/10	user17727	password	87	100000	M
17728	SSPXVF	YICJWNUBXL	5387204033 Dell Way	\N	HVLWVSC	\N	0	Japan	2	YICJWNUBXL@dell.com	5387204033	4	3251685454044491	2009/08	user17728	password	27	20000	F
17729	VQGQVF	ZYOWMJXJVF	8677100659 Dell Way	\N	FGBAZDS	\N	0	France	2	ZYOWMJXJVF@dell.com	8677100659	5	7941252642311157	2010/02	user17729	password	75	100000	M
17730	KCPGHP	EWLQGJABOF	9684831409 Dell Way	\N	IQGHTZT	\N	0	Japan	2	EWLQGJABOF@dell.com	9684831409	3	2119914003647864	2008/04	user17730	password	89	20000	M
17731	CPZKFD	HQUNZUPOAX	5374669777 Dell Way	\N	EHFYHYO	\N	0	Chile	2	HQUNZUPOAX@dell.com	5374669777	4	3905621397774667	2011/08	user17731	password	42	60000	M
17732	YMDDQK	UKYUFNIGLN	7219173120 Dell Way	\N	OQLVPAB	\N	0	Australia	2	UKYUFNIGLN@dell.com	7219173120	2	8958011753857137	2009/09	user17732	password	47	20000	M
17733	WGVNRP	XPJDDSJOFX	2794051335 Dell Way	\N	FQTURVW	\N	0	China	2	XPJDDSJOFX@dell.com	2794051335	4	7318598698824645	2012/02	user17733	password	76	80000	F
17734	BKOSAM	HKPLCZZHXE	6432434902 Dell Way	\N	YRZQMVZ	\N	0	Japan	2	HKPLCZZHXE@dell.com	6432434902	4	6325193627271802	2011/06	user17734	password	32	100000	M
17735	PJFQVN	ALZDLYLJDK	6731362990 Dell Way	\N	ACAMYZD	\N	0	Germany	2	ALZDLYLJDK@dell.com	6731362990	4	3675526345614344	2008/12	user17735	password	25	80000	M
17736	MWEIKE	TJHFHTOKDO	8957169016 Dell Way	\N	NDALCEZ	\N	0	Russia	2	TJHFHTOKDO@dell.com	8957169016	2	8584958318155260	2012/05	user17736	password	52	40000	M
17737	INETRX	CZCKTQVWFI	9932918912 Dell Way	\N	ZFTCJSV	\N	0	Chile	2	CZCKTQVWFI@dell.com	9932918912	4	1613619236741215	2009/02	user17737	password	47	40000	F
17738	XJFPHH	PJRIANFFVE	7611547233 Dell Way	\N	LPGVIBC	\N	0	China	2	PJRIANFFVE@dell.com	7611547233	1	7131205650512130	2012/07	user17738	password	83	40000	F
17739	GNCNVR	XNAYAFEWKQ	7266941825 Dell Way	\N	LRLTTNC	\N	0	France	2	XNAYAFEWKQ@dell.com	7266941825	4	4070703676436097	2009/08	user17739	password	67	80000	M
17740	FVLANJ	NOHOTLKECV	5083165516 Dell Way	\N	VNPOBRB	\N	0	Russia	2	NOHOTLKECV@dell.com	5083165516	2	1171663283836096	2008/01	user17740	password	73	20000	F
17741	PMHCVV	QCJKOUORPK	4601885625 Dell Way	\N	EFZGXAZ	\N	0	China	2	QCJKOUORPK@dell.com	4601885625	1	5264571987092495	2010/10	user17741	password	54	80000	F
17742	YAMUVC	XFNMZCDPMH	5828365993 Dell Way	\N	VMNTMNC	\N	0	South Africa	2	XFNMZCDPMH@dell.com	5828365993	3	4109048209618777	2009/01	user17742	password	22	80000	F
17743	CDUXGS	DUEDWHSJPO	9533583738 Dell Way	\N	VDHIRJF	\N	0	Canada	2	DUEDWHSJPO@dell.com	9533583738	3	5545551758725197	2008/08	user17743	password	30	20000	M
17744	IWQOOT	ISWFAPPPDL	5961564899 Dell Way	\N	TLUKUZP	\N	0	Russia	2	ISWFAPPPDL@dell.com	5961564899	1	7887429034803063	2008/04	user17744	password	76	100000	M
17745	RNEFHN	YETYUIOYTH	4720714110 Dell Way	\N	JNSENHX	\N	0	Australia	2	YETYUIOYTH@dell.com	4720714110	4	3315523596014827	2011/06	user17745	password	29	40000	F
17746	RMIZZG	DSFXATWUBF	9369309735 Dell Way	\N	ITJWBGY	\N	0	France	2	DSFXATWUBF@dell.com	9369309735	1	2599573450163007	2010/05	user17746	password	52	60000	F
17747	YWZXDD	QIBQCXLECU	7864621352 Dell Way	\N	XLQZSOM	\N	0	Japan	2	QIBQCXLECU@dell.com	7864621352	4	1436470269691199	2008/02	user17747	password	60	20000	F
17748	MCZPGP	YHGBERFHMD	2982468166 Dell Way	\N	TCCLROC	\N	0	France	2	YHGBERFHMD@dell.com	2982468166	1	5921655658166856	2009/09	user17748	password	66	40000	F
17749	UJUAYT	IEUMVAUIDN	2611309133 Dell Way	\N	KGYCVBO	\N	0	Australia	2	IEUMVAUIDN@dell.com	2611309133	1	4311064016073942	2012/10	user17749	password	73	20000	M
17750	CXOBQW	FLJBLDJORU	5519205907 Dell Way	\N	UQWPRKQ	\N	0	South Africa	2	FLJBLDJORU@dell.com	5519205907	5	7699942578561605	2009/10	user17750	password	79	80000	M
17751	SJXJFC	UPEFTNUKHO	8047842249 Dell Way	\N	AEERPUN	\N	0	Australia	2	UPEFTNUKHO@dell.com	8047842249	2	4229367089457810	2010/02	user17751	password	29	60000	M
17752	NIFTLZ	IPFCCZMKNN	1160556775 Dell Way	\N	PRFFMTH	\N	0	Chile	2	IPFCCZMKNN@dell.com	1160556775	4	8085405799094588	2008/10	user17752	password	31	100000	F
17753	MEBXDK	NINQHABVNQ	8289852411 Dell Way	\N	NTWZMDF	\N	0	Germany	2	NINQHABVNQ@dell.com	8289852411	1	6675402064342052	2011/03	user17753	password	61	100000	M
17754	TAQXLD	GYTNZUJMLW	1568498974 Dell Way	\N	GHVSLBF	\N	0	Chile	2	GYTNZUJMLW@dell.com	1568498974	5	9020459958352148	2009/06	user17754	password	79	100000	F
17755	WPCISI	HMWGGFTSCZ	7893525519 Dell Way	\N	AXSMZXT	\N	0	Australia	2	HMWGGFTSCZ@dell.com	7893525519	4	3719593740534037	2009/06	user17755	password	36	60000	F
17756	VNSOVZ	ASGHYZAAZA	9119270539 Dell Way	\N	YRNYPGZ	\N	0	China	2	ASGHYZAAZA@dell.com	9119270539	2	6031097090803087	2009/07	user17756	password	89	80000	F
17757	MLXILY	BRFZRFAQGY	2001296331 Dell Way	\N	HTWWAVF	\N	0	UK	2	BRFZRFAQGY@dell.com	2001296331	4	3780994437634945	2011/09	user17757	password	22	20000	F
17758	NXOYWP	QBPHGPXNNE	1377679089 Dell Way	\N	GKBHGGF	\N	0	China	2	QBPHGPXNNE@dell.com	1377679089	3	1050333672203123	2011/07	user17758	password	18	20000	F
17759	YPAUER	VUYCJVPXAW	8655737149 Dell Way	\N	IBDOIIY	\N	0	China	2	VUYCJVPXAW@dell.com	8655737149	5	2461799525190145	2010/12	user17759	password	31	60000	M
17760	UORYFN	TDPCYFZZBH	7475889914 Dell Way	\N	AFWJOUT	\N	0	France	2	TDPCYFZZBH@dell.com	7475889914	5	8516605976503343	2011/01	user17760	password	43	60000	M
17761	XFVCSO	FIQENQDPYE	2390397008 Dell Way	\N	VUNJOGU	\N	0	Chile	2	FIQENQDPYE@dell.com	2390397008	4	9645556606352330	2009/12	user17761	password	55	20000	M
17762	SXYLLD	TCHGSLWQPR	4969206568 Dell Way	\N	LCAAJVH	\N	0	Germany	2	TCHGSLWQPR@dell.com	4969206568	2	7841895292978735	2010/10	user17762	password	79	40000	F
17763	TEXEIQ	HQXZBTQQKB	6721144389 Dell Way	\N	TLBDGJR	\N	0	Russia	2	HQXZBTQQKB@dell.com	6721144389	3	1981893625576049	2010/04	user17763	password	44	100000	F
17764	OUFWLM	NJMOCCFNEZ	2545037447 Dell Way	\N	ZGCGPTY	\N	0	Chile	2	NJMOCCFNEZ@dell.com	2545037447	1	6821489336900414	2010/05	user17764	password	57	60000	M
17765	IQVUDI	EPXHRCUWCU	9795958974 Dell Way	\N	CEARYYY	\N	0	Canada	2	EPXHRCUWCU@dell.com	9795958974	3	5969113956205547	2009/02	user17765	password	90	40000	F
17766	QEGTNK	JLRAOMWQGZ	2363405822 Dell Way	\N	VGQTFOW	\N	0	Canada	2	JLRAOMWQGZ@dell.com	2363405822	3	6031670710537583	2009/06	user17766	password	83	80000	F
17767	CZVPKE	ACFOPCFVBA	1826544341 Dell Way	\N	CSUHHRM	\N	0	France	2	ACFOPCFVBA@dell.com	1826544341	1	7293804547283799	2010/12	user17767	password	48	60000	F
17768	KKQUPR	WVGMXLHYLK	2990134808 Dell Way	\N	RGSYXEJ	\N	0	UK	2	WVGMXLHYLK@dell.com	2990134808	1	5570331627503038	2008/07	user17768	password	25	20000	M
17769	NVSCMP	XSBVEJUQTL	8797460086 Dell Way	\N	WMKTRUT	\N	0	South Africa	2	XSBVEJUQTL@dell.com	8797460086	2	1392063189763575	2009/05	user17769	password	34	40000	M
17770	BZZNOX	GPSKYMASYW	6317821445 Dell Way	\N	FIPWDJT	\N	0	UK	2	GPSKYMASYW@dell.com	6317821445	4	4263325846288353	2012/01	user17770	password	64	80000	F
17771	PTOEQV	UIFTVFLUCR	1516547917 Dell Way	\N	DRNGAGG	\N	0	Japan	2	UIFTVFLUCR@dell.com	1516547917	4	6029800888150931	2008/03	user17771	password	43	20000	M
17772	CSATNU	CSNXYZSAQV	9211953320 Dell Way	\N	SEBTLIJ	\N	0	France	2	CSNXYZSAQV@dell.com	9211953320	5	6132607952225954	2008/04	user17772	password	69	20000	F
17773	KACXVE	QJCPJUPAQH	4116071984 Dell Way	\N	ERBQZKD	\N	0	UK	2	QJCPJUPAQH@dell.com	4116071984	4	1557879450730979	2011/05	user17773	password	23	100000	M
17774	CCSYHJ	HJYRENRUVW	3929447770 Dell Way	\N	MWNMHQJ	\N	0	Japan	2	HJYRENRUVW@dell.com	3929447770	3	3373870862182230	2011/07	user17774	password	36	60000	M
17775	JGOQPW	ZONECFYXCL	7546977925 Dell Way	\N	UPXCFHT	\N	0	Germany	2	ZONECFYXCL@dell.com	7546977925	5	3339206248521805	2009/04	user17775	password	75	100000	M
17776	AKFQGF	ETKGYJEAUY	8005921430 Dell Way	\N	QSBVZUJ	\N	0	Russia	2	ETKGYJEAUY@dell.com	8005921430	4	9505928294267506	2008/05	user17776	password	75	80000	F
17777	EWBLCG	EMMDVQEQPU	6811649112 Dell Way	\N	IQQHLAA	\N	0	Chile	2	EMMDVQEQPU@dell.com	6811649112	5	3149254427291453	2008/10	user17777	password	81	60000	M
17778	TOJVUO	HHSDYXUNRC	4386487255 Dell Way	\N	EIKPIKV	\N	0	UK	2	HHSDYXUNRC@dell.com	4386487255	1	1446548858657479	2008/12	user17778	password	57	20000	M
17779	CLMXZU	FRYDOSQGVV	3702105251 Dell Way	\N	PFLYQGY	\N	0	Australia	2	FRYDOSQGVV@dell.com	3702105251	5	2323409978765994	2009/07	user17779	password	33	100000	M
17780	QJOQDT	ICWXUNEPIT	6602854324 Dell Way	\N	VUSMAQM	\N	0	China	2	ICWXUNEPIT@dell.com	6602854324	4	5889430735725910	2008/11	user17780	password	49	80000	F
17781	UIDYCM	AYJULOKUIG	8531800472 Dell Way	\N	OASPRFX	\N	0	Chile	2	AYJULOKUIG@dell.com	8531800472	3	4910840690601617	2011/11	user17781	password	34	20000	M
17782	OIPQUP	PEKBSVWABK	4161489473 Dell Way	\N	ATARYXZ	\N	0	Russia	2	PEKBSVWABK@dell.com	4161489473	3	5310747489333153	2009/08	user17782	password	66	100000	F
17783	ZMWUCL	YMNQHJQJUR	7471745595 Dell Way	\N	CUJBRIW	\N	0	Australia	2	YMNQHJQJUR@dell.com	7471745595	2	3304195453878492	2009/12	user17783	password	28	60000	M
17784	QKUSVS	EIJMRZWLQZ	2911214806 Dell Way	\N	GAAXIWY	\N	0	Australia	2	EIJMRZWLQZ@dell.com	2911214806	2	4467950582969934	2009/05	user17784	password	85	40000	M
17785	IZRDRW	MBJEAFQREW	9464029385 Dell Way	\N	RFUABTB	\N	0	Chile	2	MBJEAFQREW@dell.com	9464029385	3	5479785829316825	2009/05	user17785	password	69	40000	M
17786	RXVJTI	KCMLICDMZV	3651457408 Dell Way	\N	RTVTNWA	\N	0	France	2	KCMLICDMZV@dell.com	3651457408	3	7538816051092000	2011/03	user17786	password	89	40000	M
17787	WDHQLS	TYDBBHOACG	6011141229 Dell Way	\N	UXZHUAT	\N	0	Australia	2	TYDBBHOACG@dell.com	6011141229	3	7568044200073928	2011/06	user17787	password	22	80000	F
17788	FAZRSS	PWURDJSGPM	1064305101 Dell Way	\N	DPUYPNA	\N	0	Canada	2	PWURDJSGPM@dell.com	1064305101	4	9610084752552212	2010/10	user17788	password	66	80000	F
17789	RTRJMH	GHYJQQPFDT	5008843692 Dell Way	\N	VXRKLSP	\N	0	France	2	GHYJQQPFDT@dell.com	5008843692	3	9160967226140202	2009/03	user17789	password	67	40000	M
17790	LXGXEM	ECWUTLAWFW	4537590368 Dell Way	\N	TXGFPWR	\N	0	Australia	2	ECWUTLAWFW@dell.com	4537590368	3	3602683889679611	2011/04	user17790	password	57	60000	M
17791	LSPQFT	TBOMNPISLC	6115380157 Dell Way	\N	QSIFOZH	\N	0	UK	2	TBOMNPISLC@dell.com	6115380157	3	5916992625221611	2012/02	user17791	password	19	60000	M
17792	TCEZWY	AKKOZTHKWX	9705334784 Dell Way	\N	DEDREKQ	\N	0	Russia	2	AKKOZTHKWX@dell.com	9705334784	1	6132640654221178	2008/03	user17792	password	24	80000	M
17793	EUXASY	LDMKXUVURY	4649433807 Dell Way	\N	YVQDFGW	\N	0	Canada	2	LDMKXUVURY@dell.com	4649433807	3	3266553449910134	2010/07	user17793	password	81	60000	M
17794	RLTKJE	OWOLQKFIJE	6692623790 Dell Way	\N	DZIJGEO	\N	0	Japan	2	OWOLQKFIJE@dell.com	6692623790	4	3081096344627440	2008/08	user17794	password	73	100000	F
17795	FPSPTG	LISCTXLDCO	3460949921 Dell Way	\N	CKYIPMZ	\N	0	Chile	2	LISCTXLDCO@dell.com	3460949921	2	4597024306189269	2012/12	user17795	password	37	40000	F
17796	WZUQFF	ZXISVTWYIY	5324413834 Dell Way	\N	JGHZTHF	\N	0	Australia	2	ZXISVTWYIY@dell.com	5324413834	4	9573557860217988	2010/11	user17796	password	33	80000	M
17797	EKKKQJ	IZCETYCCXM	3317540097 Dell Way	\N	JELCLQC	\N	0	UK	2	IZCETYCCXM@dell.com	3317540097	1	4526649713050574	2008/04	user17797	password	20	100000	F
17798	LHWBQE	BSIURLWOXF	5297245597 Dell Way	\N	TIHFZKD	\N	0	Chile	2	BSIURLWOXF@dell.com	5297245597	3	4427024645730853	2011/07	user17798	password	37	40000	M
17799	NBBEFC	XOXOZTCWZW	7472331142 Dell Way	\N	FHBFSEL	\N	0	Canada	2	XOXOZTCWZW@dell.com	7472331142	5	9310855130199344	2009/02	user17799	password	27	40000	M
17800	EIUKLR	YIGXCJUBFA	5544724712 Dell Way	\N	IHFAMRF	\N	0	Canada	2	YIGXCJUBFA@dell.com	5544724712	1	5146571445278824	2011/04	user17800	password	71	40000	F
17801	BAVMST	VZRXIMYOMH	7015134660 Dell Way	\N	VSIHKNM	\N	0	South Africa	2	VZRXIMYOMH@dell.com	7015134660	5	5443517439067364	2012/08	user17801	password	71	40000	M
17802	TEFMYA	LQXUDWIPDD	8667437724 Dell Way	\N	IMLSAXP	\N	0	Japan	2	LQXUDWIPDD@dell.com	8667437724	1	6485405429266394	2010/10	user17802	password	88	40000	M
17803	DLBCLN	TJHWFQMJTU	2881252662 Dell Way	\N	WFNWDCO	\N	0	UK	2	TJHWFQMJTU@dell.com	2881252662	1	5384688423015177	2008/02	user17803	password	70	80000	F
17804	DRJPFD	YMZECLNWGJ	9518764101 Dell Way	\N	BTGEWUE	\N	0	Australia	2	YMZECLNWGJ@dell.com	9518764101	4	1895636876579374	2008/05	user17804	password	70	40000	M
17805	KSCPVB	BVFEGTAMDC	1976153622 Dell Way	\N	GJHCDLE	\N	0	Australia	2	BVFEGTAMDC@dell.com	1976153622	2	2520273102447390	2010/12	user17805	password	55	100000	F
17806	GCZCEB	XJFEDGRGJX	4778957600 Dell Way	\N	PRZTDEW	\N	0	Chile	2	XJFEDGRGJX@dell.com	4778957600	1	7307484555058182	2009/07	user17806	password	68	80000	M
17807	UTWYUT	IAXLHORQMH	9294894469 Dell Way	\N	HMBKQXQ	\N	0	Australia	2	IAXLHORQMH@dell.com	9294894469	2	4978923151735217	2010/01	user17807	password	34	40000	M
17808	ZCUTWC	UUOBJFRVNZ	4136021987 Dell Way	\N	HOJXMAY	\N	0	China	2	UUOBJFRVNZ@dell.com	4136021987	3	8604799360036851	2009/08	user17808	password	24	20000	M
17809	EZJBBD	VPEEVWAIWI	6251579617 Dell Way	\N	XGFJGET	\N	0	Germany	2	VPEEVWAIWI@dell.com	6251579617	4	9733485536649824	2009/09	user17809	password	30	80000	M
17810	DEXEHT	UMYQJYZFGW	6472693791 Dell Way	\N	LMGSRAH	\N	0	Chile	2	UMYQJYZFGW@dell.com	6472693791	2	5074866933282465	2009/06	user17810	password	36	20000	M
17811	KCTSVN	ETDOSCUZZF	5179883655 Dell Way	\N	LGXCGFJ	\N	0	South Africa	2	ETDOSCUZZF@dell.com	5179883655	5	2246268482413143	2012/01	user17811	password	40	60000	F
17812	KEEFSJ	ZWXRZRQZXC	4431036794 Dell Way	\N	FVFLAOH	\N	0	France	2	ZWXRZRQZXC@dell.com	4431036794	3	4369539110455662	2010/09	user17812	password	77	100000	F
17813	ACISLI	PJZPBQOYTT	9056580223 Dell Way	\N	TZFUNMH	\N	0	UK	2	PJZPBQOYTT@dell.com	9056580223	4	4199819070287049	2011/06	user17813	password	37	80000	F
17814	JBFUJU	DJKFAYDTSX	6534327123 Dell Way	\N	SXSGJZE	\N	0	Chile	2	DJKFAYDTSX@dell.com	6534327123	3	9059956760145724	2008/10	user17814	password	63	60000	F
17815	RTYBOC	KYHLXKFPIY	8991512494 Dell Way	\N	NAEXZJE	\N	0	Japan	2	KYHLXKFPIY@dell.com	8991512494	1	7219163351692260	2011/09	user17815	password	35	100000	F
17816	ZTLOVV	NCHKNMAWKN	6812649534 Dell Way	\N	WPKWYPM	\N	0	South Africa	2	NCHKNMAWKN@dell.com	6812649534	1	5688325027935207	2009/06	user17816	password	43	80000	F
17817	CDZYZM	AGWOTWKDKH	8366547764 Dell Way	\N	TUERJQN	\N	0	Australia	2	AGWOTWKDKH@dell.com	8366547764	1	4281232583802194	2009/05	user17817	password	23	80000	F
17818	FQKFCL	MZAFVKJGSC	4228371239 Dell Way	\N	AWUKMIL	\N	0	China	2	MZAFVKJGSC@dell.com	4228371239	5	5935950344428421	2011/11	user17818	password	32	40000	F
17819	VRIXCU	WCZSNJYFLZ	6889239950 Dell Way	\N	BGKOOWW	\N	0	UK	2	WCZSNJYFLZ@dell.com	6889239950	3	6894370852503926	2010/08	user17819	password	83	80000	F
17820	OYJRTG	UTZHCYNNXP	4922689089 Dell Way	\N	UIDIEAF	\N	0	South Africa	2	UTZHCYNNXP@dell.com	4922689089	5	4295187312643975	2008/10	user17820	password	18	60000	F
17821	ZWZSDT	LCBNAOBYEV	3119958183 Dell Way	\N	HHDLIJH	\N	0	Russia	2	LCBNAOBYEV@dell.com	3119958183	4	8283507902175189	2008/08	user17821	password	40	40000	M
17822	EIIHBT	KDGKRHJVDQ	9867146109 Dell Way	\N	DGCLQJF	\N	0	South Africa	2	KDGKRHJVDQ@dell.com	9867146109	1	8811543465126307	2011/04	user17822	password	32	40000	M
17823	NOVOHF	ROQJWAFZQJ	1272769408 Dell Way	\N	GSUWBAT	\N	0	Australia	2	ROQJWAFZQJ@dell.com	1272769408	3	7157898818608374	2009/10	user17823	password	85	100000	F
17824	MRWTXO	HOXDODDEMJ	6070118010 Dell Way	\N	XHGZHZA	\N	0	China	2	HOXDODDEMJ@dell.com	6070118010	4	7183532577008010	2009/08	user17824	password	58	80000	F
17825	GNWEBE	SZHGDLKPUI	1175132792 Dell Way	\N	WAHEZIN	\N	0	Germany	2	SZHGDLKPUI@dell.com	1175132792	1	9178365517407656	2011/09	user17825	password	59	80000	F
17826	CPEEUW	DBCGNNWHVT	6419309604 Dell Way	\N	IDXHLKW	\N	0	France	2	DBCGNNWHVT@dell.com	6419309604	4	1957197881769389	2009/04	user17826	password	80	40000	F
17827	MNOGJS	ILZVZWCUPL	4178424367 Dell Way	\N	YNTJXPV	\N	0	Germany	2	ILZVZWCUPL@dell.com	4178424367	5	8820851451251657	2011/10	user17827	password	34	20000	F
17828	SRMCKV	OJQNFTIVEG	4248004649 Dell Way	\N	IXPGNLT	\N	0	South Africa	2	OJQNFTIVEG@dell.com	4248004649	4	5842445285990835	2008/11	user17828	password	64	60000	M
17829	HXRSSF	CJTICBDHHL	1453252532 Dell Way	\N	EXRSJLO	\N	0	Russia	2	CJTICBDHHL@dell.com	1453252532	1	8723513482604177	2012/09	user17829	password	36	60000	F
17830	EDSWIV	FCDIDGPLRU	2025283846 Dell Way	\N	JJMSUAK	\N	0	South Africa	2	FCDIDGPLRU@dell.com	2025283846	2	7673907125834376	2012/07	user17830	password	33	100000	M
17831	IPORKU	TNCXUSIMMR	1799321634 Dell Way	\N	VZKQZVM	\N	0	Canada	2	TNCXUSIMMR@dell.com	1799321634	2	9481112391687932	2011/06	user17831	password	77	40000	M
17832	KXLVRF	IUCCMLPZDK	7788654114 Dell Way	\N	YNBYINB	\N	0	France	2	IUCCMLPZDK@dell.com	7788654114	5	1368766984902322	2008/10	user17832	password	44	100000	F
17833	GKAYPJ	SSLFDAEGLD	1700068358 Dell Way	\N	UMBCACN	\N	0	Russia	2	SSLFDAEGLD@dell.com	1700068358	3	9693722827360036	2012/12	user17833	password	84	20000	F
17834	IBCXKV	QWATXFAJIU	9662363059 Dell Way	\N	WKXXMKR	\N	0	Germany	2	QWATXFAJIU@dell.com	9662363059	4	4852305632084608	2012/07	user17834	password	53	20000	M
17835	ODUZZK	WZEUEEDNZA	2855790942 Dell Way	\N	XWXKHOY	\N	0	Chile	2	WZEUEEDNZA@dell.com	2855790942	2	2123715687077492	2011/11	user17835	password	30	80000	F
17836	IKKHVG	HAAMFEZEEX	6430148914 Dell Way	\N	BCHIQFP	\N	0	South Africa	2	HAAMFEZEEX@dell.com	6430148914	4	6512045053765178	2010/11	user17836	password	35	100000	F
17837	RIMMOT	MPGRUFWZCX	5845488537 Dell Way	\N	BKGSQVO	\N	0	Chile	2	MPGRUFWZCX@dell.com	5845488537	1	7237884650938214	2010/05	user17837	password	61	80000	F
17838	XCOMWB	CCTWIPWLNX	3696628143 Dell Way	\N	VUPLPDR	\N	0	Canada	2	CCTWIPWLNX@dell.com	3696628143	2	6091744988225401	2011/12	user17838	password	31	80000	M
17839	HIIEJL	HCIQSEBFBX	4726116322 Dell Way	\N	ARJPUBT	\N	0	Australia	2	HCIQSEBFBX@dell.com	4726116322	2	8176505645271391	2009/07	user17839	password	59	40000	M
17840	WPZGAH	JIXBMZHOWH	9988817845 Dell Way	\N	FGXZHRC	\N	0	Japan	2	JIXBMZHOWH@dell.com	9988817845	5	1679211312904954	2010/06	user17840	password	41	40000	F
17841	XIPYPY	GMZSMHHJOM	4999593532 Dell Way	\N	PMMWDOO	\N	0	Canada	2	GMZSMHHJOM@dell.com	4999593532	4	6983212517574430	2012/12	user17841	password	90	40000	M
17842	HUUXTB	KSUWABFPNU	8864735207 Dell Way	\N	BZRFNGJ	\N	0	UK	2	KSUWABFPNU@dell.com	8864735207	1	8874782104045154	2012/01	user17842	password	25	80000	F
17843	XMGQOQ	JIMJJSZWNB	7067403580 Dell Way	\N	WEGKKQJ	\N	0	Chile	2	JIMJJSZWNB@dell.com	7067403580	2	2007822183892131	2011/05	user17843	password	77	20000	F
17844	IHXWXG	EKQNCPKPRG	3063579759 Dell Way	\N	UXQEOZL	\N	0	Chile	2	EKQNCPKPRG@dell.com	3063579759	3	9370818221941592	2010/05	user17844	password	88	100000	M
17845	GSODZS	NPGQFQGWWA	2724209634 Dell Way	\N	UMEJMQO	\N	0	Japan	2	NPGQFQGWWA@dell.com	2724209634	3	3415966364089400	2010/06	user17845	password	24	40000	M
17846	UVWTNJ	JTAPJGMGGG	7193284058 Dell Way	\N	SLPEBEX	\N	0	Chile	2	JTAPJGMGGG@dell.com	7193284058	1	8379499443806709	2008/03	user17846	password	24	100000	F
17847	XSULCD	FCSPJEVPLO	8042145304 Dell Way	\N	ABTCGQI	\N	0	UK	2	FCSPJEVPLO@dell.com	8042145304	1	1772989135235548	2008/03	user17847	password	87	20000	F
17848	RVOUZU	XSJGXEVJSW	5122741598 Dell Way	\N	KLZQBHO	\N	0	South Africa	2	XSJGXEVJSW@dell.com	5122741598	4	8913576208986343	2011/08	user17848	password	86	100000	F
17849	UKBTFY	MOEJSASLXD	9808821277 Dell Way	\N	WWTYEIU	\N	0	Japan	2	MOEJSASLXD@dell.com	9808821277	4	3966880092862994	2010/08	user17849	password	30	100000	F
17850	PYDUWP	IBZBCSMAVI	7789215635 Dell Way	\N	WPHBXCR	\N	0	South Africa	2	IBZBCSMAVI@dell.com	7789215635	1	5353626875206828	2009/03	user17850	password	43	80000	M
17851	HXOENX	GMYIFKIATF	9471813948 Dell Way	\N	QAGNCYL	\N	0	South Africa	2	GMYIFKIATF@dell.com	9471813948	5	3074624790344387	2008/04	user17851	password	89	100000	M
17852	WMSKJZ	XIHCSQCMWS	6472785053 Dell Way	\N	NDGQBSM	\N	0	Australia	2	XIHCSQCMWS@dell.com	6472785053	4	2175790217705071	2012/09	user17852	password	20	60000	M
17853	MEZWDW	ELYXCBJYUX	7386425708 Dell Way	\N	CBNDTZE	\N	0	China	2	ELYXCBJYUX@dell.com	7386425708	2	2984451785683632	2010/04	user17853	password	66	100000	M
17854	VYRYUW	KTTMUDLOAN	2163475282 Dell Way	\N	QORJOVR	\N	0	Chile	2	KTTMUDLOAN@dell.com	2163475282	5	6930350854992867	2010/07	user17854	password	64	40000	F
17855	PYJKVT	DOGYSRNTFD	1784844499 Dell Way	\N	HWMVSEC	\N	0	South Africa	2	DOGYSRNTFD@dell.com	1784844499	4	3597424601670355	2011/05	user17855	password	58	20000	M
17856	NKKIEO	XKMPCAJHDR	4341580966 Dell Way	\N	DQNWVPS	\N	0	South Africa	2	XKMPCAJHDR@dell.com	4341580966	5	5985039630904794	2011/07	user17856	password	62	80000	F
17857	AEJESG	PFWRFGYJXC	6706366428 Dell Way	\N	ALYVBQS	\N	0	France	2	PFWRFGYJXC@dell.com	6706366428	2	2705668076872825	2008/11	user17857	password	87	40000	M
17858	DPBVWQ	BSIGZGQXJQ	4704538240 Dell Way	\N	IHLJYDU	\N	0	Germany	2	BSIGZGQXJQ@dell.com	4704538240	5	7902710396796466	2009/12	user17858	password	90	20000	F
17859	PGXLWY	EFFDLVAVLJ	5354687202 Dell Way	\N	DXSCBNR	\N	0	France	2	EFFDLVAVLJ@dell.com	5354687202	3	7658921674359591	2010/06	user17859	password	84	60000	F
17860	DJMAHQ	FMURIVMTEQ	8267470836 Dell Way	\N	RXSSKJE	\N	0	UK	2	FMURIVMTEQ@dell.com	8267470836	5	3857521678786725	2009/10	user17860	password	75	40000	M
17861	DSZLJF	XEXFZKZEAQ	4950568380 Dell Way	\N	CSJMCNK	\N	0	South Africa	2	XEXFZKZEAQ@dell.com	4950568380	4	2120972378179431	2009/07	user17861	password	45	40000	M
17862	CECMJA	QHGPRFURWW	5235830646 Dell Way	\N	JGJLUTI	\N	0	Chile	2	QHGPRFURWW@dell.com	5235830646	3	5211083035450429	2012/11	user17862	password	67	80000	M
17863	WSKGSA	NYQEEKVBHF	5009970923 Dell Way	\N	IQQCKZH	\N	0	South Africa	2	NYQEEKVBHF@dell.com	5009970923	4	8475671904627235	2009/06	user17863	password	51	40000	F
17864	EQOWRB	VIFATBCAGK	5837560040 Dell Way	\N	RXMBWUX	\N	0	China	2	VIFATBCAGK@dell.com	5837560040	4	6476274020504207	2012/03	user17864	password	79	40000	F
17865	MVGEWB	NCCGDEHJOZ	6930613774 Dell Way	\N	GAADUXL	\N	0	China	2	NCCGDEHJOZ@dell.com	6930613774	1	3747613604646176	2012/11	user17865	password	60	40000	F
17866	KLPHNC	JPJMTRWHQD	8082371118 Dell Way	\N	IQGCOSL	\N	0	Chile	2	JPJMTRWHQD@dell.com	8082371118	4	1637860438320785	2011/04	user17866	password	38	20000	M
17867	SRZFUJ	VDVPUSWKVF	5381212422 Dell Way	\N	BCIQVTV	\N	0	Germany	2	VDVPUSWKVF@dell.com	5381212422	5	3656903609167784	2012/03	user17867	password	46	60000	M
17868	BNDWXZ	ZTOULLFGQG	6813046623 Dell Way	\N	JYXERTT	\N	0	Canada	2	ZTOULLFGQG@dell.com	6813046623	1	9836833065841348	2012/06	user17868	password	55	80000	M
17869	BXJYWJ	RKECVJJLQS	7430441982 Dell Way	\N	KNXBGRG	\N	0	UK	2	RKECVJJLQS@dell.com	7430441982	2	7634939880110324	2008/09	user17869	password	53	80000	M
17870	JCTFLK	QPNLZWXPPH	8465040449 Dell Way	\N	DMJJDPH	\N	0	South Africa	2	QPNLZWXPPH@dell.com	8465040449	1	1296203340403735	2010/07	user17870	password	71	40000	M
17871	VCCGNS	WAEWXBLNJP	3527203007 Dell Way	\N	ASZEIGA	\N	0	Canada	2	WAEWXBLNJP@dell.com	3527203007	1	7419273482169957	2011/10	user17871	password	24	80000	M
17872	ETWSMT	SQPQSBDBQD	4408274366 Dell Way	\N	UQHCWIF	\N	0	Canada	2	SQPQSBDBQD@dell.com	4408274366	5	9555491313338280	2008/01	user17872	password	62	80000	F
17873	JQXWJQ	NZHGAKHROB	3752433890 Dell Way	\N	IWDFFJJ	\N	0	Germany	2	NZHGAKHROB@dell.com	3752433890	2	7729060970712454	2009/12	user17873	password	55	60000	F
17874	DLENCR	MJXNUFFJHN	4588491264 Dell Way	\N	FLSLVCA	\N	0	Canada	2	MJXNUFFJHN@dell.com	4588491264	4	5027763973455876	2009/04	user17874	password	89	80000	F
17875	KUYNML	WKYQQEZXSF	4886165712 Dell Way	\N	JLQENRI	\N	0	UK	2	WKYQQEZXSF@dell.com	4886165712	4	3252048486843705	2011/09	user17875	password	81	20000	F
17876	RBRDMN	OLDEQDCIJM	7467820182 Dell Way	\N	UZQHRZG	\N	0	Australia	2	OLDEQDCIJM@dell.com	7467820182	3	8212911008391530	2010/05	user17876	password	85	80000	F
17877	ZGEMUT	XYXOBAWKMR	7081580261 Dell Way	\N	KDZBCFE	\N	0	South Africa	2	XYXOBAWKMR@dell.com	7081580261	5	3503663031850010	2008/11	user17877	password	82	20000	M
17878	DGJYZG	WXVYYRIKJT	9551417494 Dell Way	\N	OIVRNZM	\N	0	Canada	2	WXVYYRIKJT@dell.com	9551417494	4	2937935722526163	2012/08	user17878	password	38	80000	M
17879	NBTNIP	KDNJVWUEQI	3571675893 Dell Way	\N	NLAALNE	\N	0	China	2	KDNJVWUEQI@dell.com	3571675893	3	2989916421938687	2012/09	user17879	password	86	80000	F
17880	ANSJCD	MQMINGNDPA	6674286097 Dell Way	\N	PQAADFK	\N	0	France	2	MQMINGNDPA@dell.com	6674286097	4	4295343241188675	2009/07	user17880	password	27	60000	M
17881	QGXTKK	KXTXEHBTIQ	7020114118 Dell Way	\N	KJRNOBY	\N	0	Chile	2	KXTXEHBTIQ@dell.com	7020114118	2	5657490583602340	2009/06	user17881	password	21	80000	F
17882	HSVRDF	OWCSDEMLVW	6642434580 Dell Way	\N	UMKJNIO	\N	0	Canada	2	OWCSDEMLVW@dell.com	6642434580	1	4729584930464626	2008/02	user17882	password	33	20000	F
17883	XYCADR	XGJAKWMFTH	3876537287 Dell Way	\N	RDRFLFK	\N	0	Australia	2	XGJAKWMFTH@dell.com	3876537287	5	2157991719897836	2010/01	user17883	password	36	100000	M
17884	EZZIQW	OAXZXKFQRX	3809477179 Dell Way	\N	TICEOMG	\N	0	South Africa	2	OAXZXKFQRX@dell.com	3809477179	2	3930934539996088	2009/08	user17884	password	32	40000	M
17885	EFDVCS	VZRSJWIBTC	9170217054 Dell Way	\N	JWGXJNU	\N	0	Japan	2	VZRSJWIBTC@dell.com	9170217054	1	1008943348191678	2010/04	user17885	password	37	40000	F
17886	MMHPED	OWWYSEZMHJ	2633847362 Dell Way	\N	INGSBBJ	\N	0	UK	2	OWWYSEZMHJ@dell.com	2633847362	2	5601310605183244	2010/08	user17886	password	81	100000	F
17887	JHSOLH	KHFDMFPTOY	4363634034 Dell Way	\N	HVQIWAH	\N	0	Australia	2	KHFDMFPTOY@dell.com	4363634034	5	6092190943192691	2008/09	user17887	password	58	20000	F
17888	WWPHDA	OJDAOTTCSA	5427788433 Dell Way	\N	YIJVJRX	\N	0	Russia	2	OJDAOTTCSA@dell.com	5427788433	3	7536056523211301	2008/01	user17888	password	80	40000	M
17889	SVDVVR	EZSTSLWKMU	9526615707 Dell Way	\N	TWPCNMV	\N	0	Australia	2	EZSTSLWKMU@dell.com	9526615707	3	2800075757317245	2012/05	user17889	password	49	100000	F
17890	GYYCPD	CHWUTTFGNZ	4926287222 Dell Way	\N	CDBQQXQ	\N	0	Germany	2	CHWUTTFGNZ@dell.com	4926287222	5	5923639554064721	2012/04	user17890	password	44	100000	M
17891	HXQXBS	FYNZRTFFSH	4589404908 Dell Way	\N	JUXZROP	\N	0	Canada	2	FYNZRTFFSH@dell.com	4589404908	1	9581500019412488	2011/06	user17891	password	84	40000	M
17892	VWSWOX	UCWLWCQOKA	7578463630 Dell Way	\N	JIAAWPD	\N	0	Chile	2	UCWLWCQOKA@dell.com	7578463630	1	9429951174184680	2009/12	user17892	password	28	20000	M
17893	ZSROPL	RMXNPOCZOL	7143969185 Dell Way	\N	HOLDDPK	\N	0	South Africa	2	RMXNPOCZOL@dell.com	7143969185	2	1857914967928081	2011/06	user17893	password	25	60000	F
17894	VDBLPT	XMGNAIMOUT	6867446909 Dell Way	\N	DGXGVHD	\N	0	Germany	2	XMGNAIMOUT@dell.com	6867446909	2	2780534456484020	2008/04	user17894	password	68	80000	F
17895	VROLKM	XRZYAMNUFQ	3111450686 Dell Way	\N	BCXWKAK	\N	0	Australia	2	XRZYAMNUFQ@dell.com	3111450686	3	2913101421669125	2010/04	user17895	password	79	80000	F
17896	NHOYUM	QUKQGYLMOM	4056849107 Dell Way	\N	PLJZMTB	\N	0	Russia	2	QUKQGYLMOM@dell.com	4056849107	2	3457409418653697	2011/02	user17896	password	89	80000	M
17897	GHPATF	VEWBDHNSUC	4857886529 Dell Way	\N	EDCQWDJ	\N	0	Chile	2	VEWBDHNSUC@dell.com	4857886529	4	8578589597251267	2010/08	user17897	password	60	20000	M
17898	WUXQAS	VWTYEHRYJV	4942049290 Dell Way	\N	CMMZQVF	\N	0	Australia	2	VWTYEHRYJV@dell.com	4942049290	1	6345034593716264	2008/08	user17898	password	75	100000	F
17899	PUDPNY	MGXQOPPXKR	9094859264 Dell Way	\N	KWRARWB	\N	0	Canada	2	MGXQOPPXKR@dell.com	9094859264	4	2502858152147382	2010/06	user17899	password	23	20000	F
17900	WDPJCB	QASEPHCAZM	2815690069 Dell Way	\N	WQNONOR	\N	0	France	2	QASEPHCAZM@dell.com	2815690069	5	9278529964387418	2011/12	user17900	password	85	80000	M
17901	BGEEIV	EAZUICUIPR	7895227339 Dell Way	\N	ZCFMRXW	\N	0	South Africa	2	EAZUICUIPR@dell.com	7895227339	4	5495869222097099	2011/09	user17901	password	29	60000	M
17902	KRYTMD	UMXCOSLEJK	5503549912 Dell Way	\N	HOWYMSU	\N	0	Chile	2	UMXCOSLEJK@dell.com	5503549912	2	9406481941696256	2009/06	user17902	password	48	100000	M
17903	CYPOCJ	AZMPRXTAIA	1660167276 Dell Way	\N	PEZCWUI	\N	0	China	2	AZMPRXTAIA@dell.com	1660167276	2	6357499694917352	2010/09	user17903	password	61	40000	M
17904	OZHQJH	QWWIUQJCRY	6485217251 Dell Way	\N	GQADKJN	\N	0	France	2	QWWIUQJCRY@dell.com	6485217251	1	1031914255581796	2009/09	user17904	password	46	20000	F
17905	KIWTQM	QNUKEDMVCS	5211863637 Dell Way	\N	LDWWMJI	\N	0	Australia	2	QNUKEDMVCS@dell.com	5211863637	2	4401917593553662	2008/09	user17905	password	48	60000	F
17906	TGWKTM	YOXCRJXUCJ	9047080819 Dell Way	\N	XYFKHOM	\N	0	Russia	2	YOXCRJXUCJ@dell.com	9047080819	5	9367081347387284	2011/04	user17906	password	42	80000	F
17907	PQLJDJ	XALPJJJLTH	1257664062 Dell Way	\N	JYRRNEL	\N	0	France	2	XALPJJJLTH@dell.com	1257664062	2	1314828126225620	2009/09	user17907	password	74	40000	F
17908	KURNEO	NQDXZNISUS	2607831737 Dell Way	\N	RMJFQVP	\N	0	Japan	2	NQDXZNISUS@dell.com	2607831737	4	9885960230138154	2012/06	user17908	password	42	20000	M
17909	DVJHKW	XOTXBCQWUI	8150134032 Dell Way	\N	JENZZDR	\N	0	Canada	2	XOTXBCQWUI@dell.com	8150134032	4	1376416284590959	2009/01	user17909	password	34	20000	F
17910	BKLMHJ	ABGBDXYYGH	6665063749 Dell Way	\N	CUHCYZG	\N	0	Russia	2	ABGBDXYYGH@dell.com	6665063749	2	9479028847534210	2011/07	user17910	password	90	80000	M
17911	KFAROB	SVDWSBUZJX	5534504204 Dell Way	\N	TQZRPFK	\N	0	Chile	2	SVDWSBUZJX@dell.com	5534504204	2	8826056462246926	2008/04	user17911	password	64	60000	M
17912	VQKJRD	EUAXWUWFRP	9911877933 Dell Way	\N	VRHLWRR	\N	0	China	2	EUAXWUWFRP@dell.com	9911877933	3	4535606954246760	2009/03	user17912	password	89	20000	F
17913	PLKHPP	BPMXKJCCYY	6834660441 Dell Way	\N	TGKQXCZ	\N	0	South Africa	2	BPMXKJCCYY@dell.com	6834660441	2	2797041126992553	2012/05	user17913	password	35	100000	M
17914	SGGHVI	XIGHRJKQID	2304687229 Dell Way	\N	WSTTVTQ	\N	0	France	2	XIGHRJKQID@dell.com	2304687229	5	3740285671316087	2010/01	user17914	password	29	60000	M
17915	KTBGCZ	OJHFSRVBUS	9251664275 Dell Way	\N	UOLPICB	\N	0	France	2	OJHFSRVBUS@dell.com	9251664275	2	9767483286093920	2012/07	user17915	password	52	80000	M
17916	GVEJUT	SBZLTVMNNG	3383417707 Dell Way	\N	CZWKBXW	\N	0	UK	2	SBZLTVMNNG@dell.com	3383417707	5	9622128969058396	2011/04	user17916	password	70	80000	M
17917	OXXJRP	LQAELNSZUU	8918169705 Dell Way	\N	YQEZNBY	\N	0	Russia	2	LQAELNSZUU@dell.com	8918169705	5	6241301044356078	2008/08	user17917	password	40	80000	F
17918	GQOXGZ	OHDZUVZPQX	7931491484 Dell Way	\N	FVXTWWN	\N	0	Russia	2	OHDZUVZPQX@dell.com	7931491484	1	9417596932034940	2010/06	user17918	password	67	60000	M
17919	IDOODC	VGCQCBFTZL	8073000938 Dell Way	\N	OWEKTRE	\N	0	Germany	2	VGCQCBFTZL@dell.com	8073000938	1	9209095808211716	2009/10	user17919	password	55	100000	F
17920	RKQUMM	BPDDQJWQUL	2088529149 Dell Way	\N	NYWGPAT	\N	0	China	2	BPDDQJWQUL@dell.com	2088529149	4	6417154144030065	2012/03	user17920	password	51	100000	M
17921	WQPJDQ	YGUPPRGJCT	4606875251 Dell Way	\N	IYZYZTI	\N	0	Australia	2	YGUPPRGJCT@dell.com	4606875251	5	9846350737847388	2010/05	user17921	password	88	40000	F
17922	PAQTQO	ZLEPCKZFEH	5185242093 Dell Way	\N	DDFCXOE	\N	0	Chile	2	ZLEPCKZFEH@dell.com	5185242093	1	8778241929132492	2012/02	user17922	password	37	20000	M
17923	GSMXHM	IMCLWBQBJU	3369448984 Dell Way	\N	FOXCCCJ	\N	0	Germany	2	IMCLWBQBJU@dell.com	3369448984	2	4827900275122374	2010/07	user17923	password	56	20000	M
17924	GRRNDA	ZFMWHDXQXC	8423350388 Dell Way	\N	FVFIXPX	\N	0	Canada	2	ZFMWHDXQXC@dell.com	8423350388	2	6139314602129162	2009/10	user17924	password	71	20000	F
17925	KUPNVO	THLAKIQILV	4071688638 Dell Way	\N	DQDAFAF	\N	0	Australia	2	THLAKIQILV@dell.com	4071688638	4	4359855887480080	2008/07	user17925	password	53	40000	M
17926	GVLCKE	JVEUDVDPRG	3326049317 Dell Way	\N	FUHLVMM	\N	0	Canada	2	JVEUDVDPRG@dell.com	3326049317	5	4160306904464960	2011/04	user17926	password	61	80000	M
17927	KCRUGB	PLWTHZIYGO	3861896617 Dell Way	\N	TNZPAMT	\N	0	Chile	2	PLWTHZIYGO@dell.com	3861896617	1	1452325326856225	2011/09	user17927	password	69	40000	F
17928	UYXBZN	NVHUVQSBEL	9120560371 Dell Way	\N	PEBQQUY	\N	0	UK	2	NVHUVQSBEL@dell.com	9120560371	5	6470527974423022	2011/09	user17928	password	80	80000	F
17929	UQNTEB	PLVLBOMGAC	6732992763 Dell Way	\N	KBTBVRA	\N	0	Russia	2	PLVLBOMGAC@dell.com	6732992763	4	4066951152868569	2009/06	user17929	password	22	100000	F
17930	RIAVJP	HFBITOOTQZ	7046490421 Dell Way	\N	UKAQBBJ	\N	0	Japan	2	HFBITOOTQZ@dell.com	7046490421	4	1102761558722704	2008/10	user17930	password	77	40000	F
17931	DKHNAO	TBXMPLGGLA	7648316039 Dell Way	\N	QMRSNAK	\N	0	Canada	2	TBXMPLGGLA@dell.com	7648316039	3	3978901301044971	2010/03	user17931	password	70	100000	F
17932	DGXDUQ	FRDVDJCPKT	3145052000 Dell Way	\N	BBLOCVT	\N	0	South Africa	2	FRDVDJCPKT@dell.com	3145052000	1	4098728762473911	2010/10	user17932	password	39	100000	M
17933	NTCIKH	ANDEXFTIYV	2777698372 Dell Way	\N	KJJNFDI	\N	0	France	2	ANDEXFTIYV@dell.com	2777698372	4	9134119546040894	2008/12	user17933	password	71	100000	M
17934	MAWWIX	KLBIQVQPQB	6319395387 Dell Way	\N	YAOEDXP	\N	0	China	2	KLBIQVQPQB@dell.com	6319395387	3	3917024930939078	2010/03	user17934	password	36	20000	M
17935	HYPPVZ	AXHRTYGJAF	5420496257 Dell Way	\N	JOJMLZV	\N	0	Australia	2	AXHRTYGJAF@dell.com	5420496257	1	6629323230590672	2011/05	user17935	password	70	60000	M
17936	RBHNAH	LIZEHFNHLX	4262683670 Dell Way	\N	VUKHUFJ	\N	0	Chile	2	LIZEHFNHLX@dell.com	4262683670	5	1102262215223163	2011/09	user17936	password	52	60000	F
17937	NSXOAJ	WANEFBLRYH	9214251311 Dell Way	\N	MJPGOYN	\N	0	UK	2	WANEFBLRYH@dell.com	9214251311	3	7307230101432652	2011/01	user17937	password	28	100000	M
17938	WXBXGY	XTCDVOUTWG	6030591980 Dell Way	\N	DLNSKAQ	\N	0	China	2	XTCDVOUTWG@dell.com	6030591980	2	9284704195801170	2010/06	user17938	password	84	20000	F
17939	VDGBCD	VFGQUAKQHN	2663213519 Dell Way	\N	CUFMVWU	\N	0	China	2	VFGQUAKQHN@dell.com	2663213519	4	9404823100194336	2011/08	user17939	password	19	20000	F
17940	EGNGJJ	MPZGQKXYYZ	1053597660 Dell Way	\N	SEMNAHX	\N	0	Canada	2	MPZGQKXYYZ@dell.com	1053597660	5	8728212612215430	2011/11	user17940	password	81	20000	F
17941	CPHMYT	CYZSJWQHWJ	6649241155 Dell Way	\N	LIXLPUR	\N	0	Japan	2	CYZSJWQHWJ@dell.com	6649241155	3	3378961724229157	2010/05	user17941	password	44	60000	F
17942	ZTYYNA	XMTGJKNFTZ	6435843843 Dell Way	\N	ORLELCU	\N	0	Australia	2	XMTGJKNFTZ@dell.com	6435843843	1	6051107463892550	2012/06	user17942	password	21	60000	F
17943	VKIILF	VELEOZKIZZ	9958076825 Dell Way	\N	ZKDLMYO	\N	0	Australia	2	VELEOZKIZZ@dell.com	9958076825	1	1713092872407287	2010/02	user17943	password	57	100000	M
17944	YDHJJC	OVHDVRLURL	5904432821 Dell Way	\N	EUXRTLU	\N	0	Russia	2	OVHDVRLURL@dell.com	5904432821	5	2272805822547525	2011/05	user17944	password	87	80000	F
17945	CYSLBG	GIJBAVWRHB	4161510901 Dell Way	\N	MESFQMX	\N	0	Canada	2	GIJBAVWRHB@dell.com	4161510901	1	8767726546619088	2011/01	user17945	password	56	20000	F
17946	MUONBV	WKXWGTONUA	2701622811 Dell Way	\N	SNFIADM	\N	0	China	2	WKXWGTONUA@dell.com	2701622811	2	1931870129890740	2009/11	user17946	password	31	40000	F
17947	ZWWARS	LOPSIDFCDX	1488587472 Dell Way	\N	QIFQLSZ	\N	0	Japan	2	LOPSIDFCDX@dell.com	1488587472	1	8678055236581714	2012/04	user17947	password	29	40000	F
17948	ADHSWT	HLLPPRSSPI	1435413940 Dell Way	\N	BVZNNYE	\N	0	Germany	2	HLLPPRSSPI@dell.com	1435413940	1	5542912314180285	2009/03	user17948	password	74	60000	F
17949	XXXUQE	FCTUUMNJVO	3045183707 Dell Way	\N	EUBSTFH	\N	0	Russia	2	FCTUUMNJVO@dell.com	3045183707	4	2036120704375207	2009/07	user17949	password	69	60000	F
17950	PMGGRM	JKHDXUNSJR	5254761199 Dell Way	\N	MLKFQRA	\N	0	South Africa	2	JKHDXUNSJR@dell.com	5254761199	1	3433257165830582	2008/11	user17950	password	80	60000	F
17951	IURZHB	KOEIJRASJN	9104326569 Dell Way	\N	DTTULTR	\N	0	UK	2	KOEIJRASJN@dell.com	9104326569	5	9497462911531330	2011/10	user17951	password	52	20000	F
17952	GWDNXO	CCWLTXEDLI	7657102210 Dell Way	\N	WEDHYUF	\N	0	South Africa	2	CCWLTXEDLI@dell.com	7657102210	1	6345009150449187	2010/08	user17952	password	74	80000	M
17953	QVKOKM	QHYKFDNQLK	1546127536 Dell Way	\N	VPSTJXQ	\N	0	Canada	2	QHYKFDNQLK@dell.com	1546127536	2	6980043127201498	2011/12	user17953	password	43	60000	M
17954	EYFPLV	WKGBNUSZFN	2063565046 Dell Way	\N	OXHYVXB	\N	0	South Africa	2	WKGBNUSZFN@dell.com	2063565046	4	6004833658691496	2008/02	user17954	password	26	80000	F
17955	BYWNUT	XBVLVNLABA	7893766399 Dell Way	\N	YIYTGAQ	\N	0	China	2	XBVLVNLABA@dell.com	7893766399	1	5184215247165412	2012/04	user17955	password	33	20000	F
17956	DAWYTU	ZPGUDRVERT	3933318596 Dell Way	\N	NQNTRDC	\N	0	France	2	ZPGUDRVERT@dell.com	3933318596	3	3597301165573299	2011/10	user17956	password	49	100000	M
17957	LWWFRV	UXQXPMCHGP	1070076884 Dell Way	\N	YTIPXLA	\N	0	Chile	2	UXQXPMCHGP@dell.com	1070076884	2	8622051982209087	2011/09	user17957	password	78	80000	F
17958	ROKJKE	HACXMFETUC	1305925606 Dell Way	\N	MDSKOSQ	\N	0	Germany	2	HACXMFETUC@dell.com	1305925606	3	4213015278801322	2011/04	user17958	password	22	100000	M
17959	QJJANQ	BQNOVSHQUU	3574055650 Dell Way	\N	TMEIFVW	\N	0	Chile	2	BQNOVSHQUU@dell.com	3574055650	2	1256682327482849	2010/04	user17959	password	89	60000	M
17960	IYYWOZ	NCNIUVYOPS	2188198066 Dell Way	\N	BUAHPXO	\N	0	South Africa	2	NCNIUVYOPS@dell.com	2188198066	3	5150671604089439	2010/07	user17960	password	21	40000	M
17961	ZITOHG	QVPKQOZGGA	4923710847 Dell Way	\N	AGIPDWM	\N	0	Chile	2	QVPKQOZGGA@dell.com	4923710847	5	7428732355125249	2012/12	user17961	password	23	100000	M
17962	KQMRXD	NMNEBMKHNL	5009519994 Dell Way	\N	OVASRNZ	\N	0	Canada	2	NMNEBMKHNL@dell.com	5009519994	4	2073310630396008	2010/10	user17962	password	18	40000	F
17963	QWWOZJ	ANNCZYJMJY	3509994168 Dell Way	\N	HKQZXPD	\N	0	China	2	ANNCZYJMJY@dell.com	3509994168	2	8079237087164075	2008/03	user17963	password	30	40000	M
17964	BBLBKM	OYONXYAHWI	7084494724 Dell Way	\N	RMIPBLY	\N	0	China	2	OYONXYAHWI@dell.com	7084494724	4	4510224787052721	2012/11	user17964	password	61	100000	M
17965	QGABSO	AGCXECEBKW	2579453114 Dell Way	\N	NSMPELY	\N	0	South Africa	2	AGCXECEBKW@dell.com	2579453114	2	7825531144160778	2008/11	user17965	password	59	20000	M
17966	UBPNQP	TSNYVSZGPM	3849393810 Dell Way	\N	ZBCDMAZ	\N	0	Japan	2	TSNYVSZGPM@dell.com	3849393810	4	7783004804048688	2009/04	user17966	password	77	80000	F
17967	WJPNZJ	FNHBFHHVUG	1400524679 Dell Way	\N	WWJJWIA	\N	0	Canada	2	FNHBFHHVUG@dell.com	1400524679	4	4670923254918307	2009/07	user17967	password	30	60000	F
17968	OAYNJE	ARFGYNBTTY	1706018822 Dell Way	\N	PCHMLHR	\N	0	France	2	ARFGYNBTTY@dell.com	1706018822	1	8247996112797410	2011/03	user17968	password	34	20000	M
17969	GBIPGJ	HMQFZRZTQP	8233598492 Dell Way	\N	VXBHFST	\N	0	China	2	HMQFZRZTQP@dell.com	8233598492	3	9659399084746840	2008/10	user17969	password	23	100000	F
17970	DEPKNW	XECXWCQMRM	1375678563 Dell Way	\N	KSTQLMX	\N	0	Chile	2	XECXWCQMRM@dell.com	1375678563	5	3816547683905810	2012/12	user17970	password	29	100000	F
17971	ILNWIK	ALIWNYJEKT	2513305469 Dell Way	\N	XDJJQHP	\N	0	Japan	2	ALIWNYJEKT@dell.com	2513305469	5	5468592883087695	2008/02	user17971	password	41	40000	F
17972	TTHCEI	NNFALOEWHC	9657572328 Dell Way	\N	ZQLQYBI	\N	0	Canada	2	NNFALOEWHC@dell.com	9657572328	5	3082210794091225	2008/02	user17972	password	52	60000	M
17973	GTZLBM	YGNJVSFCUF	9625395924 Dell Way	\N	TFVRGDU	\N	0	Chile	2	YGNJVSFCUF@dell.com	9625395924	1	3240483975037932	2008/06	user17973	password	70	100000	M
17974	MZDOLB	VZLQRQSLWM	9548007321 Dell Way	\N	QSDWWYB	\N	0	South Africa	2	VZLQRQSLWM@dell.com	9548007321	2	9101116254925728	2010/01	user17974	password	82	20000	M
17975	WIBIKW	HVMYMFJIRZ	3293951070 Dell Way	\N	BVWXTYS	\N	0	Japan	2	HVMYMFJIRZ@dell.com	3293951070	4	2221034980844706	2009/06	user17975	password	39	80000	F
17976	QWRASY	VFWIKFRBFS	9379809393 Dell Way	\N	WBQQAII	\N	0	Chile	2	VFWIKFRBFS@dell.com	9379809393	3	6000886419322342	2010/10	user17976	password	43	80000	F
17977	FLJXJF	CFONLFORYL	8571540337 Dell Way	\N	TOBTWKA	\N	0	South Africa	2	CFONLFORYL@dell.com	8571540337	3	3139411089010537	2010/12	user17977	password	18	100000	F
17978	LJBUOE	ADRMIGEHSX	3312639140 Dell Way	\N	VTRSDRN	\N	0	UK	2	ADRMIGEHSX@dell.com	3312639140	4	6315186137799174	2008/10	user17978	password	58	40000	F
17979	XJAMOB	PGOYMSFEQB	1649293630 Dell Way	\N	YHUCYHC	\N	0	Chile	2	PGOYMSFEQB@dell.com	1649293630	4	4645384836476296	2012/03	user17979	password	71	20000	F
17980	CCQREF	XSEJKJOBLN	4554526292 Dell Way	\N	IFPHMSM	\N	0	Germany	2	XSEJKJOBLN@dell.com	4554526292	5	4805704417172820	2011/08	user17980	password	54	80000	M
17981	PKKTQH	MURXEFYPTG	9308578328 Dell Way	\N	UJNHBAW	\N	0	France	2	MURXEFYPTG@dell.com	9308578328	2	1841047770809382	2010/10	user17981	password	82	40000	F
17982	IRDYZP	TQMYWKOQRJ	8270841928 Dell Way	\N	ZFQAFNM	\N	0	Canada	2	TQMYWKOQRJ@dell.com	8270841928	3	7217339311260731	2010/06	user17982	password	89	100000	M
17983	RDSRSM	IFLEQZVIIU	8658402204 Dell Way	\N	NZUSMHW	\N	0	Chile	2	IFLEQZVIIU@dell.com	8658402204	3	8987584332004190	2009/07	user17983	password	81	20000	F
17984	ZUWSHE	YSJOSEXAYK	5519471437 Dell Way	\N	ZTCMAYT	\N	0	South Africa	2	YSJOSEXAYK@dell.com	5519471437	4	2687999582383781	2008/07	user17984	password	37	40000	M
17985	BCFJHD	CQSUVPUTZU	7036117690 Dell Way	\N	NCGNBAK	\N	0	Germany	2	CQSUVPUTZU@dell.com	7036117690	3	6326237434055657	2008/11	user17985	password	78	80000	M
17986	YXHFBJ	VUDQKYKKSX	4905869555 Dell Way	\N	MZLOAVC	\N	0	Japan	2	VUDQKYKKSX@dell.com	4905869555	4	8791274631861598	2009/07	user17986	password	58	40000	F
17987	MNQNWM	IADSZNCSKP	9661690780 Dell Way	\N	RWDRRGJ	\N	0	Canada	2	IADSZNCSKP@dell.com	9661690780	2	4766980041284114	2010/10	user17987	password	64	100000	F
17988	EPUACC	BFVATXSENK	7178670130 Dell Way	\N	AQCSXLV	\N	0	South Africa	2	BFVATXSENK@dell.com	7178670130	2	4249874102883041	2010/11	user17988	password	40	80000	F
17989	XNBAQD	FLEYJWDWHD	9073310028 Dell Way	\N	NJVKVRH	\N	0	Germany	2	FLEYJWDWHD@dell.com	9073310028	4	9931620672810824	2011/12	user17989	password	71	100000	M
17990	GXWWAC	IEBRBENJHA	4016906450 Dell Way	\N	SCLOUSB	\N	0	Japan	2	IEBRBENJHA@dell.com	4016906450	1	5041063677519560	2009/10	user17990	password	37	20000	F
17991	EAYFCG	KDXMHLVOMO	3235637671 Dell Way	\N	RXCLPED	\N	0	UK	2	KDXMHLVOMO@dell.com	3235637671	3	2885750127490610	2008/11	user17991	password	43	20000	F
17992	JAFLGP	OEBVQXKCLC	2920736199 Dell Way	\N	ZONOSQN	\N	0	UK	2	OEBVQXKCLC@dell.com	2920736199	4	1137378328479826	2008/01	user17992	password	25	20000	F
17993	DGWKWK	OYGFVQHGTG	1472230058 Dell Way	\N	UGVNXIM	\N	0	Canada	2	OYGFVQHGTG@dell.com	1472230058	3	2602156266570091	2008/08	user17993	password	35	60000	M
17994	NJDJUS	HAXDREJKLE	7297482492 Dell Way	\N	RHSPQES	\N	0	Japan	2	HAXDREJKLE@dell.com	7297482492	5	8150826980825514	2009/02	user17994	password	41	20000	M
17995	SEAMXH	NULEZVPLZG	5239669252 Dell Way	\N	SRWJWOA	\N	0	Germany	2	NULEZVPLZG@dell.com	5239669252	5	9012840976007284	2011/02	user17995	password	86	40000	M
17996	DGIAOV	VZAUUPFTWY	2205235378 Dell Way	\N	LSHIHIX	\N	0	Russia	2	VZAUUPFTWY@dell.com	2205235378	4	4403549034614116	2009/09	user17996	password	62	20000	M
17997	WLWKGS	JGMDWSXTQJ	4358494113 Dell Way	\N	MYRUGPO	\N	0	China	2	JGMDWSXTQJ@dell.com	4358494113	5	6838773152325303	2008/07	user17997	password	73	100000	F
17998	FWULOD	SAHPTEIJNV	1720997468 Dell Way	\N	HFPOUDX	\N	0	Canada	2	SAHPTEIJNV@dell.com	1720997468	3	3372303148731589	2011/04	user17998	password	35	20000	M
17999	CUZQYS	RFIKJRUXMC	1986423939 Dell Way	\N	CBQWFOA	\N	0	Chile	2	RFIKJRUXMC@dell.com	1986423939	2	9294143253937364	2010/07	user17999	password	86	100000	M
18000	TYHRRY	WZJGQEDDHG	4909801158 Dell Way	\N	EXCKLDS	\N	0	Germany	2	WZJGQEDDHG@dell.com	4909801158	4	1002739055082201	2012/07	user18000	password	88	60000	F
18001	XWYOVV	OFBFKFIRLM	2933766882 Dell Way	\N	ONXARPP	\N	0	Canada	2	OFBFKFIRLM@dell.com	2933766882	3	1694544910918921	2011/07	user18001	password	67	20000	F
18002	OAAKVP	PXUZCCQNPF	4552515432 Dell Way	\N	BMFSBVV	\N	0	Chile	2	PXUZCCQNPF@dell.com	4552515432	5	1517160378862172	2012/07	user18002	password	26	40000	F
18003	DLNZAD	WUDYWTLLZN	9681250270 Dell Way	\N	YFFZABH	\N	0	France	2	WUDYWTLLZN@dell.com	9681250270	2	4133838803041726	2010/06	user18003	password	72	80000	M
18004	EFOEIL	YLJVFVHEJF	8362714762 Dell Way	\N	JOFKQMU	\N	0	Germany	2	YLJVFVHEJF@dell.com	8362714762	1	2288189640734344	2009/11	user18004	password	78	100000	F
18005	ALGJWF	UGAACIELNO	9242027262 Dell Way	\N	ASYQFTG	\N	0	Australia	2	UGAACIELNO@dell.com	9242027262	2	3627751857042313	2012/03	user18005	password	29	100000	F
18006	PCPMIK	SIKVQPGEDH	5988287421 Dell Way	\N	XCYCWEC	\N	0	Russia	2	SIKVQPGEDH@dell.com	5988287421	2	6376269747503102	2011/07	user18006	password	52	20000	F
18007	PPQXZJ	GJEXZLBCSY	5664503017 Dell Way	\N	FQACUDW	\N	0	China	2	GJEXZLBCSY@dell.com	5664503017	3	2051967220380902	2008/12	user18007	password	26	40000	M
18008	SWKSFR	CJOBVPENOJ	8179678732 Dell Way	\N	DPLYSIH	\N	0	Chile	2	CJOBVPENOJ@dell.com	8179678732	3	3720881984569132	2011/07	user18008	password	56	40000	F
18009	KRYPJA	ZXCUNGHBPL	1799349013 Dell Way	\N	QBJJKRP	\N	0	Canada	2	ZXCUNGHBPL@dell.com	1799349013	5	9400768245570364	2011/06	user18009	password	32	100000	M
18010	WVKFWJ	DYEQEMSUXJ	2954565619 Dell Way	\N	WHSGZIL	\N	0	Australia	2	DYEQEMSUXJ@dell.com	2954565619	2	7078917251434178	2011/07	user18010	password	57	60000	F
18011	JWSFGV	DKMIWECUOZ	1484699803 Dell Way	\N	BGFBPRC	\N	0	South Africa	2	DKMIWECUOZ@dell.com	1484699803	4	5049596014898271	2011/04	user18011	password	84	20000	M
18012	UUWAQA	LCJIGLCULE	1822403526 Dell Way	\N	BQFRIIM	\N	0	China	2	LCJIGLCULE@dell.com	1822403526	5	1061487441416829	2010/10	user18012	password	25	20000	M
18013	XYQNZB	PIKWUMQFRS	7787278677 Dell Way	\N	WXJEFVO	\N	0	China	2	PIKWUMQFRS@dell.com	7787278677	3	7469138710759581	2010/09	user18013	password	76	20000	M
18014	TUBTWR	BGNWTECLXY	3372486645 Dell Way	\N	IHDODSW	\N	0	South Africa	2	BGNWTECLXY@dell.com	3372486645	3	5024119568057358	2012/05	user18014	password	63	60000	F
18015	KOWHGY	NTVHYXSVWA	1401592349 Dell Way	\N	DZPGRLC	\N	0	UK	2	NTVHYXSVWA@dell.com	1401592349	3	8961834953632207	2010/03	user18015	password	45	60000	M
18016	YLWFKJ	ZFRXCJTYKW	7817981061 Dell Way	\N	YZCQLFP	\N	0	France	2	ZFRXCJTYKW@dell.com	7817981061	3	9239207497797908	2012/11	user18016	password	52	60000	M
18017	XJAHTZ	NKXPUQOEMN	2780279898 Dell Way	\N	EPDPUSC	\N	0	Germany	2	NKXPUQOEMN@dell.com	2780279898	1	5361200825776905	2008/06	user18017	password	90	100000	F
18018	JWSDVF	OSVIJKMWXQ	3963499474 Dell Way	\N	LBGGUIU	\N	0	UK	2	OSVIJKMWXQ@dell.com	3963499474	2	1377230473328381	2012/04	user18018	password	83	40000	M
18019	TXUPDI	IZQSJDOHTA	4153478272 Dell Way	\N	JAGEIBD	\N	0	Japan	2	IZQSJDOHTA@dell.com	4153478272	1	5224756559822709	2011/02	user18019	password	67	40000	M
18020	PCMTKV	SBNCECKYCT	3462765190 Dell Way	\N	YJYGKCY	\N	0	Russia	2	SBNCECKYCT@dell.com	3462765190	2	4585852360818535	2009/01	user18020	password	68	40000	M
18021	USLEND	FBGKDQIFKH	8680292949 Dell Way	\N	OJNZLLS	\N	0	Japan	2	FBGKDQIFKH@dell.com	8680292949	1	1611067546531558	2012/10	user18021	password	39	80000	M
18022	AAUNEA	OLKRCTXNAL	3351324900 Dell Way	\N	WOKHADZ	\N	0	South Africa	2	OLKRCTXNAL@dell.com	3351324900	1	8081111326813699	2008/05	user18022	password	46	80000	F
18023	LLWPLL	AWCDPZQPLM	7991024664 Dell Way	\N	DVTDZTA	\N	0	Chile	2	AWCDPZQPLM@dell.com	7991024664	4	3868236093781889	2008/03	user18023	password	90	60000	M
18024	LIFXTG	TWJJWAYHMC	1415395696 Dell Way	\N	DGGCZGJ	\N	0	Russia	2	TWJJWAYHMC@dell.com	1415395696	4	8796243319287897	2009/08	user18024	password	42	100000	F
18025	RBALIT	HSCESBLFDP	7568075338 Dell Way	\N	LKSKQBE	\N	0	Japan	2	HSCESBLFDP@dell.com	7568075338	1	9338360873516650	2009/05	user18025	password	74	60000	F
18026	WNLEHT	XJXQLJWPYH	9168500939 Dell Way	\N	ZRSQSWI	\N	0	France	2	XJXQLJWPYH@dell.com	9168500939	2	8658781079575420	2009/01	user18026	password	43	40000	M
18027	WTBDNZ	NKPYULOTTN	7437214308 Dell Way	\N	KMDDIMP	\N	0	Chile	2	NKPYULOTTN@dell.com	7437214308	3	5694446461740882	2011/10	user18027	password	77	80000	M
18028	ORUBRI	MHGGTVAMIK	6230031630 Dell Way	\N	YMOHYDO	\N	0	Japan	2	MHGGTVAMIK@dell.com	6230031630	1	4716737543232739	2009/11	user18028	password	20	20000	F
18029	SVNJDA	QKHJFHWOSV	7567242621 Dell Way	\N	BGCAKRR	\N	0	UK	2	QKHJFHWOSV@dell.com	7567242621	1	4124476778786630	2011/02	user18029	password	46	20000	M
18030	FPFJQW	UXFZFCOXXP	4446378636 Dell Way	\N	DAPORHN	\N	0	China	2	UXFZFCOXXP@dell.com	4446378636	5	1129238063003867	2010/03	user18030	password	24	40000	F
18031	SOVIKP	GPPLSDJPTN	4723491777 Dell Way	\N	PJBGQOR	\N	0	Australia	2	GPPLSDJPTN@dell.com	4723491777	4	5830509330146015	2011/10	user18031	password	81	20000	F
18032	KYUUOA	KDMCHVSBIH	9018088567 Dell Way	\N	KJOBYFC	\N	0	China	2	KDMCHVSBIH@dell.com	9018088567	4	9963148443028332	2011/06	user18032	password	26	20000	M
18033	BXSPYD	TLGAGYBPGM	2858953690 Dell Way	\N	ZUNXAPF	\N	0	UK	2	TLGAGYBPGM@dell.com	2858953690	2	6112774873152376	2011/05	user18033	password	68	80000	F
18034	PIZOLT	ASTHQVWWHV	2562808214 Dell Way	\N	RUSSKYQ	\N	0	Germany	2	ASTHQVWWHV@dell.com	2562808214	1	3623369383160025	2010/11	user18034	password	83	100000	F
18035	FXBRQB	JKIAFFXNAP	1922852484 Dell Way	\N	HTHRSXH	\N	0	South Africa	2	JKIAFFXNAP@dell.com	1922852484	3	4554000831209123	2012/06	user18035	password	40	60000	M
18036	FNJWPS	GYTMDQZEFH	8402884480 Dell Way	\N	YNZQKGN	\N	0	Germany	2	GYTMDQZEFH@dell.com	8402884480	5	5545207455288619	2009/03	user18036	password	89	100000	F
18037	NJHCCN	AVZELYIRGG	4113390630 Dell Way	\N	EFXPLLD	\N	0	Chile	2	AVZELYIRGG@dell.com	4113390630	4	6079785814508796	2010/08	user18037	password	58	100000	F
18038	XHFZUG	UUKGTTXZAC	4792212457 Dell Way	\N	EXRQJUX	\N	0	Japan	2	UUKGTTXZAC@dell.com	4792212457	3	3330824789591134	2008/01	user18038	password	36	20000	M
18039	NIXIOR	DZYWSVWTYB	1326106144 Dell Way	\N	QQRZKOR	\N	0	South Africa	2	DZYWSVWTYB@dell.com	1326106144	5	8735210759565235	2008/03	user18039	password	90	100000	M
18040	IWBXOE	WMBPIXIGYZ	6694931517 Dell Way	\N	WPZHERD	\N	0	Chile	2	WMBPIXIGYZ@dell.com	6694931517	5	3454010720364749	2012/12	user18040	password	35	60000	F
18041	CQFQVC	CWRLUARSAO	9564317595 Dell Way	\N	IAVNSZT	\N	0	China	2	CWRLUARSAO@dell.com	9564317595	1	2475871181581169	2012/04	user18041	password	71	40000	F
18042	JKZFMC	BENWFFPFTX	2717240543 Dell Way	\N	GPLYOEG	\N	0	Germany	2	BENWFFPFTX@dell.com	2717240543	3	4913870639633388	2010/02	user18042	password	65	80000	M
18043	BUTOWV	TKRYPGEJDK	1180609632 Dell Way	\N	YPJNTPA	\N	0	UK	2	TKRYPGEJDK@dell.com	1180609632	3	4591723276302219	2008/02	user18043	password	31	80000	F
18044	ZLTVGN	GXMVEQEIBD	1664561803 Dell Way	\N	XKQRAQQ	\N	0	Australia	2	GXMVEQEIBD@dell.com	1664561803	1	2978179209399968	2008/03	user18044	password	85	40000	F
18045	JCAQPG	OBBSSGAUJX	2796813809 Dell Way	\N	FZOGPEH	\N	0	Japan	2	OBBSSGAUJX@dell.com	2796813809	3	8771473005879671	2010/06	user18045	password	33	60000	M
18046	IPLYVZ	AXRTERNNPT	8107241516 Dell Way	\N	NDZDIHV	\N	0	Germany	2	AXRTERNNPT@dell.com	8107241516	4	9481588718481364	2009/11	user18046	password	56	20000	F
18047	DMDYLD	WDWAUKOKEC	7280344774 Dell Way	\N	OEFWLAK	\N	0	Chile	2	WDWAUKOKEC@dell.com	7280344774	2	5095440846867860	2010/11	user18047	password	53	100000	F
18048	ZYZKCV	OZWIKLTONH	9434127788 Dell Way	\N	SSEETPK	\N	0	France	2	OZWIKLTONH@dell.com	9434127788	5	1296904210001230	2012/05	user18048	password	79	100000	F
18049	UUSXQG	XNPHYIWLQP	9764302228 Dell Way	\N	EUTYJDJ	\N	0	Chile	2	XNPHYIWLQP@dell.com	9764302228	2	2046035573817789	2009/03	user18049	password	86	80000	F
18050	SIYJOV	WEDUNZGDPL	2158643161 Dell Way	\N	XIJGLTO	\N	0	France	2	WEDUNZGDPL@dell.com	2158643161	4	7636120571754874	2009/08	user18050	password	43	60000	F
18051	RJSGEO	KIJXIPBXBY	5056253798 Dell Way	\N	GKFRDUD	\N	0	Chile	2	KIJXIPBXBY@dell.com	5056253798	5	6833628009073437	2008/03	user18051	password	22	60000	M
18052	KCCPRN	YALGQMERLK	1474822367 Dell Way	\N	CQCGKFN	\N	0	South Africa	2	YALGQMERLK@dell.com	1474822367	1	9448826922569424	2009/03	user18052	password	43	20000	M
18053	LFGCTE	DEKTRPLCZN	5229414597 Dell Way	\N	TBUEGHB	\N	0	China	2	DEKTRPLCZN@dell.com	5229414597	5	6067746073938907	2011/04	user18053	password	67	40000	M
18054	XOXQTA	VDUNTFPSSJ	5912775970 Dell Way	\N	UMNAUOI	\N	0	Chile	2	VDUNTFPSSJ@dell.com	5912775970	5	9676295396406204	2012/08	user18054	password	39	80000	F
18055	WODPPZ	TJMMOBFHLZ	3242820455 Dell Way	\N	UYAPNIW	\N	0	Australia	2	TJMMOBFHLZ@dell.com	3242820455	5	9405776679981500	2012/02	user18055	password	61	40000	M
18056	ELPTLJ	CXWRZBZKBU	1384116671 Dell Way	\N	JBJWKFX	\N	0	Japan	2	CXWRZBZKBU@dell.com	1384116671	5	5369477280415595	2008/06	user18056	password	76	20000	M
18057	GTISDL	PZDOBCZDWI	9624953699 Dell Way	\N	EGEPMCG	\N	0	Germany	2	PZDOBCZDWI@dell.com	9624953699	4	7054956219159067	2010/07	user18057	password	78	20000	M
18058	PJMSUC	SYRUAQXXYC	6716795544 Dell Way	\N	EDRQGXD	\N	0	Canada	2	SYRUAQXXYC@dell.com	6716795544	5	6458731531165541	2008/08	user18058	password	62	100000	F
18059	ZLYUNR	SEMTVKRUMV	4490964552 Dell Way	\N	XELDCPJ	\N	0	Russia	2	SEMTVKRUMV@dell.com	4490964552	5	8963709335774184	2008/07	user18059	password	79	40000	M
18060	HFIVXA	AKUVULPHGN	9745866345 Dell Way	\N	LSRNHAG	\N	0	Japan	2	AKUVULPHGN@dell.com	9745866345	1	7266512974165381	2010/12	user18060	password	87	20000	F
18061	EKCCLC	MFYGQNOXAZ	9422837038 Dell Way	\N	PSNWSUO	\N	0	Japan	2	MFYGQNOXAZ@dell.com	9422837038	2	3077644266188145	2012/03	user18061	password	41	20000	F
18062	SHMEKY	JIFAVTXWTN	2667325848 Dell Way	\N	PHKHBYZ	\N	0	UK	2	JIFAVTXWTN@dell.com	2667325848	2	9265780360437932	2009/07	user18062	password	26	80000	F
18063	KGKUEU	CKVYDSVWGK	8883535660 Dell Way	\N	DQSFORF	\N	0	Russia	2	CKVYDSVWGK@dell.com	8883535660	1	2274525026325136	2010/03	user18063	password	84	80000	M
18064	DCLIWN	SSMWKHTRSX	4707711570 Dell Way	\N	HKCWBHP	\N	0	UK	2	SSMWKHTRSX@dell.com	4707711570	4	4091077073942870	2011/08	user18064	password	18	40000	M
18065	CSDZGW	RSTCAMTSJA	3133030574 Dell Way	\N	DLWETMD	\N	0	Canada	2	RSTCAMTSJA@dell.com	3133030574	3	8213279560673983	2012/06	user18065	password	24	80000	M
18066	UWNATE	TMGUYAMHAP	4377520027 Dell Way	\N	TXUNKXR	\N	0	Japan	2	TMGUYAMHAP@dell.com	4377520027	3	5785353255923838	2012/07	user18066	password	35	40000	F
18067	CXJVCD	HJXGJKOKAI	9305260993 Dell Way	\N	IVVSSMJ	\N	0	Australia	2	HJXGJKOKAI@dell.com	9305260993	5	9442559702321888	2010/02	user18067	password	42	100000	F
18068	GEBJHJ	TFPDQENQMW	8147843257 Dell Way	\N	LHOETXG	\N	0	Japan	2	TFPDQENQMW@dell.com	8147843257	1	2229327817913145	2012/07	user18068	password	86	20000	M
18069	CFEKOX	QEAGIOWUKI	9368604221 Dell Way	\N	CZMVWTN	\N	0	Japan	2	QEAGIOWUKI@dell.com	9368604221	4	6284680574201048	2010/07	user18069	password	71	40000	M
18070	YKDMHT	QIAZWXUGFW	8549971826 Dell Way	\N	FRSCLFT	\N	0	China	2	QIAZWXUGFW@dell.com	8549971826	2	8354672393295915	2010/01	user18070	password	22	20000	F
18071	MFMTZD	BZDYWXEBTK	6587812735 Dell Way	\N	TLNFQGO	\N	0	France	2	BZDYWXEBTK@dell.com	6587812735	2	9189204609021544	2011/06	user18071	password	19	80000	M
18072	GFRFIT	FMRBJWDDHX	1337618579 Dell Way	\N	PUCGBRS	\N	0	Japan	2	FMRBJWDDHX@dell.com	1337618579	4	4315827602520585	2010/08	user18072	password	23	40000	M
18073	HADQUI	CLKLHOOPME	7808039528 Dell Way	\N	JPKKGDB	\N	0	China	2	CLKLHOOPME@dell.com	7808039528	3	8003111045807601	2010/07	user18073	password	29	40000	M
18074	ELKYUM	KFYSUNHHRQ	6109937045 Dell Way	\N	WBBDFDL	\N	0	UK	2	KFYSUNHHRQ@dell.com	6109937045	2	4279475971590728	2008/05	user18074	password	68	100000	M
18075	DHNYUY	ETQYGYFYPC	9427701571 Dell Way	\N	AQGFTSD	\N	0	China	2	ETQYGYFYPC@dell.com	9427701571	3	4710615325719118	2009/03	user18075	password	39	100000	F
18076	PKHJIL	CZKJXQHMTH	2448709888 Dell Way	\N	CZMWSQF	\N	0	Japan	2	CZKJXQHMTH@dell.com	2448709888	4	9594667226541788	2009/11	user18076	password	79	80000	F
18077	GZWPLY	OWHMMPYGXB	7768824337 Dell Way	\N	FJYYADO	\N	0	Canada	2	OWHMMPYGXB@dell.com	7768824337	3	5973111512139440	2011/05	user18077	password	36	20000	M
18078	GZFSYT	OGFBVEHSFN	5672534565 Dell Way	\N	CELDHZI	\N	0	Australia	2	OGFBVEHSFN@dell.com	5672534565	5	7388997083995492	2012/02	user18078	password	80	60000	F
18079	VRCULR	AQSWVAPBNS	1640469100 Dell Way	\N	FYWNYEO	\N	0	France	2	AQSWVAPBNS@dell.com	1640469100	2	4124094069469720	2009/02	user18079	password	78	80000	M
18080	NSTYKU	PCRKDHLQAR	1147019201 Dell Way	\N	PWENBTA	\N	0	Canada	2	PCRKDHLQAR@dell.com	1147019201	2	3996762260794640	2008/03	user18080	password	87	20000	M
18081	RWQBRG	EIQHQCYQUN	4706781292 Dell Way	\N	MZBNSBR	\N	0	Russia	2	EIQHQCYQUN@dell.com	4706781292	5	8774203779641540	2010/12	user18081	password	89	40000	M
18082	VYRNEV	WVDMYBCSPP	7978759550 Dell Way	\N	RQDKSUC	\N	0	Canada	2	WVDMYBCSPP@dell.com	7978759550	5	7471631631255151	2011/12	user18082	password	18	40000	M
18083	YZICVE	YZQWBTPQJH	7911564582 Dell Way	\N	HMRAHUD	\N	0	Australia	2	YZQWBTPQJH@dell.com	7911564582	5	7849784034304322	2011/11	user18083	password	23	60000	M
18084	BVXWZW	WQTXKIOTQV	8304441537 Dell Way	\N	FHVNCZO	\N	0	South Africa	2	WQTXKIOTQV@dell.com	8304441537	2	6134670386556537	2011/05	user18084	password	24	60000	F
18085	XKIXGE	NZCXIQRYLX	3319673765 Dell Way	\N	FHKHGYD	\N	0	Australia	2	NZCXIQRYLX@dell.com	3319673765	4	7709044621326030	2011/10	user18085	password	33	20000	M
18086	PLQWPD	VSBDISBUPH	5088058833 Dell Way	\N	CAPJYTL	\N	0	Chile	2	VSBDISBUPH@dell.com	5088058833	1	8671811867039652	2009/05	user18086	password	87	100000	M
18087	JPVZTR	RVUAOWUEDW	8345462031 Dell Way	\N	ESFDLQI	\N	0	UK	2	RVUAOWUEDW@dell.com	8345462031	1	2524279354605824	2009/02	user18087	password	29	20000	M
18088	TAMNRE	JMFXIZCMWG	8916217895 Dell Way	\N	FCJQTSO	\N	0	Germany	2	JMFXIZCMWG@dell.com	8916217895	4	7775277368258686	2008/11	user18088	password	86	60000	M
18089	ZAEREN	DKKMJMYGTE	1746854214 Dell Way	\N	IDUBVJQ	\N	0	Japan	2	DKKMJMYGTE@dell.com	1746854214	2	7341626242734493	2012/04	user18089	password	33	80000	F
18090	FTYKGC	UROEENKXRT	8225627918 Dell Way	\N	AMVVVLN	\N	0	UK	2	UROEENKXRT@dell.com	8225627918	2	8904551065992565	2008/06	user18090	password	52	40000	M
18091	GICMKX	EZCIMNGEGG	8735488355 Dell Way	\N	QBCMNQJ	\N	0	China	2	EZCIMNGEGG@dell.com	8735488355	2	4828983782790601	2009/09	user18091	password	78	100000	M
18092	ECMOZQ	OBZAPFEVLV	9352095589 Dell Way	\N	XOHKERS	\N	0	Australia	2	OBZAPFEVLV@dell.com	9352095589	1	4056506584864110	2011/12	user18092	password	42	80000	F
18093	LDSKTG	MTHBYLXKHV	2155504658 Dell Way	\N	YOGCFZD	\N	0	Canada	2	MTHBYLXKHV@dell.com	2155504658	3	8344511456321926	2008/10	user18093	password	51	40000	F
18094	PYRIED	BLFAXDKEZJ	1785750947 Dell Way	\N	TFMYEPC	\N	0	China	2	BLFAXDKEZJ@dell.com	1785750947	5	4777152880560607	2012/05	user18094	password	66	20000	M
18095	PUHUYJ	GEKDIVIHEB	1332637369 Dell Way	\N	MQARGDZ	\N	0	China	2	GEKDIVIHEB@dell.com	1332637369	3	3219050048850477	2010/01	user18095	password	45	40000	M
18096	ERLCAS	HKWPFEWKGJ	5061016831 Dell Way	\N	BGBIJAR	\N	0	France	2	HKWPFEWKGJ@dell.com	5061016831	5	8504883654415608	2010/04	user18096	password	32	20000	F
18097	WQOXJW	IFLOKIYQRA	9009711491 Dell Way	\N	XSIHTZS	\N	0	Chile	2	IFLOKIYQRA@dell.com	9009711491	3	7638783758040518	2008/09	user18097	password	86	80000	M
18098	PFMYBV	DNJNVIEMIB	6063850760 Dell Way	\N	FQIZPAF	\N	0	France	2	DNJNVIEMIB@dell.com	6063850760	5	7089024623855949	2009/11	user18098	password	41	100000	F
18099	NKKPFO	COBXWGKFHQ	7714451028 Dell Way	\N	VQPLRVY	\N	0	Chile	2	COBXWGKFHQ@dell.com	7714451028	3	5702080904506147	2011/11	user18099	password	48	20000	F
18100	VMAAAC	PCAMIKRQAM	4960710248 Dell Way	\N	GQXXLVD	\N	0	Canada	2	PCAMIKRQAM@dell.com	4960710248	4	8312382116913796	2009/02	user18100	password	82	80000	M
18101	JVXJYN	MYZUJRLKDR	4890365063 Dell Way	\N	ABPMXTR	\N	0	China	2	MYZUJRLKDR@dell.com	4890365063	3	7331849720794708	2010/05	user18101	password	54	60000	M
18102	IJDGWP	FWKONVZRNA	7069039350 Dell Way	\N	TDMQXEZ	\N	0	China	2	FWKONVZRNA@dell.com	7069039350	4	8636334950570018	2008/03	user18102	password	37	100000	M
18103	QYUMNZ	IXOWTNNHOG	6003381292 Dell Way	\N	KAWHFWQ	\N	0	South Africa	2	IXOWTNNHOG@dell.com	6003381292	3	9534901935141536	2011/09	user18103	password	72	40000	F
18104	RBVFAE	DPAWDNDRUO	9468857885 Dell Way	\N	SRVXNMV	\N	0	Australia	2	DPAWDNDRUO@dell.com	9468857885	4	8474064507056028	2011/07	user18104	password	24	20000	F
18105	DXJEBM	TCJWQMNKBG	7441122023 Dell Way	\N	CWDPJYR	\N	0	Chile	2	TCJWQMNKBG@dell.com	7441122023	3	9795944038312884	2009/08	user18105	password	20	60000	M
18106	YUXZHR	CQNTDBDEHG	1453259196 Dell Way	\N	BLVKKNS	\N	0	Canada	2	CQNTDBDEHG@dell.com	1453259196	4	4059172964654863	2011/09	user18106	password	72	60000	M
18107	NIQUZS	LMLOOPTWVV	6329051075 Dell Way	\N	HRFSFXV	\N	0	Chile	2	LMLOOPTWVV@dell.com	6329051075	1	9287632451392712	2009/11	user18107	password	42	100000	F
18108	QOFQHR	DSFRIZNEUV	5182943641 Dell Way	\N	WANBXII	\N	0	Germany	2	DSFRIZNEUV@dell.com	5182943641	2	8282006393186749	2009/07	user18108	password	71	80000	F
18109	HZVORY	HXQQWDURZQ	3324558436 Dell Way	\N	RMSPUAC	\N	0	Chile	2	HXQQWDURZQ@dell.com	3324558436	5	6436576015315951	2012/08	user18109	password	45	20000	M
18110	JWMAVT	YMJUPELOVC	7054388299 Dell Way	\N	BNRVOUB	\N	0	South Africa	2	YMJUPELOVC@dell.com	7054388299	4	6763254090677947	2009/01	user18110	password	67	40000	F
18111	OSMKLK	WVEMAQBVSC	6827914019 Dell Way	\N	JKXYEZT	\N	0	South Africa	2	WVEMAQBVSC@dell.com	6827914019	2	2465477311518043	2011/01	user18111	password	46	20000	M
18112	CPAOZX	JEJKVKGOMP	6997273960 Dell Way	\N	YKNDJHZ	\N	0	Australia	2	JEJKVKGOMP@dell.com	6997273960	1	7571134293451906	2011/07	user18112	password	81	40000	M
18113	MKEMHO	QQYLAEANUY	3048410036 Dell Way	\N	YICIPBJ	\N	0	Chile	2	QQYLAEANUY@dell.com	3048410036	1	1129302356392145	2011/12	user18113	password	45	40000	F
18114	TOWADN	RBZSGZGBYE	9348296102 Dell Way	\N	KAMACWH	\N	0	China	2	RBZSGZGBYE@dell.com	9348296102	2	1884210955351591	2012/09	user18114	password	54	40000	F
18115	BEMESD	GRWNRCOQGZ	5913806873 Dell Way	\N	QTZTPGC	\N	0	Germany	2	GRWNRCOQGZ@dell.com	5913806873	1	4695138967130333	2009/09	user18115	password	68	80000	M
18116	WDXOHE	GDSYFHOMGF	2864358471 Dell Way	\N	GFYWLAK	\N	0	UK	2	GDSYFHOMGF@dell.com	2864358471	5	2960962160024792	2012/07	user18116	password	81	80000	F
18117	AOXHSE	KKCQSQDYVJ	4804582637 Dell Way	\N	DUFPUQP	\N	0	Australia	2	KKCQSQDYVJ@dell.com	4804582637	5	9032917193137110	2012/09	user18117	password	55	40000	M
18118	BFZUJK	FMAXCDVYNZ	9676186356 Dell Way	\N	STONJEN	\N	0	Russia	2	FMAXCDVYNZ@dell.com	9676186356	3	7268622070550919	2011/12	user18118	password	89	40000	M
18119	FITOSY	BTVDXRBLQU	3263967519 Dell Way	\N	EFHNJVH	\N	0	China	2	BTVDXRBLQU@dell.com	3263967519	5	9752633604686708	2008/12	user18119	password	41	20000	F
18120	QXSJWT	DRXBJZMZUQ	4756844346 Dell Way	\N	FCEOXLW	\N	0	Canada	2	DRXBJZMZUQ@dell.com	4756844346	5	4086854878813028	2009/03	user18120	password	54	60000	M
18121	KGFGAI	YYKIYXISNN	8265017486 Dell Way	\N	URBSDYW	\N	0	Germany	2	YYKIYXISNN@dell.com	8265017486	1	9357115549501032	2012/09	user18121	password	52	80000	F
18122	TZKUII	STRQQZJDMD	8981849873 Dell Way	\N	VOVZNRN	\N	0	China	2	STRQQZJDMD@dell.com	8981849873	3	3620200323872268	2010/12	user18122	password	24	80000	M
18123	CCKKLD	ECUUBDYOHU	7465222124 Dell Way	\N	CCTPUGX	\N	0	Japan	2	ECUUBDYOHU@dell.com	7465222124	2	3455654751043767	2011/04	user18123	password	89	40000	F
18124	BSUNWZ	PQTRURFBLI	1508526633 Dell Way	\N	EEYYLWQ	\N	0	Canada	2	PQTRURFBLI@dell.com	1508526633	5	8233344625681640	2009/11	user18124	password	24	80000	M
18125	UOMRNB	HGTBXZDJHH	8035613983 Dell Way	\N	NFFZBWD	\N	0	Canada	2	HGTBXZDJHH@dell.com	8035613983	5	5359484186861664	2011/01	user18125	password	34	80000	M
18126	UCNHEU	NYWLXZUFGI	4638429042 Dell Way	\N	KMHMJLQ	\N	0	Canada	2	NYWLXZUFGI@dell.com	4638429042	1	8235563960857690	2010/05	user18126	password	50	40000	F
18127	OUKTPX	RLJOLDTRME	4753013745 Dell Way	\N	DURNGIQ	\N	0	Japan	2	RLJOLDTRME@dell.com	4753013745	3	1784026500768959	2011/11	user18127	password	46	100000	F
18128	EGEUEV	FNKRREIDIM	1480119562 Dell Way	\N	YAZEIQU	\N	0	Russia	2	FNKRREIDIM@dell.com	1480119562	5	5537997166160495	2012/04	user18128	password	44	40000	F
18129	PNGTIM	HSDYWLCFYA	9062187968 Dell Way	\N	GXFPNAI	\N	0	Germany	2	HSDYWLCFYA@dell.com	9062187968	5	5640485659241677	2008/03	user18129	password	81	80000	M
18130	JWOSIW	LLVIXXOVYU	6292413915 Dell Way	\N	TDKHDTW	\N	0	Australia	2	LLVIXXOVYU@dell.com	6292413915	2	2982156116515398	2011/04	user18130	password	80	80000	M
18131	SEJBAU	NWDKTRGSMA	6024224118 Dell Way	\N	WWHAQEB	\N	0	Chile	2	NWDKTRGSMA@dell.com	6024224118	2	1047467174474149	2012/02	user18131	password	62	60000	M
18132	UVXVQK	RTVLLCDYCA	4142703315 Dell Way	\N	VKALPBQ	\N	0	Canada	2	RTVLLCDYCA@dell.com	4142703315	4	9623208956327290	2010/04	user18132	password	48	40000	F
18133	GGWWQO	QMZBPDZSDU	5633924799 Dell Way	\N	CEGSFWV	\N	0	Germany	2	QMZBPDZSDU@dell.com	5633924799	4	1478383410722017	2011/03	user18133	password	45	100000	F
18134	QSIHGY	TGAJKABOVE	5571563105 Dell Way	\N	SBWYXSM	\N	0	France	2	TGAJKABOVE@dell.com	5571563105	3	2810458596795797	2011/12	user18134	password	19	20000	M
18135	SMVZLP	GLYRLZFHEX	8845799942 Dell Way	\N	IBVFTIR	\N	0	Chile	2	GLYRLZFHEX@dell.com	8845799942	5	9847483769990504	2012/11	user18135	password	29	40000	M
18136	REPCTW	OSNASSHWPP	4140819545 Dell Way	\N	XLVRTMY	\N	0	Japan	2	OSNASSHWPP@dell.com	4140819545	5	4903603956568986	2009/01	user18136	password	75	100000	M
18137	ZLVTIK	LVKENRADHY	5348718508 Dell Way	\N	PCQIPOZ	\N	0	UK	2	LVKENRADHY@dell.com	5348718508	3	2653654771856963	2010/03	user18137	password	20	40000	F
18138	MDXUNI	PXNDPNHWMW	6146351138 Dell Way	\N	ZDFPREO	\N	0	Canada	2	PXNDPNHWMW@dell.com	6146351138	4	7619235127232970	2011/10	user18138	password	20	100000	F
18139	EVAREQ	ORUEFBBSXA	9059485579 Dell Way	\N	VDQNHER	\N	0	South Africa	2	ORUEFBBSXA@dell.com	9059485579	3	6704258048441262	2011/06	user18139	password	58	100000	M
18140	JXHONW	FHAKJBDHCY	6187830951 Dell Way	\N	KSLSXDP	\N	0	Russia	2	FHAKJBDHCY@dell.com	6187830951	2	4986010063439608	2008/10	user18140	password	41	80000	F
18141	GXSUUX	BUILWLSYKD	6706344719 Dell Way	\N	RWVPZKJ	\N	0	Germany	2	BUILWLSYKD@dell.com	6706344719	5	6450293490197510	2010/02	user18141	password	36	60000	F
18142	EGDYEF	TNRPYJOING	1158363873 Dell Way	\N	EIVETFT	\N	0	China	2	TNRPYJOING@dell.com	1158363873	2	8217081755399705	2008/08	user18142	password	44	60000	M
18143	QSSUXM	HPBGYPOMWT	1492115352 Dell Way	\N	URYOWSZ	\N	0	South Africa	2	HPBGYPOMWT@dell.com	1492115352	4	1532605590298771	2011/02	user18143	password	62	60000	M
18144	HENFQV	URBTHQFEJA	3950917093 Dell Way	\N	VIPSAOP	\N	0	Australia	2	URBTHQFEJA@dell.com	3950917093	4	7588057397864760	2010/04	user18144	password	30	20000	M
18145	JSUZNP	RPJZFPDPPY	9431062530 Dell Way	\N	XFRXUHZ	\N	0	Canada	2	RPJZFPDPPY@dell.com	9431062530	4	5978215831331909	2009/11	user18145	password	72	80000	F
18146	MOFAEW	PNVUCZJSXG	8824845461 Dell Way	\N	XPERWEU	\N	0	Russia	2	PNVUCZJSXG@dell.com	8824845461	2	1011963176075369	2011/01	user18146	password	74	100000	M
18147	IFOMCD	AYYCXHUVOS	5414430914 Dell Way	\N	KTJGXEB	\N	0	Russia	2	AYYCXHUVOS@dell.com	5414430914	1	5753776317462326	2010/11	user18147	password	56	20000	F
18148	SRRVVR	TTUQAOLPGW	3197254200 Dell Way	\N	IQDGUEA	\N	0	Chile	2	TTUQAOLPGW@dell.com	3197254200	3	8742224757093937	2008/01	user18148	password	89	40000	M
18149	RYPMPI	FJZGYLWFHF	1035762886 Dell Way	\N	WKLQPLY	\N	0	South Africa	2	FJZGYLWFHF@dell.com	1035762886	4	9288742722477764	2008/10	user18149	password	31	100000	F
18150	CLXSUD	CUJBFFGMKC	5518392716 Dell Way	\N	XWTNISI	\N	0	China	2	CUJBFFGMKC@dell.com	5518392716	2	4549657282885164	2009/06	user18150	password	36	80000	M
18151	SQHNTJ	HCLMISZTUX	1050033893 Dell Way	\N	POKYHTG	\N	0	Russia	2	HCLMISZTUX@dell.com	1050033893	4	1508758250158280	2010/11	user18151	password	74	20000	M
18152	KHDDQL	GCYPUYJPVZ	8353039845 Dell Way	\N	DFXLZEF	\N	0	UK	2	GCYPUYJPVZ@dell.com	8353039845	2	4773160450160504	2011/01	user18152	password	48	40000	F
18153	SMOJYV	LWLFUUUQTY	8329520388 Dell Way	\N	VQJUUOU	\N	0	Japan	2	LWLFUUUQTY@dell.com	8329520388	1	4097285210154951	2012/08	user18153	password	69	40000	F
18154	FWRDRC	ACHUXCKQAG	1300252113 Dell Way	\N	GKBBYVR	\N	0	Russia	2	ACHUXCKQAG@dell.com	1300252113	1	6475918313488365	2011/09	user18154	password	82	100000	M
18155	TQBKSB	NAWKCGBDNI	1798800183 Dell Way	\N	NOJLKBF	\N	0	France	2	NAWKCGBDNI@dell.com	1798800183	5	1793706366792321	2012/09	user18155	password	21	80000	F
18156	RUWJVK	KRVMYWPLEC	6548066161 Dell Way	\N	AOOLQUW	\N	0	Russia	2	KRVMYWPLEC@dell.com	6548066161	5	5686992854345590	2009/01	user18156	password	36	80000	M
18157	BQBXAL	PVYNSNZWQA	3584303017 Dell Way	\N	LELBZIT	\N	0	Germany	2	PVYNSNZWQA@dell.com	3584303017	2	9278012553695590	2009/07	user18157	password	68	100000	M
18158	IAMJMB	FKPXYPUOPG	4045526920 Dell Way	\N	TBHSKBH	\N	0	Japan	2	FKPXYPUOPG@dell.com	4045526920	2	9817657010629774	2012/12	user18158	password	87	60000	F
18159	ZYQMAV	WPTVEOJUUC	4213472260 Dell Way	\N	WCVGDDY	\N	0	France	2	WPTVEOJUUC@dell.com	4213472260	5	4262564132455737	2009/11	user18159	password	78	60000	M
18160	UEJUZG	JTBOIKJCNF	4324555644 Dell Way	\N	FIMJMLV	\N	0	South Africa	2	JTBOIKJCNF@dell.com	4324555644	1	2008539050351828	2009/01	user18160	password	65	20000	M
18161	VMOUSY	OTNWEWZRCF	6148044052 Dell Way	\N	APONAJI	\N	0	France	2	OTNWEWZRCF@dell.com	6148044052	3	6929952760692687	2010/02	user18161	password	75	40000	M
18162	GYSZXH	SKDWHDOJIP	8839993509 Dell Way	\N	ZWCAGLK	\N	0	South Africa	2	SKDWHDOJIP@dell.com	8839993509	1	4836945450864732	2012/11	user18162	password	77	100000	F
18163	UPCRWV	CASJDHTMWT	3187807410 Dell Way	\N	JYTQJEL	\N	0	Chile	2	CASJDHTMWT@dell.com	3187807410	5	2898740078322589	2008/09	user18163	password	23	40000	F
18164	RIENEG	NWQRDJDZCN	5400139665 Dell Way	\N	YWDIAPO	\N	0	Chile	2	NWQRDJDZCN@dell.com	5400139665	4	4311092703137547	2008/11	user18164	password	62	80000	M
18165	YVACBN	ZSECBICEWB	7507529658 Dell Way	\N	AZJBPYI	\N	0	Australia	2	ZSECBICEWB@dell.com	7507529658	4	3494079021271318	2010/04	user18165	password	87	20000	F
18166	UDIVQH	OVKPENUAOV	8780566310 Dell Way	\N	AYWQWES	\N	0	Germany	2	OVKPENUAOV@dell.com	8780566310	5	2604461985640228	2008/12	user18166	password	38	40000	M
18167	KROBZC	WJSBWMCLIC	4812743556 Dell Way	\N	JFTGKLV	\N	0	Chile	2	WJSBWMCLIC@dell.com	4812743556	1	4608074286486954	2009/04	user18167	password	74	20000	M
18168	MPSLRP	VKRSWTDFWN	6515327465 Dell Way	\N	KPTUBPB	\N	0	France	2	VKRSWTDFWN@dell.com	6515327465	3	8377040784340353	2012/03	user18168	password	81	60000	M
18169	MIDEXY	OPRLJVQFIB	4262622076 Dell Way	\N	VCWWRXI	\N	0	Chile	2	OPRLJVQFIB@dell.com	4262622076	1	2823904661461711	2010/01	user18169	password	75	40000	F
18170	CKQAJF	PBQYWGEFHZ	4119162375 Dell Way	\N	HDWZBFH	\N	0	France	2	PBQYWGEFHZ@dell.com	4119162375	3	1076709882821887	2009/04	user18170	password	38	100000	F
18171	SNKBSA	DIYZPDEXDM	2719387043 Dell Way	\N	BZLCFSN	\N	0	Germany	2	DIYZPDEXDM@dell.com	2719387043	3	9211574525572360	2010/10	user18171	password	74	100000	M
18172	HFPAFS	IESYHWVLJW	9938400194 Dell Way	\N	LUYQNME	\N	0	Russia	2	IESYHWVLJW@dell.com	9938400194	1	2434085349086672	2012/11	user18172	password	89	40000	F
18173	EXEKQN	OILWFGIOCT	7085479137 Dell Way	\N	IBKWNPO	\N	0	Germany	2	OILWFGIOCT@dell.com	7085479137	4	3836252025328577	2010/09	user18173	password	64	80000	M
18174	OWHEKW	MVTRBBFDVO	7395651267 Dell Way	\N	FGLSVZF	\N	0	France	2	MVTRBBFDVO@dell.com	7395651267	3	1365016866941005	2010/03	user18174	password	72	40000	M
18175	QPWAMJ	VFAXHGBCVG	7624482420 Dell Way	\N	JGZEGFR	\N	0	UK	2	VFAXHGBCVG@dell.com	7624482420	4	4235509042162448	2012/06	user18175	password	66	80000	F
18176	GNCTWY	YXVGDWJZDS	2975098344 Dell Way	\N	FCWLHNK	\N	0	Australia	2	YXVGDWJZDS@dell.com	2975098344	4	9326262757182122	2011/06	user18176	password	58	80000	M
18177	BWLYUJ	VQQZMZYPRE	7823199646 Dell Way	\N	SNPZBAZ	\N	0	Chile	2	VQQZMZYPRE@dell.com	7823199646	5	9401849540416152	2008/06	user18177	password	68	100000	M
18178	OHMIRH	ZHHLHFBYJU	6731885149 Dell Way	\N	LZTMZST	\N	0	Russia	2	ZHHLHFBYJU@dell.com	6731885149	4	9297620369121432	2008/05	user18178	password	75	80000	M
18179	CCHUKG	CRSJXTHGNT	7229437540 Dell Way	\N	GHGFAZZ	\N	0	Japan	2	CRSJXTHGNT@dell.com	7229437540	5	7708433484192938	2008/09	user18179	password	45	20000	M
18180	MHOXNQ	OFZLZHSNAZ	1527602293 Dell Way	\N	UGFUGEL	\N	0	UK	2	OFZLZHSNAZ@dell.com	1527602293	1	1112337187398225	2011/07	user18180	password	19	60000	F
18181	HCYUSN	ASYZZRMZQH	7112318289 Dell Way	\N	GVBMANL	\N	0	Australia	2	ASYZZRMZQH@dell.com	7112318289	3	8271145525388420	2009/06	user18181	password	42	40000	M
18182	KFODTO	WSOVJBVAIC	4949786637 Dell Way	\N	WKOWXZY	\N	0	Germany	2	WSOVJBVAIC@dell.com	4949786637	4	8254100627731533	2012/01	user18182	password	25	80000	F
18183	IFQBUM	TIIDJDDRGZ	5644670869 Dell Way	\N	BUWYUUN	\N	0	Chile	2	TIIDJDDRGZ@dell.com	5644670869	2	2265395805239677	2010/05	user18183	password	75	20000	M
18184	ZRUTEO	CMRLQVCWVE	9609685275 Dell Way	\N	RRDMMQS	\N	0	UK	2	CMRLQVCWVE@dell.com	9609685275	5	6088679047301412	2009/08	user18184	password	63	20000	M
18185	IXKMMM	YDXOZAKUFC	2150926362 Dell Way	\N	MIOYYHY	\N	0	UK	2	YDXOZAKUFC@dell.com	2150926362	3	3557891418226063	2011/02	user18185	password	47	60000	F
18186	IUXUGW	YEKXFVSKXE	6188649884 Dell Way	\N	SMDRTBO	\N	0	South Africa	2	YEKXFVSKXE@dell.com	6188649884	5	6852492358069868	2011/04	user18186	password	21	20000	M
18187	WBJDXH	HIFMDXWBCP	7140606960 Dell Way	\N	OGGHHVE	\N	0	South Africa	2	HIFMDXWBCP@dell.com	7140606960	5	6300404856912792	2012/11	user18187	password	71	60000	M
18188	UWWRDD	ZJQDGNFICT	1613701949 Dell Way	\N	PIBXEGT	\N	0	South Africa	2	ZJQDGNFICT@dell.com	1613701949	2	8053621224127711	2012/02	user18188	password	39	80000	M
18189	ENOIRO	RISXVXGXRV	8653725270 Dell Way	\N	GTSKZMG	\N	0	Australia	2	RISXVXGXRV@dell.com	8653725270	1	9920279132202268	2012/04	user18189	password	67	100000	F
18190	FJUXYM	FQKAOQYFME	8845432949 Dell Way	\N	YFPXSVY	\N	0	Germany	2	FQKAOQYFME@dell.com	8845432949	5	5465747084468603	2009/08	user18190	password	40	80000	M
18191	RMTQZY	GJZUZXAMBZ	8194728242 Dell Way	\N	SRXKMWY	\N	0	China	2	GJZUZXAMBZ@dell.com	8194728242	3	6117442650254816	2010/10	user18191	password	37	40000	F
18192	TABSYI	BXDBVDOXCG	1475835496 Dell Way	\N	OZQBWPK	\N	0	Japan	2	BXDBVDOXCG@dell.com	1475835496	5	1666666981764137	2012/03	user18192	password	43	40000	M
18193	JISIRU	FUWBYKYBQM	9405562208 Dell Way	\N	BHNXXYO	\N	0	UK	2	FUWBYKYBQM@dell.com	9405562208	4	7875264843925834	2008/12	user18193	password	20	20000	F
18194	JXQBRW	WNXUYWWPIY	1091127292 Dell Way	\N	WWVUVJS	\N	0	Russia	2	WNXUYWWPIY@dell.com	1091127292	3	9480941400863232	2012/07	user18194	password	26	40000	M
18195	AYYSUV	GSQEOMTXKQ	6512928782 Dell Way	\N	UGKPQDJ	\N	0	Japan	2	GSQEOMTXKQ@dell.com	6512928782	2	6595428515691311	2008/06	user18195	password	85	20000	F
18196	WZDRUJ	JKOYXIVIYQ	9483187763 Dell Way	\N	OJGEMQV	\N	0	Australia	2	JKOYXIVIYQ@dell.com	9483187763	3	3069054604973644	2009/05	user18196	password	36	100000	F
18197	GZXAJH	LXGJFCRESF	7336193948 Dell Way	\N	NYKAOGD	\N	0	Germany	2	LXGJFCRESF@dell.com	7336193948	2	9102357849478724	2008/08	user18197	password	71	40000	M
18198	SGXCOI	AURGXJKPOY	5039404680 Dell Way	\N	OZZDGCQ	\N	0	UK	2	AURGXJKPOY@dell.com	5039404680	3	1295305680483579	2008/04	user18198	password	44	100000	F
18199	QUCEDC	ZVIWETMTSA	4121597486 Dell Way	\N	TRDZUUX	\N	0	Chile	2	ZVIWETMTSA@dell.com	4121597486	5	3548858438152820	2011/04	user18199	password	32	80000	M
18200	ZSDDVC	YEZCXLVQMP	4878033758 Dell Way	\N	HQOBKMH	\N	0	Russia	2	YEZCXLVQMP@dell.com	4878033758	3	4574637181591243	2011/10	user18200	password	20	80000	M
18201	TVXPYV	TYYRJUHVJP	5699681274 Dell Way	\N	LXQWJYQ	\N	0	South Africa	2	TYYRJUHVJP@dell.com	5699681274	1	6102299354970456	2009/01	user18201	password	37	20000	M
18202	CYKBTE	ZSVJMCEVRQ	2960846774 Dell Way	\N	SINCHEX	\N	0	South Africa	2	ZSVJMCEVRQ@dell.com	2960846774	3	1886841171421110	2009/10	user18202	password	29	20000	M
18203	COXWSX	OOGARLWJBP	1969854299 Dell Way	\N	RPSZUQU	\N	0	UK	2	OOGARLWJBP@dell.com	1969854299	5	3581107194535434	2012/01	user18203	password	48	80000	F
18204	ZQZROO	GUPXFMGHBY	6017304635 Dell Way	\N	WTXRJRQ	\N	0	France	2	GUPXFMGHBY@dell.com	6017304635	5	4092508552130312	2010/05	user18204	password	23	80000	F
18205	SSAGHG	BWDGIKNKIK	6917607935 Dell Way	\N	DGBNXSZ	\N	0	France	2	BWDGIKNKIK@dell.com	6917607935	2	1560535671655088	2008/05	user18205	password	74	40000	F
18206	MIKUOL	RSRZCFKLQN	4367378377 Dell Way	\N	RSBOLBB	\N	0	Australia	2	RSRZCFKLQN@dell.com	4367378377	1	1885060561820864	2011/11	user18206	password	49	100000	F
18207	TIEITV	BLVDRFOHTG	9731657510 Dell Way	\N	AUULVWN	\N	0	Chile	2	BLVDRFOHTG@dell.com	9731657510	4	9985686777159572	2012/01	user18207	password	84	40000	M
18208	FKEZFF	KBJCGYJAEK	9938429032 Dell Way	\N	UZVQVJW	\N	0	Russia	2	KBJCGYJAEK@dell.com	9938429032	5	6938164460938425	2008/10	user18208	password	84	100000	M
18209	IAZOGJ	PPLWNVWRGR	1306563544 Dell Way	\N	QBIMLEH	\N	0	France	2	PPLWNVWRGR@dell.com	1306563544	5	5250840418040753	2012/11	user18209	password	42	100000	F
18210	JUSPEH	EQDSLAKRRA	7530511429 Dell Way	\N	TZNEDUP	\N	0	Canada	2	EQDSLAKRRA@dell.com	7530511429	1	9917996329255404	2010/06	user18210	password	76	80000	M
18211	OLKTTO	JXHVXRNOSG	2167434738 Dell Way	\N	OFLSABW	\N	0	Russia	2	JXHVXRNOSG@dell.com	2167434738	5	3693356250412762	2010/09	user18211	password	20	40000	F
18212	MSZFHI	DODAGQPYXE	6565405443 Dell Way	\N	DJWDKTW	\N	0	Germany	2	DODAGQPYXE@dell.com	6565405443	1	1693945629987865	2009/03	user18212	password	48	60000	M
18213	DNXLVB	AZCGQSENWI	5842883089 Dell Way	\N	WSMHMJU	\N	0	Australia	2	AZCGQSENWI@dell.com	5842883089	5	4420712117105723	2011/04	user18213	password	84	60000	F
18214	KJWGKW	GMCWFHKBQH	3013530376 Dell Way	\N	UCOGLJJ	\N	0	UK	2	GMCWFHKBQH@dell.com	3013530376	4	7669616102706642	2010/08	user18214	password	31	100000	F
18215	OVIYRO	LULQCVSSCM	8416443796 Dell Way	\N	UQTGZCG	\N	0	Chile	2	LULQCVSSCM@dell.com	8416443796	5	7603613920975477	2010/02	user18215	password	67	60000	M
18216	MWREKD	ZVTBRMUUYO	1407584018 Dell Way	\N	KSVKUBQ	\N	0	Japan	2	ZVTBRMUUYO@dell.com	1407584018	2	1752688052598387	2009/01	user18216	password	62	100000	M
18217	MPSWSR	SMTKYNEXCP	1067917383 Dell Way	\N	PXAKZQA	\N	0	Australia	2	SMTKYNEXCP@dell.com	1067917383	1	3068921948783100	2008/09	user18217	password	29	60000	F
18218	THBMZU	YTEXGIUJYK	9240681417 Dell Way	\N	GYUGPVG	\N	0	Germany	2	YTEXGIUJYK@dell.com	9240681417	3	6792035538703204	2011/08	user18218	password	35	100000	F
18219	OWWOQU	HURODMXCXE	2108275366 Dell Way	\N	ARKPNQE	\N	0	France	2	HURODMXCXE@dell.com	2108275366	5	1460628955624997	2011/01	user18219	password	80	20000	M
18220	SZEIUL	DMZHZWJWAK	1220191837 Dell Way	\N	OLZBBEM	\N	0	Canada	2	DMZHZWJWAK@dell.com	1220191837	3	9570768572390080	2008/05	user18220	password	25	80000	F
18221	CWLWIO	JHWIEGEFQS	7984604147 Dell Way	\N	QQTSVGX	\N	0	South Africa	2	JHWIEGEFQS@dell.com	7984604147	5	9471510301344098	2008/12	user18221	password	65	40000	F
18222	NRXVGG	DDPHJTNZME	6685987553 Dell Way	\N	QGWLMUH	\N	0	Chile	2	DDPHJTNZME@dell.com	6685987553	2	4718178832437843	2010/11	user18222	password	66	80000	F
18223	IOGPVJ	SKRCDFBPJS	6942999863 Dell Way	\N	VGDIALO	\N	0	Japan	2	SKRCDFBPJS@dell.com	6942999863	5	3054761280771345	2010/08	user18223	password	80	100000	M
18224	KFPFPI	PHKTMMJVEF	1797459292 Dell Way	\N	CINCTCT	\N	0	France	2	PHKTMMJVEF@dell.com	1797459292	5	9542974822688848	2011/10	user18224	password	84	80000	F
18225	CILSQA	ZAULNEHRJJ	2352458193 Dell Way	\N	ZXLTZED	\N	0	Australia	2	ZAULNEHRJJ@dell.com	2352458193	1	8369803333655001	2012/12	user18225	password	58	20000	F
18226	WPUNQT	OLFBPMTZWS	7158513593 Dell Way	\N	WIMVNPX	\N	0	Japan	2	OLFBPMTZWS@dell.com	7158513593	4	6603679451625795	2011/04	user18226	password	76	80000	F
18227	KPRBJG	NOICBBBYUX	4859963137 Dell Way	\N	GGTTVRK	\N	0	Germany	2	NOICBBBYUX@dell.com	4859963137	1	2813415828626603	2011/10	user18227	password	89	100000	F
18228	OPIXVV	MDYNFAMZYS	8886276777 Dell Way	\N	FSLBJWP	\N	0	South Africa	2	MDYNFAMZYS@dell.com	8886276777	4	5805300609674305	2011/10	user18228	password	49	100000	F
18229	AHGWCS	ZBGEBSEZLK	8348762175 Dell Way	\N	RWLBSAW	\N	0	Japan	2	ZBGEBSEZLK@dell.com	8348762175	3	3781003980431706	2010/10	user18229	password	37	100000	M
18230	OESQWR	RDWTWBSHLK	7514224825 Dell Way	\N	EWLWXIM	\N	0	Russia	2	RDWTWBSHLK@dell.com	7514224825	4	3794443226419389	2010/01	user18230	password	34	60000	M
18231	KCGGUY	KRRGSJODUS	8673368935 Dell Way	\N	AFPYOBR	\N	0	Chile	2	KRRGSJODUS@dell.com	8673368935	5	8436963035259397	2012/03	user18231	password	34	60000	M
18232	ITWDRG	UJNNSBRNTR	3436469605 Dell Way	\N	TIQHKHO	\N	0	Chile	2	UJNNSBRNTR@dell.com	3436469605	2	2417821255046874	2010/08	user18232	password	66	20000	M
18233	KXBCEV	LRIETARNRK	6578374448 Dell Way	\N	VISGPGM	\N	0	South Africa	2	LRIETARNRK@dell.com	6578374448	4	4211348520591855	2009/04	user18233	password	48	20000	M
18234	IFVNBG	FKLYKDLCOH	6893147924 Dell Way	\N	KGNAMAX	\N	0	Australia	2	FKLYKDLCOH@dell.com	6893147924	2	3916635411325842	2012/09	user18234	password	53	80000	F
18235	RNNTUS	DFRNIDPXKA	2732726637 Dell Way	\N	DYAPZYS	\N	0	Japan	2	DFRNIDPXKA@dell.com	2732726637	1	6201611890457571	2012/07	user18235	password	37	100000	F
18236	UKYOCB	TUPCXFZIGC	4950725675 Dell Way	\N	GHSFFKV	\N	0	China	2	TUPCXFZIGC@dell.com	4950725675	3	3400076903402805	2012/09	user18236	password	28	20000	F
18237	OCZRET	LTWIZWQFZX	4495533381 Dell Way	\N	MRDRCZC	\N	0	Germany	2	LTWIZWQFZX@dell.com	4495533381	2	5420128111261875	2008/06	user18237	password	64	60000	F
18238	SNRWHD	QDLPACVZAH	4739350103 Dell Way	\N	RDZUCBI	\N	0	France	2	QDLPACVZAH@dell.com	4739350103	5	6047097821254284	2012/06	user18238	password	23	100000	F
18239	PQBWTR	AFHAICZIKR	6240191418 Dell Way	\N	LJLOLTB	\N	0	South Africa	2	AFHAICZIKR@dell.com	6240191418	4	7810833414085210	2008/09	user18239	password	69	20000	F
18240	JGECXE	IEFQHEZRWK	6648050313 Dell Way	\N	AHZLBAH	\N	0	Japan	2	IEFQHEZRWK@dell.com	6648050313	1	7174644088372589	2009/10	user18240	password	82	80000	F
18241	DTFAYO	FDFMIEDEPE	9835420006 Dell Way	\N	MOQOPYF	\N	0	Chile	2	FDFMIEDEPE@dell.com	9835420006	5	5712616319768131	2011/10	user18241	password	27	100000	M
18242	XBYVQD	ZVQHZUMOYZ	6933751338 Dell Way	\N	DPNSNTX	\N	0	France	2	ZVQHZUMOYZ@dell.com	6933751338	3	3149181689135730	2010/07	user18242	password	24	40000	F
18243	EHHULG	QCOPWAEVAI	4626505626 Dell Way	\N	LNAYHYL	\N	0	UK	2	QCOPWAEVAI@dell.com	4626505626	4	4598044807091355	2012/10	user18243	password	73	60000	M
18244	BTSNZJ	POYMODIPLT	8505572026 Dell Way	\N	CMSKLEJ	\N	0	South Africa	2	POYMODIPLT@dell.com	8505572026	4	8470164302736522	2011/07	user18244	password	37	60000	M
18245	AHCZQR	NPECSNREHU	3950794470 Dell Way	\N	RZFDDOZ	\N	0	UK	2	NPECSNREHU@dell.com	3950794470	5	6228960301261396	2012/01	user18245	password	27	60000	F
18246	KNBAEP	PJSIWKMDFE	1715431913 Dell Way	\N	DKHHZHG	\N	0	China	2	PJSIWKMDFE@dell.com	1715431913	5	2457623443100601	2008/12	user18246	password	60	40000	F
18247	CHJHXZ	QQHNBURGYU	2448075043 Dell Way	\N	RGBRNIZ	\N	0	Japan	2	QQHNBURGYU@dell.com	2448075043	1	7819172066636384	2008/09	user18247	password	90	60000	M
18248	HWCFVS	WDFXXXDWRV	6334006691 Dell Way	\N	DTMQCLG	\N	0	Chile	2	WDFXXXDWRV@dell.com	6334006691	1	4353352310135961	2009/12	user18248	password	79	20000	F
18249	SFNNXJ	RDGOAKLSFO	5087694333 Dell Way	\N	MSFPDLV	\N	0	Russia	2	RDGOAKLSFO@dell.com	5087694333	2	1475319699384272	2010/01	user18249	password	30	80000	M
18250	JGHHQY	KWNLHZENNR	3572440193 Dell Way	\N	FTGIFCC	\N	0	Japan	2	KWNLHZENNR@dell.com	3572440193	1	1868795725982636	2009/04	user18250	password	79	20000	M
18251	CKYSIJ	PWVXVZKJQP	2325527985 Dell Way	\N	CXYHZAY	\N	0	Chile	2	PWVXVZKJQP@dell.com	2325527985	1	6415015396662057	2010/11	user18251	password	69	20000	M
18252	CBSLLI	HGFDGPNWEP	9079136541 Dell Way	\N	UCXTDWA	\N	0	Chile	2	HGFDGPNWEP@dell.com	9079136541	4	7513267846778036	2011/04	user18252	password	79	80000	F
18253	XMWIUE	PZHVPUSUKM	8767062402 Dell Way	\N	XIGAEGH	\N	0	Australia	2	PZHVPUSUKM@dell.com	8767062402	1	8734115072991700	2008/11	user18253	password	63	60000	M
18254	CLCXPS	XXNMSFGDSD	5012807234 Dell Way	\N	LYEQELS	\N	0	Australia	2	XXNMSFGDSD@dell.com	5012807234	3	3031486617401242	2009/03	user18254	password	77	20000	F
18255	GEEWWC	UJOMPVPHZB	9549502372 Dell Way	\N	FDRKOKL	\N	0	Australia	2	UJOMPVPHZB@dell.com	9549502372	4	3802439503371716	2008/06	user18255	password	45	60000	M
18256	OQQKSK	UHXJCMRBOX	4967305037 Dell Way	\N	FFHTQTU	\N	0	Germany	2	UHXJCMRBOX@dell.com	4967305037	1	7362370451446623	2012/06	user18256	password	28	80000	F
18257	TIKMTF	TQOVDGXRDC	7581048157 Dell Way	\N	XLWNFQC	\N	0	Japan	2	TQOVDGXRDC@dell.com	7581048157	4	6225522660650313	2008/12	user18257	password	38	20000	M
18258	QPEJUX	ZJTDPRUTTS	2051708383 Dell Way	\N	EQGJHIA	\N	0	Australia	2	ZJTDPRUTTS@dell.com	2051708383	4	2796182644087821	2008/11	user18258	password	46	80000	M
18259	AYWUWW	EPZUHUNBNS	7556263410 Dell Way	\N	RTCYBDY	\N	0	Canada	2	EPZUHUNBNS@dell.com	7556263410	1	3061151601839810	2011/07	user18259	password	90	20000	M
18260	YAJUWO	KWIRRWSEPK	5185410452 Dell Way	\N	XRIZUHD	\N	0	Germany	2	KWIRRWSEPK@dell.com	5185410452	2	2376183308660984	2008/05	user18260	password	38	60000	F
18261	HYBEML	AVDSSVWHFU	3492698752 Dell Way	\N	ZOTUWXI	\N	0	China	2	AVDSSVWHFU@dell.com	3492698752	3	4314471037592739	2011/09	user18261	password	87	100000	F
18262	XZEKLF	GOXYKUFQPE	7523659713 Dell Way	\N	FIYCGGL	\N	0	Germany	2	GOXYKUFQPE@dell.com	7523659713	4	2485009962227195	2010/10	user18262	password	24	60000	M
18263	BRBNXH	BVFMPLCFQH	6505326497 Dell Way	\N	OPJUVVI	\N	0	Germany	2	BVFMPLCFQH@dell.com	6505326497	3	1337095511145889	2009/07	user18263	password	56	20000	M
18264	FBDCJF	XPRNAUSRCG	8510622295 Dell Way	\N	GLBCHJR	\N	0	South Africa	2	XPRNAUSRCG@dell.com	8510622295	4	3213842917233705	2010/03	user18264	password	37	20000	F
18265	IFNSKL	HCZIWRZYYG	7090702995 Dell Way	\N	KZIRIZO	\N	0	Canada	2	HCZIWRZYYG@dell.com	7090702995	5	5996823610272259	2012/02	user18265	password	61	40000	F
18266	UWDFIK	HHTEYTDWZO	6891750573 Dell Way	\N	WHGEGVI	\N	0	UK	2	HHTEYTDWZO@dell.com	6891750573	5	8619886157102884	2011/06	user18266	password	31	20000	F
18267	BHMJSU	QLYPECMDRI	7255670290 Dell Way	\N	LYNSUVQ	\N	0	France	2	QLYPECMDRI@dell.com	7255670290	3	2472251691389829	2008/09	user18267	password	41	60000	M
18268	PXCIRT	TQJYTWCKFN	4197913067 Dell Way	\N	JSFDNWO	\N	0	Chile	2	TQJYTWCKFN@dell.com	4197913067	4	4460405436810106	2008/01	user18268	password	77	80000	M
18269	SWYJPS	ZZQTVSDAGM	8750433708 Dell Way	\N	TLPGIEM	\N	0	Japan	2	ZZQTVSDAGM@dell.com	8750433708	5	7377601618412883	2012/09	user18269	password	52	60000	F
18270	IMTYET	YUMTNQUTDN	2125880020 Dell Way	\N	FTUOXGF	\N	0	Russia	2	YUMTNQUTDN@dell.com	2125880020	5	6784723363351077	2011/05	user18270	password	30	20000	M
18271	QYRVRP	QEJDUEXYRD	8644904763 Dell Way	\N	RMROTXH	\N	0	South Africa	2	QEJDUEXYRD@dell.com	8644904763	5	6931943978182972	2009/02	user18271	password	79	100000	M
18272	URPLGF	QQJLUGJMKA	8488073827 Dell Way	\N	YCPRAWN	\N	0	South Africa	2	QQJLUGJMKA@dell.com	8488073827	1	1961290823761373	2012/01	user18272	password	24	80000	M
18273	THGAMW	QVIKCRXNRV	2943944847 Dell Way	\N	PHMPDAL	\N	0	UK	2	QVIKCRXNRV@dell.com	2943944847	3	9423525938298554	2009/08	user18273	password	65	20000	F
18274	YHLLEB	HMMJEJWWFM	1825021094 Dell Way	\N	DRBHSNG	\N	0	UK	2	HMMJEJWWFM@dell.com	1825021094	1	2603660973254591	2011/11	user18274	password	34	20000	M
18275	NPFSQM	FDWJNTFSFI	1548256485 Dell Way	\N	KHPDVWB	\N	0	UK	2	FDWJNTFSFI@dell.com	1548256485	2	7024928465951235	2012/06	user18275	password	78	80000	M
18276	KXRBKW	EHFRALKGTU	2793341472 Dell Way	\N	OJXKFZI	\N	0	Chile	2	EHFRALKGTU@dell.com	2793341472	5	2782614999916404	2011/10	user18276	password	83	80000	F
18277	UHGFEL	MKDNVNUOII	1035350559 Dell Way	\N	YGSEFAM	\N	0	France	2	MKDNVNUOII@dell.com	1035350559	4	1471808570437133	2012/07	user18277	password	67	20000	F
18278	ZGODRB	NUPIIJXQRW	2346206618 Dell Way	\N	WKABKMM	\N	0	France	2	NUPIIJXQRW@dell.com	2346206618	3	3051757282111794	2011/03	user18278	password	35	20000	F
18279	MQIESV	ZHEHQCYIYU	8497788771 Dell Way	\N	SZWDMIO	\N	0	Japan	2	ZHEHQCYIYU@dell.com	8497788771	4	3940424891188741	2008/01	user18279	password	46	20000	M
18280	ANSSJR	ANZRQXAPRT	3151422628 Dell Way	\N	ONWBWLR	\N	0	Japan	2	ANZRQXAPRT@dell.com	3151422628	5	7408524282276631	2009/05	user18280	password	84	80000	F
18281	KMDTEE	HEVYBWNTPC	8246962557 Dell Way	\N	HLDDXUV	\N	0	Canada	2	HEVYBWNTPC@dell.com	8246962557	3	4744097060058266	2008/06	user18281	password	33	80000	M
18282	STQXXX	BTVCPJWELD	6410160715 Dell Way	\N	QOGOJBS	\N	0	Canada	2	BTVCPJWELD@dell.com	6410160715	1	4381372367031872	2008/04	user18282	password	89	100000	F
18283	TNYQLZ	KHCAQYFBBV	2927770242 Dell Way	\N	QIKAKCF	\N	0	Australia	2	KHCAQYFBBV@dell.com	2927770242	3	1417882230132818	2010/07	user18283	password	86	60000	F
18284	LNYWNI	DPIUNOVPJM	3403358883 Dell Way	\N	YUMJWSJ	\N	0	Australia	2	DPIUNOVPJM@dell.com	3403358883	3	6725841092877091	2012/05	user18284	password	33	20000	M
18285	TBRGJV	VSPJGLZQYX	1311051554 Dell Way	\N	LLGIDQK	\N	0	China	2	VSPJGLZQYX@dell.com	1311051554	1	2976061047986150	2009/04	user18285	password	41	20000	M
18286	JWFTRB	MHKTTKKSIV	6131386260 Dell Way	\N	DPDGFNR	\N	0	Chile	2	MHKTTKKSIV@dell.com	6131386260	5	6582159954588861	2012/03	user18286	password	76	100000	M
18287	QBIICU	QNNKXXCFTG	1483668552 Dell Way	\N	UWNAKEG	\N	0	UK	2	QNNKXXCFTG@dell.com	1483668552	5	8075920678209514	2009/09	user18287	password	62	100000	F
18288	RERTZH	HMSFKVLDBG	4352151548 Dell Way	\N	AOGKSNI	\N	0	Russia	2	HMSFKVLDBG@dell.com	4352151548	1	1375321587081998	2008/09	user18288	password	82	40000	F
18289	BAEAIL	NBRYWCBXIC	9494164142 Dell Way	\N	LPMECVY	\N	0	France	2	NBRYWCBXIC@dell.com	9494164142	5	5445212968159467	2011/11	user18289	password	80	20000	M
18290	WGYFSM	GJKCLMAUOM	6390916917 Dell Way	\N	JAQLVPX	\N	0	Russia	2	GJKCLMAUOM@dell.com	6390916917	2	5250500971917063	2010/03	user18290	password	58	60000	F
18291	UJINWP	WHSHTSCIFL	2444176967 Dell Way	\N	JWWFLUZ	\N	0	Australia	2	WHSHTSCIFL@dell.com	2444176967	3	5773499258328230	2010/01	user18291	password	87	60000	M
18292	IWIFME	MEMFXOODAX	6144329561 Dell Way	\N	ZXDKRCM	\N	0	South Africa	2	MEMFXOODAX@dell.com	6144329561	5	3194753455463797	2010/12	user18292	password	74	60000	F
18293	QTMDXY	HKEFZSIAQH	2558638728 Dell Way	\N	XTSPWEL	\N	0	France	2	HKEFZSIAQH@dell.com	2558638728	4	1106007467489689	2008/06	user18293	password	49	40000	F
18294	EWFCUN	MYTMRCMHJK	1830616433 Dell Way	\N	ACZWHKH	\N	0	France	2	MYTMRCMHJK@dell.com	1830616433	2	6128509943373502	2010/09	user18294	password	88	80000	M
18295	VVZQJM	OCYGEKNOVO	1553270183 Dell Way	\N	RULYFTK	\N	0	Chile	2	OCYGEKNOVO@dell.com	1553270183	5	8557485888712109	2012/12	user18295	password	52	80000	M
18296	IRJRDY	UCEYNSNIGE	5310935109 Dell Way	\N	CSDILNP	\N	0	Germany	2	UCEYNSNIGE@dell.com	5310935109	3	3843290921300650	2010/12	user18296	password	19	20000	F
18297	SNYWLS	YQRLIFUPJW	3381980089 Dell Way	\N	HNFTAVG	\N	0	France	2	YQRLIFUPJW@dell.com	3381980089	3	9109247329644860	2008/08	user18297	password	21	60000	F
18298	OJDACC	QTOZYIOIFW	4965218241 Dell Way	\N	VKPWFWJ	\N	0	France	2	QTOZYIOIFW@dell.com	4965218241	2	7015690736938269	2008/04	user18298	password	25	40000	M
18299	MMXOOO	IDNHLBPQYL	9126037656 Dell Way	\N	ANHGKQS	\N	0	South Africa	2	IDNHLBPQYL@dell.com	9126037656	2	8791563639882953	2009/06	user18299	password	32	20000	M
18300	RZOGNW	JADUCTLAFM	8455078306 Dell Way	\N	ONSYELU	\N	0	Australia	2	JADUCTLAFM@dell.com	8455078306	4	3448084488511086	2009/11	user18300	password	43	40000	M
18301	IWUWSD	XWYAQJBVWP	9898476817 Dell Way	\N	JOONAIO	\N	0	South Africa	2	XWYAQJBVWP@dell.com	9898476817	5	2451672748662531	2012/03	user18301	password	52	40000	M
18302	IDKBHH	XFHOPIKLYT	7095549772 Dell Way	\N	ANGAVVW	\N	0	South Africa	2	XFHOPIKLYT@dell.com	7095549772	1	7011940941680223	2012/06	user18302	password	20	60000	M
18303	EVWLCU	RKIGSSSRLT	6801353071 Dell Way	\N	ESTANQW	\N	0	Chile	2	RKIGSSSRLT@dell.com	6801353071	3	1829843823332339	2008/07	user18303	password	55	100000	M
18304	IUDKPV	UXCNQUFBOJ	7712926921 Dell Way	\N	UIJIYFN	\N	0	Germany	2	UXCNQUFBOJ@dell.com	7712926921	4	7461449400056154	2009/02	user18304	password	66	100000	F
18305	MDWBZR	YBEPWJQKTL	9089211362 Dell Way	\N	SDTRJHG	\N	0	Canada	2	YBEPWJQKTL@dell.com	9089211362	5	4546443179249764	2008/08	user18305	password	46	60000	F
18306	OIDNZC	OERLOIVIUO	4990399649 Dell Way	\N	LNFUUMX	\N	0	Japan	2	OERLOIVIUO@dell.com	4990399649	2	7527524881530554	2008/09	user18306	password	32	20000	F
18307	NITNLI	SCTHLPPFDB	1549184848 Dell Way	\N	TJWOWTG	\N	0	China	2	SCTHLPPFDB@dell.com	1549184848	5	4385328080505133	2011/02	user18307	password	58	100000	M
18308	WTFHBY	KVGWKVCOXV	6060648915 Dell Way	\N	YTJUNPC	\N	0	Germany	2	KVGWKVCOXV@dell.com	6060648915	3	3894097730983049	2011/01	user18308	password	41	60000	M
18309	BQFDPQ	YVMIROXOKV	2894421637 Dell Way	\N	ITQVJTJ	\N	0	UK	2	YVMIROXOKV@dell.com	2894421637	4	6839692236389965	2009/01	user18309	password	23	20000	F
18310	SIFIYD	DLMVAKJKFR	6277871790 Dell Way	\N	EWNNPWL	\N	0	South Africa	2	DLMVAKJKFR@dell.com	6277871790	1	1408368941862136	2011/03	user18310	password	31	80000	M
18311	NXFMAJ	XNEXXOIDGM	6277907036 Dell Way	\N	ATAPQMK	\N	0	Chile	2	XNEXXOIDGM@dell.com	6277907036	3	8355070697143675	2011/08	user18311	password	54	80000	F
18312	KWQKFN	YJLWYUZEGZ	5209357595 Dell Way	\N	XHPNTAT	\N	0	China	2	YJLWYUZEGZ@dell.com	5209357595	3	2042210039682686	2008/01	user18312	password	74	40000	F
18313	QWWVKV	FWRDQQHXQF	1532515845 Dell Way	\N	EGTYGMH	\N	0	Russia	2	FWRDQQHXQF@dell.com	1532515845	3	8413653260096908	2008/03	user18313	password	23	60000	M
18314	ZLQJGW	FXAWOHTFNY	6448410453 Dell Way	\N	LGWSTEK	\N	0	South Africa	2	FXAWOHTFNY@dell.com	6448410453	2	9436861210968346	2011/04	user18314	password	55	80000	F
18315	YGRFDX	DDTRLMXYLI	7187822313 Dell Way	\N	FIAYMLT	\N	0	Canada	2	DDTRLMXYLI@dell.com	7187822313	4	9054681064561010	2008/03	user18315	password	54	40000	F
18316	TYJWVN	APELBBJNKO	9939962087 Dell Way	\N	VLNIXHK	\N	0	Germany	2	APELBBJNKO@dell.com	9939962087	2	6233446668833495	2009/10	user18316	password	81	40000	M
18317	VTLRGL	GLXINGVYVQ	6963307593 Dell Way	\N	JIYGQJV	\N	0	Japan	2	GLXINGVYVQ@dell.com	6963307593	3	8484039470553399	2010/04	user18317	password	33	20000	F
18318	ZNTGYZ	SVHFCDDXTN	9851870581 Dell Way	\N	GSTWBPN	\N	0	Russia	2	SVHFCDDXTN@dell.com	9851870581	2	2693216110114008	2009/07	user18318	password	35	40000	M
18319	TDUSCM	NKSQNVOHJU	5730561915 Dell Way	\N	ZCRBSET	\N	0	Japan	2	NKSQNVOHJU@dell.com	5730561915	5	9439898766577244	2008/03	user18319	password	39	80000	M
18320	KKPNWD	YOUMKITTDT	5455747750 Dell Way	\N	WVUOAOG	\N	0	Germany	2	YOUMKITTDT@dell.com	5455747750	1	6497785860672594	2011/06	user18320	password	33	60000	M
18321	PEKMIJ	ACVLLPEOJB	1178703479 Dell Way	\N	KDPKSVY	\N	0	Canada	2	ACVLLPEOJB@dell.com	1178703479	3	8842165625188501	2010/10	user18321	password	51	40000	F
18322	QUVZDW	CZHNPLCYMM	4176996304 Dell Way	\N	CCWUYVZ	\N	0	UK	2	CZHNPLCYMM@dell.com	4176996304	5	5142886232584715	2008/04	user18322	password	79	60000	M
18323	QHYUEA	TLOJWQHJDJ	1113259079 Dell Way	\N	MAELVDK	\N	0	Canada	2	TLOJWQHJDJ@dell.com	1113259079	5	3570405126083642	2009/09	user18323	password	73	40000	F
18324	BGDFGX	QVGNMNXPXK	1724262143 Dell Way	\N	PBVKFFP	\N	0	Chile	2	QVGNMNXPXK@dell.com	1724262143	5	5959879106376321	2011/08	user18324	password	79	20000	M
18325	BGYIDP	DJDPXBFULV	7364572762 Dell Way	\N	WGGBMVH	\N	0	Germany	2	DJDPXBFULV@dell.com	7364572762	5	4148902507964522	2009/09	user18325	password	52	20000	M
18326	SZCWPG	FSWDTBYEXU	1087598461 Dell Way	\N	LDWYYEN	\N	0	Japan	2	FSWDTBYEXU@dell.com	1087598461	5	1026783118490129	2011/04	user18326	password	22	60000	F
18327	BOWQUC	IRGBTEGQZR	9736057159 Dell Way	\N	TWQSADJ	\N	0	Australia	2	IRGBTEGQZR@dell.com	9736057159	2	7650416456628592	2009/05	user18327	password	32	40000	F
18328	TFCOHL	FOMZTTPTLJ	7835531542 Dell Way	\N	PBBQEKR	\N	0	Canada	2	FOMZTTPTLJ@dell.com	7835531542	3	4778456777799875	2008/08	user18328	password	71	80000	F
18329	YTYGEE	URDOKTHVCW	6422289086 Dell Way	\N	WDNAOED	\N	0	China	2	URDOKTHVCW@dell.com	6422289086	3	5417314327321947	2009/04	user18329	password	27	60000	F
18330	WNMBRH	SUVCNCYQZU	5827394573 Dell Way	\N	UMVIRZQ	\N	0	Chile	2	SUVCNCYQZU@dell.com	5827394573	1	5416552944574505	2012/04	user18330	password	23	20000	F
18331	PPEGWX	ASZOVXEUSZ	1774529431 Dell Way	\N	HNHYMYF	\N	0	Australia	2	ASZOVXEUSZ@dell.com	1774529431	4	8710300116334111	2009/10	user18331	password	87	60000	F
18332	OSPLPQ	DOFYMJTEIA	9102260707 Dell Way	\N	RQYEPEE	\N	0	Japan	2	DOFYMJTEIA@dell.com	9102260707	1	1274589362554252	2011/12	user18332	password	57	20000	M
18333	FRYVHC	JMAWWTBFUS	1709628979 Dell Way	\N	VTXLYBC	\N	0	South Africa	2	JMAWWTBFUS@dell.com	1709628979	1	5603904653340579	2008/08	user18333	password	59	60000	M
18334	FNSNPC	ZQYVKZBESX	5857371640 Dell Way	\N	YPIWRKR	\N	0	Russia	2	ZQYVKZBESX@dell.com	5857371640	1	8145612548571081	2009/09	user18334	password	45	20000	M
18335	XUMNXL	EVHOVJTOGR	4529443418 Dell Way	\N	DONUZFO	\N	0	Germany	2	EVHOVJTOGR@dell.com	4529443418	2	7376024701632560	2008/09	user18335	password	76	20000	M
18336	PPDNAH	IIWERQSXHW	5841608830 Dell Way	\N	MVRLAFY	\N	0	France	2	IIWERQSXHW@dell.com	5841608830	4	6124198422301561	2009/06	user18336	password	67	100000	F
18337	GZOHHX	QDCITUGBRS	7641657011 Dell Way	\N	XIDYNCJ	\N	0	Australia	2	QDCITUGBRS@dell.com	7641657011	5	3847422411665320	2008/08	user18337	password	30	40000	M
18338	EVDLTU	PWCJRIKIAH	5492540462 Dell Way	\N	QEFEGPG	\N	0	UK	2	PWCJRIKIAH@dell.com	5492540462	3	2655519573483616	2008/09	user18338	password	50	100000	M
18339	HCJBWY	XYIOGSXHAO	5811948799 Dell Way	\N	LGSRVZR	\N	0	China	2	XYIOGSXHAO@dell.com	5811948799	5	4855057809036225	2009/04	user18339	password	45	20000	M
18340	MORINO	HVDOOAVPOG	5373266152 Dell Way	\N	VHYRGQZ	\N	0	Russia	2	HVDOOAVPOG@dell.com	5373266152	3	1654754897579550	2011/10	user18340	password	37	60000	F
18341	VBQIQX	DULSVHHKOD	2814810887 Dell Way	\N	RMUYDUT	\N	0	Japan	2	DULSVHHKOD@dell.com	2814810887	5	4589921007864177	2008/01	user18341	password	76	40000	M
18342	WXFNVJ	IHBDOJNCMF	7609894309 Dell Way	\N	PGESAXH	\N	0	Chile	2	IHBDOJNCMF@dell.com	7609894309	4	3112538594286889	2012/06	user18342	password	56	80000	F
18343	LYXGHF	NJIBSWEFCT	4730332952 Dell Way	\N	LGLMESS	\N	0	UK	2	NJIBSWEFCT@dell.com	4730332952	5	7501417935360224	2012/06	user18343	password	49	40000	M
18344	JEDRJQ	ASSTOWYQPK	5391078593 Dell Way	\N	XAWCTOZ	\N	0	Canada	2	ASSTOWYQPK@dell.com	5391078593	4	1648842550348490	2012/02	user18344	password	43	100000	M
18345	NYEXPE	PHYEEXUUHS	5392816283 Dell Way	\N	UDUORUS	\N	0	Canada	2	PHYEEXUUHS@dell.com	5392816283	4	2043521149549633	2011/02	user18345	password	86	20000	M
18346	XHOMMD	UKHZICTPUN	6011096201 Dell Way	\N	SPCKJUO	\N	0	South Africa	2	UKHZICTPUN@dell.com	6011096201	4	5384985418990255	2011/08	user18346	password	63	40000	M
18347	XWAKAU	VHTDKNSFAK	1710745503 Dell Way	\N	UCVEXKA	\N	0	France	2	VHTDKNSFAK@dell.com	1710745503	3	2251438959967345	2011/02	user18347	password	52	40000	F
18348	JGKJBF	RUJBIBHJLB	7705895100 Dell Way	\N	MHFJRGV	\N	0	Russia	2	RUJBIBHJLB@dell.com	7705895100	5	5066300825215876	2012/06	user18348	password	67	100000	M
18349	XIEYOV	TXXBYEKKGW	1063945044 Dell Way	\N	RMGISBC	\N	0	France	2	TXXBYEKKGW@dell.com	1063945044	3	3969261077232659	2010/03	user18349	password	34	40000	F
18350	OKCCFW	ZDYYIJIPGA	9973761990 Dell Way	\N	BMJUOLG	\N	0	Germany	2	ZDYYIJIPGA@dell.com	9973761990	3	9870041529182346	2009/10	user18350	password	33	40000	F
18351	PLLVIL	ZGJHQSXWTY	5907950039 Dell Way	\N	JDSXPZL	\N	0	Germany	2	ZGJHQSXWTY@dell.com	5907950039	3	8180100387893618	2009/08	user18351	password	29	80000	F
18352	QDBYPA	FZIVSFRLEB	8245194633 Dell Way	\N	PXYEWJT	\N	0	France	2	FZIVSFRLEB@dell.com	8245194633	3	7787922240328044	2010/09	user18352	password	50	80000	F
18353	PTGETL	ECHWHZILAX	3906844656 Dell Way	\N	IYBFIUP	\N	0	Canada	2	ECHWHZILAX@dell.com	3906844656	2	6030450338963420	2008/10	user18353	password	35	40000	F
18354	ZPPSAT	UIPCHXNHUW	1183983939 Dell Way	\N	FWBNQRQ	\N	0	UK	2	UIPCHXNHUW@dell.com	1183983939	1	9786052089184524	2012/06	user18354	password	40	40000	F
18355	WVDXOY	FEAMCOUXKZ	4045779798 Dell Way	\N	TMNKDDJ	\N	0	Canada	2	FEAMCOUXKZ@dell.com	4045779798	2	9838658900000156	2011/08	user18355	password	33	20000	M
18356	BHLQFR	UFEXUYVEXO	6619483085 Dell Way	\N	QLYUOHY	\N	0	UK	2	UFEXUYVEXO@dell.com	6619483085	5	7072586240712554	2009/02	user18356	password	79	80000	F
18357	DFUJWP	PANJYINWWE	8347811336 Dell Way	\N	HVZWDXT	\N	0	Russia	2	PANJYINWWE@dell.com	8347811336	3	1056950510013848	2012/04	user18357	password	74	20000	F
18358	ZYTVNJ	VASUJGQFKX	9585964686 Dell Way	\N	BJTEHNY	\N	0	Australia	2	VASUJGQFKX@dell.com	9585964686	5	1445595023222267	2009/09	user18358	password	30	80000	M
18359	CKNQTJ	RLDARTGCRI	4502494270 Dell Way	\N	MLNUZLW	\N	0	UK	2	RLDARTGCRI@dell.com	4502494270	5	2395212186034769	2008/02	user18359	password	75	80000	F
18360	FIVYRN	KUNCOUFFCR	3229572954 Dell Way	\N	RPLQBIO	\N	0	France	2	KUNCOUFFCR@dell.com	3229572954	4	5874317162670196	2009/07	user18360	password	42	60000	M
18361	RKRIXB	CKEQFJWHAO	5567958761 Dell Way	\N	XMFYVUJ	\N	0	Australia	2	CKEQFJWHAO@dell.com	5567958761	5	4668228921480477	2008/04	user18361	password	87	80000	M
18362	ILGGMI	RQZWZWEAKB	4021077080 Dell Way	\N	NPAIKKK	\N	0	South Africa	2	RQZWZWEAKB@dell.com	4021077080	4	9368303064256908	2011/10	user18362	password	67	60000	F
18363	CTIPCZ	GCVGYAHJCU	3771802800 Dell Way	\N	ZDDJNNG	\N	0	South Africa	2	GCVGYAHJCU@dell.com	3771802800	1	5185498327948153	2008/11	user18363	password	90	20000	M
18364	TMOVMV	XIBWIIFKDE	9852163252 Dell Way	\N	NGOBTUY	\N	0	Australia	2	XIBWIIFKDE@dell.com	9852163252	2	2138286272063851	2012/05	user18364	password	38	100000	F
18365	UKYGFW	OHTXQYHTDV	3017916420 Dell Way	\N	ARXTMVV	\N	0	France	2	OHTXQYHTDV@dell.com	3017916420	5	3774334294721484	2011/03	user18365	password	28	80000	F
18366	ORGUOV	BHSSGZLJVL	9970853054 Dell Way	\N	BTFNOBZ	\N	0	Russia	2	BHSSGZLJVL@dell.com	9970853054	2	4625410639680922	2009/06	user18366	password	27	40000	M
18367	VMTJHU	RZMXZYHVKI	2144717148 Dell Way	\N	PQWDRVY	\N	0	Japan	2	RZMXZYHVKI@dell.com	2144717148	2	9147499431390316	2010/06	user18367	password	28	60000	F
18368	QGRYBI	YOGYNNTXWI	8212727717 Dell Way	\N	OTMFPLX	\N	0	Russia	2	YOGYNNTXWI@dell.com	8212727717	4	3346317911986262	2009/12	user18368	password	74	60000	M
18369	AGNCPL	QVKDJDBGMP	5453341943 Dell Way	\N	ZZVOLSH	\N	0	Chile	2	QVKDJDBGMP@dell.com	5453341943	3	5648058004677296	2010/04	user18369	password	25	20000	F
18370	INLXZC	TJFCNHJAWI	7347442659 Dell Way	\N	ASXLKER	\N	0	South Africa	2	TJFCNHJAWI@dell.com	7347442659	1	3937993510626257	2008/04	user18370	password	42	40000	M
18371	WUOWXH	GDKUKTVHCV	2018648405 Dell Way	\N	ZZGJEYG	\N	0	South Africa	2	GDKUKTVHCV@dell.com	2018648405	3	8985605192836375	2009/12	user18371	password	36	20000	M
18372	BORYWY	BHSMAOTDJS	9631522878 Dell Way	\N	DQCHOJD	\N	0	Japan	2	BHSMAOTDJS@dell.com	9631522878	1	1473095448222011	2012/04	user18372	password	23	80000	F
18373	QKHNIJ	UBVUPPYZIB	5679877657 Dell Way	\N	PKIDUMU	\N	0	Russia	2	UBVUPPYZIB@dell.com	5679877657	5	6663535959087313	2012/11	user18373	password	42	20000	M
18374	SMBBVV	DRQTGOSOPH	1562484334 Dell Way	\N	YYLTKFM	\N	0	UK	2	DRQTGOSOPH@dell.com	1562484334	1	7792659063357861	2012/06	user18374	password	85	60000	F
18375	JPGFKJ	WBCCPVQFDP	9075188874 Dell Way	\N	EOIPUUN	\N	0	South Africa	2	WBCCPVQFDP@dell.com	9075188874	2	8416859174612910	2009/03	user18375	password	43	60000	M
18376	YSUICQ	KFTZAKFEZJ	7632400268 Dell Way	\N	SIYNDLJ	\N	0	Australia	2	KFTZAKFEZJ@dell.com	7632400268	1	4154495211318135	2012/07	user18376	password	79	60000	F
18377	OHVRYF	WRFXBKBBTU	8546189983 Dell Way	\N	JSHNERN	\N	0	UK	2	WRFXBKBBTU@dell.com	8546189983	5	8488848289940507	2009/09	user18377	password	42	100000	F
18378	QRYOWV	FBSHMTIGOS	6551875270 Dell Way	\N	YVFCMTA	\N	0	China	2	FBSHMTIGOS@dell.com	6551875270	5	7391631742473692	2009/03	user18378	password	58	80000	M
18379	FOICJO	DCWQWFWKYU	7452520627 Dell Way	\N	GDXTXXB	\N	0	Germany	2	DCWQWFWKYU@dell.com	7452520627	4	8637021621223540	2012/05	user18379	password	52	80000	M
18380	AAQKPU	MLKIQHSPBZ	5953425497 Dell Way	\N	TYSQVUD	\N	0	Germany	2	MLKIQHSPBZ@dell.com	5953425497	5	4865444298833609	2012/06	user18380	password	25	60000	F
18381	DCXSXK	EHSVPLKQKD	9239495835 Dell Way	\N	ODTKXXY	\N	0	France	2	EHSVPLKQKD@dell.com	9239495835	2	3979827300179750	2009/06	user18381	password	74	100000	M
18382	WUITEM	BXHQJSGUVV	6118818598 Dell Way	\N	XPGUNFG	\N	0	France	2	BXHQJSGUVV@dell.com	6118818598	3	8318852304946632	2008/05	user18382	password	68	80000	F
18383	MZYQMA	NUQWMXQITO	2097315873 Dell Way	\N	XZILEOW	\N	0	Russia	2	NUQWMXQITO@dell.com	2097315873	4	8257634777575732	2010/05	user18383	password	52	80000	M
18384	LPMYPZ	SGWEDNMXBK	4164165010 Dell Way	\N	XJVCYRV	\N	0	Australia	2	SGWEDNMXBK@dell.com	4164165010	4	5686620811000467	2011/02	user18384	password	31	60000	M
18385	UAMKAE	QWJUJVSLGP	2224447463 Dell Way	\N	VBRTSMV	\N	0	Australia	2	QWJUJVSLGP@dell.com	2224447463	2	8159430987667293	2009/07	user18385	password	42	100000	F
18386	IHSILJ	FVDPRVAXKW	7942607480 Dell Way	\N	YCPRPLT	\N	0	Russia	2	FVDPRVAXKW@dell.com	7942607480	3	9647930495440960	2009/11	user18386	password	73	60000	F
18387	BHONQU	IUKZQLWBHU	7822591732 Dell Way	\N	DXMSIFL	\N	0	Australia	2	IUKZQLWBHU@dell.com	7822591732	2	4447896732948721	2011/02	user18387	password	89	100000	F
18388	HLSYGA	SQAJBWKIRN	1785096446 Dell Way	\N	FDGNIRQ	\N	0	Australia	2	SQAJBWKIRN@dell.com	1785096446	1	7603986060712487	2009/12	user18388	password	62	60000	F
18389	BEFHEX	XEGYBRHSFM	7084308625 Dell Way	\N	VLADDRG	\N	0	Chile	2	XEGYBRHSFM@dell.com	7084308625	5	5208493865560740	2011/08	user18389	password	84	100000	M
18390	BDXGBV	LIUMZBEEOZ	4325056165 Dell Way	\N	QPDTGKZ	\N	0	UK	2	LIUMZBEEOZ@dell.com	4325056165	3	6509590078145266	2012/05	user18390	password	58	60000	F
18391	RNRTIC	BDPBETFTTV	9924417068 Dell Way	\N	JWPQHOO	\N	0	Japan	2	BDPBETFTTV@dell.com	9924417068	1	6357291647698731	2009/09	user18391	password	31	80000	F
18392	RLEAOG	DDHIXMCQIL	8597924820 Dell Way	\N	NXCULRK	\N	0	France	2	DDHIXMCQIL@dell.com	8597924820	1	8131959878373892	2010/03	user18392	password	59	20000	M
18393	AEXOKB	SSKPEMFNYS	9501292267 Dell Way	\N	KANWRYI	\N	0	Germany	2	SSKPEMFNYS@dell.com	9501292267	1	1850722180213779	2008/08	user18393	password	25	20000	M
18394	HYGSZY	KKOPWTCUMM	7927036121 Dell Way	\N	UZJMXRZ	\N	0	South Africa	2	KKOPWTCUMM@dell.com	7927036121	1	1031840784009546	2010/03	user18394	password	20	20000	F
18395	ZJEZIO	JWEFPGACTV	4097379045 Dell Way	\N	CCHZUGW	\N	0	Germany	2	JWEFPGACTV@dell.com	4097379045	5	9850006119348110	2010/11	user18395	password	25	100000	M
18396	LEWTTF	QXLGDMIXHK	2065629751 Dell Way	\N	ZPKUVGI	\N	0	Canada	2	QXLGDMIXHK@dell.com	2065629751	2	7427689767908306	2008/05	user18396	password	69	100000	M
18397	WTQPZG	MKMQXVNEFN	9396960992 Dell Way	\N	TQHPWQU	\N	0	UK	2	MKMQXVNEFN@dell.com	9396960992	3	1118709055706858	2009/03	user18397	password	83	20000	F
18398	QVRQBE	BOVYJICPWW	7870677013 Dell Way	\N	FEMCUGC	\N	0	Russia	2	BOVYJICPWW@dell.com	7870677013	1	1502180321142077	2012/12	user18398	password	36	20000	M
18399	CTGDXI	STGBBJQYFW	1958133805 Dell Way	\N	CRYWYAP	\N	0	Russia	2	STGBBJQYFW@dell.com	1958133805	4	7091419823933393	2008/11	user18399	password	71	80000	M
18400	MADKIW	DOYFXODDLG	4394408933 Dell Way	\N	VJDTJSL	\N	0	France	2	DOYFXODDLG@dell.com	4394408933	1	6196698112878949	2009/11	user18400	password	42	40000	F
18401	JLSRHW	GFBEUEHFKD	5185124231 Dell Way	\N	OOWXGIK	\N	0	Japan	2	GFBEUEHFKD@dell.com	5185124231	5	9315890105906876	2009/04	user18401	password	32	80000	M
18402	QKIXGP	CHTWMBBXEQ	9128401143 Dell Way	\N	LBORJYI	\N	0	South Africa	2	CHTWMBBXEQ@dell.com	9128401143	2	2559832613449544	2009/06	user18402	password	79	100000	F
18403	FEZMTC	TNZFOACSRO	8215319577 Dell Way	\N	UFGDDOZ	\N	0	Australia	2	TNZFOACSRO@dell.com	8215319577	1	3174110018182546	2009/01	user18403	password	24	40000	F
18404	GISAKL	NJRCKUVBIP	9129131140 Dell Way	\N	GOTKDTL	\N	0	UK	2	NJRCKUVBIP@dell.com	9129131140	4	2601799029856920	2012/10	user18404	password	55	20000	F
18405	VWBFIP	OZRZUMADBH	7946698016 Dell Way	\N	RURVOCT	\N	0	France	2	OZRZUMADBH@dell.com	7946698016	5	4188532745465636	2010/06	user18405	password	54	60000	F
18406	JQLRFA	QXZLJAOLHG	7464119551 Dell Way	\N	GYBUBUF	\N	0	South Africa	2	QXZLJAOLHG@dell.com	7464119551	3	4233828055672348	2008/02	user18406	password	85	40000	F
18407	OWCUWT	RWEBXTMEZS	3823895951 Dell Way	\N	DANEVTA	\N	0	Germany	2	RWEBXTMEZS@dell.com	3823895951	2	7266954386141152	2009/04	user18407	password	24	100000	M
18408	YYQVRH	SWIPPVTOOX	4910508503 Dell Way	\N	PBBLUBZ	\N	0	Australia	2	SWIPPVTOOX@dell.com	4910508503	4	5394613564480096	2011/10	user18408	password	41	60000	M
18409	GFNYNF	UWUJROYFLN	6547386330 Dell Way	\N	GNYBPYD	\N	0	Australia	2	UWUJROYFLN@dell.com	6547386330	4	7703027060255409	2009/12	user18409	password	41	20000	F
18410	OPDBUX	XPHPDFVOTB	8702495214 Dell Way	\N	CSCRQGR	\N	0	Chile	2	XPHPDFVOTB@dell.com	8702495214	3	6748704326339067	2011/10	user18410	password	70	100000	F
18411	ICJCAH	SHWVNRKGTM	3541910523 Dell Way	\N	ZWEPCWW	\N	0	UK	2	SHWVNRKGTM@dell.com	3541910523	3	7671636237762869	2008/03	user18411	password	71	40000	M
18412	VSQWZI	EVERNOYGBX	9031333973 Dell Way	\N	CFNFBKD	\N	0	China	2	EVERNOYGBX@dell.com	9031333973	5	4522133937571198	2008/08	user18412	password	71	80000	F
18413	LHIKPM	GUETICAKAC	3962003778 Dell Way	\N	PNHRXLA	\N	0	South Africa	2	GUETICAKAC@dell.com	3962003778	3	9331407665740700	2012/02	user18413	password	59	40000	M
18414	WSZMFF	GJZOLZZMBO	7218305723 Dell Way	\N	AJGYVHT	\N	0	Canada	2	GJZOLZZMBO@dell.com	7218305723	4	1865723812952637	2012/03	user18414	password	53	60000	F
18415	FKOKPU	TPJFOIRQXS	1212872420 Dell Way	\N	ZDQVKJZ	\N	0	Canada	2	TPJFOIRQXS@dell.com	1212872420	1	9552810839377344	2009/07	user18415	password	44	40000	M
18416	TXEJSY	ZBDNKVDHND	9969514087 Dell Way	\N	LEYWNYZ	\N	0	Germany	2	ZBDNKVDHND@dell.com	9969514087	5	8228484810795636	2010/04	user18416	password	28	40000	F
18417	BNLTLK	VOXFKANYEY	7155338662 Dell Way	\N	CCUQATE	\N	0	Australia	2	VOXFKANYEY@dell.com	7155338662	5	6250093199778349	2012/02	user18417	password	84	20000	F
18418	KMYWWT	LUYVULUZKW	6791670896 Dell Way	\N	BFNCYRC	\N	0	Japan	2	LUYVULUZKW@dell.com	6791670896	4	6534218251239509	2011/08	user18418	password	64	100000	F
18419	CWWZPI	TODOAXNKUP	5207036143 Dell Way	\N	PHROZUF	\N	0	Japan	2	TODOAXNKUP@dell.com	5207036143	5	4427255827002227	2008/06	user18419	password	41	20000	M
18420	EZOUHH	JLWJJJUEYK	9882716814 Dell Way	\N	MQYLKEB	\N	0	South Africa	2	JLWJJJUEYK@dell.com	9882716814	3	9530638844706120	2010/10	user18420	password	21	20000	M
18421	BOTJWC	UTMECHIBRU	7500903931 Dell Way	\N	SQGCUHZ	\N	0	Russia	2	UTMECHIBRU@dell.com	7500903931	5	3129183490760624	2010/12	user18421	password	37	60000	F
18422	VEJSHE	LUIOBRQTLI	3786628627 Dell Way	\N	JRKEZKY	\N	0	Japan	2	LUIOBRQTLI@dell.com	3786628627	1	2584371774923056	2009/06	user18422	password	61	40000	F
18423	URZBVL	VEZXVPQHXZ	3710090753 Dell Way	\N	YIEYSCQ	\N	0	Australia	2	VEZXVPQHXZ@dell.com	3710090753	5	3865075428970158	2011/05	user18423	password	63	20000	F
18424	HAGDLC	HLZDBPKZPJ	7454647116 Dell Way	\N	HUHAXXB	\N	0	Canada	2	HLZDBPKZPJ@dell.com	7454647116	2	9449966115411372	2008/01	user18424	password	88	40000	F
18425	ZOLLQT	XQWYGGXWPF	7057809762 Dell Way	\N	QWGNUHS	\N	0	Germany	2	XQWYGGXWPF@dell.com	7057809762	4	6683374364860356	2011/08	user18425	password	86	100000	M
18426	MKBDDZ	TAXZGVVWAM	3777533528 Dell Way	\N	SHZNORA	\N	0	Chile	2	TAXZGVVWAM@dell.com	3777533528	4	9269820412620904	2012/08	user18426	password	83	60000	F
18427	HPFLOZ	LLZSHVOIHH	5221183534 Dell Way	\N	PGUEXVK	\N	0	Chile	2	LLZSHVOIHH@dell.com	5221183534	2	2334927430376410	2008/03	user18427	password	67	20000	M
18428	GJZVJL	GIDOERWLYM	4306280841 Dell Way	\N	RTQPOAV	\N	0	Australia	2	GIDOERWLYM@dell.com	4306280841	5	1891838361509144	2010/08	user18428	password	36	20000	M
18429	QCSZNZ	IQOMIKXHWP	1349920145 Dell Way	\N	ANFPOBQ	\N	0	UK	2	IQOMIKXHWP@dell.com	1349920145	4	5479412440676242	2011/12	user18429	password	62	80000	M
18430	SIPFIY	VXKEHILEYL	4625041282 Dell Way	\N	REBFFRD	\N	0	Chile	2	VXKEHILEYL@dell.com	4625041282	4	9493828602135182	2009/03	user18430	password	58	100000	M
18431	XPDGNZ	DYDLGOQFAI	3708998792 Dell Way	\N	JBNOTRV	\N	0	Canada	2	DYDLGOQFAI@dell.com	3708998792	4	5729973124805838	2010/04	user18431	password	55	60000	F
18432	CQMQPP	OTBVHRAIZJ	5533644720 Dell Way	\N	JNYDFTG	\N	0	France	2	OTBVHRAIZJ@dell.com	5533644720	4	1348962944932282	2012/04	user18432	password	55	20000	F
18433	DNBTDP	MEKUWLCWUM	6981264689 Dell Way	\N	JTPOMWB	\N	0	Australia	2	MEKUWLCWUM@dell.com	6981264689	1	8375591293442995	2012/08	user18433	password	80	40000	M
18434	JLNMAZ	RLTNWVKRIT	5554406191 Dell Way	\N	KYIXUKX	\N	0	France	2	RLTNWVKRIT@dell.com	5554406191	4	4899001218844205	2008/08	user18434	password	78	100000	M
18435	GKLHJD	SDROZBGHVQ	2855215696 Dell Way	\N	FDOAOMM	\N	0	Australia	2	SDROZBGHVQ@dell.com	2855215696	5	2653486915864050	2011/09	user18435	password	23	80000	M
18436	MFGWJY	ZANYBTGWKL	8521259676 Dell Way	\N	AZMOLYQ	\N	0	Japan	2	ZANYBTGWKL@dell.com	8521259676	5	5063715263735503	2010/11	user18436	password	33	60000	F
18437	LUFUTE	UHDWBJTMVT	7958423461 Dell Way	\N	LHIWGZN	\N	0	Australia	2	UHDWBJTMVT@dell.com	7958423461	5	6664133421145380	2011/03	user18437	password	30	20000	M
18438	ZGKSLF	AOBBYUNUOY	4252227137 Dell Way	\N	BXVHWJJ	\N	0	Japan	2	AOBBYUNUOY@dell.com	4252227137	1	3746394092217088	2010/03	user18438	password	42	20000	F
18439	OPWZVW	OWXMRLGGJI	1058421894 Dell Way	\N	EFQAPAR	\N	0	UK	2	OWXMRLGGJI@dell.com	1058421894	5	5582083047367633	2008/04	user18439	password	69	40000	M
18440	IEWDAK	ZYXRJEYSNC	8043797893 Dell Way	\N	YDDNDUM	\N	0	Canada	2	ZYXRJEYSNC@dell.com	8043797893	5	3978962836787105	2008/09	user18440	password	64	100000	M
18441	UVCVGC	TEUCISVVVT	7626891790 Dell Way	\N	ZYHDTTH	\N	0	Germany	2	TEUCISVVVT@dell.com	7626891790	4	6568349620793015	2010/04	user18441	password	60	60000	F
18442	KNWRQQ	VLSEDNAZHA	1450583022 Dell Way	\N	XODQILE	\N	0	Australia	2	VLSEDNAZHA@dell.com	1450583022	4	5316632469650358	2009/05	user18442	password	83	40000	M
18443	KGMBWI	MOMQCNPJNN	2171765772 Dell Way	\N	YQEHBII	\N	0	Canada	2	MOMQCNPJNN@dell.com	2171765772	5	4929628936108202	2010/09	user18443	password	76	40000	F
18444	BUEXCR	MPHPCXZPKX	3986579702 Dell Way	\N	GOEIWNL	\N	0	Australia	2	MPHPCXZPKX@dell.com	3986579702	5	5719729114789516	2008/09	user18444	password	79	20000	M
18445	QIRTZE	IHTLESAOQH	9652166160 Dell Way	\N	CVQZIBZ	\N	0	Japan	2	IHTLESAOQH@dell.com	9652166160	3	7414035320747644	2011/05	user18445	password	81	60000	M
18446	FCTFGB	MZNQSNFIVI	8474812516 Dell Way	\N	ELHNNHE	\N	0	France	2	MZNQSNFIVI@dell.com	8474812516	5	2195002826396376	2008/10	user18446	password	57	20000	M
18447	QYEWAR	WNIOBNXWVC	7163190959 Dell Way	\N	IDPVLUH	\N	0	Chile	2	WNIOBNXWVC@dell.com	7163190959	3	5359790788497776	2010/12	user18447	password	67	60000	M
18448	PPMPHI	DPXEDVAYXI	8857675972 Dell Way	\N	CNEOHLW	\N	0	UK	2	DPXEDVAYXI@dell.com	8857675972	2	4851559617556632	2012/01	user18448	password	81	60000	M
18449	MXGTGJ	IENLZOKXXN	3808093847 Dell Way	\N	KBCRMZR	\N	0	China	2	IENLZOKXXN@dell.com	3808093847	1	2900296924635768	2009/12	user18449	password	65	100000	F
18450	OFEVPN	ZCZZRKXOYH	7648743592 Dell Way	\N	PBZCAQM	\N	0	China	2	ZCZZRKXOYH@dell.com	7648743592	4	7007249158807100	2011/04	user18450	password	64	20000	M
18451	WITLVS	OVSFGPUEXJ	6659419229 Dell Way	\N	GXMGNYP	\N	0	Chile	2	OVSFGPUEXJ@dell.com	6659419229	2	9694361633155496	2012/11	user18451	password	24	100000	M
18452	KPFGIT	BBZIQTNODT	8925282475 Dell Way	\N	LPAZOQG	\N	0	Canada	2	BBZIQTNODT@dell.com	8925282475	2	2345658085308969	2011/04	user18452	password	19	60000	M
18453	QTYYMA	ZLIQEVEHPP	1011731810 Dell Way	\N	XPOMFUR	\N	0	Canada	2	ZLIQEVEHPP@dell.com	1011731810	5	9001310754567386	2009/10	user18453	password	49	100000	F
18454	EYJQYJ	BGZGCEORTM	4667413098 Dell Way	\N	HIYNCPQ	\N	0	Canada	2	BGZGCEORTM@dell.com	4667413098	3	4688253342639655	2009/12	user18454	password	47	80000	F
18455	IBTGKV	NKBQOQIICP	3625759365 Dell Way	\N	QADTQTW	\N	0	Australia	2	NKBQOQIICP@dell.com	3625759365	2	3387357273139060	2009/09	user18455	password	86	40000	F
18456	ZCGKXU	VYKKOSSRIJ	3444576741 Dell Way	\N	RLDIFZI	\N	0	Germany	2	VYKKOSSRIJ@dell.com	3444576741	4	7765808328054846	2012/07	user18456	password	25	100000	M
18457	EFZCZU	AKFPCYHKHY	3039229949 Dell Way	\N	WKHCKQP	\N	0	Japan	2	AKFPCYHKHY@dell.com	3039229949	2	6661407680716366	2011/06	user18457	password	60	40000	M
18458	UHSUCT	EHJHFQSMPO	6424477513 Dell Way	\N	XWRIMGZ	\N	0	Russia	2	EHJHFQSMPO@dell.com	6424477513	4	5403933758847416	2008/03	user18458	password	77	80000	F
18459	CKUEDZ	LNGRDYDTNB	9955265191 Dell Way	\N	QEJCLJV	\N	0	Australia	2	LNGRDYDTNB@dell.com	9955265191	2	1848305032122880	2009/02	user18459	password	74	40000	F
18460	EZKIZW	VFNZEQTSSJ	6360103088 Dell Way	\N	XCMJLHK	\N	0	France	2	VFNZEQTSSJ@dell.com	6360103088	3	6867167653981597	2011/04	user18460	password	80	100000	F
18461	WITVEP	BRPFIIYARW	1679693192 Dell Way	\N	DDFPLPA	\N	0	Australia	2	BRPFIIYARW@dell.com	1679693192	4	7695023415610195	2009/07	user18461	password	67	80000	F
18462	ANFEDG	WSMEBKFSGI	6545192362 Dell Way	\N	WMXHBYI	\N	0	Canada	2	WSMEBKFSGI@dell.com	6545192362	1	5225513014011085	2008/10	user18462	password	35	60000	M
18463	USYXZU	QLYRVEKCMH	1024023393 Dell Way	\N	OKPQIYT	\N	0	UK	2	QLYRVEKCMH@dell.com	1024023393	2	1895442504435777	2011/06	user18463	password	64	60000	F
18464	JLEIFU	TEMPIXRVEG	8710864729 Dell Way	\N	FUWOSQM	\N	0	Japan	2	TEMPIXRVEG@dell.com	8710864729	3	5100899226032198	2009/03	user18464	password	88	60000	M
18465	KTXQOQ	UAFDYXYCED	7891198452 Dell Way	\N	XBRPREH	\N	0	Germany	2	UAFDYXYCED@dell.com	7891198452	4	8756592902354897	2012/09	user18465	password	50	60000	F
18466	EMTTCN	TIQSGPVLSS	3628278831 Dell Way	\N	MKHDOOR	\N	0	China	2	TIQSGPVLSS@dell.com	3628278831	3	3933165693655610	2012/12	user18466	password	83	20000	F
18467	JWXMJR	VAJCPENIWZ	4359389510 Dell Way	\N	SEDHSVQ	\N	0	Australia	2	VAJCPENIWZ@dell.com	4359389510	5	1021863687317818	2009/11	user18467	password	26	60000	F
18468	YLRICN	JMPZRCHOBA	8894078024 Dell Way	\N	SFHKAYL	\N	0	China	2	JMPZRCHOBA@dell.com	8894078024	3	7813149082474411	2011/07	user18468	password	39	100000	F
18469	TQVWDF	ISEZULOWLG	5729654713 Dell Way	\N	BTRBRCM	\N	0	Germany	2	ISEZULOWLG@dell.com	5729654713	2	3507994615007192	2008/07	user18469	password	33	60000	F
18470	VKCYPL	RTLLFZHRFJ	2062467196 Dell Way	\N	KWLCZXQ	\N	0	Germany	2	RTLLFZHRFJ@dell.com	2062467196	5	6140863326378167	2011/02	user18470	password	27	100000	M
18471	NZYDKP	XVBCUITASE	8897787054 Dell Way	\N	XDHWAYK	\N	0	Canada	2	XVBCUITASE@dell.com	8897787054	5	7959348685108126	2008/02	user18471	password	66	20000	M
18472	QYTBNQ	XOTSXNSPSQ	8648755166 Dell Way	\N	TZNTYXX	\N	0	South Africa	2	XOTSXNSPSQ@dell.com	8648755166	4	8561287517659367	2012/04	user18472	password	79	60000	M
18473	UIAHZX	WSPUFIKXYD	5087428761 Dell Way	\N	XLXWIUR	\N	0	Canada	2	WSPUFIKXYD@dell.com	5087428761	3	2153642522171139	2011/05	user18473	password	69	80000	F
18474	AULZSH	SICXQMVPQT	8204352536 Dell Way	\N	ANPJHHO	\N	0	Russia	2	SICXQMVPQT@dell.com	8204352536	4	5817827753722668	2008/05	user18474	password	39	40000	F
18475	BSKTAC	CDASPWHFQI	9005269816 Dell Way	\N	TGRBNFU	\N	0	China	2	CDASPWHFQI@dell.com	9005269816	2	5260694958735258	2009/08	user18475	password	73	80000	M
18476	MBLNDN	QDGFAOLQWF	4297036582 Dell Way	\N	WOGJTAR	\N	0	Japan	2	QDGFAOLQWF@dell.com	4297036582	1	9214576755650342	2012/12	user18476	password	59	80000	F
18477	PDXTRN	XXTXLFNIKK	6546101371 Dell Way	\N	WQTQRLH	\N	0	Australia	2	XXTXLFNIKK@dell.com	6546101371	2	1261232762131840	2010/10	user18477	password	69	100000	F
18478	VVDMJA	KCYWIMFSWB	2829804029 Dell Way	\N	JPSABAB	\N	0	Japan	2	KCYWIMFSWB@dell.com	2829804029	1	2959588621743023	2012/10	user18478	password	29	40000	M
18479	ZMDJNO	MLLUXQMTSV	1344051761 Dell Way	\N	JKWLKYD	\N	0	Japan	2	MLLUXQMTSV@dell.com	1344051761	2	6374103205744178	2012/06	user18479	password	87	60000	F
18480	LQWYEI	KPCIGPCYKM	4297188504 Dell Way	\N	JHXUFAK	\N	0	Chile	2	KPCIGPCYKM@dell.com	4297188504	1	1939046732150018	2012/12	user18480	password	60	40000	F
18481	FFIJNT	ZQBFFDDQPN	7284112665 Dell Way	\N	XNHDOSK	\N	0	UK	2	ZQBFFDDQPN@dell.com	7284112665	3	8023425501771272	2011/01	user18481	password	27	20000	F
18482	IKRWDQ	MEVRIZIYMF	3176717028 Dell Way	\N	MUJAMTY	\N	0	Canada	2	MEVRIZIYMF@dell.com	3176717028	4	8520193456206472	2009/11	user18482	password	82	80000	F
18483	GHBKXO	PTGYTOXGUJ	1740234623 Dell Way	\N	ADKNWJS	\N	0	Canada	2	PTGYTOXGUJ@dell.com	1740234623	3	4882565551437438	2012/05	user18483	password	21	20000	M
18484	IFBFUR	ZAPSPMYJVZ	7278690831 Dell Way	\N	MGMIPEL	\N	0	Japan	2	ZAPSPMYJVZ@dell.com	7278690831	5	6568281002342702	2008/12	user18484	password	74	80000	F
18485	AWLUNL	VCDKOBTKBG	9231488062 Dell Way	\N	QNPGRAX	\N	0	China	2	VCDKOBTKBG@dell.com	9231488062	3	5428813246544451	2012/04	user18485	password	37	20000	F
18486	DNCQYX	TCIIECSFIJ	1455363523 Dell Way	\N	TXPKYNU	\N	0	South Africa	2	TCIIECSFIJ@dell.com	1455363523	2	7308674571570010	2009/07	user18486	password	74	80000	M
18487	ITIHRB	JZJNCCTKMM	1008513662 Dell Way	\N	ICXHPSD	\N	0	Japan	2	JZJNCCTKMM@dell.com	1008513662	5	1066467591095715	2010/08	user18487	password	66	40000	M
18488	KPFCQO	CACECVPPIX	2398727246 Dell Way	\N	RFEGXIX	\N	0	UK	2	CACECVPPIX@dell.com	2398727246	5	5384247564245016	2011/08	user18488	password	72	80000	F
18489	IXCZLF	AOJDKYSSWJ	5341546482 Dell Way	\N	XAQVJOT	\N	0	Germany	2	AOJDKYSSWJ@dell.com	5341546482	2	3448981553316116	2008/12	user18489	password	88	20000	F
18490	WFIIKI	WTMGSEYOOW	7136998216 Dell Way	\N	OESXTLL	\N	0	Chile	2	WTMGSEYOOW@dell.com	7136998216	4	3746948215644807	2011/08	user18490	password	46	100000	M
18491	PIVZRS	TDYLIXZWTO	6372966540 Dell Way	\N	BLMVXXB	\N	0	Germany	2	TDYLIXZWTO@dell.com	6372966540	2	3304696871899068	2009/09	user18491	password	36	80000	F
18492	OQIGIB	JGMSDLOXAQ	8480466152 Dell Way	\N	JMLGKMW	\N	0	UK	2	JGMSDLOXAQ@dell.com	8480466152	1	3227781158871949	2010/05	user18492	password	20	100000	M
18493	QFEYGO	FTGIFVGFLP	8413425188 Dell Way	\N	SWWCJSC	\N	0	Canada	2	FTGIFVGFLP@dell.com	8413425188	2	7944312460254879	2008/05	user18493	password	67	20000	F
18494	XHZEWE	XCNDXTJIJB	6232962727 Dell Way	\N	FGEPYGU	\N	0	Russia	2	XCNDXTJIJB@dell.com	6232962727	3	9615308480337264	2012/03	user18494	password	23	100000	F
18495	JYHFCF	IQJFKSOTTU	7812226955 Dell Way	\N	ZXKYEES	\N	0	Russia	2	IQJFKSOTTU@dell.com	7812226955	4	7151854246854783	2008/10	user18495	password	65	20000	F
18496	OLJRRR	IAXSSMMLGM	8158683267 Dell Way	\N	JRKNWDG	\N	0	Japan	2	IAXSSMMLGM@dell.com	8158683267	5	6507232990581543	2010/08	user18496	password	73	80000	F
18497	FAVWSE	XPWPBIBIUL	2408966025 Dell Way	\N	AFYWIFM	\N	0	Canada	2	XPWPBIBIUL@dell.com	2408966025	1	6992169876117260	2011/11	user18497	password	42	100000	F
18498	JTXCXU	RUKTCMCXXD	5890916465 Dell Way	\N	CWZLBLO	\N	0	Chile	2	RUKTCMCXXD@dell.com	5890916465	2	9664624233264476	2009/07	user18498	password	81	60000	M
18499	QIANDR	HOLKAOIXRK	6266752127 Dell Way	\N	TRVVDJB	\N	0	Japan	2	HOLKAOIXRK@dell.com	6266752127	1	1450358844362199	2008/11	user18499	password	52	20000	F
18500	VBAZTI	NFTNUBLLMF	1621443001 Dell Way	\N	DIAGRBX	\N	0	Chile	2	NFTNUBLLMF@dell.com	1621443001	5	4695187154691667	2012/06	user18500	password	52	60000	F
18501	NMFHVT	MOGHQSSCXW	9805591772 Dell Way	\N	KYCCZAJ	\N	0	Australia	2	MOGHQSSCXW@dell.com	9805591772	4	1046588872559368	2010/04	user18501	password	50	80000	M
18502	XXBSQO	HXVXPOAMKL	7343233300 Dell Way	\N	KNNKNXM	\N	0	Germany	2	HXVXPOAMKL@dell.com	7343233300	3	9386657261289656	2012/12	user18502	password	62	80000	M
18503	MVODKW	AGTPVUCGFN	8824070521 Dell Way	\N	TTXHRKU	\N	0	China	2	AGTPVUCGFN@dell.com	8824070521	4	3931596647482365	2011/05	user18503	password	23	80000	M
18504	XFZIBZ	OVOJPRPVEJ	2647223136 Dell Way	\N	OCQFMLO	\N	0	China	2	OVOJPRPVEJ@dell.com	2647223136	5	2202585531864315	2010/12	user18504	password	74	40000	M
18505	ZIFAHU	WWDLNTHSCV	5648201305 Dell Way	\N	UTBGFQP	\N	0	China	2	WWDLNTHSCV@dell.com	5648201305	4	9226354054640980	2010/06	user18505	password	38	40000	F
18506	PPMXJI	UNUIHBAKXU	4100706501 Dell Way	\N	DYAJOQT	\N	0	Australia	2	UNUIHBAKXU@dell.com	4100706501	4	6091920098755509	2012/12	user18506	password	88	40000	M
18507	OULYCG	MXOTZODWJH	1625770108 Dell Way	\N	UKRJAKK	\N	0	China	2	MXOTZODWJH@dell.com	1625770108	5	2810506587382406	2008/12	user18507	password	54	60000	M
18508	HALKGY	HVSGKVDTDY	7107175027 Dell Way	\N	DUHEFSO	\N	0	Chile	2	HVSGKVDTDY@dell.com	7107175027	4	3624772999901325	2011/03	user18508	password	79	20000	M
18509	WPXDNE	YFLIBPBFNF	7132422212 Dell Way	\N	AUKGMYN	\N	0	Canada	2	YFLIBPBFNF@dell.com	7132422212	5	8030733737628908	2012/08	user18509	password	84	60000	M
18510	NIQANO	GYXINZOBEO	2064852523 Dell Way	\N	VPUHNIM	\N	0	Chile	2	GYXINZOBEO@dell.com	2064852523	2	2142517096363008	2011/02	user18510	password	58	40000	M
18511	WYSJNY	IKHWJVXOKS	7689717901 Dell Way	\N	DEARMMW	\N	0	Japan	2	IKHWJVXOKS@dell.com	7689717901	1	4505182322114706	2012/07	user18511	password	67	60000	F
18512	PGUCFD	NNZWIWLSPO	2279491324 Dell Way	\N	XQGKDDA	\N	0	South Africa	2	NNZWIWLSPO@dell.com	2279491324	3	7982777013909072	2011/02	user18512	password	43	20000	M
18513	PYVVBI	JBFRYQKNFI	2382527340 Dell Way	\N	ELSHOTE	\N	0	Russia	2	JBFRYQKNFI@dell.com	2382527340	5	4792190526146442	2009/04	user18513	password	58	100000	M
18514	MTTOCC	PHTNXEBCMF	6265950390 Dell Way	\N	OFMDYQV	\N	0	Australia	2	PHTNXEBCMF@dell.com	6265950390	2	4114988070446998	2012/10	user18514	password	39	80000	F
18515	BMWDPL	LIZINALZFZ	2658045078 Dell Way	\N	FSCDJYG	\N	0	UK	2	LIZINALZFZ@dell.com	2658045078	3	8312734303530306	2012/11	user18515	password	59	40000	M
18516	BECQPN	ZPWNPHNVGS	7347274966 Dell Way	\N	NJWXHCV	\N	0	France	2	ZPWNPHNVGS@dell.com	7347274966	4	5226999737322331	2010/03	user18516	password	74	60000	F
18517	YQYNEY	CBLSIYNPRB	4750919845 Dell Way	\N	ZNYGQUS	\N	0	China	2	CBLSIYNPRB@dell.com	4750919845	1	9403237336315216	2011/12	user18517	password	53	100000	M
18518	DWKHUN	IGGRETHWUG	4740780609 Dell Way	\N	JTMANFI	\N	0	UK	2	IGGRETHWUG@dell.com	4740780609	2	6050762980245054	2009/10	user18518	password	53	40000	M
18519	JRFEFO	KLFPFMLATU	4823010779 Dell Way	\N	TGVGLDE	\N	0	South Africa	2	KLFPFMLATU@dell.com	4823010779	4	3294432925526053	2008/03	user18519	password	56	20000	M
18520	FGTLUD	XASDNEDGZX	1956098582 Dell Way	\N	NUEYXJV	\N	0	China	2	XASDNEDGZX@dell.com	1956098582	1	5746700109448284	2009/08	user18520	password	61	100000	M
18521	WRHRVE	ROHFSLMRIZ	8693007998 Dell Way	\N	LMYJWTS	\N	0	UK	2	ROHFSLMRIZ@dell.com	8693007998	2	3735267803072929	2010/11	user18521	password	35	40000	M
18522	YOJTTB	IAGBMSSURE	5594702559 Dell Way	\N	HPODJGC	\N	0	Chile	2	IAGBMSSURE@dell.com	5594702559	3	7197125970385969	2009/08	user18522	password	90	20000	M
18523	OKJHLR	IRSUKLPBQX	5824044996 Dell Way	\N	REAALDG	\N	0	UK	2	IRSUKLPBQX@dell.com	5824044996	5	3697120416443795	2008/12	user18523	password	43	80000	F
18524	TDUFUD	XNYHZNJPLA	3270852624 Dell Way	\N	ULBFPIE	\N	0	Canada	2	XNYHZNJPLA@dell.com	3270852624	3	3769751723855734	2008/10	user18524	password	23	80000	M
18525	FMUAPR	NOZNBIDMJX	7536896968 Dell Way	\N	YLCOTGR	\N	0	Australia	2	NOZNBIDMJX@dell.com	7536896968	5	2647983463015407	2010/01	user18525	password	80	20000	F
18526	IXGYOU	MOHOXKBGIZ	2494323949 Dell Way	\N	SKNLRFL	\N	0	France	2	MOHOXKBGIZ@dell.com	2494323949	4	9483649321366102	2009/06	user18526	password	21	60000	M
18527	YSSNNF	BVTYFUFNTX	4642686442 Dell Way	\N	YHIQMUA	\N	0	Japan	2	BVTYFUFNTX@dell.com	4642686442	5	8881236115004868	2012/01	user18527	password	42	80000	M
18528	BKMOQN	JJMPDRDXOC	7584416630 Dell Way	\N	EWSRRTJ	\N	0	Australia	2	JJMPDRDXOC@dell.com	7584416630	2	9535086668096484	2011/07	user18528	password	64	80000	M
18529	BFERTO	AFEEWHBKKG	5382635062 Dell Way	\N	HDXYWGA	\N	0	Japan	2	AFEEWHBKKG@dell.com	5382635062	5	4280650137923658	2008/08	user18529	password	24	80000	M
18530	HWIAKJ	FPNCXOMHUU	7101038183 Dell Way	\N	KSSHZSX	\N	0	France	2	FPNCXOMHUU@dell.com	7101038183	2	5661736797075719	2009/05	user18530	password	31	100000	M
18531	BGRLQX	BEZYSMFNGQ	1410241199 Dell Way	\N	GZXFRUR	\N	0	China	2	BEZYSMFNGQ@dell.com	1410241199	2	6763053637463600	2009/05	user18531	password	59	20000	F
18532	VRXMOY	QOWIACWGSC	2893273086 Dell Way	\N	FQIXKAH	\N	0	France	2	QOWIACWGSC@dell.com	2893273086	5	8655253450851888	2011/06	user18532	password	81	20000	F
18533	OYUDWK	RSTSVPYNSE	3684229812 Dell Way	\N	DACOAJA	\N	0	Chile	2	RSTSVPYNSE@dell.com	3684229812	5	8564524671528489	2011/10	user18533	password	82	20000	F
18534	UXLRID	KBWFRUSKZW	4009641469 Dell Way	\N	KCLLLLR	\N	0	Russia	2	KBWFRUSKZW@dell.com	4009641469	3	5881625012960285	2008/05	user18534	password	65	60000	F
18535	OWWWZG	YVLQQEAQBK	1423176068 Dell Way	\N	SMWEYNY	\N	0	Chile	2	YVLQQEAQBK@dell.com	1423176068	3	4323235331568867	2010/02	user18535	password	74	80000	M
18536	QNOQTN	MFDDKDTMOM	1292273133 Dell Way	\N	YKQXYOE	\N	0	UK	2	MFDDKDTMOM@dell.com	1292273133	3	4938468298409134	2008/04	user18536	password	23	100000	M
18537	PKOIXB	OAEZEXLTKK	1449547446 Dell Way	\N	DAHCPMC	\N	0	Japan	2	OAEZEXLTKK@dell.com	1449547446	3	8106850998941810	2009/08	user18537	password	63	40000	F
18538	AXNYYC	YDBDBNWLXA	7822153484 Dell Way	\N	MFDBRFS	\N	0	Russia	2	YDBDBNWLXA@dell.com	7822153484	3	2036781382746994	2009/02	user18538	password	50	60000	F
18539	JCCIEB	LGEMTAXQBJ	6880067155 Dell Way	\N	WELNKEH	\N	0	Canada	2	LGEMTAXQBJ@dell.com	6880067155	2	5663376703858376	2011/10	user18539	password	24	100000	F
18540	EAMJBY	QFKJGHAHRW	1592964328 Dell Way	\N	MDKWHRA	\N	0	UK	2	QFKJGHAHRW@dell.com	1592964328	3	7418706274591387	2012/08	user18540	password	64	20000	M
18541	QPESNU	XXEEFEMXBY	4177984237 Dell Way	\N	AMVHDVF	\N	0	Chile	2	XXEEFEMXBY@dell.com	4177984237	5	2058939123991877	2012/08	user18541	password	32	80000	F
18542	UXYHRW	FVAKANHCMI	8028338382 Dell Way	\N	OHPSCVY	\N	0	France	2	FVAKANHCMI@dell.com	8028338382	1	4785771794617176	2009/04	user18542	password	30	80000	F
18543	CNITKO	PKZQYHSKPH	9896969478 Dell Way	\N	RFZUAYF	\N	0	South Africa	2	PKZQYHSKPH@dell.com	9896969478	4	2660576191265136	2009/10	user18543	password	75	40000	M
18544	IQRSEG	DEXBLQLAXC	7864765043 Dell Way	\N	FXWGVCB	\N	0	South Africa	2	DEXBLQLAXC@dell.com	7864765043	2	1617123295553028	2010/01	user18544	password	44	60000	F
18545	ZDBEKF	IHGTXSUVVA	6314894447 Dell Way	\N	SSGOUIJ	\N	0	Germany	2	IHGTXSUVVA@dell.com	6314894447	3	2390017874538898	2011/10	user18545	password	64	100000	M
18546	UBZEHI	MOCKGWGBWY	3895248712 Dell Way	\N	TDNOMWD	\N	0	Australia	2	MOCKGWGBWY@dell.com	3895248712	2	7215523589868099	2008/12	user18546	password	68	100000	M
18547	TXXBFK	PIUVEBXBZQ	6578852128 Dell Way	\N	FMFRJIS	\N	0	Japan	2	PIUVEBXBZQ@dell.com	6578852128	3	8397637831978501	2010/02	user18547	password	72	40000	M
18548	QDXWNN	FIIJJGLJWQ	5029326875 Dell Way	\N	WCIGKAY	\N	0	Australia	2	FIIJJGLJWQ@dell.com	5029326875	4	6205912028905005	2010/07	user18548	password	78	60000	F
18549	ZIBNVG	WEQGKBPHSM	5083485926 Dell Way	\N	JATUBRV	\N	0	Germany	2	WEQGKBPHSM@dell.com	5083485926	2	1595049855299294	2012/03	user18549	password	53	20000	F
18550	VESRKO	VAUGCKOVWX	9288291004 Dell Way	\N	WQSXHNL	\N	0	Russia	2	VAUGCKOVWX@dell.com	9288291004	3	7543723387178034	2008/12	user18550	password	80	40000	M
18551	BBMLPI	MJOPUDKRAG	2158486901 Dell Way	\N	HSEPGQI	\N	0	Canada	2	MJOPUDKRAG@dell.com	2158486901	1	3871188380289823	2008/12	user18551	password	66	100000	M
18552	SKLHSX	RHNMKXDLEK	4733224507 Dell Way	\N	EJZKZIP	\N	0	Canada	2	RHNMKXDLEK@dell.com	4733224507	5	3198691755533218	2009/07	user18552	password	30	40000	F
18553	OTPHRG	OESZCWKHGO	5384635713 Dell Way	\N	RGZRPPU	\N	0	Australia	2	OESZCWKHGO@dell.com	5384635713	1	4260023862589151	2008/03	user18553	password	68	40000	M
18554	LXBCEQ	HXPJTARAPI	8048287550 Dell Way	\N	GPZWETW	\N	0	Japan	2	HXPJTARAPI@dell.com	8048287550	2	7380946081597359	2012/12	user18554	password	20	80000	F
18555	YUMDLT	AADUBUUQDB	1319501594 Dell Way	\N	GCXKWUB	\N	0	Japan	2	AADUBUUQDB@dell.com	1319501594	4	6620672855060548	2012/10	user18555	password	45	40000	M
18556	EUWPOX	QSRSMLJQNP	8217145093 Dell Way	\N	SLZPFBG	\N	0	Chile	2	QSRSMLJQNP@dell.com	8217145093	5	2957469756249338	2011/03	user18556	password	57	40000	F
18557	IGAXDR	PUJCGSSUHL	2024861658 Dell Way	\N	FHAKIGR	\N	0	Canada	2	PUJCGSSUHL@dell.com	2024861658	5	7594558950979263	2009/06	user18557	password	24	80000	M
18558	ITRLLG	GUINNBHUMM	5222854383 Dell Way	\N	CNXKUPO	\N	0	South Africa	2	GUINNBHUMM@dell.com	5222854383	2	3055116149596870	2012/05	user18558	password	89	80000	M
18559	TIEEPK	ZYYMAGHMTJ	6553907169 Dell Way	\N	AQUUFIR	\N	0	Japan	2	ZYYMAGHMTJ@dell.com	6553907169	5	6406173331197352	2012/11	user18559	password	38	80000	M
18560	QVUFGT	EFFELMRFWR	9897316028 Dell Way	\N	WRLCZCU	\N	0	Japan	2	EFFELMRFWR@dell.com	9897316028	2	6402137792669237	2012/08	user18560	password	38	60000	F
18561	DGNKZR	PFWBSNGPEC	3988232127 Dell Way	\N	GQEGSYW	\N	0	Russia	2	PFWBSNGPEC@dell.com	3988232127	3	6160136343445629	2012/09	user18561	password	20	40000	M
18562	HTGHLV	NHXFVDUZGB	6126515104 Dell Way	\N	QLHJKDB	\N	0	Russia	2	NHXFVDUZGB@dell.com	6126515104	4	7344799090642483	2009/09	user18562	password	88	20000	M
18563	SKGEGT	LDZGHUGOVW	9549414555 Dell Way	\N	ZCGJFHC	\N	0	Russia	2	LDZGHUGOVW@dell.com	9549414555	4	1748295524623245	2011/10	user18563	password	35	80000	F
18564	QWRXQD	APKIJQXENW	2094614033 Dell Way	\N	HTGMBIH	\N	0	Australia	2	APKIJQXENW@dell.com	2094614033	2	6911850980482996	2012/08	user18564	password	37	40000	F
18565	DADTDE	IONSEKXSGE	3775713314 Dell Way	\N	MNROVYP	\N	0	UK	2	IONSEKXSGE@dell.com	3775713314	2	8507500086445362	2012/07	user18565	password	33	20000	M
18566	GHJKMS	YZLDJIWQNI	7738826411 Dell Way	\N	DFXZENY	\N	0	France	2	YZLDJIWQNI@dell.com	7738826411	4	4402696104720235	2009/12	user18566	password	56	100000	F
18567	VGPHZN	HKRQTNHHWL	2048011494 Dell Way	\N	MTKRGJD	\N	0	Australia	2	HKRQTNHHWL@dell.com	2048011494	3	3450743488036096	2008/01	user18567	password	29	40000	M
18568	LXDKLL	VCCOPJWMVJ	6852968647 Dell Way	\N	FGAMPDN	\N	0	Russia	2	VCCOPJWMVJ@dell.com	6852968647	4	8220588865224273	2011/12	user18568	password	25	60000	F
18569	ZSULDP	NFEDPAPKJV	6676334714 Dell Way	\N	RKIGNWZ	\N	0	Canada	2	NFEDPAPKJV@dell.com	6676334714	4	8806603238452227	2010/11	user18569	password	48	100000	M
18570	DSIGHV	LLZBMPLWLD	2066689186 Dell Way	\N	GUJTQIY	\N	0	Chile	2	LLZBMPLWLD@dell.com	2066689186	5	8410935423802585	2012/03	user18570	password	73	100000	F
18571	MEPUAB	GZCSPOOARU	3950525335 Dell Way	\N	UBOKKNR	\N	0	Germany	2	GZCSPOOARU@dell.com	3950525335	3	5671863217372448	2010/04	user18571	password	45	100000	M
18572	ONNOOT	ORMEGBEYWZ	6094176037 Dell Way	\N	ALKKYBY	\N	0	Chile	2	ORMEGBEYWZ@dell.com	6094176037	3	8445155247580261	2012/11	user18572	password	71	60000	F
18573	GBZUVN	MHSTJXRFWR	5451887527 Dell Way	\N	QHCOJAV	\N	0	UK	2	MHSTJXRFWR@dell.com	5451887527	4	7807678268756718	2009/05	user18573	password	40	80000	M
18574	KSLFGY	NYRWVIBSAS	8030955996 Dell Way	\N	ADGJDCH	\N	0	Japan	2	NYRWVIBSAS@dell.com	8030955996	1	9856954302173108	2008/05	user18574	password	70	100000	M
18575	KHZRFM	PWJKFKDGDD	8750245333 Dell Way	\N	JKMNMUE	\N	0	Chile	2	PWJKFKDGDD@dell.com	8750245333	1	5185316981282085	2009/11	user18575	password	39	100000	F
18576	OZYULN	QVYWGCCJFL	3411283516 Dell Way	\N	TSZGNDN	\N	0	China	2	QVYWGCCJFL@dell.com	3411283516	5	6499902706127614	2008/04	user18576	password	62	60000	M
18577	OJPAXG	VWCBYFKERD	9089168530 Dell Way	\N	WQKJUXT	\N	0	Australia	2	VWCBYFKERD@dell.com	9089168530	2	2561106356792152	2008/12	user18577	password	60	20000	M
18578	YQOVWK	RZMQFWUXAQ	2419358236 Dell Way	\N	OLAIIUJ	\N	0	Chile	2	RZMQFWUXAQ@dell.com	2419358236	3	4716018631588668	2008/02	user18578	password	49	80000	F
18579	BGXYQO	YCEDZYAAPO	8020147687 Dell Way	\N	LQWUKGA	\N	0	Germany	2	YCEDZYAAPO@dell.com	8020147687	3	7304547687061132	2012/11	user18579	password	45	100000	M
18580	QWWHKU	KPXKOYKENW	2144292815 Dell Way	\N	UJREQRT	\N	0	France	2	KPXKOYKENW@dell.com	2144292815	3	3773538018111140	2012/11	user18580	password	37	100000	F
18581	CUTNOD	DLNRKYWXUQ	1271524632 Dell Way	\N	HLVXDOI	\N	0	Chile	2	DLNRKYWXUQ@dell.com	1271524632	4	3357088473159820	2012/11	user18581	password	31	40000	F
18582	YBNNFR	YTJJRFGMVN	4437293767 Dell Way	\N	XQLBFTI	\N	0	Chile	2	YTJJRFGMVN@dell.com	4437293767	3	2024879080243408	2009/10	user18582	password	50	40000	M
18583	NVFTME	MVNDAUPWIN	5298770885 Dell Way	\N	MTOSNXY	\N	0	South Africa	2	MVNDAUPWIN@dell.com	5298770885	1	2506750896573067	2009/07	user18583	password	50	100000	F
18584	GEUTJG	OWJPRZLZMY	7250402897 Dell Way	\N	SBRGZQD	\N	0	France	2	OWJPRZLZMY@dell.com	7250402897	2	7192105746828020	2009/09	user18584	password	65	40000	F
18585	VATEHH	BRXSQIRDHK	1800105191 Dell Way	\N	FYQEOUQ	\N	0	Chile	2	BRXSQIRDHK@dell.com	1800105191	2	5259148958604783	2012/12	user18585	password	71	100000	M
18586	UPYBXZ	SUSJDJMKUS	8713329667 Dell Way	\N	JLXXFNE	\N	0	China	2	SUSJDJMKUS@dell.com	8713329667	4	2414141867775470	2012/05	user18586	password	18	80000	F
18587	POFMOX	GGHKQUVLME	9346556870 Dell Way	\N	WKCCYHL	\N	0	Russia	2	GGHKQUVLME@dell.com	9346556870	3	6506330050062389	2009/08	user18587	password	34	60000	F
18588	URRIPY	PWIGQDRDIO	7310979238 Dell Way	\N	NKRMRCG	\N	0	Japan	2	PWIGQDRDIO@dell.com	7310979238	5	9284582733642312	2009/02	user18588	password	46	60000	M
18589	BDFRBU	NKBENSHVHV	4795680662 Dell Way	\N	GZHXBON	\N	0	Russia	2	NKBENSHVHV@dell.com	4795680662	3	1628606972284615	2010/11	user18589	password	57	40000	M
18590	ROOTJB	DKGQDOMKKS	6520426977 Dell Way	\N	KRQLGEG	\N	0	Japan	2	DKGQDOMKKS@dell.com	6520426977	2	2590249848552048	2010/11	user18590	password	57	40000	M
18591	DXGMZK	XFAATNLEFV	8665340136 Dell Way	\N	VWHCAOT	\N	0	Japan	2	XFAATNLEFV@dell.com	8665340136	5	1839807852637022	2011/06	user18591	password	50	40000	M
18592	IMCIWA	NXBHKMLQIH	1866440595 Dell Way	\N	NQKOFEE	\N	0	Australia	2	NXBHKMLQIH@dell.com	1866440595	2	7725576299242676	2010/09	user18592	password	89	20000	F
18593	MHJJHX	GIFRVQIEYV	8721439665 Dell Way	\N	VIKAMPB	\N	0	Germany	2	GIFRVQIEYV@dell.com	8721439665	5	2538680868223309	2010/10	user18593	password	44	80000	F
18594	RAPYXW	HCOCTXHSTC	9831148023 Dell Way	\N	BDDNSEC	\N	0	Germany	2	HCOCTXHSTC@dell.com	9831148023	2	2242588520981371	2011/08	user18594	password	74	20000	F
18595	UQGSMN	VBQOYYHRAI	3226502348 Dell Way	\N	UDWNIZB	\N	0	China	2	VBQOYYHRAI@dell.com	3226502348	1	1644418783020228	2012/12	user18595	password	24	40000	M
18596	SLMFZH	HQWFODXPLS	5128600330 Dell Way	\N	THFCGGK	\N	0	Germany	2	HQWFODXPLS@dell.com	5128600330	3	4692723960615695	2010/07	user18596	password	62	40000	F
18597	BRMBYT	SVZHYWXKOQ	6181111917 Dell Way	\N	STSZACM	\N	0	France	2	SVZHYWXKOQ@dell.com	6181111917	5	9174848475027830	2008/07	user18597	password	26	40000	M
18598	UWRTQJ	OPQMMNXAEP	9833671881 Dell Way	\N	UXPUACH	\N	0	Germany	2	OPQMMNXAEP@dell.com	9833671881	1	7508527909871192	2010/04	user18598	password	26	20000	F
18599	ATVQCJ	GTWTHTULJO	8444823885 Dell Way	\N	JZJKBQZ	\N	0	Australia	2	GTWTHTULJO@dell.com	8444823885	4	5713709525298328	2008/10	user18599	password	62	20000	M
18600	IAMLJT	EFMMZGYJUH	4320445809 Dell Way	\N	IERJVRK	\N	0	Japan	2	EFMMZGYJUH@dell.com	4320445809	5	7827534079551698	2008/07	user18600	password	87	20000	M
18601	ZMHIGM	OSYNYWWTEE	8686763040 Dell Way	\N	XWOSNYJ	\N	0	South Africa	2	OSYNYWWTEE@dell.com	8686763040	1	1790211909450590	2009/01	user18601	password	26	40000	F
18602	PNJVAX	OZLMWHFAMD	3930610386 Dell Way	\N	XAWKZFI	\N	0	South Africa	2	OZLMWHFAMD@dell.com	3930610386	3	2810328484512865	2009/07	user18602	password	49	60000	F
18603	ZUZZSN	YDZVLFWXJT	8891350637 Dell Way	\N	YFEXLMT	\N	0	Russia	2	YDZVLFWXJT@dell.com	8891350637	5	2381051794625819	2009/05	user18603	password	60	60000	F
18604	JMIBZH	FZCQFYNPSM	1734310000 Dell Way	\N	UWKFIDZ	\N	0	Chile	2	FZCQFYNPSM@dell.com	1734310000	1	6444576839450747	2010/09	user18604	password	26	100000	F
18605	PDEPLJ	POZUMNJFZE	5775436860 Dell Way	\N	BJKKNKP	\N	0	Germany	2	POZUMNJFZE@dell.com	5775436860	2	1536015889141708	2009/05	user18605	password	81	40000	M
18606	ANNLXC	ZWXMKGRJLT	9702727736 Dell Way	\N	TVDHFTW	\N	0	Russia	2	ZWXMKGRJLT@dell.com	9702727736	5	1074573796708136	2009/10	user18606	password	44	40000	M
18607	WTGUWG	QTTAAKKLEE	3085958510 Dell Way	\N	HHLNBHG	\N	0	Australia	2	QTTAAKKLEE@dell.com	3085958510	2	3797939511016011	2008/08	user18607	password	57	100000	M
18608	HCHEJY	XCYYMJJQNR	7273611591 Dell Way	\N	YYEZGLZ	\N	0	France	2	XCYYMJJQNR@dell.com	7273611591	2	5654928889591247	2009/11	user18608	password	44	100000	F
18609	LDIUBG	XAEJJOAWFZ	3373077481 Dell Way	\N	VKZCVYO	\N	0	Germany	2	XAEJJOAWFZ@dell.com	3373077481	1	8546490177046508	2008/06	user18609	password	67	40000	M
18610	UPSWVP	WZZFOACTZY	7127045548 Dell Way	\N	DZAYYPM	\N	0	Canada	2	WZZFOACTZY@dell.com	7127045548	2	3720757735427469	2008/12	user18610	password	59	20000	M
18611	ETQZJM	ZIRNJUHJSL	2484563026 Dell Way	\N	ISKGHWL	\N	0	UK	2	ZIRNJUHJSL@dell.com	2484563026	4	2032607492525130	2008/04	user18611	password	29	100000	F
18612	XOMHBL	PTZZNGIFRR	1860288467 Dell Way	\N	YBXGYJF	\N	0	Australia	2	PTZZNGIFRR@dell.com	1860288467	2	3231982910539955	2010/06	user18612	password	31	100000	F
18613	TJRUVH	NUGBBPHTGF	9855944421 Dell Way	\N	VELTNQW	\N	0	Japan	2	NUGBBPHTGF@dell.com	9855944421	1	1320609275717288	2010/04	user18613	password	85	100000	F
18614	HOVCVJ	WBLYRSRYXN	2951538222 Dell Way	\N	CIGQZDG	\N	0	UK	2	WBLYRSRYXN@dell.com	2951538222	2	5044108869042248	2010/03	user18614	password	41	60000	F
18615	WJPRTM	TEKKXCJUPL	6706725542 Dell Way	\N	DWCDZIC	\N	0	Chile	2	TEKKXCJUPL@dell.com	6706725542	3	7436401272658259	2012/11	user18615	password	36	40000	M
18616	QYKJKE	OVPLYYGOJJ	2439769176 Dell Way	\N	LLNLUPQ	\N	0	France	2	OVPLYYGOJJ@dell.com	2439769176	2	3550070926547051	2008/08	user18616	password	64	80000	F
18617	PEQZIF	VXQUVXIFHT	2831908423 Dell Way	\N	RUFMJVX	\N	0	Germany	2	VXQUVXIFHT@dell.com	2831908423	1	6152679224032909	2012/10	user18617	password	42	20000	F
18618	NSKVXF	TOAPLIUSCM	1230220227 Dell Way	\N	MHYWDVK	\N	0	China	2	TOAPLIUSCM@dell.com	1230220227	5	2458494788035750	2012/04	user18618	password	34	40000	M
18619	XQRVWK	JWAUFVMIHZ	2911835117 Dell Way	\N	PFVTBGC	\N	0	Australia	2	JWAUFVMIHZ@dell.com	2911835117	2	9449169763363900	2010/06	user18619	password	31	40000	F
18620	VAFRKO	OKITFVBNVR	7835991897 Dell Way	\N	TRKUXNX	\N	0	Canada	2	OKITFVBNVR@dell.com	7835991897	5	6659161988645793	2009/01	user18620	password	88	80000	M
18621	ZVNJKB	UTVAOWNKOG	8267103440 Dell Way	\N	BZBYMZB	\N	0	Chile	2	UTVAOWNKOG@dell.com	8267103440	4	5226898157037795	2012/08	user18621	password	25	80000	M
18622	YEZIFU	BAVQXJALPC	7658004731 Dell Way	\N	LRAXQBD	\N	0	France	2	BAVQXJALPC@dell.com	7658004731	4	3528981999494135	2009/09	user18622	password	86	100000	M
18623	CZZIUB	JPSGYSSOUD	8037153755 Dell Way	\N	GVBXXEJ	\N	0	Japan	2	JPSGYSSOUD@dell.com	8037153755	4	1136765934061259	2010/07	user18623	password	18	20000	M
18624	ACZUEI	KWPJPIYKME	1610910553 Dell Way	\N	FNCCSLT	\N	0	France	2	KWPJPIYKME@dell.com	1610910553	4	9836543948855252	2011/10	user18624	password	26	40000	M
18625	FHOJQZ	GGJVOHFBMK	1047465401 Dell Way	\N	PONHZGU	\N	0	Australia	2	GGJVOHFBMK@dell.com	1047465401	4	7144893922843040	2011/11	user18625	password	90	60000	F
18626	HDMYCT	ELOTSTUFEK	3591250231 Dell Way	\N	TRSSYNT	\N	0	UK	2	ELOTSTUFEK@dell.com	3591250231	3	7380792499985547	2008/06	user18626	password	36	40000	M
18627	JUQMNV	XCOQVJVZTP	5477710700 Dell Way	\N	RLHPYBO	\N	0	Chile	2	XCOQVJVZTP@dell.com	5477710700	2	4902357026934624	2012/07	user18627	password	71	80000	M
18628	OHJBCG	ERXZATZUIQ	1466657945 Dell Way	\N	GQGFSUL	\N	0	Canada	2	ERXZATZUIQ@dell.com	1466657945	5	2118156595155596	2010/08	user18628	password	74	60000	F
18629	BUGEBK	VYJWSJQBAW	4492291734 Dell Way	\N	SHBKBNP	\N	0	Canada	2	VYJWSJQBAW@dell.com	4492291734	4	7126227516680957	2008/06	user18629	password	26	20000	M
18630	XKSYUO	XEKQNBROXK	2011579430 Dell Way	\N	VZUXMKA	\N	0	South Africa	2	XEKQNBROXK@dell.com	2011579430	4	8874546849168838	2011/10	user18630	password	20	20000	M
18631	LXQFLN	KWDXXVMVFH	9194565950 Dell Way	\N	UAEHKFD	\N	0	Germany	2	KWDXXVMVFH@dell.com	9194565950	1	2132192976307124	2011/01	user18631	password	39	60000	F
18632	EBSQPC	NTALPMGVUB	5691613256 Dell Way	\N	VZIGEMT	\N	0	Australia	2	NTALPMGVUB@dell.com	5691613256	5	8378153502941132	2010/03	user18632	password	36	20000	F
18633	IUAXWN	RXYGKFCEHX	8061429926 Dell Way	\N	DQDICXL	\N	0	Japan	2	RXYGKFCEHX@dell.com	8061429926	2	2940440247766673	2012/06	user18633	password	39	40000	M
18634	CISZWK	WVRGBTKIRO	6151127452 Dell Way	\N	YVXBSIR	\N	0	France	2	WVRGBTKIRO@dell.com	6151127452	5	5111662733834237	2008/03	user18634	password	74	100000	F
18635	CPFZAC	URIVLTECIC	7281219798 Dell Way	\N	XFDPNVC	\N	0	Canada	2	URIVLTECIC@dell.com	7281219798	3	2570360803510994	2012/05	user18635	password	21	20000	F
18636	RJLRLG	JUCUNGWWIU	1655894480 Dell Way	\N	BMKPHNS	\N	0	UK	2	JUCUNGWWIU@dell.com	1655894480	5	8639762499369682	2010/12	user18636	password	90	100000	M
18637	JIGVOP	PQKDWHZFBB	2976653258 Dell Way	\N	RLQYYIX	\N	0	Australia	2	PQKDWHZFBB@dell.com	2976653258	4	4913978246506304	2008/09	user18637	password	41	80000	F
18638	QZXFPN	WARSHQYISP	2635899973 Dell Way	\N	TINSRLS	\N	0	UK	2	WARSHQYISP@dell.com	2635899973	1	1472635809797793	2012/06	user18638	password	75	20000	F
18639	UYIKME	KDXSUVAMKU	4256973440 Dell Way	\N	VYMNJFK	\N	0	Germany	2	KDXSUVAMKU@dell.com	4256973440	3	5291247624438256	2012/04	user18639	password	55	100000	F
18640	MHLYLW	BIOWEPIOJE	5888386015 Dell Way	\N	NWRWCCL	\N	0	France	2	BIOWEPIOJE@dell.com	5888386015	5	3463101812172681	2011/06	user18640	password	34	100000	M
18641	MHVYDX	HSTLHCARGN	7804600450 Dell Way	\N	OXKQZWB	\N	0	Germany	2	HSTLHCARGN@dell.com	7804600450	2	4055152065120638	2008/07	user18641	password	31	20000	F
18642	MWZQTH	INSQPTHWHW	8678008029 Dell Way	\N	USMUONI	\N	0	China	2	INSQPTHWHW@dell.com	8678008029	4	5288422608748079	2010/10	user18642	password	56	60000	F
18643	KMYETG	RMXHFFDNBX	6714673036 Dell Way	\N	FNRTAZB	\N	0	South Africa	2	RMXHFFDNBX@dell.com	6714673036	3	3681417407002300	2010/01	user18643	password	73	80000	F
18644	FSQZYI	LWPRBSECPK	7729975704 Dell Way	\N	QHDRGFO	\N	0	UK	2	LWPRBSECPK@dell.com	7729975704	5	4336729546077550	2012/08	user18644	password	28	40000	M
18645	VXUUFG	RVXSNCVDML	5640739773 Dell Way	\N	LQDSWRP	\N	0	Japan	2	RVXSNCVDML@dell.com	5640739773	5	4817919494584203	2008/02	user18645	password	69	100000	M
18646	QTTWAK	RYDEAYINKT	1178078779 Dell Way	\N	ENLBEBQ	\N	0	Russia	2	RYDEAYINKT@dell.com	1178078779	1	8480235695838929	2008/10	user18646	password	75	20000	F
18647	OVGOGX	MJCNILBSEF	1044210226 Dell Way	\N	GQHLSYD	\N	0	Russia	2	MJCNILBSEF@dell.com	1044210226	5	8603196991607548	2011/10	user18647	password	85	20000	F
18648	TLWZJJ	JMWRXXJCDQ	2438984982 Dell Way	\N	TLBLJED	\N	0	China	2	JMWRXXJCDQ@dell.com	2438984982	5	2320648988243192	2012/12	user18648	password	43	40000	M
18649	UCRELA	QIROGBQKRK	9801385506 Dell Way	\N	VSVEXZN	\N	0	Australia	2	QIROGBQKRK@dell.com	9801385506	4	9998973451554776	2012/01	user18649	password	34	60000	M
18650	IGZTGQ	CYEIZVSRFN	8838619246 Dell Way	\N	KARIAFK	\N	0	UK	2	CYEIZVSRFN@dell.com	8838619246	3	9070044288411736	2012/08	user18650	password	52	80000	M
18651	SRSZHU	XLCXHVOMIZ	1807770295 Dell Way	\N	NAHNFRN	\N	0	Australia	2	XLCXHVOMIZ@dell.com	1807770295	3	9733558618463576	2011/11	user18651	password	66	80000	M
18652	IJPQEN	BHKJCZVLYI	8605673177 Dell Way	\N	LFWRXKT	\N	0	UK	2	BHKJCZVLYI@dell.com	8605673177	4	7434948575682939	2011/05	user18652	password	45	40000	M
18653	TYIYLK	FWTIVPTTYE	3859736001 Dell Way	\N	ZVWXFPX	\N	0	Australia	2	FWTIVPTTYE@dell.com	3859736001	4	8366921786218882	2011/12	user18653	password	31	60000	M
18654	DTRPEX	MXFHNYBLDB	4764873635 Dell Way	\N	GZYMPVN	\N	0	South Africa	2	MXFHNYBLDB@dell.com	4764873635	2	6396637671627105	2010/07	user18654	password	19	20000	M
18655	TVHXST	VXBIVDUZEA	4349909828 Dell Way	\N	YCMOXAL	\N	0	China	2	VXBIVDUZEA@dell.com	4349909828	1	7532688477542252	2012/01	user18655	password	81	60000	M
18656	RXTJQP	HSXDVRCZSB	1606338422 Dell Way	\N	BEPZFAI	\N	0	Germany	2	HSXDVRCZSB@dell.com	1606338422	1	5387750902213156	2008/11	user18656	password	24	100000	M
18657	ZRYQGG	IEJEWLDOMF	5913748765 Dell Way	\N	TCFYCNN	\N	0	Canada	2	IEJEWLDOMF@dell.com	5913748765	1	3717960245907307	2010/02	user18657	password	35	20000	F
18658	XZSEFB	IPFFAJUNPN	1399816965 Dell Way	\N	PUMSHAX	\N	0	South Africa	2	IPFFAJUNPN@dell.com	1399816965	2	3654913988430053	2008/06	user18658	password	41	40000	F
18659	IYNNAW	CFBDPWREJG	1912855857 Dell Way	\N	YWZGXXC	\N	0	UK	2	CFBDPWREJG@dell.com	1912855857	3	1813198394607752	2010/09	user18659	password	41	100000	F
18660	HLOHHR	MJVCFMGPTF	9723882629 Dell Way	\N	LSLJQOH	\N	0	Russia	2	MJVCFMGPTF@dell.com	9723882629	2	3433769073802978	2011/09	user18660	password	30	80000	M
18661	PHHXZT	GUWMGCBZHN	6073848828 Dell Way	\N	STWIIEB	\N	0	Chile	2	GUWMGCBZHN@dell.com	6073848828	2	9843206438701600	2009/07	user18661	password	69	40000	F
18662	ANAZHH	TDTZGVZNIS	4889069350 Dell Way	\N	HFAPKCX	\N	0	UK	2	TDTZGVZNIS@dell.com	4889069350	5	3217520066536963	2012/08	user18662	password	55	20000	M
18663	BBOJIH	MCHTXHHGZO	9458682381 Dell Way	\N	MAEWDBW	\N	0	Germany	2	MCHTXHHGZO@dell.com	9458682381	1	5467957694083452	2010/08	user18663	password	57	20000	M
18664	PRAYZN	AHGYONEOCR	5376740903 Dell Way	\N	PGNSIKG	\N	0	Chile	2	AHGYONEOCR@dell.com	5376740903	4	8028531124349684	2008/04	user18664	password	83	80000	M
18665	OTWOGX	VNVKBAYDRN	3119460219 Dell Way	\N	JEFRPMY	\N	0	Australia	2	VNVKBAYDRN@dell.com	3119460219	4	2451646685134619	2010/08	user18665	password	84	60000	F
18666	RITYFO	MAYNAWQRKA	4353798730 Dell Way	\N	WQSLCQN	\N	0	China	2	MAYNAWQRKA@dell.com	4353798730	4	8835112333297730	2012/08	user18666	password	41	20000	F
18667	QXFVMR	WKEWHUORVK	1377435176 Dell Way	\N	HNWKEJT	\N	0	Germany	2	WKEWHUORVK@dell.com	1377435176	4	5714169302023948	2011/12	user18667	password	69	100000	M
18668	QCKCUG	NYCUTRMOCU	5923526440 Dell Way	\N	BYFFIYT	\N	0	China	2	NYCUTRMOCU@dell.com	5923526440	2	9818419353105128	2010/12	user18668	password	81	20000	M
18669	ZLSTRG	RUBLLNANIC	4089964367 Dell Way	\N	LOHTMBD	\N	0	Australia	2	RUBLLNANIC@dell.com	4089964367	1	5621796144172550	2009/12	user18669	password	57	100000	M
18670	ZRRQXJ	KYVWMVJVXV	8501772229 Dell Way	\N	JFPWHTX	\N	0	Japan	2	KYVWMVJVXV@dell.com	8501772229	3	9529072002973408	2012/12	user18670	password	83	80000	M
18671	OLOMVZ	KQWXLGSJCB	3237091412 Dell Way	\N	OSYVLVL	\N	0	Chile	2	KQWXLGSJCB@dell.com	3237091412	3	1602181094698608	2009/04	user18671	password	77	20000	M
18672	GSIBST	SOQEUINXKC	8071808365 Dell Way	\N	PIYAEJH	\N	0	France	2	SOQEUINXKC@dell.com	8071808365	2	6720019819214941	2008/02	user18672	password	74	100000	F
18673	MHMFAE	URIPZWMKYB	7005394386 Dell Way	\N	TWBYGIJ	\N	0	Australia	2	URIPZWMKYB@dell.com	7005394386	5	2099747614003718	2012/10	user18673	password	23	40000	F
18674	JSMKWG	BFVBBHMZIF	5282423395 Dell Way	\N	WKDCSMD	\N	0	China	2	BFVBBHMZIF@dell.com	5282423395	2	2866136423777789	2009/05	user18674	password	49	60000	M
18675	DZCAFE	FAGGISGQYD	6701552315 Dell Way	\N	BBFTOJD	\N	0	Australia	2	FAGGISGQYD@dell.com	6701552315	2	3502302175387740	2012/10	user18675	password	74	80000	M
18676	TUYZZD	AFKIYRZWUA	3507351718 Dell Way	\N	YAUMJYN	\N	0	Australia	2	AFKIYRZWUA@dell.com	3507351718	5	9905827934853734	2008/08	user18676	password	67	100000	F
18677	MYILBI	RMQPEPMYQK	3389789944 Dell Way	\N	YKXIILJ	\N	0	Japan	2	RMQPEPMYQK@dell.com	3389789944	2	7140054890885950	2012/01	user18677	password	67	40000	F
18678	PNYRVQ	EMGICSHSDF	3370093691 Dell Way	\N	DBOMNXC	\N	0	Russia	2	EMGICSHSDF@dell.com	3370093691	4	6673148401081563	2009/06	user18678	password	79	80000	F
18679	JSSFJX	RPFUIMNLSQ	9832771447 Dell Way	\N	MHDAFFU	\N	0	France	2	RPFUIMNLSQ@dell.com	9832771447	3	7771155483555049	2010/03	user18679	password	56	60000	M
18680	GFUPCM	EIGMUUYNKL	6605665874 Dell Way	\N	UNLATFM	\N	0	Russia	2	EIGMUUYNKL@dell.com	6605665874	2	2399339447729289	2012/10	user18680	password	64	60000	F
18681	VHPYTU	GAHBUGOFRJ	1810326653 Dell Way	\N	TDJMJWF	\N	0	UK	2	GAHBUGOFRJ@dell.com	1810326653	2	8508470010943712	2012/01	user18681	password	40	100000	M
18682	OMUIHA	JOBEVQJMAC	2783237758 Dell Way	\N	QJPZGVY	\N	0	China	2	JOBEVQJMAC@dell.com	2783237758	4	2599225358106196	2009/01	user18682	password	20	20000	M
18683	NVZUWI	JYMEPWRPZH	9498108183 Dell Way	\N	ZPGFKEN	\N	0	Japan	2	JYMEPWRPZH@dell.com	9498108183	4	8279702304396779	2008/09	user18683	password	80	80000	F
18684	SQBOZK	NMOCJFRIMQ	1728670069 Dell Way	\N	XTVIXJX	\N	0	South Africa	2	NMOCJFRIMQ@dell.com	1728670069	4	8835357466246934	2012/08	user18684	password	56	20000	F
18685	EDWENJ	RCLAICIVTG	2769978920 Dell Way	\N	OPOMZMI	\N	0	Australia	2	RCLAICIVTG@dell.com	2769978920	1	8881928619462998	2011/09	user18685	password	88	20000	M
18686	CXBQGS	TSTBVBWOIL	4518027022 Dell Way	\N	EWXDIFE	\N	0	Germany	2	TSTBVBWOIL@dell.com	4518027022	1	3896784441079944	2008/01	user18686	password	46	20000	F
18687	HCTOUM	HOOCPKRXVV	2525112838 Dell Way	\N	USYDYDR	\N	0	China	2	HOOCPKRXVV@dell.com	2525112838	5	4925379424355924	2008/05	user18687	password	50	40000	M
18688	NBGINN	WCQMMHKICF	1000397147 Dell Way	\N	BBIAEAI	\N	0	China	2	WCQMMHKICF@dell.com	1000397147	4	5741858579684049	2009/03	user18688	password	78	20000	M
18689	WICKWY	MMLZUWIWBK	5486577903 Dell Way	\N	YKKCKTL	\N	0	China	2	MMLZUWIWBK@dell.com	5486577903	5	8026192028541119	2011/10	user18689	password	80	60000	M
18690	ENCBMO	NYOHUXEWHC	6851830946 Dell Way	\N	GSFQLRB	\N	0	UK	2	NYOHUXEWHC@dell.com	6851830946	5	6803806643467397	2010/09	user18690	password	25	20000	M
18691	QFXDUL	CJSXGXTOAA	5745613580 Dell Way	\N	GGQRXSQ	\N	0	Germany	2	CJSXGXTOAA@dell.com	5745613580	2	1167290428187698	2009/05	user18691	password	28	20000	F
18692	JYDEKF	NCCTAWIAWO	2115711774 Dell Way	\N	HNGFFWT	\N	0	Russia	2	NCCTAWIAWO@dell.com	2115711774	4	9507954749278724	2010/12	user18692	password	18	60000	F
18693	ZQLJWY	MYSMVBNRPU	5766249385 Dell Way	\N	EWZKSTD	\N	0	South Africa	2	MYSMVBNRPU@dell.com	5766249385	1	3929327984806150	2010/02	user18693	password	77	80000	F
18694	LFKHEX	GWJBYWTNRY	6053501821 Dell Way	\N	JRICKMY	\N	0	UK	2	GWJBYWTNRY@dell.com	6053501821	2	4647315322887153	2011/01	user18694	password	29	80000	M
18695	JDUNAB	KKCIHVVYUF	5729316079 Dell Way	\N	QCIBPGZ	\N	0	Canada	2	KKCIHVVYUF@dell.com	5729316079	3	8180757876951248	2011/07	user18695	password	56	20000	M
18696	RXKSYU	CBCJXYIREY	4610017949 Dell Way	\N	UMAJTAM	\N	0	Chile	2	CBCJXYIREY@dell.com	4610017949	2	8837033142801375	2012/10	user18696	password	90	100000	F
18697	XGEWBH	XDQVBZMGYG	4697739473 Dell Way	\N	SYQLYDS	\N	0	China	2	XDQVBZMGYG@dell.com	4697739473	3	3746190864592791	2009/07	user18697	password	29	80000	F
18698	KXILEG	PVBRUOXTVP	4443983867 Dell Way	\N	RLBQOUZ	\N	0	UK	2	PVBRUOXTVP@dell.com	4443983867	2	2871363739017397	2012/06	user18698	password	84	60000	M
18699	UUIZBX	UDOORLINBZ	9219879633 Dell Way	\N	ZDQOXQN	\N	0	Chile	2	UDOORLINBZ@dell.com	9219879633	4	3305650782771409	2009/08	user18699	password	69	40000	F
18700	MOKOLF	RATJMBWNBV	6835358096 Dell Way	\N	RSKOIXW	\N	0	Chile	2	RATJMBWNBV@dell.com	6835358096	1	6389412865042687	2009/10	user18700	password	78	80000	F
18701	JEWVJN	VDWIFTWHPN	1331637060 Dell Way	\N	ZZBHXYN	\N	0	Germany	2	VDWIFTWHPN@dell.com	1331637060	1	8536943583283574	2012/12	user18701	password	60	20000	F
18702	TAEDNZ	GKILDESTRS	6914389833 Dell Way	\N	STAPRND	\N	0	Japan	2	GKILDESTRS@dell.com	6914389833	5	5963036414235831	2011/07	user18702	password	70	100000	F
18703	TCLHCS	RKEVOXOFPH	1255263015 Dell Way	\N	ZPXQDBI	\N	0	Russia	2	RKEVOXOFPH@dell.com	1255263015	5	4566197367850691	2011/08	user18703	password	42	100000	F
18704	LJPNCH	YGCMDRSTZR	5526877473 Dell Way	\N	IWHLXQG	\N	0	UK	2	YGCMDRSTZR@dell.com	5526877473	4	5912568589672447	2008/12	user18704	password	52	60000	F
18705	WAYYHW	FKJICBBBTK	7779285414 Dell Way	\N	YBWWRCU	\N	0	Canada	2	FKJICBBBTK@dell.com	7779285414	2	3571880726609379	2011/10	user18705	password	69	20000	M
18706	SCQAYV	LHENJGPDQN	5879472410 Dell Way	\N	FNKWQFB	\N	0	China	2	LHENJGPDQN@dell.com	5879472410	2	2085184350609779	2009/01	user18706	password	37	20000	M
18707	JRUHNG	PRTZYICPWH	6638518798 Dell Way	\N	CGETLGD	\N	0	Australia	2	PRTZYICPWH@dell.com	6638518798	2	4320646304171533	2011/07	user18707	password	48	60000	M
18708	CHEQNT	IHTGPWWMEZ	2006774995 Dell Way	\N	TJSFQWF	\N	0	Chile	2	IHTGPWWMEZ@dell.com	2006774995	3	9490008101332934	2011/01	user18708	password	48	60000	F
18709	SRTFLC	MEJCBFPFEJ	4210649616 Dell Way	\N	PXOFTUL	\N	0	South Africa	2	MEJCBFPFEJ@dell.com	4210649616	2	5430137369316072	2009/10	user18709	password	90	60000	M
18710	RGTCIG	HRJIWYOBID	2737095431 Dell Way	\N	YWISQUO	\N	0	Australia	2	HRJIWYOBID@dell.com	2737095431	1	4293046683538705	2008/01	user18710	password	79	60000	M
18711	CHVKOC	CXLZWAAEEZ	3286311272 Dell Way	\N	BNRSHFS	\N	0	France	2	CXLZWAAEEZ@dell.com	3286311272	1	5608183556236327	2009/11	user18711	password	21	20000	M
18712	JVKXYM	UKLRKMVPLX	4074083419 Dell Way	\N	CCPKIHX	\N	0	Germany	2	UKLRKMVPLX@dell.com	4074083419	3	8711756291799248	2009/06	user18712	password	80	40000	M
18713	RQSPDN	APELBAANXC	8281941475 Dell Way	\N	PMMXUKM	\N	0	Canada	2	APELBAANXC@dell.com	8281941475	2	4267787327989936	2009/03	user18713	password	62	20000	M
18714	GUMKHM	AMXBMXOKAE	8886373266 Dell Way	\N	XNBRXOU	\N	0	Russia	2	AMXBMXOKAE@dell.com	8886373266	1	1016062940936535	2008/10	user18714	password	24	100000	F
18715	WKLEXL	RVMETBOTFM	1510579268 Dell Way	\N	HHDFWXY	\N	0	Russia	2	RVMETBOTFM@dell.com	1510579268	5	8131245543248952	2012/01	user18715	password	70	100000	M
18716	DGCBRT	WEXPGMJLYQ	7446418887 Dell Way	\N	TBWPZUI	\N	0	Australia	2	WEXPGMJLYQ@dell.com	7446418887	1	8658275613095612	2011/11	user18716	password	67	80000	M
18717	YSBQLX	UJNAVWMTNG	4007815937 Dell Way	\N	VJWVDFW	\N	0	South Africa	2	UJNAVWMTNG@dell.com	4007815937	4	6460837077815086	2008/05	user18717	password	35	20000	F
18718	YGYKDS	URTPNFJBME	5953521273 Dell Way	\N	KIZONWL	\N	0	South Africa	2	URTPNFJBME@dell.com	5953521273	1	1509077198337763	2012/04	user18718	password	36	40000	F
18719	MERQXL	HRBVXKWJPH	4165126540 Dell Way	\N	ROWFKHC	\N	0	UK	2	HRBVXKWJPH@dell.com	4165126540	1	9158421273343266	2011/05	user18719	password	29	100000	M
18720	JONGAU	XBPVLMEATW	3689371891 Dell Way	\N	PPCAXEZ	\N	0	Chile	2	XBPVLMEATW@dell.com	3689371891	5	9220151492394508	2011/01	user18720	password	77	60000	F
18721	JBRKWP	LMKWYOXSLN	4747155088 Dell Way	\N	INNGRNN	\N	0	UK	2	LMKWYOXSLN@dell.com	4747155088	3	6977839742787183	2010/03	user18721	password	34	100000	M
18722	HOZEDL	QOIPDFHOSQ	8038681487 Dell Way	\N	BGWTTJS	\N	0	Canada	2	QOIPDFHOSQ@dell.com	8038681487	2	6872066989541054	2008/08	user18722	password	56	80000	M
18723	CQBFBS	TJHWPPLIFN	4328722104 Dell Way	\N	OBGILZM	\N	0	Chile	2	TJHWPPLIFN@dell.com	4328722104	1	2979459578637034	2012/09	user18723	password	79	100000	M
18724	MZZNRT	XZQMPBUUOJ	3999904196 Dell Way	\N	WVRHUEM	\N	0	Canada	2	XZQMPBUUOJ@dell.com	3999904196	4	2359310034662485	2008/07	user18724	password	21	80000	F
18725	AUNSNL	SEYHFTBUCX	4323700158 Dell Way	\N	PUEKZRO	\N	0	China	2	SEYHFTBUCX@dell.com	4323700158	4	3887936281971634	2012/10	user18725	password	25	100000	M
18726	WLNKXF	OVMUOOORMD	8230556347 Dell Way	\N	LROKICS	\N	0	Russia	2	OVMUOOORMD@dell.com	8230556347	1	6591246629133821	2010/02	user18726	password	57	40000	F
18727	AWKXBZ	SOTHCIYPLJ	5812508157 Dell Way	\N	GAUPCMH	\N	0	UK	2	SOTHCIYPLJ@dell.com	5812508157	5	5204238226637244	2011/06	user18727	password	77	80000	F
18728	RDJSCC	GWJJEHYQQF	1097107206 Dell Way	\N	QLUSYCQ	\N	0	France	2	GWJJEHYQQF@dell.com	1097107206	1	2260818389244377	2010/11	user18728	password	79	100000	M
18729	YHHBKO	XTYBAWRRCH	7664625458 Dell Way	\N	CWAAZQM	\N	0	UK	2	XTYBAWRRCH@dell.com	7664625458	4	5035682252608240	2011/06	user18729	password	46	40000	F
18730	SNMCCJ	VAKWXCNZJQ	8284636278 Dell Way	\N	VJRUAEU	\N	0	Russia	2	VAKWXCNZJQ@dell.com	8284636278	2	4754985332489014	2009/08	user18730	password	65	80000	F
18731	EEKGOG	GZCDBQCKGY	7667085497 Dell Way	\N	UYTVCNP	\N	0	UK	2	GZCDBQCKGY@dell.com	7667085497	1	2762628951109946	2009/08	user18731	password	84	80000	M
18732	CBBQHI	PKLRAOBHNW	3676005941 Dell Way	\N	FGSHUHF	\N	0	Germany	2	PKLRAOBHNW@dell.com	3676005941	3	8821479980833829	2012/04	user18732	password	57	80000	F
18733	PVBXDR	HPIHEKORGU	7465740745 Dell Way	\N	YYCSGHF	\N	0	Germany	2	HPIHEKORGU@dell.com	7465740745	1	5470377591438592	2008/08	user18733	password	37	60000	F
18734	CMDGDL	WMTAWISCCQ	7039387173 Dell Way	\N	BEJIMOW	\N	0	Canada	2	WMTAWISCCQ@dell.com	7039387173	2	3144350339192897	2009/08	user18734	password	68	60000	M
18735	ERZICV	UVVQDNTGEV	4434967978 Dell Way	\N	KNDXCAC	\N	0	Russia	2	UVVQDNTGEV@dell.com	4434967978	2	1647322274278849	2008/01	user18735	password	62	80000	F
18736	HSOJNI	FIZJWTPBPA	4069820839 Dell Way	\N	OSXRTAL	\N	0	Canada	2	FIZJWTPBPA@dell.com	4069820839	3	2212286658585071	2009/02	user18736	password	81	60000	F
18737	OCUBLZ	KLJHEYITZX	5762508814 Dell Way	\N	MWOFWAJ	\N	0	Chile	2	KLJHEYITZX@dell.com	5762508814	3	6261341198347509	2011/05	user18737	password	28	20000	M
18738	GVZSVK	DERIDACCXO	6756586718 Dell Way	\N	YMUVNDB	\N	0	Australia	2	DERIDACCXO@dell.com	6756586718	4	7170748896431179	2012/10	user18738	password	71	100000	F
18739	OXTJHX	NZFQZHTXWR	3073181196 Dell Way	\N	KQNXUPY	\N	0	France	2	NZFQZHTXWR@dell.com	3073181196	4	4887132502626628	2008/05	user18739	password	43	20000	M
18740	GVHNSV	NYMMFFKBXU	3329228187 Dell Way	\N	SKSNZQY	\N	0	Chile	2	NYMMFFKBXU@dell.com	3329228187	2	3285062276292592	2011/09	user18740	password	42	60000	M
18741	EVMWQA	UCNAHXBESU	6447904044 Dell Way	\N	PKHPAGV	\N	0	Chile	2	UCNAHXBESU@dell.com	6447904044	1	9178130057174712	2009/05	user18741	password	49	40000	M
18742	GULWUG	ZHGGFILXCB	5800860191 Dell Way	\N	IKQJQLQ	\N	0	Chile	2	ZHGGFILXCB@dell.com	5800860191	3	6011857106816024	2012/12	user18742	password	79	60000	F
18743	QYCKEB	SLIYTUWWVE	7319786309 Dell Way	\N	HLNXXDD	\N	0	France	2	SLIYTUWWVE@dell.com	7319786309	4	4510803046170622	2011/07	user18743	password	83	100000	F
18744	VAPACH	MLGGFCDBGK	2081574063 Dell Way	\N	MTHKXLW	\N	0	Japan	2	MLGGFCDBGK@dell.com	2081574063	2	3759050263091922	2011/02	user18744	password	34	100000	M
18745	GKAJSN	UYTABWBHGO	1721746843 Dell Way	\N	BOYZZVP	\N	0	Canada	2	UYTABWBHGO@dell.com	1721746843	5	7807068573310972	2009/02	user18745	password	59	40000	F
18746	ZGSRTN	QMNRJOYQCA	5203219381 Dell Way	\N	EBZDWOG	\N	0	UK	2	QMNRJOYQCA@dell.com	5203219381	1	2717536541633308	2010/07	user18746	password	48	100000	M
18747	RSFLFW	XSNHHMXJMB	5400639188 Dell Way	\N	LLFIAMH	\N	0	France	2	XSNHHMXJMB@dell.com	5400639188	3	1733694287016987	2008/11	user18747	password	21	80000	M
18748	TWZYSX	RFEZRBIDDU	8445029410 Dell Way	\N	PJCQVJC	\N	0	China	2	RFEZRBIDDU@dell.com	8445029410	1	4574868316762149	2011/03	user18748	password	19	40000	M
18749	WGYODQ	UHPLJYPNSE	1992971044 Dell Way	\N	WUVSEXA	\N	0	UK	2	UHPLJYPNSE@dell.com	1992971044	3	7264465564396233	2009/06	user18749	password	87	40000	F
18750	EHXIXR	PMDZKSMCXJ	5566509001 Dell Way	\N	XSBBQCB	\N	0	Russia	2	PMDZKSMCXJ@dell.com	5566509001	4	1802259097341448	2012/09	user18750	password	49	40000	M
18751	SEFPVV	CYUMRHPOQN	4757871573 Dell Way	\N	HSPXURQ	\N	0	Chile	2	CYUMRHPOQN@dell.com	4757871573	4	3184510338120162	2008/02	user18751	password	55	20000	M
18752	RGLNBO	LWBCERRUEY	2840382531 Dell Way	\N	MUVHLMO	\N	0	South Africa	2	LWBCERRUEY@dell.com	2840382531	5	9888414723798634	2009/04	user18752	password	19	40000	F
18753	GRNIFY	EGBIXTDCSQ	3780537259 Dell Way	\N	WOYIAME	\N	0	Chile	2	EGBIXTDCSQ@dell.com	3780537259	1	6207209698390216	2011/03	user18753	password	75	80000	F
18754	MDTRCY	YEHWYLZQCW	5704265865 Dell Way	\N	EAEENJK	\N	0	South Africa	2	YEHWYLZQCW@dell.com	5704265865	5	5011119990609586	2011/10	user18754	password	24	20000	F
18755	GXXIWW	NDSLPSCROG	8355359068 Dell Way	\N	RSLEBVZ	\N	0	Germany	2	NDSLPSCROG@dell.com	8355359068	3	3695783201139420	2010/07	user18755	password	50	100000	M
18756	JTCFPP	JIBZADQOJH	9007396854 Dell Way	\N	HUMJQLY	\N	0	France	2	JIBZADQOJH@dell.com	9007396854	2	1436141024343669	2010/09	user18756	password	82	20000	F
18757	QGHGVQ	OXPPAGEKOL	9962097947 Dell Way	\N	FAUWMTI	\N	0	China	2	OXPPAGEKOL@dell.com	9962097947	2	8056472382973880	2011/03	user18757	password	86	80000	M
18758	EACARR	XHGYNLICWO	1802207175 Dell Way	\N	CRKPLSZ	\N	0	France	2	XHGYNLICWO@dell.com	1802207175	4	2076759297400713	2009/09	user18758	password	81	20000	M
18759	XHWOYT	VFSJQBLNPO	9352016163 Dell Way	\N	FAEQTEB	\N	0	South Africa	2	VFSJQBLNPO@dell.com	9352016163	1	2435763003770262	2011/01	user18759	password	43	60000	M
18760	QJMPDI	VVSLWEZMTE	1667898132 Dell Way	\N	MYVFCXB	\N	0	Australia	2	VVSLWEZMTE@dell.com	1667898132	2	6787812040187419	2008/07	user18760	password	28	20000	F
18761	NOUQXP	MQBIVBUOFH	8106401745 Dell Way	\N	MBNOYOP	\N	0	Australia	2	MQBIVBUOFH@dell.com	8106401745	2	2143457327969372	2009/05	user18761	password	32	60000	M
18762	TJNRZZ	HBHCCCRHKE	6120937677 Dell Way	\N	JXTHMIH	\N	0	Chile	2	HBHCCCRHKE@dell.com	6120937677	2	6689786265138537	2012/08	user18762	password	32	100000	F
18763	OIAOHI	PPLRSCZCHI	3497057719 Dell Way	\N	AAPNJWU	\N	0	UK	2	PPLRSCZCHI@dell.com	3497057719	3	8824510063976050	2012/08	user18763	password	67	40000	F
18764	AGSHOI	XAZPDZSKIT	4961012131 Dell Way	\N	LXGUUAS	\N	0	Australia	2	XAZPDZSKIT@dell.com	4961012131	3	9534198165405544	2008/04	user18764	password	30	40000	F
18765	KYOZHM	ZGCCGUNOOY	1068211492 Dell Way	\N	MUSHVLJ	\N	0	Chile	2	ZGCCGUNOOY@dell.com	1068211492	2	3834989614319056	2009/06	user18765	password	57	60000	M
18766	MDXTPW	ARZHMNWALI	3870658706 Dell Way	\N	VDQQPAX	\N	0	Germany	2	ARZHMNWALI@dell.com	3870658706	2	8713542835786940	2012/10	user18766	password	47	80000	F
18767	NPACMB	UMJGZFHKOC	9150666604 Dell Way	\N	OETDERS	\N	0	Germany	2	UMJGZFHKOC@dell.com	9150666604	3	3822085477411747	2011/12	user18767	password	19	100000	M
18768	QZPDBK	PKQOPYZEBO	1145630584 Dell Way	\N	IVSNMLA	\N	0	France	2	PKQOPYZEBO@dell.com	1145630584	2	1721098625101149	2008/05	user18768	password	19	60000	F
18769	ACDBNS	LEHBCHFEVO	5162210894 Dell Way	\N	ZOCMZCW	\N	0	UK	2	LEHBCHFEVO@dell.com	5162210894	5	9954832999967040	2012/12	user18769	password	54	100000	M
18770	QYADRM	HZNJGTNCHN	8252630094 Dell Way	\N	QJZPMWP	\N	0	UK	2	HZNJGTNCHN@dell.com	8252630094	3	8018692220095546	2011/02	user18770	password	63	80000	M
18771	PUVGHC	FUMMOAOVNE	1009094670 Dell Way	\N	FMURJKQ	\N	0	Canada	2	FUMMOAOVNE@dell.com	1009094670	3	9463291774038226	2008/01	user18771	password	69	100000	M
18772	NQWUTB	PGODGCZUHE	8980816598 Dell Way	\N	HBWQMMU	\N	0	France	2	PGODGCZUHE@dell.com	8980816598	4	6222830787301064	2012/06	user18772	password	46	60000	M
18773	BJTVLI	BZLICLDJPK	6185847198 Dell Way	\N	LLBXYVK	\N	0	South Africa	2	BZLICLDJPK@dell.com	6185847198	5	7678337732795627	2008/05	user18773	password	36	100000	F
18774	QSFCAH	CMPEXTNNDY	3155797202 Dell Way	\N	ZFWXAGT	\N	0	Japan	2	CMPEXTNNDY@dell.com	3155797202	3	6664848133455963	2011/10	user18774	password	61	20000	F
18775	HGMINO	UDSSXFFAEF	4228783327 Dell Way	\N	FBDGIWW	\N	0	Germany	2	UDSSXFFAEF@dell.com	4228783327	3	2462345354724675	2008/02	user18775	password	31	60000	F
18776	LZSZNM	DGFALLBQQG	9014515483 Dell Way	\N	RTNZPKO	\N	0	UK	2	DGFALLBQQG@dell.com	9014515483	4	1691940519493073	2012/11	user18776	password	59	40000	F
18777	OCIBPL	HUMTFNKVUC	4112400120 Dell Way	\N	OHCESQD	\N	0	Germany	2	HUMTFNKVUC@dell.com	4112400120	2	6131820304784924	2009/10	user18777	password	86	60000	F
18778	AXKPJS	JVMPJWKDYZ	5924889031 Dell Way	\N	LAEDRIS	\N	0	Australia	2	JVMPJWKDYZ@dell.com	5924889031	2	3288541273213923	2009/03	user18778	password	79	80000	F
18779	TCVDVF	ZHVIDGLCGW	9779965586 Dell Way	\N	DKZUTSU	\N	0	Chile	2	ZHVIDGLCGW@dell.com	9779965586	1	6614681730512530	2008/11	user18779	password	40	60000	M
18780	KHUFNT	NIBRONTUJW	5237570004 Dell Way	\N	FJQYBLF	\N	0	Australia	2	NIBRONTUJW@dell.com	5237570004	5	3052328902762383	2009/02	user18780	password	66	20000	M
18781	YUUMOH	UPYJCSEMOJ	4286574316 Dell Way	\N	VFIWQNX	\N	0	Canada	2	UPYJCSEMOJ@dell.com	4286574316	1	5325802292674780	2010/10	user18781	password	53	20000	M
18782	HWGVEA	KDKNWOZLYV	7835636722 Dell Way	\N	QGSHTQL	\N	0	Canada	2	KDKNWOZLYV@dell.com	7835636722	5	6779059925116599	2010/05	user18782	password	71	40000	M
18783	POMUPX	YALUOKGMGW	5638617064 Dell Way	\N	SYEMOPP	\N	0	China	2	YALUOKGMGW@dell.com	5638617064	2	9024563821963968	2012/12	user18783	password	34	60000	M
18784	UBJKZI	KKDZVJLBGE	5254626406 Dell Way	\N	ALQOBGW	\N	0	Germany	2	KKDZVJLBGE@dell.com	5254626406	4	5262615018058568	2010/01	user18784	password	22	20000	M
18785	DKFCTQ	NWPIGBJMFK	6477446384 Dell Way	\N	YWYZCVO	\N	0	Germany	2	NWPIGBJMFK@dell.com	6477446384	1	1071649790741503	2011/01	user18785	password	20	60000	F
18786	LQHEHV	BXDHYNUEXT	3683707829 Dell Way	\N	AWSDRHR	\N	0	Chile	2	BXDHYNUEXT@dell.com	3683707829	4	9149680482223632	2009/09	user18786	password	42	60000	F
18787	ZXIGSJ	EVRCIMHGFH	8246581742 Dell Way	\N	CXKUECB	\N	0	France	2	EVRCIMHGFH@dell.com	8246581742	5	8823283519130201	2010/04	user18787	password	51	80000	F
18788	IAOBKS	WCVFOCLTJO	4137237958 Dell Way	\N	RUIWXJJ	\N	0	Russia	2	WCVFOCLTJO@dell.com	4137237958	2	3211059257853776	2011/09	user18788	password	86	100000	F
18789	ZMBJEY	LADACPTMDL	8731066327 Dell Way	\N	GLHEVQX	\N	0	Canada	2	LADACPTMDL@dell.com	8731066327	1	8418150591198356	2010/01	user18789	password	73	60000	F
18790	GPKLNW	LRWNGQZKBG	5183591926 Dell Way	\N	VILRZIV	\N	0	South Africa	2	LRWNGQZKBG@dell.com	5183591926	4	4378108361735940	2010/05	user18790	password	85	60000	M
18791	NZCBWN	TTBZJAJLHF	4290151557 Dell Way	\N	UTWTBSP	\N	0	Germany	2	TTBZJAJLHF@dell.com	4290151557	5	1619841052219271	2011/11	user18791	password	65	60000	F
18792	QNNNBG	GCGQDQCLVW	3189560820 Dell Way	\N	ESQFKGT	\N	0	Russia	2	GCGQDQCLVW@dell.com	3189560820	5	6018131409771741	2008/06	user18792	password	90	80000	F
18793	NCQOJX	RPOUFQFBNK	2782992675 Dell Way	\N	TEPELJY	\N	0	Japan	2	RPOUFQFBNK@dell.com	2782992675	3	8480463059153409	2011/06	user18793	password	49	100000	F
18794	OLOXJG	NXASOGUCQN	2233718107 Dell Way	\N	HGSSQQK	\N	0	South Africa	2	NXASOGUCQN@dell.com	2233718107	2	5442615483421833	2011/08	user18794	password	39	80000	F
18795	TFCCLP	AMIPSCSJQZ	3569068359 Dell Way	\N	PIRGZBB	\N	0	Canada	2	AMIPSCSJQZ@dell.com	3569068359	3	7711990227457137	2012/11	user18795	password	46	20000	M
18796	PGRBVS	OEHHHZQYYG	1611120796 Dell Way	\N	HQMGSNJ	\N	0	UK	2	OEHHHZQYYG@dell.com	1611120796	1	9342457369435580	2012/07	user18796	password	22	60000	F
18797	HEEDWS	IDZPDQOCWV	6084502785 Dell Way	\N	SIBLWLL	\N	0	UK	2	IDZPDQOCWV@dell.com	6084502785	2	8546654026489706	2008/05	user18797	password	41	20000	M
18798	MJVIBD	MBTQRHSOCL	6743563390 Dell Way	\N	WEWTQHR	\N	0	Chile	2	MBTQRHSOCL@dell.com	6743563390	3	3457908384967595	2008/11	user18798	password	51	80000	F
18799	UORWSE	YMUPTMDWXA	9660436525 Dell Way	\N	BUTSBLX	\N	0	Russia	2	YMUPTMDWXA@dell.com	9660436525	1	7824931783601642	2012/08	user18799	password	54	20000	F
18800	BUIUYG	GSWAFZXDAZ	7774816158 Dell Way	\N	YURAGOS	\N	0	Chile	2	GSWAFZXDAZ@dell.com	7774816158	3	1013074985239654	2009/12	user18800	password	27	100000	F
18801	XDVWKC	PGDVGAYGZW	1585468262 Dell Way	\N	BRWHFPM	\N	0	UK	2	PGDVGAYGZW@dell.com	1585468262	3	4308171731419861	2008/08	user18801	password	32	20000	M
18802	IYKTBA	ZEVFFUMEQO	8587218330 Dell Way	\N	VNWBDIB	\N	0	Canada	2	ZEVFFUMEQO@dell.com	8587218330	3	3036773523781448	2010/08	user18802	password	40	20000	M
18803	GKRHKR	LGXQAJVRYR	2833379233 Dell Way	\N	EUTIDUM	\N	0	UK	2	LGXQAJVRYR@dell.com	2833379233	4	4901292785070837	2012/01	user18803	password	50	80000	F
18804	WLOHDA	NARNKNEIEJ	9067523657 Dell Way	\N	CXRFSEF	\N	0	UK	2	NARNKNEIEJ@dell.com	9067523657	4	7483873937278987	2012/01	user18804	password	53	40000	M
18805	YUFBVS	CMGMZLUEUX	9612149676 Dell Way	\N	BMDURIR	\N	0	Germany	2	CMGMZLUEUX@dell.com	9612149676	2	5383819856680930	2008/11	user18805	password	69	100000	M
18806	MEXHXZ	UELTPGXKDZ	8436910086 Dell Way	\N	WHTOQLC	\N	0	Germany	2	UELTPGXKDZ@dell.com	8436910086	3	6409677209798247	2011/04	user18806	password	58	60000	M
18807	SLCQKW	UWQJCNUGNR	8953804206 Dell Way	\N	NHFDSHS	\N	0	Germany	2	UWQJCNUGNR@dell.com	8953804206	2	3158495043870062	2008/11	user18807	password	74	100000	M
18808	FAGPWA	MMKOAFVOWI	5940303171 Dell Way	\N	VBMNJFB	\N	0	Chile	2	MMKOAFVOWI@dell.com	5940303171	2	4792702438309789	2010/01	user18808	password	44	20000	F
18809	KHXHIJ	UTXVYSJUBE	1431551827 Dell Way	\N	WOSFUTM	\N	0	China	2	UTXVYSJUBE@dell.com	1431551827	5	7980782791506500	2008/04	user18809	password	78	60000	M
18810	DHYLRS	EPNDIWXJBU	4318551918 Dell Way	\N	YTZTNMC	\N	0	Germany	2	EPNDIWXJBU@dell.com	4318551918	5	7176151980180294	2011/09	user18810	password	24	40000	M
18811	KGGBYL	QMPYJMIKGH	9699010777 Dell Way	\N	EGASTCH	\N	0	Canada	2	QMPYJMIKGH@dell.com	9699010777	5	7653773484285922	2011/01	user18811	password	20	60000	F
18812	HSMFEC	STBBGJMNQR	6463285603 Dell Way	\N	URJNTQQ	\N	0	Russia	2	STBBGJMNQR@dell.com	6463285603	2	4473733995575458	2011/05	user18812	password	80	20000	M
18813	POXTRP	NSRUBDHSVC	6383542171 Dell Way	\N	JFPDVGW	\N	0	France	2	NSRUBDHSVC@dell.com	6383542171	2	1954888839274645	2012/02	user18813	password	31	80000	M
18814	TOLKEZ	DVTFZBXUDH	5971501470 Dell Way	\N	ZTLVZHH	\N	0	Germany	2	DVTFZBXUDH@dell.com	5971501470	3	6169686067849398	2011/08	user18814	password	35	40000	F
18815	VUUZTX	VNCUOAPSIP	2358785067 Dell Way	\N	LTLLATZ	\N	0	Germany	2	VNCUOAPSIP@dell.com	2358785067	3	3235130897723138	2011/10	user18815	password	61	20000	M
18816	KWQETL	RWGGXVYFLK	4431598830 Dell Way	\N	YXVZQVO	\N	0	Russia	2	RWGGXVYFLK@dell.com	4431598830	5	5771248830482364	2009/05	user18816	password	63	100000	M
18817	MLYGXQ	DDWAZUGKEE	6057580623 Dell Way	\N	HZEYUTS	\N	0	Canada	2	DDWAZUGKEE@dell.com	6057580623	2	4457923127803952	2012/11	user18817	password	34	80000	F
18818	RTQOJT	SFURAACFFJ	3296117302 Dell Way	\N	FJHADAF	\N	0	Japan	2	SFURAACFFJ@dell.com	3296117302	3	6891881326679141	2008/10	user18818	password	49	60000	F
18819	ECBNWT	TQLURNAWWF	9945152966 Dell Way	\N	GEFJFKB	\N	0	France	2	TQLURNAWWF@dell.com	9945152966	4	6201722066383809	2011/02	user18819	password	22	40000	F
18820	EIWABP	RMKJZKGWQM	6436721583 Dell Way	\N	BWWGHXS	\N	0	Chile	2	RMKJZKGWQM@dell.com	6436721583	2	1522167304530739	2011/05	user18820	password	41	20000	M
18821	QXOSNG	EYPEIVBZHC	4437347240 Dell Way	\N	VEJCBCJ	\N	0	Japan	2	EYPEIVBZHC@dell.com	4437347240	3	4615261211059988	2011/09	user18821	password	51	40000	F
18822	JVCWBH	UQLDLNCTQY	8345215423 Dell Way	\N	XZAYCKP	\N	0	France	2	UQLDLNCTQY@dell.com	8345215423	1	2836248212493956	2010/06	user18822	password	51	100000	M
18823	HARIIM	YUPJHSCXQA	6121345805 Dell Way	\N	XRYZBOL	\N	0	South Africa	2	YUPJHSCXQA@dell.com	6121345805	4	4993996571283788	2008/02	user18823	password	46	100000	F
18824	LNSTAQ	NQAUIDSZDP	7245430605 Dell Way	\N	RCPSQAP	\N	0	Chile	2	NQAUIDSZDP@dell.com	7245430605	1	3286039534956217	2012/06	user18824	password	25	40000	M
18825	QXPQOD	HPXQSPPWFG	6582589552 Dell Way	\N	YUZPVPV	\N	0	Germany	2	HPXQSPPWFG@dell.com	6582589552	1	4033372096251696	2008/03	user18825	password	57	100000	M
18826	LNMART	POJIEZFKGD	7112528318 Dell Way	\N	EFTAUPN	\N	0	France	2	POJIEZFKGD@dell.com	7112528318	5	5309383129235357	2012/06	user18826	password	47	80000	M
18827	YEXPYN	EIVIHATOEX	4151791058 Dell Way	\N	UYYPNMZ	\N	0	Chile	2	EIVIHATOEX@dell.com	4151791058	3	1699128424748778	2011/11	user18827	password	74	80000	M
18828	YOKXBO	FXXNXQBCOV	9047066386 Dell Way	\N	ANKOZKT	\N	0	China	2	FXXNXQBCOV@dell.com	9047066386	5	1901025690138340	2011/08	user18828	password	72	60000	M
18829	HZLJOR	GMEDCGGRCG	4858983879 Dell Way	\N	EMVEXPM	\N	0	South Africa	2	GMEDCGGRCG@dell.com	4858983879	3	6245440065860749	2008/05	user18829	password	30	80000	M
18830	EBZSTF	EYJHEPZGWD	4592424711 Dell Way	\N	TRIRGUM	\N	0	Japan	2	EYJHEPZGWD@dell.com	4592424711	1	7643635262269527	2011/03	user18830	password	43	40000	F
18831	LJCEOH	CYPGNONKSG	5134907498 Dell Way	\N	BAYIVKA	\N	0	Chile	2	CYPGNONKSG@dell.com	5134907498	4	9592501053586604	2011/02	user18831	password	42	20000	M
18832	RESGMU	FBBSPPCHWE	3523328565 Dell Way	\N	IUNDENI	\N	0	Japan	2	FBBSPPCHWE@dell.com	3523328565	2	3958369045518339	2009/08	user18832	password	47	100000	F
18833	PQOBLU	DNMSCPAYUI	1951341035 Dell Way	\N	THMXUVO	\N	0	Australia	2	DNMSCPAYUI@dell.com	1951341035	5	5290088461712003	2011/04	user18833	password	47	20000	M
18834	BQYNKB	AXUDMVCGEV	2869038980 Dell Way	\N	OQTJLIL	\N	0	Germany	2	AXUDMVCGEV@dell.com	2869038980	5	3595930020324886	2010/04	user18834	password	42	40000	F
18835	YIXJKX	GFBTBEAFZO	3340801161 Dell Way	\N	WTXIBIW	\N	0	Chile	2	GFBTBEAFZO@dell.com	3340801161	1	7980998260900379	2010/06	user18835	password	30	100000	F
18836	NWVYUB	DVUFZULZIH	6763332356 Dell Way	\N	SGPUPMB	\N	0	South Africa	2	DVUFZULZIH@dell.com	6763332356	5	4880708980839700	2008/01	user18836	password	46	60000	M
18837	GKLALP	WGUVAFVJNO	3261662487 Dell Way	\N	PDJEPKA	\N	0	Chile	2	WGUVAFVJNO@dell.com	3261662487	3	4424894376657903	2009/11	user18837	password	89	80000	F
18838	JFDVVZ	BPVCVRLIFB	7706686364 Dell Way	\N	MOGBZHI	\N	0	Chile	2	BPVCVRLIFB@dell.com	7706686364	4	5395788275636733	2011/09	user18838	password	37	80000	F
18839	MWWHWY	XRBSJNBOOO	6662210641 Dell Way	\N	DVQDCYJ	\N	0	South Africa	2	XRBSJNBOOO@dell.com	6662210641	5	5082535494584590	2009/02	user18839	password	30	40000	M
18840	AFWWEU	OGNXTPMIDQ	9568441877 Dell Way	\N	DTTGRCC	\N	0	China	2	OGNXTPMIDQ@dell.com	9568441877	3	6414136851672084	2008/09	user18840	password	87	80000	M
18841	ENQJHE	PUCJJPRMGV	7488380115 Dell Way	\N	GZBXCEF	\N	0	Australia	2	PUCJJPRMGV@dell.com	7488380115	5	1955975586548447	2010/10	user18841	password	72	20000	M
18842	GVHOAX	ICGSSYFYUL	4375684273 Dell Way	\N	YWJAAOB	\N	0	Russia	2	ICGSSYFYUL@dell.com	4375684273	1	2632841617800295	2008/12	user18842	password	45	20000	F
18843	EJTFHB	HOUAMZYGLW	2494478503 Dell Way	\N	CUXDJZW	\N	0	Russia	2	HOUAMZYGLW@dell.com	2494478503	1	8746085914317519	2008/06	user18843	password	86	40000	M
18844	IAUPCC	EWDQWCXHYA	1684124302 Dell Way	\N	CWELWAE	\N	0	Australia	2	EWDQWCXHYA@dell.com	1684124302	1	1977044417988509	2010/12	user18844	password	46	20000	F
18845	KXXMAB	JESGGQOFQQ	3200708131 Dell Way	\N	BUBXVFX	\N	0	UK	2	JESGGQOFQQ@dell.com	3200708131	1	4645155222620815	2009/06	user18845	password	55	60000	M
18846	LJIMKR	QCYWSMBJCC	9620528930 Dell Way	\N	EEAAJYX	\N	0	Japan	2	QCYWSMBJCC@dell.com	9620528930	2	8444466502405704	2009/11	user18846	password	40	40000	F
18847	RNSCFJ	FDFYPGHSJM	7398632090 Dell Way	\N	WJMGHKW	\N	0	Chile	2	FDFYPGHSJM@dell.com	7398632090	4	6582106113433839	2010/12	user18847	password	77	100000	M
18848	IOTOXY	SCWHIEARRW	6701719777 Dell Way	\N	BDCINYO	\N	0	Chile	2	SCWHIEARRW@dell.com	6701719777	1	8047591773327441	2011/01	user18848	password	61	40000	F
18849	DBXAAP	DXXLCXDTTE	3432234368 Dell Way	\N	WWNKUCQ	\N	0	France	2	DXXLCXDTTE@dell.com	3432234368	3	1596197157632559	2009/01	user18849	password	44	80000	F
18850	KOELEH	IBTKZWDTBA	5066387841 Dell Way	\N	POKKQAV	\N	0	UK	2	IBTKZWDTBA@dell.com	5066387841	5	2829961533658206	2010/04	user18850	password	79	80000	M
18851	KUDOBL	QVWPSAITAY	1877530415 Dell Way	\N	IKIZLEX	\N	0	UK	2	QVWPSAITAY@dell.com	1877530415	1	4335417166352272	2009/12	user18851	password	89	20000	F
18852	TFXVQN	QNCINLCOJL	4797930763 Dell Way	\N	ZSKLXII	\N	0	Australia	2	QNCINLCOJL@dell.com	4797930763	4	4390323590021581	2009/09	user18852	password	50	80000	F
18853	QPHHCY	VFGIQJXAVW	3828664596 Dell Way	\N	TFHROPR	\N	0	UK	2	VFGIQJXAVW@dell.com	3828664596	1	3999697578139603	2012/06	user18853	password	21	60000	F
18854	QSKTQF	ZXOQHLQCHK	7817204150 Dell Way	\N	IOBWESV	\N	0	Germany	2	ZXOQHLQCHK@dell.com	7817204150	1	5475996647495777	2009/03	user18854	password	86	40000	M
18855	RTPHZO	FNEMZVPHFX	7623953346 Dell Way	\N	WHTAZPN	\N	0	Russia	2	FNEMZVPHFX@dell.com	7623953346	1	9879690600093456	2012/12	user18855	password	43	80000	M
18856	CJYCYD	QCQPXFXDCT	4127250073 Dell Way	\N	KWUKLID	\N	0	Canada	2	QCQPXFXDCT@dell.com	4127250073	1	2005329250823706	2009/06	user18856	password	82	100000	M
18857	GWREAI	HQXFVVIYOT	4899468962 Dell Way	\N	UIEGQHL	\N	0	UK	2	HQXFVVIYOT@dell.com	4899468962	3	3728907162323594	2012/06	user18857	password	36	60000	M
18858	DEWDMD	UKJPFSOULJ	6117371609 Dell Way	\N	CQPSXAS	\N	0	China	2	UKJPFSOULJ@dell.com	6117371609	1	3341036277823150	2012/04	user18858	password	73	80000	F
18859	YONLSH	VBXBTMVFVY	4387883483 Dell Way	\N	VLQTMJC	\N	0	Australia	2	VBXBTMVFVY@dell.com	4387883483	2	1371002090629190	2011/02	user18859	password	70	20000	F
18860	GOMYWI	AUKTGGZCEV	1263342751 Dell Way	\N	OVOAERC	\N	0	Germany	2	AUKTGGZCEV@dell.com	1263342751	1	2738301193807274	2008/11	user18860	password	34	40000	F
18861	USBRAB	MLUTRUVVPK	6714156367 Dell Way	\N	QELUVNJ	\N	0	South Africa	2	MLUTRUVVPK@dell.com	6714156367	3	1096712205093354	2010/10	user18861	password	33	60000	M
18862	XPGYQS	JLLAGHVVRL	2266820737 Dell Way	\N	ZCGVQPR	\N	0	Chile	2	JLLAGHVVRL@dell.com	2266820737	4	7560120342765004	2012/11	user18862	password	39	60000	M
18863	XSUOLD	AXEGEZBWLB	3309882487 Dell Way	\N	ZSWPHOV	\N	0	France	2	AXEGEZBWLB@dell.com	3309882487	3	4107232337351889	2008/11	user18863	password	78	20000	M
18864	OUIZXI	WBOBBQXMRW	8845916543 Dell Way	\N	EOLMCHX	\N	0	China	2	WBOBBQXMRW@dell.com	8845916543	2	5798265464603901	2011/02	user18864	password	56	60000	M
18865	HVQFDN	HSOIIMVZJA	7046362199 Dell Way	\N	OVMQDKA	\N	0	UK	2	HSOIIMVZJA@dell.com	7046362199	3	7539280387572945	2011/01	user18865	password	35	60000	F
18866	BAPFOW	XDFGPAGYBU	9707563834 Dell Way	\N	UOKXYLW	\N	0	Japan	2	XDFGPAGYBU@dell.com	9707563834	4	4520256827119738	2008/11	user18866	password	75	60000	M
18867	VACJWA	NCHCDNBEHV	2858460289 Dell Way	\N	SSSRDPI	\N	0	Canada	2	NCHCDNBEHV@dell.com	2858460289	4	2418491824064404	2008/06	user18867	password	60	100000	F
18868	PBSMCF	OJIRXJWEFO	3445798617 Dell Way	\N	XYGBOOE	\N	0	Russia	2	OJIRXJWEFO@dell.com	3445798617	2	8119182010646910	2011/11	user18868	password	71	20000	F
18869	UUZWAN	GIFDSBIYQG	8260305415 Dell Way	\N	WXHKLMD	\N	0	Russia	2	GIFDSBIYQG@dell.com	8260305415	5	5470328599214554	2011/09	user18869	password	61	40000	F
18870	KEJKSP	TXTLZBJPHG	7578129628 Dell Way	\N	MPQYBUR	\N	0	South Africa	2	TXTLZBJPHG@dell.com	7578129628	1	6336679521016777	2010/10	user18870	password	76	100000	F
18871	ZFOSVH	POTPQDFYJS	5615876244 Dell Way	\N	NZQPUIM	\N	0	Germany	2	POTPQDFYJS@dell.com	5615876244	1	9251936331391336	2009/11	user18871	password	75	60000	M
18872	AAOVIE	KBTAEYYNQM	6311950626 Dell Way	\N	NHBHQNU	\N	0	Canada	2	KBTAEYYNQM@dell.com	6311950626	4	4722735058981925	2010/07	user18872	password	80	40000	M
18873	WWJEAT	GUUKSSYJFL	3186099178 Dell Way	\N	QGSGUNK	\N	0	China	2	GUUKSSYJFL@dell.com	3186099178	5	8505015728063882	2011/08	user18873	password	28	40000	M
18874	AQSBKY	VEJOXHXCSO	1155707275 Dell Way	\N	ILVDZFN	\N	0	Chile	2	VEJOXHXCSO@dell.com	1155707275	2	9801317349541932	2011/06	user18874	password	36	40000	M
18875	WYOHXJ	LGYINVKGKT	7605781615 Dell Way	\N	SFXSLKY	\N	0	France	2	LGYINVKGKT@dell.com	7605781615	5	2168028064072132	2009/02	user18875	password	43	80000	F
18876	HHIEQT	KPCYLNFVHY	5500752937 Dell Way	\N	BEQMOPX	\N	0	China	2	KPCYLNFVHY@dell.com	5500752937	1	5694147173315287	2011/05	user18876	password	35	80000	M
18877	NAWEUG	TXFEKLARJB	5492267899 Dell Way	\N	WANLQLS	\N	0	Canada	2	TXFEKLARJB@dell.com	5492267899	2	8064965488854796	2012/06	user18877	password	54	60000	F
18878	NLEISY	FXDQJDITEE	6221965900 Dell Way	\N	USPKEIN	\N	0	Japan	2	FXDQJDITEE@dell.com	6221965900	2	6062703852076084	2008/10	user18878	password	28	20000	F
18879	OHRGFW	EJNNMVGRAA	3057333318 Dell Way	\N	KPKOYYF	\N	0	Germany	2	EJNNMVGRAA@dell.com	3057333318	4	6400193937122822	2008/12	user18879	password	68	40000	M
18880	ZATEWY	OKMAFSSFTC	7326071978 Dell Way	\N	VERUDXI	\N	0	China	2	OKMAFSSFTC@dell.com	7326071978	5	4329172874800861	2011/08	user18880	password	70	20000	M
18881	SXTPVH	ZHIFABLUEH	3644201777 Dell Way	\N	ZVBCTJL	\N	0	France	2	ZHIFABLUEH@dell.com	3644201777	5	1797835472505539	2012/07	user18881	password	34	60000	F
18882	DFWZNW	HWBIXMCBUC	5289350912 Dell Way	\N	XVFQFQC	\N	0	Germany	2	HWBIXMCBUC@dell.com	5289350912	1	4726410196628422	2008/05	user18882	password	82	40000	M
18883	CDNPZU	LBCJOFKIHH	2787466357 Dell Way	\N	EMYKDAX	\N	0	Japan	2	LBCJOFKIHH@dell.com	2787466357	2	6709619591478259	2011/03	user18883	password	84	20000	F
18884	BQXAKJ	CMSQRDYZKD	7738375536 Dell Way	\N	MINPJLF	\N	0	Germany	2	CMSQRDYZKD@dell.com	7738375536	5	2443769154604524	2012/10	user18884	password	39	40000	M
18885	YEWJNY	WGPOJNNURZ	7138309753 Dell Way	\N	DEPMPVA	\N	0	China	2	WGPOJNNURZ@dell.com	7138309753	1	3660652654245496	2010/06	user18885	password	57	40000	F
18886	SDUGCQ	MREWESQWST	5066405858 Dell Way	\N	AHFQDGZ	\N	0	Russia	2	MREWESQWST@dell.com	5066405858	2	3273920715320855	2012/10	user18886	password	56	40000	M
18887	RETTUF	KZBPRSLJLL	3659062615 Dell Way	\N	RRBUYAP	\N	0	China	2	KZBPRSLJLL@dell.com	3659062615	5	4057075561024249	2008/05	user18887	password	70	80000	F
18888	WITROE	QQTIIESUQJ	6384423947 Dell Way	\N	MSEKTTV	\N	0	Australia	2	QQTIIESUQJ@dell.com	6384423947	1	2256975060328841	2012/11	user18888	password	72	100000	M
18889	CTKQYB	HRJPWBKMLW	3361909454 Dell Way	\N	FPHYJCZ	\N	0	UK	2	HRJPWBKMLW@dell.com	3361909454	1	9396462415810676	2008/11	user18889	password	85	100000	M
18890	RHPPIW	HSMDTWQFSV	8910402606 Dell Way	\N	VATEDTE	\N	0	China	2	HSMDTWQFSV@dell.com	8910402606	1	5628896257374436	2011/01	user18890	password	46	80000	M
18891	RHIZDP	RPTLMJRFFM	9370504537 Dell Way	\N	FZRISVS	\N	0	Germany	2	RPTLMJRFFM@dell.com	9370504537	2	4083950876258314	2012/08	user18891	password	20	80000	F
18892	IZGMPY	CJKOSBTXOY	2961062013 Dell Way	\N	WGHPBZE	\N	0	Australia	2	CJKOSBTXOY@dell.com	2961062013	3	9588237493764610	2012/07	user18892	password	62	20000	M
18893	PJJFIM	OSAGUUEITB	4408986685 Dell Way	\N	OARQAVQ	\N	0	Chile	2	OSAGUUEITB@dell.com	4408986685	3	1520229680929333	2012/03	user18893	password	29	100000	M
18894	NGAVSO	OSVINARGBF	1973426654 Dell Way	\N	GSWGONM	\N	0	UK	2	OSVINARGBF@dell.com	1973426654	3	9107851763721556	2009/09	user18894	password	73	20000	F
18895	ZDCRSQ	KOZXOQDQWK	7418883354 Dell Way	\N	JSRXGEW	\N	0	China	2	KOZXOQDQWK@dell.com	7418883354	4	6970343014691026	2010/07	user18895	password	76	80000	M
18896	YTFRJQ	FJNTZRKVCT	3532302691 Dell Way	\N	OTQUYND	\N	0	Japan	2	FJNTZRKVCT@dell.com	3532302691	5	1576446137391030	2012/08	user18896	password	71	40000	M
18897	MNFWDL	FRFEJPALIP	3959909312 Dell Way	\N	FZKDMNU	\N	0	Russia	2	FRFEJPALIP@dell.com	3959909312	5	6111982448026538	2012/07	user18897	password	82	60000	F
18898	KSXNDC	FIHOYIAGXF	9850927730 Dell Way	\N	FHJSVDM	\N	0	Canada	2	FIHOYIAGXF@dell.com	9850927730	1	1816742493771016	2010/11	user18898	password	60	80000	F
18899	HNVLPA	UXOSGOYDUE	4100929661 Dell Way	\N	LDWHHIL	\N	0	Chile	2	UXOSGOYDUE@dell.com	4100929661	3	8479559930041433	2009/02	user18899	password	49	60000	F
18900	YKVOKP	MZHSOGWJKI	6256075988 Dell Way	\N	NGPUOBC	\N	0	UK	2	MZHSOGWJKI@dell.com	6256075988	5	2434178425930440	2011/05	user18900	password	70	20000	F
18901	CYVNNH	NVACBWLLEZ	7908609789 Dell Way	\N	STUGVWE	\N	0	China	2	NVACBWLLEZ@dell.com	7908609789	2	1863639971241355	2008/01	user18901	password	32	40000	F
18902	DGSRNF	MNIOKTAOTS	5358022831 Dell Way	\N	INZDJEO	\N	0	Canada	2	MNIOKTAOTS@dell.com	5358022831	4	3186128741130233	2010/10	user18902	password	64	80000	M
18903	WKQKPC	YXRIRRXKKG	5990449923 Dell Way	\N	XKJHOXK	\N	0	Australia	2	YXRIRRXKKG@dell.com	5990449923	4	6059241778217257	2009/04	user18903	password	36	40000	F
18904	QZPGBN	ESWWKUGUAE	5766371229 Dell Way	\N	FKMTIWT	\N	0	South Africa	2	ESWWKUGUAE@dell.com	5766371229	2	3318104539066553	2012/08	user18904	password	61	100000	F
18905	OOMQCR	JZNTTUOUZT	6340760166 Dell Way	\N	ELMMIGJ	\N	0	South Africa	2	JZNTTUOUZT@dell.com	6340760166	4	6995097343809903	2008/03	user18905	password	66	60000	M
18906	GXKIOU	ICNBWCWWWA	5495904820 Dell Way	\N	HJNPQWL	\N	0	Chile	2	ICNBWCWWWA@dell.com	5495904820	1	4569844015408307	2011/10	user18906	password	77	60000	M
18907	SYIHSQ	JGSGIOCFPK	5796747598 Dell Way	\N	OCZEZLK	\N	0	France	2	JGSGIOCFPK@dell.com	5796747598	4	2789199730847031	2009/08	user18907	password	69	40000	F
18908	QQQIGA	PZGXNJDDTR	1524790856 Dell Way	\N	FTWFEGR	\N	0	Russia	2	PZGXNJDDTR@dell.com	1524790856	5	1068507281132042	2011/07	user18908	password	39	100000	F
18909	YQOEQD	EXBSGEVAWB	8044710137 Dell Way	\N	TSGYZXR	\N	0	Australia	2	EXBSGEVAWB@dell.com	8044710137	4	7326284158043564	2009/12	user18909	password	68	60000	M
18910	IDCYGG	VIYCMUCIVW	2197172716 Dell Way	\N	BBVAZMB	\N	0	Russia	2	VIYCMUCIVW@dell.com	2197172716	4	2136879738420248	2008/06	user18910	password	69	100000	M
18911	VBSCIN	KHPXBSGWOH	2402778391 Dell Way	\N	YKIYWKS	\N	0	UK	2	KHPXBSGWOH@dell.com	2402778391	5	1784994472283870	2011/07	user18911	password	23	60000	F
18912	DDLLRW	SHUUZAROHP	1545312538 Dell Way	\N	YQOUAGU	\N	0	Canada	2	SHUUZAROHP@dell.com	1545312538	5	8074726382736117	2010/12	user18912	password	31	100000	F
18913	IKOZHH	GBBFBTUJIT	2822460799 Dell Way	\N	ZXNZDIE	\N	0	Canada	2	GBBFBTUJIT@dell.com	2822460799	5	7954957087524236	2008/02	user18913	password	70	40000	F
18914	DVLKCR	MEXNXRXGKX	9983860854 Dell Way	\N	DYXGHBL	\N	0	France	2	MEXNXRXGKX@dell.com	9983860854	2	6709742813836784	2008/12	user18914	password	82	60000	F
18915	SAMURY	YOMWGJCRHF	2240869845 Dell Way	\N	QEMXFXJ	\N	0	Chile	2	YOMWGJCRHF@dell.com	2240869845	1	4246099966578186	2008/11	user18915	password	87	20000	M
18916	YPKQOJ	FAFMKHDSNU	1704520800 Dell Way	\N	WARCYBI	\N	0	Australia	2	FAFMKHDSNU@dell.com	1704520800	4	2214737967122346	2012/08	user18916	password	37	60000	M
18917	WZFLIL	LNXWVAOIUL	5795724863 Dell Way	\N	IMNGOWI	\N	0	Japan	2	LNXWVAOIUL@dell.com	5795724863	3	6444792069960386	2008/09	user18917	password	31	80000	M
18918	EYAMKM	ZHJVIYDDJM	5709630568 Dell Way	\N	PXTDTBT	\N	0	Chile	2	ZHJVIYDDJM@dell.com	5709630568	2	4928667527623475	2009/07	user18918	password	31	100000	M
18919	DXFNKF	UTACREFBQV	2002834343 Dell Way	\N	YJZRLTY	\N	0	UK	2	UTACREFBQV@dell.com	2002834343	2	2989003410562873	2011/07	user18919	password	23	40000	M
18920	ZPGJUB	DUEUYKWPFU	8408623380 Dell Way	\N	ZEMKYLJ	\N	0	Australia	2	DUEUYKWPFU@dell.com	8408623380	4	7416976685635746	2009/09	user18920	password	25	20000	M
18921	RJAMKD	GOYFYUUEPT	2339009408 Dell Way	\N	JBEHMOI	\N	0	China	2	GOYFYUUEPT@dell.com	2339009408	1	7468044784385712	2012/02	user18921	password	78	60000	M
18922	ENIPQO	EPUCKPHZIQ	3855075022 Dell Way	\N	BNYOBHW	\N	0	Chile	2	EPUCKPHZIQ@dell.com	3855075022	4	1285848236642777	2010/06	user18922	password	55	40000	M
18923	AQFRFJ	HZMROURXKT	7994580577 Dell Way	\N	KJHLQER	\N	0	UK	2	HZMROURXKT@dell.com	7994580577	4	4655752923805267	2009/03	user18923	password	70	100000	F
18924	IBXNLE	NYWBSNZDHJ	2810950501 Dell Way	\N	MOVCTNB	\N	0	Germany	2	NYWBSNZDHJ@dell.com	2810950501	3	7559563235379756	2010/02	user18924	password	59	80000	F
18925	QOABTN	ZPPSDPVKZI	9087788282 Dell Way	\N	ZVKSILG	\N	0	Germany	2	ZPPSDPVKZI@dell.com	9087788282	5	9410030567087234	2008/07	user18925	password	60	60000	F
18926	DOFXCF	NSXRHTCGBB	1017769588 Dell Way	\N	CMUKYAX	\N	0	South Africa	2	NSXRHTCGBB@dell.com	1017769588	5	8987621648237110	2010/06	user18926	password	49	80000	M
18927	AXMCDZ	VBRDVTKWVM	6795274314 Dell Way	\N	JPWHQUC	\N	0	Japan	2	VBRDVTKWVM@dell.com	6795274314	1	2524584447499364	2008/06	user18927	password	81	80000	F
18928	UEOXEJ	ZVNUOXRJJA	4687905103 Dell Way	\N	ZFHPAKG	\N	0	Japan	2	ZVNUOXRJJA@dell.com	4687905103	3	7679690886288882	2012/04	user18928	password	48	40000	F
18929	OWZTGY	OTSDQJMZJM	7348970009 Dell Way	\N	FRBGCHX	\N	0	France	2	OTSDQJMZJM@dell.com	7348970009	4	4106585308909416	2012/01	user18929	password	64	20000	M
18930	MZJTYX	MQACANCKZI	1587436120 Dell Way	\N	CBOEILR	\N	0	Australia	2	MQACANCKZI@dell.com	1587436120	1	1194785627070814	2008/08	user18930	password	21	80000	F
18931	BCXZZJ	QZMRNOBMWE	1269478840 Dell Way	\N	NLIWWAX	\N	0	UK	2	QZMRNOBMWE@dell.com	1269478840	5	1334210028406232	2011/12	user18931	password	73	100000	F
18932	VTZVCQ	VOHIDIUANI	1069891841 Dell Way	\N	LVEHWCG	\N	0	South Africa	2	VOHIDIUANI@dell.com	1069891841	2	6159156327135861	2012/01	user18932	password	48	20000	M
18933	EZSGPN	VXVYGQZTZK	3024863329 Dell Way	\N	PDSLFYI	\N	0	Chile	2	VXVYGQZTZK@dell.com	3024863329	5	2888120693154633	2009/04	user18933	password	33	20000	F
18934	FVSVJO	SFNYWMSVXH	9454560169 Dell Way	\N	YQSEOBK	\N	0	Russia	2	SFNYWMSVXH@dell.com	9454560169	4	1517428314778953	2009/10	user18934	password	32	80000	F
18935	ALVKZO	PMNLZFHWMF	4608079458 Dell Way	\N	MFKBGUV	\N	0	Canada	2	PMNLZFHWMF@dell.com	4608079458	5	4932319623418153	2009/02	user18935	password	29	40000	F
18936	PCNPQD	CDPBIWXVCK	2664360381 Dell Way	\N	AMLGHHL	\N	0	Japan	2	CDPBIWXVCK@dell.com	2664360381	5	9162146207876504	2009/01	user18936	password	28	60000	M
18937	FYGWCI	ASKIPIDRSE	7622053085 Dell Way	\N	EDKMKWD	\N	0	Japan	2	ASKIPIDRSE@dell.com	7622053085	1	8999760156963021	2011/03	user18937	password	40	60000	F
18938	HRHJAH	CKQRSUIKYN	2718783827 Dell Way	\N	OJZYGDO	\N	0	UK	2	CKQRSUIKYN@dell.com	2718783827	3	7707112806383521	2009/10	user18938	password	29	100000	F
18939	VDKVLM	FBDYWMIVAW	8550744583 Dell Way	\N	EZVLDKK	\N	0	China	2	FBDYWMIVAW@dell.com	8550744583	1	7468444483820350	2011/04	user18939	password	58	80000	F
18940	RBZCNE	ERCBELWEHB	1128881069 Dell Way	\N	EDMINWQ	\N	0	China	2	ERCBELWEHB@dell.com	1128881069	2	9529353865422308	2009/11	user18940	password	60	60000	M
18941	QKSDPW	VSXZDUELVJ	7041529361 Dell Way	\N	OHRBDIK	\N	0	Canada	2	VSXZDUELVJ@dell.com	7041529361	2	5406292078550905	2010/12	user18941	password	87	20000	M
18942	JWSZTO	RQNVKSHGBW	7430083890 Dell Way	\N	NTYRBJV	\N	0	Russia	2	RQNVKSHGBW@dell.com	7430083890	2	3846176408231258	2011/04	user18942	password	53	40000	M
18943	IYQCMI	SAEDTLKVHX	7697005501 Dell Way	\N	OFPQOKJ	\N	0	Chile	2	SAEDTLKVHX@dell.com	7697005501	4	9512865873984992	2008/03	user18943	password	31	80000	M
18944	DHPQPI	QTMJFWFMTT	5094359510 Dell Way	\N	SIKHTTO	\N	0	Germany	2	QTMJFWFMTT@dell.com	5094359510	3	5714316291268915	2011/09	user18944	password	31	20000	M
18945	MSLCAC	VMMAJRNDLG	6246436762 Dell Way	\N	MVNFPBS	\N	0	Australia	2	VMMAJRNDLG@dell.com	6246436762	2	7023929632268847	2009/06	user18945	password	76	20000	M
18946	NNZOPV	BCWKTJNEQZ	2625683564 Dell Way	\N	ADFPFYQ	\N	0	Russia	2	BCWKTJNEQZ@dell.com	2625683564	2	1541736973915249	2011/02	user18946	password	28	60000	M
18947	RNEHJF	JFPDPDIGCI	8928535265 Dell Way	\N	JHXOGOJ	\N	0	France	2	JFPDPDIGCI@dell.com	8928535265	3	1295657305512577	2012/07	user18947	password	59	80000	F
18948	CUNMAX	SPBITJOVRX	3286477258 Dell Way	\N	DPMJDVU	\N	0	Australia	2	SPBITJOVRX@dell.com	3286477258	5	1272900668904185	2012/05	user18948	password	65	20000	F
18949	LPYLNR	BOZUXNQOKT	7484761270 Dell Way	\N	EXDISXJ	\N	0	UK	2	BOZUXNQOKT@dell.com	7484761270	2	8225578063167632	2008/01	user18949	password	81	60000	F
18950	MOYZFA	NEULRLACFE	2863225145 Dell Way	\N	ZIMSGVS	\N	0	UK	2	NEULRLACFE@dell.com	2863225145	3	1626441302243620	2009/05	user18950	password	66	80000	M
18951	FRVKRJ	PMUHXVKCZK	3960712814 Dell Way	\N	LLCRHVR	\N	0	France	2	PMUHXVKCZK@dell.com	3960712814	4	7615906606428326	2011/05	user18951	password	51	60000	M
18952	DKAUTP	GOWDJHGJRS	7989223640 Dell Way	\N	VUKCPBP	\N	0	UK	2	GOWDJHGJRS@dell.com	7989223640	2	6644533694256098	2008/10	user18952	password	31	80000	M
18953	OTRIJX	XGBGNIPEAK	4899999599 Dell Way	\N	YKNOMCM	\N	0	Chile	2	XGBGNIPEAK@dell.com	4899999599	1	4651996234431863	2009/04	user18953	password	30	20000	M
18954	YUEHSB	OUICDYGDJF	3827742960 Dell Way	\N	OWTAZFG	\N	0	France	2	OUICDYGDJF@dell.com	3827742960	4	6634563952684403	2010/11	user18954	password	72	60000	M
18955	NQBGRQ	BASEYZHIFW	8388097277 Dell Way	\N	EYWDEDO	\N	0	France	2	BASEYZHIFW@dell.com	8388097277	1	1758687433321029	2011/12	user18955	password	56	60000	F
18956	DNSVDT	VWYUVFCACH	2663003766 Dell Way	\N	ZZLEDZR	\N	0	UK	2	VWYUVFCACH@dell.com	2663003766	4	6367383278906346	2008/04	user18956	password	19	60000	F
18957	NIFRBB	NAWIFZJIGI	9182600264 Dell Way	\N	HRNKREI	\N	0	South Africa	2	NAWIFZJIGI@dell.com	9182600264	5	9762878985144200	2008/12	user18957	password	58	60000	F
18958	WUDYWR	YTZESJMYST	5010080584 Dell Way	\N	PFEHJND	\N	0	Chile	2	YTZESJMYST@dell.com	5010080584	1	5120529672596604	2010/09	user18958	password	20	100000	M
18959	VAMSSL	LRPDBCBTWR	3124379000 Dell Way	\N	YAZINDP	\N	0	UK	2	LRPDBCBTWR@dell.com	3124379000	1	4477449303492904	2012/02	user18959	password	38	60000	M
18960	IYRAJC	SZGTBIMXAL	5154420422 Dell Way	\N	YZUMCKL	\N	0	China	2	SZGTBIMXAL@dell.com	5154420422	5	3218202106188983	2010/02	user18960	password	69	60000	F
18961	QELAHD	ZNXBVKYVVX	7140228396 Dell Way	\N	VPJXAVG	\N	0	France	2	ZNXBVKYVVX@dell.com	7140228396	3	1274355369154363	2012/03	user18961	password	57	40000	M
18962	SSWZVV	NTWIDVEYTZ	6827127243 Dell Way	\N	ODXOZDA	\N	0	Japan	2	NTWIDVEYTZ@dell.com	6827127243	1	5036574074532837	2012/08	user18962	password	68	80000	F
18963	KNIFJV	ZGECCIBVIQ	3660883533 Dell Way	\N	YFFXJGO	\N	0	Australia	2	ZGECCIBVIQ@dell.com	3660883533	1	8869856826495380	2012/09	user18963	password	58	40000	F
18964	COILJH	SOJUWLQFBP	1712064626 Dell Way	\N	LGNVMBW	\N	0	Russia	2	SOJUWLQFBP@dell.com	1712064626	4	7200864911079407	2011/04	user18964	password	85	100000	F
18965	MEVWMN	KWIGHZMJOX	3581617597 Dell Way	\N	PBSCDOW	\N	0	Chile	2	KWIGHZMJOX@dell.com	3581617597	3	9903896673116834	2010/06	user18965	password	80	100000	M
18966	BTUNHF	JQLRPXAEVQ	2482025510 Dell Way	\N	FNSICPO	\N	0	China	2	JQLRPXAEVQ@dell.com	2482025510	3	9603292837738992	2011/05	user18966	password	83	80000	F
18967	RKZYPJ	PBAFZAJVQO	9977593454 Dell Way	\N	JJXLZLV	\N	0	Canada	2	PBAFZAJVQO@dell.com	9977593454	4	8063786440063269	2009/09	user18967	password	47	100000	F
18968	VVHLEX	MECMFLHWZQ	7546030573 Dell Way	\N	FXCFJYI	\N	0	China	2	MECMFLHWZQ@dell.com	7546030573	1	7787634632084519	2010/07	user18968	password	61	80000	F
18969	KBTPYG	TATYLAVLRB	7136752064 Dell Way	\N	JTGSROB	\N	0	France	2	TATYLAVLRB@dell.com	7136752064	5	8484162026550622	2008/06	user18969	password	61	60000	M
18970	QHKPNE	QGDCHYOYAX	5669126215 Dell Way	\N	SGQKVRV	\N	0	France	2	QGDCHYOYAX@dell.com	5669126215	4	7200806866399945	2012/03	user18970	password	33	80000	M
18971	MFMAKC	HNEOMSNMQG	2203003298 Dell Way	\N	SGQOYMA	\N	0	France	2	HNEOMSNMQG@dell.com	2203003298	4	4561703632585704	2009/12	user18971	password	31	40000	F
18972	KTLUWS	HBGUUUGKAZ	3645598848 Dell Way	\N	QRNOEOA	\N	0	China	2	HBGUUUGKAZ@dell.com	3645598848	3	7132799360435457	2009/08	user18972	password	87	80000	M
18973	SBUOUC	PBWJVDTWDK	4515009085 Dell Way	\N	OQZTFZA	\N	0	Germany	2	PBWJVDTWDK@dell.com	4515009085	4	7609754716977478	2012/09	user18973	password	45	100000	F
18974	LTYFVN	HSXCVRZYCO	1379075875 Dell Way	\N	PBHUAIH	\N	0	France	2	HSXCVRZYCO@dell.com	1379075875	1	4697798779699952	2011/06	user18974	password	46	20000	M
18975	DACZOJ	RMMNDMLGAA	2632128506 Dell Way	\N	HIVIQDT	\N	0	Japan	2	RMMNDMLGAA@dell.com	2632128506	1	4514937574975193	2011/07	user18975	password	52	60000	M
18976	MPRBZI	NLWRYHXYIF	5001264632 Dell Way	\N	GENXHHP	\N	0	France	2	NLWRYHXYIF@dell.com	5001264632	5	1809464260935783	2012/06	user18976	password	59	80000	M
18977	DJADSN	OOFMVDLEIS	2691149212 Dell Way	\N	IWQQDFD	\N	0	Germany	2	OOFMVDLEIS@dell.com	2691149212	2	6210992275271565	2011/10	user18977	password	37	60000	M
18978	QPBICQ	WIDSLPWTHF	2868233190 Dell Way	\N	QYWTDZI	\N	0	China	2	WIDSLPWTHF@dell.com	2868233190	5	9783010258805008	2012/03	user18978	password	58	100000	M
18979	DZDGQZ	PTSAIPUQUK	4744560428 Dell Way	\N	OQDSQMB	\N	0	South Africa	2	PTSAIPUQUK@dell.com	4744560428	1	8572677560150624	2011/08	user18979	password	74	60000	M
18980	TNAKNP	DGPLVJCPTR	5136199648 Dell Way	\N	GXJXKLT	\N	0	South Africa	2	DGPLVJCPTR@dell.com	5136199648	3	4901360569521785	2008/05	user18980	password	79	80000	F
18981	JUNXJQ	DZCYIFOCWV	1194227966 Dell Way	\N	AFSLRLH	\N	0	Canada	2	DZCYIFOCWV@dell.com	1194227966	4	2491813913453370	2009/07	user18981	password	87	60000	M
18982	TAVDRZ	CTYLZMNVHO	9763960062 Dell Way	\N	AAZSLHU	\N	0	France	2	CTYLZMNVHO@dell.com	9763960062	5	8624120112042875	2010/12	user18982	password	43	60000	M
18983	JHUAHX	UFITSWPAKQ	1810295783 Dell Way	\N	AKILRDX	\N	0	Japan	2	UFITSWPAKQ@dell.com	1810295783	4	2596013873815536	2008/02	user18983	password	63	80000	F
18984	XNNEKI	KSCCORCZHC	3181532386 Dell Way	\N	KPOBSMS	\N	0	South Africa	2	KSCCORCZHC@dell.com	3181532386	5	8417471602559090	2009/07	user18984	password	56	100000	F
18985	AJQKSB	DUDSMFRTIB	7997860131 Dell Way	\N	JXDBJWW	\N	0	Japan	2	DUDSMFRTIB@dell.com	7997860131	4	9673929491080344	2009/03	user18985	password	77	80000	F
18986	FKRXLU	SPMEUEYDGH	9570812560 Dell Way	\N	AKJJGGZ	\N	0	Australia	2	SPMEUEYDGH@dell.com	9570812560	5	4108994862996042	2008/10	user18986	password	25	60000	M
18987	NCWYXO	NKTIORMVZN	8331891570 Dell Way	\N	FJWMQWM	\N	0	Germany	2	NKTIORMVZN@dell.com	8331891570	5	7727989344391973	2010/12	user18987	password	30	60000	F
18988	HKKEZY	PSHEKUZKHE	9844087820 Dell Way	\N	TEQJADY	\N	0	South Africa	2	PSHEKUZKHE@dell.com	9844087820	4	4787009655032307	2012/11	user18988	password	87	40000	F
18989	JVIIUX	BBBLVBWCFQ	6958811054 Dell Way	\N	HWAHAYD	\N	0	UK	2	BBBLVBWCFQ@dell.com	6958811054	3	9334008696023376	2010/07	user18989	password	41	80000	M
18990	DAFXYG	ZASVBOYHEF	2932385561 Dell Way	\N	DFNDEQD	\N	0	South Africa	2	ZASVBOYHEF@dell.com	2932385561	1	4243356691207737	2011/05	user18990	password	22	80000	M
18991	CVLACK	AUFBJEIOJM	8612645336 Dell Way	\N	TWQYNUT	\N	0	Russia	2	AUFBJEIOJM@dell.com	8612645336	1	5190918435342610	2009/02	user18991	password	24	80000	F
18992	XFGAQH	VWJFASTJEN	3743883854 Dell Way	\N	FVLTPFM	\N	0	France	2	VWJFASTJEN@dell.com	3743883854	5	7074055915232748	2010/01	user18992	password	50	80000	M
18993	RZYHGU	DPZDITNMHT	8925757436 Dell Way	\N	ITMXYYI	\N	0	Chile	2	DPZDITNMHT@dell.com	8925757436	1	7447944791987539	2012/06	user18993	password	48	100000	F
18994	KVKQPN	GPROIEBQXJ	6627533350 Dell Way	\N	JJHIIPO	\N	0	Chile	2	GPROIEBQXJ@dell.com	6627533350	2	2022421539761126	2008/09	user18994	password	88	20000	F
18995	UPTJCZ	YTOHYQXVAG	4879850418 Dell Way	\N	FHPOXDT	\N	0	Germany	2	YTOHYQXVAG@dell.com	4879850418	5	6445741886273027	2008/11	user18995	password	76	40000	M
18996	JZZMZX	GOEEECAEJG	5060337842 Dell Way	\N	MYUJBOX	\N	0	Germany	2	GOEEECAEJG@dell.com	5060337842	3	6764340188354254	2009/04	user18996	password	81	100000	M
18997	WWEVUK	JZPOBQTKWF	9812973257 Dell Way	\N	IRPKGMX	\N	0	Russia	2	JZPOBQTKWF@dell.com	9812973257	3	9950576036702844	2009/06	user18997	password	83	100000	F
18998	UDCONM	NDAPTTZQYI	2583479265 Dell Way	\N	HOSOAQG	\N	0	Australia	2	NDAPTTZQYI@dell.com	2583479265	2	3520832828246057	2010/02	user18998	password	35	100000	M
18999	JYMWKA	ALPTEPJDXR	7666828989 Dell Way	\N	RQGSHMS	\N	0	France	2	ALPTEPJDXR@dell.com	7666828989	5	1441031621769070	2012/03	user18999	password	84	100000	M
19000	WHMHHM	TXFXMPBKHT	2630586395 Dell Way	\N	BNMIZEU	\N	0	Russia	2	TXFXMPBKHT@dell.com	2630586395	5	6645363221876324	2010/09	user19000	password	49	100000	M
19001	SMXAYQ	XEOJTQUAJV	7851851233 Dell Way	\N	OVDNAYH	\N	0	Chile	2	XEOJTQUAJV@dell.com	7851851233	5	6563201619312168	2010/05	user19001	password	62	20000	F
19002	CABARY	EGIXWCYFXM	2817084181 Dell Way	\N	BBACAHH	\N	0	Russia	2	EGIXWCYFXM@dell.com	2817084181	5	3411166785750538	2010/07	user19002	password	46	60000	M
19003	KQQCPU	IXSFZQLXDM	8195135799 Dell Way	\N	ZEPZLWT	\N	0	Japan	2	IXSFZQLXDM@dell.com	8195135799	1	2758482679259032	2009/05	user19003	password	75	100000	M
19004	LOYAIG	XBLXSWVVJV	6143448217 Dell Way	\N	ZZULWOC	\N	0	Japan	2	XBLXSWVVJV@dell.com	6143448217	2	9794365625362844	2012/01	user19004	password	85	100000	M
19005	MTNVAL	WMIOJEKSZJ	2799250341 Dell Way	\N	RUVNIXE	\N	0	UK	2	WMIOJEKSZJ@dell.com	2799250341	1	8995060763321818	2009/01	user19005	password	68	80000	M
19006	LHJLSG	XBUGFFZFOR	5901653130 Dell Way	\N	ZJFIHKG	\N	0	France	2	XBUGFFZFOR@dell.com	5901653130	1	7878984212875367	2011/10	user19006	password	57	20000	F
19007	VOSOUQ	PPWVUWBJNB	7835751764 Dell Way	\N	TTJBDQN	\N	0	Japan	2	PPWVUWBJNB@dell.com	7835751764	2	3641688501928002	2010/11	user19007	password	52	100000	M
19008	AOFVEV	LBRFYSPMTJ	2874551406 Dell Way	\N	FDKIUXA	\N	0	Germany	2	LBRFYSPMTJ@dell.com	2874551406	2	2113210408948362	2008/10	user19008	password	89	80000	M
19009	OYQTTB	VKGTDWFXFL	1861227579 Dell Way	\N	APUVNUI	\N	0	Russia	2	VKGTDWFXFL@dell.com	1861227579	3	7852081916294993	2012/06	user19009	password	52	80000	F
19010	KHTDIO	OPIRLNORZP	3109910658 Dell Way	\N	GTKTNTM	\N	0	Japan	2	OPIRLNORZP@dell.com	3109910658	2	5483805593103171	2011/09	user19010	password	30	80000	F
19011	LLGUZU	JIMVVBMVRS	2993130450 Dell Way	\N	OCMCVZS	\N	0	Australia	2	JIMVVBMVRS@dell.com	2993130450	2	7857931918930263	2012/05	user19011	password	50	20000	M
19012	XHPWCZ	EOUAQGVHZK	4612923427 Dell Way	\N	JMMFLEH	\N	0	Japan	2	EOUAQGVHZK@dell.com	4612923427	1	6418495013844222	2011/06	user19012	password	65	80000	F
19013	YFGAEL	PYMFEINESW	4313292512 Dell Way	\N	QFBCKIT	\N	0	Russia	2	PYMFEINESW@dell.com	4313292512	2	6112316315993667	2012/12	user19013	password	30	40000	M
19014	JMYNYO	MKURSHVLDM	6743223135 Dell Way	\N	QEOANHV	\N	0	South Africa	2	MKURSHVLDM@dell.com	6743223135	2	7698195542674512	2011/07	user19014	password	88	60000	M
19015	LNMJBY	UVPNDLYGXO	8158701410 Dell Way	\N	LLPZTKW	\N	0	China	2	UVPNDLYGXO@dell.com	8158701410	3	1176237263251096	2009/07	user19015	password	60	40000	F
19016	CTKERE	AHRDTQJRFV	3120497429 Dell Way	\N	DUUWFQG	\N	0	UK	2	AHRDTQJRFV@dell.com	3120497429	2	4140419845934957	2012/11	user19016	password	63	100000	M
19017	JFCBKC	JCGCSPTXLW	3382731200 Dell Way	\N	SFTXWZX	\N	0	Australia	2	JCGCSPTXLW@dell.com	3382731200	2	9071245205588640	2008/11	user19017	password	70	20000	F
19018	YEHJHQ	MNTEDMCOJU	8774093389 Dell Way	\N	UCSQBPS	\N	0	China	2	MNTEDMCOJU@dell.com	8774093389	4	5110548372380436	2011/05	user19018	password	56	100000	F
19019	RHRZYD	MRHPEKDNEX	8884953543 Dell Way	\N	PWORMGA	\N	0	China	2	MRHPEKDNEX@dell.com	8884953543	3	1909023358486592	2009/01	user19019	password	24	60000	M
19020	KERIHD	APTFZWSEUI	5858212735 Dell Way	\N	BIAOPBX	\N	0	France	2	APTFZWSEUI@dell.com	5858212735	5	7270480330102146	2010/02	user19020	password	33	40000	F
19021	JXVRAV	GUAGQTKLCL	8960239772 Dell Way	\N	UDZKFXW	\N	0	Russia	2	GUAGQTKLCL@dell.com	8960239772	3	3499066341668367	2012/10	user19021	password	55	60000	F
19022	KHVLCC	FDIWXSIAED	9791543279 Dell Way	\N	DENJBKC	\N	0	UK	2	FDIWXSIAED@dell.com	9791543279	2	9222234726417812	2011/11	user19022	password	45	100000	F
19023	QTTTVY	XDVVWDVBGZ	7910449701 Dell Way	\N	FUIGEKF	\N	0	Canada	2	XDVVWDVBGZ@dell.com	7910449701	1	9176870646886528	2011/06	user19023	password	78	100000	F
19024	ORXKPU	OLPLOLMVKR	3503503096 Dell Way	\N	PTYUDEX	\N	0	UK	2	OLPLOLMVKR@dell.com	3503503096	5	6024655728135259	2011/08	user19024	password	53	100000	F
19025	DUQTPF	FEQTQCPAUF	7412559820 Dell Way	\N	UTZYXXV	\N	0	Canada	2	FEQTQCPAUF@dell.com	7412559820	2	9647519438527524	2009/11	user19025	password	80	80000	F
19026	QGUGLZ	LBTBEJCZOW	1162573440 Dell Way	\N	SNUQKQV	\N	0	Canada	2	LBTBEJCZOW@dell.com	1162573440	4	5313547832891345	2012/08	user19026	password	23	100000	F
19027	ISNTSZ	VMAZVCYJYR	9280813270 Dell Way	\N	WSHHIDJ	\N	0	China	2	VMAZVCYJYR@dell.com	9280813270	5	3395594052039087	2010/12	user19027	password	32	100000	F
19028	YKAQJV	DJVYMUHKLE	7274595924 Dell Way	\N	DTLMWVW	\N	0	South Africa	2	DJVYMUHKLE@dell.com	7274595924	1	4344416941516101	2011/04	user19028	password	35	100000	F
19029	RYXAUA	KPYXKGIVLL	9365033455 Dell Way	\N	PWYMSUG	\N	0	France	2	KPYXKGIVLL@dell.com	9365033455	4	1451910598669201	2009/11	user19029	password	87	60000	M
19030	XKORLZ	HJWRQEMBQC	5043324410 Dell Way	\N	YPOQKVB	\N	0	China	2	HJWRQEMBQC@dell.com	5043324410	1	6251882375683636	2009/01	user19030	password	24	100000	M
19031	MLQYLX	HHOYMBZDDY	7744147440 Dell Way	\N	SRPDMQL	\N	0	UK	2	HHOYMBZDDY@dell.com	7744147440	1	3385309658013284	2012/02	user19031	password	27	80000	M
19032	OKOAHW	HVUUXUXASQ	3058421205 Dell Way	\N	SITEYFC	\N	0	Russia	2	HVUUXUXASQ@dell.com	3058421205	2	5656431345734746	2009/07	user19032	password	39	100000	F
19033	RNCZKK	VEESZCTSSL	1872170359 Dell Way	\N	ALPYQSR	\N	0	South Africa	2	VEESZCTSSL@dell.com	1872170359	1	3043917319271713	2011/06	user19033	password	32	80000	F
19034	TUDDEY	HJRGLKZDVZ	7963120042 Dell Way	\N	PLYFDPC	\N	0	Chile	2	HJRGLKZDVZ@dell.com	7963120042	2	8725706913508476	2009/07	user19034	password	58	40000	F
19035	JNKNMR	WDYHNXLIWA	7135572500 Dell Way	\N	TVGXKJE	\N	0	Canada	2	WDYHNXLIWA@dell.com	7135572500	1	4809285346418619	2009/08	user19035	password	77	60000	M
19036	IWLUOI	YMQLKCUHCO	6936468307 Dell Way	\N	CJMNSQS	\N	0	China	2	YMQLKCUHCO@dell.com	6936468307	1	6411256942898036	2009/12	user19036	password	24	20000	F
19037	YQBNZA	APLKRFSUTV	2225527198 Dell Way	\N	DFIVWAF	\N	0	Germany	2	APLKRFSUTV@dell.com	2225527198	5	7820390816312284	2008/11	user19037	password	86	40000	M
19038	OKJNKJ	DWUVCMPVHT	6676273782 Dell Way	\N	BQPXQUL	\N	0	Russia	2	DWUVCMPVHT@dell.com	6676273782	1	8705737004056574	2010/02	user19038	password	32	60000	M
19039	QUFBDJ	XYEZKUVSNW	4589022995 Dell Way	\N	JCUAXFU	\N	0	Germany	2	XYEZKUVSNW@dell.com	4589022995	4	1687442052643746	2010/11	user19039	password	53	20000	F
19040	GKNKTK	IYKTSFMGCV	3252927580 Dell Way	\N	IXVGCPU	\N	0	Germany	2	IYKTSFMGCV@dell.com	3252927580	5	1205821995157748	2008/04	user19040	password	34	60000	M
19041	QBZKMH	IXBBDNHFIQ	5377373921 Dell Way	\N	CEWFTQS	\N	0	Australia	2	IXBBDNHFIQ@dell.com	5377373921	4	1982286041136831	2012/12	user19041	password	66	60000	M
19042	TKAFSI	DTJGGRLPHO	3417729107 Dell Way	\N	TDUNUNN	\N	0	Chile	2	DTJGGRLPHO@dell.com	3417729107	4	1790832350496202	2009/04	user19042	password	53	100000	F
19043	WVHOEK	IOQPGCENRY	6697852493 Dell Way	\N	RLLLZZS	\N	0	Chile	2	IOQPGCENRY@dell.com	6697852493	5	5284990894142539	2012/04	user19043	password	41	100000	F
19044	EHTJRB	XIQDKVRBTI	3721974574 Dell Way	\N	NFUMFMS	\N	0	South Africa	2	XIQDKVRBTI@dell.com	3721974574	2	8087314723059536	2011/07	user19044	password	75	80000	M
19045	BNBTPY	BGCMCTOWCC	5641945443 Dell Way	\N	CWPHJID	\N	0	Japan	2	BGCMCTOWCC@dell.com	5641945443	5	3312376790679991	2008/09	user19045	password	20	80000	M
19046	OUNESP	LVCNOQKQTM	8156090774 Dell Way	\N	NITWQWN	\N	0	Canada	2	LVCNOQKQTM@dell.com	8156090774	4	2641588129568845	2010/10	user19046	password	84	40000	F
19047	RUOKJZ	FLNUCYLVKY	1526876027 Dell Way	\N	DDUTAHX	\N	0	South Africa	2	FLNUCYLVKY@dell.com	1526876027	1	3883662299253047	2012/01	user19047	password	60	40000	M
19048	JUCTUI	FIDHGODQMG	1236022972 Dell Way	\N	UGAVOYQ	\N	0	Japan	2	FIDHGODQMG@dell.com	1236022972	5	5338291948661208	2008/07	user19048	password	70	80000	M
19049	NVRHEW	QHDWVHNINH	7512540280 Dell Way	\N	PODDNTU	\N	0	Germany	2	QHDWVHNINH@dell.com	7512540280	2	6049126899801195	2009/12	user19049	password	39	20000	F
19050	DWUHSK	OWHKDVTRCI	5534018486 Dell Way	\N	GGMTZGG	\N	0	Russia	2	OWHKDVTRCI@dell.com	5534018486	5	9882968649268152	2010/02	user19050	password	30	100000	F
19051	ATNSEC	PMNSHGKKPQ	5142740726 Dell Way	\N	QBJQIQI	\N	0	South Africa	2	PMNSHGKKPQ@dell.com	5142740726	2	3644886596128345	2010/06	user19051	password	36	100000	M
19052	AJGFLV	RZOYGYIVOZ	3136258659 Dell Way	\N	XYPFOXA	\N	0	Australia	2	RZOYGYIVOZ@dell.com	3136258659	2	6408964320551605	2011/07	user19052	password	48	40000	M
19053	UMUFIL	FWKLVTHJSE	7200336729 Dell Way	\N	IHJWFJX	\N	0	France	2	FWKLVTHJSE@dell.com	7200336729	3	2540722959674895	2009/11	user19053	password	48	100000	M
19054	XQXFBD	CMOXFVHXAP	8777683589 Dell Way	\N	EJMKTJV	\N	0	France	2	CMOXFVHXAP@dell.com	8777683589	5	7225434352178127	2011/05	user19054	password	57	60000	F
19055	EJOFNR	RBOXXWUXLZ	2581870874 Dell Way	\N	HYJAHEM	\N	0	Canada	2	RBOXXWUXLZ@dell.com	2581870874	1	9501538339536638	2010/09	user19055	password	47	100000	M
19056	UMBHDT	JSQHOLFAKM	2163419299 Dell Way	\N	YTNGYZK	\N	0	Canada	2	JSQHOLFAKM@dell.com	2163419299	2	7299422446638346	2012/10	user19056	password	62	80000	M
19057	CTWFNF	XEMMPRMZEL	5342988840 Dell Way	\N	TRSRQDU	\N	0	Russia	2	XEMMPRMZEL@dell.com	5342988840	3	6423937379382551	2009/02	user19057	password	37	100000	F
19058	ARKNXI	RJUGBHGGTZ	9414765793 Dell Way	\N	XLROOLJ	\N	0	Australia	2	RJUGBHGGTZ@dell.com	9414765793	5	3693147960118949	2008/03	user19058	password	26	40000	F
19059	UQTRYL	BTSDAYJTYH	2299892650 Dell Way	\N	FPVTBEV	\N	0	UK	2	BTSDAYJTYH@dell.com	2299892650	1	1290276412852108	2009/03	user19059	password	36	80000	F
19060	WJRVUT	ONWPLFIKMO	3033903291 Dell Way	\N	AIIBNDB	\N	0	Japan	2	ONWPLFIKMO@dell.com	3033903291	1	1361313264351338	2010/05	user19060	password	65	60000	F
19061	AEBVXP	IUEUZNEMBE	4927346988 Dell Way	\N	VKGJNIA	\N	0	Russia	2	IUEUZNEMBE@dell.com	4927346988	1	2625891720876097	2011/09	user19061	password	65	20000	M
19062	UCOSRW	MWRMKVYMAU	3081531214 Dell Way	\N	WHDJQEC	\N	0	Australia	2	MWRMKVYMAU@dell.com	3081531214	2	8667205940000714	2012/12	user19062	password	82	80000	M
19063	YFLQCX	NTJYPILQDH	1503471959 Dell Way	\N	XHRNLUP	\N	0	Japan	2	NTJYPILQDH@dell.com	1503471959	3	6525465650018305	2012/04	user19063	password	39	80000	F
19064	NEYQBM	JLKZUVPXDN	1907317083 Dell Way	\N	EUBQOQH	\N	0	Japan	2	JLKZUVPXDN@dell.com	1907317083	5	6515981405042112	2010/03	user19064	password	42	80000	M
19065	MRIODS	ZNSUJHSNVX	7559225725 Dell Way	\N	HWNWNVM	\N	0	Japan	2	ZNSUJHSNVX@dell.com	7559225725	1	1493019265588373	2012/06	user19065	password	74	80000	M
19066	LZMORM	CJGLRZYMWG	7637392810 Dell Way	\N	JJDXFQN	\N	0	UK	2	CJGLRZYMWG@dell.com	7637392810	3	8702349969185890	2008/05	user19066	password	54	20000	M
19067	MPIEBK	OIWFHVSDCC	1870193450 Dell Way	\N	NFZSWNR	\N	0	Germany	2	OIWFHVSDCC@dell.com	1870193450	3	7864653199445457	2010/01	user19067	password	81	40000	F
19068	LOQNZF	VVLDREHTGV	7386566612 Dell Way	\N	ZGOVUFK	\N	0	South Africa	2	VVLDREHTGV@dell.com	7386566612	1	3855267743114382	2011/01	user19068	password	57	40000	F
19069	CWABBW	XMZORGIXBH	7169476485 Dell Way	\N	EPCYUNV	\N	0	Germany	2	XMZORGIXBH@dell.com	7169476485	1	3115903111174703	2011/09	user19069	password	50	40000	M
19070	HFVJBS	WBGNHOLJWQ	5916689715 Dell Way	\N	ZYPUMKH	\N	0	Canada	2	WBGNHOLJWQ@dell.com	5916689715	3	8959805514663459	2009/12	user19070	password	25	100000	F
19071	IUQKNN	LTBTINDEDC	7363086898 Dell Way	\N	DSWPCET	\N	0	Japan	2	LTBTINDEDC@dell.com	7363086898	4	8979561300016941	2011/10	user19071	password	82	100000	F
19072	RPMFDX	YERHRULVWP	6450968987 Dell Way	\N	NTEQYYH	\N	0	Japan	2	YERHRULVWP@dell.com	6450968987	1	3860391541849822	2009/01	user19072	password	38	60000	M
19073	XXYAVX	FMEXGQSDFG	4185704674 Dell Way	\N	XKWVIEL	\N	0	UK	2	FMEXGQSDFG@dell.com	4185704674	4	3757777680642903	2010/01	user19073	password	72	20000	M
19074	QCZMAE	YECFUUIZAF	3313406126 Dell Way	\N	KXBSBMR	\N	0	France	2	YECFUUIZAF@dell.com	3313406126	5	8565904232207687	2009/09	user19074	password	18	40000	F
19075	CFVDKU	HMZCHICIOM	8795859880 Dell Way	\N	FPFHCWS	\N	0	China	2	HMZCHICIOM@dell.com	8795859880	3	6762523310258985	2010/07	user19075	password	82	100000	M
19076	CUUNPC	AOEHXGQLSV	4471394547 Dell Way	\N	AYDCVVL	\N	0	Japan	2	AOEHXGQLSV@dell.com	4471394547	1	3428777428343892	2012/12	user19076	password	35	80000	F
19077	AKPQMQ	EQYCXONQKO	3038394428 Dell Way	\N	ONRJIDB	\N	0	Russia	2	EQYCXONQKO@dell.com	3038394428	2	7074299292173237	2009/07	user19077	password	39	40000	M
19078	SXFENK	VMMTAAJKPY	7382889438 Dell Way	\N	XHIGLJZ	\N	0	Japan	2	VMMTAAJKPY@dell.com	7382889438	4	8797510051168502	2009/12	user19078	password	29	100000	M
19079	BCVPMR	CZKCAUNQSK	4150536383 Dell Way	\N	XBRJLRA	\N	0	Canada	2	CZKCAUNQSK@dell.com	4150536383	5	4709257126320154	2009/01	user19079	password	38	100000	F
19080	JUSVLU	VWXVQKLJVJ	6204660593 Dell Way	\N	LNSWFSA	\N	0	Germany	2	VWXVQKLJVJ@dell.com	6204660593	3	8672468618489803	2011/09	user19080	password	77	80000	F
19081	PLWBGR	YDNPOYYJHJ	6855286888 Dell Way	\N	XZGCRGQ	\N	0	Chile	2	YDNPOYYJHJ@dell.com	6855286888	3	8977721325587482	2009/04	user19081	password	62	40000	M
19082	BGZIYX	MMMAKLKSVH	5593861440 Dell Way	\N	RBKJIAQ	\N	0	UK	2	MMMAKLKSVH@dell.com	5593861440	3	3703258991241455	2012/02	user19082	password	67	80000	F
19083	YSNXQZ	JDATOLMKTD	7496861541 Dell Way	\N	MDNUEET	\N	0	Japan	2	JDATOLMKTD@dell.com	7496861541	1	5296870188321918	2012/09	user19083	password	32	20000	M
19084	XQONPY	QQSFBEQUIC	7402549846 Dell Way	\N	YWXCART	\N	0	Russia	2	QQSFBEQUIC@dell.com	7402549846	2	6690546109806747	2010/06	user19084	password	70	20000	F
19085	ISWYQN	PITQNJLVMK	5149073539 Dell Way	\N	RKMSBFM	\N	0	Russia	2	PITQNJLVMK@dell.com	5149073539	1	2831060086842626	2012/10	user19085	password	42	40000	F
19086	ACCRPS	AIJNSUIEEA	3719507063 Dell Way	\N	ORSPXFJ	\N	0	China	2	AIJNSUIEEA@dell.com	3719507063	3	3167625685688108	2008/11	user19086	password	52	40000	M
19087	OKPECQ	NLDFGMKKMY	5623297280 Dell Way	\N	CFOZKYI	\N	0	Russia	2	NLDFGMKKMY@dell.com	5623297280	3	8618591438047589	2010/01	user19087	password	27	40000	M
19088	NZTQPG	BTLHFWSSUU	6719180824 Dell Way	\N	YJTJICC	\N	0	South Africa	2	BTLHFWSSUU@dell.com	6719180824	5	3229438420385122	2011/01	user19088	password	62	40000	M
19089	PAFEGG	XSODOHWJBV	2560248888 Dell Way	\N	TVEBXGX	\N	0	Germany	2	XSODOHWJBV@dell.com	2560248888	1	2915929266251623	2009/10	user19089	password	51	100000	F
19090	MANTHL	LVPADLKEGE	3446465314 Dell Way	\N	AKFYRDM	\N	0	South Africa	2	LVPADLKEGE@dell.com	3446465314	4	1659682010766118	2008/03	user19090	password	83	40000	M
19091	XWJFHV	BWWEIGJOKJ	5685323053 Dell Way	\N	ZQIRUVN	\N	0	Australia	2	BWWEIGJOKJ@dell.com	5685323053	3	1588934318162500	2011/06	user19091	password	48	40000	F
19092	HSPPNQ	LJUUQEIBOI	1640466694 Dell Way	\N	SWZMRMN	\N	0	Canada	2	LJUUQEIBOI@dell.com	1640466694	3	8987036750651897	2010/12	user19092	password	33	100000	F
19093	XNWLDH	VYBLCKMQTE	7537493336 Dell Way	\N	NTQEGEJ	\N	0	China	2	VYBLCKMQTE@dell.com	7537493336	2	8621939052827657	2011/06	user19093	password	74	100000	F
19094	HVVLDQ	JFCMQPDJTQ	5151957932 Dell Way	\N	DKVJOFR	\N	0	China	2	JFCMQPDJTQ@dell.com	5151957932	3	1156185986474156	2012/04	user19094	password	18	40000	M
19095	WEZZVJ	FXVWMYFGPJ	9014003172 Dell Way	\N	RKSGPJO	\N	0	Australia	2	FXVWMYFGPJ@dell.com	9014003172	3	9918015502858908	2008/07	user19095	password	42	80000	F
19096	NSKICQ	FXMSWSZLBQ	9889065100 Dell Way	\N	VUWKDLM	\N	0	Australia	2	FXMSWSZLBQ@dell.com	9889065100	3	2945140462834388	2010/10	user19096	password	87	100000	F
19097	RKQTAW	RNONGNZHEU	2304336610 Dell Way	\N	CBFGMRH	\N	0	France	2	RNONGNZHEU@dell.com	2304336610	3	1227076083421707	2012/06	user19097	password	18	40000	F
19098	KWWLSN	ZHBFVANZVP	6290515518 Dell Way	\N	BAVNSCZ	\N	0	South Africa	2	ZHBFVANZVP@dell.com	6290515518	1	8248073821421713	2008/01	user19098	password	20	20000	F
19099	XAWPNV	XOASPNSKDT	3487798465 Dell Way	\N	LYGEBGA	\N	0	Japan	2	XOASPNSKDT@dell.com	3487798465	5	6937547498382629	2009/11	user19099	password	76	80000	M
19100	VPJIKH	XLZNZRXCKI	4375899189 Dell Way	\N	BRNCYNS	\N	0	Chile	2	XLZNZRXCKI@dell.com	4375899189	2	5679643149022013	2009/03	user19100	password	35	20000	F
19101	VKJGRH	SQUSIRVTAW	1883784450 Dell Way	\N	LNZJBSP	\N	0	France	2	SQUSIRVTAW@dell.com	1883784450	1	7203908497467638	2009/05	user19101	password	70	40000	F
19102	DRLUYE	LSWTKRNKOY	1212536519 Dell Way	\N	YNIZGXL	\N	0	China	2	LSWTKRNKOY@dell.com	1212536519	1	6710610684473068	2009/11	user19102	password	86	60000	M
19103	PATNFE	FBYPTLAHKY	5477403746 Dell Way	\N	VSYCQJK	\N	0	Japan	2	FBYPTLAHKY@dell.com	5477403746	1	1247462133411318	2009/12	user19103	password	62	40000	M
19104	QACVFI	XEYQQYYAXU	4026227554 Dell Way	\N	TVWJFHA	\N	0	Russia	2	XEYQQYYAXU@dell.com	4026227554	1	1423414675984531	2009/08	user19104	password	42	100000	F
19105	JADPIA	THRJFQKDKD	5838021195 Dell Way	\N	ZGNEONX	\N	0	South Africa	2	THRJFQKDKD@dell.com	5838021195	5	2900497914291918	2008/04	user19105	password	26	60000	M
19106	DPFMPY	THIZXTCHWB	1695760404 Dell Way	\N	OJGCXDZ	\N	0	France	2	THIZXTCHWB@dell.com	1695760404	2	6421722147148103	2009/04	user19106	password	22	100000	F
19107	QFYGER	NNRKGTSDVH	6244794604 Dell Way	\N	NBJKFJV	\N	0	Chile	2	NNRKGTSDVH@dell.com	6244794604	3	6612091739196331	2012/06	user19107	password	62	40000	F
19108	VIJZZW	MRHSKZVGGI	9677058711 Dell Way	\N	HQTMAOT	\N	0	Japan	2	MRHSKZVGGI@dell.com	9677058711	2	5643250802997500	2010/12	user19108	password	82	60000	M
19109	FXUFUH	WBAHBWNIFU	4811958993 Dell Way	\N	ZYHZMBP	\N	0	France	2	WBAHBWNIFU@dell.com	4811958993	1	8923342236783356	2010/01	user19109	password	49	40000	F
19110	JAKDIG	FINHEAPJVO	3606486880 Dell Way	\N	HCOUEEF	\N	0	Germany	2	FINHEAPJVO@dell.com	3606486880	1	9970489749684932	2009/07	user19110	password	34	60000	M
19111	GXAOEF	XRMBSCLORS	8154468662 Dell Way	\N	RGMVKSK	\N	0	Russia	2	XRMBSCLORS@dell.com	8154468662	2	9999810317531228	2009/08	user19111	password	54	40000	M
19112	KFLOLI	GYKZAVOSOF	8492295779 Dell Way	\N	YBAJTLB	\N	0	Germany	2	GYKZAVOSOF@dell.com	8492295779	1	8826211808249355	2010/07	user19112	password	23	40000	M
19113	HUOSDV	RNUSJIKXOJ	8818269271 Dell Way	\N	ZPSSAUG	\N	0	South Africa	2	RNUSJIKXOJ@dell.com	8818269271	1	3824167328421027	2010/03	user19113	password	65	60000	F
19114	LZFPUW	CPPMYZKMJJ	5252443503 Dell Way	\N	BCBCXIY	\N	0	Russia	2	CPPMYZKMJJ@dell.com	5252443503	2	2786316729150712	2011/12	user19114	password	63	20000	F
19115	PJYJGB	YWNXVYJFHL	7727385201 Dell Way	\N	HJNESMY	\N	0	Canada	2	YWNXVYJFHL@dell.com	7727385201	1	8615292865782977	2011/10	user19115	password	18	20000	F
19116	KZSRAR	NOOIMYOUJV	1953591559 Dell Way	\N	DXAVJZA	\N	0	Canada	2	NOOIMYOUJV@dell.com	1953591559	5	8179180679377169	2012/11	user19116	password	78	40000	F
19117	UYXVPK	KETXCHRLDV	5561317058 Dell Way	\N	JEQTDRW	\N	0	Chile	2	KETXCHRLDV@dell.com	5561317058	4	2007705042604357	2009/06	user19117	password	41	80000	F
19118	GNDWYO	ASLCADOEYX	2863730113 Dell Way	\N	IPRMGNS	\N	0	Russia	2	ASLCADOEYX@dell.com	2863730113	5	2092361200135201	2011/02	user19118	password	72	20000	F
19119	HDHGSH	YDKYHYDFWL	5621241371 Dell Way	\N	UOYBBRU	\N	0	Chile	2	YDKYHYDFWL@dell.com	5621241371	5	9902748972643168	2011/08	user19119	password	18	20000	M
19120	EJEWQD	ABBHZEMWQH	1384414468 Dell Way	\N	KPIMGDU	\N	0	Russia	2	ABBHZEMWQH@dell.com	1384414468	4	5016284395474941	2011/10	user19120	password	57	80000	M
19121	XVUOYU	PABPFNMVVW	9054367656 Dell Way	\N	LDJRGDL	\N	0	China	2	PABPFNMVVW@dell.com	9054367656	5	1149172621779143	2011/06	user19121	password	66	60000	F
19122	NIXLCM	MEBRRONNKY	9799535436 Dell Way	\N	QUQXXCF	\N	0	South Africa	2	MEBRRONNKY@dell.com	9799535436	2	5219821529928595	2010/11	user19122	password	20	80000	F
19123	JQWMDI	QFZITNVELM	8619399533 Dell Way	\N	YBKWDPR	\N	0	Canada	2	QFZITNVELM@dell.com	8619399533	1	5922931761015207	2011/03	user19123	password	40	20000	M
19124	YABCIS	HIBBVWGHJE	9178800077 Dell Way	\N	JTBNJTQ	\N	0	Chile	2	HIBBVWGHJE@dell.com	9178800077	1	9679337691981346	2008/06	user19124	password	27	80000	F
19125	DTNMLV	VNXQJDYTIH	6592142901 Dell Way	\N	NKUWDLC	\N	0	Australia	2	VNXQJDYTIH@dell.com	6592142901	1	2352274478878826	2008/03	user19125	password	78	60000	F
19126	OCUAYP	NVGXZFRHME	2299979529 Dell Way	\N	RHAVSCW	\N	0	China	2	NVGXZFRHME@dell.com	2299979529	1	5054855202324689	2009/11	user19126	password	18	80000	F
19127	CKLBAZ	WHWWNNDZRV	5836069067 Dell Way	\N	HSRZVNI	\N	0	UK	2	WHWWNNDZRV@dell.com	5836069067	4	3423777975142002	2009/10	user19127	password	83	80000	M
19128	IGYJFV	RBREPVDHQK	5533108186 Dell Way	\N	ZIKVVST	\N	0	China	2	RBREPVDHQK@dell.com	5533108186	1	7744500440545381	2009/12	user19128	password	57	20000	F
19129	UCPZXG	BOKRKOYBZY	5960046912 Dell Way	\N	JJTECNO	\N	0	Japan	2	BOKRKOYBZY@dell.com	5960046912	2	9063202949706466	2010/11	user19129	password	23	80000	M
19130	EIPCPR	RZIBOHCNFL	5257163524 Dell Way	\N	XYQAMEQ	\N	0	Australia	2	RZIBOHCNFL@dell.com	5257163524	3	5573514458257705	2009/08	user19130	password	35	100000	M
19131	OOVDFM	DOOSVQFACD	3512289996 Dell Way	\N	ZSDMWTN	\N	0	China	2	DOOSVQFACD@dell.com	3512289996	1	7040776054840536	2012/03	user19131	password	63	80000	M
19132	EMYKZC	ZNUUDAVGDV	8383993384 Dell Way	\N	YHHVBVE	\N	0	China	2	ZNUUDAVGDV@dell.com	8383993384	5	2714480948168784	2008/06	user19132	password	77	100000	M
19133	HVBGXA	TSUXSQDVMC	9322452134 Dell Way	\N	DUXEPCM	\N	0	China	2	TSUXSQDVMC@dell.com	9322452134	4	5195947329979390	2009/06	user19133	password	42	20000	M
19134	EBABCU	TXSMNWHZYL	7928402857 Dell Way	\N	TWPIYCT	\N	0	South Africa	2	TXSMNWHZYL@dell.com	7928402857	2	3315707285422832	2009/07	user19134	password	38	20000	M
19135	JCULWO	IPAWLIWKTQ	9222230271 Dell Way	\N	HIZFLSC	\N	0	Chile	2	IPAWLIWKTQ@dell.com	9222230271	2	5230261827353388	2010/08	user19135	password	55	20000	M
19136	PYLMNU	BNQNVMXPDE	8561464392 Dell Way	\N	YCKJUMO	\N	0	Russia	2	BNQNVMXPDE@dell.com	8561464392	1	2471000466030091	2010/07	user19136	password	42	60000	F
19137	HXQURS	IHFEUDTXIS	7190262939 Dell Way	\N	ZSBUFQM	\N	0	Australia	2	IHFEUDTXIS@dell.com	7190262939	4	5724163602571935	2009/12	user19137	password	89	60000	F
19138	WBBNTK	VYOQBHOKZO	5306742381 Dell Way	\N	CBIISVJ	\N	0	China	2	VYOQBHOKZO@dell.com	5306742381	5	6843890119809658	2010/11	user19138	password	22	80000	M
19139	CVHWFD	UTTWBIHBWJ	9995535509 Dell Way	\N	DESVACF	\N	0	France	2	UTTWBIHBWJ@dell.com	9995535509	5	9639891755767168	2012/12	user19139	password	69	80000	F
19140	NYXSBS	MVPNDWPZGS	6693356574 Dell Way	\N	EYNFBTS	\N	0	Australia	2	MVPNDWPZGS@dell.com	6693356574	4	9406905479263516	2010/05	user19140	password	60	80000	M
19141	NNPPGC	LVPPREPYWU	3941841030 Dell Way	\N	WKZYERZ	\N	0	South Africa	2	LVPPREPYWU@dell.com	3941841030	5	4347719591576606	2011/06	user19141	password	90	60000	F
19142	NEQTGB	OWQGBFEYZB	8910226691 Dell Way	\N	IZZNQZH	\N	0	UK	2	OWQGBFEYZB@dell.com	8910226691	4	6886843668762595	2009/09	user19142	password	34	40000	F
19143	KAYQBN	NSUOYZMYAU	3598368525 Dell Way	\N	XAIOAPN	\N	0	South Africa	2	NSUOYZMYAU@dell.com	3598368525	1	3304377961438149	2012/05	user19143	password	65	20000	M
19144	RCLTPY	LKMKJYIKTG	5290508466 Dell Way	\N	LBULRII	\N	0	UK	2	LKMKJYIKTG@dell.com	5290508466	3	9355329101905228	2012/03	user19144	password	23	80000	M
19145	ECPUAB	ENMNMUXFBI	6837577121 Dell Way	\N	HVTZDBY	\N	0	Japan	2	ENMNMUXFBI@dell.com	6837577121	5	5438167509157211	2012/12	user19145	password	28	80000	F
19146	GJXHLB	UXOGSLMTUU	6227087955 Dell Way	\N	PNTSPSJ	\N	0	Chile	2	UXOGSLMTUU@dell.com	6227087955	5	2066896114964038	2010/12	user19146	password	81	80000	F
19147	FNNROH	ODOGOAZIVO	5510148070 Dell Way	\N	WOHMHRS	\N	0	South Africa	2	ODOGOAZIVO@dell.com	5510148070	5	4453352584969252	2010/09	user19147	password	20	80000	M
19148	OGPDND	GCKVDKEYYA	1521913869 Dell Way	\N	MGNTXFQ	\N	0	France	2	GCKVDKEYYA@dell.com	1521913869	5	9212371502071620	2011/01	user19148	password	65	80000	M
19149	XHTLLZ	NVVQFZOEAB	4898328847 Dell Way	\N	LNVJTLU	\N	0	South Africa	2	NVVQFZOEAB@dell.com	4898328847	4	6190711518749595	2010/04	user19149	password	37	20000	F
19150	OUQZUE	VPUBPJGQKR	5527097842 Dell Way	\N	EFBXRVT	\N	0	Australia	2	VPUBPJGQKR@dell.com	5527097842	2	5970243053045124	2012/08	user19150	password	62	20000	F
19151	KSDEWZ	URBKAHAKZE	2361416507 Dell Way	\N	QACHVVJ	\N	0	China	2	URBKAHAKZE@dell.com	2361416507	5	2537491878494620	2011/07	user19151	password	34	100000	M
19152	YADUAX	LBIMIIXHNN	2207248267 Dell Way	\N	IPVDLFM	\N	0	Germany	2	LBIMIIXHNN@dell.com	2207248267	4	3994990833569318	2011/11	user19152	password	33	80000	M
19153	GTQGRB	HZOQILYVZG	5753077966 Dell Way	\N	LUKWZWM	\N	0	Canada	2	HZOQILYVZG@dell.com	5753077966	4	8177694966085256	2010/01	user19153	password	48	40000	F
19154	EVNWXU	VMLDXJZWPK	5699505648 Dell Way	\N	RZGQWST	\N	0	China	2	VMLDXJZWPK@dell.com	5699505648	3	8243436181452126	2010/12	user19154	password	20	80000	F
19155	WHAUCW	GNZEXYAMJR	6804710501 Dell Way	\N	MPIJICT	\N	0	South Africa	2	GNZEXYAMJR@dell.com	6804710501	3	4508016323205084	2011/08	user19155	password	31	80000	F
19156	MUGPQN	DQRAPSNYKZ	6864429328 Dell Way	\N	OSJWVCT	\N	0	France	2	DQRAPSNYKZ@dell.com	6864429328	1	1702663618139922	2009/04	user19156	password	80	80000	M
19157	QYJHLM	XCMMVZLFZZ	7434431747 Dell Way	\N	YIWTLPE	\N	0	Australia	2	XCMMVZLFZZ@dell.com	7434431747	2	3913786247372627	2008/02	user19157	password	19	100000	M
19158	YEBKQY	NDLIDWNDWL	6755200741 Dell Way	\N	MSEXIJZ	\N	0	Australia	2	NDLIDWNDWL@dell.com	6755200741	2	1446362792979925	2011/05	user19158	password	80	60000	F
19159	APRRNF	VZNZWACSMO	8159891728 Dell Way	\N	LRMTAMU	\N	0	Japan	2	VZNZWACSMO@dell.com	8159891728	5	4969729105010629	2008/09	user19159	password	89	60000	M
19160	OCKCHF	BVEYWHRIWC	5655957541 Dell Way	\N	AIWAURS	\N	0	Japan	2	BVEYWHRIWC@dell.com	5655957541	1	7607396841514856	2009/02	user19160	password	29	100000	M
19161	GITOOV	KTTGALOWNO	5327162994 Dell Way	\N	FKPACIP	\N	0	Germany	2	KTTGALOWNO@dell.com	5327162994	2	8305492376908661	2011/07	user19161	password	72	40000	M
19162	CBIQXS	JRYKCNHQCM	5031458548 Dell Way	\N	ASMCACS	\N	0	Germany	2	JRYKCNHQCM@dell.com	5031458548	3	2145366813521832	2012/04	user19162	password	48	80000	F
19163	MBZJUJ	BTUDHBTJNU	1834422328 Dell Way	\N	CAWDCPQ	\N	0	Germany	2	BTUDHBTJNU@dell.com	1834422328	4	5558124382980168	2009/03	user19163	password	34	80000	M
19164	HRBBBC	VVFCWZLKTO	1550116136 Dell Way	\N	KQRNFHB	\N	0	China	2	VVFCWZLKTO@dell.com	1550116136	3	7018060736823828	2009/10	user19164	password	45	100000	F
19165	BZDDBY	YHBVHMFAAQ	7826178939 Dell Way	\N	RSDXZEF	\N	0	Australia	2	YHBVHMFAAQ@dell.com	7826178939	5	3724328836891800	2010/03	user19165	password	33	80000	F
19166	EULGTJ	NUFUHLVIBN	5249825382 Dell Way	\N	AEKAJPB	\N	0	Canada	2	NUFUHLVIBN@dell.com	5249825382	2	7184586257673801	2011/08	user19166	password	41	20000	M
19167	CLAWVO	QBJYMFGNSH	7755802535 Dell Way	\N	SCHCSJF	\N	0	Canada	2	QBJYMFGNSH@dell.com	7755802535	5	8942119334358723	2009/03	user19167	password	84	20000	F
19168	JDFESW	GBUSHBGZIZ	2895739109 Dell Way	\N	BQBTZHY	\N	0	Russia	2	GBUSHBGZIZ@dell.com	2895739109	5	1799393018707633	2010/09	user19168	password	33	80000	F
19169	JAGBWN	DQFLRMKZLM	9936992483 Dell Way	\N	PNGPVEI	\N	0	Australia	2	DQFLRMKZLM@dell.com	9936992483	3	5249765409622342	2011/08	user19169	password	37	80000	F
19170	GBCDOG	TURKGBKSOA	4681439672 Dell Way	\N	GUQBZZB	\N	0	UK	2	TURKGBKSOA@dell.com	4681439672	3	7045381302945317	2008/10	user19170	password	51	20000	F
19171	NEFCKY	WBJDDUWRVC	7714736574 Dell Way	\N	LLDKKFJ	\N	0	South Africa	2	WBJDDUWRVC@dell.com	7714736574	1	8919655611738563	2010/07	user19171	password	87	80000	F
19172	CVDNUZ	ODDRYZITCU	6708527027 Dell Way	\N	EFFPLPK	\N	0	Canada	2	ODDRYZITCU@dell.com	6708527027	2	7569351282436401	2008/04	user19172	password	44	20000	F
19173	FHWZHK	DLCBLLUNFZ	3782309105 Dell Way	\N	TLPEAAI	\N	0	Japan	2	DLCBLLUNFZ@dell.com	3782309105	1	8231526611838491	2010/06	user19173	password	89	100000	M
19174	HUPOES	ZHUKSPYYPR	3128300897 Dell Way	\N	JEVKEEB	\N	0	France	2	ZHUKSPYYPR@dell.com	3128300897	5	1484797205310314	2011/11	user19174	password	88	40000	F
19175	TXRYQR	FKCXAAWPSG	6006349492 Dell Way	\N	UNQYSSL	\N	0	UK	2	FKCXAAWPSG@dell.com	6006349492	3	6390812487807125	2009/06	user19175	password	83	60000	F
19176	UFEKWJ	VZHWZDLRJF	2345080115 Dell Way	\N	FAEXSQV	\N	0	Chile	2	VZHWZDLRJF@dell.com	2345080115	3	6943537709303201	2011/05	user19176	password	30	100000	F
19177	JAOGJK	FRGFVRXEXC	3713869944 Dell Way	\N	FCAXTWE	\N	0	South Africa	2	FRGFVRXEXC@dell.com	3713869944	5	5616087690927089	2011/01	user19177	password	44	80000	F
19178	JIQTSV	KYBGQYKNBQ	5816943873 Dell Way	\N	QCNJYSG	\N	0	Chile	2	KYBGQYKNBQ@dell.com	5816943873	4	8958586450666190	2010/02	user19178	password	65	100000	F
19179	YOGRKR	PLXFJITLYJ	7285233812 Dell Way	\N	NMSMEYS	\N	0	Russia	2	PLXFJITLYJ@dell.com	7285233812	4	3390598433557898	2012/04	user19179	password	31	40000	F
19180	TOWDFL	ODRYLKJKTX	7463211875 Dell Way	\N	XLJBKCU	\N	0	Canada	2	ODRYLKJKTX@dell.com	7463211875	1	9292962227016688	2012/04	user19180	password	34	20000	M
19181	UBCANR	DEPPPZAIWX	8584777243 Dell Way	\N	UGZFJUH	\N	0	Australia	2	DEPPPZAIWX@dell.com	8584777243	2	1603843670338392	2008/06	user19181	password	36	20000	F
19182	IEHVWL	ALAPKBYHYS	5183980629 Dell Way	\N	OXYYSGA	\N	0	Germany	2	ALAPKBYHYS@dell.com	5183980629	1	6711948159616441	2012/05	user19182	password	70	20000	M
19183	XLNTWN	EXDPYBXXUM	5750323572 Dell Way	\N	VSKNYLB	\N	0	France	2	EXDPYBXXUM@dell.com	5750323572	4	4129414809402078	2012/05	user19183	password	56	60000	F
19184	ZBBWOG	USWTTTQOFM	7601151129 Dell Way	\N	GQZFBBQ	\N	0	Germany	2	USWTTTQOFM@dell.com	7601151129	5	5244316816329956	2008/07	user19184	password	19	60000	F
19185	BNJQUD	IQWCKNQQZX	8045293987 Dell Way	\N	GYDIZUX	\N	0	Russia	2	IQWCKNQQZX@dell.com	8045293987	2	8767549592070282	2009/05	user19185	password	41	100000	F
19186	VEDQHM	GEPRRGHQDO	2983436695 Dell Way	\N	OHXOBVH	\N	0	South Africa	2	GEPRRGHQDO@dell.com	2983436695	1	2445678799413144	2011/06	user19186	password	88	20000	F
19187	DGYKTE	OIWGOEWSTL	4568287340 Dell Way	\N	ZQZBMGX	\N	0	Japan	2	OIWGOEWSTL@dell.com	4568287340	1	3919148942921311	2012/01	user19187	password	50	20000	F
19188	SCPLHD	TDJIHGAARZ	1403956192 Dell Way	\N	RQBDXZV	\N	0	China	2	TDJIHGAARZ@dell.com	1403956192	1	2422693969681859	2008/08	user19188	password	41	40000	F
19189	KVTRZN	VJVCPVDGVV	9690402017 Dell Way	\N	XXZVWUD	\N	0	UK	2	VJVCPVDGVV@dell.com	9690402017	2	9868104576133192	2010/08	user19189	password	34	100000	M
19190	BQRAEM	KZPZVTGROE	4443395701 Dell Way	\N	ONZKICH	\N	0	Chile	2	KZPZVTGROE@dell.com	4443395701	2	8813668290153147	2012/07	user19190	password	72	100000	M
19191	KQPODA	NSAJLGAALO	5961108408 Dell Way	\N	OKYWNGE	\N	0	UK	2	NSAJLGAALO@dell.com	5961108408	1	8916898145806045	2008/10	user19191	password	80	80000	F
19192	NGSQHG	JHPVNQVZEJ	5010241982 Dell Way	\N	JDGXKKU	\N	0	UK	2	JHPVNQVZEJ@dell.com	5010241982	4	1295362593606114	2009/07	user19192	password	67	60000	F
19193	YDRFKA	NAWAQRAVBJ	7852494481 Dell Way	\N	ZIHJSCI	\N	0	Canada	2	NAWAQRAVBJ@dell.com	7852494481	2	4632888504303992	2009/01	user19193	password	77	40000	F
19194	YAFJBT	JXTZPUVQDU	8964825591 Dell Way	\N	ZLERNNW	\N	0	Chile	2	JXTZPUVQDU@dell.com	8964825591	2	6111376750748605	2012/01	user19194	password	83	100000	F
19195	XEJYXT	VRTLLOBPJA	8599529179 Dell Way	\N	ANSOAPV	\N	0	UK	2	VRTLLOBPJA@dell.com	8599529179	2	8765472321771086	2012/04	user19195	password	77	100000	F
19196	ZIDXBZ	PVKAJMQSNR	4495753410 Dell Way	\N	GGFHVAF	\N	0	Japan	2	PVKAJMQSNR@dell.com	4495753410	1	6238503634463996	2011/11	user19196	password	57	100000	M
19197	WZUYZJ	TJKDWAWJRD	7273164110 Dell Way	\N	PWKKXQC	\N	0	Chile	2	TJKDWAWJRD@dell.com	7273164110	4	9537244052626194	2010/03	user19197	password	76	60000	F
19198	UGAUPU	EZXAAUKSXZ	2381138140 Dell Way	\N	PIKMYMT	\N	0	Japan	2	EZXAAUKSXZ@dell.com	2381138140	4	3064707393757999	2009/07	user19198	password	68	60000	F
19199	YLCNFG	NDHNXRFVRU	7441998154 Dell Way	\N	DBHCOAT	\N	0	Russia	2	NDHNXRFVRU@dell.com	7441998154	5	1628868307452649	2009/09	user19199	password	53	60000	M
19200	XQDDWQ	GDEEVJZMED	9795311133 Dell Way	\N	OLGCMZV	\N	0	Canada	2	GDEEVJZMED@dell.com	9795311133	5	4676602878607810	2011/05	user19200	password	86	40000	F
19201	OJLLZR	ODVJNVVSZK	2995304049 Dell Way	\N	EFMQFIV	\N	0	Canada	2	ODVJNVVSZK@dell.com	2995304049	2	8591322487685830	2011/03	user19201	password	23	100000	M
19202	LIDKAS	OWCCSYURIY	6722354091 Dell Way	\N	XVPDDKI	\N	0	China	2	OWCCSYURIY@dell.com	6722354091	1	9679224196821452	2012/03	user19202	password	81	60000	M
19203	FRCFJR	CMTUKNLSMJ	9594838783 Dell Way	\N	NBMRMUA	\N	0	Australia	2	CMTUKNLSMJ@dell.com	9594838783	5	9123087871819736	2008/11	user19203	password	49	100000	F
19204	CZHMQK	YJEJXQBJZP	3486202961 Dell Way	\N	KMGWHHZ	\N	0	Chile	2	YJEJXQBJZP@dell.com	3486202961	5	4797729677520693	2008/04	user19204	password	39	40000	F
19205	GNXXXV	GCEDTGMTVX	7001558814 Dell Way	\N	FCUMKUS	\N	0	Japan	2	GCEDTGMTVX@dell.com	7001558814	1	8242188979405911	2012/06	user19205	password	19	40000	M
19206	NHOLCV	OHYHNLAJJF	5832151177 Dell Way	\N	MESWYKN	\N	0	Japan	2	OHYHNLAJJF@dell.com	5832151177	2	6279867769218982	2012/05	user19206	password	89	80000	M
19207	GFIJBW	QZDDLENUKZ	7060470907 Dell Way	\N	ZCVXMJN	\N	0	Australia	2	QZDDLENUKZ@dell.com	7060470907	1	9964087161701174	2008/01	user19207	password	64	100000	F
19208	WFRXCH	XGLJKZEUYD	6766040076 Dell Way	\N	WUAJDOK	\N	0	South Africa	2	XGLJKZEUYD@dell.com	6766040076	3	8358389021363110	2011/01	user19208	password	69	20000	M
19209	YSVAAS	GMBRLGLJJI	5778179834 Dell Way	\N	EJSHXDC	\N	0	Germany	2	GMBRLGLJJI@dell.com	5778179834	5	3476950568612665	2010/08	user19209	password	40	60000	M
19210	AIOABV	MDNXJYHSHL	7700915294 Dell Way	\N	CZTADVO	\N	0	Japan	2	MDNXJYHSHL@dell.com	7700915294	5	3104885610751808	2009/02	user19210	password	71	100000	F
19211	BMFCIR	GVPPUXIBJK	8500677795 Dell Way	\N	BDKEYZV	\N	0	Russia	2	GVPPUXIBJK@dell.com	8500677795	1	1588564525358379	2012/10	user19211	password	89	20000	M
19212	MJZUBF	QRVKPDMZNO	6910167295 Dell Way	\N	CYTBYPT	\N	0	Russia	2	QRVKPDMZNO@dell.com	6910167295	5	7861172371078283	2010/10	user19212	password	85	40000	F
19213	HIBJNR	AJBQMOPACR	3456303372 Dell Way	\N	ZVSXKMR	\N	0	Australia	2	AJBQMOPACR@dell.com	3456303372	3	5775245812255890	2008/05	user19213	password	81	40000	M
19214	EJASAB	BCSNQHOSZN	5797301189 Dell Way	\N	ORKYDCA	\N	0	France	2	BCSNQHOSZN@dell.com	5797301189	3	5330138816963881	2012/05	user19214	password	76	60000	M
19215	EPHERJ	HJXXQLQPZE	7206814951 Dell Way	\N	HKDLMDW	\N	0	Australia	2	HJXXQLQPZE@dell.com	7206814951	2	9244776501320304	2008/02	user19215	password	53	80000	F
19216	CZMTJT	CGRTSHJRMR	3739442020 Dell Way	\N	BPCNSZO	\N	0	France	2	CGRTSHJRMR@dell.com	3739442020	3	5691797537263483	2010/12	user19216	password	33	80000	F
19217	FFTOZW	URQMYZEKQF	7620947407 Dell Way	\N	ZTSSSHD	\N	0	Australia	2	URQMYZEKQF@dell.com	7620947407	4	5014642711728811	2011/11	user19217	password	31	80000	F
19218	KMQKIL	BYYAYCLOHL	9718554236 Dell Way	\N	HAEZIHZ	\N	0	Australia	2	BYYAYCLOHL@dell.com	9718554236	3	7514984003733844	2012/08	user19218	password	49	100000	F
19219	XPMFBN	EZOCCZRKKY	4481674775 Dell Way	\N	LOYTWYU	\N	0	South Africa	2	EZOCCZRKKY@dell.com	4481674775	3	7157434892840684	2008/12	user19219	password	63	20000	M
19220	FOBGBF	GQIJPZTAYE	3089598800 Dell Way	\N	PXYLWSH	\N	0	Chile	2	GQIJPZTAYE@dell.com	3089598800	5	3287124970462173	2008/08	user19220	password	41	20000	M
19221	WBBYHI	OQREPKEOPT	5052596170 Dell Way	\N	MNFIGMO	\N	0	France	2	OQREPKEOPT@dell.com	5052596170	5	6828463449142874	2008/02	user19221	password	65	100000	M
19222	SXYZFM	QWRFHWUWQG	9237681832 Dell Way	\N	KVOQICD	\N	0	Russia	2	QWRFHWUWQG@dell.com	9237681832	4	8374916738830508	2008/06	user19222	password	66	20000	F
19223	OZDUMT	QDZYATUQAF	7684392031 Dell Way	\N	MPWVRZP	\N	0	Japan	2	QDZYATUQAF@dell.com	7684392031	3	6853622138034553	2008/01	user19223	password	68	40000	M
19224	RKKDEB	GDZHXTXXZJ	2700692365 Dell Way	\N	MVEEUUU	\N	0	Germany	2	GDZHXTXXZJ@dell.com	2700692365	3	7273532030172647	2009/02	user19224	password	90	100000	M
19225	KHXOIE	SHLPBIMASY	3924832916 Dell Way	\N	WXDQRXE	\N	0	South Africa	2	SHLPBIMASY@dell.com	3924832916	5	2243620844557881	2010/11	user19225	password	19	40000	F
19226	HCVQHN	XSCZBPAUNW	5788891554 Dell Way	\N	SRMKORH	\N	0	South Africa	2	XSCZBPAUNW@dell.com	5788891554	3	3916153795551509	2009/06	user19226	password	57	80000	M
19227	QMJYAH	QCHSRHNFDF	3555274860 Dell Way	\N	WQPLHWI	\N	0	South Africa	2	QCHSRHNFDF@dell.com	3555274860	4	2883421265985817	2011/03	user19227	password	80	60000	M
19228	IVTIDK	LKCDRPJVVF	6765348263 Dell Way	\N	LKRTHZO	\N	0	Germany	2	LKCDRPJVVF@dell.com	6765348263	4	3557513360865414	2012/08	user19228	password	72	80000	M
19229	PKISUT	DXXUNGQILB	1995591218 Dell Way	\N	TDUACJP	\N	0	Russia	2	DXXUNGQILB@dell.com	1995591218	5	6214534576516599	2011/08	user19229	password	35	80000	F
19230	QAXLTB	JQVXWMGIOZ	5359095702 Dell Way	\N	LIAORPI	\N	0	Russia	2	JQVXWMGIOZ@dell.com	5359095702	5	5792640754953027	2008/02	user19230	password	34	40000	M
19231	GGGAHP	QDMNPSWDSI	2349392679 Dell Way	\N	MSXEIGY	\N	0	South Africa	2	QDMNPSWDSI@dell.com	2349392679	3	9310905450955034	2009/09	user19231	password	35	20000	M
19232	MIZTXQ	WKDMDAPVJB	7096954998 Dell Way	\N	OGFXNES	\N	0	Japan	2	WKDMDAPVJB@dell.com	7096954998	4	9570576421450824	2009/11	user19232	password	20	40000	F
19233	IICGYZ	RCLUDBQMDF	5070040440 Dell Way	\N	TJCGNVX	\N	0	Chile	2	RCLUDBQMDF@dell.com	5070040440	5	6521909564733506	2009/11	user19233	password	89	80000	F
19234	HUMGUD	IFYLHOYKUR	7531674577 Dell Way	\N	TWYHSWM	\N	0	Canada	2	IFYLHOYKUR@dell.com	7531674577	1	5287525699008256	2011/01	user19234	password	29	100000	F
19235	YJQSNY	YLKFAIPUAI	3103510362 Dell Way	\N	RZQJVDN	\N	0	Germany	2	YLKFAIPUAI@dell.com	3103510362	5	2536976844072342	2009/02	user19235	password	20	80000	F
19236	KIVXHT	IRYJAOEBXV	7503960300 Dell Way	\N	ANFVQSJ	\N	0	South Africa	2	IRYJAOEBXV@dell.com	7503960300	3	2829442601650953	2012/08	user19236	password	83	100000	M
19237	FUWMNF	EMOFBSGYOG	1240641753 Dell Way	\N	MTCDMMA	\N	0	Chile	2	EMOFBSGYOG@dell.com	1240641753	2	1818493008147925	2011/02	user19237	password	22	60000	F
19238	WMVKRA	WGFXZLWOSI	7245800524 Dell Way	\N	HVMUHMA	\N	0	China	2	WGFXZLWOSI@dell.com	7245800524	1	9337554463185372	2012/03	user19238	password	55	20000	F
19239	ZZKRZH	XEFXQBLIKT	6754437212 Dell Way	\N	EWNLJNT	\N	0	Australia	2	XEFXQBLIKT@dell.com	6754437212	4	8758523468393833	2012/03	user19239	password	18	100000	F
19240	ZGVYNT	DTQTVBCFUG	2322757292 Dell Way	\N	CISMWMN	\N	0	France	2	DTQTVBCFUG@dell.com	2322757292	2	3666594866197556	2009/05	user19240	password	27	60000	F
19241	JJIXCM	QSGLUIROPU	2281767258 Dell Way	\N	WIGSUTF	\N	0	UK	2	QSGLUIROPU@dell.com	2281767258	3	3477253616321832	2010/08	user19241	password	76	100000	F
19242	EFXGRN	ZXZTGRIWLF	7021872034 Dell Way	\N	FSYZLEX	\N	0	Japan	2	ZXZTGRIWLF@dell.com	7021872034	1	2182262295857072	2009/12	user19242	password	20	40000	F
19243	GFKYTJ	WTDDKMAWSF	3391984196 Dell Way	\N	OQEAUCP	\N	0	France	2	WTDDKMAWSF@dell.com	3391984196	4	7942948389332742	2009/10	user19243	password	24	40000	F
19244	HUZBEV	UIZEUZBMEP	9389692440 Dell Way	\N	DJPYLFK	\N	0	Russia	2	UIZEUZBMEP@dell.com	9389692440	1	9562528419774028	2011/03	user19244	password	42	80000	M
19245	CRPHNK	PMPKLQWQFA	5473574373 Dell Way	\N	ZUYLZID	\N	0	UK	2	PMPKLQWQFA@dell.com	5473574373	1	6553585137240589	2011/06	user19245	password	42	40000	M
19246	AXVOHK	AWUMMRDRRD	8036068332 Dell Way	\N	MQOMYSJ	\N	0	France	2	AWUMMRDRRD@dell.com	8036068332	5	2775762245059013	2009/05	user19246	password	53	80000	F
19247	JOXRYY	NTLAKOSCRE	1238143460 Dell Way	\N	SGQRYAD	\N	0	Russia	2	NTLAKOSCRE@dell.com	1238143460	2	9236773736774922	2009/10	user19247	password	66	80000	F
19248	FQWEOJ	YZKIOCLGHD	3191770868 Dell Way	\N	MXUKYYC	\N	0	UK	2	YZKIOCLGHD@dell.com	3191770868	1	4007697974797338	2008/09	user19248	password	22	40000	M
19249	SCCGMA	GWIVZTBGXN	1511384095 Dell Way	\N	ESYCQAB	\N	0	South Africa	2	GWIVZTBGXN@dell.com	1511384095	3	9347642004024238	2011/06	user19249	password	30	80000	F
19250	GSKTSR	QBMPVOVSCZ	6089819878 Dell Way	\N	LACBAEY	\N	0	Australia	2	QBMPVOVSCZ@dell.com	6089819878	5	8512808576226235	2008/01	user19250	password	52	20000	F
19251	FPBXHR	ZUGUJBNLBY	8258219138 Dell Way	\N	LDAMHYO	\N	0	South Africa	2	ZUGUJBNLBY@dell.com	8258219138	2	9074834696948528	2012/11	user19251	password	24	20000	F
19252	SEZZVZ	UCTDDHOFFZ	4908948698 Dell Way	\N	IFMQEAN	\N	0	UK	2	UCTDDHOFFZ@dell.com	4908948698	3	8311501845251770	2009/06	user19252	password	87	40000	F
19253	DJEZIZ	BCDFJRKPRT	3625593185 Dell Way	\N	VEJZEXY	\N	0	Japan	2	BCDFJRKPRT@dell.com	3625593185	4	9423479506745936	2011/09	user19253	password	41	100000	M
19254	REUADW	CHBMZLBQEX	6223309670 Dell Way	\N	VOWZLVQ	\N	0	Russia	2	CHBMZLBQEX@dell.com	6223309670	3	5695175989065320	2009/11	user19254	password	54	20000	M
19255	RYPVUS	CVEBHGSLDN	7383775309 Dell Way	\N	AANLVDF	\N	0	France	2	CVEBHGSLDN@dell.com	7383775309	4	7257027945481241	2010/03	user19255	password	78	20000	M
19256	UTSOLV	KQWSWPDADE	5933964692 Dell Way	\N	AQQWUVG	\N	0	France	2	KQWSWPDADE@dell.com	5933964692	5	1761600400321185	2011/10	user19256	password	35	80000	M
19257	ZJDKFO	BCGYRKYUOZ	1123616722 Dell Way	\N	LEVFABS	\N	0	Germany	2	BCGYRKYUOZ@dell.com	1123616722	4	3976365180220455	2011/01	user19257	password	90	40000	F
19258	JMLOAM	QGKIQJCEJO	3486699903 Dell Way	\N	JETJGMY	\N	0	Chile	2	QGKIQJCEJO@dell.com	3486699903	2	1405163475777953	2009/04	user19258	password	46	40000	M
19259	WUFWGW	CRESBHXKVG	8438101746 Dell Way	\N	OPQVBOB	\N	0	China	2	CRESBHXKVG@dell.com	8438101746	1	6996292213443667	2008/06	user19259	password	90	80000	F
19260	UXFAUH	SYZTGWDBDS	7259929408 Dell Way	\N	RTNTIPC	\N	0	Canada	2	SYZTGWDBDS@dell.com	7259929408	4	3043327241670340	2008/10	user19260	password	87	60000	M
19261	WTOQAH	PAAVXEXAXP	2832060102 Dell Way	\N	UKICZLG	\N	0	Japan	2	PAAVXEXAXP@dell.com	2832060102	3	8897630065679551	2012/05	user19261	password	48	60000	F
19262	DBXEIN	EJIBOGCLVW	7146126351 Dell Way	\N	VEZVPFN	\N	0	South Africa	2	EJIBOGCLVW@dell.com	7146126351	2	7996190669946373	2008/10	user19262	password	38	40000	M
19263	JHCSUH	BDJPKLAGIW	6369269995 Dell Way	\N	KISANFV	\N	0	Chile	2	BDJPKLAGIW@dell.com	6369269995	3	3769264039583504	2009/11	user19263	password	67	40000	F
19264	ZLYUTA	YCQINRPWNZ	4788384802 Dell Way	\N	EFASLVY	\N	0	Australia	2	YCQINRPWNZ@dell.com	4788384802	2	4832648216746748	2009/11	user19264	password	74	60000	M
19265	FMRYMP	ACYOTNLHNQ	5452248993 Dell Way	\N	NNIYIGZ	\N	0	Russia	2	ACYOTNLHNQ@dell.com	5452248993	2	1477490943390876	2010/03	user19265	password	61	40000	F
19266	BZIOOJ	RNYKAJSNZF	5831443920 Dell Way	\N	AIEJPDC	\N	0	Australia	2	RNYKAJSNZF@dell.com	5831443920	1	5474169778171927	2011/10	user19266	password	76	20000	M
19267	TLKIUB	VTMWDEJDKK	1355430094 Dell Way	\N	LOTBSWD	\N	0	Chile	2	VTMWDEJDKK@dell.com	1355430094	4	9577115131542088	2011/06	user19267	password	21	80000	F
19268	MANGBI	ANFDSOGDZR	5338272619 Dell Way	\N	RTSKQWR	\N	0	Japan	2	ANFDSOGDZR@dell.com	5338272619	4	5108345088548959	2012/08	user19268	password	23	20000	F
19269	CPKDYK	RDNKSTNRLF	8859921974 Dell Way	\N	LEPBAGS	\N	0	France	2	RDNKSTNRLF@dell.com	8859921974	1	4589717470109463	2010/03	user19269	password	53	80000	F
19270	CAMAKE	EYPWRCOCHZ	9113142400 Dell Way	\N	GXAHETU	\N	0	Australia	2	EYPWRCOCHZ@dell.com	9113142400	1	6195209369529039	2008/08	user19270	password	33	60000	M
19271	GZTREX	PTUGVIJDHQ	8492726152 Dell Way	\N	BIXGBRH	\N	0	UK	2	PTUGVIJDHQ@dell.com	8492726152	5	2061335170641541	2010/02	user19271	password	62	40000	F
19272	PZZTXO	NRVIAFMIVN	9242987581 Dell Way	\N	QSTSJBR	\N	0	Chile	2	NRVIAFMIVN@dell.com	9242987581	4	7244726823642851	2008/05	user19272	password	84	40000	M
19273	XITUXG	MTPMYBUTPL	6467295606 Dell Way	\N	LJDVKVA	\N	0	China	2	MTPMYBUTPL@dell.com	6467295606	4	3941840552724898	2008/08	user19273	password	65	20000	M
19274	ZTIWAU	PQGNRBHHMS	3926018801 Dell Way	\N	QPOBKPJ	\N	0	Australia	2	PQGNRBHHMS@dell.com	3926018801	4	1329218429047614	2012/05	user19274	password	21	60000	F
19275	VVFVQV	LXJDZQLLJB	3033745703 Dell Way	\N	BXDLNNM	\N	0	South Africa	2	LXJDZQLLJB@dell.com	3033745703	3	8205687035806478	2010/07	user19275	password	40	100000	F
19276	EEFUZR	SIVRYGCIID	6481238575 Dell Way	\N	FLPSYCO	\N	0	Canada	2	SIVRYGCIID@dell.com	6481238575	2	7978884529322387	2008/08	user19276	password	70	60000	M
19277	WTQVLI	EGADMDLUHQ	3513726793 Dell Way	\N	FWJEZYJ	\N	0	Germany	2	EGADMDLUHQ@dell.com	3513726793	1	7751394476275892	2012/11	user19277	password	40	80000	M
19278	BKONST	TTWFWHADYG	9493462099 Dell Way	\N	AILZGUO	\N	0	Germany	2	TTWFWHADYG@dell.com	9493462099	2	5350118239875883	2012/08	user19278	password	36	60000	M
19279	QCEJVX	DSDZZECYKC	9409537174 Dell Way	\N	HVCOQQC	\N	0	Germany	2	DSDZZECYKC@dell.com	9409537174	3	4434561539907009	2010/10	user19279	password	84	40000	F
19280	ZJVVHY	NLYNPBMADT	9713649624 Dell Way	\N	WGIMWKB	\N	0	South Africa	2	NLYNPBMADT@dell.com	9713649624	3	4104021205101162	2011/05	user19280	password	58	40000	F
19281	YCEGBS	RZGHASIEME	2632734216 Dell Way	\N	KURHFSC	\N	0	Canada	2	RZGHASIEME@dell.com	2632734216	3	9594771132804454	2010/12	user19281	password	33	100000	M
19282	HCEJUW	IADJTLNFPY	7892242833 Dell Way	\N	AGFFZIK	\N	0	Canada	2	IADJTLNFPY@dell.com	7892242833	2	7466586014721543	2011/07	user19282	password	63	80000	M
19283	SWFMSO	NVXHHLMXJN	5466109341 Dell Way	\N	EPTEYDI	\N	0	Japan	2	NVXHHLMXJN@dell.com	5466109341	1	5060021065641195	2008/09	user19283	password	27	100000	F
19284	ZDWRRK	NORUAESJRW	4789330985 Dell Way	\N	ZLAXPJP	\N	0	Australia	2	NORUAESJRW@dell.com	4789330985	1	2281056033447385	2008/03	user19284	password	21	60000	F
19285	EIVWTJ	KKDKOVUGST	3741893433 Dell Way	\N	SSRHCGJ	\N	0	Germany	2	KKDKOVUGST@dell.com	3741893433	3	6444044119212777	2010/07	user19285	password	23	80000	M
19286	KMPDVA	OZLCVFJNZB	3123575025 Dell Way	\N	GRIJXSW	\N	0	Chile	2	OZLCVFJNZB@dell.com	3123575025	3	7362299448344857	2012/07	user19286	password	44	60000	M
19287	WECRER	RPTNVDBVEH	9700135968 Dell Way	\N	MNQKFNQ	\N	0	France	2	RPTNVDBVEH@dell.com	9700135968	2	3475725352298468	2010/09	user19287	password	79	60000	M
19288	ZOFEFX	UZKQCMLHUY	3755333157 Dell Way	\N	UKJAYZM	\N	0	South Africa	2	UZKQCMLHUY@dell.com	3755333157	4	4586733671836555	2012/08	user19288	password	80	60000	M
19289	KTTQRO	PCESOQZIPT	1131420798 Dell Way	\N	TYURXGO	\N	0	Chile	2	PCESOQZIPT@dell.com	1131420798	5	2972452927846461	2011/10	user19289	password	72	20000	F
19290	NZWENM	GSFUJECYYW	1434446077 Dell Way	\N	XTNVZCA	\N	0	Australia	2	GSFUJECYYW@dell.com	1434446077	2	6506287767551840	2012/01	user19290	password	76	20000	M
19291	UZRHLY	ZQSJVVHURF	3783855499 Dell Way	\N	NFANHBN	\N	0	China	2	ZQSJVVHURF@dell.com	3783855499	1	2911187196150422	2009/12	user19291	password	40	100000	M
19292	HNZTLZ	KEIFZQARVN	6902109620 Dell Way	\N	XWAFXNO	\N	0	Chile	2	KEIFZQARVN@dell.com	6902109620	4	5828142724931241	2010/01	user19292	password	44	40000	F
19293	WHCHGM	LPSLGSDCGA	5704952703 Dell Way	\N	YGFWUUC	\N	0	France	2	LPSLGSDCGA@dell.com	5704952703	4	1374961852561682	2010/12	user19293	password	41	100000	M
19294	PBEWNP	LGBSZFUFGS	3565789103 Dell Way	\N	MMPHGRT	\N	0	Russia	2	LGBSZFUFGS@dell.com	3565789103	4	4206274187657982	2009/02	user19294	password	39	20000	M
19295	IHOWWA	CYSCEMHKFT	6071347241 Dell Way	\N	WUBDMUX	\N	0	Russia	2	CYSCEMHKFT@dell.com	6071347241	2	1111841695383191	2011/07	user19295	password	27	40000	M
19296	KXTHXW	GPYKCFUHZR	9509309562 Dell Way	\N	CBVOVSH	\N	0	China	2	GPYKCFUHZR@dell.com	9509309562	2	1562888807151466	2010/06	user19296	password	49	40000	M
19297	IDCGZJ	WYTYEOGEGI	5256252914 Dell Way	\N	FBWATEL	\N	0	Japan	2	WYTYEOGEGI@dell.com	5256252914	3	2616063972935080	2012/12	user19297	password	58	80000	F
19298	RWNRFK	PYJTMPXSYD	1794430584 Dell Way	\N	UVENZPF	\N	0	France	2	PYJTMPXSYD@dell.com	1794430584	2	4206867659930140	2008/12	user19298	password	24	40000	M
19299	YVHDFX	COQOEOHCRB	2441763511 Dell Way	\N	XVPXLUI	\N	0	Germany	2	COQOEOHCRB@dell.com	2441763511	4	5773860053159297	2008/10	user19299	password	77	80000	M
19300	QAWVXY	KNNOCVRUWP	5588201832 Dell Way	\N	PLMBGVO	\N	0	China	2	KNNOCVRUWP@dell.com	5588201832	1	5411194724962116	2009/11	user19300	password	32	20000	M
19301	FXICVT	QJHSEZMBOC	8061928381 Dell Way	\N	MADSVSD	\N	0	China	2	QJHSEZMBOC@dell.com	8061928381	4	6774920392315835	2011/10	user19301	password	67	40000	F
19302	OODKHT	TPLYOYZCBM	9336292831 Dell Way	\N	DEEYXIH	\N	0	Japan	2	TPLYOYZCBM@dell.com	9336292831	5	4175285013392568	2011/08	user19302	password	58	80000	F
19303	CWPKQJ	ZCHNAGQCST	9704969815 Dell Way	\N	HXSEGAV	\N	0	Canada	2	ZCHNAGQCST@dell.com	9704969815	1	9105652390047908	2010/09	user19303	password	66	80000	M
19304	OJFESF	GASHHJJZDQ	8063060571 Dell Way	\N	XWUDWPH	\N	0	South Africa	2	GASHHJJZDQ@dell.com	8063060571	2	4867964179720730	2010/11	user19304	password	32	40000	F
19305	OOPHTV	HMCOWMOZCM	2273625790 Dell Way	\N	VWQSMYO	\N	0	Chile	2	HMCOWMOZCM@dell.com	2273625790	5	8111452445853502	2008/03	user19305	password	27	60000	M
19306	SAALVH	YYWUKLTNXP	8887353047 Dell Way	\N	KNIXLWE	\N	0	Germany	2	YYWUKLTNXP@dell.com	8887353047	5	6528849348891527	2008/02	user19306	password	21	100000	M
19307	BVGXDE	WZZHKTUIJE	2800583667 Dell Way	\N	VRCHOGX	\N	0	France	2	WZZHKTUIJE@dell.com	2800583667	3	5415103650651872	2009/07	user19307	password	39	20000	M
19308	DINGNJ	GNQRGLZPQV	5965441986 Dell Way	\N	GSDVYAG	\N	0	Canada	2	GNQRGLZPQV@dell.com	5965441986	4	5044200458098203	2008/01	user19308	password	56	80000	F
19309	WGKKQR	XHIDSITJEA	8306209842 Dell Way	\N	BHVAICE	\N	0	South Africa	2	XHIDSITJEA@dell.com	8306209842	4	9908180307596924	2012/02	user19309	password	70	20000	F
19310	ZKLPCI	XKMQTGZXGB	8932276649 Dell Way	\N	ECBNEGJ	\N	0	UK	2	XKMQTGZXGB@dell.com	8932276649	2	8407959621865303	2008/02	user19310	password	78	20000	F
19311	GNSIVP	TIFMOEJUFO	8327426635 Dell Way	\N	WHBBOLA	\N	0	France	2	TIFMOEJUFO@dell.com	8327426635	5	5206093401648104	2012/09	user19311	password	57	100000	M
19312	BRGXHZ	FMLTRUOXJL	4255529498 Dell Way	\N	EKMSVND	\N	0	Japan	2	FMLTRUOXJL@dell.com	4255529498	4	6138025209773332	2008/02	user19312	password	59	100000	F
19313	GECNEH	ZPBRKPOTAS	2549067781 Dell Way	\N	DMLZZOQ	\N	0	China	2	ZPBRKPOTAS@dell.com	2549067781	2	4543727790471167	2009/10	user19313	password	43	60000	F
19314	OQOSXO	HZFROTKOMO	4741937978 Dell Way	\N	BXOAMFK	\N	0	Japan	2	HZFROTKOMO@dell.com	4741937978	4	9650021646171808	2008/02	user19314	password	53	40000	M
19315	CTJAHQ	ZNIOGTCSHD	4085103258 Dell Way	\N	PVEBBOS	\N	0	France	2	ZNIOGTCSHD@dell.com	4085103258	4	6879006421659142	2010/02	user19315	password	81	20000	F
19316	QNHYDH	LMVRFYKNCZ	5012079303 Dell Way	\N	JGBKVUV	\N	0	Canada	2	LMVRFYKNCZ@dell.com	5012079303	3	6704466594383121	2011/05	user19316	password	74	100000	F
19317	HEYLMK	XICCGMPIMY	7181649087 Dell Way	\N	POIKIEO	\N	0	Russia	2	XICCGMPIMY@dell.com	7181649087	2	4339847756549716	2008/12	user19317	password	35	20000	F
19318	LASXLP	FNSMZIVMHK	6458309690 Dell Way	\N	AQVIVKC	\N	0	Germany	2	FNSMZIVMHK@dell.com	6458309690	3	6038057234603912	2010/09	user19318	password	64	100000	F
19319	ROBCDG	PWTPEOBMYB	9849688617 Dell Way	\N	CUKXENK	\N	0	Russia	2	PWTPEOBMYB@dell.com	9849688617	5	4438822694122791	2011/08	user19319	password	35	100000	F
19320	UXIYDY	UXNZLOLKQO	8210545949 Dell Way	\N	EBLJOVE	\N	0	Germany	2	UXNZLOLKQO@dell.com	8210545949	3	3190163856372237	2009/10	user19320	password	24	80000	M
19321	ZZNDXI	AKILZTVQIA	1865445035 Dell Way	\N	RTKFPOT	\N	0	China	2	AKILZTVQIA@dell.com	1865445035	1	8044311494566501	2012/02	user19321	password	48	60000	F
19322	KZFHHF	SPRRJNHROZ	9563942367 Dell Way	\N	KYEAMYK	\N	0	Germany	2	SPRRJNHROZ@dell.com	9563942367	1	5151799686718732	2008/08	user19322	password	84	20000	F
19323	WIHEOA	TFRDSZUGYF	8349962291 Dell Way	\N	EDGRBQG	\N	0	Australia	2	TFRDSZUGYF@dell.com	8349962291	4	1660346004180610	2010/08	user19323	password	32	60000	M
19324	NSRBTK	GKNZKIGIOL	1886988567 Dell Way	\N	MUCOKJO	\N	0	Chile	2	GKNZKIGIOL@dell.com	1886988567	4	6920787635724992	2011/11	user19324	password	24	40000	F
19325	VXKOIR	ZWRJEXSTIE	9593000397 Dell Way	\N	NLTYVHE	\N	0	UK	2	ZWRJEXSTIE@dell.com	9593000397	5	6781754572875798	2011/11	user19325	password	82	20000	M
19326	UPHCGG	YYQDVIWENJ	3849791456 Dell Way	\N	PGIKOMI	\N	0	Germany	2	YYQDVIWENJ@dell.com	3849791456	5	3725882795639336	2009/11	user19326	password	51	100000	M
19327	BGSHNR	GDUBLQGYAW	6048881984 Dell Way	\N	FJGTVPG	\N	0	Canada	2	GDUBLQGYAW@dell.com	6048881984	3	4495305971708149	2010/01	user19327	password	43	20000	F
19328	PTJCKP	FFRRWXQWTV	4757811219 Dell Way	\N	GAPBQWF	\N	0	Canada	2	FFRRWXQWTV@dell.com	4757811219	4	6288853060454131	2010/12	user19328	password	63	60000	M
19329	JWRUMX	AEOWBFTVBZ	8923867631 Dell Way	\N	WQAMMGQ	\N	0	UK	2	AEOWBFTVBZ@dell.com	8923867631	2	4125857512932271	2012/11	user19329	password	80	60000	F
19330	TCBFZB	JOXLUQGVPD	5264075112 Dell Way	\N	LQPYXGV	\N	0	Russia	2	JOXLUQGVPD@dell.com	5264075112	1	6725325895007700	2009/01	user19330	password	22	60000	M
19331	EQZERJ	SOUNFBIVEU	7681739314 Dell Way	\N	LTSJAOD	\N	0	France	2	SOUNFBIVEU@dell.com	7681739314	4	8334739272017033	2011/11	user19331	password	46	60000	F
19332	AOERXX	GSKMTSHYMT	1425924444 Dell Way	\N	SFCSTGE	\N	0	France	2	GSKMTSHYMT@dell.com	1425924444	5	3575861288234592	2012/05	user19332	password	79	100000	F
19333	KBCHYJ	ZIVTBDROXJ	3103705740 Dell Way	\N	TABNGGA	\N	0	China	2	ZIVTBDROXJ@dell.com	3103705740	2	2839468275662511	2011/02	user19333	password	25	20000	M
19334	DDWCMV	LIPMMGBJQU	6698669024 Dell Way	\N	JRIQXIY	\N	0	Canada	2	LIPMMGBJQU@dell.com	6698669024	1	7966992846690119	2011/04	user19334	password	76	40000	F
19335	YEMLAY	TPLGWMPMHZ	7476483173 Dell Way	\N	EPPCYOF	\N	0	Germany	2	TPLGWMPMHZ@dell.com	7476483173	1	4151103063486517	2012/10	user19335	password	67	40000	M
19336	WWEWUY	MGEISUVZTZ	3673081398 Dell Way	\N	PJBNYHC	\N	0	Japan	2	MGEISUVZTZ@dell.com	3673081398	3	6641340637579561	2008/02	user19336	password	18	100000	M
19337	WAWRYI	XCRQWNPQMF	3426752959 Dell Way	\N	AOSYWVP	\N	0	Canada	2	XCRQWNPQMF@dell.com	3426752959	2	3310532440897077	2009/03	user19337	password	25	40000	F
19338	CFUBOR	DGHATXRGCR	4990733161 Dell Way	\N	VVQRRFV	\N	0	UK	2	DGHATXRGCR@dell.com	4990733161	1	3913092435337603	2011/03	user19338	password	68	80000	F
19339	YOIMFM	TNNNLEUOWP	3034804614 Dell Way	\N	KMHBSDZ	\N	0	Canada	2	TNNNLEUOWP@dell.com	3034804614	2	8310566843952984	2010/12	user19339	password	60	80000	M
19340	DBLJOE	XBSIGMWDCG	6214175491 Dell Way	\N	PKHHNHL	\N	0	Russia	2	XBSIGMWDCG@dell.com	6214175491	2	2578812896739691	2010/11	user19340	password	83	60000	M
19341	YYINCF	OUNVHKYKRO	6013224048 Dell Way	\N	UZWIGHB	\N	0	South Africa	2	OUNVHKYKRO@dell.com	6013224048	2	4787180268671364	2009/02	user19341	password	85	40000	F
19342	WRPYXE	TLABVZLNNF	8667826720 Dell Way	\N	MKNTRPP	\N	0	Chile	2	TLABVZLNNF@dell.com	8667826720	1	6740536735858769	2012/12	user19342	password	90	20000	M
19343	RRTOWN	ZWOVWZIJEV	3239070761 Dell Way	\N	TSPLIFR	\N	0	Canada	2	ZWOVWZIJEV@dell.com	3239070761	2	2484244694467634	2009/04	user19343	password	36	20000	M
19344	YTOVGO	SUJOUSXYOR	2328340985 Dell Way	\N	REDZJVE	\N	0	Japan	2	SUJOUSXYOR@dell.com	2328340985	2	8417339839041234	2010/07	user19344	password	78	60000	M
19345	PAIVPB	QYPKRNJFEA	5588839322 Dell Way	\N	JIATDEJ	\N	0	Chile	2	QYPKRNJFEA@dell.com	5588839322	1	7753406028263272	2008/01	user19345	password	34	80000	M
19346	GYLVZB	UPMLCVQHWA	3627446940 Dell Way	\N	PWTSBCZ	\N	0	Germany	2	UPMLCVQHWA@dell.com	3627446940	4	6987891614437104	2009/12	user19346	password	38	100000	F
19347	GIBGJV	VVGXRXENXU	2962389070 Dell Way	\N	KRMMUMB	\N	0	Australia	2	VVGXRXENXU@dell.com	2962389070	4	4309910154901445	2008/12	user19347	password	37	40000	F
19348	PLMYHI	UNFMLKAJEK	6782526705 Dell Way	\N	ARWUDYW	\N	0	China	2	UNFMLKAJEK@dell.com	6782526705	2	5919682315085084	2011/06	user19348	password	86	100000	F
19349	KJARRV	EXHQIHZNSA	8911544758 Dell Way	\N	EPUINQS	\N	0	Canada	2	EXHQIHZNSA@dell.com	8911544758	2	8267863859422506	2009/03	user19349	password	68	60000	M
19350	BLGTHL	QPBZXBNPBR	9790318637 Dell Way	\N	FVASMSX	\N	0	China	2	QPBZXBNPBR@dell.com	9790318637	4	7654497056268156	2008/05	user19350	password	30	80000	F
19351	QZEXLV	NMVKNIAPAF	5817138073 Dell Way	\N	KBYXUVH	\N	0	Russia	2	NMVKNIAPAF@dell.com	5817138073	1	9267741160001608	2012/03	user19351	password	66	40000	M
19352	ROTCKG	PFQCOQROWC	3984328889 Dell Way	\N	PUAJQHD	\N	0	Canada	2	PFQCOQROWC@dell.com	3984328889	1	1786443581804633	2010/09	user19352	password	51	40000	F
19353	ACMLJB	RZEFQWUNYJ	9485576781 Dell Way	\N	HZTYHXC	\N	0	Japan	2	RZEFQWUNYJ@dell.com	9485576781	1	2294665025547147	2011/08	user19353	password	54	20000	M
19354	PNCYPT	YTYPPSCOCK	6422962622 Dell Way	\N	NWIVTLL	\N	0	Russia	2	YTYPPSCOCK@dell.com	6422962622	3	4271868950221688	2009/01	user19354	password	48	100000	M
19355	YZQNTP	GSEWKHKNSY	8074626529 Dell Way	\N	KBUDMFW	\N	0	Australia	2	GSEWKHKNSY@dell.com	8074626529	2	3848173048812896	2012/08	user19355	password	34	60000	M
19356	FECZTI	RYFCFQPYPA	2862419561 Dell Way	\N	ZJDLOZN	\N	0	China	2	RYFCFQPYPA@dell.com	2862419561	5	2988665079232305	2012/01	user19356	password	73	40000	F
19357	YMGRVX	QAAWQQUFQT	6066962927 Dell Way	\N	PUFETSN	\N	0	UK	2	QAAWQQUFQT@dell.com	6066962927	4	8234606684651227	2011/07	user19357	password	32	100000	F
19358	REDMBT	MCPDSJJIDY	4307239978 Dell Way	\N	CICWBQV	\N	0	Japan	2	MCPDSJJIDY@dell.com	4307239978	4	3081275931093842	2012/10	user19358	password	28	40000	F
19359	HLYJEL	LUODEXLHWO	8774843314 Dell Way	\N	PZKQPFG	\N	0	UK	2	LUODEXLHWO@dell.com	8774843314	3	8511119903530926	2011/08	user19359	password	28	20000	M
19360	PDHUOS	ODWSBIZXWP	9603970640 Dell Way	\N	WGFMMML	\N	0	China	2	ODWSBIZXWP@dell.com	9603970640	2	1467248249333351	2010/06	user19360	password	34	60000	F
19361	JTUYMI	BJACRAAOPX	1668646225 Dell Way	\N	VVJIIUR	\N	0	Chile	2	BJACRAAOPX@dell.com	1668646225	4	8634528608527035	2010/12	user19361	password	42	60000	F
19362	CGGPPH	YQKQRKEGHZ	7263974539 Dell Way	\N	CRHLMZS	\N	0	Germany	2	YQKQRKEGHZ@dell.com	7263974539	3	1360531073529273	2011/11	user19362	password	56	100000	M
19363	UFPKMN	AXERIIYQIB	7559699738 Dell Way	\N	HQMTPEI	\N	0	Chile	2	AXERIIYQIB@dell.com	7559699738	2	9448500321712346	2011/11	user19363	password	83	80000	M
19364	CEBPSC	MWTUFRLNTS	2355305852 Dell Way	\N	DFMTKUA	\N	0	Canada	2	MWTUFRLNTS@dell.com	2355305852	5	7594736580271275	2008/11	user19364	password	42	80000	M
19365	NUOGWB	CQWIIHVBAZ	7843115450 Dell Way	\N	GMTQHUT	\N	0	France	2	CQWIIHVBAZ@dell.com	7843115450	3	5301862508524209	2011/10	user19365	password	32	80000	F
19366	ZEPWGR	MDAUKWVLVC	9993040782 Dell Way	\N	XPTFJNQ	\N	0	Canada	2	MDAUKWVLVC@dell.com	9993040782	1	7948382951319218	2012/04	user19366	password	46	20000	F
19367	OTEVLQ	YLKJHGUDIS	7260379784 Dell Way	\N	TBXCOOG	\N	0	Germany	2	YLKJHGUDIS@dell.com	7260379784	1	4666712346021086	2008/05	user19367	password	61	40000	M
19368	JMUVDS	GOBOUVSDNL	8432101619 Dell Way	\N	FLOUAUJ	\N	0	Russia	2	GOBOUVSDNL@dell.com	8432101619	4	7575767197646201	2009/05	user19368	password	22	20000	M
19369	OZNSSU	GTJBPBFDNL	4330506531 Dell Way	\N	PBFPWPH	\N	0	Russia	2	GTJBPBFDNL@dell.com	4330506531	1	9378895941656084	2011/02	user19369	password	27	60000	M
19370	CZJVUQ	PDREFXITIX	8745474705 Dell Way	\N	UNNRDVJ	\N	0	France	2	PDREFXITIX@dell.com	8745474705	2	3100685577373952	2012/06	user19370	password	68	80000	M
19371	SZJMQY	QHDWELPNJK	7782211205 Dell Way	\N	AXBESLQ	\N	0	Germany	2	QHDWELPNJK@dell.com	7782211205	5	5828700620215387	2008/08	user19371	password	30	80000	F
19372	EDTUBK	CFGHRVUAGV	5653134906 Dell Way	\N	XHZQTQF	\N	0	France	2	CFGHRVUAGV@dell.com	5653134906	4	7191755890380592	2008/11	user19372	password	49	40000	F
19373	ODWQOY	VUGMQAMWVK	9862100509 Dell Way	\N	EVBXLGK	\N	0	UK	2	VUGMQAMWVK@dell.com	9862100509	1	1520941342227161	2012/07	user19373	password	49	100000	F
19374	OVSDUN	XAZOAMKWXP	9876706512 Dell Way	\N	RYMDEXB	\N	0	Canada	2	XAZOAMKWXP@dell.com	9876706512	1	1566423028241843	2010/07	user19374	password	20	60000	F
19375	WHGQUE	RUSRGDODTG	6021159464 Dell Way	\N	CGJHDLL	\N	0	Canada	2	RUSRGDODTG@dell.com	6021159464	3	6641329007688910	2008/07	user19375	password	33	40000	F
19376	NNAHSS	BLJIPYMIEO	8319600896 Dell Way	\N	ONWRYHU	\N	0	Germany	2	BLJIPYMIEO@dell.com	8319600896	3	6687688052654267	2009/08	user19376	password	83	80000	F
19377	LULDMN	PWVEUIMZXA	9397041726 Dell Way	\N	MTSLBNY	\N	0	South Africa	2	PWVEUIMZXA@dell.com	9397041726	3	2961757527198642	2010/06	user19377	password	88	80000	M
19378	TDBGRQ	CNUXVHWTIJ	4103863621 Dell Way	\N	MAVNOTK	\N	0	France	2	CNUXVHWTIJ@dell.com	4103863621	4	1428382692858576	2012/08	user19378	password	73	80000	F
19379	XVPPLS	CGPYNMRWWE	7490333023 Dell Way	\N	XRSLLCX	\N	0	Russia	2	CGPYNMRWWE@dell.com	7490333023	5	6504628347698600	2009/09	user19379	password	44	80000	M
19380	EGFQYH	WOGKBXGXCD	4881410127 Dell Way	\N	OUOAWMU	\N	0	Japan	2	WOGKBXGXCD@dell.com	4881410127	3	9210954201873392	2008/10	user19380	password	59	80000	M
19381	VZOUHL	INVJLCHNGW	1729165339 Dell Way	\N	HVWEHRU	\N	0	Russia	2	INVJLCHNGW@dell.com	1729165339	4	8863664439879359	2012/04	user19381	password	65	80000	F
19382	QIWXTF	LPPXRXKYTS	4503435001 Dell Way	\N	TQXBHSU	\N	0	China	2	LPPXRXKYTS@dell.com	4503435001	4	3047932087443769	2011/04	user19382	password	18	80000	M
19383	JQVCWH	SMEKJPICIC	6141002838 Dell Way	\N	TGDAYXK	\N	0	China	2	SMEKJPICIC@dell.com	6141002838	4	9816745478659868	2012/08	user19383	password	71	80000	F
19384	JQDGYV	SDGBSOEBRY	1180914930 Dell Way	\N	HUZFSJO	\N	0	Chile	2	SDGBSOEBRY@dell.com	1180914930	3	2391336767002940	2011/04	user19384	password	87	80000	M
19385	PUXNQP	QWRJLWKCUS	9837094099 Dell Way	\N	XTYPDMX	\N	0	Canada	2	QWRJLWKCUS@dell.com	9837094099	1	8438259765971453	2009/12	user19385	password	54	100000	M
19386	ITCYJT	VBCGXNISFG	8000598390 Dell Way	\N	LDVPPTT	\N	0	Germany	2	VBCGXNISFG@dell.com	8000598390	3	8498194765765221	2011/01	user19386	password	70	40000	F
19387	MMIVFD	XIJUWSMBYY	8352445824 Dell Way	\N	FUNVNGL	\N	0	China	2	XIJUWSMBYY@dell.com	8352445824	2	1779233523178845	2012/12	user19387	password	50	40000	F
19388	XOHDSE	MCZIUMKTKP	2081442459 Dell Way	\N	OYLCEWK	\N	0	UK	2	MCZIUMKTKP@dell.com	2081442459	3	8938105316367001	2008/12	user19388	password	28	60000	M
19389	SVZKAL	MZUHLEBWTP	6422680676 Dell Way	\N	UFSZBCY	\N	0	Canada	2	MZUHLEBWTP@dell.com	6422680676	5	3515515181235969	2010/12	user19389	password	77	60000	M
19390	RKDRWQ	RQXDUZZOPT	5729401768 Dell Way	\N	THSVKRA	\N	0	Australia	2	RQXDUZZOPT@dell.com	5729401768	2	5923615694977344	2010/02	user19390	password	87	40000	M
19391	IILFYD	VWGQWFELZY	1698895554 Dell Way	\N	TSTDKUD	\N	0	UK	2	VWGQWFELZY@dell.com	1698895554	4	4858715051319450	2008/08	user19391	password	64	100000	M
19392	ZKEYOA	VUQRAUCZTV	8218505681 Dell Way	\N	SNZCHDA	\N	0	China	2	VUQRAUCZTV@dell.com	8218505681	3	6045160763431341	2010/02	user19392	password	56	60000	F
19393	YPZMPV	HGMHBPHULZ	6093246367 Dell Way	\N	HKCPNDY	\N	0	China	2	HGMHBPHULZ@dell.com	6093246367	3	7802129075862468	2011/01	user19393	password	30	80000	M
19394	TSMJNU	QABRPJLAJT	8207042963 Dell Way	\N	KLIYOHG	\N	0	Canada	2	QABRPJLAJT@dell.com	8207042963	1	8029862811788917	2012/03	user19394	password	54	100000	M
19395	FIITCY	TEPINBJWVT	9635024908 Dell Way	\N	IESWLYZ	\N	0	Chile	2	TEPINBJWVT@dell.com	9635024908	4	1900562187656760	2008/04	user19395	password	86	20000	F
19396	GKGJJZ	NZIBBRXWLF	8763257923 Dell Way	\N	BDCMCCT	\N	0	Australia	2	NZIBBRXWLF@dell.com	8763257923	5	2743693586438894	2008/10	user19396	password	38	80000	F
19397	SWLBWY	AEACWYYHDZ	1933470620 Dell Way	\N	LGMOIGP	\N	0	Canada	2	AEACWYYHDZ@dell.com	1933470620	4	3981917629484087	2012/01	user19397	password	88	100000	M
19398	VJVSIW	WJYTHXALXM	4683387622 Dell Way	\N	RKAAQQF	\N	0	Russia	2	WJYTHXALXM@dell.com	4683387622	3	6715910922270269	2010/06	user19398	password	61	40000	F
19399	ZBAIYX	RWQYURJRDB	7893955754 Dell Way	\N	BEBRUGK	\N	0	Chile	2	RWQYURJRDB@dell.com	7893955754	1	7151576407719404	2009/08	user19399	password	85	60000	M
19400	APYYMP	VDOPUYGYZH	5053547482 Dell Way	\N	CAZXGKC	\N	0	Australia	2	VDOPUYGYZH@dell.com	5053547482	4	3521371935494244	2008/09	user19400	password	80	80000	M
19401	LRRYGM	BVBWTHUSPX	7235378352 Dell Way	\N	SOUZYXA	\N	0	France	2	BVBWTHUSPX@dell.com	7235378352	2	5535818986129016	2010/02	user19401	password	34	20000	M
19402	WUODHP	YIMRQGKFDD	4696110664 Dell Way	\N	UYCTVDD	\N	0	Germany	2	YIMRQGKFDD@dell.com	4696110664	4	9527872762177140	2010/11	user19402	password	24	20000	M
19403	XSXEIV	NUNDBXJEBD	7166348740 Dell Way	\N	DDXZGAM	\N	0	Japan	2	NUNDBXJEBD@dell.com	7166348740	3	3168304309714585	2010/07	user19403	password	47	40000	F
19404	DFPLAC	GOGHMPMNTP	5673676855 Dell Way	\N	RQOYRBQ	\N	0	China	2	GOGHMPMNTP@dell.com	5673676855	5	9263821463566274	2008/04	user19404	password	34	60000	F
19405	LBWMEC	AKKNAXAUNS	2119510004 Dell Way	\N	KCQCEGL	\N	0	Japan	2	AKKNAXAUNS@dell.com	2119510004	2	7568446745164693	2009/08	user19405	password	33	80000	F
19406	HQMLTN	WEAXBBROTC	1104476374 Dell Way	\N	RJEVQQM	\N	0	Russia	2	WEAXBBROTC@dell.com	1104476374	2	2464437942951917	2011/06	user19406	password	87	80000	M
19407	PDEJQB	NQYPRQELSV	4134587726 Dell Way	\N	UXQLODF	\N	0	Germany	2	NQYPRQELSV@dell.com	4134587726	2	2608117501251399	2011/05	user19407	password	77	60000	M
19408	YRHOSV	FRKXHOIAJD	2490036778 Dell Way	\N	YAOMDUB	\N	0	France	2	FRKXHOIAJD@dell.com	2490036778	2	3313754817470908	2010/01	user19408	password	72	60000	M
19409	KSODNT	UXQBMYCWBA	8194716976 Dell Way	\N	WQNZKOL	\N	0	Germany	2	UXQBMYCWBA@dell.com	8194716976	4	1644424700643867	2012/06	user19409	password	54	100000	M
19410	FJZTCT	RTVDRXZTYW	1116803367 Dell Way	\N	JLVTZHI	\N	0	Russia	2	RTVDRXZTYW@dell.com	1116803367	3	6759083238895983	2010/11	user19410	password	52	40000	F
19411	VIWYCO	RYSJWSCUOL	9563191692 Dell Way	\N	FKFFROA	\N	0	Japan	2	RYSJWSCUOL@dell.com	9563191692	4	2562688604462892	2012/02	user19411	password	56	100000	M
19412	WWXZLP	YDYUVBPKNU	6835349719 Dell Way	\N	USAMGAE	\N	0	Chile	2	YDYUVBPKNU@dell.com	6835349719	2	1665827127639204	2011/11	user19412	password	22	80000	M
19413	YPSJEQ	NDLJEATRVN	5248149487 Dell Way	\N	KVZRVDW	\N	0	France	2	NDLJEATRVN@dell.com	5248149487	5	3180252700112760	2009/01	user19413	password	87	20000	M
19414	OUITLV	WWEBXXTSLD	6703385844 Dell Way	\N	NLUJORW	\N	0	Australia	2	WWEBXXTSLD@dell.com	6703385844	1	4329001355916262	2011/01	user19414	password	49	80000	M
19415	FYIQUF	MYGKWZCIDQ	9671174782 Dell Way	\N	TYAIQWJ	\N	0	Chile	2	MYGKWZCIDQ@dell.com	9671174782	4	9113759350031616	2008/02	user19415	password	55	80000	F
19416	LYZFDM	EKWBJZJNPC	5314141988 Dell Way	\N	LPKBMTI	\N	0	France	2	EKWBJZJNPC@dell.com	5314141988	2	5017201853450388	2011/09	user19416	password	21	100000	F
19417	ZZKDMO	NIPXIYKXBV	4804607339 Dell Way	\N	NMXZFFL	\N	0	Russia	2	NIPXIYKXBV@dell.com	4804607339	5	3973804462701082	2008/12	user19417	password	41	40000	M
19418	HSATGO	CWLKUVIWRV	2160185993 Dell Way	\N	IOVOUGG	\N	0	Chile	2	CWLKUVIWRV@dell.com	2160185993	3	4155515347607434	2008/11	user19418	password	66	100000	F
19419	JAYQOA	MZLHVTDMPL	8132041882 Dell Way	\N	BKZWRFB	\N	0	Russia	2	MZLHVTDMPL@dell.com	8132041882	3	8644931669346989	2011/01	user19419	password	77	100000	F
19420	VUBKVN	JGUFAXSPJU	1879543744 Dell Way	\N	AIQRORM	\N	0	China	2	JGUFAXSPJU@dell.com	1879543744	2	1328973581083118	2008/02	user19420	password	83	80000	M
19421	SRJNET	UZYUXQKGLK	8732443507 Dell Way	\N	PBCETON	\N	0	South Africa	2	UZYUXQKGLK@dell.com	8732443507	3	1098867494147270	2012/06	user19421	password	63	100000	F
19422	HIRMBL	LZGIQRPBBE	4693692736 Dell Way	\N	DDIWRWS	\N	0	Germany	2	LZGIQRPBBE@dell.com	4693692736	4	5883874933701009	2012/04	user19422	password	54	20000	M
19423	VRCWDN	WKWNBLOCQR	9643513475 Dell Way	\N	GZOYVGM	\N	0	Chile	2	WKWNBLOCQR@dell.com	9643513475	1	1940156403928995	2009/07	user19423	password	25	100000	F
19424	UZFXNC	HJPIVDLLVS	2746538429 Dell Way	\N	LKRGQEN	\N	0	Germany	2	HJPIVDLLVS@dell.com	2746538429	4	8997832646127791	2011/09	user19424	password	76	20000	M
19425	UIKHKS	RZBMDNYZFJ	7965536017 Dell Way	\N	JXQABEP	\N	0	Chile	2	RZBMDNYZFJ@dell.com	7965536017	3	9792054822668434	2010/04	user19425	password	23	20000	F
19426	KKJUDA	UENXSMXYVG	4309793759 Dell Way	\N	VMHWQWC	\N	0	France	2	UENXSMXYVG@dell.com	4309793759	1	9298300120513888	2011/02	user19426	password	85	80000	M
19427	ICIMCC	QQAICXGYEC	2201878820 Dell Way	\N	LLYCIBN	\N	0	Russia	2	QQAICXGYEC@dell.com	2201878820	3	4233234499581158	2009/05	user19427	password	23	100000	M
19428	EDEHGV	XHEAEKYJNK	4945039559 Dell Way	\N	VLMEMAW	\N	0	Japan	2	XHEAEKYJNK@dell.com	4945039559	2	9225877891294660	2011/04	user19428	password	71	60000	F
19429	XRTDMR	KQSPBRZOBV	2125738818 Dell Way	\N	ZOZMOWD	\N	0	UK	2	KQSPBRZOBV@dell.com	2125738818	1	8068477548193187	2010/10	user19429	password	38	100000	M
19430	YSUKJF	BCVCTUQUQQ	3540632333 Dell Way	\N	IPDWMGW	\N	0	Japan	2	BCVCTUQUQQ@dell.com	3540632333	4	1635617357213050	2008/12	user19430	password	18	80000	M
19431	SNHCSJ	ENLXICRYTA	4924540006 Dell Way	\N	OXXBDUR	\N	0	France	2	ENLXICRYTA@dell.com	4924540006	4	5259600277990103	2009/09	user19431	password	31	40000	F
19432	ROOKYS	YJQGMIEGIT	2676125954 Dell Way	\N	DGUHALS	\N	0	France	2	YJQGMIEGIT@dell.com	2676125954	1	8608853099867702	2012/05	user19432	password	25	40000	F
19433	RYLPRJ	ZHPMPUSYNW	1007349143 Dell Way	\N	FHDGTVS	\N	0	UK	2	ZHPMPUSYNW@dell.com	1007349143	3	8793844892177732	2009/09	user19433	password	36	40000	F
19434	FVYWFX	EUKUPCSDYY	5209449708 Dell Way	\N	KCEEXXC	\N	0	UK	2	EUKUPCSDYY@dell.com	5209449708	5	3481214337982237	2008/03	user19434	password	66	60000	F
19435	MKHSIL	NSFCVYFUXQ	8835413386 Dell Way	\N	WCUUZXS	\N	0	France	2	NSFCVYFUXQ@dell.com	8835413386	5	6319237333722413	2008/08	user19435	password	22	60000	F
19436	MUVUGJ	NMLILRCIHY	4897854616 Dell Way	\N	KCTKALV	\N	0	South Africa	2	NMLILRCIHY@dell.com	4897854616	3	9802180044353008	2008/07	user19436	password	54	40000	M
19437	HCUOLH	AWPLORUVQE	8606425591 Dell Way	\N	YJOZVKW	\N	0	Chile	2	AWPLORUVQE@dell.com	8606425591	5	4141714472789317	2009/04	user19437	password	60	40000	M
19438	RCECJF	ZZQNRKJHPH	9535581460 Dell Way	\N	RDGNODU	\N	0	France	2	ZZQNRKJHPH@dell.com	9535581460	1	7746994492597879	2009/09	user19438	password	23	100000	F
19439	EBMOGL	NXYEIHMXPE	6238796037 Dell Way	\N	BWRPZLA	\N	0	UK	2	NXYEIHMXPE@dell.com	6238796037	4	2899037606548518	2009/11	user19439	password	25	80000	F
19440	EDOKPC	IOGQVTOLXP	9721347300 Dell Way	\N	IPFIBFG	\N	0	Japan	2	IOGQVTOLXP@dell.com	9721347300	3	9248947122599930	2012/07	user19440	password	60	100000	M
19441	TJDILM	WSCSLQDJFM	5425640968 Dell Way	\N	YLUZQAP	\N	0	Japan	2	WSCSLQDJFM@dell.com	5425640968	3	4683423421811313	2008/02	user19441	password	33	80000	M
19442	PYEAKA	SMTEDWNJJM	6044863034 Dell Way	\N	UDLLEBA	\N	0	Japan	2	SMTEDWNJJM@dell.com	6044863034	3	7375383800361306	2011/08	user19442	password	53	60000	F
19443	KRHVSA	HLELISUREP	5470538243 Dell Way	\N	UPAYRBP	\N	0	Chile	2	HLELISUREP@dell.com	5470538243	2	8935666538774968	2008/10	user19443	password	46	60000	F
19444	BRATRI	EWTMOODTEY	8318957598 Dell Way	\N	JEXAFMF	\N	0	Russia	2	EWTMOODTEY@dell.com	8318957598	1	8947776113171131	2011/06	user19444	password	39	100000	M
19445	ZWHQFM	NZZCNDVRBE	5389244909 Dell Way	\N	WYECLKV	\N	0	Chile	2	NZZCNDVRBE@dell.com	5389244909	4	8920293881092221	2012/12	user19445	password	70	60000	M
19446	PVPUHD	THFHKAZLEV	4740148240 Dell Way	\N	KJXWTSC	\N	0	Chile	2	THFHKAZLEV@dell.com	4740148240	5	2842399263754487	2009/09	user19446	password	71	40000	F
19447	OYCWBV	DHCNHBZMXJ	3940950537 Dell Way	\N	VUFONIU	\N	0	UK	2	DHCNHBZMXJ@dell.com	3940950537	5	4088188292924315	2008/09	user19447	password	68	40000	F
19448	QKDSGG	ZJUHKTTIDO	9347562623 Dell Way	\N	DIDQRYP	\N	0	Australia	2	ZJUHKTTIDO@dell.com	9347562623	5	1366558713838458	2011/08	user19448	password	45	100000	F
19449	UBZAIZ	JCGUWACZPG	4863074152 Dell Way	\N	ISXZQMZ	\N	0	Germany	2	JCGUWACZPG@dell.com	4863074152	1	3005034533794969	2008/05	user19449	password	29	40000	F
19450	FIFNIP	QPKMPNLETT	8024892862 Dell Way	\N	XQTNDTC	\N	0	Germany	2	QPKMPNLETT@dell.com	8024892862	2	6616929874289781	2008/06	user19450	password	88	40000	M
19451	IPFQFW	FPIVDUZWOW	8366355961 Dell Way	\N	NHKQBMF	\N	0	South Africa	2	FPIVDUZWOW@dell.com	8366355961	5	1205922121182084	2009/10	user19451	password	47	100000	F
19452	AFTFBZ	VJUYEUVSRJ	1623663040 Dell Way	\N	ABABOFX	\N	0	China	2	VJUYEUVSRJ@dell.com	1623663040	5	7005745914764703	2012/05	user19452	password	64	100000	F
19453	VTPWSK	GNJKHFDYPE	1734260685 Dell Way	\N	APGOVDY	\N	0	South Africa	2	GNJKHFDYPE@dell.com	1734260685	4	7922248734626920	2010/03	user19453	password	73	80000	F
19454	MJZFUF	SDQAJUYYYY	1478843552 Dell Way	\N	NENJILG	\N	0	France	2	SDQAJUYYYY@dell.com	1478843552	1	8460496309679002	2009/10	user19454	password	62	40000	F
19455	ZJMTOF	WFFGZEEYDS	4308887445 Dell Way	\N	DQCLBIW	\N	0	Canada	2	WFFGZEEYDS@dell.com	4308887445	4	4859024343546480	2008/04	user19455	password	77	60000	F
19456	EYZTDW	YJCYNHXQAA	9897805975 Dell Way	\N	HDLJLIM	\N	0	South Africa	2	YJCYNHXQAA@dell.com	9897805975	5	9802807798609140	2009/09	user19456	password	48	60000	M
19457	INQMJO	WMNKUKBULI	1448012820 Dell Way	\N	XXRJFDF	\N	0	Canada	2	WMNKUKBULI@dell.com	1448012820	1	5127924652770162	2011/08	user19457	password	89	80000	M
19458	MHLWVH	IJRCUSXFAV	6450440391 Dell Way	\N	CSFHVKM	\N	0	South Africa	2	IJRCUSXFAV@dell.com	6450440391	5	6972395109944046	2009/12	user19458	password	41	20000	F
19459	PPGLWP	UOSPHQUHLX	6695916797 Dell Way	\N	ARFWCRT	\N	0	Japan	2	UOSPHQUHLX@dell.com	6695916797	3	9052360878326000	2010/09	user19459	password	20	100000	F
19460	QFTMVO	ANDIDYQPWQ	6650314986 Dell Way	\N	GBMITFA	\N	0	China	2	ANDIDYQPWQ@dell.com	6650314986	5	9559382754378022	2009/12	user19460	password	84	80000	M
19461	DKBYZC	MDKQBAFYRL	7801016860 Dell Way	\N	ADUTJVE	\N	0	UK	2	MDKQBAFYRL@dell.com	7801016860	1	4029982014559209	2011/01	user19461	password	18	40000	F
19462	LJDKMP	NXGPYLNPXN	6210719368 Dell Way	\N	TSHCNMC	\N	0	Chile	2	NXGPYLNPXN@dell.com	6210719368	3	1038213943131268	2011/06	user19462	password	40	80000	M
19463	RXGENT	CTJAEXQCKJ	9538472173 Dell Way	\N	USLIENP	\N	0	Russia	2	CTJAEXQCKJ@dell.com	9538472173	4	4366480864118785	2009/11	user19463	password	29	40000	M
19464	BLTPFV	IPWNMMQXWK	9239629765 Dell Way	\N	QHSUVIO	\N	0	Russia	2	IPWNMMQXWK@dell.com	9239629765	5	2420424892101437	2012/02	user19464	password	45	60000	F
19465	VETBAC	QXPDKGAGQQ	9767876103 Dell Way	\N	OJLJRAE	\N	0	Germany	2	QXPDKGAGQQ@dell.com	9767876103	2	4685609895735979	2008/09	user19465	password	78	40000	M
19466	AZPBBG	YRJIXKOOBC	9859177438 Dell Way	\N	XNMPORE	\N	0	Germany	2	YRJIXKOOBC@dell.com	9859177438	3	6279387067072094	2011/05	user19466	password	78	40000	F
19467	VVMWBK	OLTMWIBXLY	3337632713 Dell Way	\N	KXNYORM	\N	0	Germany	2	OLTMWIBXLY@dell.com	3337632713	1	3181973701808601	2011/11	user19467	password	51	20000	M
19468	HOOIZD	USQQBROMPY	4895056313 Dell Way	\N	KDXZVJN	\N	0	Australia	2	USQQBROMPY@dell.com	4895056313	4	7676390113774688	2009/03	user19468	password	78	100000	M
19469	JOVJSQ	CIGDZUPOTZ	3321557598 Dell Way	\N	SRZNBMP	\N	0	France	2	CIGDZUPOTZ@dell.com	3321557598	2	8104879248421640	2010/03	user19469	password	75	100000	M
19470	JVXBMZ	JSCINSWHSP	1427010818 Dell Way	\N	YRCZESM	\N	0	France	2	JSCINSWHSP@dell.com	1427010818	2	9088634021114560	2009/01	user19470	password	82	80000	F
19471	SRLEQU	XSCLLZSDOR	4618991593 Dell Way	\N	URRYJDJ	\N	0	France	2	XSCLLZSDOR@dell.com	4618991593	2	6654691819101573	2010/02	user19471	password	46	100000	M
19472	BHBRBZ	KEKVDDZSUT	3999644340 Dell Way	\N	JMSTPBD	\N	0	Australia	2	KEKVDDZSUT@dell.com	3999644340	4	5085325423628092	2010/03	user19472	password	40	40000	F
19473	PLWRKH	VVCZYBRTVB	7596038235 Dell Way	\N	FNUUPYU	\N	0	UK	2	VVCZYBRTVB@dell.com	7596038235	2	4825145918875933	2012/07	user19473	password	75	20000	F
19474	FZVPGQ	KJQJLICGKH	2515157538 Dell Way	\N	UECKDXJ	\N	0	South Africa	2	KJQJLICGKH@dell.com	2515157538	4	7959675642196090	2011/07	user19474	password	82	100000	M
19475	WSJDIU	NZEYHGFROZ	5718155026 Dell Way	\N	WRKAPTW	\N	0	Russia	2	NZEYHGFROZ@dell.com	5718155026	4	5311295112594962	2008/07	user19475	password	44	100000	F
19476	BFNKAA	JEZRLEIZEF	7826309986 Dell Way	\N	RPFGICA	\N	0	South Africa	2	JEZRLEIZEF@dell.com	7826309986	3	9457147034350784	2009/11	user19476	password	75	80000	M
19477	AGHAHR	FGIQLRQPWI	1385848482 Dell Way	\N	ECONFOJ	\N	0	UK	2	FGIQLRQPWI@dell.com	1385848482	2	3320247536059469	2012/02	user19477	password	88	80000	F
19478	FBDMSJ	SBZESQTPYY	2444432276 Dell Way	\N	SNMXBVW	\N	0	Canada	2	SBZESQTPYY@dell.com	2444432276	1	9894938048906624	2009/01	user19478	password	73	40000	F
19479	VNTOWM	PWQIMKXLIP	5435854690 Dell Way	\N	YUNZQJC	\N	0	South Africa	2	PWQIMKXLIP@dell.com	5435854690	1	1641477024182677	2010/11	user19479	password	51	100000	M
19480	ZPGWBW	SSEFCCQLSP	7845613635 Dell Way	\N	GFOXPRS	\N	0	Australia	2	SSEFCCQLSP@dell.com	7845613635	4	6914562165737153	2011/03	user19480	password	54	40000	F
19481	COBEKU	XOZZRQLJFR	1188204387 Dell Way	\N	PUOELGH	\N	0	Chile	2	XOZZRQLJFR@dell.com	1188204387	5	8419889978598804	2009/06	user19481	password	27	60000	M
19482	RMSBGP	QGPIWARBSH	6947809835 Dell Way	\N	WHLHNTN	\N	0	Germany	2	QGPIWARBSH@dell.com	6947809835	2	8111138598062099	2008/06	user19482	password	34	80000	F
19483	SJFZYV	FODCPVDHCA	2397668406 Dell Way	\N	POHCHVR	\N	0	UK	2	FODCPVDHCA@dell.com	2397668406	3	1480695512611419	2011/09	user19483	password	68	80000	F
19484	AYJZUO	OYQDUULWUA	3293451023 Dell Way	\N	LCDTYUS	\N	0	Australia	2	OYQDUULWUA@dell.com	3293451023	4	7264735859818757	2012/06	user19484	password	50	40000	F
19485	KRMEGA	DWEXRPUMQF	4780849999 Dell Way	\N	OUZMPRP	\N	0	South Africa	2	DWEXRPUMQF@dell.com	4780849999	2	7949250168167055	2012/09	user19485	password	24	40000	F
19486	TUHAVL	WZIOPCAGIP	9581533836 Dell Way	\N	AHCPYRL	\N	0	China	2	WZIOPCAGIP@dell.com	9581533836	2	3062582338228822	2011/04	user19486	password	59	80000	F
19487	JCCENZ	EVNTYOAGDA	3806068226 Dell Way	\N	NGQMYCW	\N	0	South Africa	2	EVNTYOAGDA@dell.com	3806068226	1	6031299253925682	2011/08	user19487	password	43	80000	F
19488	LUFYTJ	THDRVDYZEM	8870212034 Dell Way	\N	GVYEXUB	\N	0	Chile	2	THDRVDYZEM@dell.com	8870212034	4	8585731339175255	2010/12	user19488	password	58	60000	F
19489	ISICCC	KFUFJSFNFM	4062104409 Dell Way	\N	IDQGYSM	\N	0	South Africa	2	KFUFJSFNFM@dell.com	4062104409	2	4014522708952427	2009/11	user19489	password	80	80000	F
19490	OBHRDR	WYXFRDTWPC	2221859768 Dell Way	\N	AGJYZVU	\N	0	China	2	WYXFRDTWPC@dell.com	2221859768	1	6629055583849550	2012/12	user19490	password	42	20000	M
19491	JMFNEC	LCHDGBZWEZ	8552697496 Dell Way	\N	DNYCJSK	\N	0	France	2	LCHDGBZWEZ@dell.com	8552697496	1	5315841544885189	2012/05	user19491	password	67	40000	M
19492	EOGJQS	MYWSAVOEVR	2916335767 Dell Way	\N	SUUBNEN	\N	0	China	2	MYWSAVOEVR@dell.com	2916335767	1	2475339471362531	2010/09	user19492	password	55	40000	M
19493	BPFSIR	QEKQZYVVQN	1988430772 Dell Way	\N	QKODPCM	\N	0	South Africa	2	QEKQZYVVQN@dell.com	1988430772	4	4479236664716154	2011/03	user19493	password	69	80000	F
19494	HWYQOP	UYGUXCQNPG	5759916987 Dell Way	\N	YEJNHWI	\N	0	China	2	UYGUXCQNPG@dell.com	5759916987	4	2648567534983158	2011/06	user19494	password	78	100000	M
19495	SXJGND	ETYBWOPLUN	2231256016 Dell Way	\N	QEBXBKH	\N	0	Germany	2	ETYBWOPLUN@dell.com	2231256016	3	3499342366121709	2010/04	user19495	password	34	40000	F
19496	DRGQVL	KUNGICSDQI	1361047432 Dell Way	\N	HSGJCOX	\N	0	Chile	2	KUNGICSDQI@dell.com	1361047432	1	8341073237359525	2009/06	user19496	password	27	40000	M
19497	VQFRBQ	LOWTRPWHYE	6858093229 Dell Way	\N	ZENCTLI	\N	0	Russia	2	LOWTRPWHYE@dell.com	6858093229	1	2221625171601772	2008/04	user19497	password	55	80000	F
19498	DWTFME	UIYMXVTWAT	3911355969 Dell Way	\N	AOVTZEO	\N	0	Japan	2	UIYMXVTWAT@dell.com	3911355969	4	7521771417465062	2011/03	user19498	password	44	80000	F
19499	FMORQJ	APVYKOULIV	8231650731 Dell Way	\N	ZEPZIDQ	\N	0	Japan	2	APVYKOULIV@dell.com	8231650731	2	3484260564669967	2012/09	user19499	password	89	40000	M
19500	LXPCGQ	SBODQIOYDN	5054164126 Dell Way	\N	DTMMWCD	\N	0	Japan	2	SBODQIOYDN@dell.com	5054164126	3	6891139218118042	2008/05	user19500	password	89	20000	M
19501	WRYCHR	EWUUFITJVX	9315540379 Dell Way	\N	CIJYLNP	\N	0	South Africa	2	EWUUFITJVX@dell.com	9315540379	2	1490540292579680	2009/03	user19501	password	27	20000	F
19502	VDFCUK	ZOFEXYNTVP	4276474609 Dell Way	\N	BFNNSCK	\N	0	Japan	2	ZOFEXYNTVP@dell.com	4276474609	3	9602337711490692	2011/08	user19502	password	28	80000	F
19503	HYNCIM	RNQOMDHISJ	8038670670 Dell Way	\N	NGXFJIV	\N	0	Russia	2	RNQOMDHISJ@dell.com	8038670670	5	3866320422384888	2009/12	user19503	password	20	100000	F
19504	ZIIHVZ	VMNHPVQIED	9968673408 Dell Way	\N	PBJYJFQ	\N	0	Canada	2	VMNHPVQIED@dell.com	9968673408	5	5958657104521990	2012/12	user19504	password	44	20000	M
19505	SMGNLC	ZZKPUAYZDN	1694956244 Dell Way	\N	BNLLSCP	\N	0	Japan	2	ZZKPUAYZDN@dell.com	1694956244	1	6694027629680932	2008/06	user19505	password	76	20000	F
19506	HISSKS	SUIMVGMZUN	7016939460 Dell Way	\N	MGYEJNW	\N	0	France	2	SUIMVGMZUN@dell.com	7016939460	3	5585946450941265	2008/04	user19506	password	58	40000	M
19507	WBHHUA	CCMXJZWDMJ	9079975707 Dell Way	\N	KKNTYKE	\N	0	Japan	2	CCMXJZWDMJ@dell.com	9079975707	4	8068017737939955	2008/03	user19507	password	28	80000	F
19508	FBKABM	COJMNGQAPA	6823690257 Dell Way	\N	LDTKOYA	\N	0	France	2	COJMNGQAPA@dell.com	6823690257	4	6708669791929424	2012/12	user19508	password	47	20000	F
19509	MKEOWH	DGTRNJRDJD	3727377167 Dell Way	\N	HDNVCNG	\N	0	Russia	2	DGTRNJRDJD@dell.com	3727377167	5	6772840112913401	2009/04	user19509	password	65	60000	M
19510	BOIYVL	FPDTYUWIYE	2242068138 Dell Way	\N	MLZOYGI	\N	0	Chile	2	FPDTYUWIYE@dell.com	2242068138	5	5377982988487929	2010/08	user19510	password	82	40000	M
19511	LOQHAV	WDOVYLEWPQ	5232184933 Dell Way	\N	HPFGVNM	\N	0	UK	2	WDOVYLEWPQ@dell.com	5232184933	5	4629120319150388	2008/11	user19511	password	63	80000	F
19512	EJPEFM	IUIHFMDVCL	2410152995 Dell Way	\N	KIRFVEE	\N	0	Chile	2	IUIHFMDVCL@dell.com	2410152995	3	4378519179765135	2008/03	user19512	password	27	40000	F
19513	NYOSLX	MUESGINJTX	9260014084 Dell Way	\N	RLDNQIU	\N	0	Russia	2	MUESGINJTX@dell.com	9260014084	1	8251748514827342	2008/04	user19513	password	28	60000	M
19514	CCNOZA	IESPMFYGDQ	1987384941 Dell Way	\N	SGDIPYC	\N	0	Germany	2	IESPMFYGDQ@dell.com	1987384941	5	6780836540739984	2010/01	user19514	password	29	40000	F
19515	GTSGTA	LLQXROEVFW	3006508784 Dell Way	\N	CIFRHHE	\N	0	China	2	LLQXROEVFW@dell.com	3006508784	5	8256743236444891	2009/12	user19515	password	20	60000	F
19516	UDNNEY	ZUWRJAMPWO	3178098546 Dell Way	\N	YBGFJKP	\N	0	Japan	2	ZUWRJAMPWO@dell.com	3178098546	3	8998793648090214	2009/06	user19516	password	42	60000	F
19517	MZTRXT	MTKWTXLQMJ	6157068629 Dell Way	\N	SSOCDES	\N	0	China	2	MTKWTXLQMJ@dell.com	6157068629	3	6370466742198915	2008/12	user19517	password	23	40000	F
19518	BZCYSO	SDKMBWDNFV	3298355857 Dell Way	\N	GUYJYRS	\N	0	Germany	2	SDKMBWDNFV@dell.com	3298355857	2	5691911292262376	2008/05	user19518	password	72	80000	F
19519	SSKLHC	PSOQORETNK	8395182827 Dell Way	\N	NLTMDMZ	\N	0	China	2	PSOQORETNK@dell.com	8395182827	3	6034625838510693	2009/03	user19519	password	30	80000	M
19520	WBLDDA	VRRKIWDWGR	6460782750 Dell Way	\N	IADLNCU	\N	0	China	2	VRRKIWDWGR@dell.com	6460782750	2	6062946089077741	2012/07	user19520	password	33	100000	F
19521	GGOJHK	BYUKUYGBPO	2329217283 Dell Way	\N	CTZPWUY	\N	0	France	2	BYUKUYGBPO@dell.com	2329217283	3	3754745187703520	2011/09	user19521	password	27	20000	M
19522	JQJRAK	PUVKSBLIQO	6659675200 Dell Way	\N	BPDXKCJ	\N	0	Germany	2	PUVKSBLIQO@dell.com	6659675200	4	3013649483211338	2009/10	user19522	password	39	40000	F
19523	XSVXDK	SYVKAHSQVT	6900683393 Dell Way	\N	GZRRCAF	\N	0	Russia	2	SYVKAHSQVT@dell.com	6900683393	3	1719903030432760	2010/09	user19523	password	49	80000	M
19524	EKOHVH	GRRHYKYTEF	5644816341 Dell Way	\N	TVWVVCO	\N	0	France	2	GRRHYKYTEF@dell.com	5644816341	4	9292092089075596	2009/01	user19524	password	56	100000	F
19525	YMNUTU	LKCKVAEZFX	9296135498 Dell Way	\N	VCTQEHD	\N	0	Japan	2	LKCKVAEZFX@dell.com	9296135498	1	9413089689332992	2012/07	user19525	password	78	40000	M
19526	HTHANT	LPDHQIGVGC	8966025171 Dell Way	\N	YZSCHVU	\N	0	Canada	2	LPDHQIGVGC@dell.com	8966025171	4	2602926995139569	2010/07	user19526	password	46	100000	M
19527	DHXQAI	GEPWMWSTYQ	3408044099 Dell Way	\N	SRTZNOE	\N	0	China	2	GEPWMWSTYQ@dell.com	3408044099	2	8678784369956703	2012/09	user19527	password	77	80000	M
19528	COMDXT	HNPUKINJYG	7678599440 Dell Way	\N	ASFOGKY	\N	0	Germany	2	HNPUKINJYG@dell.com	7678599440	4	4135071215219796	2010/08	user19528	password	20	40000	M
19529	PVVNOD	AEXKMLULRU	1749800017 Dell Way	\N	DXIKHHY	\N	0	Australia	2	AEXKMLULRU@dell.com	1749800017	2	5503426731564105	2011/04	user19529	password	78	60000	M
19530	RFKFJL	KGWWSQIJLL	1755477864 Dell Way	\N	GUWOBUO	\N	0	Canada	2	KGWWSQIJLL@dell.com	1755477864	1	8589174524415285	2009/11	user19530	password	36	40000	M
19531	MSUVDE	CZAUPIEAUK	6217784906 Dell Way	\N	URYWMNA	\N	0	Germany	2	CZAUPIEAUK@dell.com	6217784906	5	9610521638300272	2010/02	user19531	password	36	20000	M
19532	YVKCZM	BAHRJLREWM	2696109978 Dell Way	\N	WUIIIIX	\N	0	UK	2	BAHRJLREWM@dell.com	2696109978	5	4425017938483507	2009/02	user19532	password	48	100000	F
19533	FGDFTF	FAWPLNTIAP	7040485584 Dell Way	\N	DJYLSVJ	\N	0	South Africa	2	FAWPLNTIAP@dell.com	7040485584	4	2529795929323882	2011/02	user19533	password	20	100000	F
19534	HZOBEU	BAJNODVOSZ	5397769355 Dell Way	\N	XRKPMTM	\N	0	Canada	2	BAJNODVOSZ@dell.com	5397769355	4	9315550735220314	2011/09	user19534	password	72	100000	M
19535	SOAWJC	XSQLVMZOLX	7051159908 Dell Way	\N	FVNSPAW	\N	0	Australia	2	XSQLVMZOLX@dell.com	7051159908	4	7483468098100276	2009/07	user19535	password	70	40000	F
19536	HJDQMA	JCLEPLTAIZ	4145521294 Dell Way	\N	WVSMVOO	\N	0	Germany	2	JCLEPLTAIZ@dell.com	4145521294	2	8939732030034066	2012/12	user19536	password	35	20000	F
19537	QGXCHG	FSLUDFVMFS	1095231709 Dell Way	\N	IXEDMTR	\N	0	South Africa	2	FSLUDFVMFS@dell.com	1095231709	3	7286203883588315	2008/10	user19537	password	79	40000	F
19538	CENKLS	CWNGBJTGBB	4764952634 Dell Way	\N	EGFQZWL	\N	0	UK	2	CWNGBJTGBB@dell.com	4764952634	1	9920819324906916	2009/12	user19538	password	37	80000	F
19539	LDMWWO	TJVUTOBVPF	4748596402 Dell Way	\N	BVWBRHA	\N	0	Australia	2	TJVUTOBVPF@dell.com	4748596402	1	3741860999725759	2009/04	user19539	password	84	60000	M
19540	AYQXNJ	HIEAXGWNMX	1076941328 Dell Way	\N	IIYAPZC	\N	0	Australia	2	HIEAXGWNMX@dell.com	1076941328	3	4597209148108959	2009/04	user19540	password	81	20000	F
19541	URGHAN	QEONKKBWIJ	9125281130 Dell Way	\N	EHJUGMU	\N	0	Chile	2	QEONKKBWIJ@dell.com	9125281130	1	6146868637297303	2009/01	user19541	password	62	60000	M
19542	GWDHJU	LYHWIITQSY	7248835959 Dell Way	\N	XCSEPNL	\N	0	France	2	LYHWIITQSY@dell.com	7248835959	1	7484921738039703	2011/08	user19542	password	41	80000	M
19543	ETEONQ	MVNUEGLWEJ	1075657145 Dell Way	\N	ZWNOJZB	\N	0	Australia	2	MVNUEGLWEJ@dell.com	1075657145	4	8387394069228322	2011/01	user19543	password	48	60000	F
19544	ESURJH	MWCQCNNGWM	8694293204 Dell Way	\N	DKBNJCP	\N	0	China	2	MWCQCNNGWM@dell.com	8694293204	3	1319469135720282	2012/10	user19544	password	60	20000	M
19545	HZRRHE	NJVPWIWTVA	5757077823 Dell Way	\N	DWNNZDX	\N	0	South Africa	2	NJVPWIWTVA@dell.com	5757077823	5	7914625511039049	2009/07	user19545	password	88	40000	M
19546	YAMGEA	PAQMINFENJ	7876607130 Dell Way	\N	BBXAEVW	\N	0	Russia	2	PAQMINFENJ@dell.com	7876607130	4	1651960949413478	2009/08	user19546	password	48	20000	M
19547	LQUQQK	QGWZTCDHLF	7620531430 Dell Way	\N	JIGODCG	\N	0	UK	2	QGWZTCDHLF@dell.com	7620531430	2	2931355966255069	2009/10	user19547	password	43	100000	F
19548	ZRVPCL	WYKQBOYNTH	4945786160 Dell Way	\N	VZVZCCX	\N	0	South Africa	2	WYKQBOYNTH@dell.com	4945786160	1	2433999711181968	2008/06	user19548	password	21	40000	F
19549	TFBVRY	UBPVQNIJUE	2876749321 Dell Way	\N	JQELTCH	\N	0	Canada	2	UBPVQNIJUE@dell.com	2876749321	3	4415133642032743	2011/06	user19549	password	74	20000	F
19550	ZFBQDV	SSQIGZRBDB	3066991663 Dell Way	\N	RHNLJUP	\N	0	Germany	2	SSQIGZRBDB@dell.com	3066991663	5	3497371022123843	2011/10	user19550	password	48	100000	M
19551	QZJTUC	MLKSKCTODL	5322913205 Dell Way	\N	WRWFLMV	\N	0	Japan	2	MLKSKCTODL@dell.com	5322913205	1	4565098064485938	2009/07	user19551	password	42	100000	F
19552	IJXDLJ	OWCZZWNDHJ	5613819765 Dell Way	\N	UEPFRKX	\N	0	Canada	2	OWCZZWNDHJ@dell.com	5613819765	2	4478019075933844	2008/08	user19552	password	45	20000	M
19553	TBCFLQ	COPBKDESMY	4382258451 Dell Way	\N	WBEOMBR	\N	0	Australia	2	COPBKDESMY@dell.com	4382258451	1	1257320760283619	2008/06	user19553	password	31	100000	F
19554	GBKRSM	GINQLSIXQF	5637112810 Dell Way	\N	ZVTMXLM	\N	0	Chile	2	GINQLSIXQF@dell.com	5637112810	3	3524167534895241	2012/09	user19554	password	36	20000	M
19555	IOQABW	IPNTHWRYCR	2432011590 Dell Way	\N	TVEQHQX	\N	0	South Africa	2	IPNTHWRYCR@dell.com	2432011590	1	7900103851221503	2012/06	user19555	password	85	100000	M
19556	MMTOJB	DWVLTNJVED	8682290553 Dell Way	\N	RITYZRT	\N	0	Canada	2	DWVLTNJVED@dell.com	8682290553	3	1009889468085020	2009/06	user19556	password	78	20000	M
19557	HUMQWQ	NSBGFLBJOT	9664028145 Dell Way	\N	SIRRZLV	\N	0	South Africa	2	NSBGFLBJOT@dell.com	9664028145	5	2128451982047409	2010/08	user19557	password	30	40000	M
19558	ZWPVMC	NOJSZLCNEU	1949400947 Dell Way	\N	WWMVHHQ	\N	0	Chile	2	NOJSZLCNEU@dell.com	1949400947	4	7054997374303640	2011/12	user19558	password	19	80000	M
19559	WGTJJH	XSAXEDKIXG	5713099104 Dell Way	\N	EKCMRTT	\N	0	Russia	2	XSAXEDKIXG@dell.com	5713099104	3	5832586135249585	2010/06	user19559	password	33	40000	F
19560	MDRVLP	OMMSPXBNDG	9207637859 Dell Way	\N	XGTPZMK	\N	0	Germany	2	OMMSPXBNDG@dell.com	9207637859	5	9863334858324380	2009/02	user19560	password	45	80000	M
19561	NJLZYZ	LKSAHTNLZL	4067757559 Dell Way	\N	RSARFKE	\N	0	Canada	2	LKSAHTNLZL@dell.com	4067757559	1	5382700772024691	2010/07	user19561	password	30	20000	F
19562	ONBMNM	XFMEZAQZMI	4300725776 Dell Way	\N	RMAXXEA	\N	0	Chile	2	XFMEZAQZMI@dell.com	4300725776	3	7574482650030405	2012/09	user19562	password	77	100000	F
19563	IBSWNP	BAUBBLANTS	2230680179 Dell Way	\N	ATPXYQE	\N	0	China	2	BAUBBLANTS@dell.com	2230680179	5	3021737345028668	2012/09	user19563	password	33	20000	F
19564	GTXUJZ	UEAVPAJISJ	4162257809 Dell Way	\N	CIHAYLI	\N	0	Australia	2	UEAVPAJISJ@dell.com	4162257809	3	9061560813337564	2008/10	user19564	password	87	20000	F
19565	SAVCZP	GALVAUESDG	2607191996 Dell Way	\N	AKHZWQB	\N	0	Chile	2	GALVAUESDG@dell.com	2607191996	5	3600849858019501	2012/11	user19565	password	48	100000	M
19566	LURLKY	LVULQYETFF	2408564063 Dell Way	\N	EMEBDFH	\N	0	Chile	2	LVULQYETFF@dell.com	2408564063	3	3278961118310690	2008/12	user19566	password	35	80000	F
19567	BIVLGG	GASXZWQECV	7429045033 Dell Way	\N	RGWUMDC	\N	0	Japan	2	GASXZWQECV@dell.com	7429045033	2	7083259978331626	2011/08	user19567	password	41	20000	M
19568	QYBXEI	YXFXUWCWSU	1474477091 Dell Way	\N	DPPPTSF	\N	0	France	2	YXFXUWCWSU@dell.com	1474477091	5	2257561290636658	2011/03	user19568	password	34	40000	M
19569	EJTJSS	GYPAUSWNMZ	7494409520 Dell Way	\N	CCPVUVH	\N	0	South Africa	2	GYPAUSWNMZ@dell.com	7494409520	3	5296012870501727	2012/08	user19569	password	74	100000	M
19570	DOEVGK	TWLOOIBBIE	7388554309 Dell Way	\N	DXZXTHT	\N	0	France	2	TWLOOIBBIE@dell.com	7388554309	2	4597740669734776	2009/12	user19570	password	32	20000	F
19571	UJYBUS	XFHMOJOWNR	5935813996 Dell Way	\N	UNPNVIZ	\N	0	Germany	2	XFHMOJOWNR@dell.com	5935813996	2	8999337830580772	2010/07	user19571	password	23	80000	F
19572	LPKFII	KPUYYIVMAP	5275093320 Dell Way	\N	AQDVZCI	\N	0	Germany	2	KPUYYIVMAP@dell.com	5275093320	2	1414789068978279	2008/04	user19572	password	68	60000	M
19573	HVYPDI	EXHDGDQHSQ	1218858578 Dell Way	\N	YVLXYUK	\N	0	France	2	EXHDGDQHSQ@dell.com	1218858578	3	5228925793897361	2009/02	user19573	password	82	20000	F
19574	RZAVIF	SQJZTZHMPF	9714597814 Dell Way	\N	HBCGWNR	\N	0	South Africa	2	SQJZTZHMPF@dell.com	9714597814	1	2935291743371636	2008/01	user19574	password	38	60000	M
19575	GONPUG	FDFZDNLTST	8082206854 Dell Way	\N	UVZRIRO	\N	0	Chile	2	FDFZDNLTST@dell.com	8082206854	4	4727482061833143	2011/01	user19575	password	88	60000	F
19576	NAXIGD	LMDPZOISID	2115591464 Dell Way	\N	NIUWZJE	\N	0	Russia	2	LMDPZOISID@dell.com	2115591464	3	6010382989887149	2008/07	user19576	password	22	60000	F
19577	BKJINV	VQKVFTNNWB	7093653848 Dell Way	\N	VRYUACO	\N	0	Canada	2	VQKVFTNNWB@dell.com	7093653848	1	3757101156283170	2009/03	user19577	password	75	40000	F
19578	ERPSNK	IYGORTBNVX	4463938626 Dell Way	\N	EUSFWGI	\N	0	Germany	2	IYGORTBNVX@dell.com	4463938626	4	7861043499317021	2010/06	user19578	password	21	100000	M
19579	SKHFVQ	DBFUVHIREN	7181694283 Dell Way	\N	LWSHDBW	\N	0	Germany	2	DBFUVHIREN@dell.com	7181694283	4	1834738431498408	2008/08	user19579	password	84	80000	F
19580	IAPDRS	EWNADWRIJC	8774771397 Dell Way	\N	FCKJDGW	\N	0	South Africa	2	EWNADWRIJC@dell.com	8774771397	5	9367375019937756	2010/11	user19580	password	65	100000	F
19581	RMIJFN	FSNJPFSYIX	2064113939 Dell Way	\N	ASGEZDZ	\N	0	South Africa	2	FSNJPFSYIX@dell.com	2064113939	5	4151579440571368	2008/07	user19581	password	35	40000	F
19582	SNPXBV	QPEFUXECVF	3542583988 Dell Way	\N	VBKUFJQ	\N	0	China	2	QPEFUXECVF@dell.com	3542583988	5	4040023957844824	2012/03	user19582	password	57	20000	M
19583	BQVDMM	SQSNOXQJCL	8364126157 Dell Way	\N	LNGQWWZ	\N	0	Canada	2	SQSNOXQJCL@dell.com	8364126157	2	9971518280450256	2008/11	user19583	password	23	100000	M
19584	SUBEGU	VYIKWYTYKE	2321883910 Dell Way	\N	MQVIMVM	\N	0	China	2	VYIKWYTYKE@dell.com	2321883910	3	3959310153033584	2008/07	user19584	password	37	100000	F
19585	BAMHVH	GDRCBLBMPN	8532712163 Dell Way	\N	CLWPGJX	\N	0	France	2	GDRCBLBMPN@dell.com	8532712163	2	4804718810133636	2009/06	user19585	password	45	80000	M
19586	KDVFLC	IDFKOGWEUZ	7253440851 Dell Way	\N	PROWAMH	\N	0	South Africa	2	IDFKOGWEUZ@dell.com	7253440851	4	3129134967923164	2008/01	user19586	password	84	80000	F
19587	BPRMRZ	PXKDEGIYGX	8019707419 Dell Way	\N	PUUQHBL	\N	0	UK	2	PXKDEGIYGX@dell.com	8019707419	4	2419162434991449	2012/08	user19587	password	83	40000	M
19588	MZDEZS	BJWFQEEWCU	5858665542 Dell Way	\N	RXKYZVX	\N	0	Russia	2	BJWFQEEWCU@dell.com	5858665542	1	6416110785678030	2008/12	user19588	password	85	80000	F
19589	XXPXQQ	GNWWRATUUK	3444761105 Dell Way	\N	REIQAFK	\N	0	Germany	2	GNWWRATUUK@dell.com	3444761105	5	7240364311262966	2009/11	user19589	password	53	80000	M
19590	KGSAWZ	OSWFTPANZS	7395769854 Dell Way	\N	RIIROSG	\N	0	South Africa	2	OSWFTPANZS@dell.com	7395769854	5	1273076994810253	2011/05	user19590	password	67	60000	M
19591	XEWUDK	NZQGPQTPIL	3530794003 Dell Way	\N	XRCLJJG	\N	0	Australia	2	NZQGPQTPIL@dell.com	3530794003	2	7468822503462435	2011/12	user19591	password	30	60000	M
19592	IJRMTE	MJKBZDRIPO	5849531330 Dell Way	\N	ZRAJBGM	\N	0	China	2	MJKBZDRIPO@dell.com	5849531330	1	1169776919763535	2010/05	user19592	password	56	40000	M
19593	WAEQEQ	ZPSZTJIIYH	3752893595 Dell Way	\N	AYRBEDJ	\N	0	Russia	2	ZPSZTJIIYH@dell.com	3752893595	2	3001478469464928	2011/11	user19593	password	61	40000	M
19594	QNLUEK	KWKDGSLEAL	3106654510 Dell Way	\N	CRMHUWA	\N	0	Canada	2	KWKDGSLEAL@dell.com	3106654510	2	7851072433404625	2008/11	user19594	password	25	100000	F
19595	QJGUUQ	RFTXXECYQF	7889541253 Dell Way	\N	PCNKYNN	\N	0	Canada	2	RFTXXECYQF@dell.com	7889541253	2	3932379282545298	2010/05	user19595	password	37	20000	M
19596	QHULYL	QRJOWLMMRC	3424932372 Dell Way	\N	PEMNRAS	\N	0	France	2	QRJOWLMMRC@dell.com	3424932372	1	1427861916832625	2011/04	user19596	password	25	80000	M
19597	KKKIWA	AFPXRBJIEZ	3192825818 Dell Way	\N	MRNERFP	\N	0	UK	2	AFPXRBJIEZ@dell.com	3192825818	4	6186509280931205	2010/09	user19597	password	33	60000	F
19598	QXMMYM	SNJJPTRTSD	5987089848 Dell Way	\N	KGHCLXA	\N	0	Japan	2	SNJJPTRTSD@dell.com	5987089848	3	3116323777940124	2009/10	user19598	password	71	60000	F
19599	QXYOKQ	BUZRORLHUW	5909842627 Dell Way	\N	NCYYAYQ	\N	0	Germany	2	BUZRORLHUW@dell.com	5909842627	5	8744198632426561	2009/08	user19599	password	40	80000	F
19600	FSUQJW	KJOYAZFVVT	2634069524 Dell Way	\N	XTRXSIM	\N	0	Chile	2	KJOYAZFVVT@dell.com	2634069524	2	6554282130207867	2011/08	user19600	password	48	20000	M
19601	DVMNSX	WGVWFBRBUO	3682022127 Dell Way	\N	VMMNUZU	\N	0	UK	2	WGVWFBRBUO@dell.com	3682022127	3	7937827423680574	2012/10	user19601	password	76	80000	M
19602	QHMIEI	PAEVCVWXKR	5014051816 Dell Way	\N	KXFEWAE	\N	0	Canada	2	PAEVCVWXKR@dell.com	5014051816	5	1893693222198635	2009/09	user19602	password	83	40000	F
19603	ESSJBH	JFCMBYJMQT	1636007580 Dell Way	\N	JWYGXDK	\N	0	China	2	JFCMBYJMQT@dell.com	1636007580	3	6626519127748907	2012/05	user19603	password	81	20000	M
19604	PWYQEH	WGUXFDKWXT	8942676772 Dell Way	\N	TWZQZKZ	\N	0	Australia	2	WGUXFDKWXT@dell.com	8942676772	4	8843362862709911	2009/06	user19604	password	21	100000	F
19605	YUTCBP	JWNOZXLXRE	4652251936 Dell Way	\N	TRVTBUV	\N	0	UK	2	JWNOZXLXRE@dell.com	4652251936	4	2867016335017979	2012/09	user19605	password	21	100000	M
19606	VSUXHD	TVSTTDQKHK	6931038334 Dell Way	\N	BCEDXZB	\N	0	China	2	TVSTTDQKHK@dell.com	6931038334	2	2858229233883321	2009/04	user19606	password	31	20000	F
19607	XVAFZU	ARNTUEECOG	7071619044 Dell Way	\N	FTJDSKL	\N	0	China	2	ARNTUEECOG@dell.com	7071619044	4	7868508715648205	2012/10	user19607	password	78	20000	M
19608	RDYQYZ	HLSCPXFEDK	6660075285 Dell Way	\N	XNOPXZZ	\N	0	Germany	2	HLSCPXFEDK@dell.com	6660075285	4	6189421317540110	2010/07	user19608	password	68	20000	F
19609	WDWUCE	FVHUSMZWXW	2551563526 Dell Way	\N	JMMGLLW	\N	0	Australia	2	FVHUSMZWXW@dell.com	2551563526	3	5809498493093998	2011/02	user19609	password	70	100000	M
19610	VWTXAZ	SIULVTHSPQ	2783150352 Dell Way	\N	ECXQNTS	\N	0	Japan	2	SIULVTHSPQ@dell.com	2783150352	2	4833956937771291	2009/12	user19610	password	47	40000	M
19611	GBSHAL	PVXKOEDEVI	9129866861 Dell Way	\N	GSYTMRL	\N	0	Japan	2	PVXKOEDEVI@dell.com	9129866861	5	1182338953483849	2012/04	user19611	password	42	80000	M
19612	KKULVK	GSVUXYZSGF	3526683530 Dell Way	\N	LFZYWKQ	\N	0	Russia	2	GSVUXYZSGF@dell.com	3526683530	4	6871675542090089	2010/12	user19612	password	41	20000	F
19613	SWVOHB	HCWEBVXIAI	6030964380 Dell Way	\N	OZHLKXF	\N	0	Japan	2	HCWEBVXIAI@dell.com	6030964380	5	3027200086973607	2010/03	user19613	password	40	100000	M
19614	ETLMUS	PQWQLUYMCN	1129152362 Dell Way	\N	LKYWHDN	\N	0	South Africa	2	PQWQLUYMCN@dell.com	1129152362	4	4574802351184189	2009/01	user19614	password	41	20000	F
19615	BOSVGH	MDYYXXKAKW	9850034869 Dell Way	\N	KISSMGO	\N	0	France	2	MDYYXXKAKW@dell.com	9850034869	5	7206865440122784	2008/04	user19615	password	75	40000	F
19616	IZEOHQ	SFOQCZQMWB	3485702612 Dell Way	\N	UOTHUIT	\N	0	Russia	2	SFOQCZQMWB@dell.com	3485702612	3	8347316502127797	2010/03	user19616	password	24	100000	M
19617	BBDIRW	NGMPGCCCEX	4604427177 Dell Way	\N	QXELGYG	\N	0	Germany	2	NGMPGCCCEX@dell.com	4604427177	1	1545132931321859	2011/02	user19617	password	86	40000	F
19618	ZJNRFB	YRREUTGZRX	6838999773 Dell Way	\N	WVJCUPQ	\N	0	Canada	2	YRREUTGZRX@dell.com	6838999773	4	8457450782880188	2011/08	user19618	password	21	100000	M
19619	KNHQOF	IGJCAQCRNZ	4376894226 Dell Way	\N	NXBHMSM	\N	0	Canada	2	IGJCAQCRNZ@dell.com	4376894226	2	9299661366734656	2012/05	user19619	password	84	80000	M
19620	KWJZCR	FLUFCWXPVK	5367912379 Dell Way	\N	NXSZPED	\N	0	UK	2	FLUFCWXPVK@dell.com	5367912379	1	9824998283758760	2012/12	user19620	password	60	60000	F
19621	MYJOQP	ZKVCHSSDDF	4494098219 Dell Way	\N	BVFRZIQ	\N	0	France	2	ZKVCHSSDDF@dell.com	4494098219	4	3858220046386123	2009/03	user19621	password	83	80000	M
19622	WCFMRF	XMHFEZIIEJ	3632259372 Dell Way	\N	DKADSRP	\N	0	Canada	2	XMHFEZIIEJ@dell.com	3632259372	5	5135696546174586	2010/10	user19622	password	31	20000	M
19623	GJEYPB	KWGPWPXBZB	7354785373 Dell Way	\N	LZEERUH	\N	0	UK	2	KWGPWPXBZB@dell.com	7354785373	4	5095321564003825	2010/11	user19623	password	63	40000	F
19624	ZJCOLN	LSDHHAIGCU	9513602081 Dell Way	\N	GGYXAFW	\N	0	Russia	2	LSDHHAIGCU@dell.com	9513602081	2	3375268515199423	2012/12	user19624	password	53	20000	M
19625	WENHRY	AVGHWPOYJU	9279760507 Dell Way	\N	EISENPX	\N	0	France	2	AVGHWPOYJU@dell.com	9279760507	1	3969860320445150	2012/08	user19625	password	45	80000	M
19626	NHVFGV	AMDWBSULMY	3211641058 Dell Way	\N	TFDGUBT	\N	0	Russia	2	AMDWBSULMY@dell.com	3211641058	1	6304542843252421	2012/06	user19626	password	46	60000	M
19627	RGEYCE	KGBMYVYLUR	7649069271 Dell Way	\N	QYYLZRE	\N	0	Chile	2	KGBMYVYLUR@dell.com	7649069271	4	2384988087229430	2008/02	user19627	password	61	20000	M
19628	WIUZNF	FOREKQPEHG	6787575230 Dell Way	\N	DFSCXWJ	\N	0	Japan	2	FOREKQPEHG@dell.com	6787575230	3	8266593246720732	2011/02	user19628	password	87	80000	M
19629	GLYTQD	IIHSYXXFDA	9949556156 Dell Way	\N	LVDISMZ	\N	0	China	2	IIHSYXXFDA@dell.com	9949556156	4	2378212525509298	2008/09	user19629	password	76	20000	M
19630	FZTWDC	ELUDIRILSU	8621047528 Dell Way	\N	HVCAHBJ	\N	0	Chile	2	ELUDIRILSU@dell.com	8621047528	3	4557457808870822	2010/04	user19630	password	50	60000	M
19631	LHKOKO	ZERHWATOVB	9163386293 Dell Way	\N	JXBRZKZ	\N	0	South Africa	2	ZERHWATOVB@dell.com	9163386293	2	4701964455656707	2009/10	user19631	password	88	80000	F
19632	HDVRSV	VKCSLWGGXQ	7242381956 Dell Way	\N	DYIDJIZ	\N	0	Chile	2	VKCSLWGGXQ@dell.com	7242381956	3	5285557100083679	2010/05	user19632	password	34	80000	M
19633	JQHBLD	MOVXKCDISH	8416769722 Dell Way	\N	HBLQJKX	\N	0	Australia	2	MOVXKCDISH@dell.com	8416769722	2	6175652608275414	2008/08	user19633	password	44	100000	M
19634	ZDALGM	ZCJKENSWUZ	9148527869 Dell Way	\N	XFQHQNI	\N	0	France	2	ZCJKENSWUZ@dell.com	9148527869	5	6745020777452738	2010/04	user19634	password	52	60000	F
19635	PMRWZR	YJBCWTZRTX	4337806465 Dell Way	\N	WJEMXMY	\N	0	South Africa	2	YJBCWTZRTX@dell.com	4337806465	3	3843171852175146	2011/01	user19635	password	74	100000	M
19636	HOMGFL	QHNNAMEUJA	1006212549 Dell Way	\N	DNNBALW	\N	0	China	2	QHNNAMEUJA@dell.com	1006212549	1	1143586628139019	2008/12	user19636	password	84	80000	F
19637	MEMSPD	ZDQAQVUZWY	1329898079 Dell Way	\N	NJZNUWX	\N	0	South Africa	2	ZDQAQVUZWY@dell.com	1329898079	5	8584525971207769	2012/11	user19637	password	55	40000	F
19638	RTAHWA	KNAAJVAFTO	9334387910 Dell Way	\N	OTBJPZE	\N	0	Japan	2	KNAAJVAFTO@dell.com	9334387910	1	6685207939706743	2011/07	user19638	password	81	20000	F
19639	PDNMEX	ZEYJAYOTMD	7438477361 Dell Way	\N	NONCORT	\N	0	France	2	ZEYJAYOTMD@dell.com	7438477361	2	3205641736276448	2009/03	user19639	password	42	60000	M
19640	MZIQXI	VVRVUFPGIC	3670268859 Dell Way	\N	VVFJNYV	\N	0	Chile	2	VVRVUFPGIC@dell.com	3670268859	1	5514197690878064	2010/06	user19640	password	89	40000	M
19641	ZRNWZI	SRDMWTTFVO	8789429603 Dell Way	\N	BAYOYUV	\N	0	Chile	2	SRDMWTTFVO@dell.com	8789429603	2	8050131024792791	2009/04	user19641	password	29	20000	F
19642	VSEVAW	MEJJXCOTRP	3950435029 Dell Way	\N	TPESJAZ	\N	0	Chile	2	MEJJXCOTRP@dell.com	3950435029	4	5726058998145164	2011/11	user19642	password	70	100000	M
19643	KCOLYB	QIKNKZGCPA	5408908833 Dell Way	\N	RUTBUTH	\N	0	Canada	2	QIKNKZGCPA@dell.com	5408908833	4	7824577187187970	2009/07	user19643	password	67	20000	M
19644	TSJSUZ	AFNLEUNUVF	3829854940 Dell Way	\N	OOGJHNM	\N	0	Russia	2	AFNLEUNUVF@dell.com	3829854940	2	2747409154195338	2012/12	user19644	password	42	80000	M
19645	BDKVCK	APWFKKZFPO	7062656803 Dell Way	\N	UVYCJLW	\N	0	Japan	2	APWFKKZFPO@dell.com	7062656803	1	5414282379206270	2010/05	user19645	password	35	40000	F
19646	JRHLCI	BYOLIORYCL	5392272255 Dell Way	\N	UANDLKU	\N	0	Canada	2	BYOLIORYCL@dell.com	5392272255	2	7602091507520527	2012/07	user19646	password	19	40000	M
19647	RRIUZK	TOWBCNAEZU	9672162812 Dell Way	\N	FNXRXRV	\N	0	France	2	TOWBCNAEZU@dell.com	9672162812	3	3792310669086874	2010/07	user19647	password	67	40000	F
19648	IRAICT	WYVYMWDLQJ	4605314280 Dell Way	\N	YNAWFWH	\N	0	Canada	2	WYVYMWDLQJ@dell.com	4605314280	3	6932964847888798	2012/04	user19648	password	18	40000	M
19649	SGYUAV	SVUERXQIHO	3691602173 Dell Way	\N	VILBESG	\N	0	Germany	2	SVUERXQIHO@dell.com	3691602173	5	5769839815795422	2010/11	user19649	password	72	20000	M
19650	ZDJZYC	VSHNQXVXLR	8752122129 Dell Way	\N	GWSKPZZ	\N	0	South Africa	2	VSHNQXVXLR@dell.com	8752122129	3	5105705463793129	2011/03	user19650	password	63	40000	F
19651	TTFRWA	KDOBAJZMBF	1593281059 Dell Way	\N	JUPYTOV	\N	0	Japan	2	KDOBAJZMBF@dell.com	1593281059	2	4412605576217175	2009/12	user19651	password	73	60000	M
19652	NTJJUU	MIVNSVZTAI	4755035150 Dell Way	\N	OQHHFDX	\N	0	Chile	2	MIVNSVZTAI@dell.com	4755035150	2	6094580728560687	2009/01	user19652	password	24	20000	M
19653	VJXPEK	YZXQUXKVGY	4946116424 Dell Way	\N	LNGQREX	\N	0	Australia	2	YZXQUXKVGY@dell.com	4946116424	3	4716314764227718	2010/07	user19653	password	49	20000	F
19654	UYAYIY	YGPTEAOKZA	1375703269 Dell Way	\N	YFRPJOR	\N	0	South Africa	2	YGPTEAOKZA@dell.com	1375703269	1	3567046765703708	2011/07	user19654	password	40	20000	F
19655	GAHPYF	WOZAONLNOK	7990455134 Dell Way	\N	SFACURX	\N	0	South Africa	2	WOZAONLNOK@dell.com	7990455134	1	4964140818919987	2009/06	user19655	password	50	80000	M
19656	LWIKCE	YBFMPRZEBS	9162255843 Dell Way	\N	KBVETSA	\N	0	Germany	2	YBFMPRZEBS@dell.com	9162255843	3	8425545118749143	2010/11	user19656	password	49	20000	F
19657	IMTKRS	MXECOEGQXQ	3486650982 Dell Way	\N	RSVLLVZ	\N	0	China	2	MXECOEGQXQ@dell.com	3486650982	5	7665042353793979	2008/03	user19657	password	82	60000	M
19658	JHZBZL	YDOMIUCFLU	1121135025 Dell Way	\N	YGGJCFS	\N	0	China	2	YDOMIUCFLU@dell.com	1121135025	3	5739729400258512	2009/04	user19658	password	21	100000	M
19659	IUTHGR	LUETPGZABX	4892899805 Dell Way	\N	HHHJNZS	\N	0	Germany	2	LUETPGZABX@dell.com	4892899805	2	7902111002709717	2011/04	user19659	password	59	60000	M
19660	JFWPWH	JBBYHBZJYG	5788160925 Dell Way	\N	QGPDGHR	\N	0	Japan	2	JBBYHBZJYG@dell.com	5788160925	3	4918313132133335	2012/01	user19660	password	83	60000	F
19661	CHYZPH	AQGIRFRQLI	6228654738 Dell Way	\N	XAMDIDU	\N	0	South Africa	2	AQGIRFRQLI@dell.com	6228654738	2	7085932384710760	2010/02	user19661	password	24	100000	F
19662	JWGYEH	PKPGQHXBQU	9734657720 Dell Way	\N	CDYLGTH	\N	0	South Africa	2	PKPGQHXBQU@dell.com	9734657720	5	4873785248026252	2008/01	user19662	password	44	40000	F
19663	GPJKWY	VMFLUDNLYP	3648816220 Dell Way	\N	OWAUPIQ	\N	0	Germany	2	VMFLUDNLYP@dell.com	3648816220	1	7104707227554173	2009/06	user19663	password	20	80000	M
19664	QDCNCX	AHJULWFJLT	3728483247 Dell Way	\N	FMOVUFK	\N	0	Australia	2	AHJULWFJLT@dell.com	3728483247	1	5008247068151832	2011/02	user19664	password	33	60000	M
19665	INGKLH	SUBDQHNCBS	1166802274 Dell Way	\N	PQOKWYM	\N	0	Canada	2	SUBDQHNCBS@dell.com	1166802274	5	9199055574834348	2008/02	user19665	password	43	100000	F
19666	WDXIKP	DMTUUGXWZM	3395872272 Dell Way	\N	MOWIMIM	\N	0	Germany	2	DMTUUGXWZM@dell.com	3395872272	3	6725328656844795	2010/10	user19666	password	55	100000	M
19667	QUZBKC	ODXIKUEKGR	9334597872 Dell Way	\N	YCALLNY	\N	0	Russia	2	ODXIKUEKGR@dell.com	9334597872	3	2043382621835917	2011/02	user19667	password	90	40000	M
19668	UIUEKJ	IISSCXDJOB	1304504358 Dell Way	\N	LPNXCLP	\N	0	Australia	2	IISSCXDJOB@dell.com	1304504358	4	7417645310051740	2008/09	user19668	password	21	100000	M
19669	JRRUAZ	CTSEQWOFYZ	3133078468 Dell Way	\N	ULXWXNX	\N	0	UK	2	CTSEQWOFYZ@dell.com	3133078468	4	1477767935954034	2012/08	user19669	password	85	60000	F
19670	PDUQDX	JWCZSQEQQZ	4397141027 Dell Way	\N	CNWZATX	\N	0	Chile	2	JWCZSQEQQZ@dell.com	4397141027	5	3004580762702972	2008/11	user19670	password	68	20000	F
19671	VWCZTM	VVLOLQFBPI	2691990897 Dell Way	\N	PMHPFFW	\N	0	Germany	2	VVLOLQFBPI@dell.com	2691990897	1	6772109705489129	2008/10	user19671	password	69	60000	M
19672	ORPIDL	EPZPGFRWNG	8261229767 Dell Way	\N	IVWOBSD	\N	0	Chile	2	EPZPGFRWNG@dell.com	8261229767	4	3823893110267818	2010/06	user19672	password	81	20000	F
19673	OUJRFN	HFDNLVJZBS	2440707157 Dell Way	\N	UYGWRJC	\N	0	France	2	HFDNLVJZBS@dell.com	2440707157	2	1420423095114529	2011/04	user19673	password	35	80000	M
19674	ACMGQT	MTHXOQWQJR	1004401869 Dell Way	\N	PPNGZPS	\N	0	Canada	2	MTHXOQWQJR@dell.com	1004401869	4	7981849535368384	2009/12	user19674	password	53	20000	F
19675	OOHEIT	YPRNGNEPFT	4855790965 Dell Way	\N	FSZEIRH	\N	0	China	2	YPRNGNEPFT@dell.com	4855790965	1	6437050116714091	2010/07	user19675	password	67	60000	F
19676	GSHOMF	EDTLQXBWQG	8048157472 Dell Way	\N	PPKYHSG	\N	0	Russia	2	EDTLQXBWQG@dell.com	8048157472	5	2224972585216164	2009/07	user19676	password	60	60000	M
19677	HTJTZO	WSZNPBKFHZ	1340932038 Dell Way	\N	VSXDLEV	\N	0	Chile	2	WSZNPBKFHZ@dell.com	1340932038	5	5904691637493671	2010/07	user19677	password	90	40000	M
19678	TTPSIM	KIAZJLFRKB	9678212094 Dell Way	\N	JIEUNZA	\N	0	Germany	2	KIAZJLFRKB@dell.com	9678212094	3	2117099503055215	2010/07	user19678	password	54	40000	F
19679	GZZOLJ	WMJGXPXIQH	6752922745 Dell Way	\N	QUBDUCR	\N	0	Russia	2	WMJGXPXIQH@dell.com	6752922745	5	3327452884055674	2008/04	user19679	password	63	60000	M
19680	PLDBVA	NEHLTETKLK	1301321472 Dell Way	\N	ENOYPFS	\N	0	Chile	2	NEHLTETKLK@dell.com	1301321472	5	4867220759391785	2009/07	user19680	password	83	100000	F
19681	ICFECS	JKECOXNAHR	3676392531 Dell Way	\N	NVQDBIJ	\N	0	Australia	2	JKECOXNAHR@dell.com	3676392531	5	5008489602711052	2012/09	user19681	password	45	20000	F
19682	LGFOZO	YDRNBEOIWC	4757188964 Dell Way	\N	EMFGVPI	\N	0	Canada	2	YDRNBEOIWC@dell.com	4757188964	4	9912887291051448	2008/02	user19682	password	20	20000	M
19683	HKEGYD	JQRKUFTQHY	3692464059 Dell Way	\N	DNEYDNB	\N	0	Germany	2	JQRKUFTQHY@dell.com	3692464059	1	6943504248745740	2010/01	user19683	password	79	20000	F
19684	FGPEJZ	UAKPFEFNCI	4169691576 Dell Way	\N	AHGDUIR	\N	0	Australia	2	UAKPFEFNCI@dell.com	4169691576	2	5907527247909457	2010/03	user19684	password	62	80000	F
19685	VJOFIJ	FSYLWEYZNZ	1960401633 Dell Way	\N	GTCBCUD	\N	0	France	2	FSYLWEYZNZ@dell.com	1960401633	4	8699035022873432	2009/04	user19685	password	63	80000	F
19686	ZGIHPN	AOZXSXXFXD	1121075346 Dell Way	\N	ZZEBUIN	\N	0	South Africa	2	AOZXSXXFXD@dell.com	1121075346	2	2373566889204085	2009/12	user19686	password	78	60000	M
19687	BTGRHH	GGFYECEBGE	2135284725 Dell Way	\N	BLGVTTS	\N	0	Russia	2	GGFYECEBGE@dell.com	2135284725	5	1628659514244645	2008/09	user19687	password	54	20000	M
19688	GILNQR	UVQYXUADZC	5388493773 Dell Way	\N	OFXIZQC	\N	0	Canada	2	UVQYXUADZC@dell.com	5388493773	1	2974015390034765	2008/08	user19688	password	39	100000	M
19689	QJKGAF	BQEYLECLGR	2929223953 Dell Way	\N	QEZQVBT	\N	0	Chile	2	BQEYLECLGR@dell.com	2929223953	5	5233429868239910	2012/03	user19689	password	47	80000	M
19690	TECUJD	LNCWSFHZWY	3403863482 Dell Way	\N	EVOZWIG	\N	0	Australia	2	LNCWSFHZWY@dell.com	3403863482	4	9665863581467420	2010/02	user19690	password	70	40000	M
19691	XMRHPC	USZNXHMTFQ	6503002304 Dell Way	\N	PUPMCWO	\N	0	China	2	USZNXHMTFQ@dell.com	6503002304	3	8959082780871541	2011/03	user19691	password	36	80000	F
19692	SHKIKF	BJTZQFSWWH	8771548380 Dell Way	\N	RMUUJID	\N	0	UK	2	BJTZQFSWWH@dell.com	8771548380	1	7383913652505726	2008/04	user19692	password	43	40000	F
19693	QRJBXK	LQJCWCYSKQ	6209652369 Dell Way	\N	EEKONON	\N	0	China	2	LQJCWCYSKQ@dell.com	6209652369	2	5357904038857669	2012/07	user19693	password	72	100000	F
19694	KGGIQR	YAUUCTNNJS	9816310378 Dell Way	\N	RTGEHTO	\N	0	South Africa	2	YAUUCTNNJS@dell.com	9816310378	1	7743504025042058	2010/10	user19694	password	64	80000	F
19695	WANNSM	NMHQFUDOMV	6439597930 Dell Way	\N	ITAQMON	\N	0	France	2	NMHQFUDOMV@dell.com	6439597930	2	1158893571700900	2009/11	user19695	password	74	60000	M
19696	UDGMPU	ZWKEQOTDJC	5319262358 Dell Way	\N	WJSJYFV	\N	0	Germany	2	ZWKEQOTDJC@dell.com	5319262358	5	9311475424561650	2009/08	user19696	password	55	20000	F
19697	QKXGEW	CPBTDVWNXT	8045991550 Dell Way	\N	WQCVVYI	\N	0	China	2	CPBTDVWNXT@dell.com	8045991550	2	7256683155894280	2010/10	user19697	password	77	100000	F
19698	FSRKPT	ZRMDNJQKCN	9557342423 Dell Way	\N	BEIXCRF	\N	0	South Africa	2	ZRMDNJQKCN@dell.com	9557342423	5	3671785322017968	2011/09	user19698	password	26	20000	M
19699	VVILOI	DBLQKCBMQC	1813285168 Dell Way	\N	RZZURER	\N	0	Japan	2	DBLQKCBMQC@dell.com	1813285168	5	4081716109998524	2012/02	user19699	password	55	80000	M
19700	ICJXKM	ZWDJYEWPGO	9788604684 Dell Way	\N	OFIFKAV	\N	0	France	2	ZWDJYEWPGO@dell.com	9788604684	1	3756661378778517	2008/08	user19700	password	22	100000	M
19701	EJXOWW	LZGJDDZJRN	7400344969 Dell Way	\N	PATZAOM	\N	0	UK	2	LZGJDDZJRN@dell.com	7400344969	4	1528635367751121	2009/11	user19701	password	21	40000	M
19702	KHOGDZ	FJJINISEWH	5506173242 Dell Way	\N	EPGFDSF	\N	0	South Africa	2	FJJINISEWH@dell.com	5506173242	2	3108839149121195	2009/04	user19702	password	62	40000	M
19703	WXYAWE	KGNXOFBLMG	9489467979 Dell Way	\N	ATMEMRA	\N	0	UK	2	KGNXOFBLMG@dell.com	9489467979	2	3899706967640668	2009/11	user19703	password	65	100000	M
19704	OYTKCD	RPAFVCQHJR	2014019926 Dell Way	\N	BVVNMWN	\N	0	France	2	RPAFVCQHJR@dell.com	2014019926	5	7231600197497756	2012/06	user19704	password	66	80000	F
19705	PMMRPD	HQJCTZKCRL	4149553404 Dell Way	\N	XMZKJNV	\N	0	France	2	HQJCTZKCRL@dell.com	4149553404	3	4943586741108448	2012/03	user19705	password	29	100000	M
19706	QJLFMT	WVVPVFRMRP	4162924811 Dell Way	\N	ZQZIDVU	\N	0	Germany	2	WVVPVFRMRP@dell.com	4162924811	2	4172083687968552	2010/05	user19706	password	36	40000	F
19707	PTGCMC	XISTNKGFZF	6131121002 Dell Way	\N	WZOAUIN	\N	0	Canada	2	XISTNKGFZF@dell.com	6131121002	5	7104278308805079	2012/02	user19707	password	90	100000	M
19708	TFUGHS	OZMCJSIJXE	5697714004 Dell Way	\N	IMECURG	\N	0	China	2	OZMCJSIJXE@dell.com	5697714004	5	3978478895034641	2011/12	user19708	password	39	40000	M
19709	MDXUWM	UIPEBXNZBW	2363390118 Dell Way	\N	LFZGXFQ	\N	0	France	2	UIPEBXNZBW@dell.com	2363390118	5	1349472904112190	2008/03	user19709	password	45	80000	M
19710	NRNKEH	TTMURZTTVE	9966037261 Dell Way	\N	YVLWABG	\N	0	Canada	2	TTMURZTTVE@dell.com	9966037261	2	3281697650440037	2009/09	user19710	password	90	100000	F
19711	RMPVUI	OGCGGWZBBY	3982072698 Dell Way	\N	XMUXNAC	\N	0	Germany	2	OGCGGWZBBY@dell.com	3982072698	2	7925156668294222	2008/05	user19711	password	71	40000	F
19712	FUVZDK	GGQMCPNENL	8086313932 Dell Way	\N	RIIEILS	\N	0	Japan	2	GGQMCPNENL@dell.com	8086313932	3	7148116282653064	2008/03	user19712	password	83	20000	F
19713	RZLVJR	BADEQRIECZ	4664417515 Dell Way	\N	MLEVWXM	\N	0	Japan	2	BADEQRIECZ@dell.com	4664417515	1	8090503186453135	2011/01	user19713	password	86	20000	M
19714	XNOHEQ	HIVXZDCBDO	1229190171 Dell Way	\N	MIJJGWA	\N	0	Japan	2	HIVXZDCBDO@dell.com	1229190171	4	3645355106797069	2008/09	user19714	password	45	100000	M
19715	XKXBBF	JWDJAFKETX	1765308881 Dell Way	\N	NDHTZHK	\N	0	Australia	2	JWDJAFKETX@dell.com	1765308881	4	1893786219414323	2012/02	user19715	password	86	60000	M
19716	JJBKPL	HTUIYFMSDZ	8989200203 Dell Way	\N	WKTVREW	\N	0	Russia	2	HTUIYFMSDZ@dell.com	8989200203	5	6279445011168719	2012/11	user19716	password	21	100000	F
19717	KZRALY	TFHSKTLNTH	9291334318 Dell Way	\N	YNDQRZK	\N	0	Germany	2	TFHSKTLNTH@dell.com	9291334318	5	5916382720228285	2012/01	user19717	password	54	20000	F
19718	MTLXSF	DZYOSJBMQA	9930626985 Dell Way	\N	ZTQRTAG	\N	0	Japan	2	DZYOSJBMQA@dell.com	9930626985	4	5220852210652083	2008/04	user19718	password	56	60000	M
19719	GXRZDV	YBJQKLDBLC	8143700171 Dell Way	\N	VBUOCAF	\N	0	Australia	2	YBJQKLDBLC@dell.com	8143700171	4	1852963501121848	2008/03	user19719	password	57	100000	F
19720	LOLPJJ	QSABDDCPGY	4228857955 Dell Way	\N	RAMTARV	\N	0	South Africa	2	QSABDDCPGY@dell.com	4228857955	5	8995181349571795	2010/06	user19720	password	71	20000	M
19721	HMNQWE	JWGNAJCGHT	3728605384 Dell Way	\N	GTNHLJC	\N	0	Russia	2	JWGNAJCGHT@dell.com	3728605384	5	4244182731956244	2011/09	user19721	password	47	80000	M
19722	XGQTLZ	PRMQAPWIJD	5157199262 Dell Way	\N	BWKMGMH	\N	0	Germany	2	PRMQAPWIJD@dell.com	5157199262	4	3970083781983703	2008/01	user19722	password	22	20000	M
19723	IURUUH	LHYMWUUFXW	3540955539 Dell Way	\N	CHJIUQW	\N	0	Chile	2	LHYMWUUFXW@dell.com	3540955539	2	4850805166643113	2009/04	user19723	password	61	40000	M
19724	KZJFHV	MFIJZDPXZR	2061935524 Dell Way	\N	FIAZZXG	\N	0	Chile	2	MFIJZDPXZR@dell.com	2061935524	4	6359568851534278	2009/04	user19724	password	81	100000	M
19725	VJWCFJ	INSHRHEQZJ	3314801624 Dell Way	\N	ZAJZXPG	\N	0	Australia	2	INSHRHEQZJ@dell.com	3314801624	5	4885665279813111	2010/09	user19725	password	48	20000	M
19726	UBRZKZ	NDGELLVLVV	8830649233 Dell Way	\N	LEUJUBK	\N	0	Australia	2	NDGELLVLVV@dell.com	8830649233	5	5952413944527507	2010/04	user19726	password	71	20000	F
19727	UUBFTO	IATULPFGLQ	3081010497 Dell Way	\N	LGZFHKG	\N	0	Canada	2	IATULPFGLQ@dell.com	3081010497	4	7587155702058227	2010/07	user19727	password	80	60000	F
19728	QPNJEW	JYQVNVBZMN	7905568361 Dell Way	\N	FMSNWZR	\N	0	Australia	2	JYQVNVBZMN@dell.com	7905568361	3	6226767478045077	2009/04	user19728	password	26	80000	M
19729	SEGWAQ	URLINNIZAO	2301829704 Dell Way	\N	LTBHTTK	\N	0	France	2	URLINNIZAO@dell.com	2301829704	5	8194444803986699	2010/02	user19729	password	49	40000	M
19730	PNRQEM	HPVVCDUDSF	9079175127 Dell Way	\N	XTNQMYD	\N	0	Japan	2	HPVVCDUDSF@dell.com	9079175127	5	1396800075657665	2012/05	user19730	password	41	80000	M
19731	WMOAZW	QURTYMWQSU	5311158839 Dell Way	\N	KFKXDON	\N	0	Australia	2	QURTYMWQSU@dell.com	5311158839	3	1369688306935131	2012/11	user19731	password	79	80000	M
19732	IJUHFK	BXDAJAQBUA	1309056532 Dell Way	\N	HFXLTLM	\N	0	Chile	2	BXDAJAQBUA@dell.com	1309056532	3	1573341195471584	2012/05	user19732	password	80	80000	M
19733	FMZLXA	IBASBRUWSB	5879326280 Dell Way	\N	BQNUBAA	\N	0	Canada	2	IBASBRUWSB@dell.com	5879326280	1	1438399079721421	2012/12	user19733	password	73	80000	F
19734	GOPEPY	FQQGHLCAME	1477854248 Dell Way	\N	QAYSAZU	\N	0	Germany	2	FQQGHLCAME@dell.com	1477854248	5	5332321887835860	2012/08	user19734	password	24	20000	M
19735	QSAGQG	WHNESQEFUV	2456516139 Dell Way	\N	FTNGSIV	\N	0	Russia	2	WHNESQEFUV@dell.com	2456516139	2	7679889499675483	2011/05	user19735	password	81	80000	F
19736	PRHFXE	NKJFAOKUJQ	9773504275 Dell Way	\N	NWWFERZ	\N	0	China	2	NKJFAOKUJQ@dell.com	9773504275	4	1923831218387931	2009/08	user19736	password	71	40000	F
19737	KQKHVX	SEDSSNNBDB	9944706935 Dell Way	\N	XAHCSGK	\N	0	Japan	2	SEDSSNNBDB@dell.com	9944706935	3	1271332066971808	2010/04	user19737	password	47	80000	M
19738	BEZWCR	AFKTTYUWZS	7543374884 Dell Way	\N	XGUPNFH	\N	0	Germany	2	AFKTTYUWZS@dell.com	7543374884	2	1972233679145574	2012/09	user19738	password	82	80000	M
19739	BPREHS	JSLCQGZPYX	2078581799 Dell Way	\N	WTNJYUW	\N	0	Japan	2	JSLCQGZPYX@dell.com	2078581799	5	6909663270227612	2012/11	user19739	password	40	80000	M
19740	XHCFZM	XLPNROCPMZ	2868027490 Dell Way	\N	JZIHUFZ	\N	0	South Africa	2	XLPNROCPMZ@dell.com	2868027490	4	7681325441226364	2008/12	user19740	password	45	20000	M
19741	RDBRQY	CFMUUPKGOT	6614355632 Dell Way	\N	FXAACAX	\N	0	China	2	CFMUUPKGOT@dell.com	6614355632	4	4563710406888276	2010/01	user19741	password	49	40000	M
19742	OLJFKM	KWGELRLAKR	2775834103 Dell Way	\N	XLRALOI	\N	0	Australia	2	KWGELRLAKR@dell.com	2775834103	4	6565046476200224	2009/02	user19742	password	18	100000	M
19743	LHXWTH	SAMESYFCPC	2251929125 Dell Way	\N	OGCZVLB	\N	0	Australia	2	SAMESYFCPC@dell.com	2251929125	4	3014503624290228	2009/09	user19743	password	27	100000	F
19744	KXZEFS	FSXXQCAFFO	3654354379 Dell Way	\N	LIOHTPH	\N	0	South Africa	2	FSXXQCAFFO@dell.com	3654354379	3	2435140366666019	2012/08	user19744	password	29	20000	F
19745	BDGGWL	YTJOWJTBYF	3595903856 Dell Way	\N	JMNDCUZ	\N	0	France	2	YTJOWJTBYF@dell.com	3595903856	1	4487460535485298	2012/04	user19745	password	55	100000	F
19746	QFPMRO	GACCKWEICN	8199698689 Dell Way	\N	VPQYJQI	\N	0	Japan	2	GACCKWEICN@dell.com	8199698689	4	6390105193480850	2008/03	user19746	password	60	60000	M
19747	UBKMPQ	MSSXOXGRKB	1860572890 Dell Way	\N	HBARSJI	\N	0	Germany	2	MSSXOXGRKB@dell.com	1860572890	5	6602347827050836	2009/07	user19747	password	23	40000	F
19748	DQUTGG	LZEAWKSHMZ	8941878078 Dell Way	\N	JMQBWYP	\N	0	UK	2	LZEAWKSHMZ@dell.com	8941878078	2	3714070912916213	2009/04	user19748	password	57	80000	F
19749	EMEKSP	KXQGHIOUHX	8174548986 Dell Way	\N	GXZDWPC	\N	0	Russia	2	KXQGHIOUHX@dell.com	8174548986	2	2337301306892186	2008/12	user19749	password	79	60000	F
19750	ISNBIX	YYEFHTAORH	8860691445 Dell Way	\N	MQKJFMD	\N	0	Australia	2	YYEFHTAORH@dell.com	8860691445	2	2025812644045800	2012/02	user19750	password	64	100000	F
19751	IKMQIK	PNQWGQLXXY	7157849943 Dell Way	\N	OIHUUKU	\N	0	Japan	2	PNQWGQLXXY@dell.com	7157849943	5	5250852307770401	2012/07	user19751	password	45	40000	M
19752	USODCD	QTAXKLVHJJ	8973587987 Dell Way	\N	PREKCZB	\N	0	Russia	2	QTAXKLVHJJ@dell.com	8973587987	3	6135421698447317	2010/12	user19752	password	76	40000	M
19753	NXVPAM	JBJTMEBWOQ	7094522825 Dell Way	\N	OSBQSDK	\N	0	Germany	2	JBJTMEBWOQ@dell.com	7094522825	5	1236210882663726	2010/10	user19753	password	44	40000	F
19754	GDXHPG	IYZVDBSSRG	3444672458 Dell Way	\N	LTXDWHS	\N	0	Germany	2	IYZVDBSSRG@dell.com	3444672458	4	2334860165603459	2008/02	user19754	password	50	40000	F
19755	OFQDMZ	CMUGNNYFTK	9896570705 Dell Way	\N	YQNVYGJ	\N	0	Chile	2	CMUGNNYFTK@dell.com	9896570705	3	3294134647119790	2008/12	user19755	password	60	60000	M
19756	UCRGCU	SWBFJAKDKJ	1577657334 Dell Way	\N	TYESEOX	\N	0	Canada	2	SWBFJAKDKJ@dell.com	1577657334	1	3376049721147865	2008/09	user19756	password	70	60000	M
19757	VGVXAO	UCTECEHMOB	8458836223 Dell Way	\N	KSTPHRT	\N	0	China	2	UCTECEHMOB@dell.com	8458836223	1	4315080263651908	2010/09	user19757	password	85	20000	M
19758	EYMFMG	HGKJLSWZTH	6864728268 Dell Way	\N	SNWZEQI	\N	0	Australia	2	HGKJLSWZTH@dell.com	6864728268	4	6174651498906315	2009/08	user19758	password	68	100000	M
19759	QLACSH	IDRTVNTPUL	5145225202 Dell Way	\N	CRLGHTG	\N	0	UK	2	IDRTVNTPUL@dell.com	5145225202	5	4001749895513058	2008/07	user19759	password	40	100000	F
19760	TWGMEP	PVILJCADNC	5135979058 Dell Way	\N	UZJCTQA	\N	0	Canada	2	PVILJCADNC@dell.com	5135979058	2	3521598292980343	2012/08	user19760	password	29	20000	F
19761	BKXFZN	BIYKKYOYBJ	8320515270 Dell Way	\N	XLLQBLV	\N	0	Germany	2	BIYKKYOYBJ@dell.com	8320515270	1	5536859549116344	2010/04	user19761	password	65	100000	F
19762	BUNAHO	IGZSFNQHXO	2186607591 Dell Way	\N	SIETUAH	\N	0	Japan	2	IGZSFNQHXO@dell.com	2186607591	4	1711016955785453	2010/06	user19762	password	89	80000	F
19763	UGMBVU	IUNNIEUFTM	3690376865 Dell Way	\N	OYGIYNY	\N	0	Australia	2	IUNNIEUFTM@dell.com	3690376865	1	5309814608655870	2011/12	user19763	password	31	20000	M
19764	LRVGME	AARIEMOYZC	4399590697 Dell Way	\N	WGLUTJW	\N	0	Australia	2	AARIEMOYZC@dell.com	4399590697	2	8028792794793845	2009/07	user19764	password	88	20000	M
19765	QZFCDF	CVOHIDFHFB	1836827499 Dell Way	\N	NQWHATJ	\N	0	China	2	CVOHIDFHFB@dell.com	1836827499	1	7794325310271234	2011/02	user19765	password	82	80000	M
19766	WVVABY	VPGETMLYOZ	8063301626 Dell Way	\N	PKHPDQZ	\N	0	Chile	2	VPGETMLYOZ@dell.com	8063301626	4	8916185302659870	2012/08	user19766	password	53	80000	M
19767	HMNIKJ	YRNRDZQRYG	6337867848 Dell Way	\N	BGWFXVM	\N	0	Japan	2	YRNRDZQRYG@dell.com	6337867848	2	6169662078842521	2009/10	user19767	password	32	80000	F
19768	RGLBPK	SDCWCSNBYP	6450287752 Dell Way	\N	HVUFQGW	\N	0	Chile	2	SDCWCSNBYP@dell.com	6450287752	3	5307297665625811	2010/08	user19768	password	33	60000	F
19769	MAKCKD	FMZHFMIEBQ	2478534497 Dell Way	\N	ZWVQDSX	\N	0	Russia	2	FMZHFMIEBQ@dell.com	2478534497	2	2401699955109507	2012/08	user19769	password	70	20000	F
19770	SNDDRI	QQPWCYBEOA	9341462378 Dell Way	\N	AJRDCOW	\N	0	Chile	2	QQPWCYBEOA@dell.com	9341462378	1	1619603085797280	2010/09	user19770	password	33	60000	F
19771	TSPKAG	BQCDODIDEI	4154390571 Dell Way	\N	NWMPKIV	\N	0	China	2	BQCDODIDEI@dell.com	4154390571	5	8624491333961488	2008/02	user19771	password	48	60000	M
19772	CDHDJI	UMMJQUMUDZ	3905458658 Dell Way	\N	QPPBYKK	\N	0	Chile	2	UMMJQUMUDZ@dell.com	3905458658	2	4263284745626152	2010/08	user19772	password	83	40000	M
19773	APXKXS	XJBNDOIGOZ	6973717849 Dell Way	\N	WDAUOKB	\N	0	South Africa	2	XJBNDOIGOZ@dell.com	6973717849	3	3811797319911420	2009/05	user19773	password	62	20000	F
19774	FAUCSR	LUEPIMVXLS	9990395432 Dell Way	\N	AMMOXOL	\N	0	Germany	2	LUEPIMVXLS@dell.com	9990395432	4	8918029074091465	2009/05	user19774	password	89	80000	M
19775	ZMQSDC	MHRVUNSGFS	5505074115 Dell Way	\N	SRHPGTE	\N	0	Chile	2	MHRVUNSGFS@dell.com	5505074115	1	6233221380040050	2012/01	user19775	password	38	60000	F
19776	TCSWEF	EVAZJTFOMX	7596043004 Dell Way	\N	GTNMNRT	\N	0	Australia	2	EVAZJTFOMX@dell.com	7596043004	2	8927533666137607	2011/08	user19776	password	41	80000	F
19777	KMGPRK	LRJUKPIWNO	1981151998 Dell Way	\N	QABDSUD	\N	0	France	2	LRJUKPIWNO@dell.com	1981151998	1	2829874613322317	2011/05	user19777	password	87	20000	M
19778	KHICST	TCOERWBELR	1036906454 Dell Way	\N	FMVYHZK	\N	0	China	2	TCOERWBELR@dell.com	1036906454	3	1882173696067184	2009/07	user19778	password	29	20000	M
19779	LLBDFU	GTZXQACBRI	3102757831 Dell Way	\N	ONGVMQF	\N	0	France	2	GTZXQACBRI@dell.com	3102757831	2	8528635646216572	2011/06	user19779	password	87	80000	M
19780	KUBPPH	JPFZPHBHQP	9830222334 Dell Way	\N	UWLGNRT	\N	0	Russia	2	JPFZPHBHQP@dell.com	9830222334	3	5788127883803100	2010/07	user19780	password	38	40000	M
19781	CLOSTX	HYXWGZEWOY	5890792841 Dell Way	\N	TAFGRYA	\N	0	Japan	2	HYXWGZEWOY@dell.com	5890792841	3	1919616248458624	2008/10	user19781	password	52	20000	M
19782	XOQRMX	PJUWIZTXXM	3786223806 Dell Way	\N	XDTOCTF	\N	0	Japan	2	PJUWIZTXXM@dell.com	3786223806	2	7374987319577486	2008/10	user19782	password	69	20000	M
19783	GSJSPZ	CKVLJPIHBG	3967356025 Dell Way	\N	KVUNPAD	\N	0	UK	2	CKVLJPIHBG@dell.com	3967356025	5	1386680826079100	2008/07	user19783	password	25	100000	M
19784	UFOKEQ	VABEPKMRQW	4298178495 Dell Way	\N	NKJCLNA	\N	0	Russia	2	VABEPKMRQW@dell.com	4298178495	1	8979830095078797	2012/02	user19784	password	70	80000	M
19785	YHJDXE	EZJTJVLZSZ	2184538464 Dell Way	\N	KCBVQCP	\N	0	UK	2	EZJTJVLZSZ@dell.com	2184538464	3	9293053870555014	2009/03	user19785	password	66	40000	F
19786	YQGWVK	VEEFAQETPP	5467652756 Dell Way	\N	WRKMTAM	\N	0	South Africa	2	VEEFAQETPP@dell.com	5467652756	3	2664898709394038	2011/01	user19786	password	49	100000	F
19787	BCXWNS	BSXCJCVYRS	1996243183 Dell Way	\N	QCFKDSH	\N	0	Japan	2	BSXCJCVYRS@dell.com	1996243183	3	3843379916157574	2008/12	user19787	password	29	40000	M
19788	GCVUVX	NTZWWVVNNL	6836604334 Dell Way	\N	QSWTKEJ	\N	0	Germany	2	NTZWWVVNNL@dell.com	6836604334	4	7492766809649766	2010/11	user19788	password	86	60000	F
19789	AKXWHK	PHGLCCZPOQ	4964561737 Dell Way	\N	IKKTOTH	\N	0	Chile	2	PHGLCCZPOQ@dell.com	4964561737	1	8108760836534203	2009/12	user19789	password	42	40000	M
19790	SHVASL	HZXJBXZQNI	4614134176 Dell Way	\N	AXCPRKV	\N	0	Canada	2	HZXJBXZQNI@dell.com	4614134176	4	4638741147238761	2009/12	user19790	password	76	40000	M
19791	CERVQZ	VOJWLIMZRN	5907475351 Dell Way	\N	XTDOEYS	\N	0	Germany	2	VOJWLIMZRN@dell.com	5907475351	1	9182365302927792	2010/11	user19791	password	36	20000	F
19792	LWVBVQ	PENBNAAFOX	3598468940 Dell Way	\N	ZRMDPER	\N	0	Canada	2	PENBNAAFOX@dell.com	3598468940	3	6668313459493220	2008/11	user19792	password	75	20000	F
19793	QAIMRY	QEZEFAJTYI	7553759102 Dell Way	\N	KKLAPDD	\N	0	South Africa	2	QEZEFAJTYI@dell.com	7553759102	4	1804805133957415	2010/07	user19793	password	38	100000	F
19794	IERZCI	ECMKCWDAFO	5054431790 Dell Way	\N	LROBURY	\N	0	Germany	2	ECMKCWDAFO@dell.com	5054431790	1	1781801960431039	2008/05	user19794	password	85	40000	M
19795	CXQEFV	HSFJOIKTWW	9192371476 Dell Way	\N	KKXFCWS	\N	0	Germany	2	HSFJOIKTWW@dell.com	9192371476	5	6069692268036306	2009/09	user19795	password	74	100000	M
19796	RNAWJH	OORDXBXUXH	1409475738 Dell Way	\N	FVNHRGW	\N	0	Germany	2	OORDXBXUXH@dell.com	1409475738	3	8526540711056442	2011/03	user19796	password	71	60000	M
19797	GPTQWI	ENLBPIWNQB	6397389373 Dell Way	\N	IDIAJEP	\N	0	France	2	ENLBPIWNQB@dell.com	6397389373	3	2828346713911742	2011/03	user19797	password	76	80000	F
19798	KKBHSF	VDHKMDXDEG	3686779289 Dell Way	\N	HNGRSWC	\N	0	China	2	VDHKMDXDEG@dell.com	3686779289	2	1959243937861174	2010/01	user19798	password	73	100000	F
19799	DYTVEO	ZMZMQXPVDW	9037116811 Dell Way	\N	IKNBGPJ	\N	0	Germany	2	ZMZMQXPVDW@dell.com	9037116811	3	1272025153972208	2012/03	user19799	password	86	60000	F
19800	XFFCTF	OTREQHAUDJ	3488029596 Dell Way	\N	ERKLHUA	\N	0	Canada	2	OTREQHAUDJ@dell.com	3488029596	1	2355533626861870	2010/12	user19800	password	61	100000	M
19801	UDYOIM	HZRXGSSKBW	4089963994 Dell Way	\N	CLIJGIO	\N	0	Germany	2	HZRXGSSKBW@dell.com	4089963994	4	1419023380149155	2009/04	user19801	password	86	20000	F
19802	BCRJPY	JHWQZOBALD	7965268676 Dell Way	\N	MTNTBBH	\N	0	France	2	JHWQZOBALD@dell.com	7965268676	2	7444424882996828	2008/04	user19802	password	82	20000	F
19803	ZVSPUC	WRTVFUWRYJ	7133148215 Dell Way	\N	KMCMOJX	\N	0	China	2	WRTVFUWRYJ@dell.com	7133148215	4	4526855048723519	2012/06	user19803	password	59	40000	F
19804	KZBEBX	VUTBPQTNZD	2204026519 Dell Way	\N	ZCQOLNW	\N	0	Canada	2	VUTBPQTNZD@dell.com	2204026519	2	1679647129960358	2011/10	user19804	password	42	20000	F
19805	IDKJBF	EVHTMAGMEG	9329955966 Dell Way	\N	OVVAIRD	\N	0	France	2	EVHTMAGMEG@dell.com	9329955966	2	1871944551356136	2011/07	user19805	password	32	100000	M
19806	JJGKPK	GWDTXKFBRT	2108970222 Dell Way	\N	XMTFDXS	\N	0	Australia	2	GWDTXKFBRT@dell.com	2108970222	4	8284899801015855	2011/12	user19806	password	74	60000	F
19807	DUTSEA	OHTMRZOISL	2392680390 Dell Way	\N	UMRYKJA	\N	0	Germany	2	OHTMRZOISL@dell.com	2392680390	5	2872725479770452	2008/08	user19807	password	72	60000	M
19808	NGKRGZ	ZALRZZZSKU	6048048940 Dell Way	\N	FBTQLTE	\N	0	Germany	2	ZALRZZZSKU@dell.com	6048048940	2	7550566888414324	2008/02	user19808	password	33	100000	M
19809	LGISFI	TRZTQZMBTS	8864442523 Dell Way	\N	DMIOGND	\N	0	Russia	2	TRZTQZMBTS@dell.com	8864442523	5	9503370292484760	2012/01	user19809	password	75	80000	M
19810	BZGGIA	YHTOGGQAYT	3754668258 Dell Way	\N	NHITULO	\N	0	Japan	2	YHTOGGQAYT@dell.com	3754668258	3	6994971430860460	2009/04	user19810	password	41	100000	F
19811	IEPQEN	YYCEESFDMT	5901523944 Dell Way	\N	LUMFGBX	\N	0	Germany	2	YYCEESFDMT@dell.com	5901523944	3	9290484653785826	2012/11	user19811	password	78	20000	F
19812	AUVEIT	DKYIDDLQWX	6115726321 Dell Way	\N	KJCQKAE	\N	0	UK	2	DKYIDDLQWX@dell.com	6115726321	1	8068563651293517	2010/12	user19812	password	88	80000	M
19813	TLDBEG	LCPPGBFDYQ	6075806120 Dell Way	\N	MBHWBLV	\N	0	Japan	2	LCPPGBFDYQ@dell.com	6075806120	4	1565059150103479	2010/07	user19813	password	68	60000	F
19814	DPJIWV	LLLSMQVKHH	6598571373 Dell Way	\N	LOEMAAC	\N	0	Germany	2	LLLSMQVKHH@dell.com	6598571373	1	1708059941884130	2008/11	user19814	password	56	60000	F
19815	CXIZSU	KDMWUHGBPS	5347836677 Dell Way	\N	QTFQUIF	\N	0	China	2	KDMWUHGBPS@dell.com	5347836677	2	6370270366780460	2009/10	user19815	password	26	40000	M
19816	ZSXSMH	WYDRGKSVDI	5228994110 Dell Way	\N	PIZJQEU	\N	0	Canada	2	WYDRGKSVDI@dell.com	5228994110	2	5243386915419251	2009/06	user19816	password	78	40000	F
19817	NCFAKB	YNSFYLACUQ	2321608883 Dell Way	\N	KTABYUE	\N	0	France	2	YNSFYLACUQ@dell.com	2321608883	4	7312495009507985	2011/06	user19817	password	84	20000	M
19818	AIAKJY	YCEXNEZIVJ	2942742454 Dell Way	\N	BVKAPPL	\N	0	Russia	2	YCEXNEZIVJ@dell.com	2942742454	1	4306693612132222	2011/01	user19818	password	53	80000	F
19819	URMEQK	GUHUZGCUQE	7684083560 Dell Way	\N	PBEEQPY	\N	0	South Africa	2	GUHUZGCUQE@dell.com	7684083560	2	5672782192472369	2011/10	user19819	password	32	100000	M
19820	WITNSZ	HATHGVBXZR	1536919085 Dell Way	\N	YEVOUTK	\N	0	Germany	2	HATHGVBXZR@dell.com	1536919085	5	3787259160075337	2012/02	user19820	password	30	40000	M
19821	MDMFCU	FWBMSDKSUI	2597401912 Dell Way	\N	WQWQKGE	\N	0	France	2	FWBMSDKSUI@dell.com	2597401912	3	3630246902350336	2009/08	user19821	password	68	40000	F
19822	VTJYOP	UQBNULFOUC	4645180154 Dell Way	\N	FRTPYYB	\N	0	Canada	2	UQBNULFOUC@dell.com	4645180154	2	4517181485891342	2008/01	user19822	password	66	20000	M
19823	LNUZCP	QECKQIYLLE	2306068500 Dell Way	\N	CFTADUD	\N	0	Germany	2	QECKQIYLLE@dell.com	2306068500	3	6182788658887148	2008/03	user19823	password	73	20000	M
19824	HVPKKF	PNQGWPRHTU	4876725531 Dell Way	\N	MMUPHXD	\N	0	France	2	PNQGWPRHTU@dell.com	4876725531	4	6516756617929787	2011/06	user19824	password	65	40000	M
19825	MUEXAU	KQBHGSOZMB	5649582450 Dell Way	\N	MHRTFUE	\N	0	Japan	2	KQBHGSOZMB@dell.com	5649582450	4	3108101172838360	2012/06	user19825	password	50	80000	M
19826	GYVHTF	XUMENBDADP	3892627381 Dell Way	\N	HUIMPNC	\N	0	Canada	2	XUMENBDADP@dell.com	3892627381	2	2012084121815860	2011/10	user19826	password	82	80000	F
19827	VMHPSF	JFJWHNWKCE	1922407736 Dell Way	\N	FLQVZTY	\N	0	Chile	2	JFJWHNWKCE@dell.com	1922407736	1	1568275776691734	2012/12	user19827	password	72	100000	M
19828	GFIYLS	EVPLIMWLQB	8630276326 Dell Way	\N	XHWWBUE	\N	0	Canada	2	EVPLIMWLQB@dell.com	8630276326	2	1409734450280666	2011/12	user19828	password	88	60000	F
19829	EWEQOI	MEUUQQGHSD	4566874994 Dell Way	\N	POAQJEU	\N	0	Chile	2	MEUUQQGHSD@dell.com	4566874994	5	9846125235315412	2009/10	user19829	password	55	60000	M
19830	JTQYCC	DWXTNDBFGQ	8894321275 Dell Way	\N	TGGDLBI	\N	0	South Africa	2	DWXTNDBFGQ@dell.com	8894321275	2	2831296221818775	2011/11	user19830	password	75	80000	F
19831	OHEQKH	NHAAKBGRRA	8215522910 Dell Way	\N	YYDJZMF	\N	0	South Africa	2	NHAAKBGRRA@dell.com	8215522910	3	5870405655354262	2011/03	user19831	password	33	100000	M
19832	NAKXHX	EIYOKEGCEE	2575950116 Dell Way	\N	AIOAUTW	\N	0	Japan	2	EIYOKEGCEE@dell.com	2575950116	3	3154113349504769	2009/08	user19832	password	24	20000	F
19833	CNAKLF	SJUCOAFTFG	5982634963 Dell Way	\N	BUGWODM	\N	0	Russia	2	SJUCOAFTFG@dell.com	5982634963	4	1863824934698641	2008/10	user19833	password	34	40000	M
19834	TJHEOA	OJDCJIWPOX	9860801549 Dell Way	\N	JVUYYHQ	\N	0	France	2	OJDCJIWPOX@dell.com	9860801549	4	7134178196080030	2011/12	user19834	password	18	80000	M
19835	JZWYZK	HDNRLJHAHQ	9739735171 Dell Way	\N	VBPTIFG	\N	0	China	2	HDNRLJHAHQ@dell.com	9739735171	5	1994611893780529	2012/12	user19835	password	76	80000	F
19836	UMGUXN	XKFITMJADE	1756766171 Dell Way	\N	CSXLYET	\N	0	UK	2	XKFITMJADE@dell.com	1756766171	5	8613288882654161	2008/08	user19836	password	52	40000	F
19837	ZOGWCD	GIMAUVAYZD	2408519094 Dell Way	\N	QXOPBHM	\N	0	Canada	2	GIMAUVAYZD@dell.com	2408519094	2	2403564991429448	2012/10	user19837	password	53	40000	M
19838	BNREQY	MDYHYZFYCW	3721971057 Dell Way	\N	VQLXYYA	\N	0	Australia	2	MDYHYZFYCW@dell.com	3721971057	1	9129325365647676	2008/09	user19838	password	30	100000	M
19839	RPXINK	LLRKKXJMUF	3753792446 Dell Way	\N	DGCBEDD	\N	0	France	2	LLRKKXJMUF@dell.com	3753792446	1	6559919563587756	2012/03	user19839	password	57	80000	M
19840	DPFQZR	BRBMPLZJQC	3889930009 Dell Way	\N	PSDUVHH	\N	0	Canada	2	BRBMPLZJQC@dell.com	3889930009	5	2139101537875831	2010/06	user19840	password	78	60000	M
19841	LQELHG	CJSRURBLUQ	6105376531 Dell Way	\N	EXKZFRD	\N	0	Germany	2	CJSRURBLUQ@dell.com	6105376531	2	1462081040721386	2012/02	user19841	password	52	60000	M
19842	CSZKYC	URTPIVACLE	6349273770 Dell Way	\N	AWEFNIT	\N	0	Australia	2	URTPIVACLE@dell.com	6349273770	4	1816471619997173	2011/04	user19842	password	63	40000	F
19843	IFUHHO	YBDHWEKIIL	2709316819 Dell Way	\N	EMRSVKU	\N	0	France	2	YBDHWEKIIL@dell.com	2709316819	5	1983241364359855	2010/07	user19843	password	43	100000	M
19844	OQDWFC	YJKVNUDWFI	7289590067 Dell Way	\N	JWAEHVO	\N	0	France	2	YJKVNUDWFI@dell.com	7289590067	4	9319462854415180	2009/01	user19844	password	73	20000	M
19845	KFMPIL	YSGMMKISSR	1665137887 Dell Way	\N	PSVWNKI	\N	0	Chile	2	YSGMMKISSR@dell.com	1665137887	2	4898826963268221	2008/01	user19845	password	55	80000	F
19846	TEABPZ	TWLGGUZYLP	1584800845 Dell Way	\N	QHLERUJ	\N	0	Russia	2	TWLGGUZYLP@dell.com	1584800845	5	8737410099711270	2008/04	user19846	password	59	60000	F
19847	TOCJNW	GZDMTCKERB	4791759453 Dell Way	\N	MDFEYPX	\N	0	UK	2	GZDMTCKERB@dell.com	4791759453	4	1810337797738611	2011/05	user19847	password	62	80000	F
19848	DXMRTS	QWFJZPOQRB	8957611086 Dell Way	\N	UXFSNCS	\N	0	UK	2	QWFJZPOQRB@dell.com	8957611086	4	7121332590002567	2009/05	user19848	password	52	40000	M
19849	JUFDNW	ASGZIVQAWL	6789044427 Dell Way	\N	XBDLEVJ	\N	0	Australia	2	ASGZIVQAWL@dell.com	6789044427	1	3551622052211314	2008/07	user19849	password	62	80000	M
19850	KVAYSB	QYBZTRZQCX	7539718840 Dell Way	\N	RGIWCRX	\N	0	Russia	2	QYBZTRZQCX@dell.com	7539718840	1	8099057040177286	2009/10	user19850	password	47	20000	F
19851	GEEYFV	XGUQYTHBRY	9249949690 Dell Way	\N	HZUKRSD	\N	0	China	2	XGUQYTHBRY@dell.com	9249949690	5	6684180888347328	2011/04	user19851	password	74	100000	M
19852	YCNEYK	LSBKMILDGT	3031781786 Dell Way	\N	CBEUUHE	\N	0	Russia	2	LSBKMILDGT@dell.com	3031781786	4	4897217432502657	2010/07	user19852	password	45	20000	M
19853	MQRKAD	DBNPKZTQSW	6103593395 Dell Way	\N	SWQNEUF	\N	0	China	2	DBNPKZTQSW@dell.com	6103593395	4	9535741713829340	2008/01	user19853	password	22	80000	M
19854	SIYSLC	UZREYLVQHO	9514483480 Dell Way	\N	NXBRSHC	\N	0	Chile	2	UZREYLVQHO@dell.com	9514483480	1	4536713382229209	2012/02	user19854	password	20	60000	M
19855	JMNVOH	UGMSRIJZWW	6974278079 Dell Way	\N	WYOPFQV	\N	0	Canada	2	UGMSRIJZWW@dell.com	6974278079	2	2335434321779758	2011/04	user19855	password	66	60000	M
19856	DBLRJF	YWYPEHOADL	2041862873 Dell Way	\N	YSAEIWI	\N	0	UK	2	YWYPEHOADL@dell.com	2041862873	3	7829264917410911	2009/02	user19856	password	40	20000	F
19857	JLZTRX	PPNUWCUANT	7765384098 Dell Way	\N	SOYBLGB	\N	0	Germany	2	PPNUWCUANT@dell.com	7765384098	5	9547334481030704	2012/02	user19857	password	88	20000	F
19858	KEGCCW	RPQORLOFFH	2524322974 Dell Way	\N	UDIGKJU	\N	0	Canada	2	RPQORLOFFH@dell.com	2524322974	4	1683012736495584	2009/09	user19858	password	37	80000	F
19859	LBFNXX	COLUAAAGHU	6115856257 Dell Way	\N	KPAVZVZ	\N	0	Canada	2	COLUAAAGHU@dell.com	6115856257	1	4917021824512631	2009/04	user19859	password	34	60000	M
19860	GQHENK	TZETZEZHZK	3298608249 Dell Way	\N	XZFWVEA	\N	0	China	2	TZETZEZHZK@dell.com	3298608249	3	6928517661523075	2010/09	user19860	password	23	40000	M
19861	SQCFAW	FFPEJPMIZJ	7581049405 Dell Way	\N	IEGDJHN	\N	0	Japan	2	FFPEJPMIZJ@dell.com	7581049405	1	2974156117998063	2010/03	user19861	password	59	40000	M
19862	FMEGIJ	LXOUNADNKM	3889268468 Dell Way	\N	RQQBXDS	\N	0	Japan	2	LXOUNADNKM@dell.com	3889268468	5	1511947995983064	2010/06	user19862	password	47	60000	M
19863	WRYFBJ	DPEQQIDAUV	5539293117 Dell Way	\N	RKXPOPF	\N	0	South Africa	2	DPEQQIDAUV@dell.com	5539293117	2	5077044782228768	2012/09	user19863	password	88	80000	M
19864	QQURZX	HENXMRYHMP	7393677480 Dell Way	\N	SJFGYLD	\N	0	France	2	HENXMRYHMP@dell.com	7393677480	3	5063707644585520	2010/07	user19864	password	28	100000	F
19865	UTXTQE	XECJVARHQJ	4093891335 Dell Way	\N	RVPPGTB	\N	0	UK	2	XECJVARHQJ@dell.com	4093891335	3	4348026201594621	2012/08	user19865	password	43	20000	F
19866	CZETEC	XGMSHDAXMR	8617335971 Dell Way	\N	TCGZVIY	\N	0	Canada	2	XGMSHDAXMR@dell.com	8617335971	2	1813328766729682	2010/09	user19866	password	32	100000	M
19867	EDNJFL	PSEWVETIVN	7952355395 Dell Way	\N	KCMGLLL	\N	0	Chile	2	PSEWVETIVN@dell.com	7952355395	3	7999593848362566	2010/09	user19867	password	70	40000	M
19868	VUHBFW	TJSPNMXJZI	6406540839 Dell Way	\N	LMPWYBD	\N	0	Russia	2	TJSPNMXJZI@dell.com	6406540839	5	2432121146470308	2009/08	user19868	password	47	40000	F
19869	ENNKKH	TDXHPVRPEC	1633191697 Dell Way	\N	CTZAVDT	\N	0	France	2	TDXHPVRPEC@dell.com	1633191697	5	7839550874661655	2011/04	user19869	password	19	20000	F
19870	OSWYAQ	BXYRSPHWSJ	1381696674 Dell Way	\N	QRKLVDW	\N	0	UK	2	BXYRSPHWSJ@dell.com	1381696674	4	6523648813832552	2009/08	user19870	password	76	100000	F
19871	NREOHF	LFXEUEBMOS	7156270172 Dell Way	\N	EZEADBX	\N	0	Canada	2	LFXEUEBMOS@dell.com	7156270172	3	5567345591261983	2009/05	user19871	password	41	60000	M
19872	ZSKHYW	MVBHADUPVZ	5023414268 Dell Way	\N	OZZSAXW	\N	0	Russia	2	MVBHADUPVZ@dell.com	5023414268	2	1426461300812661	2011/09	user19872	password	62	80000	M
19873	IBZHYL	CATDDOTYOH	3358781558 Dell Way	\N	YNAYLWQ	\N	0	South Africa	2	CATDDOTYOH@dell.com	3358781558	4	7150248563382775	2012/04	user19873	password	42	80000	M
19874	KPXJBA	JVDNJWMXEK	7080169013 Dell Way	\N	LFIXBZV	\N	0	China	2	JVDNJWMXEK@dell.com	7080169013	3	3668786352500320	2012/10	user19874	password	86	80000	F
19875	NNPPNZ	LRMUNYSSIE	4515204153 Dell Way	\N	XRCZRXI	\N	0	China	2	LRMUNYSSIE@dell.com	4515204153	4	3818710914812982	2009/07	user19875	password	85	60000	F
19876	KBSYAD	PMYDLQVUVT	7367569368 Dell Way	\N	MXTDVCL	\N	0	Chile	2	PMYDLQVUVT@dell.com	7367569368	4	4848675283137709	2009/09	user19876	password	82	40000	F
19877	YBBYFQ	LDTXUPRPJD	5407455583 Dell Way	\N	NCGJFSO	\N	0	UK	2	LDTXUPRPJD@dell.com	5407455583	5	2563610022887587	2008/11	user19877	password	57	40000	M
19878	PITVZE	YTBSITISWW	7623504097 Dell Way	\N	VDFAWTX	\N	0	China	2	YTBSITISWW@dell.com	7623504097	1	5678686840925366	2011/08	user19878	password	77	40000	F
19879	DDBDIZ	WKSEDAXAWS	7484597370 Dell Way	\N	DBSZVQI	\N	0	Germany	2	WKSEDAXAWS@dell.com	7484597370	5	2378126179333776	2009/08	user19879	password	57	80000	M
19880	RRYZQU	JJZNJWNGOQ	8163360583 Dell Way	\N	IHQDXYR	\N	0	Japan	2	JJZNJWNGOQ@dell.com	8163360583	5	9947377573698760	2010/05	user19880	password	61	40000	F
19881	GEBXZL	GYYQVLXKCF	8683798369 Dell Way	\N	RSIPRAG	\N	0	France	2	GYYQVLXKCF@dell.com	8683798369	2	9329236585181208	2009/10	user19881	password	31	40000	F
19882	JJZJUG	HTXDEUNHZE	3358790544 Dell Way	\N	AIURJAE	\N	0	Chile	2	HTXDEUNHZE@dell.com	3358790544	1	4959755910094828	2008/04	user19882	password	71	20000	M
19883	CEZWKH	QIKUCYCCDC	1015404559 Dell Way	\N	LXTUYXZ	\N	0	Canada	2	QIKUCYCCDC@dell.com	1015404559	3	3582118475344032	2009/02	user19883	password	51	100000	F
19884	QXDBFT	JPOMOQPRTA	2912972306 Dell Way	\N	OMUMKUR	\N	0	France	2	JPOMOQPRTA@dell.com	2912972306	5	7196178056765348	2009/06	user19884	password	61	80000	F
19885	MUDROM	HCYVTNMMOB	3039571046 Dell Way	\N	ZIOKDGV	\N	0	China	2	HCYVTNMMOB@dell.com	3039571046	3	7463500346988440	2011/02	user19885	password	44	80000	M
19886	DWHRIP	UHLOVYBJAA	8006633452 Dell Way	\N	SOLVVGE	\N	0	Australia	2	UHLOVYBJAA@dell.com	8006633452	5	7374038446228952	2012/04	user19886	password	50	60000	F
19887	HUCQKX	XWLTUMCUNV	7594474360 Dell Way	\N	JYREFVF	\N	0	UK	2	XWLTUMCUNV@dell.com	7594474360	5	8961884017102421	2012/05	user19887	password	45	40000	M
19888	EMHPJF	LUYGHBBUXK	7942438006 Dell Way	\N	TOPZKVY	\N	0	Canada	2	LUYGHBBUXK@dell.com	7942438006	5	1974110584240406	2008/03	user19888	password	53	100000	F
19889	YDZHIL	CHRJJSEGDX	7104849631 Dell Way	\N	VSWFOVI	\N	0	China	2	CHRJJSEGDX@dell.com	7104849631	3	5291441460140050	2012/12	user19889	password	40	40000	M
19890	LHEUTH	CKRLCVSFTO	5694726819 Dell Way	\N	YQTMLCV	\N	0	Canada	2	CKRLCVSFTO@dell.com	5694726819	2	1323170416522771	2010/08	user19890	password	43	40000	F
19891	QNUJUX	ULIWHBCAPA	6548590264 Dell Way	\N	QJNCLIF	\N	0	UK	2	ULIWHBCAPA@dell.com	6548590264	2	4715976868756116	2009/08	user19891	password	72	40000	F
19892	GAQBXK	NGHUIKVYKM	1328533153 Dell Way	\N	HYOTGUS	\N	0	South Africa	2	NGHUIKVYKM@dell.com	1328533153	1	1771825379226356	2011/11	user19892	password	41	100000	F
19893	JOEHZS	OGNWRIUBUC	6859433982 Dell Way	\N	AJVGDOD	\N	0	Canada	2	OGNWRIUBUC@dell.com	6859433982	2	8345782333053649	2010/07	user19893	password	70	80000	M
19894	GVEFNS	MBPDKKFFMF	8717505254 Dell Way	\N	OIMSWQW	\N	0	Germany	2	MBPDKKFFMF@dell.com	8717505254	4	1315869292709976	2010/05	user19894	password	66	40000	M
19895	MMXAFK	CUNMFTRRZG	5634936738 Dell Way	\N	AMYXCVL	\N	0	UK	2	CUNMFTRRZG@dell.com	5634936738	3	4230776933953166	2012/02	user19895	password	66	60000	M
19896	DMQJWS	EKFJEXBDDB	8701945152 Dell Way	\N	PCZSYKR	\N	0	France	2	EKFJEXBDDB@dell.com	8701945152	1	4263951044064015	2012/09	user19896	password	87	80000	M
19897	LGFIZJ	SFSXCTAGVQ	1239698500 Dell Way	\N	IUJGEAS	\N	0	Australia	2	SFSXCTAGVQ@dell.com	1239698500	1	1115211907774209	2011/01	user19897	password	63	60000	F
19898	WTUWCN	BVKDOLJJCS	7811851337 Dell Way	\N	DLZILRI	\N	0	France	2	BVKDOLJJCS@dell.com	7811851337	2	2561612254939973	2011/12	user19898	password	70	40000	M
19899	MASONT	KYWYJGHLZL	5122595811 Dell Way	\N	XYTIQCU	\N	0	France	2	KYWYJGHLZL@dell.com	5122595811	5	2675394796766341	2010/09	user19899	password	49	40000	F
19900	LZSZSC	YPBIWJUVUR	7588779662 Dell Way	\N	UOZLRUW	\N	0	Canada	2	YPBIWJUVUR@dell.com	7588779662	1	6030234781559557	2010/06	user19900	password	78	60000	M
19901	UHXNKW	DMEZVYUQQP	9403442148 Dell Way	\N	FPBWJXZ	\N	0	Canada	2	DMEZVYUQQP@dell.com	9403442148	3	5753951847087592	2010/05	user19901	password	24	40000	F
19902	KGSUCV	GHUCGPSWFX	3780105884 Dell Way	\N	LGTVDTY	\N	0	Australia	2	GHUCGPSWFX@dell.com	3780105884	3	5270183009095490	2011/07	user19902	password	76	100000	M
19903	BPUDKB	LFDRUVNATZ	3382049118 Dell Way	\N	GNVKHUL	\N	0	Germany	2	LFDRUVNATZ@dell.com	3382049118	5	3492801447398961	2012/09	user19903	password	29	100000	M
19904	TPYEQJ	JTAEPOEJNK	2768049129 Dell Way	\N	WIUDDGT	\N	0	China	2	JTAEPOEJNK@dell.com	2768049129	1	3065640777349472	2012/02	user19904	password	21	80000	M
19905	QQBHAL	BAPQPTACEW	7828150036 Dell Way	\N	LZAOGTY	\N	0	France	2	BAPQPTACEW@dell.com	7828150036	1	4337885783519596	2012/03	user19905	password	24	100000	M
19906	SXDTIE	UXVJRVLWSX	5948450465 Dell Way	\N	VSLBMJN	\N	0	Chile	2	UXVJRVLWSX@dell.com	5948450465	5	2431722507346421	2011/12	user19906	password	90	80000	M
19907	XULFYF	DUOUQARIXM	9738403739 Dell Way	\N	BIONSCT	\N	0	Chile	2	DUOUQARIXM@dell.com	9738403739	5	1320401735603809	2012/12	user19907	password	66	80000	M
19908	LCAKHD	EWYUWPDTCE	4557405082 Dell Way	\N	CRSVTMC	\N	0	Russia	2	EWYUWPDTCE@dell.com	4557405082	1	7008703293278814	2009/10	user19908	password	40	20000	F
19909	KDPRHU	NGOKWREZWG	3390061270 Dell Way	\N	QOBKBDD	\N	0	France	2	NGOKWREZWG@dell.com	3390061270	4	7755709467455745	2008/02	user19909	password	81	40000	F
19910	AWEIQS	OFCLXGKUNB	4143153641 Dell Way	\N	IOLKSOV	\N	0	UK	2	OFCLXGKUNB@dell.com	4143153641	3	1329758852254599	2010/06	user19910	password	39	100000	F
19911	ECUVVI	AXTYEESRFB	8633134568 Dell Way	\N	GQLZFHZ	\N	0	Germany	2	AXTYEESRFB@dell.com	8633134568	1	1012694811448454	2009/04	user19911	password	86	80000	F
19912	BNHWWI	UQGYUYQAAX	8562739678 Dell Way	\N	QLWWSVK	\N	0	Germany	2	UQGYUYQAAX@dell.com	8562739678	3	8875780359376223	2008/05	user19912	password	64	80000	F
19913	EXGBFA	RMZMLPMLMD	8351216065 Dell Way	\N	XJZQFKF	\N	0	Australia	2	RMZMLPMLMD@dell.com	8351216065	1	2621415449306369	2008/09	user19913	password	76	60000	M
19914	SVYYWQ	KVCWLPIYTG	2806643933 Dell Way	\N	HTWMDCN	\N	0	UK	2	KVCWLPIYTG@dell.com	2806643933	4	2094929138664156	2012/07	user19914	password	68	100000	F
19915	NUDJKO	FNLQCTOVZW	6085347605 Dell Way	\N	OWJSYWR	\N	0	Canada	2	FNLQCTOVZW@dell.com	6085347605	4	1838779246434569	2008/06	user19915	password	86	40000	M
19916	SLIDAN	QLETETPEPE	3909332887 Dell Way	\N	AYWZVND	\N	0	China	2	QLETETPEPE@dell.com	3909332887	2	4997597566805780	2011/02	user19916	password	70	80000	M
19917	EDAEQQ	PVKUOZYEDY	3424340547 Dell Way	\N	CAXXOBH	\N	0	South Africa	2	PVKUOZYEDY@dell.com	3424340547	4	6986446645576508	2010/06	user19917	password	50	40000	M
19918	OHUFYJ	AIDPICTLAW	8249590841 Dell Way	\N	MYTAZBW	\N	0	Chile	2	AIDPICTLAW@dell.com	8249590841	3	7205829055514187	2009/12	user19918	password	90	100000	M
19919	HRTGBU	OFJXHCJHYV	3378849637 Dell Way	\N	GSVGUSN	\N	0	Germany	2	OFJXHCJHYV@dell.com	3378849637	2	8808927900623531	2009/03	user19919	password	73	80000	F
19920	LOSMIH	RSEYUOGTJM	5166143910 Dell Way	\N	METHXGW	\N	0	Canada	2	RSEYUOGTJM@dell.com	5166143910	4	4822469908278436	2011/07	user19920	password	34	20000	M
19921	UWKCDB	UIAPWGJGTW	8129846037 Dell Way	\N	KNEITBN	\N	0	Chile	2	UIAPWGJGTW@dell.com	8129846037	5	8957885870244355	2009/02	user19921	password	19	40000	M
19922	WQAASV	JTLGAVMTSX	6809097757 Dell Way	\N	HWFAXSG	\N	0	Japan	2	JTLGAVMTSX@dell.com	6809097757	1	9897872695699336	2011/03	user19922	password	34	80000	F
19923	WTBPPL	IARIWDCOAJ	8452165121 Dell Way	\N	KFKIYRZ	\N	0	Germany	2	IARIWDCOAJ@dell.com	8452165121	5	4512620846275240	2012/03	user19923	password	26	20000	F
19924	WCRLOA	MFJJIMXIWI	6548591807 Dell Way	\N	OGQNYQC	\N	0	Russia	2	MFJJIMXIWI@dell.com	6548591807	3	7943951418157668	2012/08	user19924	password	77	100000	F
19925	YPYMQK	RAUZMRIJAX	1393245591 Dell Way	\N	QQLOHOI	\N	0	UK	2	RAUZMRIJAX@dell.com	1393245591	1	7559752142522485	2011/12	user19925	password	65	20000	M
19926	GBIXMZ	XGZKYITZGJ	4265829730 Dell Way	\N	QRYXFGV	\N	0	Chile	2	XGZKYITZGJ@dell.com	4265829730	3	9105611402541400	2009/03	user19926	password	20	20000	F
19927	CLIPLG	WLQVTJUZTK	7047904373 Dell Way	\N	RRIWXDC	\N	0	Chile	2	WLQVTJUZTK@dell.com	7047904373	5	6099961759522558	2012/01	user19927	password	69	40000	F
19928	EQTPWP	BMLUWFUPQL	4575627956 Dell Way	\N	GZHECKL	\N	0	Russia	2	BMLUWFUPQL@dell.com	4575627956	1	6724643314722926	2010/09	user19928	password	85	60000	M
19929	OIMKXN	WJITPDIFPP	3291292155 Dell Way	\N	FXTHHFC	\N	0	Japan	2	WJITPDIFPP@dell.com	3291292155	4	2061223921831697	2012/08	user19929	password	68	100000	F
19930	AJPYWM	HFFWIOBXDH	4521319375 Dell Way	\N	UXPCDRU	\N	0	China	2	HFFWIOBXDH@dell.com	4521319375	5	4324255254119635	2008/08	user19930	password	35	40000	M
19931	PVNMIU	RNQABSYFZT	5617910956 Dell Way	\N	COVGGPQ	\N	0	Japan	2	RNQABSYFZT@dell.com	5617910956	1	7063741589430720	2008/03	user19931	password	84	80000	M
19932	TFHBAZ	PQZRJXWJRZ	8883703445 Dell Way	\N	YMGECWU	\N	0	Japan	2	PQZRJXWJRZ@dell.com	8883703445	3	7482965301256628	2008/05	user19932	password	48	100000	F
19933	QGFQFU	HFMQDJAUIY	4440382612 Dell Way	\N	HPCJLXA	\N	0	China	2	HFMQDJAUIY@dell.com	4440382612	4	4989328358322382	2011/02	user19933	password	46	100000	M
19934	QDKVYR	BKIETIZCGG	4223139658 Dell Way	\N	RJQDHQL	\N	0	Japan	2	BKIETIZCGG@dell.com	4223139658	5	4829321892000735	2010/04	user19934	password	42	40000	M
19935	MRTKIU	URZNZYPGFH	7536724041 Dell Way	\N	PVKWMVN	\N	0	South Africa	2	URZNZYPGFH@dell.com	7536724041	5	3991209815721959	2008/04	user19935	password	61	100000	M
19936	GQEPLY	GLMGKCMPJC	5339424687 Dell Way	\N	LTZXPNT	\N	0	China	2	GLMGKCMPJC@dell.com	5339424687	1	3893884616903961	2011/09	user19936	password	34	60000	M
19937	WSNIQU	TCADFNTOQE	9475789904 Dell Way	\N	IQCXDWF	\N	0	Japan	2	TCADFNTOQE@dell.com	9475789904	3	4646770210005343	2011/10	user19937	password	87	60000	M
19938	RCZHWT	KXXPLQECVM	2441964019 Dell Way	\N	SYJVUPL	\N	0	Russia	2	KXXPLQECVM@dell.com	2441964019	5	4153168146498501	2012/10	user19938	password	84	60000	F
19939	AOTWHE	UEUGVYIRKA	2536919650 Dell Way	\N	PUWJKIC	\N	0	Germany	2	UEUGVYIRKA@dell.com	2536919650	3	5504891506861896	2012/05	user19939	password	24	60000	F
19940	QFGYKB	DEHZDPQNQF	2309020183 Dell Way	\N	IMPTUSH	\N	0	UK	2	DEHZDPQNQF@dell.com	2309020183	4	9424473751336336	2010/11	user19940	password	46	100000	M
19941	QCMAEQ	FLPIBFVRLE	9979053485 Dell Way	\N	DAXXSFW	\N	0	South Africa	2	FLPIBFVRLE@dell.com	9979053485	5	4322755329310894	2012/03	user19941	password	35	60000	M
19942	JXVNNA	YCIZIERTIU	4329803466 Dell Way	\N	UGSMLOJ	\N	0	France	2	YCIZIERTIU@dell.com	4329803466	4	3910086710005999	2010/12	user19942	password	71	40000	F
19943	QFVDFT	GOTOSKIBFC	6960844218 Dell Way	\N	IXPTMYF	\N	0	South Africa	2	GOTOSKIBFC@dell.com	6960844218	3	4734046516939998	2011/04	user19943	password	75	100000	M
19944	ZTAFNG	THVMSDNXFV	3778187556 Dell Way	\N	VVPHTUE	\N	0	France	2	THVMSDNXFV@dell.com	3778187556	3	1313810211140662	2010/05	user19944	password	89	60000	F
19945	TMOGSH	OOTGRHEXDZ	1306806799 Dell Way	\N	STHMNLW	\N	0	South Africa	2	OOTGRHEXDZ@dell.com	1306806799	5	4613401342183352	2009/11	user19945	password	79	80000	M
19946	IHXBPL	PJSHQXFUXY	2787036478 Dell Way	\N	NEKBQHX	\N	0	Japan	2	PJSHQXFUXY@dell.com	2787036478	2	1711894758976996	2008/02	user19946	password	77	80000	F
19947	CPNRBC	AUKRRPMONA	3573650297 Dell Way	\N	TYCKFZC	\N	0	France	2	AUKRRPMONA@dell.com	3573650297	1	5491179719101638	2010/12	user19947	password	33	100000	F
19948	VKUXNV	RXMJNZXBZQ	3515378535 Dell Way	\N	ZCBEBDP	\N	0	China	2	RXMJNZXBZQ@dell.com	3515378535	1	8053730993531645	2009/04	user19948	password	68	40000	F
19949	CCAQXS	NKBBKZCKPB	9318441787 Dell Way	\N	MQGOUVX	\N	0	Australia	2	NKBBKZCKPB@dell.com	9318441787	4	3757370357867330	2009/05	user19949	password	65	40000	F
19950	TKBRDP	CEQMDTXTUJ	5251912253 Dell Way	\N	KBXEWUF	\N	0	Russia	2	CEQMDTXTUJ@dell.com	5251912253	3	1265993196982890	2012/03	user19950	password	47	40000	M
19951	UJPYYS	CPFGICADMK	4031396506 Dell Way	\N	EKPAEVV	\N	0	Japan	2	CPFGICADMK@dell.com	4031396506	5	5425472450442612	2010/04	user19951	password	74	60000	F
19952	DBZBTC	RZJZBJCNUG	1002062606 Dell Way	\N	YJHDEDU	\N	0	Germany	2	RZJZBJCNUG@dell.com	1002062606	2	1230682715773582	2009/01	user19952	password	52	40000	F
19953	NIGHLX	GUWHEZVYGU	9476736422 Dell Way	\N	IOXMSRA	\N	0	Japan	2	GUWHEZVYGU@dell.com	9476736422	1	9601749729365112	2012/07	user19953	password	39	20000	F
19954	QJIBHO	WDWADSZJMH	8659634499 Dell Way	\N	YJUQAVI	\N	0	UK	2	WDWADSZJMH@dell.com	8659634499	2	9701429673004896	2009/07	user19954	password	26	40000	F
19955	NSGUGC	XDCBVCLIKJ	6246065707 Dell Way	\N	REZSZHS	\N	0	South Africa	2	XDCBVCLIKJ@dell.com	6246065707	4	2854195275343954	2008/10	user19955	password	61	40000	F
19956	HOBOQZ	STANVLWFVO	6876995515 Dell Way	\N	KVHKDZG	\N	0	Japan	2	STANVLWFVO@dell.com	6876995515	3	8614577214699239	2010/01	user19956	password	30	80000	F
19957	TUYJUQ	DVDZHAFCOQ	7810620404 Dell Way	\N	XVBAUHT	\N	0	France	2	DVDZHAFCOQ@dell.com	7810620404	3	9067489861510696	2012/10	user19957	password	64	20000	F
19958	LCWGSA	BWAIWFLLWJ	7298634698 Dell Way	\N	GXKBEDM	\N	0	UK	2	BWAIWFLLWJ@dell.com	7298634698	2	7856381488963962	2010/01	user19958	password	86	100000	F
19959	AUSTVT	QVCNBOYXXE	2056263997 Dell Way	\N	UHFZKSY	\N	0	Canada	2	QVCNBOYXXE@dell.com	2056263997	4	6064070345368237	2008/08	user19959	password	54	80000	M
19960	HIKDBB	YEOZSMXPRR	3648028422 Dell Way	\N	XXRHQPK	\N	0	Russia	2	YEOZSMXPRR@dell.com	3648028422	5	9094459158834072	2012/06	user19960	password	55	60000	M
19961	VAXXBW	BQWTDTJULG	9498681527 Dell Way	\N	SCOJSZC	\N	0	Australia	2	BQWTDTJULG@dell.com	9498681527	1	9343944469932468	2010/07	user19961	password	55	40000	F
19962	NCGPZH	FVBIOKDARW	4048936121 Dell Way	\N	DFFVEIV	\N	0	Canada	2	FVBIOKDARW@dell.com	4048936121	4	5930410564411432	2012/04	user19962	password	72	40000	M
19963	WLKVTQ	RUYGFCGWZJ	8059885074 Dell Way	\N	CFFHNAK	\N	0	South Africa	2	RUYGFCGWZJ@dell.com	8059885074	5	7538076373282821	2008/09	user19963	password	86	100000	M
19964	JGKDWB	YVHDYOAYXD	7850027532 Dell Way	\N	DCKQDUN	\N	0	UK	2	YVHDYOAYXD@dell.com	7850027532	2	9765518656000496	2010/03	user19964	password	79	20000	M
19965	CLRZNQ	VUTUIUSGXV	3159799058 Dell Way	\N	JIMMDZK	\N	0	South Africa	2	VUTUIUSGXV@dell.com	3159799058	2	4117641190066934	2010/03	user19965	password	45	100000	F
19966	VRHIHD	DBXMVPSTKC	4194916771 Dell Way	\N	BXOEXZB	\N	0	Canada	2	DBXMVPSTKC@dell.com	4194916771	3	5973552400246263	2010/10	user19966	password	56	100000	M
19967	FEXMIA	NFNJUFCFID	8018117745 Dell Way	\N	DWIAWJE	\N	0	Chile	2	NFNJUFCFID@dell.com	8018117745	4	8066070860717446	2010/03	user19967	password	67	20000	F
19968	WCXEDL	KQUFVXLEBO	5013247317 Dell Way	\N	AJPXTTC	\N	0	Germany	2	KQUFVXLEBO@dell.com	5013247317	5	1774747985415160	2011/07	user19968	password	35	20000	F
19969	IBPLMZ	BHEXEQBFEC	9940953674 Dell Way	\N	OTZIMCV	\N	0	UK	2	BHEXEQBFEC@dell.com	9940953674	5	6553354396019132	2010/03	user19969	password	72	100000	F
19970	UPYGPA	NUXSKZXPBM	5953364314 Dell Way	\N	IBUVEQT	\N	0	Canada	2	NUXSKZXPBM@dell.com	5953364314	2	7447565632406623	2011/02	user19970	password	69	40000	M
19971	IEDXER	SBJCBHSCTA	9406340430 Dell Way	\N	ENVIEOM	\N	0	Russia	2	SBJCBHSCTA@dell.com	9406340430	2	4908592391759157	2008/11	user19971	password	65	100000	F
19972	VBDZTV	BDYCKQEERJ	4411600321 Dell Way	\N	SNRWCEO	\N	0	Australia	2	BDYCKQEERJ@dell.com	4411600321	1	1477565953042358	2009/08	user19972	password	88	60000	F
19973	ARLUNM	XMOIDTMUCE	6600573927 Dell Way	\N	HUBJZQK	\N	0	China	2	XMOIDTMUCE@dell.com	6600573927	3	6845748458988965	2009/06	user19973	password	30	80000	F
19974	VFGIRE	UGMXAZSDEZ	3137938749 Dell Way	\N	XFJXVUG	\N	0	France	2	UGMXAZSDEZ@dell.com	3137938749	5	7522864044643939	2011/01	user19974	password	53	20000	M
19975	RJFJOA	QAYQAQTEQR	7504619202 Dell Way	\N	JZOFUVQ	\N	0	Australia	2	QAYQAQTEQR@dell.com	7504619202	2	7126993220299483	2011/11	user19975	password	77	80000	M
19976	EXWTYM	TWDUMWYCNI	5533491557 Dell Way	\N	CCNWXDX	\N	0	Japan	2	TWDUMWYCNI@dell.com	5533491557	3	4756211382802576	2009/05	user19976	password	26	100000	M
19977	ATHZGB	VJWIFUKTCN	8691826657 Dell Way	\N	VQKSTHJ	\N	0	Chile	2	VJWIFUKTCN@dell.com	8691826657	4	6511329679284245	2009/11	user19977	password	52	100000	M
19978	FCXMET	VABBVMUYZQ	5338537224 Dell Way	\N	OKJIRSP	\N	0	Germany	2	VABBVMUYZQ@dell.com	5338537224	2	7856848008930684	2009/09	user19978	password	59	40000	M
19979	REJWXF	XYGTLBRLSG	4525819540 Dell Way	\N	VBPMUEA	\N	0	Chile	2	XYGTLBRLSG@dell.com	4525819540	4	6633433233946562	2008/05	user19979	password	83	100000	F
19980	BJXZOU	YVNJWFUPMP	8877727186 Dell Way	\N	QBCLFCR	\N	0	Japan	2	YVNJWFUPMP@dell.com	8877727186	2	7217582512181253	2009/03	user19980	password	67	40000	F
19981	ADGPYF	KMOHRIWDYM	9396769931 Dell Way	\N	FAYKDQA	\N	0	Australia	2	KMOHRIWDYM@dell.com	9396769931	4	3095722363330424	2008/05	user19981	password	52	60000	F
19982	PSAOXK	AMRSVOWTBB	2875747642 Dell Way	\N	UZMYPMY	\N	0	Germany	2	AMRSVOWTBB@dell.com	2875747642	1	7022905296646059	2011/08	user19982	password	26	20000	F
19983	VAVTLV	FDOARKUSMO	6806161694 Dell Way	\N	RYNGKLU	\N	0	Japan	2	FDOARKUSMO@dell.com	6806161694	3	3073803158476949	2009/07	user19983	password	36	60000	F
19984	HKDTGI	WUJOFDGRSY	4840830789 Dell Way	\N	PFFARZQ	\N	0	China	2	WUJOFDGRSY@dell.com	4840830789	5	6575194006320090	2012/02	user19984	password	32	40000	F
19985	PNEVWA	QFOVIVNATC	6737064989 Dell Way	\N	GYDXXTF	\N	0	China	2	QFOVIVNATC@dell.com	6737064989	5	4045594210270792	2011/01	user19985	password	70	20000	M
19986	GIMCJC	HXYQTLQMOW	8442474245 Dell Way	\N	KRUILZR	\N	0	Australia	2	HXYQTLQMOW@dell.com	8442474245	1	8532942456658930	2012/09	user19986	password	19	60000	M
19987	JZCTCJ	QAZKMQWBNH	4071199889 Dell Way	\N	SHQDHIF	\N	0	Australia	2	QAZKMQWBNH@dell.com	4071199889	1	9631086612585932	2008/01	user19987	password	51	20000	F
19988	KEENNV	NNFADBBQJU	2632857975 Dell Way	\N	XZXFHDH	\N	0	Japan	2	NNFADBBQJU@dell.com	2632857975	2	7616681312210859	2009/09	user19988	password	77	80000	F
19989	ZWQMSE	AXEDZGUJAS	5114179337 Dell Way	\N	IYXQCFH	\N	0	Chile	2	AXEDZGUJAS@dell.com	5114179337	1	5712483437266201	2008/11	user19989	password	34	40000	M
19990	CXHUCI	SHMSNGBOZK	4042183190 Dell Way	\N	NXAPCIW	\N	0	Germany	2	SHMSNGBOZK@dell.com	4042183190	2	7425495381467045	2008/08	user19990	password	18	100000	M
19991	XHNAPF	HBXVIYJIIX	7898401683 Dell Way	\N	FJMHRJW	\N	0	Australia	2	HBXVIYJIIX@dell.com	7898401683	3	2829765598289668	2009/07	user19991	password	31	20000	F
19992	MPMCVU	ESPMRZVAWA	7589889455 Dell Way	\N	KJICTED	\N	0	Germany	2	ESPMRZVAWA@dell.com	7589889455	2	9030644825659692	2009/07	user19992	password	90	80000	M
19993	PHCKBG	DRTVQOWNOH	8470775406 Dell Way	\N	XWJQAMD	\N	0	Russia	2	DRTVQOWNOH@dell.com	8470775406	1	1641855521593243	2009/01	user19993	password	80	40000	M
19994	DKAFRE	XKZOYWBMDY	7597718245 Dell Way	\N	JNOKASE	\N	0	South Africa	2	XKZOYWBMDY@dell.com	7597718245	2	2630336409434676	2011/02	user19994	password	56	40000	F
19995	YJMPOJ	ZOXXKZKOXT	6088190939 Dell Way	\N	BMEBEIW	\N	0	UK	2	ZOXXKZKOXT@dell.com	6088190939	1	7026820751838387	2011/08	user19995	password	20	100000	M
19996	KKDZUC	NSAXRLLPEM	5392978326 Dell Way	\N	BJOGRLE	\N	0	Chile	2	NSAXRLLPEM@dell.com	5392978326	5	9188167935237288	2008/11	user19996	password	78	60000	F
19997	GSGAVT	SWRJHDYMQA	3311555452 Dell Way	\N	VEGNPKT	\N	0	Australia	2	SWRJHDYMQA@dell.com	3311555452	4	2423516578041017	2008/06	user19997	password	73	60000	M
19998	MQTIKL	EBVMFUZVUU	7635641998 Dell Way	\N	ZBIPMBR	\N	0	Russia	2	EBVMFUZVUU@dell.com	7635641998	5	8653337796218694	2009/08	user19998	password	36	100000	F
19999	XSKHEO	JZBOUAKOVK	5488070628 Dell Way	\N	QDZCFRV	\N	0	UK	2	JZBOUAKOVK@dell.com	5488070628	4	2519272508565336	2008/12	user19999	password	28	20000	M
20000	WODADM	AEBUFMJAWZ	6224597470 Dell Way	\N	DVCINXG	\N	0	Australia	2	AEBUFMJAWZ@dell.com	6224597470	3	1869697669055313	2010/07	user20000	password	37	40000	F
\.


--
-- Data for Name: inventory; Type: TABLE DATA; Schema: public; Owner: chriskl
--

COPY inventory (prod_id, quan_in_stock, sales) FROM stdin;
1	138	9
2	118	19
3	228	11
4	279	12
5	382	13
6	109	14
7	90	10
8	357	6
9	215	27
10	105	16
11	80	5
12	22	13
13	64	11
14	136	14
15	343	9
16	481	8
17	114	13
18	189	9
19	389	7
20	131	9
21	443	10
22	172	6
23	122	10
24	18	17
25	461	15
26	210	23
27	270	13
28	410	37
29	438	23
30	150	5
31	158	21
32	75	6
33	268	18
34	386	8
35	355	17
36	149	16
37	496	14
38	445	7
39	6	14
40	211	11
41	50	6
42	86	16
43	233	13
44	115	8
45	222	7
46	75	15
47	95	17
48	336	13
49	265	12
50	484	16
51	467	15
52	207	28
53	156	11
54	89	11
55	226	16
56	116	9
57	300	13
58	496	7
59	25	17
60	237	11
61	145	6
62	183	9
63	313	13
64	413	8
65	69	11
66	167	20
67	62	10
68	65	3
69	112	10
70	68	6
71	276	16
72	162	8
73	154	7
74	8	8
75	277	9
76	376	9
77	84	20
78	372	3
79	212	18
80	349	15
81	356	7
82	178	17
83	56	13
84	11	9
85	268	16
86	282	28
87	128	18
88	67	16
89	277	15
90	153	6
91	304	18
92	423	16
93	337	6
94	116	9
95	336	10
96	407	24
97	283	9
98	398	10
99	472	3
100	395	4
101	466	8
102	247	6
103	57	9
104	120	11
105	255	15
106	334	19
107	496	20
108	340	10
109	206	6
110	208	4
111	188	11
112	61	13
113	386	7
114	244	13
115	73	6
116	154	12
117	26	14
118	201	12
119	221	1
120	303	7
121	355	18
122	24	6
123	226	3
124	192	15
125	141	12
126	61	14
127	98	9
128	425	11
129	460	12
130	69	15
131	319	13
132	426	15
133	316	13
134	377	22
135	45	7
136	71	11
137	210	8
138	41	14
139	411	4
140	416	4
141	249	3
142	99	10
143	478	4
144	135	12
145	344	10
146	50	8
147	289	18
148	370	9
149	252	8
150	9	16
151	173	7
152	106	8
153	34	7
154	399	7
155	298	20
156	175	7
157	461	12
158	396	6
159	99	16
160	420	10
161	466	9
162	419	9
163	346	20
164	281	7
165	296	16
166	391	7
167	353	11
168	5	2
169	432	14
170	264	8
171	422	9
172	181	10
173	363	7
174	399	11
175	316	17
176	206	17
177	450	2
178	105	10
179	76	14
180	201	16
181	115	9
182	249	10
183	308	5
184	150	14
185	148	17
186	106	9
187	325	11
188	108	21
189	2	9
190	425	5
191	28	13
192	468	4
193	344	11
194	374	16
195	249	21
196	139	15
197	265	9
198	102	12
199	145	12
200	197	15
201	366	5
202	66	22
203	378	11
204	228	14
205	466	13
206	194	17
207	435	11
208	415	18
209	299	10
210	10	7
211	116	13
212	415	5
213	259	12
214	425	13
215	64	13
216	407	13
217	30	9
218	390	14
219	15	10
220	32	6
221	314	28
222	44	23
223	0	14
224	158	15
225	418	13
226	249	14
227	298	14
228	182	15
229	351	16
230	443	11
231	380	7
232	216	12
233	9	11
234	257	13
235	445	7
236	476	9
237	452	7
238	379	13
239	391	11
240	250	11
241	390	11
242	6	11
243	165	16
244	149	12
245	431	15
246	229	6
247	56	3
248	462	12
249	118	7
250	71	21
251	494	2
252	433	32
253	115	8
254	494	6
255	90	27
256	33	4
257	243	11
258	389	3
259	216	15
260	94	19
261	331	4
262	95	11
263	311	5
264	341	14
265	352	6
266	255	5
267	316	18
268	304	19
269	134	8
270	206	9
271	53	8
272	23	9
273	212	15
274	219	6
275	172	15
276	143	8
277	448	12
278	228	9
279	104	15
280	65	24
281	300	12
282	98	2
283	499	18
284	416	13
285	92	14
286	88	15
287	449	8
288	335	16
289	477	14
290	165	4
291	430	9
292	308	16
293	260	8
294	240	10
295	148	11
296	112	22
297	495	5
298	465	21
299	416	18
300	129	24
301	170	11
302	470	10
303	153	18
304	383	7
305	188	13
306	325	28
307	26	17
308	135	16
309	53	15
310	131	5
311	201	7
312	354	10
313	229	13
314	199	12
315	269	4
316	321	20
317	288	20
318	218	8
319	156	11
320	265	10
321	383	20
322	86	22
323	73	12
324	143	15
325	326	16
326	222	8
327	255	3
328	321	12
329	186	18
330	171	9
331	450	4
332	357	18
333	140	12
334	102	7
335	239	17
336	329	14
337	428	18
338	265	21
339	465	13
340	482	10
341	396	6
342	165	22
343	336	7
344	125	8
345	365	11
346	105	17
347	447	6
348	153	6
349	323	8
350	103	15
351	419	10
352	206	13
353	189	17
354	493	8
355	349	13
356	14	32
357	214	8
358	104	15
359	336	15
360	401	17
361	275	20
362	286	15
363	257	11
364	416	8
365	388	14
366	497	12
367	244	16
368	316	13
369	261	15
370	208	4
371	298	11
372	157	19
373	374	12
374	133	16
375	282	5
376	239	15
377	238	25
378	229	12
379	393	13
380	61	16
381	332	15
382	312	17
383	268	8
384	20	14
385	304	10
386	117	8
387	35	9
388	18	10
389	221	24
390	372	14
391	419	9
392	497	19
393	157	15
394	175	8
395	413	16
396	45	17
397	171	13
398	157	20
399	361	15
400	433	10
401	365	9
402	159	8
403	90	19
404	239	18
405	292	22
406	373	21
407	479	21
408	30	11
409	101	10
410	371	6
411	92	15
412	433	22
413	182	22
414	360	11
415	454	20
416	486	9
417	477	4
418	490	3
419	3	14
420	198	12
421	361	10
422	423	10
423	195	14
424	17	8
425	98	11
426	108	9
427	62	10
428	270	0
429	265	11
430	424	11
431	203	9
432	130	18
433	82	7
434	293	17
435	369	16
436	375	13
437	165	25
438	348	8
439	406	14
440	267	16
441	218	11
442	498	12
443	199	16
444	401	10
445	358	16
446	153	13
447	386	6
448	335	3
449	143	7
450	390	16
451	33	10
452	3	10
453	313	7
454	228	1
455	21	8
456	411	9
457	336	10
458	83	10
459	180	8
460	101	33
461	7	10
462	383	8
463	231	21
464	90	9
465	176	10
466	100	9
467	466	11
468	341	7
469	448	7
470	371	11
471	107	12
472	165	14
473	369	13
474	307	6
475	65	7
476	226	9
477	461	22
478	452	9
479	60	2
480	103	10
481	342	14
482	94	7
483	106	15
484	154	20
485	322	23
486	128	11
487	64	12
488	158	15
489	212	15
490	245	11
491	259	14
492	219	12
493	128	13
494	490	10
495	309	6
496	304	6
497	89	21
498	274	10
499	144	19
500	37	11
501	145	8
502	252	10
503	202	16
504	13	14
505	59	12
506	268	4
507	240	17
508	19	8
509	220	10
510	301	9
511	122	17
512	61	9
513	395	5
514	229	7
515	215	13
516	216	15
517	357	17
518	280	11
519	375	14
520	68	7
521	24	12
522	134	20
523	288	7
524	152	12
525	123	16
526	97	25
527	456	3
528	213	16
529	372	11
530	100	13
531	250	11
532	16	17
533	353	2
534	453	12
535	30	11
536	412	19
537	220	9
538	270	5
539	431	12
540	440	10
541	70	5
542	53	20
543	1	15
544	466	13
545	282	12
546	216	19
547	182	11
548	139	14
549	496	19
550	56	10
551	208	7
552	20	21
553	190	14
554	496	13
555	173	10
556	314	19
557	92	13
558	128	14
559	26	14
560	464	2
561	229	16
562	277	11
563	481	14
564	81	14
565	230	6
566	10	13
567	493	15
568	450	13
569	280	18
570	424	21
571	390	6
572	351	5
573	478	15
574	391	12
575	316	8
576	260	9
577	107	16
578	498	14
579	399	7
580	103	25
581	54	10
582	107	11
583	124	7
584	244	6
585	102	19
586	297	1
587	57	15
588	195	10
589	426	13
590	84	14
591	159	18
592	154	14
593	362	9
594	139	10
595	236	15
596	91	17
597	150	13
598	229	10
599	41	10
600	431	6
601	152	11
602	432	7
603	281	4
604	129	14
605	323	5
606	97	11
607	389	11
608	430	14
609	95	25
610	288	20
611	33	12
612	149	21
613	395	8
614	157	10
615	394	8
616	498	13
617	455	14
618	452	15
619	192	14
620	380	11
621	36	8
622	352	10
623	34	16
624	398	23
625	492	9
626	270	15
627	490	8
628	141	9
629	499	17
630	30	10
631	71	14
632	151	16
633	462	16
634	353	10
635	281	8
636	284	25
637	451	12
638	169	4
639	214	13
640	45	16
641	458	10
642	248	14
643	195	5
644	353	12
645	406	11
646	88	12
647	350	5
648	360	20
649	39	9
650	42	13
651	240	19
652	75	14
653	394	9
654	274	20
655	474	10
656	385	7
657	43	8
658	463	9
659	26	19
660	41	15
661	494	24
662	97	9
663	193	10
664	456	18
665	451	11
666	474	13
667	240	12
668	401	15
669	143	17
670	454	17
671	446	6
672	100	10
673	202	22
674	140	14
675	453	12
676	107	16
677	229	17
678	303	5
679	468	11
680	269	15
681	346	17
682	207	14
683	344	13
684	239	12
685	481	7
686	318	3
687	124	4
688	24	15
689	281	2
690	150	14
691	66	12
692	274	21
693	248	8
694	259	8
695	229	9
696	198	12
697	232	13
698	469	12
699	98	12
700	375	9
701	423	7
702	44	8
703	476	7
704	125	22
705	185	2
706	429	13
707	233	12
708	414	7
709	231	5
710	200	19
711	182	23
712	76	10
713	408	8
714	26	19
715	316	12
716	389	9
717	345	8
718	441	14
719	413	13
720	125	5
721	91	12
722	479	22
723	399	11
724	340	12
725	237	17
726	128	12
727	37	10
728	470	16
729	96	12
730	136	22
731	344	18
732	19	13
733	181	24
734	319	7
735	144	13
736	366	10
737	247	22
738	377	13
739	280	4
740	479	7
741	77	8
742	463	10
743	55	13
744	485	4
745	490	12
746	372	11
747	374	17
748	334	5
749	313	9
750	286	4
751	460	11
752	404	16
753	265	23
754	358	6
755	243	11
756	2	13
757	487	9
758	281	11
759	472	20
760	83	9
761	418	22
762	315	13
763	102	20
764	98	24
765	134	18
766	247	10
767	465	26
768	381	10
769	123	13
770	244	14
771	360	7
772	201	16
773	207	14
774	415	6
775	185	7
776	196	6
777	287	18
778	58	17
779	30	15
780	99	5
781	345	15
782	490	11
783	2	18
784	109	3
785	348	9
786	246	10
787	112	4
788	334	14
789	27	5
790	83	12
791	417	10
792	445	15
793	398	25
794	19	7
795	43	12
796	32	14
797	266	12
798	7	10
799	414	11
800	390	7
801	252	4
802	273	20
803	90	14
804	459	15
805	188	15
806	276	15
807	155	6
808	475	10
809	335	9
810	185	9
811	73	23
812	179	10
813	174	13
814	76	9
815	289	7
816	21	14
817	323	11
818	401	4
819	356	5
820	351	15
821	484	11
822	272	12
823	295	17
824	382	17
825	292	7
826	339	12
827	415	16
828	57	13
829	346	20
830	328	19
831	447	17
832	97	12
833	100	13
834	37	18
835	56	10
836	289	12
837	313	15
838	211	13
839	263	11
840	147	16
841	396	9
842	337	20
843	327	17
844	70	9
845	414	16
846	115	19
847	92	5
848	237	8
849	16	12
850	448	21
851	87	11
852	0	11
853	220	10
854	383	10
855	383	9
856	11	12
857	221	7
858	297	19
859	69	10
860	67	12
861	124	21
862	15	2
863	165	10
864	225	10
865	52	14
866	221	9
867	13	17
868	366	19
869	432	10
870	277	10
871	12	9
872	328	10
873	113	4
874	339	12
875	399	13
876	27	20
877	455	18
878	491	14
879	264	14
880	471	6
881	439	10
882	351	10
883	472	0
884	158	20
885	233	12
886	354	11
887	169	13
888	455	5
889	150	5
890	238	3
891	21	17
892	274	8
893	254	28
894	186	13
895	499	18
896	307	19
897	407	21
898	12	6
899	172	11
900	339	18
901	289	8
902	185	12
903	167	15
904	403	17
905	23	9
906	65	10
907	430	9
908	478	2
909	56	10
910	194	12
911	449	13
912	495	2
913	44	11
914	420	4
915	152	17
916	278	6
917	273	18
918	322	8
919	232	24
920	424	10
921	60	12
922	254	12
923	197	10
924	314	10
925	440	7
926	196	22
927	121	19
928	347	30
929	208	16
930	293	7
931	186	13
932	497	15
933	478	4
934	353	15
935	400	13
936	1	3
937	419	9
938	329	12
939	480	15
940	476	14
941	22	5
942	429	7
943	470	15
944	67	14
945	348	20
946	122	14
947	345	9
948	121	6
949	445	7
950	77	9
951	44	18
952	4	11
953	331	11
954	242	13
955	319	15
956	271	20
957	438	17
958	440	15
959	118	8
960	145	10
961	233	14
962	304	5
963	142	21
964	211	14
965	157	17
966	41	12
967	213	17
968	76	8
969	371	4
970	192	21
971	51	6
972	394	5
973	120	15
974	21	6
975	461	15
976	469	17
977	144	11
978	306	10
979	90	14
980	88	4
981	384	9
982	135	18
983	92	13
984	215	24
985	377	9
986	412	4
987	487	19
988	314	8
989	351	7
990	104	12
991	460	15
992	84	14
993	408	11
994	102	11
995	296	15
996	65	13
997	144	18
998	8	17
999	141	11
1000	14	3
1001	200	13
1002	193	12
1003	409	13
1004	321	8
1005	214	5
1006	370	7
1007	290	10
1008	358	18
1009	175	16
1010	380	9
1011	447	7
1012	59	13
1013	14	18
1014	38	18
1015	274	10
1016	391	4
1017	450	7
1018	261	14
1019	205	25
1020	301	14
1021	365	10
1022	165	8
1023	386	19
1024	273	20
1025	267	17
1026	181	11
1027	338	10
1028	412	16
1029	189	14
1030	480	19
1031	427	7
1032	390	15
1033	173	9
1034	335	11
1035	211	10
1036	388	13
1037	204	10
1038	0	23
1039	245	14
1040	380	18
1041	381	9
1042	192	5
1043	440	11
1044	396	15
1045	230	10
1046	214	5
1047	287	3
1048	180	5
1049	475	23
1050	492	9
1051	482	7
1052	340	10
1053	157	15
1054	367	15
1055	112	7
1056	425	8
1057	48	6
1058	451	11
1059	336	9
1060	237	17
1061	431	19
1062	262	10
1063	127	13
1064	103	16
1065	97	14
1066	339	18
1067	491	7
1068	302	16
1069	340	15
1070	236	10
1071	182	11
1072	220	20
1073	428	16
1074	121	14
1075	115	23
1076	158	12
1077	336	15
1078	402	23
1079	338	11
1080	310	12
1081	394	7
1082	319	17
1083	149	13
1084	50	10
1085	186	9
1086	262	15
1087	476	18
1088	234	12
1089	213	15
1090	311	11
1091	472	25
1092	143	10
1093	73	9
1094	98	13
1095	246	20
1096	171	9
1097	438	11
1098	236	18
1099	473	12
1100	277	18
1101	473	17
1102	155	11
1103	497	7
1104	400	13
1105	277	12
1106	112	15
1107	57	16
1108	112	16
1109	14	19
1110	396	16
1111	423	11
1112	408	23
1113	214	10
1114	72	34
1115	459	21
1116	400	12
1117	334	13
1118	434	14
1119	134	12
1120	46	9
1121	244	6
1122	105	6
1123	189	2
1124	318	13
1125	204	9
1126	436	14
1127	489	6
1128	141	14
1129	172	16
1130	462	20
1131	418	8
1132	144	13
1133	116	12
1134	415	11
1135	43	12
1136	393	12
1137	26	6
1138	101	10
1139	5	3
1140	40	2
1141	497	9
1142	428	10
1143	449	18
1144	211	20
1145	500	19
1146	407	19
1147	111	5
1148	333	20
1149	340	10
1150	245	8
1151	380	13
1152	84	5
1153	350	0
1154	69	9
1155	402	12
1156	53	14
1157	4	18
1158	391	3
1159	195	8
1160	176	6
1161	352	14
1162	112	6
1163	320	9
1164	469	10
1165	27	17
1166	364	17
1167	362	12
1168	54	12
1169	466	15
1170	367	4
1171	95	6
1172	462	5
1173	294	5
1174	43	23
1175	172	14
1176	293	23
1177	451	14
1178	283	13
1179	126	3
1180	290	8
1181	28	11
1182	5	14
1183	375	6
1184	378	11
1185	74	14
1186	277	6
1187	432	13
1188	79	12
1189	167	13
1190	126	10
1191	255	20
1192	19	6
1193	239	11
1194	75	10
1195	488	6
1196	266	14
1197	440	6
1198	350	12
1199	321	10
1200	405	7
1201	216	23
1202	416	12
1203	367	9
1204	9	30
1205	460	14
1206	39	3
1207	303	5
1208	410	17
1209	323	12
1210	430	12
1211	200	13
1212	351	15
1213	435	12
1214	74	14
1215	228	5
1216	9	2
1217	351	6
1218	160	18
1219	88	17
1220	17	10
1221	286	9
1222	344	10
1223	37	14
1224	24	6
1225	419	7
1226	25	7
1227	291	10
1228	359	9
1229	375	13
1230	111	4
1231	264	15
1232	90	8
1233	27	15
1234	130	17
1235	100	20
1236	487	15
1237	170	14
1238	404	21
1239	396	11
1240	493	15
1241	333	12
1242	95	17
1243	343	22
1244	268	10
1245	170	9
1246	71	13
1247	277	5
1248	20	13
1249	232	3
1250	366	17
1251	38	7
1252	17	9
1253	209	12
1254	75	10
1255	42	14
1256	127	7
1257	101	33
1258	334	11
1259	487	6
1260	476	5
1261	446	14
1262	250	15
1263	66	10
1264	473	18
1265	381	17
1266	166	13
1267	459	7
1268	50	28
1269	70	12
1270	355	2
1271	42	23
1272	403	13
1273	451	18
1274	386	17
1275	170	21
1276	120	10
1277	458	8
1278	448	15
1279	140	6
1280	189	8
1281	313	5
1282	179	4
1283	207	7
1284	21	14
1285	255	21
1286	249	8
1287	149	6
1288	356	14
1289	82	18
1290	135	13
1291	332	15
1292	28	6
1293	385	2
1294	398	24
1295	0	16
1296	265	14
1297	64	14
1298	460	8
1299	316	16
1300	134	10
1301	314	16
1302	358	16
1303	36	7
1304	264	15
1305	244	13
1306	207	13
1307	385	8
1308	201	10
1309	154	7
1310	25	8
1311	391	26
1312	467	8
1313	204	12
1314	97	13
1315	489	13
1316	460	8
1317	346	18
1318	137	18
1319	315	14
1320	429	12
1321	273	6
1322	147	16
1323	457	6
1324	157	25
1325	44	6
1326	458	5
1327	423	12
1328	108	10
1329	417	22
1330	238	13
1331	243	15
1332	231	13
1333	96	21
1334	280	5
1335	496	11
1336	340	7
1337	487	8
1338	380	9
1339	41	2
1340	141	16
1341	405	14
1342	432	5
1343	108	15
1344	109	10
1345	29	8
1346	96	12
1347	68	15
1348	376	8
1349	234	15
1350	384	10
1351	305	17
1352	6	11
1353	30	6
1354	262	19
1355	164	15
1356	75	20
1357	219	11
1358	87	10
1359	184	8
1360	136	9
1361	325	10
1362	427	12
1363	367	10
1364	422	12
1365	206	5
1366	362	15
1367	262	6
1368	193	13
1369	242	7
1370	303	14
1371	334	13
1372	147	12
1373	235	6
1374	443	11
1375	256	10
1376	264	9
1377	38	9
1378	325	7
1379	139	11
1380	273	19
1381	209	12
1382	444	14
1383	279	16
1384	240	9
1385	205	11
1386	444	13
1387	315	22
1388	425	12
1389	30	15
1390	499	10
1391	60	13
1392	356	14
1393	426	13
1394	427	11
1395	277	7
1396	131	10
1397	289	8
1398	38	8
1399	324	7
1400	31	15
1401	342	13
1402	158	20
1403	178	9
1404	76	7
1405	100	17
1406	435	12
1407	341	15
1408	139	6
1409	260	7
1410	481	9
1411	412	23
1412	470	7
1413	424	17
1414	191	7
1415	209	6
1416	129	6
1417	134	13
1418	24	12
1419	54	7
1420	164	8
1421	23	2
1422	114	7
1423	19	8
1424	449	12
1425	41	7
1426	297	17
1427	79	19
1428	331	11
1429	336	9
1430	404	11
1431	362	24
1432	177	16
1433	62	14
1434	40	0
1435	254	6
1436	162	18
1437	475	11
1438	94	8
1439	302	10
1440	235	12
1441	75	14
1442	213	12
1443	204	10
1444	500	7
1445	405	15
1446	413	4
1447	128	11
1448	38	4
1449	438	13
1450	182	9
1451	203	5
1452	461	12
1453	297	11
1454	223	17
1455	409	13
1456	338	12
1457	19	16
1458	489	20
1459	169	15
1460	355	17
1461	393	23
1462	30	8
1463	32	3
1464	455	18
1465	70	3
1466	286	16
1467	117	15
1468	45	11
1469	381	10
1470	419	9
1471	280	26
1472	456	8
1473	131	5
1474	484	8
1475	455	16
1476	35	21
1477	397	18
1478	83	13
1479	74	18
1480	334	11
1481	266	13
1482	277	8
1483	295	11
1484	62	14
1485	500	10
1486	204	12
1487	401	11
1488	19	13
1489	192	10
1490	69	15
1491	374	18
1492	85	22
1493	100	8
1494	407	12
1495	39	9
1496	171	23
1497	192	6
1498	156	6
1499	216	9
1500	72	12
1501	74	14
1502	497	14
1503	28	10
1504	206	17
1505	480	9
1506	483	13
1507	242	17
1508	377	13
1509	65	21
1510	316	8
1511	211	9
1512	332	5
1513	92	17
1514	6	13
1515	395	8
1516	92	8
1517	210	12
1518	295	17
1519	112	16
1520	402	11
1521	365	18
1522	486	14
1523	487	15
1524	465	11
1525	393	14
1526	26	18
1527	135	14
1528	84	15
1529	182	15
1530	352	16
1531	157	8
1532	257	8
1533	348	13
1534	185	8
1535	463	16
1536	328	24
1537	167	11
1538	204	7
1539	204	15
1540	233	16
1541	20	19
1542	416	17
1543	65	17
1544	112	19
1545	422	17
1546	460	10
1547	205	11
1548	131	16
1549	255	13
1550	317	10
1551	33	5
1552	119	3
1553	303	8
1554	20	3
1555	84	9
1556	195	17
1557	47	6
1558	220	9
1559	280	22
1560	229	3
1561	71	12
1562	437	9
1563	487	6
1564	420	25
1565	121	11
1566	449	21
1567	247	20
1568	289	5
1569	153	16
1570	452	8
1571	22	6
1572	173	15
1573	367	8
1574	88	17
1575	286	12
1576	289	12
1577	47	7
1578	492	9
1579	421	22
1580	302	23
1581	309	15
1582	455	10
1583	421	14
1584	111	13
1585	475	17
1586	5	24
1587	307	12
1588	21	13
1589	225	9
1590	86	21
1591	251	9
1592	297	7
1593	23	9
1594	238	12
1595	216	12
1596	145	13
1597	187	4
1598	463	4
1599	435	8
1600	340	17
1601	415	14
1602	458	13
1603	13	12
1604	281	15
1605	45	19
1606	299	13
1607	70	12
1608	92	7
1609	290	13
1610	491	18
1611	395	18
1612	98	14
1613	445	10
1614	316	7
1615	210	26
1616	420	27
1617	321	6
1618	17	23
1619	442	16
1620	46	16
1621	104	14
1622	193	8
1623	343	10
1624	127	11
1625	431	10
1626	58	12
1627	273	13
1628	118	11
1629	21	6
1630	207	9
1631	458	19
1632	436	16
1633	164	13
1634	471	20
1635	217	9
1636	210	4
1637	270	15
1638	288	19
1639	303	8
1640	60	5
1641	278	10
1642	197	7
1643	159	10
1644	223	3
1645	12	16
1646	370	13
1647	143	11
1648	333	4
1649	387	8
1650	85	11
1651	380	14
1652	492	10
1653	278	10
1654	222	8
1655	118	5
1656	209	4
1657	281	10
1658	392	15
1659	327	7
1660	302	16
1661	98	10
1662	285	12
1663	238	16
1664	263	9
1665	256	8
1666	456	5
1667	473	9
1668	25	10
1669	243	16
1670	276	5
1671	86	8
1672	21	17
1673	473	8
1674	245	10
1675	245	13
1676	485	30
1677	115	3
1678	388	10
1679	318	7
1680	1	5
1681	473	16
1682	197	18
1683	493	9
1684	251	17
1685	420	2
1686	111	12
1687	461	6
1688	200	16
1689	2	11
1690	288	7
1691	2	10
1692	101	12
1693	72	7
1694	241	14
1695	365	5
1696	328	11
1697	196	11
1698	337	34
1699	354	21
1700	439	14
1701	112	8
1702	441	14
1703	461	10
1704	85	9
1705	186	18
1706	205	3
1707	70	19
1708	301	8
1709	92	15
1710	389	7
1711	303	6
1712	65	21
1713	86	9
1714	296	7
1715	317	12
1716	5	12
1717	408	13
1718	277	9
1719	206	10
1720	410	1
1721	64	23
1722	209	14
1723	11	10
1724	137	12
1725	450	12
1726	376	26
1727	466	16
1728	145	8
1729	213	15
1730	320	19
1731	84	21
1732	326	14
1733	260	7
1734	44	17
1735	411	9
1736	446	10
1737	249	13
1738	482	9
1739	246	24
1740	342	7
1741	370	8
1742	49	20
1743	408	8
1744	456	7
1745	345	16
1746	224	11
1747	462	5
1748	252	11
1749	1	12
1750	167	8
1751	162	9
1752	66	8
1753	377	14
1754	173	13
1755	203	29
1756	326	23
1757	49	19
1758	169	9
1759	471	19
1760	262	10
1761	489	11
1762	54	13
1763	87	14
1764	248	13
1765	99	10
1766	499	11
1767	193	10
1768	348	12
1769	480	16
1770	440	6
1771	190	10
1772	350	21
1773	489	9
1774	97	6
1775	306	11
1776	334	8
1777	322	15
1778	267	20
1779	85	6
1780	323	17
1781	435	14
1782	248	12
1783	389	8
1784	311	21
1785	421	16
1786	92	12
1787	136	14
1788	471	14
1789	261	6
1790	107	8
1791	232	10
1792	249	13
1793	162	15
1794	320	6
1795	498	12
1796	261	12
1797	318	12
1798	191	10
1799	109	14
1800	298	15
1801	131	6
1802	299	18
1803	147	11
1804	120	11
1805	397	12
1806	454	11
1807	454	13
1808	218	12
1809	220	8
1810	39	13
1811	41	11
1812	155	13
1813	287	2
1814	431	5
1815	466	15
1816	208	15
1817	22	15
1818	102	13
1819	178	2
1820	284	10
1821	210	9
1822	410	15
1823	33	7
1824	372	5
1825	229	3
1826	30	11
1827	133	15
1828	47	18
1829	221	12
1830	242	8
1831	346	11
1832	352	14
1833	41	12
1834	494	4
1835	472	7
1836	439	9
1837	447	8
1838	426	16
1839	157	18
1840	167	11
1841	465	13
1842	198	9
1843	322	15
1844	251	9
1845	128	3
1846	288	13
1847	459	11
1848	151	19
1849	391	13
1850	136	16
1851	435	11
1852	100	12
1853	46	11
1854	468	8
1855	473	7
1856	275	17
1857	498	4
1858	105	9
1859	323	8
1860	219	14
1861	348	14
1862	169	14
1863	71	13
1864	390	10
1865	162	3
1866	43	13
1867	329	22
1868	109	16
1869	469	16
1870	486	11
1871	276	12
1872	434	10
1873	184	5
1874	97	11
1875	184	11
1876	312	14
1877	386	7
1878	143	19
1879	464	9
1880	276	18
1881	279	16
1882	398	10
1883	377	4
1884	325	7
1885	366	2
1886	349	13
1887	100	10
1888	364	9
1889	455	15
1890	424	9
1891	83	16
1892	303	15
1893	92	7
1894	154	10
1895	192	11
1896	255	11
1897	198	5
1898	20	8
1899	364	17
1900	167	15
1901	6	15
1902	139	6
1903	100	7
1904	190	8
1905	237	14
1906	285	10
1907	2	8
1908	123	8
1909	428	10
1910	466	15
1911	400	9
1912	207	5
1913	364	25
1914	276	6
1915	32	5
1916	229	11
1917	125	21
1918	133	11
1919	92	4
1920	79	10
1921	56	11
1922	175	10
1923	382	4
1924	149	12
1925	330	21
1926	74	8
1927	405	10
1928	28	7
1929	95	10
1930	268	7
1931	195	7
1932	101	5
1933	408	12
1934	296	15
1935	291	8
1936	145	12
1937	80	23
1938	294	13
1939	268	12
1940	8	5
1941	259	16
1942	168	12
1943	215	12
1944	123	8
1945	444	12
1946	248	8
1947	352	20
1948	69	9
1949	381	17
1950	445	12
1951	148	4
1952	438	14
1953	120	22
1954	30	2
1955	86	8
1956	451	9
1957	104	9
1958	491	13
1959	479	19
1960	199	11
1961	259	9
1962	174	6
1963	301	14
1964	167	9
1965	470	9
1966	91	16
1967	312	13
1968	50	8
1969	386	7
1970	80	2
1971	58	11
1972	144	13
1973	248	14
1974	274	0
1975	267	7
1976	192	9
1977	21	9
1978	119	21
1979	261	16
1980	402	11
1981	64	4
1982	410	9
1983	339	12
1984	184	15
1985	440	4
1986	426	6
1987	135	5
1988	44	8
1989	417	11
1990	113	19
1991	244	5
1992	175	11
1993	287	14
1994	44	10
1995	342	12
1996	257	11
1997	136	12
1998	154	17
1999	307	6
2000	21	11
2001	235	6
2002	365	8
2003	166	17
2004	483	16
2005	138	7
2006	434	13
2007	175	18
2008	160	11
2009	52	15
2010	436	9
2011	61	13
2012	117	24
2013	346	12
2014	401	12
2015	301	9
2016	285	15
2017	326	9
2018	436	8
2019	330	8
2020	242	0
2021	49	8
2022	73	7
2023	418	11
2024	337	18
2025	117	15
2026	259	8
2027	93	8
2028	253	11
2029	414	18
2030	400	8
2031	275	8
2032	148	10
2033	264	2
2034	441	9
2035	131	24
2036	403	2
2037	374	5
2038	306	10
2039	63	12
2040	427	8
2041	242	15
2042	124	12
2043	43	11
2044	87	19
2045	25	14
2046	345	14
2047	373	14
2048	351	2
2049	281	8
2050	202	10
2051	93	10
2052	331	13
2053	275	7
2054	10	7
2055	167	5
2056	393	21
2057	270	5
2058	260	24
2059	145	14
2060	183	17
2061	159	7
2062	421	25
2063	331	8
2064	424	18
2065	361	17
2066	462	7
2067	327	13
2068	235	8
2069	268	12
2070	390	6
2071	161	18
2072	9	11
2073	13	8
2074	205	11
2075	97	2
2076	39	16
2077	50	12
2078	470	21
2079	391	11
2080	332	16
2081	172	20
2082	484	15
2083	162	10
2084	447	16
2085	495	11
2086	329	8
2087	340	11
2088	264	10
2089	88	8
2090	486	19
2091	448	16
2092	247	12
2093	406	2
2094	279	14
2095	170	14
2096	266	22
2097	241	16
2098	497	10
2099	1	10
2100	8	14
2101	386	6
2102	162	14
2103	18	8
2104	400	13
2105	368	10
2106	115	16
2107	439	17
2108	418	13
2109	85	13
2110	329	16
2111	250	8
2112	257	14
2113	313	10
2114	412	3
2115	204	12
2116	308	7
2117	240	6
2118	43	12
2119	71	15
2120	328	13
2121	28	13
2122	19	11
2123	75	9
2124	434	16
2125	298	8
2126	245	6
2127	200	11
2128	39	27
2129	242	12
2130	201	9
2131	47	23
2132	128	8
2133	364	25
2134	65	11
2135	28	14
2136	231	15
2137	180	6
2138	467	15
2139	149	8
2140	265	12
2141	296	11
2142	399	14
2143	22	12
2144	109	14
2145	310	22
2146	226	10
2147	417	5
2148	50	15
2149	269	16
2150	489	13
2151	378	14
2152	297	8
2153	7	9
2154	453	12
2155	231	14
2156	306	9
2157	198	20
2158	431	3
2159	345	14
2160	441	14
2161	132	6
2162	393	6
2163	68	5
2164	496	11
2165	458	22
2166	96	19
2167	227	3
2168	138	9
2169	63	14
2170	377	15
2171	404	12
2172	360	18
2173	276	5
2174	426	16
2175	469	19
2176	86	23
2177	151	17
2178	385	10
2179	136	7
2180	421	12
2181	374	12
2182	13	8
2183	218	18
2184	381	9
2185	467	15
2186	449	14
2187	187	8
2188	164	13
2189	380	3
2190	32	10
2191	105	16
2192	11	11
2193	425	18
2194	173	16
2195	6	8
2196	383	7
2197	270	6
2198	233	13
2199	21	11
2200	333	7
2201	109	14
2202	425	16
2203	192	13
2204	386	12
2205	351	10
2206	161	8
2207	472	22
2208	2	16
2209	46	15
2210	107	21
2211	423	18
2212	420	16
2213	121	16
2214	140	9
2215	301	15
2216	87	12
2217	89	11
2218	488	12
2219	252	4
2220	469	21
2221	20	12
2222	357	14
2223	481	15
2224	446	11
2225	30	22
2226	487	16
2227	328	13
2228	300	14
2229	220	9
2230	350	17
2231	132	20
2232	330	12
2233	274	4
2234	325	11
2235	215	23
2236	125	14
2237	486	12
2238	186	8
2239	127	7
2240	31	8
2241	293	10
2242	50	18
2243	451	0
2244	415	16
2245	191	14
2246	252	19
2247	1	13
2248	280	8
2249	239	4
2250	254	9
2251	249	8
2252	260	8
2253	110	9
2254	229	9
2255	205	7
2256	140	13
2257	216	9
2258	32	21
2259	441	16
2260	437	25
2261	382	21
2262	73	21
2263	266	11
2264	156	3
2265	398	9
2266	482	20
2267	282	21
2268	384	17
2269	168	11
2270	409	5
2271	416	22
2272	462	9
2273	460	6
2274	367	24
2275	376	14
2276	150	5
2277	118	10
2278	377	16
2279	431	3
2280	357	21
2281	130	13
2282	179	20
2283	116	12
2284	241	15
2285	409	11
2286	322	12
2287	382	9
2288	125	21
2289	354	4
2290	322	15
2291	61	13
2292	236	8
2293	395	16
2294	328	11
2295	393	17
2296	293	18
2297	309	5
2298	174	12
2299	176	12
2300	477	27
2301	83	21
2302	91	12
2303	438	13
2304	43	12
2305	459	19
2306	313	11
2307	193	15
2308	76	20
2309	190	10
2310	123	11
2311	434	10
2312	321	16
2313	303	12
2314	50	10
2315	62	6
2316	212	4
2317	372	8
2318	444	8
2319	337	12
2320	226	13
2321	266	6
2322	398	10
2323	463	10
2324	161	9
2325	225	17
2326	355	8
2327	455	24
2328	34	17
2329	29	7
2330	131	15
2331	11	12
2332	113	9
2333	223	11
2334	449	11
2335	156	9
2336	181	20
2337	262	9
2338	350	15
2339	257	27
2340	453	9
2341	474	8
2342	190	15
2343	274	19
2344	276	9
2345	240	13
2346	336	11
2347	489	14
2348	112	14
2349	280	10
2350	325	20
2351	338	16
2352	46	2
2353	223	16
2354	300	11
2355	207	23
2356	449	15
2357	155	26
2358	162	9
2359	483	14
2360	184	6
2361	293	7
2362	494	5
2363	298	17
2364	15	14
2365	443	11
2366	454	7
2367	196	11
2368	205	5
2369	304	7
2370	453	9
2371	157	1
2372	277	10
2373	143	17
2374	431	13
2375	52	24
2376	384	7
2377	267	18
2378	41	14
2379	496	14
2380	46	4
2381	366	8
2382	333	9
2383	92	28
2384	88	13
2385	132	8
2386	300	22
2387	37	8
2388	288	13
2389	462	21
2390	19	8
2391	472	12
2392	254	15
2393	13	13
2394	270	24
2395	269	17
2396	456	10
2397	224	6
2398	466	14
2399	161	9
2400	27	4
2401	419	8
2402	318	15
2403	304	2
2404	61	8
2405	249	7
2406	357	5
2407	445	14
2408	16	5
2409	398	6
2410	440	14
2411	62	11
2412	264	5
2413	273	6
2414	155	19
2415	353	5
2416	406	8
2417	455	6
2418	390	6
2419	193	18
2420	417	8
2421	409	2
2422	165	5
2423	171	12
2424	422	8
2425	435	8
2426	440	11
2427	378	9
2428	158	7
2429	406	10
2430	38	4
2431	186	6
2432	324	4
2433	357	24
2434	490	12
2435	385	10
2436	106	11
2437	347	8
2438	330	8
2439	122	18
2440	244	20
2441	270	17
2442	185	13
2443	8	11
2444	42	10
2445	340	13
2446	361	9
2447	449	19
2448	295	8
2449	250	12
2450	141	18
2451	211	8
2452	159	9
2453	306	4
2454	382	17
2455	81	11
2456	241	11
2457	322	17
2458	460	7
2459	400	7
2460	227	13
2461	498	9
2462	85	9
2463	51	11
2464	355	14
2465	75	27
2466	436	8
2467	461	12
2468	422	14
2469	266	7
2470	83	10
2471	166	23
2472	35	13
2473	268	17
2474	174	7
2475	78	15
2476	108	7
2477	35	24
2478	26	4
2479	403	21
2480	285	12
2481	168	14
2482	114	16
2483	445	2
2484	475	15
2485	496	17
2486	25	5
2487	215	21
2488	318	14
2489	486	11
2490	114	21
2491	44	7
2492	483	15
2493	200	13
2494	95	7
2495	338	7
2496	275	12
2497	31	16
2498	298	17
2499	197	11
2500	297	8
2501	382	10
2502	363	12
2503	333	6
2504	149	15
2505	37	15
2506	411	12
2507	258	8
2508	72	20
2509	438	11
2510	160	11
2511	358	17
2512	105	9
2513	274	9
2514	303	9
2515	79	15
2516	270	11
2517	329	23
2518	295	10
2519	87	18
2520	314	10
2521	410	13
2522	132	10
2523	296	14
2524	109	18
2525	228	3
2526	133	5
2527	385	15
2528	259	6
2529	432	8
2530	81	4
2531	56	14
2532	313	11
2533	445	7
2534	390	14
2535	463	18
2536	483	11
2537	301	11
2538	221	11
2539	54	19
2540	238	16
2541	381	10
2542	413	8
2543	344	2
2544	155	16
2545	215	11
2546	424	8
2547	425	6
2548	43	11
2549	218	5
2550	12	9
2551	358	13
2552	128	8
2553	144	14
2554	153	10
2555	237	6
2556	373	8
2557	287	8
2558	122	22
2559	132	14
2560	219	26
2561	203	20
2562	189	9
2563	32	15
2564	148	12
2565	78	7
2566	496	5
2567	130	11
2568	379	12
2569	216	10
2570	185	7
2571	117	12
2572	97	8
2573	98	22
2574	461	8
2575	253	20
2576	313	5
2577	385	18
2578	178	4
2579	357	15
2580	103	9
2581	190	4
2582	214	16
2583	231	7
2584	335	15
2585	368	7
2586	469	12
2587	207	16
2588	155	7
2589	90	24
2590	339	4
2591	375	10
2592	294	16
2593	27	7
2594	408	20
2595	442	14
2596	106	3
2597	403	9
2598	72	3
2599	485	17
2600	119	6
2601	257	5
2602	102	10
2603	216	14
2604	356	10
2605	62	16
2606	469	6
2607	168	9
2608	448	13
2609	146	19
2610	25	10
2611	50	17
2612	337	22
2613	240	9
2614	281	4
2615	171	9
2616	108	15
2617	250	7
2618	379	12
2619	264	13
2620	340	9
2621	218	5
2622	138	9
2623	134	8
2624	246	12
2625	46	10
2626	76	19
2627	352	10
2628	449	16
2629	148	9
2630	337	16
2631	68	16
2632	406	16
2633	439	13
2634	284	7
2635	261	6
2636	1	14
2637	253	11
2638	430	11
2639	449	10
2640	400	22
2641	456	11
2642	499	11
2643	236	10
2644	195	15
2645	280	15
2646	408	12
2647	304	20
2648	29	12
2649	286	6
2650	67	10
2651	370	13
2652	4	11
2653	206	15
2654	3	13
2655	250	6
2656	252	14
2657	79	5
2658	101	13
2659	201	11
2660	228	14
2661	439	9
2662	269	9
2663	133	6
2664	377	11
2665	53	9
2666	395	9
2667	378	8
2668	306	9
2669	324	11
2670	327	6
2671	205	5
2672	279	9
2673	325	12
2674	442	8
2675	475	8
2676	105	9
2677	349	23
2678	279	10
2679	135	13
2680	135	7
2681	346	10
2682	4	11
2683	139	15
2684	52	9
2685	8	8
2686	390	5
2687	305	5
2688	88	12
2689	491	18
2690	5	14
2691	316	11
2692	429	8
2693	274	10
2694	449	7
2695	306	8
2696	328	18
2697	344	13
2698	183	5
2699	133	5
2700	167	18
2701	9	11
2702	339	11
2703	447	13
2704	335	7
2705	280	5
2706	422	21
2707	440	10
2708	129	17
2709	200	18
2710	74	13
2711	265	17
2712	46	10
2713	79	11
2714	405	14
2715	98	10
2716	87	21
2717	294	7
2718	404	4
2719	175	4
2720	284	11
2721	409	26
2722	491	19
2723	213	13
2724	183	5
2725	440	13
2726	18	12
2727	10	8
2728	283	12
2729	202	11
2730	144	19
2731	451	8
2732	212	13
2733	483	8
2734	397	9
2735	47	15
2736	263	3
2737	318	10
2738	488	16
2739	393	12
2740	18	8
2741	62	10
2742	157	16
2743	64	13
2744	141	8
2745	61	6
2746	163	15
2747	229	9
2748	356	15
2749	66	14
2750	404	17
2751	140	12
2752	475	15
2753	395	0
2754	353	8
2755	158	15
2756	335	9
2757	372	11
2758	168	8
2759	118	4
2760	74	20
2761	313	15
2762	68	18
2763	286	13
2764	295	12
2765	466	10
2766	334	3
2767	58	6
2768	284	21
2769	321	11
2770	451	9
2771	302	9
2772	383	4
2773	108	11
2774	366	15
2775	23	9
2776	170	9
2777	28	12
2778	252	20
2779	25	17
2780	95	14
2781	156	8
2782	165	3
2783	69	7
2784	51	11
2785	18	19
2786	228	16
2787	387	19
2788	391	15
2789	397	16
2790	4	11
2791	465	14
2792	209	8
2793	73	14
2794	251	11
2795	4	5
2796	39	12
2797	84	7
2798	62	2
2799	324	8
2800	406	18
2801	13	18
2802	125	18
2803	288	2
2804	122	11
2805	492	3
2806	312	14
2807	293	16
2808	20	4
2809	64	22
2810	318	3
2811	115	5
2812	221	14
2813	484	14
2814	185	13
2815	272	19
2816	2	24
2817	413	11
2818	159	6
2819	394	9
2820	310	10
2821	164	19
2822	358	10
2823	18	9
2824	238	4
2825	109	14
2826	22	10
2827	277	4
2828	194	17
2829	85	10
2830	101	8
2831	99	6
2832	99	15
2833	227	10
2834	388	16
2835	221	4
2836	218	11
2837	199	11
2838	13	14
2839	239	11
2840	263	20
2841	332	12
2842	355	18
2843	484	17
2844	316	7
2845	40	15
2846	256	18
2847	319	11
2848	454	20
2849	415	16
2850	212	10
2851	263	15
2852	78	15
2853	70	21
2854	282	11
2855	316	17
2856	179	15
2857	305	7
2858	93	8
2859	374	3
2860	390	12
2861	194	6
2862	473	18
2863	489	13
2864	421	8
2865	360	14
2866	210	12
2867	139	11
2868	59	21
2869	224	10
2870	379	18
2871	322	13
2872	56	13
2873	234	15
2874	306	5
2875	373	5
2876	274	16
2877	61	12
2878	191	7
2879	228	2
2880	477	23
2881	403	9
2882	492	13
2883	54	11
2884	474	10
2885	273	16
2886	371	7
2887	152	11
2888	77	16
2889	465	16
2890	26	9
2891	467	7
2892	158	13
2893	499	9
2894	456	9
2895	79	17
2896	359	16
2897	166	9
2898	219	12
2899	418	4
2900	391	20
2901	97	9
2902	240	16
2903	447	7
2904	331	8
2905	45	9
2906	319	11
2907	105	14
2908	107	11
2909	9	15
2910	333	15
2911	83	8
2912	413	22
2913	324	7
2914	138	10
2915	386	10
2916	97	19
2917	9	19
2918	38	9
2919	174	10
2920	474	16
2921	64	14
2922	141	7
2923	132	1
2924	63	10
2925	97	7
2926	211	17
2927	423	19
2928	263	11
2929	430	15
2930	340	3
2931	153	16
2932	27	9
2933	80	7
2934	100	9
2935	358	12
2936	126	17
2937	419	16
2938	464	10
2939	233	17
2940	429	14
2941	297	13
2942	317	7
2943	341	13
2944	120	14
2945	455	12
2946	227	4
2947	217	22
2948	464	10
2949	265	11
2950	392	6
2951	438	14
2952	330	21
2953	32	9
2954	69	15
2955	393	17
2956	129	10
2957	281	13
2958	315	8
2959	393	10
2960	211	17
2961	155	9
2962	45	8
2963	238	5
2964	236	19
2965	145	17
2966	96	13
2967	362	16
2968	64	10
2969	59	25
2970	94	12
2971	493	15
2972	356	15
2973	411	15
2974	334	7
2975	477	15
2976	366	3
2977	60	8
2978	194	14
2979	330	18
2980	326	9
2981	85	10
2982	267	13
2983	155	22
2984	117	20
2985	336	10
2986	48	8
2987	247	21
2988	117	11
2989	364	9
2990	139	9
2991	328	17
2992	18	13
2993	184	8
2994	65	14
2995	255	10
2996	330	13
2997	161	6
2998	116	19
2999	394	10
3000	221	20
3001	211	3
3002	387	8
3003	77	9
3004	122	7
3005	220	18
3006	53	7
3007	488	10
3008	281	18
3009	248	10
3010	317	9
3011	106	36
3012	333	15
3013	84	27
3014	262	9
3015	451	15
3016	421	9
3017	310	6
3018	197	11
3019	37	27
3020	173	17
3021	336	11
3022	365	15
3023	192	6
3024	20	22
3025	431	18
3026	448	25
3027	350	13
3028	91	7
3029	63	19
3030	244	10
3031	313	11
3032	274	10
3033	131	7
3034	390	9
3035	397	18
3036	351	20
3037	444	15
3038	384	6
3039	131	10
3040	191	6
3041	201	8
3042	238	7
3043	24	17
3044	286	15
3045	500	14
3046	475	9
3047	206	14
3048	310	7
3049	171	4
3050	243	17
3051	484	11
3052	6	11
3053	108	7
3054	176	11
3055	26	8
3056	38	6
3057	123	15
3058	377	9
3059	130	25
3060	186	16
3061	121	16
3062	443	13
3063	461	10
3064	252	22
3065	333	8
3066	357	9
3067	103	14
3068	277	8
3069	241	12
3070	235	8
3071	469	17
3072	443	13
3073	473	18
3074	493	13
3075	228	9
3076	473	11
3077	467	5
3078	435	4
3079	282	5
3080	137	14
3081	178	19
3082	266	10
3083	144	5
3084	286	12
3085	442	21
3086	171	16
3087	325	20
3088	64	22
3089	47	16
3090	455	13
3091	251	5
3092	169	16
3093	398	14
3094	212	3
3095	421	10
3096	231	8
3097	68	13
3098	24	8
3099	7	4
3100	310	7
3101	259	13
3102	477	9
3103	253	7
3104	232	6
3105	469	8
3106	482	8
3107	204	5
3108	436	17
3109	416	16
3110	487	10
3111	72	22
3112	94	13
3113	252	9
3114	217	10
3115	380	9
3116	193	12
3117	388	12
3118	205	12
3119	258	7
3120	436	7
3121	159	13
3122	8	10
3123	104	18
3124	57	22
3125	220	19
3126	25	17
3127	288	13
3128	289	18
3129	49	12
3130	296	13
3131	99	12
3132	309	17
3133	272	9
3134	352	12
3135	40	16
3136	241	18
3137	333	16
3138	245	11
3139	176	10
3140	249	14
3141	231	8
3142	249	9
3143	343	16
3144	484	12
3145	466	18
3146	223	18
3147	176	13
3148	353	7
3149	428	14
3150	435	7
3151	289	15
3152	87	15
3153	443	10
3154	393	15
3155	144	5
3156	163	8
3157	419	15
3158	432	14
3159	453	14
3160	469	9
3161	227	8
3162	51	7
3163	277	19
3164	500	21
3165	403	10
3166	318	8
3167	240	23
3168	236	15
3169	62	16
3170	416	14
3171	486	10
3172	293	4
3173	165	19
3174	328	9
3175	277	9
3176	130	15
3177	50	15
3178	453	14
3179	484	11
3180	479	11
3181	388	11
3182	272	20
3183	65	23
3184	331	6
3185	165	11
3186	209	16
3187	494	16
3188	84	7
3189	141	11
3190	447	6
3191	52	14
3192	369	18
3193	498	17
3194	330	10
3195	368	21
3196	401	17
3197	147	14
3198	108	13
3199	137	10
3200	209	4
3201	24	10
3202	122	8
3203	2	8
3204	189	14
3205	450	15
3206	279	12
3207	319	10
3208	0	15
3209	232	4
3210	303	5
3211	480	14
3212	120	11
3213	75	12
3214	44	11
3215	451	17
3216	240	8
3217	254	7
3218	445	25
3219	324	5
3220	395	10
3221	391	24
3222	377	21
3223	263	5
3224	389	8
3225	206	9
3226	130	11
3227	289	4
3228	354	16
3229	238	4
3230	427	14
3231	62	8
3232	263	15
3233	48	10
3234	65	12
3235	452	8
3236	499	9
3237	345	16
3238	270	14
3239	500	6
3240	77	17
3241	73	8
3242	479	12
3243	197	12
3244	148	14
3245	22	9
3246	147	18
3247	389	12
3248	276	12
3249	92	15
3250	212	11
3251	170	5
3252	483	18
3253	89	13
3254	434	10
3255	372	14
3256	295	9
3257	63	8
3258	161	14
3259	148	11
3260	302	8
3261	87	6
3262	211	16
3263	64	2
3264	135	6
3265	277	20
3266	16	6
3267	134	0
3268	121	13
3269	287	11
3270	133	13
3271	199	10
3272	360	9
3273	111	14
3274	396	9
3275	7	10
3276	134	15
3277	43	15
3278	396	10
3279	410	11
3280	136	11
3281	108	16
3282	80	15
3283	119	4
3284	197	4
3285	13	11
3286	491	10
3287	493	13
3288	77	17
3289	151	9
3290	141	7
3291	380	4
3292	238	6
3293	353	5
3294	445	11
3295	374	3
3296	130	30
3297	461	11
3298	7	9
3299	252	19
3300	247	2
3301	140	5
3302	451	7
3303	107	8
3304	252	12
3305	347	9
3306	114	14
3307	386	9
3308	391	14
3309	10	5
3310	296	11
3311	26	13
3312	119	14
3313	376	5
3314	145	11
3315	317	12
3316	390	2
3317	135	12
3318	310	9
3319	468	12
3320	287	5
3321	451	12
3322	348	11
3323	25	4
3324	304	7
3325	292	8
3326	400	16
3327	434	7
3328	253	10
3329	407	9
3330	186	1
3331	0	9
3332	47	16
3333	136	21
3334	107	9
3335	299	18
3336	483	8
3337	222	14
3338	184	17
3339	374	11
3340	233	11
3341	480	3
3342	400	11
3343	352	10
3344	356	17
3345	44	14
3346	168	16
3347	246	10
3348	180	13
3349	478	14
3350	213	11
3351	468	12
3352	429	18
3353	60	15
3354	494	11
3355	233	12
3356	353	8
3357	393	13
3358	167	12
3359	105	12
3360	300	13
3361	353	19
3362	106	7
3363	347	5
3364	489	23
3365	214	5
3366	146	15
3367	472	12
3368	436	16
3369	331	13
3370	345	14
3371	168	19
3372	310	5
3373	245	13
3374	20	11
3375	166	7
3376	290	10
3377	188	14
3378	413	21
3379	470	13
3380	166	10
3381	125	18
3382	438	7
3383	95	10
3384	186	18
3385	431	8
3386	328	17
3387	39	18
3388	323	7
3389	495	17
3390	145	8
3391	122	13
3392	347	7
3393	251	9
3394	470	3
3395	336	12
3396	465	18
3397	115	7
3398	307	9
3399	401	7
3400	446	10
3401	152	7
3402	69	11
3403	256	1
3404	397	18
3405	89	8
3406	423	13
3407	186	9
3408	278	17
3409	335	26
3410	156	4
3411	445	12
3412	461	14
3413	93	17
3414	39	7
3415	147	8
3416	24	7
3417	367	8
3418	186	27
3419	347	9
3420	362	18
3421	332	11
3422	470	10
3423	208	16
3424	82	16
3425	439	13
3426	44	4
3427	47	16
3428	54	8
3429	351	13
3430	449	21
3431	0	20
3432	3	16
3433	18	4
3434	256	6
3435	400	8
3436	107	16
3437	178	15
3438	86	9
3439	386	15
3440	12	8
3441	242	10
3442	331	9
3443	474	14
3444	336	6
3445	370	8
3446	120	25
3447	360	5
3448	237	7
3449	306	11
3450	207	9
3451	99	12
3452	137	16
3453	177	11
3454	307	7
3455	220	10
3456	116	14
3457	352	8
3458	268	19
3459	170	10
3460	202	15
3461	217	11
3462	170	18
3463	206	12
3464	235	11
3465	427	4
3466	105	14
3467	343	10
3468	105	12
3469	192	11
3470	229	17
3471	117	11
3472	434	16
3473	59	16
3474	90	20
3475	270	13
3476	430	9
3477	211	16
3478	130	16
3479	166	11
3480	16	10
3481	338	10
3482	266	19
3483	154	11
3484	14	15
3485	73	5
3486	375	11
3487	131	12
3488	425	18
3489	143	11
3490	302	10
3491	127	13
3492	360	19
3493	473	3
3494	333	16
3495	95	7
3496	399	14
3497	439	7
3498	438	19
3499	3	16
3500	130	6
3501	166	11
3502	121	2
3503	64	17
3504	225	21
3505	212	12
3506	334	10
3507	154	12
3508	423	11
3509	465	11
3510	321	7
3511	440	15
3512	302	11
3513	86	7
3514	94	21
3515	317	1
3516	159	21
3517	470	22
3518	448	8
3519	84	9
3520	112	17
3521	250	12
3522	211	11
3523	473	10
3524	222	15
3525	43	16
3526	67	9
3527	121	16
3528	482	7
3529	4	7
3530	125	17
3531	111	15
3532	171	12
3533	247	15
3534	176	16
3535	396	5
3536	460	4
3537	9	11
3538	50	11
3539	382	12
3540	475	15
3541	372	12
3542	322	11
3543	276	17
3544	459	8
3545	417	8
3546	93	16
3547	118	8
3548	386	15
3549	40	14
3550	202	26
3551	498	19
3552	291	9
3553	413	26
3554	471	17
3555	12	21
3556	457	12
3557	37	8
3558	134	21
3559	438	8
3560	42	14
3561	259	8
3562	49	17
3563	213	13
3564	5	9
3565	225	18
3566	109	12
3567	465	7
3568	235	12
3569	159	20
3570	347	9
3571	209	13
3572	31	13
3573	169	6
3574	485	10
3575	490	12
3576	85	12
3577	78	15
3578	108	4
3579	471	15
3580	119	19
3581	311	5
3582	469	11
3583	410	18
3584	223	8
3585	439	10
3586	423	5
3587	179	14
3588	477	22
3589	56	9
3590	117	19
3591	18	5
3592	316	13
3593	166	6
3594	232	9
3595	321	8
3596	392	10
3597	341	14
3598	286	9
3599	126	15
3600	0	20
3601	133	9
3602	335	13
3603	31	4
3604	302	10
3605	320	17
3606	21	11
3607	388	8
3608	398	16
3609	130	11
3610	358	16
3611	16	9
3612	441	15
3613	327	12
3614	427	4
3615	164	11
3616	265	14
3617	349	3
3618	344	16
3619	241	18
3620	405	21
3621	461	15
3622	260	17
3623	220	10
3624	127	9
3625	492	7
3626	41	26
3627	18	13
3628	332	9
3629	328	11
3630	144	15
3631	333	16
3632	462	3
3633	480	13
3634	365	17
3635	263	9
3636	300	7
3637	387	15
3638	151	15
3639	198	16
3640	16	14
3641	8	20
3642	215	17
3643	458	15
3644	335	12
3645	141	5
3646	121	15
3647	100	8
3648	490	14
3649	465	8
3650	342	6
3651	395	14
3652	426	10
3653	101	12
3654	115	14
3655	52	11
3656	93	9
3657	157	17
3658	70	14
3659	426	10
3660	486	16
3661	215	18
3662	258	12
3663	447	12
3664	195	12
3665	122	3
3666	210	8
3667	495	6
3668	9	24
3669	361	1
3670	192	23
3671	26	16
3672	370	13
3673	408	20
3674	484	22
3675	204	16
3676	48	11
3677	104	16
3678	305	3
3679	38	16
3680	69	27
3681	146	14
3682	434	10
3683	495	12
3684	248	15
3685	49	17
3686	46	11
3687	341	11
3688	206	17
3689	117	8
3690	266	3
3691	191	12
3692	332	7
3693	24	16
3694	138	19
3695	26	16
3696	147	10
3697	348	10
3698	21	7
3699	156	9
3700	208	10
3701	214	13
3702	182	12
3703	77	13
3704	121	10
3705	165	9
3706	282	15
3707	170	13
3708	270	9
3709	87	19
3710	209	22
3711	339	11
3712	233	8
3713	143	6
3714	334	3
3715	482	18
3716	192	6
3717	380	17
3718	322	9
3719	399	17
3720	497	14
3721	88	25
3722	90	7
3723	329	18
3724	112	7
3725	228	7
3726	355	11
3727	259	11
3728	76	3
3729	377	11
3730	415	3
3731	284	15
3732	90	18
3733	96	8
3734	362	9
3735	211	6
3736	262	19
3737	144	13
3738	382	11
3739	31	11
3740	232	14
3741	90	18
3742	371	15
3743	465	12
3744	234	17
3745	204	11
3746	447	15
3747	426	7
3748	84	13
3749	268	8
3750	325	12
3751	80	17
3752	356	13
3753	415	14
3754	410	3
3755	469	17
3756	143	19
3757	265	13
3758	227	9
3759	219	16
3760	141	14
3761	141	15
3762	3	11
3763	231	10
3764	238	6
3765	366	14
3766	443	14
3767	0	18
3768	10	16
3769	324	6
3770	32	11
3771	242	11
3772	415	11
3773	403	4
3774	207	13
3775	148	5
3776	107	12
3777	153	9
3778	74	5
3779	191	7
3780	421	22
3781	399	3
3782	272	15
3783	277	14
3784	314	8
3785	181	9
3786	245	7
3787	457	9
3788	447	11
3789	472	14
3790	176	17
3791	87	12
3792	113	10
3793	180	8
3794	318	6
3795	352	14
3796	45	3
3797	261	9
3798	352	8
3799	55	4
3800	84	6
3801	385	19
3802	297	25
3803	500	12
3804	288	7
3805	3	7
3806	147	13
3807	395	13
3808	156	25
3809	222	17
3810	86	16
3811	77	16
3812	120	11
3813	358	13
3814	355	7
3815	434	12
3816	39	1
3817	99	6
3818	391	21
3819	486	11
3820	71	6
3821	66	13
3822	73	8
3823	185	1
3824	246	10
3825	392	12
3826	37	17
3827	292	9
3828	152	21
3829	389	6
3830	347	12
3831	237	0
3832	274	10
3833	144	10
3834	236	12
3835	61	17
3836	148	8
3837	384	8
3838	456	20
3839	304	18
3840	105	9
3841	41	20
3842	382	5
3843	225	11
3844	400	18
3845	237	5
3846	159	7
3847	440	11
3848	336	6
3849	49	11
3850	426	4
3851	408	16
3852	116	12
3853	499	2
3854	93	5
3855	363	10
3856	391	11
3857	130	9
3858	154	10
3859	42	18
3860	19	13
3861	0	12
3862	279	14
3863	293	22
3864	145	19
3865	15	8
3866	354	10
3867	293	18
3868	399	11
3869	310	17
3870	97	9
3871	3	5
3872	352	11
3873	480	18
3874	229	8
3875	252	23
3876	216	9
3877	389	4
3878	191	14
3879	52	15
3880	438	27
3881	117	24
3882	460	8
3883	54	8
3884	116	8
3885	53	11
3886	417	11
3887	6	15
3888	183	21
3889	70	12
3890	48	9
3891	203	12
3892	71	7
3893	328	19
3894	496	22
3895	216	19
3896	343	4
3897	350	9
3898	8	10
3899	241	14
3900	159	13
3901	106	8
3902	245	12
3903	11	0
3904	85	13
3905	475	5
3906	263	16
3907	301	9
3908	363	3
3909	455	13
3910	353	8
3911	301	12
3912	71	12
3913	313	15
3914	355	7
3915	188	10
3916	366	10
3917	271	3
3918	194	16
3919	49	12
3920	341	18
3921	243	10
3922	252	9
3923	412	3
3924	70	10
3925	248	10
3926	128	12
3927	414	17
3928	98	5
3929	137	16
3930	155	14
3931	257	11
3932	243	8
3933	401	8
3934	269	10
3935	328	13
3936	375	8
3937	31	5
3938	128	14
3939	238	15
3940	486	14
3941	481	19
3942	38	14
3943	56	18
3944	293	16
3945	393	12
3946	244	15
3947	159	11
3948	164	12
3949	439	10
3950	208	8
3951	4	15
3952	182	6
3953	460	18
3954	417	14
3955	253	4
3956	208	16
3957	44	10
3958	166	14
3959	306	15
3960	182	3
3961	322	3
3962	63	7
3963	425	19
3964	222	12
3965	332	2
3966	252	8
3967	97	15
3968	363	22
3969	380	7
3970	335	9
3971	348	5
3972	361	8
3973	373	7
3974	405	15
3975	153	11
3976	266	6
3977	149	17
3978	312	10
3979	430	13
3980	87	16
3981	20	6
3982	435	9
3983	269	15
3984	480	11
3985	352	14
3986	21	9
3987	188	10
3988	397	10
3989	188	11
3990	494	9
3991	78	11
3992	9	22
3993	56	22
3994	2	12
3995	231	11
3996	389	15
3997	254	20
3998	329	21
3999	251	9
4000	134	11
4001	163	15
4002	99	12
4003	495	28
4004	36	21
4005	3	22
4006	148	7
4007	302	17
4008	153	13
4009	460	22
4010	232	3
4011	241	8
4012	481	4
4013	167	15
4014	9	17
4015	461	17
4016	18	27
4017	31	14
4018	148	6
4019	415	13
4020	220	3
4021	141	11
4022	493	13
4023	229	8
4024	198	15
4025	495	13
4026	461	15
4027	86	10
4028	249	11
4029	289	13
4030	338	5
4031	383	18
4032	453	13
4033	437	15
4034	377	20
4035	489	11
4036	441	8
4037	25	5
4038	291	14
4039	93	15
4040	485	8
4041	23	24
4042	334	11
4043	465	8
4044	190	15
4045	344	6
4046	425	12
4047	209	11
4048	376	30
4049	73	13
4050	123	1
4051	95	18
4052	215	9
4053	116	10
4054	325	13
4055	414	5
4056	111	11
4057	286	15
4058	500	15
4059	360	16
4060	75	16
4061	338	8
4062	243	16
4063	28	14
4064	275	11
4065	120	1
4066	16	11
4067	215	13
4068	145	4
4069	308	14
4070	309	10
4071	130	18
4072	332	20
4073	142	10
4074	94	12
4075	22	8
4076	487	13
4077	19	12
4078	231	11
4079	362	27
4080	93	12
4081	354	14
4082	458	8
4083	308	9
4084	470	13
4085	283	19
4086	221	8
4087	80	11
4088	68	10
4089	221	21
4090	441	15
4091	144	4
4092	58	12
4093	183	19
4094	172	11
4095	333	19
4096	303	7
4097	189	6
4098	48	8
4099	448	20
4100	498	6
4101	357	14
4102	77	6
4103	329	15
4104	500	12
4105	172	6
4106	351	9
4107	486	13
4108	192	11
4109	82	30
4110	347	22
4111	285	11
4112	437	22
4113	305	14
4114	93	16
4115	406	9
4116	87	9
4117	314	22
4118	487	13
4119	155	4
4120	35	8
4121	428	6
4122	300	23
4123	93	7
4124	111	18
4125	472	6
4126	427	11
4127	414	7
4128	160	13
4129	476	10
4130	362	10
4131	157	6
4132	332	23
4133	440	17
4134	487	15
4135	332	8
4136	112	15
4137	338	9
4138	317	11
4139	305	11
4140	420	12
4141	164	6
4142	90	9
4143	356	22
4144	469	18
4145	183	9
4146	262	13
4147	55	17
4148	498	4
4149	249	9
4150	211	19
4151	32	19
4152	176	19
4153	10	4
4154	126	7
4155	287	3
4156	483	6
4157	52	17
4158	201	8
4159	142	1
4160	28	16
4161	63	13
4162	300	12
4163	361	10
4164	3	22
4165	286	8
4166	192	17
4167	115	10
4168	123	19
4169	9	5
4170	421	31
4171	42	11
4172	173	19
4173	10	9
4174	399	18
4175	142	18
4176	194	16
4177	160	3
4178	198	12
4179	191	5
4180	409	19
4181	410	20
4182	223	11
4183	85	10
4184	420	15
4185	349	8
4186	373	20
4187	402	25
4188	402	8
4189	73	8
4190	44	15
4191	430	12
4192	137	20
4193	344	12
4194	291	11
4195	140	11
4196	130	13
4197	483	16
4198	256	15
4199	253	10
4200	492	18
4201	176	13
4202	296	9
4203	165	13
4204	186	4
4205	194	10
4206	307	7
4207	380	15
4208	354	10
4209	4	9
4210	71	18
4211	263	16
4212	414	15
4213	294	7
4214	348	18
4215	334	15
4216	143	9
4217	220	9
4218	236	16
4219	45	24
4220	294	20
4221	280	17
4222	475	17
4223	431	10
4224	124	2
4225	265	14
4226	71	19
4227	254	9
4228	248	11
4229	327	15
4230	7	19
4231	239	1
4232	2	10
4233	303	15
4234	404	19
4235	189	21
4236	498	20
4237	211	9
4238	68	6
4239	351	14
4240	215	9
4241	140	9
4242	114	5
4243	129	20
4244	435	10
4245	463	12
4246	463	14
4247	77	14
4248	183	17
4249	199	24
4250	122	10
4251	477	0
4252	480	7
4253	97	9
4254	408	15
4255	103	11
4256	363	11
4257	479	10
4258	358	13
4259	110	15
4260	305	10
4261	365	18
4262	350	8
4263	308	5
4264	168	14
4265	254	15
4266	497	13
4267	165	18
4268	465	2
4269	65	7
4270	16	7
4271	180	9
4272	205	21
4273	130	11
4274	309	14
4275	139	14
4276	92	14
4277	272	11
4278	216	15
4279	275	11
4280	471	14
4281	339	7
4282	252	0
4283	450	8
4284	437	24
4285	159	8
4286	53	18
4287	299	10
4288	138	20
4289	411	7
4290	410	4
4291	443	3
4292	276	10
4293	259	23
4294	251	11
4295	444	9
4296	13	17
4297	247	26
4298	108	11
4299	479	14
4300	312	8
4301	124	12
4302	158	14
4303	16	13
4304	255	17
4305	467	25
4306	155	4
4307	347	17
4308	239	9
4309	372	14
4310	122	17
4311	209	6
4312	211	10
4313	374	12
4314	159	17
4315	147	15
4316	33	10
4317	212	21
4318	447	14
4319	172	18
4320	122	9
4321	356	22
4322	115	16
4323	399	12
4324	115	15
4325	366	20
4326	342	9
4327	128	21
4328	112	11
4329	450	20
4330	106	7
4331	424	9
4332	74	17
4333	265	17
4334	441	6
4335	329	12
4336	231	13
4337	95	13
4338	176	15
4339	471	8
4340	468	11
4341	298	14
4342	179	10
4343	179	17
4344	172	22
4345	338	6
4346	326	14
4347	206	7
4348	50	13
4349	272	8
4350	378	11
4351	173	10
4352	127	16
4353	494	14
4354	71	9
4355	243	11
4356	359	20
4357	413	11
4358	372	19
4359	471	18
4360	363	5
4361	478	20
4362	395	10
4363	437	20
4364	242	16
4365	335	9
4366	266	19
4367	474	21
4368	430	6
4369	442	6
4370	444	8
4371	398	7
4372	240	11
4373	123	6
4374	76	19
4375	413	15
4376	462	15
4377	403	25
4378	118	5
4379	11	5
4380	174	13
4381	497	7
4382	184	11
4383	302	8
4384	490	16
4385	256	12
4386	44	4
4387	349	3
4388	168	7
4389	417	9
4390	319	13
4391	31	10
4392	394	17
4393	213	17
4394	468	14
4395	136	12
4396	47	8
4397	234	26
4398	110	4
4399	478	19
4400	175	4
4401	54	11
4402	376	15
4403	415	12
4404	177	16
4405	453	15
4406	328	15
4407	139	13
4408	355	16
4409	447	10
4410	151	14
4411	28	17
4412	443	14
4413	335	15
4414	331	13
4415	433	23
4416	91	11
4417	376	15
4418	282	17
4419	259	10
4420	292	11
4421	100	10
4422	291	6
4423	186	19
4424	314	21
4425	259	15
4426	322	10
4427	362	11
4428	493	15
4429	433	9
4430	340	5
4431	167	15
4432	487	2
4433	215	17
4434	82	11
4435	164	11
4436	167	13
4437	410	12
4438	303	20
4439	21	23
4440	356	4
4441	454	14
4442	50	9
4443	299	7
4444	289	25
4445	381	9
4446	232	14
4447	380	15
4448	257	20
4449	13	4
4450	139	13
4451	48	14
4452	114	7
4453	431	10
4454	234	15
4455	429	15
4456	189	9
4457	56	16
4458	290	12
4459	181	9
4460	490	15
4461	129	15
4462	348	11
4463	476	9
4464	345	13
4465	431	11
4466	140	10
4467	12	15
4468	341	16
4469	444	15
4470	34	7
4471	196	16
4472	398	9
4473	84	3
4474	496	14
4475	187	16
4476	466	16
4477	228	19
4478	67	12
4479	223	14
4480	242	9
4481	206	13
4482	271	7
4483	356	9
4484	137	9
4485	5	10
4486	284	7
4487	326	14
4488	62	7
4489	74	8
4490	6	16
4491	51	19
4492	204	18
4493	355	20
4494	27	16
4495	48	14
4496	285	9
4497	167	10
4498	61	14
4499	125	17
4500	110	11
4501	95	14
4502	322	10
4503	8	7
4504	180	19
4505	317	18
4506	195	5
4507	145	22
4508	45	15
4509	262	9
4510	368	13
4511	287	15
4512	469	13
4513	139	5
4514	142	15
4515	105	9
4516	145	20
4517	427	14
4518	431	6
4519	207	12
4520	0	11
4521	437	12
4522	258	6
4523	205	19
4524	292	15
4525	286	11
4526	253	14
4527	76	14
4528	453	18
4529	315	5
4530	202	13
4531	63	11
4532	410	17
4533	23	31
4534	72	4
4535	89	11
4536	341	9
4537	267	13
4538	235	6
4539	386	5
4540	28	16
4541	103	18
4542	172	11
4543	497	18
4544	242	20
4545	315	20
4546	102	9
4547	387	4
4548	241	19
4549	32	8
4550	94	14
4551	242	16
4552	470	11
4553	353	12
4554	447	6
4555	261	9
4556	138	16
4557	200	17
4558	338	8
4559	91	5
4560	14	12
4561	39	11
4562	155	20
4563	425	1
4564	62	11
4565	227	10
4566	13	5
4567	403	10
4568	494	22
4569	248	4
4570	289	10
4571	21	14
4572	351	12
4573	461	4
4574	18	12
4575	93	11
4576	276	10
4577	121	7
4578	481	13
4579	16	10
4580	154	22
4581	74	16
4582	259	18
4583	123	5
4584	427	5
4585	206	9
4586	385	9
4587	64	8
4588	406	22
4589	222	11
4590	156	8
4591	421	8
4592	262	10
4593	311	13
4594	345	4
4595	324	6
4596	37	9
4597	358	8
4598	227	19
4599	30	17
4600	106	15
4601	15	16
4602	52	22
4603	458	5
4604	477	12
4605	71	9
4606	50	23
4607	252	11
4608	192	4
4609	30	11
4610	269	8
4611	346	11
4612	104	18
4613	28	16
4614	470	19
4615	31	18
4616	234	9
4617	355	20
4618	96	14
4619	140	32
4620	77	17
4621	252	14
4622	60	2
4623	339	26
4624	62	5
4625	406	9
4626	163	12
4627	99	11
4628	264	5
4629	391	12
4630	129	23
4631	370	20
4632	407	12
4633	182	12
4634	328	20
4635	383	11
4636	253	11
4637	378	13
4638	135	9
4639	446	13
4640	409	24
4641	405	5
4642	292	5
4643	13	10
4644	433	20
4645	262	8
4646	44	20
4647	167	26
4648	116	15
4649	140	17
4650	307	1
4651	194	17
4652	392	14
4653	368	11
4654	32	12
4655	454	5
4656	273	16
4657	196	8
4658	53	12
4659	36	9
4660	86	15
4661	183	23
4662	407	23
4663	494	16
4664	365	19
4665	234	25
4666	377	16
4667	118	12
4668	112	12
4669	11	9
4670	63	13
4671	20	10
4672	417	16
4673	356	31
4674	33	15
4675	350	10
4676	117	10
4677	78	26
4678	16	12
4679	234	9
4680	218	20
4681	323	1
4682	428	7
4683	110	10
4684	191	10
4685	461	3
4686	64	27
4687	464	7
4688	156	11
4689	117	7
4690	0	14
4691	243	11
4692	300	14
4693	408	6
4694	237	7
4695	165	3
4696	141	11
4697	113	18
4698	283	13
4699	254	7
4700	124	7
4701	347	10
4702	275	13
4703	41	11
4704	203	10
4705	308	10
4706	391	9
4707	320	7
4708	386	24
4709	407	19
4710	54	2
4711	104	7
4712	230	15
4713	482	13
4714	214	9
4715	421	13
4716	443	19
4717	278	9
4718	385	7
4719	99	7
4720	395	12
4721	385	12
4722	342	15
4723	195	14
4724	293	11
4725	78	10
4726	360	7
4727	434	8
4728	192	13
4729	143	14
4730	188	6
4731	317	14
4732	491	10
4733	463	10
4734	358	15
4735	193	15
4736	271	10
4737	248	19
4738	13	21
4739	157	16
4740	155	5
4741	67	12
4742	261	8
4743	386	1
4744	49	17
4745	475	7
4746	307	21
4747	492	19
4748	253	13
4749	191	13
4750	90	10
4751	148	8
4752	76	12
4753	433	19
4754	343	9
4755	370	22
4756	11	27
4757	203	19
4758	304	6
4759	203	18
4760	347	9
4761	492	14
4762	19	6
4763	338	6
4764	454	17
4765	377	6
4766	31	9
4767	225	10
4768	125	20
4769	44	12
4770	382	0
4771	281	19
4772	112	2
4773	142	17
4774	167	14
4775	162	27
4776	117	5
4777	474	6
4778	153	3
4779	370	14
4780	165	14
4781	244	9
4782	18	12
4783	242	4
4784	177	12
4785	361	10
4786	111	9
4787	188	11
4788	64	11
4789	415	4
4790	392	14
4791	411	9
4792	407	10
4793	411	12
4794	249	4
4795	360	15
4796	288	15
4797	280	7
4798	85	6
4799	414	13
4800	325	17
4801	467	11
4802	195	12
4803	437	10
4804	108	9
4805	362	17
4806	99	9
4807	226	8
4808	336	5
4809	253	21
4810	96	20
4811	1	17
4812	497	9
4813	114	12
4814	243	9
4815	174	7
4816	476	17
4817	355	4
4818	362	10
4819	39	13
4820	270	15
4821	254	12
4822	451	6
4823	176	20
4824	165	6
4825	199	10
4826	35	23
4827	454	12
4828	479	7
4829	121	15
4830	367	16
4831	303	12
4832	87	16
4833	62	10
4834	240	14
4835	196	11
4836	425	8
4837	339	20
4838	422	15
4839	260	5
4840	91	7
4841	18	6
4842	261	25
4843	88	13
4844	132	12
4845	4	17
4846	262	20
4847	107	17
4848	359	5
4849	124	5
4850	147	13
4851	128	23
4852	378	11
4853	97	21
4854	304	5
4855	42	12
4856	297	13
4857	340	8
4858	496	2
4859	276	5
4860	461	12
4861	363	15
4862	78	16
4863	48	6
4864	426	9
4865	319	12
4866	244	15
4867	350	5
4868	158	14
4869	166	7
4870	109	10
4871	249	14
4872	184	14
4873	371	14
4874	338	7
4875	316	6
4876	375	5
4877	99	15
4878	424	10
4879	234	3
4880	224	9
4881	70	24
4882	363	8
4883	102	10
4884	168	8
4885	167	13
4886	144	4
4887	465	11
4888	6	22
4889	140	14
4890	240	12
4891	468	19
4892	3	4
4893	319	16
4894	15	10
4895	429	10
4896	137	13
4897	260	10
4898	279	15
4899	295	18
4900	426	27
4901	388	16
4902	44	10
4903	109	19
4904	259	12
4905	383	8
4906	426	14
4907	134	11
4908	483	19
4909	349	19
4910	368	13
4911	206	6
4912	420	13
4913	231	12
4914	308	7
4915	87	10
4916	398	8
4917	453	19
4918	51	9
4919	405	19
4920	92	10
4921	292	24
4922	372	6
4923	96	16
4924	110	9
4925	388	11
4926	25	11
4927	248	19
4928	147	21
4929	304	5
4930	42	10
4931	72	14
4932	192	2
4933	87	7
4934	182	13
4935	451	11
4936	470	13
4937	107	12
4938	85	16
4939	452	18
4940	456	5
4941	454	9
4942	158	10
4943	376	11
4944	184	19
4945	466	9
4946	463	12
4947	81	9
4948	418	7
4949	13	13
4950	486	7
4951	10	19
4952	306	13
4953	358	9
4954	107	11
4955	416	26
4956	245	17
4957	132	3
4958	163	8
4959	393	13
4960	436	15
4961	206	10
4962	465	13
4963	127	12
4964	293	12
4965	147	7
4966	78	4
4967	263	13
4968	254	10
4969	163	14
4970	214	6
4971	210	28
4972	116	17
4973	372	12
4974	85	11
4975	301	8
4976	338	4
4977	47	7
4978	382	10
4979	256	13
4980	61	7
4981	368	12
4982	267	12
4983	367	6
4984	226	15
4985	374	7
4986	283	22
4987	472	11
4988	5	10
4989	446	12
4990	364	4
4991	442	12
4992	151	18
4993	329	4
4994	69	7
4995	445	9
4996	476	14
4997	148	9
4998	207	9
4999	230	21
5000	311	19
5001	422	13
5002	440	7
5003	428	16
5004	294	13
5005	24	13
5006	229	16
5007	131	10
5008	72	19
5009	110	9
5010	388	10
5011	134	9
5012	479	12
5013	154	11
5014	1	7
5015	204	6
5016	27	13
5017	284	9
5018	176	13
5019	33	15
5020	229	13
5021	39	7
5022	475	27
5023	381	9
5024	369	26
5025	44	12
5026	326	19
5027	344	12
5028	192	13
5029	33	19
5030	73	12
5031	3	13
5032	455	14
5033	13	12
5034	431	15
5035	249	4
5036	38	9
5037	159	14
5038	381	9
5039	110	11
5040	270	15
5041	268	15
5042	245	9
5043	249	12
5044	422	11
5045	246	11
5046	454	11
5047	449	2
5048	30	12
5049	129	13
5050	482	18
5051	260	17
5052	169	12
5053	457	11
5054	140	6
5055	37	7
5056	0	13
5057	467	9
5058	382	4
5059	193	9
5060	500	9
5061	455	16
5062	196	18
5063	455	21
5064	469	18
5065	127	6
5066	203	8
5067	6	5
5068	287	11
5069	83	9
5070	117	6
5071	57	14
5072	351	9
5073	362	0
5074	306	6
5075	273	2
5076	108	15
5077	260	11
5078	221	19
5079	138	7
5080	390	3
5081	203	20
5082	398	9
5083	58	9
5084	160	11
5085	38	16
5086	96	19
5087	161	13
5088	4	5
5089	478	13
5090	354	16
5091	4	14
5092	433	22
5093	49	6
5094	459	11
5095	401	15
5096	176	18
5097	161	7
5098	407	5
5099	464	12
5100	245	7
5101	24	24
5102	20	8
5103	96	8
5104	387	17
5105	327	20
5106	369	5
5107	495	12
5108	86	11
5109	90	1
5110	133	8
5111	476	20
5112	293	10
5113	30	13
5114	34	15
5115	454	12
5116	69	2
5117	130	15
5118	114	8
5119	73	11
5120	108	21
5121	469	3
5122	78	12
5123	40	4
5124	18	12
5125	36	21
5126	441	17
5127	195	10
5128	198	11
5129	348	20
5130	158	18
5131	444	21
5132	372	12
5133	178	4
5134	39	5
5135	259	9
5136	4	9
5137	408	15
5138	253	11
5139	91	6
5140	498	5
5141	386	13
5142	67	10
5143	291	10
5144	417	21
5145	101	5
5146	245	11
5147	487	14
5148	232	9
5149	360	5
5150	59	10
5151	340	15
5152	328	6
5153	138	11
5154	380	11
5155	346	7
5156	174	16
5157	321	17
5158	40	10
5159	373	12
5160	169	13
5161	199	7
5162	316	18
5163	40	8
5164	377	17
5165	355	6
5166	299	5
5167	382	19
5168	263	14
5169	52	10
5170	473	13
5171	261	7
5172	439	12
5173	39	11
5174	52	15
5175	356	5
5176	141	10
5177	297	13
5178	342	9
5179	373	5
5180	156	16
5181	402	8
5182	213	1
5183	485	14
5184	39	23
5185	93	12
5186	330	15
5187	214	14
5188	414	17
5189	371	14
5190	86	12
5191	82	16
5192	69	11
5193	402	14
5194	123	20
5195	447	18
5196	257	8
5197	423	8
5198	328	11
5199	20	9
5200	476	13
5201	300	11
5202	281	30
5203	415	19
5204	340	6
5205	333	5
5206	270	8
5207	481	9
5208	130	10
5209	112	8
5210	354	11
5211	287	17
5212	13	18
5213	66	11
5214	271	16
5215	53	16
5216	159	19
5217	100	6
5218	267	10
5219	73	23
5220	472	7
5221	353	9
5222	156	12
5223	41	16
5224	255	14
5225	279	8
5226	488	8
5227	12	12
5228	202	13
5229	315	8
5230	32	8
5231	177	7
5232	115	9
5233	314	11
5234	92	16
5235	455	13
5236	147	8
5237	362	14
5238	436	15
5239	277	6
5240	474	15
5241	289	7
5242	63	10
5243	488	12
5244	355	4
5245	334	14
5246	40	21
5247	14	11
5248	435	15
5249	308	9
5250	87	6
5251	407	15
5252	161	8
5253	243	4
5254	448	12
5255	416	10
5256	22	9
5257	435	13
5258	429	7
5259	225	12
5260	250	7
5261	461	9
5262	402	23
5263	366	18
5264	275	19
5265	495	13
5266	321	13
5267	422	8
5268	356	14
5269	256	14
5270	198	16
5271	330	20
5272	44	6
5273	262	11
5274	318	9
5275	400	11
5276	95	7
5277	359	12
5278	414	9
5279	30	11
5280	166	18
5281	1	9
5282	437	14
5283	327	10
5284	245	14
5285	384	14
5286	243	12
5287	267	14
5288	319	12
5289	171	19
5290	492	12
5291	69	9
5292	132	8
5293	394	7
5294	435	11
5295	407	10
5296	388	4
5297	255	19
5298	328	10
5299	244	8
5300	11	14
5301	26	9
5302	74	12
5303	55	9
5304	288	14
5305	392	9
5306	456	21
5307	384	8
5308	250	7
5309	369	15
5310	414	7
5311	416	4
5312	371	12
5313	350	16
5314	243	15
5315	115	10
5316	234	1
5317	486	15
5318	383	9
5319	53	12
5320	157	22
5321	374	17
5322	122	12
5323	289	21
5324	268	10
5325	57	3
5326	196	18
5327	155	5
5328	313	13
5329	23	11
5330	400	10
5331	324	21
5332	50	14
5333	474	22
5334	380	11
5335	338	7
5336	366	18
5337	335	12
5338	221	3
5339	115	13
5340	204	11
5341	134	20
5342	31	14
5343	75	11
5344	485	9
5345	275	11
5346	190	11
5347	219	22
5348	260	19
5349	72	10
5350	272	13
5351	417	21
5352	447	5
5353	395	23
5354	206	10
5355	214	14
5356	452	14
5357	402	7
5358	370	1
5359	265	15
5360	426	21
5361	269	17
5362	88	22
5363	476	10
5364	243	19
5365	469	7
5366	314	11
5367	108	9
5368	304	6
5369	35	23
5370	224	10
5371	8	15
5372	170	11
5373	256	4
5374	83	10
5375	154	7
5376	30	9
5377	273	20
5378	373	19
5379	291	14
5380	345	9
5381	144	13
5382	208	13
5383	292	18
5384	39	5
5385	414	15
5386	5	20
5387	491	6
5388	316	13
5389	375	7
5390	255	17
5391	241	6
5392	144	10
5393	344	9
5394	217	12
5395	388	11
5396	313	13
5397	30	10
5398	497	9
5399	116	11
5400	65	18
5401	220	15
5402	124	12
5403	235	13
5404	476	19
5405	207	12
5406	390	11
5407	6	11
5408	481	7
5409	263	14
5410	297	10
5411	326	13
5412	408	9
5413	4	0
5414	117	4
5415	447	14
5416	419	10
5417	122	9
5418	437	14
5419	234	8
5420	498	17
5421	192	12
5422	476	20
5423	142	10
5424	36	6
5425	192	12
5426	29	5
5427	350	6
5428	223	11
5429	25	2
5430	466	18
5431	289	22
5432	246	18
5433	90	15
5434	24	14
5435	222	8
5436	298	19
5437	414	12
5438	228	17
5439	278	19
5440	176	9
5441	25	13
5442	103	26
5443	83	12
5444	29	11
5445	220	12
5446	30	13
5447	448	16
5448	343	18
5449	468	9
5450	182	8
5451	341	12
5452	160	18
5453	157	8
5454	483	29
5455	196	15
5456	349	12
5457	12	3
5458	46	12
5459	71	15
5460	38	10
5461	11	4
5462	361	17
5463	284	11
5464	102	10
5465	385	16
5466	6	5
5467	400	5
5468	298	12
5469	234	9
5470	178	17
5471	475	16
5472	259	11
5473	281	11
5474	58	21
5475	289	7
5476	1	15
5477	88	19
5478	237	10
5479	345	13
5480	55	15
5481	419	15
5482	185	10
5483	216	15
5484	75	5
5485	168	17
5486	413	16
5487	425	10
5488	180	17
5489	459	8
5490	497	9
5491	219	11
5492	471	10
5493	357	12
5494	2	22
5495	72	7
5496	241	23
5497	9	9
5498	473	15
5499	39	12
5500	243	11
5501	150	9
5502	14	12
5503	2	6
5504	432	14
5505	72	17
5506	291	6
5507	434	6
5508	161	13
5509	27	10
5510	278	15
5511	217	9
5512	447	8
5513	464	18
5514	433	9
5515	22	15
5516	131	10
5517	345	16
5518	447	25
5519	312	14
5520	303	20
5521	443	9
5522	30	12
5523	273	14
5524	300	15
5525	33	7
5526	346	14
5527	41	11
5528	42	11
5529	319	12
5530	80	9
5531	286	17
5532	470	27
5533	94	6
5534	288	18
5535	402	14
5536	167	8
5537	78	13
5538	335	15
5539	329	7
5540	106	8
5541	113	16
5542	45	5
5543	53	17
5544	77	13
5545	479	6
5546	75	11
5547	208	10
5548	323	13
5549	22	14
5550	19	27
5551	126	4
5552	465	14
5553	50	15
5554	400	3
5555	265	12
5556	84	11
5557	246	10
5558	306	4
5559	126	3
5560	64	8
5561	387	4
5562	412	11
5563	33	7
5564	482	6
5565	200	21
5566	435	13
5567	148	5
5568	279	18
5569	270	4
5570	478	17
5571	385	11
5572	383	13
5573	22	14
5574	439	10
5575	460	6
5576	0	7
5577	13	14
5578	168	28
5579	324	17
5580	35	12
5581	188	10
5582	451	21
5583	0	9
5584	238	11
5585	350	14
5586	266	17
5587	323	14
5588	95	7
5589	71	22
5590	449	3
5591	159	24
5592	459	11
5593	361	23
5594	193	8
5595	440	6
5596	60	18
5597	127	11
5598	88	17
5599	339	12
5600	397	21
5601	65	12
5602	224	10
5603	280	14
5604	87	24
5605	162	23
5606	240	8
5607	88	18
5608	176	9
5609	408	20
5610	413	24
5611	212	5
5612	96	13
5613	363	13
5614	213	18
5615	335	16
5616	213	16
5617	479	17
5618	157	11
5619	308	10
5620	49	25
5621	105	3
5622	468	13
5623	7	10
5624	467	21
5625	160	16
5626	448	4
5627	26	16
5628	287	12
5629	35	8
5630	366	5
5631	184	11
5632	101	20
5633	90	12
5634	465	12
5635	189	10
5636	253	3
5637	204	15
5638	277	10
5639	430	5
5640	112	14
5641	190	15
5642	141	23
5643	208	21
5644	52	8
5645	354	11
5646	42	14
5647	265	10
5648	332	16
5649	200	14
5650	73	23
5651	382	2
5652	306	8
5653	40	16
5654	390	5
5655	272	6
5656	201	5
5657	337	13
5658	299	22
5659	489	10
5660	373	17
5661	165	7
5662	172	11
5663	474	11
5664	255	16
5665	136	7
5666	162	14
5667	7	11
5668	341	4
5669	440	16
5670	437	27
5671	454	6
5672	129	4
5673	78	16
5674	161	27
5675	182	10
5676	432	12
5677	204	4
5678	448	3
5679	264	7
5680	405	18
5681	20	16
5682	145	7
5683	210	7
5684	61	10
5685	35	11
5686	482	7
5687	262	11
5688	372	15
5689	281	21
5690	250	12
5691	245	11
5692	446	12
5693	422	5
5694	218	14
5695	201	3
5696	58	16
5697	381	10
5698	209	12
5699	400	8
5700	321	6
5701	146	15
5702	353	12
5703	451	16
5704	224	6
5705	14	22
5706	132	9
5707	156	16
5708	219	5
5709	79	7
5710	420	9
5711	123	9
5712	100	10
5713	65	10
5714	334	22
5715	161	12
5716	100	12
5717	315	7
5718	423	19
5719	473	18
5720	96	15
5721	172	11
5722	217	8
5723	42	15
5724	94	9
5725	436	6
5726	243	17
5727	153	13
5728	316	9
5729	453	7
5730	53	14
5731	137	10
5732	98	9
5733	406	12
5734	87	17
5735	323	16
5736	421	18
5737	219	24
5738	479	15
5739	139	3
5740	299	7
5741	399	11
5742	263	1
5743	400	14
5744	465	5
5745	96	16
5746	60	15
5747	64	20
5748	412	16
5749	484	15
5750	36	7
5751	7	5
5752	156	10
5753	254	18
5754	50	7
5755	250	5
5756	189	13
5757	293	9
5758	404	14
5759	5	10
5760	245	18
5761	457	17
5762	143	28
5763	344	34
5764	362	11
5765	230	21
5766	166	11
5767	283	9
5768	450	9
5769	145	14
5770	422	16
5771	248	6
5772	43	8
5773	185	13
5774	147	10
5775	7	7
5776	281	10
5777	208	10
5778	72	6
5779	193	17
5780	191	8
5781	109	12
5782	201	15
5783	347	20
5784	363	21
5785	251	14
5786	97	9
5787	52	12
5788	44	15
5789	0	8
5790	58	24
5791	289	24
5792	457	9
5793	201	8
5794	133	2
5795	319	16
5796	431	1
5797	299	6
5798	101	16
5799	380	7
5800	444	20
5801	23	19
5802	128	10
5803	488	15
5804	208	19
5805	276	19
5806	496	15
5807	490	21
5808	484	5
5809	67	10
5810	182	13
5811	175	9
5812	176	19
5813	384	13
5814	21	5
5815	39	8
5816	134	9
5817	119	10
5818	92	19
5819	178	12
5820	119	21
5821	150	13
5822	468	9
5823	76	9
5824	352	4
5825	100	14
5826	395	16
5827	283	12
5828	400	9
5829	497	17
5830	162	20
5831	344	4
5832	20	8
5833	291	4
5834	331	5
5835	228	19
5836	66	10
5837	326	17
5838	218	14
5839	49	10
5840	394	8
5841	401	17
5842	224	11
5843	70	11
5844	284	15
5845	246	8
5846	109	20
5847	419	7
5848	365	16
5849	202	18
5850	96	7
5851	485	28
5852	352	14
5853	64	11
5854	60	7
5855	204	9
5856	164	13
5857	456	6
5858	487	16
5859	64	8
5860	452	8
5861	149	19
5862	408	13
5863	472	9
5864	440	8
5865	238	9
5866	200	7
5867	5	20
5868	64	3
5869	419	7
5870	55	6
5871	458	13
5872	319	11
5873	280	21
5874	28	17
5875	103	14
5876	26	11
5877	137	5
5878	21	8
5879	391	5
5880	339	17
5881	118	14
5882	376	8
5883	191	8
5884	182	16
5885	436	6
5886	395	6
5887	346	8
5888	391	16
5889	382	7
5890	410	12
5891	343	14
5892	30	13
5893	318	20
5894	315	4
5895	470	11
5896	56	16
5897	14	23
5898	476	12
5899	120	17
5900	433	13
5901	30	8
5902	78	18
5903	252	10
5904	311	5
5905	106	14
5906	356	12
5907	337	11
5908	244	9
5909	377	10
5910	228	5
5911	83	7
5912	495	21
5913	103	9
5914	275	23
5915	176	7
5916	38	11
5917	170	11
5918	22	14
5919	430	13
5920	51	5
5921	433	11
5922	272	17
5923	81	9
5924	250	21
5925	87	8
5926	50	8
5927	306	10
5928	101	15
5929	26	13
5930	427	8
5931	34	11
5932	56	22
5933	4	7
5934	287	11
5935	368	16
5936	111	14
5937	142	15
5938	204	13
5939	355	7
5940	19	12
5941	432	7
5942	439	7
5943	14	17
5944	35	13
5945	213	17
5946	191	8
5947	74	12
5948	383	21
5949	213	8
5950	3	6
5951	434	10
5952	146	9
5953	276	18
5954	14	17
5955	397	18
5956	363	5
5957	65	5
5958	202	15
5959	465	17
5960	92	18
5961	129	15
5962	500	7
5963	148	12
5964	133	9
5965	286	10
5966	16	11
5967	245	9
5968	429	15
5969	220	9
5970	99	13
5971	449	8
5972	152	13
5973	38	4
5974	463	19
5975	187	6
5976	251	10
5977	153	14
5978	262	10
5979	133	12
5980	367	11
5981	265	19
5982	66	4
5983	12	10
5984	41	17
5985	81	10
5986	409	13
5987	404	12
5988	147	23
5989	111	8
5990	369	5
5991	239	7
5992	240	15
5993	368	19
5994	388	14
5995	374	2
5996	154	9
5997	404	22
5998	118	4
5999	82	10
6000	124	10
6001	218	17
6002	30	16
6003	277	8
6004	256	9
6005	494	28
6006	465	11
6007	7	13
6008	147	13
6009	226	14
6010	140	10
6011	13	13
6012	491	14
6013	207	16
6014	26	9
6015	32	21
6016	289	20
6017	436	11
6018	436	3
6019	436	13
6020	46	11
6021	305	16
6022	175	3
6023	287	11
6024	172	16
6025	63	7
6026	161	9
6027	326	10
6028	467	16
6029	279	14
6030	409	19
6031	91	20
6032	498	7
6033	440	9
6034	368	5
6035	254	6
6036	433	13
6037	332	15
6038	261	8
6039	79	9
6040	57	13
6041	402	3
6042	93	11
6043	48	16
6044	108	8
6045	119	5
6046	80	13
6047	397	12
6048	55	14
6049	16	10
6050	333	10
6051	102	2
6052	322	21
6053	8	8
6054	389	12
6055	494	12
6056	71	7
6057	50	13
6058	320	18
6059	38	1
6060	329	15
6061	229	7
6062	129	7
6063	327	3
6064	168	12
6065	498	26
6066	81	10
6067	101	6
6068	329	12
6069	342	7
6070	181	8
6071	387	20
6072	243	2
6073	274	12
6074	436	12
6075	352	4
6076	394	10
6077	16	13
6078	249	8
6079	450	11
6080	33	16
6081	81	17
6082	51	13
6083	355	18
6084	90	17
6085	441	30
6086	349	20
6087	161	12
6088	491	8
6089	168	17
6090	199	10
6091	320	11
6092	398	14
6093	328	4
6094	146	17
6095	65	9
6096	325	11
6097	227	11
6098	167	15
6099	154	12
6100	69	8
6101	348	4
6102	41	3
6103	313	9
6104	122	26
6105	477	6
6106	164	2
6107	15	8
6108	494	10
6109	414	4
6110	465	11
6111	26	14
6112	496	13
6113	16	12
6114	382	14
6115	85	12
6116	457	15
6117	230	4
6118	246	10
6119	447	10
6120	399	15
6121	445	13
6122	266	11
6123	296	10
6124	273	11
6125	413	12
6126	361	10
6127	98	16
6128	139	17
6129	27	25
6130	252	7
6131	209	10
6132	376	20
6133	294	12
6134	22	10
6135	498	10
6136	271	17
6137	187	20
6138	13	10
6139	264	14
6140	100	18
6141	479	14
6142	291	13
6143	95	9
6144	495	6
6145	172	16
6146	180	6
6147	451	15
6148	402	20
6149	427	19
6150	397	13
6151	301	18
6152	372	3
6153	162	7
6154	96	12
6155	144	5
6156	75	15
6157	458	7
6158	242	20
6159	214	9
6160	486	10
6161	495	12
6162	424	11
6163	361	22
6164	288	17
6165	446	11
6166	359	5
6167	58	4
6168	132	5
6169	372	4
6170	323	10
6171	232	6
6172	350	15
6173	113	18
6174	328	14
6175	345	13
6176	286	15
6177	8	19
6178	295	20
6179	187	12
6180	435	9
6181	192	6
6182	489	7
6183	306	12
6184	355	11
6185	84	11
6186	451	12
6187	430	6
6188	42	17
6189	193	10
6190	144	10
6191	28	10
6192	188	21
6193	67	13
6194	389	8
6195	477	25
6196	13	11
6197	248	15
6198	35	12
6199	145	8
6200	119	15
6201	358	11
6202	378	9
6203	470	8
6204	472	6
6205	206	9
6206	314	12
6207	257	11
6208	214	14
6209	109	13
6210	445	22
6211	149	6
6212	301	13
6213	433	16
6214	456	4
6215	155	9
6216	17	21
6217	406	13
6218	84	10
6219	59	5
6220	99	17
6221	228	12
6222	87	4
6223	287	9
6224	295	16
6225	477	15
6226	263	10
6227	309	9
6228	225	19
6229	298	17
6230	454	13
6231	345	19
6232	156	7
6233	332	17
6234	314	16
6235	127	16
6236	38	6
6237	128	17
6238	385	13
6239	252	12
6240	237	4
6241	329	8
6242	402	1
6243	38	12
6244	261	8
6245	357	15
6246	193	13
6247	279	7
6248	262	13
6249	277	9
6250	338	12
6251	362	6
6252	5	13
6253	426	26
6254	148	28
6255	301	15
6256	403	5
6257	412	10
6258	109	16
6259	127	11
6260	210	18
6261	63	7
6262	472	11
6263	366	4
6264	396	15
6265	286	12
6266	494	12
6267	434	20
6268	414	8
6269	378	27
6270	186	6
6271	151	6
6272	206	10
6273	87	7
6274	189	5
6275	468	5
6276	444	11
6277	383	13
6278	246	13
6279	206	16
6280	160	12
6281	84	18
6282	67	12
6283	165	3
6284	10	9
6285	215	8
6286	466	20
6287	413	10
6288	126	5
6289	74	21
6290	40	9
6291	337	16
6292	138	8
6293	12	11
6294	202	16
6295	33	7
6296	298	13
6297	195	19
6298	467	12
6299	212	6
6300	73	16
6301	152	7
6302	364	16
6303	280	10
6304	239	11
6305	52	15
6306	247	9
6307	183	24
6308	436	7
6309	494	14
6310	389	11
6311	95	9
6312	78	7
6313	456	17
6314	260	12
6315	88	10
6316	171	9
6317	225	17
6318	1	10
6319	298	12
6320	300	11
6321	41	0
6322	134	5
6323	438	22
6324	53	27
6325	337	12
6326	471	11
6327	352	8
6328	32	4
6329	438	24
6330	63	0
6331	105	21
6332	90	3
6333	428	7
6334	385	7
6335	330	3
6336	480	11
6337	132	13
6338	12	22
6339	415	11
6340	125	24
6341	401	10
6342	10	18
6343	204	14
6344	357	13
6345	270	12
6346	292	10
6347	28	12
6348	496	7
6349	293	8
6350	326	20
6351	295	16
6352	335	10
6353	461	12
6354	233	16
6355	389	9
6356	297	17
6357	204	16
6358	241	19
6359	329	24
6360	141	7
6361	305	23
6362	434	7
6363	232	7
6364	232	7
6365	319	6
6366	61	14
6367	211	16
6368	451	18
6369	73	7
6370	126	23
6371	76	14
6372	475	6
6373	136	18
6374	280	3
6375	332	4
6376	407	27
6377	72	20
6378	360	17
6379	402	8
6380	366	12
6381	186	13
6382	197	6
6383	200	13
6384	146	10
6385	430	14
6386	89	22
6387	443	14
6388	134	7
6389	330	17
6390	271	10
6391	276	9
6392	134	19
6393	205	10
6394	7	25
6395	366	11
6396	23	7
6397	68	11
6398	77	7
6399	475	6
6400	142	8
6401	204	8
6402	51	20
6403	117	10
6404	341	18
6405	332	4
6406	449	13
6407	247	13
6408	404	8
6409	309	16
6410	149	8
6411	269	8
6412	495	12
6413	346	9
6414	470	12
6415	140	12
6416	276	20
6417	58	19
6418	83	15
6419	410	12
6420	389	19
6421	355	16
6422	185	14
6423	22	9
6424	60	2
6425	192	7
6426	389	7
6427	83	14
6428	261	5
6429	467	4
6430	58	14
6431	404	8
6432	170	12
6433	110	10
6434	20	21
6435	11	13
6436	442	9
6437	469	10
6438	258	9
6439	346	7
6440	278	7
6441	407	12
6442	115	12
6443	272	14
6444	253	14
6445	84	13
6446	413	19
6447	28	23
6448	143	12
6449	497	26
6450	438	14
6451	32	11
6452	351	11
6453	122	9
6454	55	9
6455	411	9
6456	315	15
6457	444	7
6458	495	19
6459	76	12
6460	410	12
6461	53	10
6462	480	15
6463	80	13
6464	163	7
6465	500	2
6466	91	11
6467	105	19
6468	469	12
6469	350	9
6470	452	10
6471	246	10
6472	257	12
6473	66	15
6474	18	11
6475	9	28
6476	151	16
6477	431	4
6478	37	11
6479	294	9
6480	428	4
6481	475	12
6482	326	11
6483	278	6
6484	97	15
6485	382	12
6486	189	11
6487	413	12
6488	325	8
6489	183	16
6490	489	19
6491	235	6
6492	237	22
6493	468	17
6494	316	19
6495	401	15
6496	468	6
6497	408	6
6498	5	8
6499	436	25
6500	257	16
6501	457	17
6502	182	9
6503	13	6
6504	23	20
6505	200	14
6506	23	6
6507	174	16
6508	131	15
6509	60	8
6510	468	12
6511	58	8
6512	35	8
6513	294	15
6514	337	15
6515	132	6
6516	175	15
6517	25	13
6518	44	11
6519	0	3
6520	209	11
6521	33	9
6522	236	16
6523	446	9
6524	1	15
6525	51	24
6526	346	18
6527	469	8
6528	459	10
6529	352	4
6530	405	4
6531	216	16
6532	309	17
6533	87	20
6534	230	6
6535	332	14
6536	287	20
6537	253	7
6538	5	6
6539	419	16
6540	313	12
6541	474	20
6542	477	12
6543	348	19
6544	268	13
6545	313	11
6546	481	9
6547	444	6
6548	339	7
6549	25	17
6550	445	26
6551	47	9
6552	58	14
6553	180	14
6554	494	12
6555	59	6
6556	232	12
6557	340	6
6558	28	10
6559	190	7
6560	191	10
6561	434	16
6562	407	16
6563	0	12
6564	20	15
6565	136	15
6566	333	8
6567	308	10
6568	389	21
6569	339	16
6570	226	10
6571	201	13
6572	313	10
6573	203	25
6574	49	17
6575	80	2
6576	15	14
6577	29	20
6578	24	16
6579	354	4
6580	54	9
6581	469	13
6582	402	12
6583	113	15
6584	148	10
6585	395	7
6586	173	6
6587	380	9
6588	234	8
6589	202	14
6590	70	11
6591	426	11
6592	135	10
6593	477	11
6594	427	9
6595	156	11
6596	113	7
6597	259	7
6598	464	6
6599	1	0
6600	97	21
6601	190	7
6602	203	4
6603	410	16
6604	393	9
6605	252	8
6606	491	5
6607	408	3
6608	282	10
6609	15	18
6610	262	5
6611	337	7
6612	484	22
6613	163	10
6614	450	8
6615	132	13
6616	58	15
6617	123	16
6618	12	9
6619	292	11
6620	325	13
6621	82	9
6622	218	15
6623	460	17
6624	59	18
6625	144	18
6626	115	15
6627	172	3
6628	403	8
6629	79	11
6630	174	17
6631	0	7
6632	269	5
6633	377	17
6634	411	9
6635	161	14
6636	129	16
6637	402	9
6638	69	6
6639	411	9
6640	417	13
6641	332	5
6642	248	16
6643	401	15
6644	496	7
6645	197	18
6646	32	8
6647	53	9
6648	320	16
6649	44	7
6650	346	10
6651	144	12
6652	127	13
6653	64	9
6654	104	21
6655	187	22
6656	208	11
6657	220	9
6658	360	11
6659	111	16
6660	299	2
6661	33	13
6662	112	16
6663	68	14
6664	410	14
6665	22	3
6666	230	16
6667	39	13
6668	425	14
6669	300	19
6670	450	9
6671	342	9
6672	131	6
6673	197	17
6674	242	14
6675	127	14
6676	395	3
6677	275	7
6678	181	5
6679	215	5
6680	320	8
6681	26	14
6682	360	11
6683	447	19
6684	91	17
6685	465	15
6686	134	18
6687	299	6
6688	184	25
6689	494	12
6690	410	8
6691	484	7
6692	26	9
6693	21	11
6694	51	7
6695	437	10
6696	44	18
6697	282	12
6698	476	6
6699	470	16
6700	81	15
6701	425	8
6702	311	16
6703	213	21
6704	122	25
6705	52	15
6706	340	13
6707	17	4
6708	327	18
6709	20	17
6710	233	10
6711	146	3
6712	47	19
6713	92	12
6714	93	13
6715	138	13
6716	56	8
6717	227	9
6718	438	8
6719	241	15
6720	220	9
6721	348	8
6722	224	22
6723	246	7
6724	370	12
6725	276	9
6726	183	11
6727	414	11
6728	57	17
6729	158	10
6730	383	8
6731	138	21
6732	83	13
6733	193	18
6734	351	13
6735	206	15
6736	246	9
6737	191	9
6738	223	3
6739	73	6
6740	212	35
6741	456	18
6742	219	12
6743	260	7
6744	48	6
6745	313	12
6746	398	15
6747	105	13
6748	39	15
6749	336	29
6750	347	5
6751	260	12
6752	183	2
6753	71	6
6754	6	14
6755	52	15
6756	347	6
6757	189	14
6758	466	9
6759	405	11
6760	347	10
6761	349	12
6762	43	18
6763	430	8
6764	42	7
6765	395	8
6766	135	16
6767	289	11
6768	85	18
6769	359	5
6770	362	10
6771	297	12
6772	315	11
6773	81	15
6774	56	17
6775	363	10
6776	394	6
6777	455	3
6778	469	10
6779	433	12
6780	290	7
6781	316	15
6782	193	9
6783	474	18
6784	387	10
6785	199	6
6786	25	11
6787	234	16
6788	388	7
6789	492	24
6790	138	20
6791	235	29
6792	340	11
6793	181	1
6794	164	10
6795	383	11
6796	75	7
6797	300	16
6798	171	9
6799	161	6
6800	158	15
6801	32	4
6802	459	19
6803	473	10
6804	113	18
6805	15	7
6806	336	4
6807	6	8
6808	471	9
6809	305	16
6810	440	7
6811	260	16
6812	120	15
6813	133	13
6814	233	5
6815	6	10
6816	332	19
6817	259	12
6818	240	18
6819	220	17
6820	250	6
6821	378	7
6822	455	10
6823	89	23
6824	59	9
6825	119	26
6826	473	5
6827	135	15
6828	419	7
6829	143	22
6830	296	16
6831	76	13
6832	176	13
6833	254	4
6834	48	10
6835	289	6
6836	269	5
6837	384	18
6838	296	13
6839	239	5
6840	188	24
6841	236	20
6842	500	15
6843	309	21
6844	369	17
6845	233	12
6846	315	11
6847	200	11
6848	493	20
6849	55	14
6850	421	21
6851	242	13
6852	434	16
6853	375	13
6854	332	11
6855	493	12
6856	494	11
6857	304	11
6858	127	18
6859	412	15
6860	448	17
6861	424	13
6862	489	12
6863	123	20
6864	178	11
6865	36	5
6866	412	11
6867	447	9
6868	421	7
6869	208	19
6870	186	11
6871	109	11
6872	444	16
6873	186	12
6874	418	16
6875	312	22
6876	420	12
6877	233	18
6878	12	11
6879	412	16
6880	289	12
6881	434	11
6882	153	16
6883	222	12
6884	308	9
6885	486	31
6886	215	11
6887	302	3
6888	289	20
6889	343	5
6890	214	11
6891	236	15
6892	266	5
6893	202	16
6894	359	16
6895	444	9
6896	239	10
6897	271	13
6898	391	17
6899	160	16
6900	479	10
6901	77	12
6902	269	14
6903	422	8
6904	264	17
6905	187	10
6906	234	16
6907	184	15
6908	421	12
6909	247	8
6910	95	16
6911	209	9
6912	180	21
6913	249	11
6914	431	17
6915	489	15
6916	234	9
6917	146	16
6918	291	19
6919	23	11
6920	489	15
6921	4	12
6922	259	7
6923	255	12
6924	207	18
6925	118	13
6926	199	4
6927	447	6
6928	389	11
6929	89	13
6930	106	13
6931	368	13
6932	167	10
6933	376	8
6934	290	13
6935	432	7
6936	62	9
6937	24	15
6938	115	18
6939	483	6
6940	271	5
6941	211	19
6942	192	10
6943	452	11
6944	460	11
6945	122	16
6946	440	12
6947	194	15
6948	269	12
6949	230	3
6950	217	22
6951	257	12
6952	235	11
6953	477	9
6954	12	8
6955	443	12
6956	95	12
6957	211	15
6958	389	12
6959	485	15
6960	301	15
6961	496	16
6962	352	8
6963	469	11
6964	371	11
6965	142	11
6966	400	17
6967	433	17
6968	166	12
6969	14	13
6970	416	11
6971	438	12
6972	225	6
6973	107	14
6974	389	12
6975	185	16
6976	230	9
6977	329	11
6978	379	10
6979	499	7
6980	59	5
6981	96	16
6982	256	13
6983	295	16
6984	73	12
6985	269	10
6986	237	16
6987	168	21
6988	480	6
6989	126	16
6990	152	15
6991	281	12
6992	121	7
6993	4	12
6994	249	8
6995	492	10
6996	146	12
6997	148	11
6998	425	7
6999	312	12
7000	163	19
7001	341	13
7002	250	9
7003	389	19
7004	448	13
7005	138	11
7006	73	17
7007	178	10
7008	468	6
7009	453	20
7010	177	10
7011	26	7
7012	48	10
7013	433	15
7014	321	3
7015	122	3
7016	202	13
7017	58	10
7018	290	5
7019	181	11
7020	184	11
7021	442	3
7022	463	11
7023	306	4
7024	446	17
7025	211	21
7026	298	8
7027	92	5
7028	360	2
7029	223	11
7030	405	11
7031	23	17
7032	63	19
7033	154	8
7034	412	11
7035	11	7
7036	292	3
7037	485	23
7038	189	12
7039	259	15
7040	438	13
7041	366	11
7042	286	4
7043	487	4
7044	299	19
7045	106	10
7046	108	10
7047	0	13
7048	165	10
7049	398	25
7050	182	2
7051	350	25
7052	340	10
7053	144	5
7054	155	1
7055	286	16
7056	356	10
7057	454	21
7058	378	13
7059	216	9
7060	176	22
7061	282	12
7062	239	8
7063	239	6
7064	436	9
7065	150	5
7066	251	24
7067	228	16
7068	135	18
7069	440	11
7070	488	16
7071	72	16
7072	306	15
7073	273	13
7074	59	7
7075	104	10
7076	380	7
7077	167	18
7078	104	19
7079	44	19
7080	64	10
7081	286	13
7082	394	6
7083	404	16
7084	431	12
7085	49	6
7086	189	14
7087	286	13
7088	2	12
7089	67	15
7090	1	11
7091	179	14
7092	349	14
7093	241	13
7094	419	11
7095	285	14
7096	391	16
7097	169	11
7098	12	8
7099	26	15
7100	108	8
7101	0	20
7102	99	13
7103	414	4
7104	273	25
7105	158	16
7106	18	6
7107	153	14
7108	325	14
7109	123	19
7110	197	10
7111	390	5
7112	410	8
7113	91	20
7114	293	8
7115	340	8
7116	141	7
7117	483	11
7118	126	8
7119	143	13
7120	50	8
7121	128	12
7122	323	6
7123	399	8
7124	369	19
7125	241	13
7126	184	11
7127	260	10
7128	410	16
7129	197	11
7130	286	14
7131	18	19
7132	197	15
7133	386	20
7134	433	9
7135	470	15
7136	44	11
7137	451	12
7138	123	14
7139	370	5
7140	73	15
7141	320	21
7142	259	19
7143	483	13
7144	412	14
7145	52	8
7146	323	12
7147	52	13
7148	35	15
7149	449	10
7150	196	12
7151	85	18
7152	76	21
7153	18	16
7154	485	4
7155	445	18
7156	259	14
7157	168	12
7158	205	15
7159	169	15
7160	365	8
7161	492	7
7162	187	17
7163	61	13
7164	377	11
7165	119	16
7166	31	12
7167	422	17
7168	70	14
7169	154	7
7170	291	16
7171	144	11
7172	475	18
7173	49	8
7174	127	18
7175	386	13
7176	101	17
7177	450	12
7178	438	19
7179	137	26
7180	399	20
7181	134	8
7182	222	7
7183	476	13
7184	152	12
7185	206	12
7186	420	10
7187	412	8
7188	374	12
7189	125	9
7190	80	12
7191	238	21
7192	116	12
7193	267	18
7194	300	8
7195	493	7
7196	387	24
7197	331	16
7198	415	14
7199	458	6
7200	486	6
7201	205	10
7202	101	15
7203	460	7
7204	254	10
7205	228	22
7206	345	11
7207	356	21
7208	178	12
7209	283	18
7210	493	12
7211	76	17
7212	417	8
7213	215	8
7214	51	16
7215	69	6
7216	421	10
7217	472	14
7218	481	7
7219	295	11
7220	96	19
7221	60	8
7222	33	19
7223	213	4
7224	328	9
7225	333	3
7226	206	6
7227	214	10
7228	164	11
7229	120	14
7230	171	9
7231	149	4
7232	325	12
7233	273	2
7234	108	4
7235	79	8
7236	1	10
7237	454	6
7238	435	10
7239	179	15
7240	237	7
7241	428	12
7242	256	5
7243	154	16
7244	143	7
7245	307	14
7246	223	18
7247	64	22
7248	279	6
7249	203	9
7250	359	8
7251	375	6
7252	264	2
7253	393	11
7254	87	14
7255	91	6
7256	226	6
7257	293	6
7258	306	7
7259	391	7
7260	414	7
7261	478	16
7262	39	19
7263	238	10
7264	250	15
7265	148	13
7266	317	11
7267	251	11
7268	102	9
7269	252	10
7270	431	9
7271	339	21
7272	180	8
7273	186	10
7274	493	7
7275	323	11
7276	493	15
7277	215	8
7278	387	8
7279	272	16
7280	419	14
7281	246	15
7282	147	13
7283	183	21
7284	138	15
7285	235	8
7286	274	1
7287	364	18
7288	28	10
7289	80	7
7290	254	15
7291	442	6
7292	57	11
7293	294	10
7294	179	6
7295	308	8
7296	443	13
7297	496	13
7298	59	7
7299	44	7
7300	248	12
7301	490	21
7302	383	14
7303	428	13
7304	176	13
7305	376	21
7306	250	13
7307	169	12
7308	91	5
7309	136	7
7310	441	13
7311	9	12
7312	382	22
7313	87	12
7314	193	9
7315	20	8
7316	322	12
7317	468	20
7318	384	6
7319	350	6
7320	47	18
7321	138	14
7322	291	4
7323	105	16
7324	433	11
7325	471	10
7326	413	17
7327	375	12
7328	466	6
7329	473	19
7330	419	11
7331	214	12
7332	462	10
7333	302	10
7334	141	8
7335	137	19
7336	177	6
7337	391	15
7338	306	16
7339	268	11
7340	27	5
7341	246	12
7342	278	8
7343	410	15
7344	334	15
7345	471	15
7346	430	10
7347	155	9
7348	438	11
7349	314	14
7350	5	21
7351	485	16
7352	453	11
7353	296	19
7354	90	15
7355	385	12
7356	267	8
7357	2	8
7358	259	10
7359	233	11
7360	475	14
7361	178	21
7362	447	18
7363	437	11
7364	480	7
7365	87	14
7366	74	17
7367	156	15
7368	478	10
7369	381	9
7370	424	10
7371	5	12
7372	127	20
7373	202	16
7374	415	4
7375	461	8
7376	172	18
7377	345	16
7378	116	16
7379	109	6
7380	158	17
7381	121	17
7382	94	14
7383	110	7
7384	418	9
7385	184	13
7386	496	9
7387	184	10
7388	187	19
7389	254	23
7390	417	7
7391	162	5
7392	432	10
7393	363	17
7394	98	13
7395	412	7
7396	451	2
7397	173	3
7398	67	16
7399	428	19
7400	53	20
7401	492	19
7402	434	12
7403	180	11
7404	193	23
7405	348	15
7406	140	8
7407	365	4
7408	192	14
7409	256	11
7410	475	18
7411	351	3
7412	378	14
7413	69	11
7414	462	18
7415	295	15
7416	254	17
7417	457	25
7418	480	18
7419	441	10
7420	211	12
7421	396	18
7422	103	8
7423	142	3
7424	259	19
7425	201	14
7426	54	16
7427	209	7
7428	375	11
7429	121	5
7430	137	11
7431	428	11
7432	113	21
7433	70	8
7434	107	12
7435	306	7
7436	419	12
7437	248	12
7438	171	20
7439	111	9
7440	4	10
7441	146	6
7442	462	18
7443	382	18
7444	215	7
7445	423	20
7446	177	15
7447	469	9
7448	380	2
7449	156	7
7450	410	9
7451	90	16
7452	52	17
7453	12	10
7454	233	14
7455	312	6
7456	214	9
7457	287	9
7458	20	10
7459	88	12
7460	409	13
7461	158	8
7462	16	8
7463	21	13
7464	229	1
7465	123	14
7466	327	6
7467	148	13
7468	372	14
7469	499	28
7470	259	17
7471	376	12
7472	144	5
7473	221	13
7474	257	13
7475	360	15
7476	144	3
7477	434	15
7478	329	0
7479	23	10
7480	89	9
7481	239	11
7482	114	9
7483	142	19
7484	251	15
7485	347	12
7486	454	12
7487	466	8
7488	134	18
7489	475	14
7490	54	5
7491	42	10
7492	132	4
7493	70	15
7494	63	16
7495	362	24
7496	193	8
7497	391	16
7498	9	8
7499	64	22
7500	389	17
7501	269	5
7502	440	5
7503	33	23
7504	491	10
7505	197	13
7506	393	17
7507	134	15
7508	130	15
7509	222	15
7510	158	9
7511	220	12
7512	461	22
7513	272	12
7514	362	13
7515	212	8
7516	119	6
7517	316	12
7518	177	9
7519	253	6
7520	290	12
7521	231	20
7522	296	8
7523	422	8
7524	301	10
7525	359	15
7526	284	11
7527	495	12
7528	250	10
7529	294	10
7530	59	5
7531	138	13
7532	62	14
7533	500	12
7534	172	11
7535	52	4
7536	197	5
7537	65	28
7538	187	15
7539	328	19
7540	287	16
7541	346	6
7542	47	3
7543	248	17
7544	118	13
7545	410	11
7546	460	15
7547	237	11
7548	225	20
7549	137	13
7550	491	10
7551	15	9
7552	369	24
7553	287	0
7554	438	10
7555	170	28
7556	145	13
7557	221	9
7558	164	13
7559	396	16
7560	14	19
7561	224	12
7562	34	8
7563	77	15
7564	224	15
7565	206	23
7566	130	7
7567	421	17
7568	271	23
7569	317	5
7570	248	12
7571	58	31
7572	162	14
7573	296	7
7574	306	12
7575	280	24
7576	205	11
7577	266	13
7578	17	14
7579	431	17
7580	403	8
7581	8	22
7582	446	22
7583	271	11
7584	295	10
7585	384	9
7586	442	20
7587	441	14
7588	104	2
7589	105	12
7590	336	7
7591	118	5
7592	330	4
7593	370	11
7594	196	7
7595	53	14
7596	75	17
7597	326	11
7598	474	15
7599	347	6
7600	142	13
7601	222	8
7602	406	29
7603	305	12
7604	17	11
7605	211	13
7606	84	13
7607	223	16
7608	478	14
7609	102	5
7610	154	16
7611	381	13
7612	110	17
7613	100	2
7614	152	18
7615	405	10
7616	484	8
7617	93	12
7618	345	13
7619	87	10
7620	199	14
7621	180	6
7622	206	17
7623	28	5
7624	50	21
7625	402	15
7626	82	12
7627	125	6
7628	227	12
7629	56	18
7630	473	11
7631	370	8
7632	278	19
7633	378	13
7634	174	11
7635	296	9
7636	89	3
7637	259	26
7638	18	18
7639	66	5
7640	361	12
7641	172	4
7642	448	9
7643	472	9
7644	273	28
7645	99	12
7646	376	11
7647	256	9
7648	192	15
7649	221	11
7650	344	21
7651	391	13
7652	402	12
7653	49	7
7654	420	8
7655	452	6
7656	452	15
7657	2	18
7658	77	20
7659	179	11
7660	58	6
7661	49	24
7662	48	11
7663	337	12
7664	428	14
7665	223	12
7666	132	11
7667	16	10
7668	482	7
7669	151	13
7670	83	8
7671	343	11
7672	324	8
7673	30	10
7674	314	23
7675	96	5
7676	129	22
7677	190	7
7678	353	4
7679	322	2
7680	411	11
7681	196	4
7682	213	11
7683	313	13
7684	246	4
7685	132	19
7686	264	6
7687	197	9
7688	135	5
7689	342	9
7690	376	4
7691	193	19
7692	391	12
7693	424	7
7694	30	14
7695	319	11
7696	146	6
7697	163	16
7698	335	4
7699	128	17
7700	314	12
7701	419	11
7702	471	16
7703	137	17
7704	449	6
7705	285	13
7706	234	10
7707	78	10
7708	475	5
7709	86	10
7710	400	10
7711	386	17
7712	283	9
7713	113	21
7714	198	10
7715	28	11
7716	246	24
7717	463	7
7718	225	8
7719	381	8
7720	304	3
7721	101	11
7722	74	6
7723	195	15
7724	25	21
7725	104	9
7726	13	15
7727	171	15
7728	267	16
7729	349	17
7730	300	12
7731	81	1
7732	267	10
7733	271	6
7734	219	14
7735	216	13
7736	55	14
7737	453	9
7738	294	18
7739	30	8
7740	39	11
7741	194	6
7742	417	9
7743	322	20
7744	307	10
7745	115	15
7746	350	5
7747	52	16
7748	77	23
7749	75	7
7750	433	17
7751	382	17
7752	176	11
7753	7	10
7754	76	12
7755	201	23
7756	111	12
7757	90	17
7758	373	21
7759	379	8
7760	439	8
7761	172	11
7762	460	16
7763	205	15
7764	443	16
7765	179	8
7766	422	17
7767	499	15
7768	131	12
7769	215	17
7770	29	19
7771	171	10
7772	410	8
7773	446	11
7774	493	6
7775	216	8
7776	61	6
7777	343	7
7778	269	23
7779	138	15
7780	418	10
7781	202	21
7782	20	9
7783	93	14
7784	209	16
7785	96	20
7786	295	13
7787	321	17
7788	187	25
7789	167	9
7790	199	14
7791	125	9
7792	339	11
7793	159	20
7794	331	13
7795	282	6
7796	338	5
7797	252	8
7798	281	20
7799	470	9
7800	468	7
7801	310	10
7802	140	9
7803	377	14
7804	256	1
7805	133	19
7806	93	13
7807	317	12
7808	476	14
7809	362	13
7810	456	17
7811	394	9
7812	64	15
7813	476	24
7814	487	19
7815	273	8
7816	72	17
7817	281	12
7818	94	12
7819	259	19
7820	449	6
7821	294	11
7822	385	15
7823	287	24
7824	453	7
7825	215	15
7826	69	5
7827	291	4
7828	468	11
7829	351	11
7830	261	11
7831	435	13
7832	160	17
7833	401	21
7834	311	11
7835	417	13
7836	34	13
7837	405	23
7838	234	12
7839	9	3
7840	266	13
7841	189	3
7842	404	9
7843	330	18
7844	165	7
7845	390	19
7846	103	13
7847	238	8
7848	171	12
7849	197	9
7850	498	29
7851	119	14
7852	491	13
7853	382	9
7854	407	6
7855	444	2
7856	97	10
7857	477	12
7858	234	5
7859	64	3
7860	327	6
7861	495	27
7862	500	23
7863	488	5
7864	396	13
7865	310	8
7866	404	11
7867	431	6
7868	215	14
7869	138	13
7870	441	23
7871	481	19
7872	327	20
7873	344	14
7874	311	12
7875	493	9
7876	234	6
7877	414	15
7878	230	9
7879	405	12
7880	111	21
7881	227	13
7882	24	9
7883	101	15
7884	108	12
7885	432	10
7886	44	13
7887	206	8
7888	408	20
7889	279	12
7890	270	15
7891	235	7
7892	274	16
7893	269	15
7894	222	9
7895	170	13
7896	79	13
7897	126	6
7898	100	22
7899	294	18
7900	264	25
7901	40	14
7902	275	9
7903	91	10
7904	384	7
7905	85	11
7906	83	20
7907	117	16
7908	500	8
7909	313	9
7910	22	5
7911	110	12
7912	40	19
7913	46	12
7914	212	7
7915	148	19
7916	479	12
7917	257	18
7918	354	12
7919	387	12
7920	36	24
7921	124	13
7922	121	11
7923	310	11
7924	394	4
7925	344	12
7926	480	8
7927	473	12
7928	471	19
7929	80	11
7930	267	8
7931	235	10
7932	120	6
7933	41	12
7934	326	7
7935	4	10
7936	127	15
7937	410	8
7938	121	8
7939	127	8
7940	223	9
7941	144	8
7942	238	13
7943	263	13
7944	190	7
7945	450	21
7946	412	4
7947	169	12
7948	206	15
7949	266	15
7950	55	21
7951	243	6
7952	390	10
7953	176	7
7954	52	18
7955	283	13
7956	19	11
7957	32	16
7958	256	6
7959	491	2
7960	112	10
7961	23	17
7962	225	5
7963	233	12
7964	65	12
7965	51	6
7966	237	10
7967	192	13
7968	461	13
7969	359	11
7970	320	29
7971	183	12
7972	2	8
7973	57	9
7974	447	16
7975	193	13
7976	6	10
7977	358	13
7978	362	16
7979	213	5
7980	123	7
7981	417	11
7982	457	16
7983	12	16
7984	93	14
7985	8	12
7986	296	10
7987	113	9
7988	41	17
7989	52	13
7990	103	6
7991	154	10
7992	75	15
7993	329	11
7994	387	7
7995	140	14
7996	380	11
7997	124	9
7998	333	18
7999	340	12
8000	484	12
8001	152	2
8002	23	16
8003	486	16
8004	210	6
8005	470	13
8006	178	9
8007	217	16
8008	328	12
8009	40	6
8010	431	20
8011	451	13
8012	458	13
8013	387	13
8014	464	16
8015	50	17
8016	395	15
8017	259	12
8018	163	20
8019	437	13
8020	311	4
8021	267	12
8022	90	10
8023	387	7
8024	95	8
8025	478	15
8026	26	13
8027	475	21
8028	102	13
8029	360	19
8030	315	11
8031	85	16
8032	12	24
8033	339	11
8034	70	7
8035	222	7
8036	308	5
8037	249	9
8038	439	30
8039	135	12
8040	290	10
8041	369	16
8042	86	6
8043	247	22
8044	255	11
8045	49	16
8046	298	15
8047	150	4
8048	309	6
8049	461	2
8050	86	18
8051	119	7
8052	228	18
8053	177	5
8054	5	8
8055	323	12
8056	154	17
8057	32	11
8058	298	16
8059	257	14
8060	393	10
8061	112	12
8062	342	11
8063	405	9
8064	451	16
8065	413	13
8066	126	13
8067	259	14
8068	161	13
8069	64	10
8070	395	9
8071	452	6
8072	434	12
8073	482	14
8074	198	9
8075	189	16
8076	30	7
8077	496	9
8078	339	19
8079	339	9
8080	457	5
8081	426	16
8082	459	7
8083	184	7
8084	102	5
8085	465	16
8086	7	2
8087	257	4
8088	498	7
8089	305	23
8090	13	12
8091	390	19
8092	418	12
8093	355	6
8094	294	9
8095	369	5
8096	267	7
8097	420	12
8098	128	19
8099	429	9
8100	485	7
8101	23	14
8102	380	21
8103	419	9
8104	4	8
8105	78	14
8106	107	12
8107	35	8
8108	73	22
8109	446	10
8110	374	5
8111	30	2
8112	371	12
8113	332	10
8114	215	5
8115	474	19
8116	297	5
8117	222	11
8118	230	10
8119	294	26
8120	27	6
8121	243	14
8122	183	9
8123	446	18
8124	98	21
8125	477	11
8126	315	21
8127	365	17
8128	397	11
8129	443	16
8130	294	10
8131	381	8
8132	467	9
8133	173	11
8134	299	9
8135	471	16
8136	252	17
8137	406	4
8138	5	12
8139	325	11
8140	352	8
8141	380	9
8142	356	10
8143	223	5
8144	212	20
8145	70	18
8146	196	29
8147	8	7
8148	293	13
8149	426	25
8150	302	16
8151	321	15
8152	169	15
8153	485	9
8154	267	13
8155	267	4
8156	462	21
8157	81	9
8158	132	6
8159	358	16
8160	24	7
8161	426	7
8162	239	12
8163	491	14
8164	99	11
8165	38	8
8166	461	2
8167	351	12
8168	445	14
8169	467	4
8170	176	6
8171	297	20
8172	346	21
8173	32	22
8174	19	9
8175	58	6
8176	102	9
8177	215	6
8178	66	19
8179	396	11
8180	141	15
8181	369	15
8182	217	12
8183	310	21
8184	354	8
8185	484	6
8186	76	16
8187	315	2
8188	64	22
8189	209	19
8190	173	16
8191	89	8
8192	135	14
8193	413	8
8194	79	12
8195	234	17
8196	451	10
8197	40	14
8198	85	13
8199	396	9
8200	6	3
8201	262	11
8202	192	13
8203	353	16
8204	294	19
8205	211	12
8206	411	8
8207	397	9
8208	427	24
8209	478	15
8210	293	18
8211	67	13
8212	346	17
8213	9	6
8214	377	18
8215	199	8
8216	494	8
8217	454	4
8218	13	3
8219	58	7
8220	162	24
8221	187	12
8222	147	11
8223	297	7
8224	99	11
8225	226	12
8226	31	15
8227	50	15
8228	266	23
8229	117	20
8230	446	12
8231	273	17
8232	379	9
8233	137	13
8234	126	5
8235	173	20
8236	349	11
8237	37	17
8238	70	13
8239	275	12
8240	14	9
8241	363	11
8242	342	18
8243	360	14
8244	373	8
8245	218	9
8246	59	7
8247	366	5
8248	172	5
8249	72	24
8250	425	13
8251	334	8
8252	260	10
8253	71	19
8254	131	8
8255	359	10
8256	298	14
8257	162	17
8258	409	16
8259	64	14
8260	280	13
8261	355	9
8262	338	8
8263	159	8
8264	493	13
8265	464	12
8266	332	15
8267	341	5
8268	1	10
8269	402	11
8270	116	15
8271	16	8
8272	265	14
8273	459	14
8274	376	13
8275	137	14
8276	177	9
8277	436	16
8278	3	13
8279	349	13
8280	8	18
8281	428	33
8282	182	10
8283	268	14
8284	500	23
8285	314	9
8286	126	12
8287	297	11
8288	477	12
8289	35	13
8290	362	7
8291	256	9
8292	391	7
8293	199	11
8294	415	18
8295	383	19
8296	163	16
8297	246	12
8298	224	14
8299	164	9
8300	148	12
8301	340	14
8302	180	24
8303	413	12
8304	299	17
8305	56	3
8306	49	22
8307	476	13
8308	492	17
8309	53	6
8310	324	9
8311	500	18
8312	481	11
8313	6	20
8314	267	14
8315	480	5
8316	320	7
8317	394	7
8318	277	15
8319	297	7
8320	430	16
8321	138	8
8322	52	11
8323	320	23
8324	337	16
8325	468	17
8326	203	20
8327	0	17
8328	214	12
8329	427	4
8330	164	12
8331	362	16
8332	267	8
8333	345	13
8334	275	13
8335	65	4
8336	402	8
8337	325	6
8338	40	14
8339	393	10
8340	378	8
8341	365	2
8342	393	18
8343	359	30
8344	371	5
8345	160	11
8346	338	11
8347	191	13
8348	53	18
8349	115	16
8350	488	17
8351	484	1
8352	254	5
8353	40	12
8354	304	8
8355	90	11
8356	7	13
8357	6	21
8358	91	12
8359	221	19
8360	433	13
8361	256	17
8362	83	12
8363	200	21
8364	100	16
8365	358	15
8366	265	19
8367	1	22
8368	182	20
8369	306	18
8370	395	22
8371	59	18
8372	170	6
8373	287	17
8374	418	7
8375	41	6
8376	447	8
8377	256	5
8378	233	8
8379	0	15
8380	371	13
8381	221	10
8382	484	5
8383	124	7
8384	261	15
8385	287	13
8386	215	10
8387	269	17
8388	294	10
8389	307	11
8390	490	13
8391	226	13
8392	62	12
8393	72	20
8394	426	11
8395	162	7
8396	430	11
8397	191	9
8398	164	4
8399	111	3
8400	498	15
8401	58	6
8402	171	10
8403	168	5
8404	346	0
8405	88	16
8406	209	8
8407	292	18
8408	345	17
8409	443	19
8410	293	19
8411	216	20
8412	163	13
8413	277	13
8414	341	9
8415	425	12
8416	64	16
8417	55	9
8418	193	14
8419	358	9
8420	363	16
8421	182	18
8422	84	9
8423	425	19
8424	255	7
8425	10	19
8426	86	15
8427	185	7
8428	201	9
8429	250	15
8430	297	15
8431	199	16
8432	309	9
8433	468	18
8434	367	19
8435	154	7
8436	56	12
8437	76	11
8438	447	14
8439	401	8
8440	18	9
8441	239	4
8442	117	25
8443	182	13
8444	15	5
8445	458	2
8446	106	6
8447	79	5
8448	13	4
8449	299	15
8450	437	13
8451	376	25
8452	482	9
8453	21	18
8454	300	24
8455	237	11
8456	31	8
8457	386	17
8458	422	13
8459	232	16
8460	136	15
8461	218	9
8462	431	15
8463	446	2
8464	186	15
8465	298	17
8466	99	11
8467	243	15
8468	374	12
8469	45	9
8470	143	10
8471	392	2
8472	284	5
8473	260	12
8474	73	13
8475	300	20
8476	217	7
8477	180	15
8478	380	16
8479	231	14
8480	480	11
8481	317	7
8482	106	14
8483	461	9
8484	338	12
8485	406	10
8486	198	3
8487	369	11
8488	292	11
8489	119	11
8490	101	4
8491	429	14
8492	338	15
8493	32	20
8494	374	20
8495	24	19
8496	330	6
8497	473	9
8498	267	12
8499	203	11
8500	18	9
8501	411	10
8502	95	22
8503	303	4
8504	170	8
8505	169	6
8506	102	27
8507	388	18
8508	349	17
8509	483	16
8510	119	16
8511	328	14
8512	299	6
8513	225	14
8514	289	6
8515	136	10
8516	130	11
8517	487	1
8518	4	18
8519	423	19
8520	106	16
8521	106	6
8522	351	15
8523	444	3
8524	138	4
8525	224	6
8526	469	13
8527	468	18
8528	197	14
8529	235	3
8530	171	5
8531	215	11
8532	145	4
8533	266	12
8534	18	8
8535	316	6
8536	435	7
8537	121	28
8538	204	27
8539	284	11
8540	103	8
8541	323	17
8542	112	6
8543	402	3
8544	47	8
8545	401	19
8546	37	11
8547	178	23
8548	388	22
8549	42	24
8550	100	17
8551	494	13
8552	148	9
8553	452	10
8554	438	13
8555	287	13
8556	175	13
8557	406	9
8558	254	12
8559	373	10
8560	140	14
8561	426	9
8562	87	11
8563	286	8
8564	191	14
8565	106	13
8566	101	8
8567	126	14
8568	227	7
8569	306	9
8570	411	11
8571	330	12
8572	128	14
8573	22	7
8574	231	12
8575	176	12
8576	423	19
8577	269	15
8578	355	10
8579	310	10
8580	312	11
8581	456	10
8582	304	9
8583	461	8
8584	407	9
8585	241	10
8586	247	4
8587	82	15
8588	146	3
8589	1	9
8590	455	10
8591	287	5
8592	427	3
8593	42	15
8594	73	5
8595	118	8
8596	148	10
8597	175	5
8598	245	9
8599	375	14
8600	481	14
8601	155	6
8602	205	3
8603	109	12
8604	178	7
8605	436	8
8606	286	17
8607	101	10
8608	205	8
8609	140	10
8610	412	14
8611	16	7
8612	96	12
8613	215	18
8614	478	2
8615	2	5
8616	456	25
8617	224	3
8618	85	12
8619	102	7
8620	226	17
8621	39	12
8622	390	18
8623	153	19
8624	82	10
8625	463	12
8626	272	11
8627	230	18
8628	138	20
8629	16	18
8630	105	9
8631	118	17
8632	172	11
8633	310	10
8634	228	10
8635	351	12
8636	246	17
8637	13	12
8638	452	2
8639	451	7
8640	154	13
8641	363	10
8642	468	16
8643	250	11
8644	77	10
8645	445	22
8646	253	5
8647	33	13
8648	169	7
8649	338	12
8650	136	5
8651	396	21
8652	378	18
8653	26	12
8654	48	14
8655	460	20
8656	490	4
8657	321	20
8658	190	14
8659	127	12
8660	338	12
8661	296	8
8662	246	7
8663	10	16
8664	105	5
8665	474	14
8666	361	18
8667	351	9
8668	487	13
8669	312	5
8670	302	12
8671	140	8
8672	175	6
8673	269	11
8674	391	6
8675	253	7
8676	214	7
8677	143	14
8678	287	5
8679	383	11
8680	482	15
8681	423	9
8682	279	21
8683	359	11
8684	450	17
8685	328	17
8686	319	13
8687	440	12
8688	148	9
8689	9	15
8690	66	9
8691	486	21
8692	305	8
8693	312	13
8694	496	7
8695	410	20
8696	286	18
8697	357	20
8698	261	4
8699	272	2
8700	168	7
8701	63	12
8702	413	4
8703	343	6
8704	332	7
8705	304	10
8706	95	8
8707	46	9
8708	448	14
8709	382	9
8710	430	13
8711	429	13
8712	305	9
8713	208	9
8714	288	10
8715	255	14
8716	35	9
8717	107	18
8718	194	15
8719	183	11
8720	116	13
8721	261	20
8722	169	15
8723	421	13
8724	72	11
8725	165	6
8726	330	8
8727	358	18
8728	21	12
8729	91	15
8730	130	13
8731	190	19
8732	154	18
8733	43	9
8734	33	8
8735	487	13
8736	347	7
8737	128	31
8738	32	5
8739	294	12
8740	10	9
8741	462	5
8742	223	14
8743	316	17
8744	169	11
8745	10	6
8746	70	5
8747	205	11
8748	118	4
8749	265	8
8750	389	4
8751	234	16
8752	25	11
8753	57	13
8754	154	12
8755	98	16
8756	223	24
8757	485	5
8758	456	6
8759	244	20
8760	75	11
8761	86	20
8762	435	5
8763	230	12
8764	129	14
8765	468	14
8766	216	19
8767	476	9
8768	96	15
8769	249	14
8770	270	18
8771	106	6
8772	210	3
8773	493	26
8774	423	9
8775	380	9
8776	3	13
8777	494	14
8778	85	17
8779	121	6
8780	258	11
8781	474	10
8782	355	5
8783	283	11
8784	31	5
8785	9	19
8786	381	9
8787	254	2
8788	494	24
8789	337	14
8790	499	7
8791	69	7
8792	423	8
8793	433	20
8794	300	8
8795	52	13
8796	400	22
8797	16	20
8798	28	14
8799	497	9
8800	265	2
8801	298	27
8802	102	5
8803	476	21
8804	291	21
8805	25	11
8806	356	8
8807	294	4
8808	18	9
8809	441	16
8810	415	12
8811	276	9
8812	415	1
8813	270	16
8814	59	13
8815	446	14
8816	279	16
8817	440	12
8818	199	10
8819	273	15
8820	276	14
8821	198	11
8822	343	17
8823	199	10
8824	131	14
8825	142	15
8826	252	19
8827	30	7
8828	158	13
8829	280	8
8830	27	17
8831	424	17
8832	78	5
8833	129	11
8834	399	14
8835	369	10
8836	155	9
8837	254	11
8838	162	9
8839	173	11
8840	195	13
8841	77	8
8842	450	15
8843	109	23
8844	347	23
8845	8	21
8846	55	18
8847	126	12
8848	448	11
8849	254	14
8850	400	10
8851	224	10
8852	453	16
8853	242	9
8854	424	9
8855	83	14
8856	385	16
8857	175	7
8858	114	22
8859	43	23
8860	456	15
8861	141	4
8862	467	3
8863	33	7
8864	271	16
8865	366	9
8866	402	16
8867	426	17
8868	120	14
8869	64	6
8870	99	4
8871	315	13
8872	142	18
8873	48	26
8874	425	8
8875	490	6
8876	56	8
8877	480	9
8878	115	8
8879	4	13
8880	234	12
8881	15	14
8882	229	1
8883	186	8
8884	258	9
8885	152	10
8886	269	20
8887	142	10
8888	328	14
8889	384	14
8890	186	11
8891	283	10
8892	24	15
8893	153	12
8894	317	16
8895	295	17
8896	18	3
8897	218	12
8898	221	13
8899	139	22
8900	283	12
8901	320	4
8902	455	14
8903	425	11
8904	368	7
8905	379	9
8906	414	9
8907	425	15
8908	358	9
8909	29	13
8910	429	17
8911	92	7
8912	44	20
8913	157	17
8914	278	7
8915	302	7
8916	310	15
8917	47	6
8918	445	14
8919	138	5
8920	432	11
8921	131	14
8922	421	6
8923	456	13
8924	284	17
8925	237	11
8926	251	22
8927	303	9
8928	456	11
8929	472	8
8930	442	14
8931	238	23
8932	291	13
8933	396	7
8934	163	12
8935	159	13
8936	275	10
8937	77	2
8938	83	7
8939	133	3
8940	106	12
8941	12	5
8942	225	28
8943	151	18
8944	169	14
8945	3	8
8946	454	1
8947	480	4
8948	51	7
8949	398	10
8950	117	6
8951	483	21
8952	29	8
8953	38	10
8954	438	10
8955	313	25
8956	276	8
8957	189	6
8958	116	18
8959	231	4
8960	160	21
8961	58	11
8962	470	16
8963	452	15
8964	455	16
8965	132	12
8966	110	22
8967	229	9
8968	209	11
8969	194	10
8970	362	13
8971	316	24
8972	206	17
8973	87	7
8974	467	6
8975	376	18
8976	90	14
8977	420	2
8978	356	15
8979	141	8
8980	318	13
8981	473	9
8982	123	15
8983	347	4
8984	11	16
8985	61	0
8986	160	6
8987	287	6
8988	250	13
8989	277	14
8990	17	7
8991	411	13
8992	335	16
8993	488	19
8994	362	26
8995	290	18
8996	120	13
8997	473	10
8998	18	7
8999	330	19
9000	167	17
9001	381	9
9002	145	10
9003	373	23
9004	469	13
9005	112	7
9006	248	14
9007	58	4
9008	31	7
9009	104	15
9010	199	9
9011	350	11
9012	76	9
9013	323	8
9014	197	5
9015	87	6
9016	385	11
9017	357	7
9018	375	10
9019	134	5
9020	134	12
9021	392	15
9022	45	14
9023	470	10
9024	380	9
9025	408	15
9026	259	10
9027	500	8
9028	380	13
9029	278	16
9030	329	8
9031	46	9
9032	159	2
9033	475	17
9034	420	15
9035	127	6
9036	86	8
9037	168	12
9038	185	12
9039	118	12
9040	272	11
9041	385	18
9042	468	14
9043	349	2
9044	208	11
9045	164	15
9046	437	19
9047	92	8
9048	21	6
9049	311	9
9050	227	11
9051	156	27
9052	203	9
9053	272	6
9054	125	13
9055	82	8
9056	179	21
9057	384	9
9058	81	10
9059	59	5
9060	162	13
9061	411	23
9062	106	10
9063	321	22
9064	385	9
9065	25	12
9066	448	11
9067	472	15
9068	194	14
9069	133	9
9070	89	15
9071	466	16
9072	18	3
9073	57	19
9074	315	33
9075	227	22
9076	222	7
9077	251	16
9078	319	18
9079	243	16
9080	61	11
9081	46	3
9082	400	13
9083	265	10
9084	319	6
9085	24	11
9086	347	15
9087	498	7
9088	409	17
9089	429	14
9090	57	18
9091	70	7
9092	339	16
9093	163	15
9094	391	0
9095	224	7
9096	189	5
9097	339	19
9098	195	16
9099	383	7
9100	472	8
9101	285	9
9102	349	6
9103	491	10
9104	342	12
9105	163	15
9106	217	15
9107	63	14
9108	415	3
9109	36	8
9110	307	28
9111	476	14
9112	82	3
9113	206	4
9114	240	13
9115	401	15
9116	230	17
9117	87	12
9118	399	9
9119	138	10
9120	15	9
9121	456	8
9122	209	11
9123	355	16
9124	119	12
9125	99	9
9126	79	29
9127	309	6
9128	438	9
9129	275	9
9130	192	15
9131	410	11
9132	59	12
9133	41	14
9134	401	6
9135	401	9
9136	204	8
9137	117	9
9138	465	15
9139	118	7
9140	154	9
9141	272	9
9142	94	15
9143	236	18
9144	478	6
9145	335	7
9146	137	12
9147	208	8
9148	422	10
9149	35	12
9150	347	11
9151	438	15
9152	492	12
9153	55	8
9154	293	18
9155	111	16
9156	155	7
9157	373	6
9158	421	9
9159	93	15
9160	147	5
9161	112	14
9162	2	12
9163	206	10
9164	154	22
9165	404	17
9166	107	14
9167	358	12
9168	21	5
9169	72	11
9170	477	17
9171	175	8
9172	344	14
9173	71	9
9174	412	14
9175	322	28
9176	407	9
9177	48	17
9178	29	16
9179	329	3
9180	84	4
9181	376	15
9182	266	20
9183	76	16
9184	432	11
9185	59	8
9186	188	12
9187	86	6
9188	432	12
9189	108	7
9190	179	10
9191	79	14
9192	221	16
9193	182	8
9194	286	17
9195	375	8
9196	85	14
9197	393	5
9198	233	16
9199	107	9
9200	466	17
9201	210	11
9202	282	13
9203	309	10
9204	282	16
9205	194	5
9206	130	24
9207	188	11
9208	243	13
9209	160	3
9210	16	7
9211	327	6
9212	36	29
9213	283	8
9214	404	1
9215	468	18
9216	342	10
9217	92	9
9218	53	6
9219	274	7
9220	200	9
9221	233	12
9222	353	8
9223	422	18
9224	415	21
9225	138	10
9226	296	7
9227	0	13
9228	31	15
9229	29	8
9230	107	15
9231	498	16
9232	239	14
9233	390	11
9234	307	34
9235	20	5
9236	83	13
9237	438	11
9238	208	16
9239	326	18
9240	97	12
9241	225	14
9242	153	23
9243	133	8
9244	7	5
9245	56	24
9246	101	23
9247	350	10
9248	149	8
9249	155	12
9250	124	19
9251	349	17
9252	388	6
9253	478	11
9254	271	9
9255	302	14
9256	116	15
9257	67	18
9258	303	11
9259	147	8
9260	96	10
9261	410	9
9262	145	10
9263	336	11
9264	300	11
9265	452	15
9266	357	12
9267	383	11
9268	389	15
9269	65	15
9270	208	3
9271	486	18
9272	290	18
9273	362	13
9274	119	10
9275	298	12
9276	419	9
9277	220	18
9278	147	12
9279	67	5
9280	375	22
9281	272	11
9282	417	20
9283	262	10
9284	249	3
9285	187	6
9286	64	13
9287	365	4
9288	254	11
9289	367	19
9290	12	15
9291	351	18
9292	277	15
9293	157	15
9294	186	10
9295	77	9
9296	108	24
9297	42	9
9298	460	8
9299	498	6
9300	107	7
9301	168	11
9302	483	6
9303	398	6
9304	29	0
9305	101	9
9306	195	10
9307	449	15
9308	322	14
9309	343	10
9310	15	22
9311	196	7
9312	114	12
9313	432	11
9314	459	15
9315	363	9
9316	118	8
9317	23	25
9318	228	16
9319	373	14
9320	391	6
9321	241	14
9322	223	12
9323	168	15
9324	398	7
9325	410	9
9326	245	20
9327	6	19
9328	452	24
9329	204	16
9330	3	14
9331	59	15
9332	373	17
9333	487	3
9334	457	12
9335	402	29
9336	88	10
9337	151	4
9338	351	12
9339	410	14
9340	494	3
9341	366	12
9342	106	6
9343	107	8
9344	297	17
9345	65	21
9346	471	10
9347	416	13
9348	88	23
9349	199	18
9350	289	11
9351	479	11
9352	440	8
9353	12	6
9354	146	14
9355	338	21
9356	422	8
9357	391	14
9358	344	13
9359	373	9
9360	95	10
9361	348	16
9362	432	14
9363	468	16
9364	335	11
9365	389	8
9366	370	8
9367	423	8
9368	39	14
9369	220	12
9370	333	6
9371	32	10
9372	86	8
9373	440	6
9374	140	12
9375	384	9
9376	4	3
9377	111	13
9378	300	10
9379	93	11
9380	310	9
9381	88	13
9382	72	8
9383	249	14
9384	100	14
9385	218	12
9386	87	28
9387	21	10
9388	109	3
9389	431	11
9390	395	20
9391	205	15
9392	279	10
9393	327	6
9394	173	10
9395	113	8
9396	215	13
9397	42	17
9398	36	5
9399	255	12
9400	263	16
9401	369	11
9402	288	20
9403	349	9
9404	309	25
9405	428	3
9406	232	14
9407	313	6
9408	39	14
9409	31	19
9410	406	13
9411	349	3
9412	120	13
9413	478	11
9414	98	11
9415	221	6
9416	196	7
9417	185	13
9418	242	13
9419	306	19
9420	116	22
9421	137	8
9422	10	15
9423	395	7
9424	464	11
9425	183	14
9426	8	9
9427	179	22
9428	226	14
9429	44	18
9430	434	13
9431	490	24
9432	414	9
9433	221	13
9434	338	7
9435	222	19
9436	149	11
9437	70	16
9438	34	14
9439	188	10
9440	102	13
9441	441	8
9442	37	13
9443	223	15
9444	419	19
9445	135	4
9446	444	10
9447	115	18
9448	321	13
9449	186	7
9450	422	3
9451	437	4
9452	323	14
9453	432	14
9454	332	21
9455	287	12
9456	115	13
9457	340	4
9458	467	6
9459	342	5
9460	385	6
9461	400	18
9462	331	27
9463	298	13
9464	121	19
9465	169	11
9466	19	18
9467	271	8
9468	239	11
9469	54	6
9470	459	15
9471	342	8
9472	496	10
9473	496	6
9474	64	16
9475	415	5
9476	131	6
9477	7	5
9478	29	11
9479	452	17
9480	193	11
9481	451	6
9482	388	12
9483	16	11
9484	383	14
9485	219	9
9486	303	16
9487	499	3
9488	59	19
9489	269	14
9490	340	14
9491	444	21
9492	169	13
9493	171	17
9494	242	12
9495	290	7
9496	340	5
9497	261	12
9498	61	10
9499	79	16
9500	316	9
9501	19	9
9502	421	16
9503	311	18
9504	15	8
9505	486	15
9506	226	6
9507	146	8
9508	493	18
9509	255	17
9510	97	17
9511	186	2
9512	206	10
9513	486	17
9514	202	8
9515	89	10
9516	205	21
9517	5	15
9518	87	6
9519	264	8
9520	275	13
9521	428	11
9522	208	6
9523	444	9
9524	98	13
9525	450	9
9526	234	16
9527	438	20
9528	211	18
9529	295	11
9530	17	1
9531	26	9
9532	315	32
9533	438	12
9534	338	27
9535	330	22
9536	423	6
9537	63	5
9538	476	9
9539	416	8
9540	319	20
9541	73	8
9542	102	13
9543	25	19
9544	58	12
9545	305	7
9546	114	18
9547	263	26
9548	310	17
9549	202	12
9550	27	13
9551	84	12
9552	129	16
9553	235	10
9554	28	3
9555	228	14
9556	185	17
9557	262	14
9558	166	6
9559	396	15
9560	57	7
9561	183	14
9562	423	6
9563	372	11
9564	120	11
9565	260	8
9566	201	8
9567	43	15
9568	324	7
9569	177	7
9570	460	6
9571	143	14
9572	250	5
9573	61	7
9574	168	11
9575	308	15
9576	366	8
9577	282	16
9578	70	14
9579	176	7
9580	485	18
9581	97	9
9582	260	12
9583	114	18
9584	333	11
9585	289	20
9586	342	21
9587	17	13
9588	50	21
9589	7	4
9590	413	10
9591	108	10
9592	190	15
9593	336	8
9594	480	12
9595	311	20
9596	95	9
9597	181	7
9598	355	21
9599	420	4
9600	358	7
9601	314	4
9602	62	10
9603	107	20
9604	376	8
9605	231	11
9606	415	16
9607	242	7
9608	13	12
9609	486	9
9610	418	7
9611	498	13
9612	83	16
9613	178	12
9614	111	7
9615	416	11
9616	467	11
9617	453	2
9618	433	22
9619	16	17
9620	461	10
9621	346	8
9622	124	13
9623	151	16
9624	181	14
9625	104	17
9626	463	10
9627	277	8
9628	285	11
9629	317	3
9630	197	12
9631	142	18
9632	131	16
9633	259	16
9634	250	17
9635	6	23
9636	491	12
9637	165	3
9638	248	17
9639	3	7
9640	150	11
9641	166	9
9642	0	7
9643	234	7
9644	344	14
9645	111	14
9646	149	3
9647	310	24
9648	64	5
9649	82	10
9650	327	7
9651	24	7
9652	429	14
9653	452	9
9654	176	20
9655	110	20
9656	55	10
9657	138	10
9658	387	9
9659	340	15
9660	455	12
9661	83	15
9662	483	16
9663	86	17
9664	343	21
9665	232	14
9666	93	21
9667	333	0
9668	397	14
9669	342	17
9670	336	11
9671	47	13
9672	7	14
9673	337	6
9674	281	13
9675	351	7
9676	449	13
9677	431	11
9678	160	16
9679	12	8
9680	13	7
9681	487	18
9682	37	21
9683	442	13
9684	438	11
9685	213	2
9686	51	16
9687	494	10
9688	352	8
9689	439	17
9690	334	5
9691	307	14
9692	22	7
9693	316	17
9694	393	10
9695	365	7
9696	48	18
9697	486	5
9698	198	15
9699	445	12
9700	327	14
9701	34	5
9702	492	10
9703	335	9
9704	371	11
9705	273	11
9706	185	11
9707	320	3
9708	203	16
9709	346	6
9710	332	17
9711	216	16
9712	333	1
9713	370	11
9714	158	10
9715	271	18
9716	82	19
9717	209	17
9718	264	11
9719	435	8
9720	147	19
9721	97	11
9722	241	21
9723	169	9
9724	414	20
9725	133	10
9726	34	7
9727	462	10
9728	119	6
9729	233	9
9730	406	16
9731	447	15
9732	267	2
9733	398	7
9734	281	8
9735	138	8
9736	170	9
9737	466	4
9738	458	17
9739	374	16
9740	312	13
9741	290	15
9742	90	5
9743	144	13
9744	159	8
9745	248	19
9746	415	9
9747	242	12
9748	458	13
9749	178	16
9750	176	11
9751	105	6
9752	276	13
9753	418	11
9754	274	11
9755	189	10
9756	50	13
9757	309	17
9758	150	12
9759	170	12
9760	41	15
9761	56	7
9762	116	6
9763	309	8
9764	455	21
9765	397	18
9766	448	19
9767	124	15
9768	363	11
9769	406	11
9770	499	9
9771	174	6
9772	196	11
9773	88	21
9774	319	8
9775	356	9
9776	337	2
9777	233	18
9778	98	11
9779	294	15
9780	412	12
9781	274	7
9782	399	24
9783	188	4
9784	192	17
9785	173	7
9786	377	14
9787	242	12
9788	482	15
9789	27	5
9790	412	11
9791	23	16
9792	83	10
9793	28	6
9794	333	26
9795	37	17
9796	425	14
9797	281	22
9798	162	21
9799	288	10
9800	186	6
9801	161	20
9802	463	12
9803	382	18
9804	250	23
9805	281	18
9806	238	14
9807	86	7
9808	14	10
9809	336	18
9810	380	18
9811	426	13
9812	110	12
9813	279	9
9814	114	8
9815	302	17
9816	452	7
9817	491	16
9818	43	6
9819	434	9
9820	18	2
9821	456	9
9822	458	12
9823	102	8
9824	484	4
9825	290	12
9826	140	12
9827	409	7
9828	70	16
9829	303	10
9830	196	10
9831	257	11
9832	464	8
9833	159	10
9834	139	7
9835	213	20
9836	440	12
9837	377	7
9838	300	14
9839	454	7
9840	212	7
9841	179	17
9842	380	13
9843	322	10
9844	458	8
9845	494	23
9846	124	17
9847	410	15
9848	485	12
9849	167	2
9850	343	12
9851	2	19
9852	123	13
9853	300	2
9854	105	10
9855	107	19
9856	90	0
9857	245	12
9858	15	12
9859	161	4
9860	47	19
9861	212	9
9862	418	13
9863	11	7
9864	371	11
9865	57	16
9866	224	3
9867	311	16
9868	434	8
9869	23	6
9870	265	25
9871	146	16
9872	203	18
9873	145	14
9874	469	5
9875	161	10
9876	139	15
9877	92	16
9878	70	10
9879	123	16
9880	259	10
9881	414	11
9882	126	6
9883	383	12
9884	214	18
9885	232	9
9886	490	14
9887	304	12
9888	477	12
9889	5	17
9890	466	17
9891	24	16
9892	218	14
9893	383	4
9894	35	12
9895	89	8
9896	440	9
9897	260	5
9898	400	20
9899	374	12
9900	284	5
9901	165	7
9902	19	8
9903	488	10
9904	310	10
9905	488	12
9906	148	21
9907	449	11
9908	79	12
9909	219	14
9910	72	6
9911	339	5
9912	133	8
9913	199	17
9914	222	8
9915	348	11
9916	431	12
9917	212	16
9918	152	13
9919	408	11
9920	217	18
9921	117	8
9922	432	6
9923	436	4
9924	0	13
9925	468	7
9926	24	15
9927	440	13
9928	228	17
9929	425	10
9930	314	17
9931	11	12
9932	89	22
9933	333	24
9934	500	6
9935	400	9
9936	321	4
9937	148	15
9938	349	18
9939	401	13
9940	368	19
9941	422	19
9942	239	19
9943	0	13
9944	120	11
9945	461	20
9946	348	16
9947	51	11
9948	173	7
9949	500	3
9950	460	16
9951	390	10
9952	117	6
9953	391	20
9954	326	7
9955	117	19
9956	359	21
9957	350	16
9958	57	6
9959	86	7
9960	275	13
9961	371	17
9962	98	9
9963	364	7
9964	204	28
9965	97	11
9966	264	5
9967	24	9
9968	245	3
9969	113	9
9970	425	4
9971	112	28
9972	34	6
9973	164	10
9974	113	14
9975	155	15
9976	125	4
9977	462	11
9978	206	13
9979	298	10
9980	462	5
9981	166	14
9982	188	7
9983	78	8
9984	56	14
9985	13	13
9986	195	14
9987	416	8
9988	364	27
9989	252	11
9990	2	18
9991	138	10
9992	123	16
9993	100	8
9994	2	13
9995	327	13
9996	198	13
9997	267	16
9998	352	3
9999	444	13
10000	3800	9
\.


--
-- Data for Name: orderlines; Type: TABLE DATA; Schema: public; Owner: chriskl
--

COPY orderlines (orderlineid, orderid, prod_id, quantity, orderdate) FROM stdin;
1	1	9117	1	2004-01-27
2	1	3353	3	2004-01-27
3	1	2778	2	2004-01-27
4	1	4774	2	2004-01-27
5	1	3648	2	2004-01-27
6	1	9523	3	2004-01-27
7	1	6358	3	2004-01-27
8	1	1417	2	2004-01-27
1	2	1567	2	2004-01-01
2	2	1298	1	2004-01-01
3	2	9990	1	2004-01-01
4	2	5130	3	2004-01-01
5	2	6127	1	2004-01-01
6	2	6376	2	2004-01-01
7	2	4936	3	2004-01-01
8	2	2926	3	2004-01-01
1	3	2834	2	2004-01-17
2	3	8078	3	2004-01-17
3	3	698	3	2004-01-17
4	3	5260	1	2004-01-17
5	3	1923	2	2004-01-17
6	3	8903	2	2004-01-17
7	3	642	1	2004-01-17
8	3	4578	1	2004-01-17
9	3	2383	3	2004-01-17
1	4	3753	3	2004-01-28
2	4	5126	3	2004-01-28
3	4	5317	1	2004-01-28
4	4	4377	3	2004-01-28
5	4	9309	3	2004-01-28
1	5	6879	1	2004-01-09
2	5	4402	3	2004-01-09
3	5	8293	1	2004-01-09
4	5	2290	3	2004-01-09
1	6	6574	3	2004-01-11
2	6	4396	3	2004-01-11
3	6	3985	3	2004-01-11
4	6	6843	3	2004-01-11
5	6	4825	1	2004-01-11
6	6	9503	3	2004-01-11
1	7	6196	1	2004-01-05
2	7	7861	1	2004-01-05
3	7	4471	1	2004-01-05
4	7	1876	1	2004-01-05
1	8	1032	1	2004-01-18
2	8	4955	3	2004-01-18
3	8	9848	3	2004-01-18
4	8	6845	2	2004-01-18
5	8	7498	2	2004-01-18
6	8	2942	1	2004-01-18
7	8	5845	1	2004-01-18
8	8	1524	3	2004-01-18
9	8	1255	3	2004-01-18
1	9	526	2	2004-01-06
2	9	1763	1	2004-01-06
3	9	7978	3	2004-01-06
4	9	6566	3	2004-01-06
5	9	6395	3	2004-01-06
6	9	935	1	2004-01-06
7	9	5203	1	2004-01-06
8	9	700	1	2004-01-06
9	9	4615	3	2004-01-06
1	10	10000	1	2004-01-18
2	10	8900	1	2004-01-18
1	11	42	3	2004-01-31
1	12	9131	3	2004-01-19
2	12	3591	2	2004-01-19
3	12	5795	2	2004-01-19
4	12	6874	1	2004-01-19
1	13	5770	3	2004-01-17
2	13	7479	2	2004-01-17
3	13	355	3	2004-01-17
4	13	8333	3	2004-01-17
5	13	8733	3	2004-01-17
6	13	9795	3	2004-01-17
7	13	9034	3	2004-01-17
8	13	6669	2	2004-01-17
9	13	1640	3	2004-01-17
1	14	6295	1	2004-01-28
2	14	7007	1	2004-01-28
3	14	3288	1	2004-01-28
1	15	5107	3	2004-01-03
2	15	2801	2	2004-01-03
3	15	7193	1	2004-01-03
4	15	4715	2	2004-01-03
5	15	9444	2	2004-01-03
6	15	3364	3	2004-01-03
1	16	8333	1	2004-01-14
2	16	6755	2	2004-01-14
3	16	4820	1	2004-01-14
4	16	7121	1	2004-01-14
5	16	6219	1	2004-01-14
6	16	4140	3	2004-01-14
1	17	6092	2	2004-01-21
2	17	7308	1	2004-01-21
1	18	6532	1	2004-01-23
2	18	5325	1	2004-01-23
3	18	2605	3	2004-01-23
4	18	6862	1	2004-01-23
5	18	1113	2	2004-01-23
6	18	5767	2	2004-01-23
7	18	6666	1	2004-01-23
1	19	9844	1	2004-01-25
2	19	8274	1	2004-01-25
1	20	7649	3	2004-01-06
2	20	1212	3	2004-01-06
3	20	3839	3	2004-01-06
4	20	9431	3	2004-01-06
5	20	8620	1	2004-01-06
6	20	7937	2	2004-01-06
7	20	2973	3	2004-01-06
8	20	9097	3	2004-01-06
9	20	4982	2	2004-01-06
1	21	4637	3	2004-01-06
2	21	4960	1	2004-01-06
3	21	1805	3	2004-01-06
4	21	7276	1	2004-01-06
5	21	6032	2	2004-01-06
1	22	4986	1	2004-01-26
2	22	1383	2	2004-01-26
1	23	8369	3	2004-01-11
2	23	4961	2	2004-01-11
3	23	3944	2	2004-01-11
4	23	6089	1	2004-01-11
5	23	1513	1	2004-01-11
6	23	1079	2	2004-01-11
1	24	4274	3	2004-01-12
1	25	4875	1	2004-01-19
2	25	8831	2	2004-01-19
3	25	5178	1	2004-01-19
4	25	5576	2	2004-01-19
5	25	8300	2	2004-01-19
6	25	2444	1	2004-01-19
7	25	7294	2	2004-01-19
1	26	4108	1	2004-01-31
2	26	7833	3	2004-01-31
1	27	492	2	2004-01-10
2	27	9865	3	2004-01-10
3	27	2109	2	2004-01-10
4	27	8652	1	2004-01-10
5	27	996	2	2004-01-10
6	27	3018	2	2004-01-10
7	27	8091	1	2004-01-10
1	28	6921	2	2004-01-02
2	28	1192	2	2004-01-02
3	28	5787	2	2004-01-02
4	28	5951	2	2004-01-02
5	28	3043	3	2004-01-02
6	28	4766	1	2004-01-02
7	28	6098	2	2004-01-02
8	28	6190	2	2004-01-02
1	29	9238	1	2004-01-08
1	30	3572	3	2004-01-15
2	30	3443	3	2004-01-15
3	30	6592	1	2004-01-15
1	31	3082	1	2004-01-08
2	31	1981	2	2004-01-08
3	31	1098	3	2004-01-08
4	31	7823	3	2004-01-08
5	31	2004	2	2004-01-08
6	31	3157	2	2004-01-08
7	31	2310	2	2004-01-08
8	31	5329	1	2004-01-08
1	32	3055	3	2004-01-18
2	32	2605	2	2004-01-18
3	32	5524	3	2004-01-18
4	32	6860	3	2004-01-18
1	33	5330	3	2004-01-22
1	34	3622	3	2004-01-20
2	34	8019	3	2004-01-20
3	34	1529	1	2004-01-20
4	34	636	3	2004-01-20
1	35	12	1	2004-01-06
2	35	3053	1	2004-01-06
3	35	6554	3	2004-01-06
4	35	1812	2	2004-01-06
5	35	6674	3	2004-01-06
6	35	6534	1	2004-01-06
1	36	8290	3	2004-01-28
2	36	9042	1	2004-01-28
3	36	3946	3	2004-01-28
4	36	8690	2	2004-01-28
5	36	7390	3	2004-01-28
1	37	4945	2	2004-01-08
2	37	9392	3	2004-01-08
3	37	8142	2	2004-01-08
4	37	6573	3	2004-01-08
5	37	9359	1	2004-01-08
6	37	8744	2	2004-01-08
7	37	6378	3	2004-01-08
8	37	7755	3	2004-01-08
9	37	2628	2	2004-01-08
1	38	8731	2	2004-01-15
2	38	4125	2	2004-01-15
3	38	5969	2	2004-01-15
4	38	5386	1	2004-01-15
5	38	5791	1	2004-01-15
6	38	7010	2	2004-01-15
7	38	8327	2	2004-01-15
8	38	1127	2	2004-01-15
1	39	6377	2	2004-01-16
2	39	1440	2	2004-01-16
3	39	2471	2	2004-01-16
4	39	175	3	2004-01-16
1	40	4774	3	2004-01-18
2	40	588	1	2004-01-18
3	40	6408	2	2004-01-18
4	40	2227	1	2004-01-18
5	40	6303	3	2004-01-18
1	41	9527	3	2004-01-23
2	41	8991	3	2004-01-23
3	41	3336	2	2004-01-23
4	41	2192	2	2004-01-23
5	41	9499	2	2004-01-23
6	41	8844	3	2004-01-23
7	41	1838	2	2004-01-23
8	41	7803	3	2004-01-23
1	42	3319	2	2004-01-29
2	42	5608	2	2004-01-29
3	42	6222	1	2004-01-29
4	42	4780	2	2004-01-29
5	42	6539	3	2004-01-29
6	42	2107	2	2004-01-29
7	42	8655	1	2004-01-29
8	42	3736	1	2004-01-29
9	42	6466	2	2004-01-29
1	43	5637	1	2004-01-21
2	43	190	2	2004-01-21
3	43	91	3	2004-01-21
4	43	6015	3	2004-01-21
5	43	8872	3	2004-01-21
6	43	1731	2	2004-01-21
1	44	1554	1	2004-01-16
2	44	8823	2	2004-01-16
3	44	8995	3	2004-01-16
4	44	4759	1	2004-01-16
5	44	9467	1	2004-01-16
6	44	8657	2	2004-01-16
7	44	7187	3	2004-01-16
8	44	1841	1	2004-01-16
9	44	1672	1	2004-01-16
1	45	9470	1	2004-01-20
2	45	1609	1	2004-01-20
3	45	4619	2	2004-01-20
1	46	3938	2	2004-01-29
1	47	5662	1	2004-01-14
2	47	348	2	2004-01-14
3	47	8140	3	2004-01-14
4	47	3564	3	2004-01-14
5	47	357	2	2004-01-14
6	47	2010	2	2004-01-14
7	47	6998	1	2004-01-14
8	47	8894	2	2004-01-14
9	47	3415	1	2004-01-14
1	48	9042	1	2004-01-24
2	48	7525	1	2004-01-24
3	48	8094	1	2004-01-24
4	48	5912	1	2004-01-24
5	48	1015	1	2004-01-24
6	48	2442	1	2004-01-24
7	48	5892	1	2004-01-24
1	49	4691	1	2004-01-28
2	49	5871	1	2004-01-28
3	49	5846	2	2004-01-28
4	49	8156	3	2004-01-28
5	49	5266	2	2004-01-28
6	49	7294	1	2004-01-28
7	49	2642	2	2004-01-28
8	49	5382	1	2004-01-28
9	49	9316	2	2004-01-28
1	50	6800	2	2004-01-07
2	50	4434	1	2004-01-07
3	50	7032	1	2004-01-07
1	51	162	3	2004-01-07
2	51	8525	2	2004-01-07
3	51	3215	3	2004-01-07
4	51	5269	3	2004-01-07
5	51	2503	1	2004-01-07
6	51	733	2	2004-01-07
7	51	8899	2	2004-01-07
1	52	3440	2	2004-01-17
2	52	440	1	2004-01-17
3	52	51	2	2004-01-17
4	52	2929	3	2004-01-17
5	52	8202	2	2004-01-17
6	52	4675	1	2004-01-17
7	52	1910	2	2004-01-17
1	53	7114	2	2004-01-29
2	53	929	3	2004-01-29
3	53	8675	1	2004-01-29
1	54	5787	3	2004-01-15
1	55	9465	1	2004-01-24
2	55	2749	1	2004-01-24
3	55	8098	1	2004-01-24
4	55	7468	1	2004-01-24
5	55	1734	3	2004-01-24
6	55	7609	1	2004-01-24
7	55	9812	3	2004-01-24
8	55	3416	3	2004-01-24
1	56	6005	1	2004-01-15
2	56	813	2	2004-01-15
3	56	1370	2	2004-01-15
1	57	6684	2	2004-01-04
2	57	3124	3	2004-01-04
1	58	3993	1	2004-01-24
2	58	4527	1	2004-01-24
3	58	3083	2	2004-01-24
4	58	55	2	2004-01-24
5	58	1263	2	2004-01-24
1	59	9103	3	2004-01-03
2	59	627	1	2004-01-03
3	59	5271	1	2004-01-03
4	59	9279	1	2004-01-03
5	59	3880	2	2004-01-03
6	59	6385	3	2004-01-03
7	59	5395	2	2004-01-03
1	60	7893	2	2004-01-26
2	60	3819	1	2004-01-26
1	61	8493	3	2004-01-26
2	61	7145	2	2004-01-26
3	61	5162	2	2004-01-26
4	61	5025	2	2004-01-26
5	61	6719	1	2004-01-26
6	61	7560	2	2004-01-26
7	61	1391	1	2004-01-26
8	61	1959	3	2004-01-26
9	61	8443	3	2004-01-26
1	62	8885	1	2004-01-06
1	63	6577	3	2004-01-15
2	63	2220	2	2004-01-15
3	63	7785	3	2004-01-15
1	64	8735	1	2004-01-05
2	64	6740	2	2004-01-05
3	64	8326	3	2004-01-05
4	64	7734	1	2004-01-05
5	64	5905	2	2004-01-05
6	64	7638	3	2004-01-05
1	65	1790	2	2004-01-09
2	65	4431	2	2004-01-09
1	66	6077	1	2004-01-21
2	66	8058	3	2004-01-21
3	66	3988	2	2004-01-21
4	66	3943	1	2004-01-21
5	66	5997	1	2004-01-21
6	66	9016	2	2004-01-21
7	66	8813	3	2004-01-21
8	66	4607	2	2004-01-21
1	67	3012	1	2004-01-10
2	67	7495	2	2004-01-10
3	67	4859	1	2004-01-10
4	67	8589	1	2004-01-10
5	67	2932	1	2004-01-10
6	67	29	3	2004-01-10
1	68	1755	1	2004-01-09
2	68	9598	3	2004-01-09
3	68	1130	3	2004-01-09
4	68	2073	3	2004-01-09
5	68	5362	3	2004-01-09
6	68	4659	3	2004-01-09
7	68	8924	3	2004-01-09
1	69	6737	1	2004-01-13
2	69	3472	2	2004-01-13
1	70	5412	1	2004-01-15
2	70	2687	1	2004-01-15
3	70	6934	2	2004-01-15
4	70	2364	2	2004-01-15
5	70	2192	2	2004-01-15
1	71	944	3	2004-01-16
1	72	1802	2	2004-01-28
2	72	4390	3	2004-01-28
3	72	6831	3	2004-01-28
1	73	6005	3	2004-01-12
1	74	3132	2	2004-01-04
2	74	4557	2	2004-01-04
3	74	7451	3	2004-01-04
4	74	9588	1	2004-01-04
5	74	206	1	2004-01-04
6	74	8979	3	2004-01-04
7	74	398	2	2004-01-04
8	74	1839	1	2004-01-04
1	75	4090	2	2004-01-25
2	75	6019	3	2004-01-25
3	75	5634	1	2004-01-25
4	75	8033	3	2004-01-25
5	75	714	3	2004-01-25
1	76	9169	1	2004-01-15
2	76	9009	3	2004-01-15
3	76	1918	3	2004-01-15
4	76	9287	1	2004-01-15
5	76	8210	3	2004-01-15
6	76	5088	1	2004-01-15
7	76	1883	1	2004-01-15
8	76	6276	1	2004-01-15
9	76	7487	1	2004-01-15
1	77	5528	3	2004-01-23
2	77	9578	2	2004-01-23
3	77	6379	2	2004-01-23
1	78	993	1	2004-01-01
2	78	8011	1	2004-01-01
3	78	1861	3	2004-01-01
4	78	3808	1	2004-01-01
5	78	6981	3	2004-01-01
6	78	117	3	2004-01-01
7	78	1768	2	2004-01-01
8	78	1483	3	2004-01-01
9	78	6757	3	2004-01-01
1	79	2230	1	2004-01-09
2	79	4527	3	2004-01-09
3	79	5458	2	2004-01-09
4	79	8569	3	2004-01-09
5	79	3867	3	2004-01-09
6	79	1742	1	2004-01-09
7	79	2472	2	2004-01-09
8	79	9174	2	2004-01-09
1	80	5019	3	2004-01-12
2	80	180	2	2004-01-12
3	80	6195	3	2004-01-12
4	80	5202	3	2004-01-12
1	81	7883	1	2004-01-08
2	81	3252	2	2004-01-08
3	81	6380	1	2004-01-08
4	81	2436	1	2004-01-08
5	81	1382	2	2004-01-08
1	82	132	1	2004-01-07
2	82	7452	2	2004-01-07
1	83	8971	3	2004-01-17
2	83	2355	2	2004-01-17
3	83	7395	2	2004-01-17
4	83	925	2	2004-01-17
5	83	9413	3	2004-01-17
1	84	4485	2	2004-01-20
2	84	3026	2	2004-01-20
3	84	8760	2	2004-01-20
1	85	7988	2	2004-01-31
2	85	5156	1	2004-01-31
3	85	6367	3	2004-01-31
4	85	8642	2	2004-01-31
5	85	5843	1	2004-01-31
6	85	9509	1	2004-01-31
7	85	5765	1	2004-01-31
8	85	7872	2	2004-01-31
9	85	9242	2	2004-01-31
1	86	5972	1	2004-01-25
2	86	8192	2	2004-01-25
3	86	5228	3	2004-01-25
1	87	5570	1	2004-01-04
2	87	2480	1	2004-01-04
3	87	317	1	2004-01-04
4	87	7273	2	2004-01-04
5	87	2118	3	2004-01-04
6	87	9397	3	2004-01-04
7	87	7216	3	2004-01-04
8	87	3060	2	2004-01-04
9	87	1542	1	2004-01-04
1	88	8674	1	2004-01-25
2	88	8547	2	2004-01-25
3	88	9328	3	2004-01-25
4	88	5573	3	2004-01-25
1	89	3078	1	2004-01-29
2	89	2671	1	2004-01-29
1	90	2672	2	2004-01-21
2	90	3141	2	2004-01-21
3	90	804	2	2004-01-21
4	90	6633	3	2004-01-21
5	90	3277	3	2004-01-21
6	90	2465	1	2004-01-21
1	91	826	1	2004-01-04
1	92	1445	2	2004-01-24
2	92	8008	2	2004-01-24
3	92	5993	2	2004-01-24
4	92	8905	1	2004-01-24
5	92	356	1	2004-01-24
6	92	7473	2	2004-01-24
7	92	7307	3	2004-01-24
1	93	3799	3	2004-01-26
2	93	3404	2	2004-01-26
1	94	677	2	2004-01-02
2	94	1123	1	2004-01-02
1	95	6683	2	2004-01-04
2	95	3554	2	2004-01-04
3	95	8002	2	2004-01-04
4	95	7162	2	2004-01-04
5	95	7405	2	2004-01-04
6	95	3750	2	2004-01-04
7	95	8409	1	2004-01-04
8	95	7036	1	2004-01-04
9	95	65	1	2004-01-04
1	96	1692	1	2004-01-23
2	96	6336	1	2004-01-23
3	96	3610	3	2004-01-23
1	97	7370	1	2004-01-17
2	97	7650	2	2004-01-17
1	98	9281	2	2004-01-13
2	98	6918	3	2004-01-13
1	99	4393	3	2004-01-17
2	99	5798	2	2004-01-17
3	99	142	3	2004-01-17
4	99	4453	2	2004-01-17
5	99	304	3	2004-01-17
1	100	7747	3	2004-01-13
1	101	208	2	2004-01-02
2	101	5632	3	2004-01-02
3	101	8731	1	2004-01-02
4	101	7176	2	2004-01-02
1	102	4248	2	2004-01-21
1	103	866	1	2004-01-16
2	103	7493	2	2004-01-16
3	103	8606	3	2004-01-16
4	103	5084	2	2004-01-16
5	103	5970	2	2004-01-16
6	103	1749	3	2004-01-16
7	103	9745	1	2004-01-16
8	103	3401	2	2004-01-16
9	103	1443	1	2004-01-16
1	104	5688	2	2004-01-25
2	104	5323	3	2004-01-25
3	104	592	1	2004-01-25
4	104	4325	1	2004-01-25
1	105	9932	2	2004-01-31
2	105	5271	2	2004-01-31
3	105	1091	1	2004-01-31
4	105	464	1	2004-01-31
5	105	503	1	2004-01-31
6	105	4795	2	2004-01-31
7	105	5586	2	2004-01-31
1	106	7939	1	2004-01-19
2	106	7627	1	2004-01-19
1	107	1429	1	2004-01-02
2	107	9993	3	2004-01-02
3	107	517	3	2004-01-02
4	107	2300	2	2004-01-02
5	107	4939	2	2004-01-02
1	108	5611	1	2004-01-22
2	108	1433	1	2004-01-22
3	108	7262	3	2004-01-22
4	108	4707	1	2004-01-22
5	108	9631	1	2004-01-22
6	108	2659	3	2004-01-22
7	108	5907	1	2004-01-22
1	109	2762	3	2004-01-17
2	109	4467	1	2004-01-17
3	109	7854	3	2004-01-17
4	109	9066	1	2004-01-17
5	109	157	2	2004-01-17
6	109	8194	2	2004-01-17
7	109	3622	2	2004-01-17
1	110	2520	3	2004-01-23
2	110	6789	1	2004-01-23
3	110	2353	3	2004-01-23
4	110	9409	3	2004-01-23
5	110	2583	2	2004-01-23
1	111	8451	2	2004-01-24
1	112	9096	1	2004-01-12
2	112	8924	3	2004-01-12
3	112	9567	1	2004-01-12
1	113	1651	1	2004-01-04
2	113	5801	3	2004-01-04
3	113	2269	3	2004-01-04
4	113	7886	1	2004-01-04
5	113	6412	1	2004-01-04
6	113	6561	2	2004-01-04
1	114	4607	3	2004-01-04
2	114	5743	3	2004-01-04
3	114	1225	2	2004-01-04
4	114	808	1	2004-01-04
5	114	2127	1	2004-01-04
6	114	2693	1	2004-01-04
7	114	7352	1	2004-01-04
8	114	9314	3	2004-01-04
9	114	408	2	2004-01-04
1	115	4353	3	2004-01-24
2	115	5795	1	2004-01-24
3	115	3818	3	2004-01-24
4	115	9264	3	2004-01-24
5	115	6223	2	2004-01-24
1	116	6802	1	2004-01-22
2	116	8212	3	2004-01-22
3	116	2681	1	2004-01-22
4	116	2148	1	2004-01-22
5	116	1194	1	2004-01-22
6	116	9034	1	2004-01-22
7	116	6576	2	2004-01-22
8	116	4278	3	2004-01-22
1	117	9543	2	2004-01-06
2	117	4380	3	2004-01-06
3	117	1784	1	2004-01-06
4	117	2677	3	2004-01-06
5	117	2566	2	2004-01-06
6	117	6685	3	2004-01-06
7	117	6482	2	2004-01-06
1	118	9195	3	2004-01-26
1	119	4704	1	2004-01-06
2	119	8323	2	2004-01-06
3	119	1501	3	2004-01-06
4	119	4101	1	2004-01-06
5	119	1182	3	2004-01-06
6	119	9850	1	2004-01-06
7	119	9082	1	2004-01-06
8	119	1586	1	2004-01-06
1	120	3167	3	2004-01-21
2	120	2345	3	2004-01-21
3	120	9754	1	2004-01-21
1	121	140	2	2004-01-19
2	121	7427	3	2004-01-19
3	121	976	3	2004-01-19
4	121	6305	2	2004-01-19
5	121	9971	3	2004-01-19
1	122	2346	1	2004-01-12
2	122	4284	3	2004-01-12
3	122	307	2	2004-01-12
1	123	2440	2	2004-01-07
2	123	6111	3	2004-01-07
3	123	6021	2	2004-01-07
4	123	2954	2	2004-01-07
5	123	351	1	2004-01-07
1	124	6402	3	2004-01-15
1	125	2593	1	2004-01-27
2	125	897	3	2004-01-27
3	125	488	1	2004-01-27
4	125	2173	1	2004-01-27
5	125	4676	3	2004-01-27
6	125	7287	3	2004-01-27
7	125	1143	2	2004-01-27
8	125	5514	3	2004-01-27
1	126	8846	3	2004-01-29
2	126	952	3	2004-01-29
3	126	8868	3	2004-01-29
4	126	7430	3	2004-01-29
5	126	7310	2	2004-01-29
6	126	6139	3	2004-01-29
7	126	7968	3	2004-01-29
8	126	6778	3	2004-01-29
9	126	8237	3	2004-01-29
1	127	27	3	2004-01-04
2	127	1854	2	2004-01-04
3	127	4036	1	2004-01-04
4	127	4006	3	2004-01-04
5	127	757	1	2004-01-04
6	127	5300	1	2004-01-04
7	127	1003	2	2004-01-04
8	127	9062	3	2004-01-04
1	128	6273	1	2004-01-05
2	128	4618	1	2004-01-05
3	128	1381	1	2004-01-05
4	128	2000	1	2004-01-05
5	128	5766	3	2004-01-05
6	128	1008	2	2004-01-05
7	128	4604	1	2004-01-05
1	129	5996	2	2004-01-05
2	129	8188	1	2004-01-05
3	129	6456	3	2004-01-05
4	129	5463	2	2004-01-05
5	129	7622	3	2004-01-05
1	130	5505	3	2004-01-06
2	130	1209	3	2004-01-06
3	130	1961	1	2004-01-06
4	130	9437	3	2004-01-06
5	130	938	1	2004-01-06
6	130	3519	2	2004-01-06
7	130	3305	2	2004-01-06
8	130	4180	3	2004-01-06
1	131	1471	3	2004-01-01
2	131	7563	3	2004-01-01
3	131	4014	2	2004-01-01
4	131	3841	2	2004-01-01
5	131	7764	3	2004-01-01
6	131	4060	1	2004-01-01
7	131	7438	2	2004-01-01
8	131	155	3	2004-01-01
1	132	35	1	2004-01-27
2	132	4955	2	2004-01-27
3	132	5493	3	2004-01-27
4	132	634	2	2004-01-27
5	132	9309	1	2004-01-27
6	132	4051	1	2004-01-27
7	132	1173	1	2004-01-27
8	132	7713	2	2004-01-27
9	132	6798	1	2004-01-27
1	133	7831	3	2004-01-04
2	133	413	3	2004-01-04
3	133	6721	3	2004-01-04
4	133	7576	2	2004-01-04
5	133	8302	3	2004-01-04
1	134	2389	1	2004-01-14
2	134	5660	1	2004-01-14
3	134	4259	3	2004-01-14
4	134	2477	2	2004-01-14
5	134	1325	1	2004-01-14
6	134	618	3	2004-01-14
7	134	1743	1	2004-01-14
8	134	2684	1	2004-01-14
9	134	6849	1	2004-01-14
1	135	6150	2	2004-01-28
2	135	9513	2	2004-01-28
3	135	3685	2	2004-01-28
4	135	7706	2	2004-01-28
5	135	3983	1	2004-01-28
6	135	6217	3	2004-01-28
1	136	5908	1	2004-01-06
2	136	4459	2	2004-01-06
3	136	8799	2	2004-01-06
4	136	8229	1	2004-01-06
1	137	2340	1	2004-01-25
2	137	2441	3	2004-01-25
3	137	6569	1	2004-01-25
4	137	2940	1	2004-01-25
5	137	5955	1	2004-01-25
6	137	4888	3	2004-01-25
7	137	741	1	2004-01-25
1	138	6802	3	2004-01-30
2	138	9611	1	2004-01-30
3	138	4013	3	2004-01-30
4	138	7461	1	2004-01-30
5	138	9892	2	2004-01-30
6	138	7320	1	2004-01-30
7	138	2061	3	2004-01-30
8	138	2383	2	2004-01-30
9	138	8148	3	2004-01-30
1	139	1734	2	2004-01-21
2	139	2348	1	2004-01-21
3	139	5197	1	2004-01-21
1	140	4265	1	2004-01-16
2	140	3070	3	2004-01-16
1	141	5817	3	2004-01-28
2	141	659	3	2004-01-28
3	141	7497	1	2004-01-28
4	141	2379	2	2004-01-28
5	141	1992	3	2004-01-28
6	141	6733	1	2004-01-28
7	141	1243	3	2004-01-28
8	141	5289	2	2004-01-28
1	142	7262	2	2004-01-03
2	142	7757	1	2004-01-03
3	142	6848	1	2004-01-03
4	142	9804	2	2004-01-03
5	142	1356	1	2004-01-03
6	142	4499	3	2004-01-03
1	143	8198	3	2004-01-26
2	143	1302	1	2004-01-26
3	143	6262	3	2004-01-26
4	143	1387	3	2004-01-26
5	143	6501	3	2004-01-26
6	143	1093	3	2004-01-26
1	144	2987	1	2004-01-23
2	144	5949	3	2004-01-23
3	144	1972	2	2004-01-23
4	144	5563	1	2004-01-23
1	145	5219	2	2004-01-19
2	145	9891	2	2004-01-19
3	145	2977	1	2004-01-19
4	145	3607	3	2004-01-19
1	146	1669	3	2004-01-29
2	146	3169	3	2004-01-29
3	146	4444	2	2004-01-29
4	146	3253	3	2004-01-29
5	146	7705	3	2004-01-29
6	146	7266	3	2004-01-29
1	147	2890	2	2004-01-16
1	148	1525	1	2004-01-17
2	148	6344	2	2004-01-17
3	148	1266	2	2004-01-17
4	148	124	3	2004-01-17
5	148	1298	1	2004-01-17
1	149	1025	2	2004-01-19
1	150	8405	3	2004-01-24
2	150	7810	1	2004-01-24
3	150	9054	1	2004-01-24
4	150	4909	2	2004-01-24
5	150	8808	2	2004-01-24
1	151	5462	3	2004-01-30
2	151	1379	2	2004-01-30
3	151	5261	1	2004-01-30
4	151	7377	1	2004-01-30
5	151	7143	3	2004-01-30
6	151	1387	3	2004-01-30
1	152	4085	2	2004-01-06
2	152	2970	1	2004-01-06
3	152	6707	1	2004-01-06
4	152	2594	1	2004-01-06
5	152	6338	1	2004-01-06
1	153	1612	3	2004-01-18
2	153	8817	1	2004-01-18
1	154	5179	1	2004-01-09
1	155	5669	3	2004-01-26
1	156	1647	3	2004-01-16
2	156	9958	2	2004-01-16
3	156	1491	2	2004-01-16
4	156	5641	3	2004-01-16
5	156	2098	3	2004-01-16
6	156	8628	2	2004-01-16
7	156	4567	3	2004-01-16
8	156	6699	3	2004-01-16
1	157	5174	2	2004-01-05
2	157	3265	2	2004-01-05
3	157	5674	3	2004-01-05
4	157	4019	1	2004-01-05
5	157	8685	3	2004-01-05
6	157	8572	1	2004-01-05
7	157	7064	3	2004-01-05
1	158	5620	3	2004-01-15
1	159	1692	3	2004-01-24
2	159	9496	1	2004-01-24
1	160	2648	1	2004-01-31
2	160	1016	3	2004-01-31
3	160	2109	2	2004-01-31
4	160	8959	1	2004-01-31
5	160	2223	3	2004-01-31
1	161	7841	1	2004-01-04
2	161	5906	2	2004-01-04
3	161	7803	2	2004-01-04
4	161	7707	3	2004-01-04
5	161	5640	3	2004-01-04
6	161	5761	2	2004-01-04
1	162	321	2	2004-01-09
2	162	5697	1	2004-01-09
3	162	3100	3	2004-01-09
1	163	9588	3	2004-01-20
2	163	7878	2	2004-01-20
3	163	5415	2	2004-01-20
4	163	6529	1	2004-01-20
5	163	9178	2	2004-01-20
6	163	4809	3	2004-01-20
7	163	2764	1	2004-01-20
8	163	6282	3	2004-01-20
1	164	1413	2	2004-01-18
2	164	2493	3	2004-01-18
3	164	5633	2	2004-01-18
4	164	4913	1	2004-01-18
5	164	7651	2	2004-01-18
6	164	593	3	2004-01-18
7	164	3230	3	2004-01-18
1	165	9965	2	2004-01-09
2	165	3745	2	2004-01-09
3	165	250	2	2004-01-09
4	165	5222	2	2004-01-09
5	165	5032	1	2004-01-09
6	165	5423	3	2004-01-09
7	165	8518	3	2004-01-09
8	165	3307	1	2004-01-09
9	165	3943	3	2004-01-09
1	166	2364	1	2004-01-21
2	166	1492	2	2004-01-21
3	166	5	2	2004-01-21
4	166	4238	2	2004-01-21
1	167	8976	3	2004-01-12
2	167	4042	2	2004-01-12
3	167	4337	3	2004-01-12
4	167	5001	3	2004-01-12
5	167	8082	2	2004-01-12
6	167	6594	1	2004-01-12
7	167	4530	1	2004-01-12
1	168	5386	1	2004-01-02
2	168	2802	3	2004-01-02
1	169	6998	2	2004-01-23
2	169	5789	2	2004-01-23
1	170	8961	3	2004-01-08
2	170	5692	2	2004-01-08
3	170	6457	2	2004-01-08
4	170	7480	1	2004-01-08
5	170	5163	1	2004-01-08
6	170	3588	2	2004-01-08
1	171	4734	3	2004-01-10
2	171	5404	1	2004-01-10
3	171	2366	2	2004-01-10
4	171	3668	3	2004-01-10
5	171	1703	3	2004-01-10
6	171	3918	2	2004-01-10
7	171	4220	2	2004-01-10
8	171	900	1	2004-01-10
1	172	365	2	2004-01-10
2	172	2484	2	2004-01-10
3	172	6629	2	2004-01-10
4	172	1017	3	2004-01-10
5	172	9050	3	2004-01-10
6	172	8296	2	2004-01-10
7	172	7334	2	2004-01-10
8	172	5865	3	2004-01-10
9	172	358	3	2004-01-10
1	173	6340	1	2004-01-29
2	173	9259	3	2004-01-29
3	173	6389	1	2004-01-29
1	174	8150	2	2004-01-12
2	174	9722	2	2004-01-12
3	174	223	1	2004-01-12
4	174	4548	3	2004-01-12
1	175	6543	3	2004-01-27
2	175	5544	3	2004-01-27
3	175	8454	2	2004-01-27
4	175	8961	3	2004-01-27
5	175	7585	2	2004-01-27
6	175	651	3	2004-01-27
1	176	569	1	2004-01-08
2	176	565	3	2004-01-08
3	176	4897	1	2004-01-08
4	176	3498	2	2004-01-08
5	176	1025	3	2004-01-08
6	176	4392	3	2004-01-08
1	177	6368	1	2004-01-03
2	177	4333	2	2004-01-03
3	177	5532	1	2004-01-03
4	177	2264	1	2004-01-03
5	177	8594	1	2004-01-03
6	177	9960	1	2004-01-03
7	177	9953	3	2004-01-03
1	178	9241	2	2004-01-24
2	178	8354	1	2004-01-24
3	178	9798	3	2004-01-24
4	178	783	2	2004-01-24
5	178	8916	1	2004-01-24
6	178	1637	2	2004-01-24
7	178	9103	3	2004-01-24
8	178	5223	2	2004-01-24
1	179	3871	2	2004-01-09
2	179	8003	2	2004-01-09
3	179	6454	3	2004-01-09
4	179	2866	2	2004-01-09
5	179	8478	1	2004-01-09
1	180	455	3	2004-01-07
1	181	2908	1	2004-01-31
2	181	2968	1	2004-01-31
3	181	954	3	2004-01-31
4	181	5446	2	2004-01-31
5	181	8944	1	2004-01-31
6	181	8868	1	2004-01-31
7	181	7495	3	2004-01-31
8	181	6644	2	2004-01-31
1	182	2157	3	2004-01-15
2	182	1020	3	2004-01-15
3	182	305	1	2004-01-15
1	183	8730	2	2004-01-21
2	183	867	1	2004-01-21
3	183	7630	1	2004-01-21
4	183	9887	1	2004-01-21
5	183	5600	3	2004-01-21
6	183	5249	2	2004-01-21
7	183	1645	1	2004-01-21
8	183	1337	3	2004-01-21
1	184	9464	3	2004-01-21
2	184	4525	1	2004-01-21
3	184	9435	2	2004-01-21
4	184	1958	2	2004-01-21
5	184	4888	2	2004-01-21
1	185	5313	3	2004-01-13
2	185	6645	2	2004-01-13
3	185	993	1	2004-01-13
4	185	4029	2	2004-01-13
5	185	6710	2	2004-01-13
1	186	4208	1	2004-01-28
2	186	273	2	2004-01-28
3	186	1709	2	2004-01-28
4	186	4156	1	2004-01-28
5	186	9626	2	2004-01-28
6	186	7184	2	2004-01-28
1	187	5965	2	2004-01-03
1	188	4853	1	2004-01-28
2	188	6221	1	2004-01-28
3	188	8342	2	2004-01-28
4	188	9609	1	2004-01-28
5	188	882	2	2004-01-28
6	188	4058	1	2004-01-28
7	188	7489	2	2004-01-28
8	188	5952	1	2004-01-28
9	188	6910	2	2004-01-28
1	189	5233	3	2004-01-25
2	189	9607	1	2004-01-25
3	189	1660	3	2004-01-25
4	189	3807	1	2004-01-25
5	189	8572	3	2004-01-25
6	189	2969	2	2004-01-25
7	189	222	1	2004-01-25
8	189	9997	3	2004-01-25
1	190	2032	1	2004-01-12
2	190	3435	3	2004-01-12
3	190	2779	1	2004-01-12
4	190	3560	1	2004-01-12
5	190	4436	2	2004-01-12
6	190	9074	3	2004-01-12
7	190	1866	3	2004-01-12
1	191	3825	2	2004-01-03
2	191	3333	3	2004-01-03
3	191	636	2	2004-01-03
4	191	8103	1	2004-01-03
5	191	3385	1	2004-01-03
1	192	8167	1	2004-01-05
2	192	1526	1	2004-01-05
3	192	3161	2	2004-01-05
4	192	1481	3	2004-01-05
1	193	9234	3	2004-01-28
1	194	2351	2	2004-01-13
2	194	4741	1	2004-01-13
3	194	9691	1	2004-01-13
4	194	3619	1	2004-01-13
5	194	4558	2	2004-01-13
6	194	107	2	2004-01-13
7	194	8672	3	2004-01-13
8	194	6757	1	2004-01-13
1	195	7515	2	2004-01-29
1	196	2912	3	2004-01-04
1	197	1854	1	2004-01-22
2	197	2330	1	2004-01-22
3	197	4266	2	2004-01-22
4	197	4619	3	2004-01-22
5	197	1078	2	2004-01-22
6	197	2762	3	2004-01-22
7	197	2998	3	2004-01-22
8	197	9946	1	2004-01-22
9	197	9437	2	2004-01-22
1	198	1731	2	2004-01-10
2	198	4654	2	2004-01-10
3	198	2585	1	2004-01-10
4	198	359	3	2004-01-10
1	199	3756	2	2004-01-04
2	199	9268	3	2004-01-04
3	199	3776	1	2004-01-04
1	200	6057	1	2004-01-10
2	200	8314	2	2004-01-10
3	200	5265	1	2004-01-10
4	200	2443	2	2004-01-10
5	200	5396	2	2004-01-10
6	200	8354	1	2004-01-10
1	201	204	1	2004-01-28
2	201	1386	1	2004-01-28
3	201	6005	2	2004-01-28
4	201	5846	2	2004-01-28
5	201	3516	3	2004-01-28
6	201	5618	2	2004-01-28
7	201	6159	2	2004-01-28
8	201	2713	1	2004-01-28
9	201	5750	1	2004-01-28
1	202	5518	3	2004-01-24
1	203	4809	3	2004-01-14
2	203	2313	2	2004-01-14
3	203	2081	2	2004-01-14
1	204	3358	1	2004-01-19
2	204	1370	3	2004-01-19
1	205	9744	1	2004-01-28
2	205	2709	3	2004-01-28
1	206	2612	1	2004-01-05
2	206	836	1	2004-01-05
3	206	5065	2	2004-01-05
4	206	9705	3	2004-01-05
5	206	656	1	2004-01-05
6	206	1076	2	2004-01-05
7	206	9870	3	2004-01-05
1	207	2201	1	2004-01-26
2	207	7206	3	2004-01-26
3	207	2921	3	2004-01-26
4	207	7320	2	2004-01-26
5	207	4402	3	2004-01-26
6	207	591	1	2004-01-26
7	207	5733	1	2004-01-26
8	207	3930	2	2004-01-26
9	207	3512	3	2004-01-26
1	208	5000	3	2004-01-07
2	208	9428	2	2004-01-07
3	208	7361	3	2004-01-07
1	209	868	2	2004-01-26
1	210	9418	2	2004-01-23
2	210	3269	1	2004-01-23
3	210	7974	3	2004-01-23
4	210	3210	1	2004-01-23
5	210	5570	3	2004-01-23
1	211	650	2	2004-01-03
2	211	4716	1	2004-01-03
3	211	9804	1	2004-01-03
4	211	7813	3	2004-01-03
5	211	1707	2	2004-01-03
6	211	8195	1	2004-01-03
7	211	9843	2	2004-01-03
1	212	7381	1	2004-01-20
2	212	5788	2	2004-01-20
3	212	2145	3	2004-01-20
4	212	7257	3	2004-01-20
5	212	5718	3	2004-01-20
6	212	5496	2	2004-01-20
1	213	6223	1	2004-01-17
1	214	9259	2	2004-01-07
2	214	6497	3	2004-01-07
3	214	1860	1	2004-01-07
4	214	513	1	2004-01-07
1	215	3246	3	2004-01-27
2	215	3424	1	2004-01-27
3	215	4739	3	2004-01-27
4	215	8657	1	2004-01-27
1	216	4219	1	2004-01-15
2	216	5773	2	2004-01-15
3	216	6635	2	2004-01-15
4	216	356	2	2004-01-15
5	216	547	3	2004-01-15
1	217	4143	3	2004-01-16
2	217	3400	3	2004-01-16
3	217	2777	2	2004-01-16
4	217	6047	2	2004-01-16
5	217	7148	1	2004-01-16
1	218	9884	3	2004-01-17
1	219	537	2	2004-01-18
2	219	5349	1	2004-01-18
1	220	8302	3	2004-01-08
2	220	3027	1	2004-01-08
3	220	5804	2	2004-01-08
4	220	1467	3	2004-01-08
5	220	3071	3	2004-01-08
6	220	4780	1	2004-01-08
7	220	8298	1	2004-01-08
1	221	6712	2	2004-01-19
2	221	9	3	2004-01-19
3	221	7054	1	2004-01-19
4	221	3339	1	2004-01-19
5	221	1437	2	2004-01-19
6	221	8298	3	2004-01-19
1	222	9044	1	2004-01-11
2	222	2834	1	2004-01-11
3	222	1018	2	2004-01-11
4	222	8023	2	2004-01-11
5	222	6122	2	2004-01-11
6	222	5917	1	2004-01-11
1	223	1937	3	2004-01-18
2	223	9055	3	2004-01-18
3	223	8603	1	2004-01-18
1	224	9219	1	2004-01-05
2	224	6289	2	2004-01-05
3	224	8046	2	2004-01-05
4	224	8290	1	2004-01-05
5	224	5842	3	2004-01-05
6	224	6783	2	2004-01-05
7	224	5105	1	2004-01-05
8	224	185	1	2004-01-05
9	224	5048	2	2004-01-05
1	225	1156	3	2004-01-23
2	225	8118	3	2004-01-23
3	225	9615	3	2004-01-23
4	225	9797	3	2004-01-23
5	225	9199	3	2004-01-23
6	225	9508	2	2004-01-23
7	225	4868	3	2004-01-23
8	225	819	1	2004-01-23
9	225	8434	2	2004-01-23
1	226	8121	1	2004-01-08
2	226	8589	1	2004-01-08
3	226	6528	2	2004-01-08
4	226	6266	2	2004-01-08
5	226	4906	3	2004-01-08
6	226	1916	1	2004-01-08
7	226	7180	1	2004-01-08
1	227	5992	3	2004-01-08
2	227	7218	1	2004-01-08
1	228	4697	2	2004-01-21
2	228	111	2	2004-01-21
3	228	4049	3	2004-01-21
4	228	5929	1	2004-01-21
5	228	1399	1	2004-01-21
1	229	5086	3	2004-01-27
2	229	6346	1	2004-01-27
3	229	595	3	2004-01-27
1	230	8902	3	2004-01-29
2	230	6091	2	2004-01-29
3	230	5864	1	2004-01-29
4	230	257	1	2004-01-29
5	230	6587	1	2004-01-29
1	231	3273	3	2004-01-18
2	231	4166	1	2004-01-18
1	232	383	1	2004-01-24
2	232	5009	1	2004-01-24
3	232	235	2	2004-01-24
1	233	8670	2	2004-01-04
2	233	5236	2	2004-01-04
3	233	5680	2	2004-01-04
4	233	5093	1	2004-01-04
5	233	5859	1	2004-01-04
6	233	2902	2	2004-01-04
7	233	2582	2	2004-01-04
8	233	4451	3	2004-01-04
9	233	7864	1	2004-01-04
1	234	4233	3	2004-01-25
2	234	9424	2	2004-01-25
3	234	4113	1	2004-01-25
4	234	5310	2	2004-01-25
5	234	268	2	2004-01-25
6	234	9168	2	2004-01-25
7	234	8511	2	2004-01-25
8	234	995	2	2004-01-25
1	235	1309	3	2004-01-23
1	236	7868	1	2004-01-20
2	236	6926	1	2004-01-20
3	236	317	1	2004-01-20
4	236	2584	3	2004-01-20
1	237	291	1	2004-01-18
1	238	4305	3	2004-01-16
2	238	7027	1	2004-01-16
3	238	3755	1	2004-01-16
4	238	1430	2	2004-01-16
1	239	1667	3	2004-01-27
2	239	4235	3	2004-01-27
3	239	1411	2	2004-01-27
1	240	691	2	2004-01-31
2	240	6308	1	2004-01-31
3	240	4831	1	2004-01-31
4	240	439	1	2004-01-31
5	240	4644	2	2004-01-31
1	241	3173	3	2004-01-24
2	241	6455	1	2004-01-24
1	242	5966	3	2004-01-17
2	242	5464	3	2004-01-17
3	242	2884	2	2004-01-17
4	242	1370	3	2004-01-17
5	242	588	1	2004-01-17
6	242	1603	3	2004-01-17
7	242	3041	2	2004-01-17
1	243	8221	2	2004-01-26
2	243	4430	2	2004-01-26
3	243	6201	3	2004-01-26
1	244	9932	2	2004-01-07
2	244	4044	2	2004-01-07
3	244	1762	3	2004-01-07
4	244	3272	2	2004-01-07
5	244	4721	2	2004-01-07
6	244	1821	2	2004-01-07
7	244	6702	2	2004-01-07
1	245	3221	3	2004-01-07
1	246	5821	3	2004-01-10
2	246	5111	3	2004-01-10
3	246	692	2	2004-01-10
4	246	4960	1	2004-01-10
5	246	7874	3	2004-01-10
6	246	6519	3	2004-01-10
7	246	8511	3	2004-01-10
1	247	8540	1	2004-01-14
2	247	9524	1	2004-01-14
3	247	876	3	2004-01-14
4	247	1065	2	2004-01-14
5	247	6406	2	2004-01-14
6	247	5538	3	2004-01-14
1	248	9147	3	2004-01-06
2	248	1208	2	2004-01-06
3	248	7590	3	2004-01-06
4	248	3110	2	2004-01-06
5	248	8717	1	2004-01-06
6	248	3899	1	2004-01-06
7	248	4851	3	2004-01-06
1	249	4136	1	2004-01-29
2	249	8000	2	2004-01-29
3	249	4437	2	2004-01-29
4	249	9345	3	2004-01-29
5	249	2645	1	2004-01-29
6	249	1334	3	2004-01-29
7	249	7763	1	2004-01-29
8	249	5889	3	2004-01-29
1	250	7587	3	2004-01-15
2	250	9316	1	2004-01-15
3	250	9765	2	2004-01-15
4	250	9817	3	2004-01-15
5	250	7557	3	2004-01-15
6	250	7482	1	2004-01-15
7	250	9622	2	2004-01-15
1	251	4033	1	2004-01-22
2	251	7236	2	2004-01-22
3	251	1452	2	2004-01-22
4	251	5846	3	2004-01-22
5	251	3968	1	2004-01-22
6	251	818	1	2004-01-22
1	252	9890	3	2004-01-26
2	252	1610	3	2004-01-26
3	252	7412	3	2004-01-26
4	252	8988	2	2004-01-26
5	252	859	3	2004-01-26
6	252	374	3	2004-01-26
7	252	2667	1	2004-01-26
1	253	2065	2	2004-01-13
2	253	6220	3	2004-01-13
1	254	2207	2	2004-01-05
2	254	802	1	2004-01-05
3	254	3915	1	2004-01-05
1	255	4691	3	2004-01-30
2	255	1849	2	2004-01-30
3	255	7993	1	2004-01-30
4	255	3299	1	2004-01-30
5	255	2481	3	2004-01-30
6	255	7358	2	2004-01-30
7	255	8509	3	2004-01-30
1	256	4916	2	2004-01-30
1	257	8116	2	2004-01-11
2	257	4979	3	2004-01-11
3	257	1583	2	2004-01-11
4	257	4615	2	2004-01-11
1	258	8685	2	2004-01-15
2	258	3413	1	2004-01-15
3	258	2406	1	2004-01-15
1	259	5642	3	2004-01-20
2	259	7031	1	2004-01-20
3	259	3198	1	2004-01-20
4	259	7681	2	2004-01-20
5	259	4804	2	2004-01-20
6	259	1401	3	2004-01-20
1	260	9255	3	2004-01-11
2	260	4533	1	2004-01-11
3	260	2673	1	2004-01-11
4	260	6197	2	2004-01-11
5	260	4383	3	2004-01-11
6	260	6856	1	2004-01-11
7	260	9517	3	2004-01-11
8	260	6760	2	2004-01-11
1	261	4307	2	2004-01-15
2	261	3112	3	2004-01-15
3	261	9192	2	2004-01-15
4	261	8893	1	2004-01-15
5	261	7495	2	2004-01-15
6	261	717	3	2004-01-15
7	261	3970	2	2004-01-15
1	262	2728	1	2004-01-25
2	262	2624	3	2004-01-25
3	262	3666	1	2004-01-25
4	262	6631	1	2004-01-25
1	263	8972	3	2004-01-23
2	263	6411	1	2004-01-23
3	263	7632	2	2004-01-23
1	264	575	3	2004-01-21
2	264	838	2	2004-01-21
3	264	4214	3	2004-01-21
4	264	1188	1	2004-01-21
1	265	3498	3	2004-01-09
2	265	7449	1	2004-01-09
3	265	9619	2	2004-01-09
4	265	1331	2	2004-01-09
5	265	7761	1	2004-01-09
1	266	9773	3	2004-01-08
2	266	6510	3	2004-01-08
3	266	3068	3	2004-01-08
4	266	6986	2	2004-01-08
5	266	1630	1	2004-01-08
6	266	2569	1	2004-01-08
7	266	3880	2	2004-01-08
8	266	6732	3	2004-01-08
9	266	563	1	2004-01-08
1	267	2758	1	2004-01-27
2	267	2055	1	2004-01-27
3	267	1990	2	2004-01-27
4	267	4689	2	2004-01-27
5	267	4394	2	2004-01-27
6	267	3353	1	2004-01-27
7	267	2482	2	2004-01-27
8	267	7987	3	2004-01-27
1	268	2433	2	2004-01-02
2	268	8149	3	2004-01-02
3	268	3956	3	2004-01-02
1	269	780	3	2004-01-30
2	269	1439	1	2004-01-30
3	269	9997	2	2004-01-30
4	269	7243	2	2004-01-30
5	269	7802	1	2004-01-30
6	269	9146	1	2004-01-30
7	269	2539	1	2004-01-30
8	269	7575	1	2004-01-30
9	269	1094	3	2004-01-30
1	270	6307	3	2004-01-01
2	270	1738	1	2004-01-01
3	270	7657	1	2004-01-01
1	271	3858	1	2004-01-09
2	271	6434	2	2004-01-09
3	271	5747	2	2004-01-09
4	271	8539	2	2004-01-09
1	272	9311	1	2004-01-17
2	272	8375	1	2004-01-17
3	272	179	3	2004-01-17
4	272	2164	1	2004-01-17
5	272	1089	3	2004-01-17
6	272	9921	1	2004-01-17
7	272	8733	3	2004-01-17
8	272	3956	1	2004-01-17
1	273	7155	1	2004-01-07
2	273	9666	1	2004-01-07
3	273	5262	3	2004-01-07
4	273	6449	1	2004-01-07
5	273	5889	1	2004-01-07
6	273	8423	2	2004-01-07
1	274	5312	3	2004-01-11
2	274	4581	2	2004-01-11
3	274	6237	2	2004-01-11
4	274	9226	2	2004-01-11
1	275	8017	1	2004-01-07
2	275	9844	2	2004-01-07
3	275	3259	3	2004-01-07
4	275	8071	3	2004-01-07
1	276	5670	3	2004-01-24
2	276	8801	3	2004-01-24
3	276	4312	2	2004-01-24
4	276	2703	3	2004-01-24
1	277	1784	2	2004-01-07
2	277	3373	2	2004-01-07
3	277	8429	3	2004-01-07
4	277	7893	2	2004-01-07
5	277	1566	3	2004-01-07
6	277	1615	2	2004-01-07
7	277	7246	3	2004-01-07
8	277	3345	2	2004-01-07
1	278	9953	3	2004-01-14
2	278	8970	2	2004-01-14
3	278	1764	1	2004-01-14
4	278	3889	2	2004-01-14
5	278	8955	3	2004-01-14
6	278	2336	1	2004-01-14
7	278	5160	2	2004-01-14
8	278	4598	2	2004-01-14
9	278	5601	1	2004-01-14
1	279	1990	3	2004-01-01
2	279	1334	2	2004-01-01
1	280	5411	3	2004-01-08
1	281	6053	2	2004-01-26
1	282	5745	1	2004-01-13
2	282	2093	1	2004-01-13
3	282	4537	3	2004-01-13
4	282	2832	2	2004-01-13
5	282	4859	1	2004-01-13
6	282	6218	3	2004-01-13
1	283	3088	3	2004-01-02
2	283	3953	3	2004-01-02
3	283	7677	1	2004-01-02
1	284	5543	2	2004-01-09
2	284	3938	1	2004-01-09
3	284	2860	3	2004-01-09
4	284	2280	2	2004-01-09
5	284	24	3	2004-01-09
6	284	2646	1	2004-01-09
7	284	1386	3	2004-01-09
8	284	5914	3	2004-01-09
9	284	4352	2	2004-01-09
1	285	6486	2	2004-01-16
2	285	6740	2	2004-01-16
3	285	5663	3	2004-01-16
4	285	3827	3	2004-01-16
5	285	8550	3	2004-01-16
6	285	4562	1	2004-01-16
7	285	700	3	2004-01-16
8	285	2170	1	2004-01-16
1	286	5049	1	2004-01-08
2	286	2523	1	2004-01-08
3	286	8785	3	2004-01-08
4	286	7404	2	2004-01-08
5	286	3407	3	2004-01-08
1	287	4054	2	2004-01-07
2	287	8537	3	2004-01-07
3	287	3912	3	2004-01-07
4	287	7248	3	2004-01-07
5	287	9574	3	2004-01-07
6	287	5895	1	2004-01-07
7	287	927	3	2004-01-07
8	287	3937	1	2004-01-07
9	287	3286	3	2004-01-07
1	288	2682	3	2004-01-06
1	289	5981	2	2004-01-15
2	289	5722	1	2004-01-15
3	289	144	2	2004-01-15
4	289	7913	2	2004-01-15
5	289	1345	2	2004-01-15
6	289	2529	1	2004-01-15
7	289	3108	3	2004-01-15
1	290	4757	3	2004-01-09
2	290	5584	2	2004-01-09
3	290	5785	2	2004-01-09
4	290	7347	3	2004-01-09
5	290	2880	1	2004-01-09
6	290	4556	3	2004-01-09
1	291	569	1	2004-01-28
2	291	8755	3	2004-01-28
3	291	5556	1	2004-01-28
4	291	3642	3	2004-01-28
5	291	1019	3	2004-01-28
1	292	279	2	2004-01-21
2	292	3175	2	2004-01-21
3	292	2201	3	2004-01-21
1	293	1519	1	2004-01-05
2	293	1308	1	2004-01-05
3	293	2517	1	2004-01-05
4	293	4791	1	2004-01-05
1	294	3645	2	2004-01-13
2	294	7802	2	2004-01-13
3	294	1959	2	2004-01-13
4	294	8343	1	2004-01-13
5	294	7507	3	2004-01-13
6	294	8284	1	2004-01-13
7	294	4483	1	2004-01-13
8	294	9641	2	2004-01-13
9	294	31	3	2004-01-13
1	295	1843	1	2004-01-01
2	295	4114	2	2004-01-01
1	296	7995	2	2004-01-15
2	296	1424	2	2004-01-15
3	296	8485	2	2004-01-15
4	296	106	3	2004-01-15
5	296	6125	3	2004-01-15
6	296	5449	2	2004-01-15
1	297	5804	2	2004-01-26
2	297	4999	2	2004-01-26
3	297	6471	2	2004-01-26
4	297	7398	3	2004-01-26
5	297	5609	1	2004-01-26
6	297	4947	1	2004-01-26
7	297	9788	2	2004-01-26
8	297	6472	3	2004-01-26
1	298	1276	2	2004-01-28
2	298	4259	3	2004-01-28
3	298	1295	3	2004-01-28
4	298	1808	3	2004-01-28
5	298	9638	3	2004-01-28
6	298	7521	2	2004-01-28
7	298	1620	1	2004-01-28
1	299	6404	1	2004-01-05
2	299	298	1	2004-01-05
3	299	2430	1	2004-01-05
4	299	6475	3	2004-01-05
5	299	7868	2	2004-01-05
6	299	6796	1	2004-01-05
7	299	2853	3	2004-01-05
8	299	5129	3	2004-01-05
1	300	6012	2	2004-01-17
2	300	3977	2	2004-01-17
3	300	1898	2	2004-01-17
4	300	6052	1	2004-01-17
5	300	3688	1	2004-01-17
6	300	2073	1	2004-01-17
7	300	4790	1	2004-01-17
1	301	6121	1	2004-01-05
2	301	3336	1	2004-01-05
3	301	1770	2	2004-01-05
4	301	987	3	2004-01-05
5	301	3299	2	2004-01-05
6	301	3322	1	2004-01-05
7	301	3737	3	2004-01-05
8	301	6573	3	2004-01-05
1	302	1756	3	2004-01-09
2	302	1533	2	2004-01-09
3	302	7089	2	2004-01-09
4	302	6198	3	2004-01-09
5	302	3542	3	2004-01-09
6	302	6445	3	2004-01-09
7	302	8978	3	2004-01-09
8	302	2578	1	2004-01-09
9	302	5969	2	2004-01-09
1	303	9384	2	2004-01-24
1	304	4427	2	2004-01-01
2	304	2078	2	2004-01-01
3	304	1781	2	2004-01-01
1	305	7398	2	2004-01-01
2	305	4861	2	2004-01-01
3	305	3136	2	2004-01-01
4	305	3623	2	2004-01-01
5	305	4585	3	2004-01-01
6	305	9278	1	2004-01-01
1	306	3061	2	2004-01-28
2	306	4198	2	2004-01-28
3	306	6652	3	2004-01-28
4	306	9317	3	2004-01-28
5	306	4807	1	2004-01-28
6	306	2338	2	2004-01-28
7	306	9966	1	2004-01-28
8	306	1024	3	2004-01-28
1	307	9723	2	2004-01-18
2	307	4592	2	2004-01-18
3	307	4419	2	2004-01-18
4	307	6535	1	2004-01-18
5	307	3171	3	2004-01-18
6	307	1517	2	2004-01-18
7	307	3218	2	2004-01-18
8	307	764	3	2004-01-18
1	308	1177	1	2004-01-14
2	308	3961	1	2004-01-14
3	308	3206	2	2004-01-14
4	308	8507	3	2004-01-14
5	308	868	3	2004-01-14
6	308	7826	1	2004-01-14
7	308	4541	1	2004-01-14
8	308	4896	3	2004-01-14
9	308	6287	1	2004-01-14
1	309	5687	2	2004-01-07
2	309	9465	2	2004-01-07
3	309	4246	2	2004-01-07
4	309	6530	1	2004-01-07
1	310	8849	3	2004-01-10
2	310	1892	3	2004-01-10
3	310	5933	1	2004-01-10
4	310	7068	2	2004-01-10
5	310	3349	1	2004-01-10
6	310	6176	3	2004-01-10
7	310	566	1	2004-01-10
1	311	6549	3	2004-01-30
1	312	9816	1	2004-01-17
2	312	2297	1	2004-01-17
3	312	8291	2	2004-01-17
4	312	9672	3	2004-01-17
5	312	3060	1	2004-01-17
6	312	4495	3	2004-01-17
7	312	4322	1	2004-01-17
8	312	2751	3	2004-01-17
9	312	3170	3	2004-01-17
1	313	6535	1	2004-01-19
2	313	6423	1	2004-01-19
3	313	913	1	2004-01-19
4	313	9097	2	2004-01-19
5	313	1085	3	2004-01-19
6	313	5553	2	2004-01-19
1	314	983	1	2004-01-06
2	314	2911	2	2004-01-06
1	315	4903	1	2004-01-05
2	315	3186	1	2004-01-05
3	315	3946	2	2004-01-05
4	315	6407	1	2004-01-05
1	316	4460	1	2004-01-25
2	316	3762	2	2004-01-25
3	316	1574	3	2004-01-25
4	316	8925	1	2004-01-25
5	316	3158	3	2004-01-25
6	316	4598	2	2004-01-25
7	316	897	3	2004-01-25
8	316	9618	1	2004-01-25
1	317	6867	3	2004-01-15
2	317	460	1	2004-01-15
3	317	4424	3	2004-01-15
4	317	1292	1	2004-01-15
5	317	9696	2	2004-01-15
6	317	1100	2	2004-01-15
7	317	7516	2	2004-01-15
8	317	9700	3	2004-01-15
9	317	4176	3	2004-01-15
1	318	1474	3	2004-01-08
2	318	4444	1	2004-01-08
3	318	306	3	2004-01-08
4	318	7749	3	2004-01-08
5	318	8826	2	2004-01-08
6	318	6819	3	2004-01-08
7	318	5427	1	2004-01-08
1	319	1574	2	2004-01-20
2	319	5	3	2004-01-20
3	319	9510	3	2004-01-20
4	319	8178	2	2004-01-20
5	319	8327	1	2004-01-20
6	319	1019	2	2004-01-20
1	320	3584	2	2004-01-24
2	320	1079	1	2004-01-24
1	321	9191	1	2004-01-02
2	321	8567	2	2004-01-02
3	321	8091	1	2004-01-02
4	321	1192	3	2004-01-02
5	321	6764	1	2004-01-02
6	321	8753	2	2004-01-02
7	321	899	3	2004-01-02
1	322	4557	2	2004-01-31
1	323	1324	3	2004-01-11
2	323	8384	1	2004-01-11
3	323	7776	2	2004-01-11
4	323	9153	3	2004-01-11
5	323	5703	3	2004-01-11
6	323	2309	2	2004-01-11
7	323	9835	2	2004-01-11
1	324	2870	2	2004-01-11
2	324	9141	1	2004-01-11
1	325	1484	3	2004-01-15
2	325	7165	3	2004-01-15
3	325	4324	3	2004-01-15
4	325	6148	1	2004-01-15
5	325	316	2	2004-01-15
6	325	7037	3	2004-01-15
7	325	890	1	2004-01-15
8	325	7187	1	2004-01-15
9	325	6533	3	2004-01-15
1	326	2201	2	2004-01-21
2	326	6990	1	2004-01-21
1	327	1188	3	2004-01-29
2	327	391	3	2004-01-29
3	327	7688	2	2004-01-29
1	328	7759	2	2004-01-22
2	328	6623	3	2004-01-22
3	328	7198	2	2004-01-22
4	328	1847	2	2004-01-22
5	328	830	3	2004-01-22
6	328	3721	2	2004-01-22
7	328	9941	2	2004-01-22
1	329	8741	2	2004-01-03
1	330	8281	1	2004-01-11
2	330	8472	2	2004-01-11
3	330	6122	2	2004-01-11
4	330	2275	2	2004-01-11
1	331	2706	2	2004-01-02
2	331	1278	2	2004-01-02
3	331	2921	2	2004-01-02
4	331	7982	1	2004-01-02
5	331	919	3	2004-01-02
6	331	9791	3	2004-01-02
7	331	9165	3	2004-01-02
1	332	6289	3	2004-01-11
2	332	255	2	2004-01-11
3	332	1861	2	2004-01-11
4	332	653	2	2004-01-11
5	332	257	1	2004-01-11
6	332	3033	1	2004-01-11
7	332	8552	2	2004-01-11
8	332	7160	3	2004-01-11
1	333	2941	2	2004-01-29
2	333	6172	1	2004-01-29
3	333	3927	2	2004-01-29
4	333	1264	3	2004-01-29
5	333	7869	3	2004-01-29
6	333	5264	2	2004-01-29
7	333	6464	2	2004-01-29
1	334	2460	1	2004-01-28
2	334	574	2	2004-01-28
3	334	4934	3	2004-01-28
4	334	1231	1	2004-01-28
5	334	8954	1	2004-01-28
6	334	2174	2	2004-01-28
7	334	7761	2	2004-01-28
8	334	9527	2	2004-01-28
9	334	7846	2	2004-01-28
1	335	8832	2	2004-01-29
2	335	1294	2	2004-01-29
3	335	1529	1	2004-01-29
4	335	3620	2	2004-01-29
5	335	9782	2	2004-01-29
6	335	5572	1	2004-01-29
7	335	1572	1	2004-01-29
1	336	3308	2	2004-01-30
2	336	2215	1	2004-01-30
3	336	9887	1	2004-01-30
4	336	4999	3	2004-01-30
5	336	5195	2	2004-01-30
6	336	6840	2	2004-01-30
7	336	1404	2	2004-01-30
8	336	1955	1	2004-01-30
1	337	6906	1	2004-01-03
2	337	667	1	2004-01-03
3	337	3044	1	2004-01-03
4	337	2984	1	2004-01-03
5	337	5042	2	2004-01-03
1	338	9416	1	2004-01-03
2	338	4913	2	2004-01-03
3	338	7973	1	2004-01-03
1	339	485	3	2004-01-27
1	340	6039	3	2004-01-09
2	340	8379	3	2004-01-09
3	340	872	1	2004-01-09
4	340	8944	2	2004-01-09
5	340	3946	2	2004-01-09
6	340	9438	2	2004-01-09
1	341	35	1	2004-01-08
2	341	6163	3	2004-01-08
1	342	4929	1	2004-01-10
2	342	7150	3	2004-01-10
3	342	4757	3	2004-01-10
4	342	3400	1	2004-01-10
5	342	7032	1	2004-01-10
6	342	7501	3	2004-01-10
7	342	3201	2	2004-01-10
8	342	1759	3	2004-01-10
9	342	430	1	2004-01-10
1	343	4512	1	2004-01-07
1	344	5519	1	2004-01-10
2	344	5349	1	2004-01-10
3	344	5157	1	2004-01-10
4	344	8158	3	2004-01-10
5	344	1136	1	2004-01-10
6	344	708	3	2004-01-10
1	345	4653	3	2004-01-11
2	345	3681	2	2004-01-11
3	345	9024	2	2004-01-11
4	345	7845	1	2004-01-11
5	345	5852	1	2004-01-11
6	345	1037	3	2004-01-11
1	346	1920	1	2004-01-10
2	346	8996	3	2004-01-10
3	346	3010	3	2004-01-10
4	346	6989	2	2004-01-10
5	346	8711	3	2004-01-10
6	346	2312	1	2004-01-10
7	346	5905	3	2004-01-10
8	346	8580	1	2004-01-10
1	347	7990	2	2004-01-20
2	347	5245	2	2004-01-20
3	347	5841	2	2004-01-20
4	347	2801	3	2004-01-20
5	347	6349	3	2004-01-20
1	348	5344	1	2004-01-24
2	348	3570	1	2004-01-24
3	348	5632	1	2004-01-24
4	348	29	3	2004-01-24
5	348	4325	2	2004-01-24
6	348	6325	1	2004-01-24
1	349	7765	1	2004-01-21
2	349	5612	1	2004-01-21
1	350	324	2	2004-01-22
2	350	7762	3	2004-01-22
3	350	3907	2	2004-01-22
4	350	4160	3	2004-01-22
5	350	7726	3	2004-01-22
6	350	1583	2	2004-01-22
7	350	9	1	2004-01-22
8	350	1301	2	2004-01-22
9	350	7543	3	2004-01-22
1	351	6161	3	2004-01-23
2	351	5557	1	2004-01-23
3	351	932	1	2004-01-23
1	352	5861	1	2004-01-10
2	352	1292	3	2004-01-10
3	352	6348	2	2004-01-10
4	352	9017	2	2004-01-10
1	353	2210	3	2004-01-10
2	353	7523	3	2004-01-10
3	353	6354	2	2004-01-10
1	354	4433	1	2004-01-12
2	354	1716	2	2004-01-12
3	354	5272	2	2004-01-12
4	354	5586	3	2004-01-12
5	354	8488	1	2004-01-12
6	354	7729	3	2004-01-12
7	354	1214	2	2004-01-12
8	354	5230	1	2004-01-12
9	354	8149	3	2004-01-12
1	355	4307	3	2004-01-03
2	355	2791	1	2004-01-03
3	355	3882	2	2004-01-03
1	356	3763	3	2004-01-23
2	356	6969	3	2004-01-23
1	357	4001	2	2004-01-10
2	357	1439	2	2004-01-10
1	358	5078	2	2004-01-27
2	358	2184	3	2004-01-27
3	358	9312	2	2004-01-27
4	358	5798	1	2004-01-27
5	358	7151	3	2004-01-27
6	358	8676	2	2004-01-27
1	359	3427	1	2004-01-03
2	359	3520	2	2004-01-03
3	359	5448	1	2004-01-03
4	359	8261	3	2004-01-03
5	359	4557	3	2004-01-03
1	360	9622	1	2004-01-15
1	361	8296	2	2004-01-20
2	361	7792	2	2004-01-20
3	361	3600	2	2004-01-20
4	361	9768	2	2004-01-20
5	361	1662	2	2004-01-20
6	361	8808	2	2004-01-20
1	362	2501	3	2004-01-27
2	362	3484	3	2004-01-27
3	362	9649	3	2004-01-27
4	362	72	2	2004-01-27
1	363	1499	2	2004-01-26
2	363	321	3	2004-01-26
3	363	9504	3	2004-01-26
4	363	5241	1	2004-01-26
5	363	4580	2	2004-01-26
1	364	1329	3	2004-01-24
2	364	8559	1	2004-01-24
3	364	3324	1	2004-01-24
4	364	2967	3	2004-01-24
5	364	8116	1	2004-01-24
6	364	4952	3	2004-01-24
1	365	7833	3	2004-01-27
2	365	1676	3	2004-01-27
3	365	9174	1	2004-01-27
4	365	6265	2	2004-01-27
5	365	4283	1	2004-01-27
6	365	9424	1	2004-01-27
1	366	9414	2	2004-01-22
2	366	1431	1	2004-01-22
3	366	7555	2	2004-01-22
4	366	9543	2	2004-01-22
5	366	7011	2	2004-01-22
6	366	3858	2	2004-01-22
7	366	7697	1	2004-01-22
8	366	1733	2	2004-01-22
1	367	4588	3	2004-01-04
1	368	577	3	2004-01-15
2	368	4255	3	2004-01-15
3	368	6286	2	2004-01-15
4	368	5011	3	2004-01-15
1	369	8236	3	2004-01-20
2	369	441	1	2004-01-20
3	369	4765	3	2004-01-20
4	369	3833	2	2004-01-20
5	369	3666	2	2004-01-20
6	369	9906	3	2004-01-20
1	370	3364	3	2004-01-17
2	370	4079	2	2004-01-17
3	370	5951	3	2004-01-17
4	370	2454	1	2004-01-17
5	370	2002	3	2004-01-17
6	370	9953	3	2004-01-17
7	370	30	1	2004-01-17
8	370	4353	3	2004-01-17
9	370	1189	2	2004-01-17
1	371	2450	2	2004-01-02
2	371	9142	1	2004-01-02
3	371	3941	2	2004-01-02
4	371	6849	1	2004-01-02
1	372	4152	2	2004-01-14
2	372	6746	2	2004-01-14
3	372	7497	3	2004-01-14
4	372	4069	3	2004-01-14
5	372	7153	2	2004-01-14
6	372	9515	1	2004-01-14
7	372	2364	1	2004-01-14
8	372	6299	1	2004-01-14
1	373	5825	2	2004-01-21
2	373	1460	3	2004-01-21
3	373	440	3	2004-01-21
4	373	996	2	2004-01-21
5	373	8521	1	2004-01-21
6	373	3186	1	2004-01-21
7	373	5565	3	2004-01-21
8	373	9277	1	2004-01-21
9	373	8679	2	2004-01-21
1	374	7337	3	2004-01-02
1	375	2864	3	2004-01-03
2	375	6487	3	2004-01-03
3	375	5499	3	2004-01-03
4	375	8453	2	2004-01-03
5	375	6255	3	2004-01-03
6	375	712	2	2004-01-03
7	375	9753	2	2004-01-03
1	376	8378	1	2004-01-24
2	376	71	3	2004-01-24
3	376	8338	3	2004-01-24
4	376	8912	2	2004-01-24
5	376	7322	3	2004-01-24
6	376	9309	3	2004-01-24
7	376	7020	1	2004-01-24
1	377	1452	3	2004-01-29
2	377	733	3	2004-01-29
3	377	8761	1	2004-01-29
4	377	2482	3	2004-01-29
5	377	5342	3	2004-01-29
1	378	1676	3	2004-01-12
2	378	1095	1	2004-01-12
1	379	9645	2	2004-01-14
2	379	1411	2	2004-01-14
1	380	5499	1	2004-01-23
2	380	7340	2	2004-01-23
3	380	9328	2	2004-01-23
4	380	7676	1	2004-01-23
5	380	4614	1	2004-01-23
6	380	1739	3	2004-01-23
7	380	2186	3	2004-01-23
8	380	652	2	2004-01-23
1	381	1753	3	2004-01-16
2	381	913	1	2004-01-16
3	381	4555	1	2004-01-16
4	381	8061	1	2004-01-16
5	381	3029	3	2004-01-16
6	381	9749	3	2004-01-16
7	381	9851	3	2004-01-16
8	381	4759	3	2004-01-16
9	381	3189	1	2004-01-16
1	382	6246	3	2004-01-04
2	382	1119	3	2004-01-04
3	382	1496	2	2004-01-04
1	383	4929	2	2004-01-27
1	384	1204	1	2004-01-06
2	384	8082	1	2004-01-06
3	384	379	3	2004-01-06
4	384	8041	2	2004-01-06
5	384	7111	1	2004-01-06
6	384	7571	3	2004-01-06
7	384	9031	1	2004-01-06
8	384	824	2	2004-01-06
9	384	657	1	2004-01-06
1	385	7522	2	2004-01-07
1	386	1933	3	2004-01-04
2	386	2857	1	2004-01-04
3	386	935	1	2004-01-04
1	387	6450	2	2004-01-13
2	387	3357	2	2004-01-13
1	388	7664	3	2004-01-13
2	388	6844	3	2004-01-13
3	388	9850	2	2004-01-13
4	388	655	3	2004-01-13
5	388	8781	1	2004-01-13
1	389	8126	3	2004-01-31
2	389	4889	3	2004-01-31
1	390	1105	3	2004-01-27
2	390	3516	2	2004-01-27
3	390	842	3	2004-01-27
4	390	6848	3	2004-01-27
5	390	2496	2	2004-01-27
6	390	5581	3	2004-01-27
7	390	4349	2	2004-01-27
1	391	6870	1	2004-01-14
2	391	2181	1	2004-01-14
3	391	4374	1	2004-01-14
1	392	8239	3	2004-01-30
2	392	5670	3	2004-01-30
3	392	6559	3	2004-01-30
4	392	3803	3	2004-01-30
5	392	6779	1	2004-01-30
6	392	5284	3	2004-01-30
7	392	5162	1	2004-01-30
8	392	8613	3	2004-01-30
1	393	6110	1	2004-01-20
2	393	1715	3	2004-01-20
3	393	3122	2	2004-01-20
4	393	8597	1	2004-01-20
5	393	5350	3	2004-01-20
6	393	724	2	2004-01-20
7	393	7701	2	2004-01-20
8	393	2931	2	2004-01-20
9	393	5579	3	2004-01-20
1	394	1631	1	2004-01-06
2	394	7806	1	2004-01-06
3	394	2055	2	2004-01-06
4	394	3214	2	2004-01-06
5	394	3193	3	2004-01-06
6	394	7948	2	2004-01-06
7	394	7614	1	2004-01-06
1	395	4174	2	2004-01-04
2	395	9933	1	2004-01-04
3	395	777	1	2004-01-04
4	395	6133	2	2004-01-04
5	395	9596	3	2004-01-04
6	395	8712	3	2004-01-04
1	396	585	1	2004-01-15
2	396	6639	2	2004-01-15
3	396	8145	3	2004-01-15
1	397	7163	2	2004-01-10
1	398	5206	1	2004-01-22
2	398	2992	2	2004-01-22
1	399	6916	1	2004-01-16
2	399	1445	1	2004-01-16
3	399	1390	1	2004-01-16
4	399	4189	1	2004-01-16
5	399	2546	1	2004-01-16
1	400	6783	2	2004-01-18
2	400	9629	2	2004-01-18
3	400	1126	2	2004-01-18
4	400	4767	1	2004-01-18
5	400	7693	3	2004-01-18
6	400	5210	1	2004-01-18
7	400	5954	1	2004-01-18
8	400	9809	3	2004-01-18
9	400	4546	3	2004-01-18
1	401	6958	1	2004-01-29
1	402	194	2	2004-01-09
2	402	7367	3	2004-01-09
3	402	9439	3	2004-01-09
4	402	921	1	2004-01-09
5	402	3568	2	2004-01-09
6	402	3766	1	2004-01-09
7	402	5659	3	2004-01-09
8	402	1945	1	2004-01-09
1	403	8478	3	2004-01-29
2	403	9591	3	2004-01-29
3	403	9969	2	2004-01-29
4	403	9411	1	2004-01-29
1	404	6842	3	2004-01-19
2	404	3220	2	2004-01-19
3	404	5505	2	2004-01-19
4	404	6844	3	2004-01-19
5	404	9827	1	2004-01-19
6	404	333	2	2004-01-19
1	405	4031	3	2004-01-30
2	405	2242	1	2004-01-30
3	405	6241	1	2004-01-30
4	405	9358	2	2004-01-30
5	405	8380	3	2004-01-30
6	405	8879	2	2004-01-30
7	405	1567	1	2004-01-30
8	405	673	3	2004-01-30
1	406	8032	1	2004-01-27
2	406	3109	3	2004-01-27
3	406	2142	2	2004-01-27
4	406	3342	1	2004-01-27
1	407	7438	1	2004-01-18
2	407	2258	2	2004-01-18
3	407	4441	1	2004-01-18
4	407	9887	1	2004-01-18
5	407	384	3	2004-01-18
6	407	7249	1	2004-01-18
7	407	8788	3	2004-01-18
8	407	359	3	2004-01-18
9	407	1814	2	2004-01-18
1	408	7703	3	2004-01-05
2	408	7905	1	2004-01-05
3	408	446	2	2004-01-05
4	408	1483	1	2004-01-05
5	408	3373	3	2004-01-05
1	409	7246	1	2004-01-11
2	409	681	3	2004-01-11
3	409	1250	3	2004-01-11
4	409	9580	1	2004-01-11
5	409	5851	3	2004-01-11
6	409	7357	3	2004-01-11
7	409	4984	3	2004-01-11
8	409	7510	1	2004-01-11
1	410	6256	1	2004-01-10
1	411	6658	2	2004-01-15
2	411	3707	3	2004-01-15
3	411	2822	1	2004-01-15
4	411	1740	2	2004-01-15
5	411	8581	1	2004-01-15
6	411	1431	3	2004-01-15
7	411	3026	3	2004-01-15
8	411	8098	1	2004-01-15
1	412	4643	1	2004-01-16
2	412	7667	2	2004-01-16
3	412	3352	2	2004-01-16
1	413	6132	3	2004-01-18
2	413	2150	3	2004-01-18
3	413	7573	2	2004-01-18
4	413	791	3	2004-01-18
5	413	8474	3	2004-01-18
6	413	2301	3	2004-01-18
7	413	7532	2	2004-01-18
1	414	8710	2	2004-01-23
2	414	4588	2	2004-01-23
1	415	6176	2	2004-01-22
1	416	6153	1	2004-01-27
2	416	4452	2	2004-01-27
3	416	8236	2	2004-01-27
4	416	3037	3	2004-01-27
5	416	4613	2	2004-01-27
1	417	7773	2	2004-01-21
2	417	5932	2	2004-01-21
3	417	1178	1	2004-01-21
4	417	9835	3	2004-01-21
1	418	2035	3	2004-01-09
2	418	6784	1	2004-01-09
3	418	1773	1	2004-01-09
4	418	6413	2	2004-01-09
5	418	6661	2	2004-01-09
6	418	1466	3	2004-01-09
7	418	1358	2	2004-01-09
8	418	5034	3	2004-01-09
9	418	8223	2	2004-01-09
1	419	2478	1	2004-01-06
2	419	8220	1	2004-01-06
3	419	1501	1	2004-01-06
4	419	421	1	2004-01-06
5	419	9941	1	2004-01-06
6	419	7338	3	2004-01-06
7	419	5605	3	2004-01-06
1	420	6666	3	2004-01-30
2	420	6017	3	2004-01-30
3	420	2878	1	2004-01-30
4	420	5994	1	2004-01-30
5	420	6749	3	2004-01-30
6	420	7096	3	2004-01-30
1	421	1885	2	2004-01-17
2	421	4676	1	2004-01-17
3	421	3748	2	2004-01-17
4	421	4762	1	2004-01-17
1	422	2383	2	2004-01-05
1	423	7071	2	2004-01-23
2	423	4386	1	2004-01-23
3	423	6305	1	2004-01-23
4	423	828	2	2004-01-23
1	424	9975	2	2004-01-31
2	424	5594	2	2004-01-31
1	425	426	1	2004-01-23
2	425	2291	1	2004-01-23
1	426	3721	3	2004-01-05
2	426	2258	1	2004-01-05
3	426	3680	2	2004-01-05
4	426	3856	3	2004-01-05
5	426	7779	2	2004-01-05
6	426	3385	3	2004-01-05
7	426	974	2	2004-01-05
8	426	9757	1	2004-01-05
9	426	1218	2	2004-01-05
1	427	308	2	2004-01-18
2	427	5469	1	2004-01-18
3	427	5737	3	2004-01-18
4	427	7271	1	2004-01-18
5	427	5995	1	2004-01-18
1	428	4895	2	2004-01-02
2	428	4023	1	2004-01-02
3	428	321	3	2004-01-02
4	428	406	1	2004-01-02
1	429	5513	3	2004-01-12
2	429	3365	1	2004-01-12
3	429	2706	2	2004-01-12
4	429	5321	3	2004-01-12
5	429	6270	1	2004-01-12
1	430	4532	1	2004-01-17
2	430	9493	2	2004-01-17
1	431	7061	1	2004-01-23
2	431	8770	3	2004-01-23
1	432	7519	1	2004-01-12
2	432	3652	1	2004-01-12
3	432	3347	2	2004-01-12
4	432	4555	3	2004-01-12
5	432	4532	1	2004-01-12
6	432	9724	3	2004-01-12
1	433	5968	1	2004-01-14
2	433	5210	1	2004-01-14
3	433	4900	3	2004-01-14
4	433	4670	1	2004-01-14
5	433	9434	2	2004-01-14
6	433	9427	1	2004-01-14
7	433	5976	3	2004-01-14
8	433	8811	2	2004-01-14
9	433	199	1	2004-01-14
1	434	2212	2	2004-01-14
2	434	9754	1	2004-01-14
3	434	3130	2	2004-01-14
4	434	4602	2	2004-01-14
5	434	3012	1	2004-01-14
6	434	4661	3	2004-01-14
7	434	3876	3	2004-01-14
8	434	5383	3	2004-01-14
9	434	1521	2	2004-01-14
1	435	8005	2	2004-01-07
2	435	1454	3	2004-01-07
3	435	9090	2	2004-01-07
4	435	1748	3	2004-01-07
5	435	4761	2	2004-01-07
6	435	1261	2	2004-01-07
7	435	5895	2	2004-01-07
8	435	8632	1	2004-01-07
1	436	9865	2	2004-01-27
2	436	2760	2	2004-01-27
3	436	3486	2	2004-01-27
1	437	3431	1	2004-01-01
2	437	4508	2	2004-01-01
3	437	1436	2	2004-01-01
4	437	715	1	2004-01-01
5	437	1508	2	2004-01-01
6	437	7142	1	2004-01-01
7	437	9990	1	2004-01-01
8	437	7157	3	2004-01-01
1	438	8894	1	2004-01-11
2	438	9535	1	2004-01-11
3	438	5377	1	2004-01-11
4	438	5934	2	2004-01-11
5	438	8491	1	2004-01-11
1	439	6805	2	2004-01-11
2	439	1426	3	2004-01-11
3	439	9013	1	2004-01-11
4	439	2994	2	2004-01-11
5	439	5700	1	2004-01-11
6	439	9191	1	2004-01-11
7	439	1605	1	2004-01-11
8	439	8551	1	2004-01-11
1	440	9098	3	2004-01-23
2	440	9872	2	2004-01-23
3	440	2816	3	2004-01-23
4	440	6194	2	2004-01-23
5	440	283	1	2004-01-23
6	440	3962	3	2004-01-23
7	440	6418	2	2004-01-23
1	441	1586	2	2004-01-15
2	441	583	1	2004-01-15
3	441	6875	1	2004-01-15
4	441	3498	2	2004-01-15
5	441	4058	1	2004-01-15
6	441	2870	2	2004-01-15
7	441	7667	1	2004-01-15
1	442	5900	1	2004-01-11
2	442	2383	2	2004-01-11
3	442	3779	2	2004-01-11
4	442	3269	1	2004-01-11
5	442	1732	3	2004-01-11
6	442	5627	1	2004-01-11
1	443	7988	1	2004-01-17
2	443	8244	1	2004-01-17
3	443	6368	1	2004-01-17
4	443	2299	3	2004-01-17
5	443	8359	3	2004-01-17
6	443	1204	1	2004-01-17
1	444	1392	1	2004-01-24
2	444	9585	2	2004-01-24
3	444	6766	1	2004-01-24
4	444	5366	3	2004-01-24
1	445	8204	1	2004-01-03
2	445	2258	2	2004-01-03
3	445	3559	1	2004-01-03
4	445	7676	3	2004-01-03
5	445	2804	3	2004-01-03
6	445	9163	1	2004-01-03
1	446	8567	1	2004-01-31
2	446	845	3	2004-01-31
3	446	1413	1	2004-01-31
4	446	5129	3	2004-01-31
5	446	3283	1	2004-01-31
6	446	6676	2	2004-01-31
7	446	1487	2	2004-01-31
1	447	5881	1	2004-01-01
2	447	2972	2	2004-01-01
3	447	1324	2	2004-01-01
1	448	852	3	2004-01-11
2	448	911	3	2004-01-11
3	448	880	1	2004-01-11
4	448	9377	1	2004-01-11
1	449	5000	3	2004-01-07
2	449	9479	2	2004-01-07
3	449	2369	3	2004-01-07
4	449	6177	1	2004-01-07
5	449	2160	1	2004-01-07
1	450	906	3	2004-01-05
2	450	3413	3	2004-01-05
3	450	2612	2	2004-01-05
1	451	5279	1	2004-01-24
2	451	901	3	2004-01-24
3	451	7564	1	2004-01-24
4	451	2932	1	2004-01-24
5	451	8517	1	2004-01-24
6	451	9049	1	2004-01-24
7	451	2100	2	2004-01-24
8	451	1093	2	2004-01-24
1	452	5624	1	2004-01-23
2	452	2038	3	2004-01-23
3	452	8138	2	2004-01-23
1	453	4477	2	2004-01-11
2	453	40	2	2004-01-11
3	453	913	3	2004-01-11
4	453	6749	2	2004-01-11
5	453	166	2	2004-01-11
6	453	6254	3	2004-01-11
7	453	6151	3	2004-01-11
1	454	9940	1	2004-01-14
2	454	4615	2	2004-01-14
1	455	1301	3	2004-01-08
1	456	2922	2	2004-01-20
1	457	7679	1	2004-01-20
2	457	8171	2	2004-01-20
3	457	1903	2	2004-01-20
1	458	8062	1	2004-01-08
2	458	6899	1	2004-01-08
3	458	7066	3	2004-01-08
4	458	9329	1	2004-01-08
5	458	9633	1	2004-01-08
1	459	6717	1	2004-01-30
2	459	9362	1	2004-01-30
3	459	6857	1	2004-01-30
4	459	5779	2	2004-01-30
1	460	8270	1	2004-01-15
2	460	2817	3	2004-01-15
3	460	5646	1	2004-01-15
4	460	1337	1	2004-01-15
5	460	3555	3	2004-01-15
6	460	1741	1	2004-01-15
1	461	7311	2	2004-01-01
2	461	4071	2	2004-01-01
3	461	6636	2	2004-01-01
4	461	6900	2	2004-01-01
5	461	5318	1	2004-01-01
6	461	8027	3	2004-01-01
7	461	6626	2	2004-01-01
8	461	6367	2	2004-01-01
9	461	7243	3	2004-01-01
1	462	5432	2	2004-01-15
2	462	4468	3	2004-01-15
3	462	6499	2	2004-01-15
4	462	8546	1	2004-01-15
5	462	4163	2	2004-01-15
6	462	3624	3	2004-01-15
1	463	3750	3	2004-01-31
2	463	9459	1	2004-01-31
3	463	6874	2	2004-01-31
4	463	8269	1	2004-01-31
5	463	979	2	2004-01-31
6	463	2424	2	2004-01-31
7	463	8399	1	2004-01-31
1	464	1003	1	2004-01-06
2	464	773	3	2004-01-06
3	464	2610	2	2004-01-06
4	464	5404	2	2004-01-06
5	464	3169	2	2004-01-06
6	464	6491	2	2004-01-06
1	465	2018	3	2004-01-07
2	465	7609	1	2004-01-07
1	466	4294	2	2004-01-06
2	466	6841	2	2004-01-06
3	466	8026	1	2004-01-06
4	466	2305	3	2004-01-06
1	467	8014	2	2004-01-18
2	467	4383	1	2004-01-18
3	467	9264	1	2004-01-18
4	467	6018	1	2004-01-18
5	467	1115	3	2004-01-18
6	467	2856	1	2004-01-18
7	467	6529	1	2004-01-18
8	467	3417	3	2004-01-18
1	468	3409	3	2004-01-29
2	468	9410	1	2004-01-29
3	468	2599	1	2004-01-29
4	468	462	3	2004-01-29
1	469	3015	1	2004-01-15
2	469	3988	1	2004-01-15
3	469	1545	1	2004-01-15
1	470	5790	2	2004-01-12
2	470	6928	3	2004-01-12
3	470	2831	2	2004-01-12
4	470	8421	2	2004-01-12
5	470	9323	1	2004-01-12
6	470	5306	3	2004-01-12
1	471	6043	2	2004-01-11
2	471	2761	1	2004-01-11
3	471	8046	2	2004-01-11
4	471	3002	1	2004-01-11
1	472	7205	3	2004-01-25
2	472	8127	1	2004-01-25
1	473	1033	1	2004-01-14
2	473	2728	1	2004-01-14
3	473	2450	3	2004-01-14
4	473	9087	2	2004-01-14
5	473	5936	3	2004-01-14
6	473	9438	1	2004-01-14
7	473	4774	1	2004-01-14
1	474	4852	2	2004-01-14
2	474	1856	3	2004-01-14
3	474	7689	3	2004-01-14
4	474	6770	2	2004-01-14
5	474	2055	1	2004-01-14
6	474	870	2	2004-01-14
7	474	8099	1	2004-01-14
1	475	8859	1	2004-01-16
2	475	3039	2	2004-01-16
3	475	877	1	2004-01-16
4	475	6773	2	2004-01-16
5	475	4673	1	2004-01-16
6	475	8468	1	2004-01-16
7	475	8391	1	2004-01-16
1	476	9307	3	2004-01-27
2	476	2175	1	2004-01-27
3	476	7999	1	2004-01-27
4	476	5617	2	2004-01-27
5	476	4947	1	2004-01-27
6	476	6924	3	2004-01-27
1	477	576	3	2004-01-25
1	478	8429	2	2004-01-11
2	478	649	3	2004-01-11
3	478	6859	3	2004-01-11
4	478	7066	3	2004-01-11
5	478	5680	2	2004-01-11
6	478	4049	3	2004-01-11
7	478	7734	1	2004-01-11
8	478	899	2	2004-01-11
1	479	3048	1	2004-01-26
2	479	850	1	2004-01-26
3	479	2514	1	2004-01-26
4	479	1015	2	2004-01-26
5	479	8774	2	2004-01-26
1	480	4022	2	2004-01-12
2	480	3817	1	2004-01-12
3	480	3553	3	2004-01-12
4	480	7459	3	2004-01-12
5	480	7351	2	2004-01-12
1	481	4095	1	2004-01-30
2	481	2861	3	2004-01-30
3	481	4040	2	2004-01-30
4	481	8736	2	2004-01-30
5	481	5136	3	2004-01-30
6	481	2397	2	2004-01-30
7	481	5837	2	2004-01-30
8	481	1112	2	2004-01-30
1	482	6219	2	2004-01-03
2	482	4055	2	2004-01-03
3	482	3100	1	2004-01-03
4	482	8869	1	2004-01-03
5	482	9656	3	2004-01-03
1	483	893	2	2004-01-02
2	483	7113	3	2004-01-02
3	483	382	1	2004-01-02
4	483	9379	1	2004-01-02
1	484	677	3	2004-01-20
2	484	2402	1	2004-01-20
3	484	4324	3	2004-01-20
4	484	8121	3	2004-01-20
5	484	2297	1	2004-01-20
6	484	9784	1	2004-01-20
7	484	3970	3	2004-01-20
1	485	7914	2	2004-01-27
2	485	2192	2	2004-01-27
3	485	3710	1	2004-01-27
4	485	7275	1	2004-01-27
5	485	5352	2	2004-01-27
6	485	8303	2	2004-01-27
7	485	702	3	2004-01-27
8	485	4141	1	2004-01-27
1	486	6843	2	2004-01-05
2	486	943	2	2004-01-05
3	486	5184	2	2004-01-05
4	486	6065	2	2004-01-05
5	486	9423	3	2004-01-05
6	486	2120	3	2004-01-05
7	486	3334	2	2004-01-05
8	486	2362	3	2004-01-05
9	486	6885	3	2004-01-05
1	487	6612	2	2004-01-01
2	487	7413	1	2004-01-01
3	487	6872	3	2004-01-01
4	487	9216	3	2004-01-01
5	487	8737	2	2004-01-01
6	487	2612	3	2004-01-01
7	487	2684	3	2004-01-01
8	487	4591	3	2004-01-01
1	488	1349	1	2004-01-05
2	488	7982	2	2004-01-05
3	488	8377	2	2004-01-05
4	488	3346	3	2004-01-05
1	489	184	2	2004-01-23
2	489	4465	3	2004-01-23
3	489	3366	2	2004-01-23
4	489	5649	1	2004-01-23
1	490	6056	2	2004-01-31
2	490	1171	3	2004-01-31
3	490	384	3	2004-01-31
1	491	5442	3	2004-01-04
2	491	4124	3	2004-01-04
3	491	7388	1	2004-01-04
4	491	5202	2	2004-01-04
5	491	4939	2	2004-01-04
6	491	8680	3	2004-01-04
7	491	2441	1	2004-01-04
8	491	3085	3	2004-01-04
9	491	4148	1	2004-01-04
1	492	2300	2	2004-01-20
2	492	14	1	2004-01-20
3	492	5587	1	2004-01-20
1	493	4972	2	2004-01-14
2	493	8645	1	2004-01-14
3	493	5900	2	2004-01-14
4	493	6687	1	2004-01-14
5	493	9232	2	2004-01-14
6	493	242	1	2004-01-14
7	493	7411	1	2004-01-14
8	493	9763	1	2004-01-14
9	493	6149	2	2004-01-14
1	494	7810	3	2004-01-24
2	494	2468	2	2004-01-24
3	494	9826	3	2004-01-24
4	494	9488	1	2004-01-24
5	494	6740	2	2004-01-24
6	494	5050	2	2004-01-24
7	494	6819	1	2004-01-24
8	494	9231	2	2004-01-24
9	494	1787	3	2004-01-24
1	495	5353	3	2004-01-28
2	495	7841	1	2004-01-28
3	495	6012	2	2004-01-28
4	495	2895	2	2004-01-28
5	495	5112	1	2004-01-28
6	495	3067	3	2004-01-28
1	496	3268	1	2004-01-13
2	496	8048	3	2004-01-13
3	496	6587	2	2004-01-13
4	496	9267	2	2004-01-13
1	497	3082	2	2004-01-26
2	497	3524	3	2004-01-26
3	497	4313	1	2004-01-26
4	497	9936	1	2004-01-26
5	497	6691	1	2004-01-26
6	497	4856	1	2004-01-26
7	497	3534	3	2004-01-26
1	498	1222	2	2004-01-30
2	498	5045	3	2004-01-30
3	498	2399	1	2004-01-30
4	498	4135	1	2004-01-30
1	499	9748	2	2004-01-24
2	499	6141	1	2004-01-24
1	500	777	1	2004-01-14
2	500	6999	2	2004-01-14
3	500	3127	1	2004-01-14
4	500	3554	1	2004-01-14
1	501	8449	1	2004-01-26
2	501	8656	1	2004-01-26
3	501	3025	1	2004-01-26
4	501	2513	1	2004-01-26
5	501	5295	2	2004-01-26
6	501	2199	2	2004-01-26
7	501	1031	3	2004-01-26
8	501	8314	2	2004-01-26
9	501	8792	1	2004-01-26
1	502	5200	3	2004-01-30
2	502	6963	3	2004-01-30
3	502	9908	2	2004-01-30
4	502	3121	2	2004-01-30
5	502	4516	1	2004-01-30
6	502	7651	1	2004-01-30
1	503	1147	1	2004-01-08
2	503	160	2	2004-01-08
3	503	6298	1	2004-01-08
4	503	1684	2	2004-01-08
5	503	6454	1	2004-01-08
1	504	2318	2	2004-01-24
2	504	9234	3	2004-01-24
1	505	5397	3	2004-01-13
2	505	8686	1	2004-01-13
3	505	2096	1	2004-01-13
4	505	3723	3	2004-01-13
5	505	6030	2	2004-01-13
6	505	9312	2	2004-01-13
7	505	8214	2	2004-01-13
1	506	373	3	2004-01-23
2	506	9718	1	2004-01-23
3	506	9612	1	2004-01-23
4	506	5658	3	2004-01-23
1	507	6770	2	2004-01-05
2	507	4651	2	2004-01-05
3	507	6430	3	2004-01-05
4	507	6556	1	2004-01-05
5	507	4803	1	2004-01-05
6	507	5022	2	2004-01-05
1	508	3132	3	2004-01-28
2	508	9982	2	2004-01-28
3	508	7721	3	2004-01-28
4	508	3919	3	2004-01-28
5	508	1736	3	2004-01-28
6	508	6179	1	2004-01-28
1	509	7547	2	2004-01-29
2	509	1455	2	2004-01-29
3	509	176	3	2004-01-29
4	509	4129	2	2004-01-29
5	509	596	3	2004-01-29
6	509	9093	3	2004-01-29
1	510	8757	2	2004-01-08
2	510	9020	2	2004-01-08
3	510	5201	1	2004-01-08
4	510	3811	3	2004-01-08
5	510	2515	3	2004-01-08
1	511	7745	1	2004-01-31
2	511	2198	3	2004-01-31
3	511	5675	1	2004-01-31
4	511	7210	3	2004-01-31
5	511	7352	3	2004-01-31
6	511	8953	2	2004-01-31
7	511	7174	1	2004-01-31
8	511	5259	1	2004-01-31
1	512	493	2	2004-01-22
2	512	8811	2	2004-01-22
3	512	331	1	2004-01-22
4	512	4292	1	2004-01-22
5	512	3071	3	2004-01-22
6	512	9088	1	2004-01-22
1	513	3658	3	2004-01-01
2	513	5620	1	2004-01-01
3	513	5030	2	2004-01-01
4	513	7453	1	2004-01-01
5	513	5909	1	2004-01-01
6	513	4896	1	2004-01-01
1	514	6483	3	2004-01-21
2	514	1523	3	2004-01-21
3	514	8770	2	2004-01-21
4	514	7133	1	2004-01-21
5	514	4257	2	2004-01-21
6	514	2656	2	2004-01-21
7	514	7504	1	2004-01-21
1	515	2171	2	2004-01-01
2	515	405	3	2004-01-01
3	515	7128	2	2004-01-01
4	515	2335	1	2004-01-01
5	515	9075	3	2004-01-01
6	515	5111	3	2004-01-01
1	516	8406	2	2004-01-20
2	516	3616	2	2004-01-20
3	516	5763	3	2004-01-20
4	516	1757	3	2004-01-20
5	516	2271	3	2004-01-20
6	516	1089	1	2004-01-20
7	516	422	1	2004-01-20
8	516	8318	1	2004-01-20
1	517	5036	2	2004-01-19
2	517	5057	2	2004-01-19
3	517	3611	1	2004-01-19
1	518	7694	1	2004-01-06
2	518	891	1	2004-01-06
3	518	5705	2	2004-01-06
4	518	9182	3	2004-01-06
5	518	5070	1	2004-01-06
6	518	6722	2	2004-01-06
7	518	3938	3	2004-01-06
1	519	978	1	2004-01-23
2	519	6084	2	2004-01-23
3	519	6501	1	2004-01-23
1	520	3	1	2004-01-01
2	520	8910	3	2004-01-01
1	521	6452	3	2004-01-11
2	521	6401	1	2004-01-11
3	521	9640	1	2004-01-11
4	521	7680	2	2004-01-11
5	521	266	2	2004-01-11
6	521	5833	1	2004-01-11
7	521	7870	3	2004-01-11
8	521	1952	2	2004-01-11
9	521	2825	3	2004-01-11
1	522	4889	3	2004-01-16
2	522	9470	2	2004-01-16
3	522	6261	1	2004-01-16
4	522	3598	2	2004-01-16
5	522	1644	1	2004-01-16
6	522	3454	3	2004-01-16
1	523	6671	1	2004-01-05
2	523	4072	1	2004-01-05
3	523	1433	1	2004-01-05
4	523	9314	2	2004-01-05
5	523	5894	1	2004-01-05
6	523	1836	1	2004-01-05
7	523	5086	1	2004-01-05
8	523	7389	3	2004-01-05
9	523	8963	3	2004-01-05
1	524	490	1	2004-01-12
2	524	7418	2	2004-01-12
3	524	9251	3	2004-01-12
4	524	7037	1	2004-01-12
5	524	8239	2	2004-01-12
6	524	1849	1	2004-01-12
7	524	6211	1	2004-01-12
1	525	7662	3	2004-01-14
1	526	2721	3	2004-01-04
2	526	5379	2	2004-01-04
3	526	3084	2	2004-01-04
4	526	3862	2	2004-01-04
5	526	6148	1	2004-01-04
6	526	7517	2	2004-01-04
7	526	268	2	2004-01-04
8	526	5816	3	2004-01-04
1	527	945	2	2004-01-26
2	527	9995	3	2004-01-26
3	527	5212	3	2004-01-26
4	527	6108	2	2004-01-26
5	527	403	2	2004-01-26
1	528	9616	2	2004-01-16
1	529	4756	3	2004-01-17
2	529	6730	2	2004-01-17
1	530	209	2	2004-01-05
2	530	4321	1	2004-01-05
3	530	9412	2	2004-01-05
4	530	8761	2	2004-01-05
5	530	1971	2	2004-01-05
6	530	967	1	2004-01-05
7	530	9872	2	2004-01-05
8	530	5497	1	2004-01-05
9	530	6072	2	2004-01-05
1	531	2586	2	2004-01-27
2	531	5240	3	2004-01-27
3	531	8367	3	2004-01-27
4	531	1861	1	2004-01-27
5	531	6680	1	2004-01-27
6	531	6241	1	2004-01-27
7	531	3222	2	2004-01-27
8	531	5316	1	2004-01-27
1	532	9661	3	2004-01-01
2	532	7071	2	2004-01-01
1	533	4397	3	2004-01-30
2	533	6345	3	2004-01-30
3	533	2199	1	2004-01-30
4	533	6297	1	2004-01-30
5	533	8414	3	2004-01-30
6	533	2462	2	2004-01-30
7	533	226	3	2004-01-30
8	533	6095	2	2004-01-30
1	534	8697	1	2004-01-14
2	534	5871	3	2004-01-14
3	534	9003	1	2004-01-14
4	534	3514	3	2004-01-14
5	534	6083	2	2004-01-14
1	535	7461	2	2004-01-21
2	535	4530	2	2004-01-21
3	535	5402	1	2004-01-21
1	536	6564	2	2004-01-06
2	536	5588	1	2004-01-06
1	537	3297	1	2004-01-18
2	537	2595	1	2004-01-18
3	537	4359	2	2004-01-18
4	537	760	1	2004-01-18
1	538	306	3	2004-01-31
2	538	7362	2	2004-01-31
3	538	2139	1	2004-01-31
1	539	6192	3	2004-01-25
2	539	9945	1	2004-01-25
3	539	8107	2	2004-01-25
4	539	2796	2	2004-01-25
5	539	9724	2	2004-01-25
6	539	5071	1	2004-01-25
1	540	9870	3	2004-01-27
2	540	6512	1	2004-01-27
3	540	842	3	2004-01-27
4	540	9171	3	2004-01-27
5	540	1651	1	2004-01-27
6	540	967	3	2004-01-27
7	540	5361	1	2004-01-27
8	540	5243	1	2004-01-27
9	540	8780	2	2004-01-27
1	541	541	1	2004-01-11
2	541	2221	2	2004-01-11
3	541	2715	1	2004-01-11
4	541	5041	1	2004-01-11
5	541	9764	2	2004-01-11
6	541	9457	2	2004-01-11
1	542	8501	2	2004-01-18
2	542	6179	3	2004-01-18
3	542	4170	1	2004-01-18
4	542	1058	3	2004-01-18
5	542	3092	3	2004-01-18
1	543	2551	3	2004-01-15
2	543	5670	2	2004-01-15
3	543	2876	3	2004-01-15
4	543	5384	3	2004-01-15
5	543	9525	2	2004-01-15
1	544	9279	2	2004-01-09
2	544	3396	3	2004-01-09
3	544	9254	3	2004-01-09
4	544	7246	2	2004-01-09
5	544	1114	3	2004-01-09
6	544	2835	2	2004-01-09
7	544	8141	3	2004-01-09
8	544	629	2	2004-01-09
1	545	7951	2	2004-01-09
2	545	6761	2	2004-01-09
3	545	2922	2	2004-01-09
4	545	8482	2	2004-01-09
5	545	5266	3	2004-01-09
6	545	4274	2	2004-01-09
7	545	4415	3	2004-01-09
8	545	2323	2	2004-01-09
1	546	7872	3	2004-01-23
2	546	2562	2	2004-01-23
3	546	7360	1	2004-01-23
4	546	879	1	2004-01-23
5	546	6369	1	2004-01-23
6	546	8443	2	2004-01-23
7	546	8014	2	2004-01-23
8	546	7653	1	2004-01-23
1	547	6037	1	2004-01-05
2	547	1297	1	2004-01-05
3	547	8626	2	2004-01-05
4	547	4118	2	2004-01-05
5	547	3189	1	2004-01-05
6	547	4226	1	2004-01-05
7	547	1133	3	2004-01-05
1	548	8558	2	2004-01-22
2	548	960	3	2004-01-22
3	548	665	3	2004-01-22
4	548	2202	3	2004-01-22
5	548	9909	2	2004-01-22
6	548	4452	2	2004-01-22
7	548	442	1	2004-01-22
8	548	7548	1	2004-01-22
1	549	2042	3	2004-01-03
2	549	6264	2	2004-01-03
3	549	9608	3	2004-01-03
4	549	3054	3	2004-01-03
5	549	5888	1	2004-01-03
1	550	1445	1	2004-01-15
2	550	4565	2	2004-01-15
3	550	8358	2	2004-01-15
4	550	7335	1	2004-01-15
5	550	1064	3	2004-01-15
6	550	3296	3	2004-01-15
1	551	9289	3	2004-01-30
2	551	3421	2	2004-01-30
3	551	3093	1	2004-01-30
4	551	2948	2	2004-01-30
5	551	9709	3	2004-01-30
1	552	9932	2	2004-01-29
2	552	8593	2	2004-01-29
3	552	8370	3	2004-01-29
4	552	8969	2	2004-01-29
5	552	9758	1	2004-01-29
6	552	3481	1	2004-01-29
7	552	8643	1	2004-01-29
8	552	7287	2	2004-01-29
1	553	2128	2	2004-01-25
2	553	4317	2	2004-01-25
1	554	8366	3	2004-01-30
2	554	7220	3	2004-01-30
3	554	1913	2	2004-01-30
4	554	2794	1	2004-01-30
5	554	2761	1	2004-01-30
6	554	5985	1	2004-01-30
7	554	1794	3	2004-01-30
8	554	5572	1	2004-01-30
1	555	9434	2	2004-01-08
1	556	6636	3	2004-01-06
2	556	9960	1	2004-01-06
3	556	5616	3	2004-01-06
4	556	7735	1	2004-01-06
5	556	6624	3	2004-01-06
6	556	8647	3	2004-01-06
1	557	3926	1	2004-01-31
2	557	5378	3	2004-01-31
3	557	3409	3	2004-01-31
4	557	2356	3	2004-01-31
5	557	8167	1	2004-01-31
6	557	1386	3	2004-01-31
1	558	5794	2	2004-01-11
2	558	531	1	2004-01-11
3	558	4003	3	2004-01-11
4	558	4245	1	2004-01-11
5	558	7911	1	2004-01-11
6	558	43	3	2004-01-11
7	558	4299	1	2004-01-11
8	558	3752	3	2004-01-11
9	558	4193	3	2004-01-11
1	559	4872	2	2004-01-24
1	560	5102	1	2004-01-06
2	560	5200	1	2004-01-06
3	560	6311	2	2004-01-06
4	560	2304	1	2004-01-06
5	560	3995	2	2004-01-06
1	561	9745	2	2004-01-03
1	562	2625	3	2004-01-07
2	562	3994	3	2004-01-07
3	562	9759	3	2004-01-07
4	562	4724	1	2004-01-07
5	562	5122	3	2004-01-07
6	562	6839	1	2004-01-07
1	563	7768	2	2004-01-01
2	563	6896	1	2004-01-01
3	563	9969	3	2004-01-01
4	563	3668	3	2004-01-01
5	563	8815	2	2004-01-01
6	563	3145	1	2004-01-01
1	564	4788	1	2004-01-22
2	564	9123	2	2004-01-22
3	564	265	2	2004-01-22
4	564	6171	2	2004-01-22
5	564	3486	1	2004-01-22
6	564	5609	2	2004-01-22
7	564	5046	3	2004-01-22
8	564	342	1	2004-01-22
9	564	147	3	2004-01-22
1	565	9523	2	2004-01-15
2	565	1654	1	2004-01-15
3	565	4901	3	2004-01-15
4	565	7773	1	2004-01-15
5	565	8092	1	2004-01-15
6	565	3709	3	2004-01-15
7	565	7108	2	2004-01-15
8	565	1060	1	2004-01-15
1	566	8303	1	2004-01-30
2	566	1694	3	2004-01-30
3	566	4145	1	2004-01-30
4	566	5882	3	2004-01-30
5	566	1956	1	2004-01-30
1	567	4145	3	2004-01-22
2	567	7176	1	2004-01-22
3	567	2047	2	2004-01-22
4	567	4479	2	2004-01-22
5	567	2480	1	2004-01-22
6	567	9729	2	2004-01-22
7	567	4863	3	2004-01-22
8	567	8084	1	2004-01-22
1	568	5031	2	2004-01-13
2	568	7590	1	2004-01-13
3	568	5343	3	2004-01-13
4	568	1865	1	2004-01-13
5	568	1023	3	2004-01-13
6	568	920	2	2004-01-13
1	569	3361	1	2004-01-20
2	569	4244	2	2004-01-20
3	569	3148	2	2004-01-20
4	569	9380	3	2004-01-20
5	569	3059	3	2004-01-20
6	569	9158	3	2004-01-20
7	569	3850	1	2004-01-20
8	569	2864	3	2004-01-20
1	570	9997	1	2004-01-26
2	570	5908	1	2004-01-26
3	570	8359	3	2004-01-26
4	570	6187	2	2004-01-26
1	571	4834	3	2004-01-16
2	571	4123	3	2004-01-16
3	571	1504	2	2004-01-16
4	571	5992	2	2004-01-16
5	571	966	2	2004-01-16
6	571	1677	2	2004-01-16
7	571	6787	2	2004-01-16
8	571	3695	2	2004-01-16
1	572	5142	2	2004-01-16
2	572	6009	2	2004-01-16
3	572	1386	1	2004-01-16
4	572	8302	2	2004-01-16
5	572	5467	1	2004-01-16
1	573	8282	1	2004-01-15
2	573	2215	2	2004-01-15
3	573	5190	1	2004-01-15
4	573	9423	3	2004-01-15
5	573	7996	2	2004-01-15
6	573	1406	1	2004-01-15
7	573	1257	2	2004-01-15
8	573	5177	3	2004-01-15
1	574	3820	2	2004-01-05
2	574	9591	1	2004-01-05
3	574	2159	2	2004-01-05
4	574	3712	3	2004-01-05
5	574	5357	1	2004-01-05
6	574	5460	2	2004-01-05
7	574	3462	3	2004-01-05
1	575	5517	3	2004-01-25
2	575	3543	3	2004-01-25
3	575	542	2	2004-01-25
4	575	3321	2	2004-01-25
5	575	4708	2	2004-01-25
6	575	6037	3	2004-01-25
7	575	2104	3	2004-01-25
1	576	6751	2	2004-01-16
2	576	3932	1	2004-01-16
3	576	8522	3	2004-01-16
4	576	5745	1	2004-01-16
5	576	7066	2	2004-01-16
6	576	634	3	2004-01-16
7	576	989	2	2004-01-16
1	577	9332	2	2004-01-21
2	577	3030	2	2004-01-21
3	577	1101	3	2004-01-21
4	577	3212	1	2004-01-21
5	577	8921	3	2004-01-21
6	577	4897	1	2004-01-21
7	577	5421	1	2004-01-21
1	578	8743	3	2004-01-21
2	578	7090	2	2004-01-21
3	578	3154	3	2004-01-21
4	578	3728	2	2004-01-21
5	578	3874	1	2004-01-21
1	579	3339	1	2004-01-27
2	579	2044	2	2004-01-27
3	579	9905	2	2004-01-27
4	579	7642	3	2004-01-27
5	579	3493	1	2004-01-27
6	579	9722	3	2004-01-27
7	579	4186	2	2004-01-27
8	579	8265	3	2004-01-27
1	580	2814	1	2004-01-05
2	580	6225	2	2004-01-05
3	580	4733	1	2004-01-05
4	580	7040	2	2004-01-05
5	580	7044	2	2004-01-05
6	580	1412	1	2004-01-05
7	580	5689	2	2004-01-05
8	580	4821	2	2004-01-05
1	581	5001	2	2004-01-28
2	581	1118	3	2004-01-28
1	582	6388	2	2004-01-02
2	582	360	3	2004-01-02
1	583	6682	1	2004-01-16
2	583	3291	2	2004-01-16
3	583	7631	2	2004-01-16
4	583	4108	1	2004-01-16
5	583	8159	3	2004-01-16
6	583	8912	3	2004-01-16
7	583	1391	1	2004-01-16
8	583	9075	2	2004-01-16
9	583	7469	1	2004-01-16
1	584	9773	2	2004-01-18
2	584	7264	1	2004-01-18
3	584	5162	1	2004-01-18
1	585	3685	2	2004-01-21
2	585	7124	1	2004-01-21
3	585	293	1	2004-01-21
4	585	4634	3	2004-01-21
1	586	6874	2	2004-01-01
2	586	7942	2	2004-01-01
1	587	6220	1	2004-01-15
2	587	121	2	2004-01-15
3	587	2162	2	2004-01-15
4	587	5898	3	2004-01-15
1	588	3787	3	2004-01-20
2	588	1184	2	2004-01-20
3	588	629	2	2004-01-20
4	588	2531	1	2004-01-20
5	588	9362	3	2004-01-20
6	588	2338	2	2004-01-20
7	588	2249	1	2004-01-20
8	588	579	3	2004-01-20
9	588	3797	1	2004-01-20
1	589	3499	3	2004-01-04
2	589	6399	3	2004-01-04
1	590	2453	1	2004-01-19
2	590	7576	2	2004-01-19
3	590	5459	3	2004-01-19
4	590	9455	3	2004-01-19
5	590	8992	3	2004-01-19
6	590	5841	1	2004-01-19
7	590	5052	3	2004-01-19
8	590	1607	2	2004-01-19
1	591	5420	1	2004-01-16
2	591	7039	3	2004-01-16
3	591	359	2	2004-01-16
4	591	8313	2	2004-01-16
5	591	6021	2	2004-01-16
6	591	4441	3	2004-01-16
1	592	221	1	2004-01-23
2	592	731	3	2004-01-23
3	592	381	2	2004-01-23
1	593	1063	3	2004-01-02
2	593	7550	3	2004-01-02
1	594	1886	1	2004-01-18
2	594	5984	1	2004-01-18
3	594	9483	1	2004-01-18
1	595	5941	1	2004-01-19
2	595	6130	2	2004-01-19
3	595	4152	3	2004-01-19
4	595	5372	2	2004-01-19
1	596	8058	1	2004-01-11
2	596	7680	2	2004-01-11
3	596	557	1	2004-01-11
4	596	8576	2	2004-01-11
5	596	5734	1	2004-01-11
6	596	6638	1	2004-01-11
7	596	661	2	2004-01-11
8	596	3721	3	2004-01-11
1	597	6786	2	2004-01-01
2	597	2146	1	2004-01-01
3	597	3143	3	2004-01-01
4	597	5470	2	2004-01-01
5	597	3430	2	2004-01-01
6	597	4668	1	2004-01-01
1	598	5535	2	2004-01-21
2	598	436	1	2004-01-21
3	598	6132	3	2004-01-21
4	598	2984	3	2004-01-21
5	598	3194	3	2004-01-21
6	598	3557	1	2004-01-21
7	598	902	2	2004-01-21
1	599	8624	1	2004-01-29
2	599	8888	2	2004-01-29
1	600	3804	2	2004-01-31
2	600	6723	1	2004-01-31
3	600	3005	1	2004-01-31
4	600	6567	2	2004-01-31
1	601	9490	2	2004-01-11
2	601	3212	1	2004-01-11
3	601	6946	2	2004-01-11
4	601	6755	2	2004-01-11
5	601	1799	3	2004-01-11
6	601	7539	1	2004-01-11
1	602	8743	2	2004-01-31
2	602	3962	1	2004-01-31
3	602	28	1	2004-01-31
4	602	3444	1	2004-01-31
5	602	2942	1	2004-01-31
6	602	6473	2	2004-01-31
7	602	2708	3	2004-01-31
8	602	2974	1	2004-01-31
9	602	692	2	2004-01-31
1	603	3807	1	2004-01-17
2	603	8742	1	2004-01-17
1	604	8206	2	2004-01-08
2	604	1073	1	2004-01-08
3	604	9061	1	2004-01-08
4	604	2852	1	2004-01-08
5	604	4133	2	2004-01-08
6	604	2514	1	2004-01-08
7	604	2260	2	2004-01-08
1	605	1419	1	2004-01-24
2	605	5919	1	2004-01-24
3	605	4656	3	2004-01-24
4	605	3812	2	2004-01-24
5	605	1070	2	2004-01-24
6	605	2016	3	2004-01-24
7	605	3362	1	2004-01-24
8	605	5356	2	2004-01-24
1	606	6920	3	2004-01-08
2	606	1034	3	2004-01-08
3	606	271	1	2004-01-08
4	606	4654	3	2004-01-08
5	606	8527	1	2004-01-08
1	607	1661	3	2004-01-20
2	607	1785	2	2004-01-20
1	608	1696	2	2004-01-09
2	608	5019	3	2004-01-09
3	608	9598	3	2004-01-09
4	608	1468	2	2004-01-09
5	608	2647	3	2004-01-09
1	609	6974	1	2004-01-15
2	609	2929	2	2004-01-15
3	609	4544	3	2004-01-15
4	609	5445	3	2004-01-15
5	609	1130	3	2004-01-15
1	610	5768	2	2004-01-27
2	610	6236	3	2004-01-27
1	611	8660	2	2004-01-30
2	611	4273	1	2004-01-30
3	611	4368	3	2004-01-30
4	611	4987	1	2004-01-30
5	611	4139	1	2004-01-30
6	611	4661	3	2004-01-30
7	611	7460	3	2004-01-30
8	611	6136	1	2004-01-30
9	611	8477	3	2004-01-30
1	612	8572	2	2004-01-01
2	612	6966	2	2004-01-01
3	612	3410	2	2004-01-01
1	613	3904	3	2004-01-19
2	613	6026	3	2004-01-19
3	613	8992	1	2004-01-19
4	613	459	1	2004-01-19
5	613	2972	2	2004-01-19
1	614	3335	1	2004-01-01
2	614	3598	2	2004-01-01
3	614	9933	2	2004-01-01
4	614	5929	3	2004-01-01
5	614	9724	1	2004-01-01
6	614	3311	1	2004-01-01
1	615	4090	2	2004-01-30
2	615	4975	1	2004-01-30
3	615	3232	2	2004-01-30
4	615	1128	2	2004-01-30
5	615	7097	2	2004-01-30
1	616	3626	3	2004-01-28
2	616	5932	3	2004-01-28
3	616	1208	2	2004-01-28
1	617	31	3	2004-01-04
1	618	4487	1	2004-01-12
2	618	9870	3	2004-01-12
3	618	1255	1	2004-01-12
4	618	3428	1	2004-01-12
5	618	6791	1	2004-01-12
1	619	8733	1	2004-01-21
1	620	529	3	2004-01-28
1	621	2577	2	2004-01-23
2	621	6685	3	2004-01-23
3	621	9151	1	2004-01-23
4	621	765	3	2004-01-23
5	621	631	1	2004-01-23
6	621	2122	2	2004-01-23
7	621	4402	3	2004-01-23
1	622	1894	1	2004-01-15
2	622	3840	1	2004-01-15
3	622	7909	1	2004-01-15
1	623	3336	1	2004-01-03
2	623	5323	2	2004-01-03
3	623	6791	1	2004-01-03
4	623	5538	2	2004-01-03
5	623	3177	2	2004-01-03
6	623	4961	2	2004-01-03
7	623	8323	3	2004-01-03
8	623	7866	1	2004-01-03
1	624	4845	2	2004-01-19
1	625	1187	3	2004-01-12
2	625	98	2	2004-01-12
1	626	9345	1	2004-01-17
1	627	1186	2	2004-01-08
2	627	9508	3	2004-01-08
3	627	680	3	2004-01-08
4	627	2232	3	2004-01-08
5	627	9820	2	2004-01-08
6	627	7179	2	2004-01-08
1	628	2589	2	2004-01-05
2	628	4731	1	2004-01-05
3	628	7889	3	2004-01-05
4	628	6119	2	2004-01-05
5	628	443	2	2004-01-05
6	628	6488	1	2004-01-05
7	628	347	2	2004-01-05
1	629	1040	3	2004-01-27
2	629	5547	1	2004-01-27
3	629	6074	2	2004-01-27
4	629	9109	1	2004-01-27
5	629	32	1	2004-01-27
6	629	4182	2	2004-01-27
7	629	8056	3	2004-01-27
8	629	7915	1	2004-01-27
1	630	9597	1	2004-01-30
2	630	1039	2	2004-01-30
3	630	6119	1	2004-01-30
4	630	1208	2	2004-01-30
5	630	2917	3	2004-01-30
6	630	2959	2	2004-01-30
1	631	3873	2	2004-01-29
2	631	8655	2	2004-01-29
3	631	6782	1	2004-01-29
4	631	7284	2	2004-01-29
5	631	9606	2	2004-01-29
1	632	4637	1	2004-01-24
1	633	7060	3	2004-01-11
2	633	4391	3	2004-01-11
3	633	7819	3	2004-01-11
4	633	3932	3	2004-01-11
5	633	5856	1	2004-01-11
6	633	2550	3	2004-01-11
7	633	7493	1	2004-01-11
8	633	3633	2	2004-01-11
9	633	4040	1	2004-01-11
1	634	2707	3	2004-01-29
2	634	7068	3	2004-01-29
3	634	7716	1	2004-01-29
4	634	3020	2	2004-01-29
5	634	160	1	2004-01-29
6	634	2288	2	2004-01-29
7	634	55	1	2004-01-29
1	635	5144	3	2004-01-06
2	635	7485	1	2004-01-06
3	635	1008	1	2004-01-06
4	635	6911	2	2004-01-06
5	635	2034	2	2004-01-06
6	635	8692	3	2004-01-06
7	635	2756	1	2004-01-06
1	636	378	1	2004-01-17
2	636	7379	1	2004-01-17
3	636	1840	3	2004-01-17
1	637	5881	3	2004-01-16
2	637	4745	1	2004-01-16
3	637	6831	1	2004-01-16
4	637	3661	3	2004-01-16
5	637	3345	1	2004-01-16
6	637	2885	2	2004-01-16
7	637	6593	1	2004-01-16
1	638	9173	1	2004-01-11
2	638	1774	3	2004-01-11
3	638	3477	3	2004-01-11
4	638	88	2	2004-01-11
5	638	8819	2	2004-01-11
6	638	7211	3	2004-01-11
7	638	2165	1	2004-01-11
8	638	5619	3	2004-01-11
1	639	287	1	2004-01-13
2	639	8346	1	2004-01-13
3	639	7861	2	2004-01-13
4	639	4746	1	2004-01-13
5	639	4287	3	2004-01-13
6	639	180	2	2004-01-13
7	639	9435	1	2004-01-13
1	640	8227	3	2004-01-10
2	640	8273	2	2004-01-10
3	640	8516	1	2004-01-10
1	641	6582	2	2004-01-27
2	641	419	3	2004-01-27
3	641	8967	3	2004-01-27
1	642	8215	3	2004-01-01
2	642	2504	3	2004-01-01
3	642	1449	1	2004-01-01
4	642	346	2	2004-01-01
5	642	4850	1	2004-01-01
1	643	8515	3	2004-01-24
2	643	6264	3	2004-01-24
3	643	4023	2	2004-01-24
4	643	9686	1	2004-01-24
5	643	95	1	2004-01-24
6	643	7473	3	2004-01-24
1	644	2295	2	2004-01-28
2	644	562	2	2004-01-28
3	644	2497	1	2004-01-28
1	645	4293	2	2004-01-21
2	645	4664	2	2004-01-21
1	646	221	3	2004-01-31
2	646	9718	3	2004-01-31
3	646	185	3	2004-01-31
4	646	11	3	2004-01-31
5	646	8873	3	2004-01-31
6	646	5168	2	2004-01-31
1	647	2261	1	2004-01-05
2	647	4022	3	2004-01-05
1	648	4507	2	2004-01-14
2	648	4162	2	2004-01-14
3	648	8426	3	2004-01-14
4	648	460	3	2004-01-14
5	648	9300	1	2004-01-14
6	648	8552	3	2004-01-14
7	648	9989	3	2004-01-14
8	648	7141	3	2004-01-14
1	649	9770	1	2004-01-24
2	649	906	1	2004-01-24
3	649	3845	2	2004-01-24
4	649	1027	3	2004-01-24
5	649	5416	1	2004-01-24
6	649	6541	3	2004-01-24
7	649	6859	1	2004-01-24
8	649	4274	2	2004-01-24
9	649	422	2	2004-01-24
1	650	9205	2	2004-01-13
2	650	1045	2	2004-01-13
3	650	3760	3	2004-01-13
1	651	9867	3	2004-01-27
2	651	452	2	2004-01-27
3	651	3212	1	2004-01-27
4	651	1757	3	2004-01-27
5	651	3090	3	2004-01-27
6	651	8550	3	2004-01-27
7	651	9000	1	2004-01-27
8	651	5233	3	2004-01-27
1	652	1646	3	2004-01-24
2	652	7365	1	2004-01-24
3	652	4691	1	2004-01-24
1	653	1765	3	2004-01-04
2	653	6840	1	2004-01-04
3	653	2082	1	2004-01-04
4	653	3694	2	2004-01-04
5	653	8679	3	2004-01-04
6	653	2135	3	2004-01-04
7	653	6732	1	2004-01-04
8	653	51	1	2004-01-04
1	654	72	1	2004-01-02
2	654	8043	3	2004-01-02
3	654	5463	1	2004-01-02
4	654	8560	2	2004-01-02
5	654	6076	3	2004-01-02
6	654	5194	3	2004-01-02
7	654	5435	1	2004-01-02
8	654	55	3	2004-01-02
9	654	2084	2	2004-01-02
1	655	7989	3	2004-01-05
2	655	4623	3	2004-01-05
3	655	9228	2	2004-01-05
4	655	5645	1	2004-01-05
1	656	3153	3	2004-01-16
2	656	5652	1	2004-01-16
3	656	5229	1	2004-01-16
1	657	2454	3	2004-01-28
2	657	1725	2	2004-01-28
3	657	3370	1	2004-01-28
4	657	5299	2	2004-01-28
1	658	1327	1	2004-01-21
2	658	6367	3	2004-01-21
1	659	4160	2	2004-01-03
2	659	2464	3	2004-01-03
3	659	7552	3	2004-01-03
4	659	1538	2	2004-01-03
1	660	724	1	2004-01-26
1	661	7996	1	2004-01-16
1	662	9552	3	2004-01-12
2	662	1988	1	2004-01-12
3	662	701	2	2004-01-12
4	662	4172	2	2004-01-12
5	662	517	2	2004-01-12
1	663	4395	1	2004-01-15
2	663	7311	2	2004-01-15
3	663	3005	3	2004-01-15
4	663	7191	3	2004-01-15
5	663	2128	1	2004-01-15
6	663	8510	1	2004-01-15
1	664	7217	3	2004-01-14
2	664	6985	3	2004-01-14
3	664	9132	3	2004-01-14
4	664	3881	1	2004-01-14
5	664	2544	2	2004-01-14
6	664	9938	3	2004-01-14
7	664	2464	2	2004-01-14
1	665	1789	3	2004-01-11
1	666	1508	2	2004-01-28
1	667	3467	2	2004-01-04
1	668	8135	3	2004-01-29
2	668	1567	1	2004-01-29
3	668	3221	1	2004-01-29
4	668	7893	2	2004-01-29
5	668	5767	1	2004-01-29
6	668	2543	1	2004-01-29
7	668	2046	2	2004-01-29
8	668	2174	1	2004-01-29
1	669	6311	1	2004-01-11
2	669	758	2	2004-01-11
3	669	3020	2	2004-01-11
4	669	574	1	2004-01-11
5	669	4675	2	2004-01-11
1	670	3489	3	2004-01-02
2	670	3488	1	2004-01-02
1	671	1722	2	2004-01-11
2	671	118	2	2004-01-11
3	671	5553	2	2004-01-11
4	671	3882	3	2004-01-11
5	671	8243	1	2004-01-11
6	671	9979	3	2004-01-11
1	672	5151	3	2004-01-16
2	672	1116	2	2004-01-16
3	672	709	2	2004-01-16
4	672	7551	2	2004-01-16
5	672	3018	1	2004-01-16
6	672	5578	2	2004-01-16
1	673	3014	1	2004-01-01
2	673	5909	3	2004-01-01
1	674	9983	2	2004-01-18
2	674	2836	2	2004-01-18
3	674	8800	2	2004-01-18
4	674	607	2	2004-01-18
1	675	7179	3	2004-01-13
2	675	8863	1	2004-01-13
3	675	8105	2	2004-01-13
4	675	6459	3	2004-01-13
5	675	2713	3	2004-01-13
1	676	4292	2	2004-01-02
2	676	6108	1	2004-01-02
3	676	102	2	2004-01-02
4	676	5916	1	2004-01-02
5	676	1098	2	2004-01-02
6	676	8997	1	2004-01-02
1	677	7621	1	2004-01-27
2	677	5251	2	2004-01-27
3	677	802	2	2004-01-27
4	677	923	3	2004-01-27
5	677	1752	2	2004-01-27
6	677	5768	1	2004-01-27
7	677	9360	2	2004-01-27
8	677	8479	2	2004-01-27
1	678	676	3	2004-01-09
2	678	5746	1	2004-01-09
3	678	4397	2	2004-01-09
1	679	1246	2	2004-01-11
2	679	7510	2	2004-01-11
3	679	1799	3	2004-01-11
4	679	9851	1	2004-01-11
5	679	5571	1	2004-01-11
6	679	6356	1	2004-01-11
7	679	3764	2	2004-01-11
1	680	6828	1	2004-01-25
1	681	9277	3	2004-01-11
2	681	3784	1	2004-01-11
3	681	272	1	2004-01-11
4	681	9659	1	2004-01-11
5	681	6797	3	2004-01-11
6	681	8013	3	2004-01-11
7	681	5479	3	2004-01-11
8	681	1316	1	2004-01-11
9	681	9466	3	2004-01-11
1	682	5471	1	2004-01-08
1	683	9803	3	2004-01-03
2	683	2991	3	2004-01-03
3	683	5905	3	2004-01-03
4	683	1833	2	2004-01-03
1	684	8659	2	2004-01-26
2	684	3646	2	2004-01-26
3	684	3570	2	2004-01-26
4	684	5186	1	2004-01-26
5	684	2632	3	2004-01-26
1	685	8769	3	2004-01-20
2	685	4034	2	2004-01-20
1	686	2915	3	2004-01-08
2	686	2105	2	2004-01-08
3	686	5428	1	2004-01-08
4	686	6239	1	2004-01-08
5	686	5410	2	2004-01-08
1	687	4016	2	2004-01-28
2	687	5432	2	2004-01-28
3	687	1793	1	2004-01-28
1	688	7922	3	2004-01-09
2	688	6085	1	2004-01-09
1	689	8682	3	2004-01-05
2	689	8961	2	2004-01-05
3	689	8054	2	2004-01-05
4	689	7231	2	2004-01-05
1	690	8455	2	2004-01-01
2	690	3350	2	2004-01-01
3	690	3182	2	2004-01-01
4	690	5582	2	2004-01-01
5	690	4673	3	2004-01-01
6	690	7279	1	2004-01-01
7	690	6476	2	2004-01-01
8	690	2855	3	2004-01-01
9	690	2794	3	2004-01-01
1	691	5585	2	2004-01-07
1	692	8873	1	2004-01-20
2	692	5370	3	2004-01-20
3	692	6709	3	2004-01-20
4	692	1214	3	2004-01-20
5	692	3861	3	2004-01-20
6	692	5736	3	2004-01-20
1	693	6378	2	2004-01-19
2	693	57	3	2004-01-19
3	693	2427	1	2004-01-19
1	694	2760	3	2004-01-03
2	694	9048	1	2004-01-03
3	694	5377	3	2004-01-03
4	694	592	1	2004-01-03
5	694	5248	3	2004-01-03
6	694	9466	2	2004-01-03
1	695	1861	3	2004-01-23
2	695	5940	1	2004-01-23
3	695	1344	1	2004-01-23
1	696	3444	1	2004-01-22
2	696	7963	2	2004-01-22
3	696	8367	1	2004-01-22
4	696	5571	3	2004-01-22
5	696	1139	1	2004-01-22
6	696	5334	1	2004-01-22
7	696	1694	1	2004-01-22
8	696	9030	1	2004-01-22
9	696	7041	2	2004-01-22
1	697	9358	2	2004-01-14
2	697	9334	1	2004-01-14
3	697	7400	2	2004-01-14
4	697	2100	3	2004-01-14
5	697	5699	2	2004-01-14
6	697	1023	2	2004-01-14
1	698	6803	2	2004-01-07
2	698	8494	1	2004-01-07
3	698	7251	1	2004-01-07
4	698	2717	2	2004-01-07
5	698	1347	3	2004-01-07
6	698	2499	2	2004-01-07
7	698	54	1	2004-01-07
1	699	111	2	2004-01-07
2	699	7814	1	2004-01-07
1	700	7173	3	2004-01-10
2	700	3424	1	2004-01-10
3	700	7277	1	2004-01-10
4	700	7076	2	2004-01-10
1	701	606	3	2004-01-08
2	701	4837	1	2004-01-08
3	701	3137	2	2004-01-08
4	701	4747	2	2004-01-08
5	701	4300	1	2004-01-08
1	702	6622	3	2004-01-22
2	702	8153	2	2004-01-22
3	702	2642	2	2004-01-22
4	702	4105	2	2004-01-22
5	702	6880	1	2004-01-22
1	703	8282	1	2004-01-20
2	703	3733	3	2004-01-20
3	703	415	3	2004-01-20
4	703	1992	2	2004-01-20
5	703	3458	3	2004-01-20
6	703	8867	3	2004-01-20
7	703	8210	2	2004-01-20
8	703	2169	2	2004-01-20
1	704	3164	2	2004-01-02
2	704	3810	3	2004-01-02
3	704	1120	1	2004-01-02
4	704	8651	3	2004-01-02
5	704	4645	2	2004-01-02
6	704	6065	1	2004-01-02
7	704	8913	3	2004-01-02
8	704	1814	3	2004-01-02
1	705	545	1	2004-01-26
2	705	9581	3	2004-01-26
1	706	539	2	2004-01-24
2	706	6256	2	2004-01-24
3	706	26	1	2004-01-24
4	706	971	1	2004-01-24
5	706	755	3	2004-01-24
6	706	8557	2	2004-01-24
7	706	5423	2	2004-01-24
1	707	3663	1	2004-01-26
1	708	8287	2	2004-01-13
2	708	3243	2	2004-01-13
3	708	5936	2	2004-01-13
4	708	3496	2	2004-01-13
5	708	772	3	2004-01-13
1	709	1943	1	2004-01-01
2	709	767	1	2004-01-01
1	710	526	3	2004-01-19
2	710	4434	2	2004-01-19
3	710	2322	3	2004-01-19
4	710	730	3	2004-01-19
1	711	4742	3	2004-01-09
2	711	1910	3	2004-01-09
3	711	3524	1	2004-01-09
4	711	7989	2	2004-01-09
5	711	3480	3	2004-01-09
6	711	4847	2	2004-01-09
1	712	1803	1	2004-01-26
2	712	8641	1	2004-01-26
3	712	582	1	2004-01-26
4	712	6517	1	2004-01-26
1	713	6262	1	2004-01-05
2	713	429	1	2004-01-05
3	713	7996	1	2004-01-05
4	713	9240	1	2004-01-05
1	714	5033	1	2004-01-16
2	714	3921	2	2004-01-16
3	714	5679	3	2004-01-16
4	714	7755	3	2004-01-16
5	714	885	2	2004-01-16
6	714	9810	1	2004-01-16
7	714	9469	2	2004-01-16
8	714	4370	1	2004-01-16
1	715	5147	2	2004-01-12
2	715	837	1	2004-01-12
3	715	8007	1	2004-01-12
4	715	4662	1	2004-01-12
5	715	7305	3	2004-01-12
6	715	1525	1	2004-01-12
7	715	9947	2	2004-01-12
8	715	5746	2	2004-01-12
9	715	5289	2	2004-01-12
1	716	7640	3	2004-01-10
2	716	9242	1	2004-01-10
3	716	283	1	2004-01-10
1	717	1191	2	2004-01-20
2	717	4500	3	2004-01-20
1	718	9042	2	2004-01-12
1	719	4614	2	2004-01-10
2	719	2447	3	2004-01-10
3	719	655	1	2004-01-10
4	719	637	3	2004-01-10
5	719	1703	3	2004-01-10
6	719	304	1	2004-01-10
7	719	2692	2	2004-01-10
8	719	7509	2	2004-01-10
9	719	7871	3	2004-01-10
1	720	1531	1	2004-01-28
2	720	3243	1	2004-01-28
3	720	3865	2	2004-01-28
1	721	7540	3	2004-01-30
2	721	1895	3	2004-01-30
3	721	176	1	2004-01-30
4	721	6488	1	2004-01-30
1	722	3306	1	2004-01-08
2	722	439	1	2004-01-08
3	722	71	3	2004-01-08
4	722	3546	3	2004-01-08
5	722	1639	2	2004-01-08
1	723	1324	2	2004-01-26
2	723	5007	3	2004-01-26
1	724	740	2	2004-01-30
2	724	3808	3	2004-01-30
1	725	1317	3	2004-01-21
1	726	1014	1	2004-01-06
2	726	9872	1	2004-01-06
1	727	9903	3	2004-01-23
2	727	7978	2	2004-01-23
3	727	5568	3	2004-01-23
1	728	4837	1	2004-01-24
2	728	5421	1	2004-01-24
3	728	8660	3	2004-01-24
4	728	1901	3	2004-01-24
5	728	6762	2	2004-01-24
6	728	1732	2	2004-01-24
7	728	5643	1	2004-01-24
8	728	7305	2	2004-01-24
1	729	7195	2	2004-01-17
2	729	1786	2	2004-01-17
3	729	8281	3	2004-01-17
1	730	3929	1	2004-01-08
2	730	3610	3	2004-01-08
1	731	2246	2	2004-01-12
2	731	9378	2	2004-01-12
3	731	808	2	2004-01-12
4	731	6722	3	2004-01-12
5	731	535	1	2004-01-12
6	731	2539	2	2004-01-12
1	732	4904	2	2004-01-16
2	732	4187	3	2004-01-16
3	732	1392	1	2004-01-16
4	732	8602	2	2004-01-16
5	732	3959	1	2004-01-16
6	732	4668	3	2004-01-16
7	732	4481	2	2004-01-16
1	733	702	3	2004-01-11
2	733	7740	3	2004-01-11
3	733	7923	3	2004-01-11
1	734	194	3	2004-01-30
2	734	1423	2	2004-01-30
3	734	5309	2	2004-01-30
4	734	2532	3	2004-01-30
5	734	7263	1	2004-01-30
1	735	8921	3	2004-01-07
2	735	142	1	2004-01-07
3	735	4551	3	2004-01-07
4	735	4982	2	2004-01-07
5	735	8953	1	2004-01-07
6	735	2675	3	2004-01-07
7	735	995	1	2004-01-07
1	736	2926	3	2004-01-23
2	736	2626	3	2004-01-23
3	736	3837	2	2004-01-23
4	736	4935	1	2004-01-23
5	736	6291	3	2004-01-23
6	736	2321	3	2004-01-23
7	736	3641	1	2004-01-23
1	737	2925	3	2004-01-24
2	737	7262	1	2004-01-24
1	738	2153	2	2004-01-04
2	738	5472	3	2004-01-04
1	739	6631	1	2004-01-12
2	739	1400	1	2004-01-12
3	739	2122	3	2004-01-12
4	739	8519	2	2004-01-12
5	739	7325	1	2004-01-12
6	739	5683	2	2004-01-12
1	740	7670	2	2004-01-19
2	740	743	3	2004-01-19
3	740	3991	3	2004-01-19
4	740	1074	2	2004-01-19
5	740	5582	2	2004-01-19
6	740	5101	3	2004-01-19
7	740	4943	1	2004-01-19
8	740	5441	1	2004-01-19
1	741	4530	1	2004-01-11
2	741	9873	1	2004-01-11
3	741	3818	2	2004-01-11
4	741	6639	3	2004-01-11
5	741	4741	2	2004-01-11
1	742	1284	1	2004-01-27
2	742	8862	1	2004-01-27
3	742	7619	2	2004-01-27
4	742	8903	1	2004-01-27
5	742	3642	2	2004-01-27
6	742	5006	3	2004-01-27
7	742	5419	3	2004-01-27
8	742	5922	3	2004-01-27
9	742	3746	1	2004-01-27
1	743	9174	3	2004-01-01
2	743	3790	2	2004-01-01
3	743	2375	1	2004-01-01
4	743	6323	3	2004-01-01
1	744	9964	3	2004-01-06
1	745	2711	3	2004-01-16
2	745	7812	3	2004-01-16
3	745	4994	2	2004-01-16
4	745	6686	3	2004-01-16
5	745	4184	3	2004-01-16
6	745	2358	2	2004-01-16
7	745	932	1	2004-01-16
8	745	5433	2	2004-01-16
1	746	7668	3	2004-01-17
2	746	9374	3	2004-01-17
1	747	8203	3	2004-01-30
2	747	3378	1	2004-01-30
3	747	6312	1	2004-01-30
4	747	9043	1	2004-01-30
5	747	4922	2	2004-01-30
1	748	5595	2	2004-01-01
2	748	3934	1	2004-01-01
3	748	8282	3	2004-01-01
1	749	4335	1	2004-01-28
2	749	5508	2	2004-01-28
3	749	9855	2	2004-01-28
4	749	8545	3	2004-01-28
5	749	3099	1	2004-01-28
6	749	8971	3	2004-01-28
1	750	3741	1	2004-01-10
2	750	7139	2	2004-01-10
3	750	3164	1	2004-01-10
4	750	9930	3	2004-01-10
5	750	3762	3	2004-01-10
6	750	6475	1	2004-01-10
7	750	3629	3	2004-01-10
8	750	9100	3	2004-01-10
1	751	8073	1	2004-01-26
2	751	6049	1	2004-01-26
3	751	2328	2	2004-01-26
4	751	582	2	2004-01-26
5	751	3033	1	2004-01-26
6	751	3473	3	2004-01-26
7	751	2058	1	2004-01-26
8	751	3143	2	2004-01-26
1	752	1284	3	2004-01-11
2	752	9703	2	2004-01-11
3	752	6412	3	2004-01-11
4	752	2877	2	2004-01-11
5	752	3409	2	2004-01-11
6	752	2540	1	2004-01-11
7	752	5141	3	2004-01-11
1	753	2907	2	2004-01-09
2	753	4532	2	2004-01-09
3	753	3413	2	2004-01-09
1	754	9628	2	2004-01-22
1	755	5825	3	2004-01-24
2	755	5945	3	2004-01-24
3	755	3880	3	2004-01-24
4	755	3437	2	2004-01-24
5	755	836	3	2004-01-24
6	755	5008	2	2004-01-24
7	755	6046	3	2004-01-24
1	756	5331	3	2004-01-21
2	756	7843	1	2004-01-21
1	757	3782	1	2004-01-17
2	757	5762	3	2004-01-17
3	757	7239	1	2004-01-17
4	757	6035	1	2004-01-17
5	757	286	3	2004-01-17
1	758	2300	1	2004-01-08
2	758	6861	3	2004-01-08
3	758	9956	2	2004-01-08
4	758	7298	2	2004-01-08
1	759	4949	3	2004-01-15
2	759	2331	3	2004-01-15
3	759	3950	2	2004-01-15
1	760	1297	3	2004-01-24
2	760	8122	1	2004-01-24
3	760	8764	1	2004-01-24
4	760	5305	2	2004-01-24
5	760	4031	3	2004-01-24
1	761	4474	1	2004-01-20
2	761	1605	3	2004-01-20
3	761	5876	2	2004-01-20
4	761	1987	1	2004-01-20
5	761	4582	2	2004-01-20
6	761	8429	3	2004-01-20
1	762	1066	3	2004-01-02
2	762	2094	3	2004-01-02
3	762	1122	1	2004-01-02
1	763	4031	1	2004-01-31
2	763	4766	3	2004-01-31
3	763	8789	3	2004-01-31
4	763	3228	1	2004-01-31
1	764	9928	1	2004-01-27
1	765	4483	3	2004-01-16
2	765	8528	2	2004-01-16
3	765	6770	1	2004-01-16
4	765	4735	3	2004-01-16
5	765	1479	2	2004-01-16
1	766	9828	1	2004-01-14
2	766	8328	3	2004-01-14
3	766	2459	1	2004-01-14
4	766	9011	1	2004-01-14
5	766	659	2	2004-01-14
6	766	1542	1	2004-01-14
7	766	5344	2	2004-01-14
8	766	8942	2	2004-01-14
1	767	8972	3	2004-01-06
1	768	8285	1	2004-01-03
2	768	9738	3	2004-01-03
3	768	8888	3	2004-01-03
1	769	8771	3	2004-01-31
2	769	3423	3	2004-01-31
3	769	2079	2	2004-01-31
1	770	1755	1	2004-01-01
2	770	2380	1	2004-01-01
3	770	3240	1	2004-01-01
4	770	1651	2	2004-01-01
5	770	5058	3	2004-01-01
6	770	6368	2	2004-01-01
7	770	8416	2	2004-01-01
8	770	82	3	2004-01-01
9	770	5670	1	2004-01-01
1	771	1044	2	2004-01-15
2	771	2719	1	2004-01-15
3	771	841	1	2004-01-15
1	772	5234	2	2004-01-02
2	772	5615	3	2004-01-02
3	772	5421	3	2004-01-02
1	773	3822	2	2004-01-08
2	773	5010	2	2004-01-08
3	773	859	1	2004-01-08
4	773	3942	2	2004-01-08
5	773	4531	2	2004-01-08
6	773	8666	2	2004-01-08
7	773	2273	1	2004-01-08
8	773	8696	1	2004-01-08
9	773	4118	3	2004-01-08
1	774	9876	3	2004-01-17
1	775	5775	3	2004-01-28
2	775	460	3	2004-01-28
1	776	6149	3	2004-01-10
2	776	9345	1	2004-01-10
3	776	3837	3	2004-01-10
4	776	6253	2	2004-01-10
1	777	4187	2	2004-01-30
2	777	9320	2	2004-01-30
3	777	5078	3	2004-01-30
4	777	2872	2	2004-01-30
1	778	6841	2	2004-01-14
1	779	3919	3	2004-01-31
2	779	802	1	2004-01-31
3	779	8405	2	2004-01-31
4	779	1275	2	2004-01-31
1	780	4182	2	2004-01-03
2	780	4501	2	2004-01-03
3	780	9513	3	2004-01-03
4	780	2696	1	2004-01-03
5	780	3673	3	2004-01-03
6	780	9670	3	2004-01-03
7	780	7453	2	2004-01-03
8	780	5432	3	2004-01-03
9	780	6462	3	2004-01-03
1	781	3644	1	2004-01-03
2	781	6116	2	2004-01-03
1	782	6831	3	2004-01-25
2	782	1193	1	2004-01-25
3	782	3271	1	2004-01-25
4	782	909	2	2004-01-25
5	782	3088	2	2004-01-25
6	782	3153	1	2004-01-25
7	782	3904	1	2004-01-25
1	783	6344	3	2004-01-29
2	783	6109	1	2004-01-29
3	783	74	3	2004-01-29
4	783	4219	2	2004-01-29
5	783	4671	1	2004-01-29
6	783	3052	1	2004-01-29
1	784	1214	1	2004-01-30
1	785	6704	1	2004-01-05
2	785	7158	1	2004-01-05
3	785	3022	2	2004-01-05
4	785	9943	1	2004-01-05
1	786	7365	3	2004-01-07
2	786	8017	1	2004-01-07
3	786	5798	1	2004-01-07
4	786	3599	3	2004-01-07
5	786	2945	1	2004-01-07
6	786	8732	1	2004-01-07
7	786	3623	3	2004-01-07
8	786	6269	2	2004-01-07
1	787	7949	2	2004-01-07
2	787	9379	1	2004-01-07
3	787	2920	3	2004-01-07
4	787	1911	2	2004-01-07
5	787	5607	1	2004-01-07
6	787	3339	1	2004-01-07
7	787	1055	1	2004-01-07
8	787	4556	3	2004-01-07
1	788	1168	2	2004-01-13
2	788	9957	2	2004-01-13
3	788	4378	2	2004-01-13
4	788	9726	2	2004-01-13
5	788	1758	3	2004-01-13
6	788	5216	3	2004-01-13
7	788	5556	2	2004-01-13
1	789	3550	3	2004-01-03
2	789	4032	3	2004-01-03
3	789	2494	2	2004-01-03
1	790	5203	3	2004-01-26
2	790	9269	2	2004-01-26
3	790	2074	3	2004-01-26
1	791	2896	3	2004-01-04
1	792	2706	3	2004-01-31
2	792	3980	2	2004-01-31
3	792	173	3	2004-01-31
4	792	6143	2	2004-01-31
5	792	4417	3	2004-01-31
1	793	4944	1	2004-01-29
2	793	8869	2	2004-01-29
1	794	7393	3	2004-01-23
2	794	9307	1	2004-01-23
3	794	6092	3	2004-01-23
4	794	8400	1	2004-01-23
5	794	4760	1	2004-01-23
6	794	592	3	2004-01-23
7	794	7726	1	2004-01-23
8	794	6267	2	2004-01-23
1	795	3344	3	2004-01-16
2	795	5488	3	2004-01-16
3	795	9080	2	2004-01-16
4	795	2498	2	2004-01-16
1	796	4820	2	2004-01-17
2	796	2978	1	2004-01-17
3	796	3320	1	2004-01-17
1	797	6817	1	2004-01-13
2	797	5271	1	2004-01-13
3	797	4076	1	2004-01-13
4	797	3768	2	2004-01-13
5	797	4498	3	2004-01-13
1	798	4341	3	2004-01-15
2	798	188	3	2004-01-15
3	798	3830	2	2004-01-15
4	798	2328	3	2004-01-15
1	799	6683	2	2004-01-28
2	799	408	3	2004-01-28
3	799	7982	3	2004-01-28
1	800	3492	2	2004-01-30
2	800	28	3	2004-01-30
3	800	1187	2	2004-01-30
4	800	7974	2	2004-01-30
1	801	1952	3	2004-01-27
2	801	3782	2	2004-01-27
3	801	6957	1	2004-01-27
4	801	9586	2	2004-01-27
5	801	5121	2	2004-01-27
6	801	9992	2	2004-01-27
7	801	5432	3	2004-01-27
8	801	2754	2	2004-01-27
1	802	7137	3	2004-01-04
2	802	2708	3	2004-01-04
3	802	3075	1	2004-01-04
4	802	4906	1	2004-01-04
5	802	2996	3	2004-01-04
1	803	9227	2	2004-01-02
2	803	7133	3	2004-01-02
3	803	1166	1	2004-01-02
4	803	5080	1	2004-01-02
1	804	5314	1	2004-01-25
1	805	1839	3	2004-01-12
1	806	6636	1	2004-01-29
2	806	3345	3	2004-01-29
3	806	6406	1	2004-01-29
4	806	1536	2	2004-01-29
1	807	922	3	2004-01-18
2	807	8010	3	2004-01-18
3	807	34	3	2004-01-18
4	807	9239	2	2004-01-18
5	807	7498	1	2004-01-18
6	807	8910	1	2004-01-18
7	807	3567	1	2004-01-18
1	808	6581	1	2004-01-02
2	808	275	3	2004-01-02
3	808	9493	3	2004-01-02
4	808	962	1	2004-01-02
5	808	2312	2	2004-01-02
6	808	9696	3	2004-01-02
7	808	3501	1	2004-01-02
8	808	6280	1	2004-01-02
1	809	1661	2	2004-01-29
2	809	1394	1	2004-01-29
3	809	8721	2	2004-01-29
4	809	1319	3	2004-01-29
5	809	7582	3	2004-01-29
6	809	7891	2	2004-01-29
7	809	9278	3	2004-01-29
8	809	4087	3	2004-01-29
1	810	1698	3	2004-01-16
2	810	3913	2	2004-01-16
3	810	111	1	2004-01-16
4	810	6708	3	2004-01-16
5	810	6505	2	2004-01-16
6	810	7991	3	2004-01-16
7	810	1507	3	2004-01-16
1	811	9301	1	2004-01-28
1	812	5357	1	2004-01-22
2	812	5081	1	2004-01-22
3	812	5224	2	2004-01-22
4	812	7359	3	2004-01-22
5	812	4371	1	2004-01-22
6	812	2119	2	2004-01-22
1	813	4185	1	2004-01-05
2	813	6133	2	2004-01-05
3	813	1286	2	2004-01-05
4	813	5918	2	2004-01-05
5	813	4921	2	2004-01-05
6	813	7556	1	2004-01-05
7	813	2411	2	2004-01-05
8	813	8264	3	2004-01-05
1	814	8222	2	2004-01-12
2	814	5960	1	2004-01-12
3	814	6600	3	2004-01-12
4	814	7074	3	2004-01-12
5	814	6904	1	2004-01-12
6	814	6031	1	2004-01-12
7	814	2888	1	2004-01-12
8	814	6780	2	2004-01-12
9	814	7031	1	2004-01-12
1	815	3905	1	2004-01-31
2	815	1001	1	2004-01-31
3	815	8093	2	2004-01-31
4	815	5513	2	2004-01-31
5	815	3857	2	2004-01-31
6	815	1390	3	2004-01-31
7	815	6327	3	2004-01-31
1	816	4385	1	2004-01-25
2	816	5887	3	2004-01-25
3	816	4246	1	2004-01-25
4	816	1445	1	2004-01-25
5	816	5363	1	2004-01-25
1	817	3605	3	2004-01-11
2	817	9302	1	2004-01-11
3	817	4424	2	2004-01-11
4	817	7759	3	2004-01-11
5	817	8548	3	2004-01-11
6	817	8097	2	2004-01-11
7	817	7138	2	2004-01-11
1	818	5273	3	2004-01-26
2	818	9930	3	2004-01-26
3	818	9343	1	2004-01-26
1	819	7984	1	2004-01-03
2	819	1156	1	2004-01-03
3	819	835	1	2004-01-03
4	819	3285	2	2004-01-03
1	820	191	1	2004-01-17
2	820	8693	3	2004-01-17
3	820	7625	3	2004-01-17
4	820	519	3	2004-01-17
1	821	5309	2	2004-01-30
2	821	927	2	2004-01-30
3	821	9138	2	2004-01-30
4	821	126	3	2004-01-30
5	821	4778	1	2004-01-30
6	821	8709	2	2004-01-30
7	821	1739	1	2004-01-30
8	821	870	3	2004-01-30
9	821	3036	2	2004-01-30
1	822	555	2	2004-01-03
2	822	6487	1	2004-01-03
3	822	2080	2	2004-01-03
4	822	6864	3	2004-01-03
5	822	5663	1	2004-01-03
6	822	1603	2	2004-01-03
7	822	8275	1	2004-01-03
8	822	139	3	2004-01-03
9	822	7862	2	2004-01-03
1	823	8564	1	2004-01-31
2	823	8430	1	2004-01-31
1	824	8779	2	2004-01-18
2	824	5511	2	2004-01-18
1	825	4761	3	2004-01-21
2	825	5488	2	2004-01-21
3	825	3627	2	2004-01-21
1	826	8680	1	2004-01-23
2	826	1536	3	2004-01-23
3	826	3266	1	2004-01-23
4	826	605	1	2004-01-23
5	826	1698	2	2004-01-23
1	827	1903	2	2004-01-03
2	827	4998	3	2004-01-03
3	827	1354	2	2004-01-03
4	827	1673	2	2004-01-03
5	827	3409	3	2004-01-03
6	827	2479	3	2004-01-03
7	827	923	3	2004-01-03
8	827	799	1	2004-01-03
9	827	4548	3	2004-01-03
1	828	6183	3	2004-01-16
2	828	9892	3	2004-01-16
3	828	5698	1	2004-01-16
4	828	4404	2	2004-01-16
5	828	577	2	2004-01-16
6	828	7714	2	2004-01-16
7	828	4663	3	2004-01-16
8	828	1946	2	2004-01-16
1	829	2389	2	2004-01-17
2	829	7243	1	2004-01-17
3	829	7503	1	2004-01-17
4	829	2667	1	2004-01-17
5	829	7874	1	2004-01-17
6	829	630	2	2004-01-17
7	829	643	1	2004-01-17
1	830	292	1	2004-01-07
2	830	2647	3	2004-01-07
3	830	7517	3	2004-01-07
4	830	7073	3	2004-01-07
5	830	3644	1	2004-01-07
6	830	4816	3	2004-01-07
1	831	392	3	2004-01-31
2	831	8947	1	2004-01-31
3	831	1490	3	2004-01-31
4	831	4411	1	2004-01-31
5	831	878	2	2004-01-31
6	831	2640	1	2004-01-31
7	831	1394	2	2004-01-31
1	832	9690	2	2004-01-29
2	832	9111	3	2004-01-29
1	833	9892	3	2004-01-10
2	833	4944	1	2004-01-10
3	833	6088	2	2004-01-10
4	833	503	2	2004-01-10
5	833	8394	1	2004-01-10
6	833	1856	1	2004-01-10
7	833	4112	1	2004-01-10
1	834	756	2	2004-01-25
2	834	934	3	2004-01-25
3	834	6506	1	2004-01-25
4	834	166	2	2004-01-25
5	834	7384	1	2004-01-25
6	834	8371	2	2004-01-25
7	834	830	3	2004-01-25
8	834	5331	2	2004-01-25
9	834	9708	1	2004-01-25
1	835	2203	3	2004-01-04
2	835	2306	2	2004-01-04
3	835	1041	1	2004-01-04
4	835	3064	2	2004-01-04
5	835	9411	2	2004-01-04
6	835	1291	1	2004-01-04
7	835	522	3	2004-01-04
8	835	967	1	2004-01-04
9	835	3413	3	2004-01-04
1	836	44	1	2004-01-12
2	836	381	3	2004-01-12
3	836	1499	1	2004-01-12
4	836	9962	3	2004-01-12
5	836	992	1	2004-01-12
1	837	3460	1	2004-01-20
2	837	3888	1	2004-01-20
3	837	5360	2	2004-01-20
4	837	3214	2	2004-01-20
5	837	2975	2	2004-01-20
6	837	6568	2	2004-01-20
7	837	2531	1	2004-01-20
1	838	7362	2	2004-01-26
2	838	7964	3	2004-01-26
3	838	6820	3	2004-01-26
4	838	6812	3	2004-01-26
5	838	88	1	2004-01-26
6	838	1109	3	2004-01-26
7	838	370	2	2004-01-26
8	838	105	2	2004-01-26
1	839	1346	1	2004-01-24
1	840	8258	3	2004-01-15
2	840	4643	1	2004-01-15
3	840	5177	1	2004-01-15
4	840	8539	1	2004-01-15
5	840	865	2	2004-01-15
6	840	1065	3	2004-01-15
7	840	3171	1	2004-01-15
1	841	8847	3	2004-01-03
2	841	5374	2	2004-01-03
1	842	7219	1	2004-01-17
2	842	4543	2	2004-01-17
3	842	9130	1	2004-01-17
4	842	2979	2	2004-01-17
5	842	6009	3	2004-01-17
6	842	5777	2	2004-01-17
1	843	4317	1	2004-01-05
2	843	3514	2	2004-01-05
3	843	7355	1	2004-01-05
1	844	2487	3	2004-01-20
2	844	6362	3	2004-01-20
1	845	9595	1	2004-01-16
2	845	2310	1	2004-01-16
3	845	4092	3	2004-01-16
4	845	730	3	2004-01-16
5	845	2865	1	2004-01-16
6	845	6509	1	2004-01-16
7	845	4387	1	2004-01-16
8	845	5847	3	2004-01-16
9	845	5888	1	2004-01-16
1	846	3619	1	2004-01-04
2	846	2517	3	2004-01-04
3	846	1311	3	2004-01-04
4	846	3561	1	2004-01-04
1	847	5730	3	2004-01-22
2	847	7619	2	2004-01-22
3	847	6781	1	2004-01-22
4	847	8485	1	2004-01-22
5	847	3254	1	2004-01-22
6	847	4113	3	2004-01-22
7	847	771	3	2004-01-22
8	847	2302	1	2004-01-22
9	847	2067	1	2004-01-22
1	848	5666	2	2004-01-19
2	848	6081	3	2004-01-19
3	848	7405	1	2004-01-19
4	848	2383	1	2004-01-19
5	848	2374	3	2004-01-19
6	848	7137	3	2004-01-19
7	848	4571	2	2004-01-19
8	848	476	1	2004-01-19
1	849	2830	3	2004-01-23
2	849	1319	2	2004-01-23
1	850	9070	1	2004-01-27
2	850	3273	2	2004-01-27
3	850	5332	3	2004-01-27
4	850	3962	1	2004-01-27
5	850	2425	2	2004-01-27
1	851	4790	3	2004-01-10
1	852	8995	3	2004-01-13
2	852	2537	1	2004-01-13
1	853	7239	2	2004-01-15
2	853	7970	2	2004-01-15
3	853	4218	1	2004-01-15
1	854	2284	1	2004-01-04
2	854	1349	2	2004-01-04
3	854	7817	2	2004-01-04
4	854	5339	1	2004-01-04
5	854	4830	3	2004-01-04
1	855	4915	1	2004-01-25
2	855	8690	3	2004-01-25
3	855	6961	2	2004-01-25
4	855	2909	2	2004-01-25
5	855	9434	1	2004-01-25
6	855	507	2	2004-01-25
7	855	2120	1	2004-01-25
1	856	5734	3	2004-01-10
2	856	725	2	2004-01-10
3	856	3706	2	2004-01-10
4	856	6156	3	2004-01-10
5	856	5416	2	2004-01-10
1	857	9092	3	2004-01-17
1	858	251	2	2004-01-31
2	858	3759	1	2004-01-31
3	858	8308	2	2004-01-31
1	859	6989	2	2004-01-08
2	859	6762	3	2004-01-08
3	859	7875	1	2004-01-08
4	859	3777	2	2004-01-08
5	859	9003	3	2004-01-08
6	859	8057	2	2004-01-08
7	859	5178	3	2004-01-08
8	859	4806	2	2004-01-08
1	860	7660	1	2004-01-27
2	860	8411	1	2004-01-27
3	860	1329	3	2004-01-27
4	860	7296	2	2004-01-27
1	861	213	3	2004-01-26
2	861	2927	3	2004-01-26
3	861	9724	3	2004-01-26
4	861	2119	3	2004-01-26
5	861	5895	1	2004-01-26
1	862	5341	3	2004-01-10
2	862	2757	2	2004-01-10
3	862	1405	1	2004-01-10
4	862	6233	3	2004-01-10
5	862	1834	3	2004-01-10
6	862	6535	3	2004-01-10
7	862	1197	2	2004-01-10
8	862	5018	2	2004-01-10
1	863	3318	1	2004-01-31
2	863	9602	2	2004-01-31
3	863	1397	2	2004-01-31
1	864	2547	1	2004-01-18
2	864	2386	2	2004-01-18
3	864	7571	2	2004-01-18
4	864	5720	2	2004-01-18
5	864	3606	3	2004-01-18
1	865	4900	1	2004-01-05
2	865	6253	2	2004-01-05
3	865	6930	3	2004-01-05
1	866	5683	1	2004-01-25
2	866	2869	1	2004-01-25
3	866	7838	3	2004-01-25
4	866	6027	1	2004-01-25
5	866	1347	3	2004-01-25
6	866	5688	3	2004-01-25
7	866	2202	1	2004-01-25
1	867	5948	2	2004-01-09
2	867	6645	1	2004-01-09
3	867	7343	1	2004-01-09
4	867	5719	2	2004-01-09
1	868	863	1	2004-01-07
2	868	7238	2	2004-01-07
3	868	1497	2	2004-01-07
4	868	3169	3	2004-01-07
1	869	3431	3	2004-01-17
2	869	2554	2	2004-01-17
1	870	7158	3	2004-01-13
2	870	739	2	2004-01-13
3	870	9775	2	2004-01-13
4	870	8773	1	2004-01-13
5	870	9947	1	2004-01-13
6	870	5842	1	2004-01-13
7	870	3496	1	2004-01-13
8	870	4541	2	2004-01-13
9	870	8155	3	2004-01-13
1	871	4760	2	2004-01-08
2	871	6586	3	2004-01-08
3	871	1805	1	2004-01-08
4	871	8829	1	2004-01-08
5	871	422	2	2004-01-08
6	871	8916	1	2004-01-08
7	871	487	3	2004-01-08
8	871	7617	3	2004-01-08
1	872	8372	2	2004-01-02
2	872	9484	1	2004-01-02
3	872	1039	3	2004-01-02
4	872	621	2	2004-01-02
5	872	1251	1	2004-01-02
6	872	2002	2	2004-01-02
1	873	9118	1	2004-01-27
1	874	698	3	2004-01-08
2	874	9947	3	2004-01-08
1	875	6913	2	2004-01-25
1	876	4034	3	2004-01-21
2	876	1075	2	2004-01-21
3	876	624	1	2004-01-21
4	876	1295	3	2004-01-21
5	876	1664	2	2004-01-21
6	876	9425	1	2004-01-21
7	876	6771	1	2004-01-21
1	877	3535	1	2004-01-01
1	878	1854	1	2004-01-29
2	878	9454	3	2004-01-29
3	878	6785	2	2004-01-29
4	878	5859	1	2004-01-29
5	878	4394	3	2004-01-29
1	879	4140	1	2004-01-19
2	879	2014	2	2004-01-19
3	879	2454	3	2004-01-19
4	879	5329	1	2004-01-19
5	879	3694	3	2004-01-19
6	879	3789	3	2004-01-19
7	879	1318	1	2004-01-19
1	880	5183	3	2004-01-27
1	881	2785	3	2004-01-28
2	881	1628	3	2004-01-28
3	881	3802	1	2004-01-28
4	881	6281	3	2004-01-28
5	881	3310	3	2004-01-28
1	882	8536	1	2004-01-05
2	882	5184	1	2004-01-05
3	882	8000	2	2004-01-05
4	882	5443	2	2004-01-05
5	882	1295	2	2004-01-05
6	882	7146	2	2004-01-05
7	882	1546	2	2004-01-05
1	883	4722	1	2004-01-27
2	883	113	3	2004-01-27
1	884	4686	3	2004-01-13
2	884	3014	1	2004-01-13
3	884	4800	1	2004-01-13
4	884	2535	3	2004-01-13
5	884	3873	1	2004-01-13
6	884	6484	3	2004-01-13
7	884	7179	3	2004-01-13
1	885	306	1	2004-01-10
2	885	565	1	2004-01-10
3	885	3925	2	2004-01-10
4	885	3288	2	2004-01-10
5	885	3809	3	2004-01-10
1	886	8239	3	2004-01-02
2	886	6879	1	2004-01-02
3	886	9041	3	2004-01-02
4	886	3021	1	2004-01-02
5	886	9948	3	2004-01-02
1	887	1450	1	2004-01-07
2	887	9939	1	2004-01-07
3	887	4233	1	2004-01-07
4	887	2739	3	2004-01-07
5	887	5790	2	2004-01-07
1	888	9870	3	2004-01-07
2	888	7738	3	2004-01-07
3	888	5226	2	2004-01-07
1	889	7180	2	2004-01-04
2	889	3670	3	2004-01-04
3	889	1104	1	2004-01-04
4	889	4719	1	2004-01-04
1	890	5161	3	2004-01-08
2	890	4875	1	2004-01-08
3	890	3073	3	2004-01-08
4	890	549	2	2004-01-08
5	890	9691	1	2004-01-08
6	890	4060	3	2004-01-08
7	890	8527	3	2004-01-08
1	891	3839	1	2004-01-07
2	891	52	3	2004-01-07
3	891	139	1	2004-01-07
4	891	8460	2	2004-01-07
5	891	3708	1	2004-01-07
6	891	9514	3	2004-01-07
1	892	5625	3	2004-01-24
2	892	9607	2	2004-01-24
3	892	4462	3	2004-01-24
1	893	7807	3	2004-01-21
2	893	4792	1	2004-01-21
3	893	4845	3	2004-01-21
4	893	2090	2	2004-01-21
5	893	6139	1	2004-01-21
1	894	5545	2	2004-01-19
2	894	7773	1	2004-01-19
3	894	1273	1	2004-01-19
4	894	5747	3	2004-01-19
5	894	971	2	2004-01-19
6	894	3071	2	2004-01-19
7	894	4652	3	2004-01-19
8	894	3954	1	2004-01-19
9	894	4783	1	2004-01-19
1	895	8205	2	2004-01-01
2	895	9888	2	2004-01-01
3	895	7437	2	2004-01-01
4	895	8942	2	2004-01-01
5	895	5694	2	2004-01-01
1	896	6302	2	2004-01-04
2	896	9290	3	2004-01-04
3	896	8795	1	2004-01-04
1	897	4823	3	2004-01-09
2	897	8419	2	2004-01-09
3	897	6381	1	2004-01-09
4	897	9963	2	2004-01-09
5	897	6747	3	2004-01-09
6	897	8929	2	2004-01-09
1	898	2356	3	2004-01-18
2	898	4947	1	2004-01-18
1	899	8521	1	2004-01-07
2	899	3868	1	2004-01-07
1	900	2699	2	2004-01-18
1	901	3664	2	2004-01-18
2	901	5336	1	2004-01-18
3	901	8768	1	2004-01-18
4	901	462	3	2004-01-18
5	901	2603	1	2004-01-18
1	902	8798	2	2004-01-23
2	902	1019	3	2004-01-23
3	902	8639	2	2004-01-23
4	902	8543	2	2004-01-23
5	902	778	2	2004-01-23
6	902	4921	2	2004-01-23
7	902	2725	1	2004-01-23
8	902	2554	1	2004-01-23
9	902	5929	2	2004-01-23
1	903	2387	3	2004-01-16
2	903	1385	2	2004-01-16
3	903	2088	3	2004-01-16
4	903	2539	2	2004-01-16
1	904	8655	3	2004-01-26
2	904	4097	3	2004-01-26
3	904	4315	2	2004-01-26
4	904	3621	3	2004-01-26
5	904	8349	2	2004-01-26
6	904	9680	1	2004-01-26
7	904	6908	2	2004-01-26
8	904	7121	1	2004-01-26
9	904	6873	2	2004-01-26
1	905	4248	3	2004-01-19
2	905	6033	3	2004-01-19
3	905	2242	2	2004-01-19
4	905	8123	2	2004-01-19
5	905	3436	3	2004-01-19
6	905	3496	3	2004-01-19
7	905	3974	3	2004-01-19
1	906	3940	3	2004-01-08
1	907	2902	3	2004-01-06
2	907	4708	3	2004-01-06
3	907	8466	3	2004-01-06
4	907	6222	1	2004-01-06
5	907	7196	1	2004-01-06
6	907	9499	3	2004-01-06
7	907	6480	3	2004-01-06
8	907	2987	3	2004-01-06
1	908	4293	3	2004-01-14
2	908	5966	1	2004-01-14
3	908	609	3	2004-01-14
4	908	8066	1	2004-01-14
5	908	754	1	2004-01-14
6	908	1045	2	2004-01-14
7	908	9606	2	2004-01-14
8	908	2525	3	2004-01-14
1	909	1001	1	2004-01-18
2	909	2293	3	2004-01-18
3	909	7903	2	2004-01-18
1	910	672	2	2004-01-23
2	910	4697	2	2004-01-23
3	910	7394	2	2004-01-23
4	910	6544	2	2004-01-23
5	910	7571	3	2004-01-23
1	911	4367	2	2004-01-19
2	911	3534	1	2004-01-19
3	911	2222	2	2004-01-19
4	911	2883	1	2004-01-19
5	911	4598	2	2004-01-19
1	912	4801	1	2004-01-03
2	912	2940	2	2004-01-03
3	912	8269	3	2004-01-03
4	912	2110	2	2004-01-03
5	912	2941	3	2004-01-03
6	912	1120	1	2004-01-03
7	912	5950	3	2004-01-03
8	912	9126	3	2004-01-03
1	913	3519	1	2004-01-08
2	913	289	2	2004-01-08
3	913	5821	2	2004-01-08
4	913	1576	2	2004-01-08
5	913	7387	1	2004-01-08
6	913	4619	1	2004-01-08
1	914	5194	3	2004-01-14
2	914	8173	3	2004-01-14
3	914	8423	3	2004-01-14
1	915	1273	3	2004-01-27
2	915	1263	1	2004-01-27
3	915	4680	2	2004-01-27
4	915	4249	2	2004-01-27
5	915	1181	1	2004-01-27
6	915	9855	1	2004-01-27
7	915	6591	3	2004-01-27
1	916	8768	3	2004-01-15
2	916	1539	2	2004-01-15
3	916	6858	3	2004-01-15
4	916	2095	2	2004-01-15
5	916	9004	1	2004-01-15
6	916	9652	2	2004-01-15
7	916	8510	1	2004-01-15
8	916	3980	3	2004-01-15
9	916	2574	3	2004-01-15
1	917	6891	2	2004-01-15
2	917	8489	2	2004-01-15
3	917	725	1	2004-01-15
4	917	4690	1	2004-01-15
5	917	2300	2	2004-01-15
6	917	7242	2	2004-01-15
1	918	9378	1	2004-01-23
2	918	252	3	2004-01-23
3	918	7825	3	2004-01-23
4	918	9953	1	2004-01-23
5	918	8533	1	2004-01-23
6	918	464	1	2004-01-23
7	918	9349	2	2004-01-23
8	918	8817	2	2004-01-23
9	918	7574	3	2004-01-23
1	919	8451	1	2004-01-31
2	919	7866	2	2004-01-31
3	919	6715	2	2004-01-31
4	919	9790	1	2004-01-31
1	920	8196	1	2004-01-15
2	920	3807	3	2004-01-15
3	920	2448	1	2004-01-15
4	920	675	1	2004-01-15
5	920	5422	1	2004-01-15
1	921	1543	2	2004-01-22
2	921	2872	1	2004-01-22
3	921	390	1	2004-01-22
4	921	4996	3	2004-01-22
5	921	7013	1	2004-01-22
1	922	5970	2	2004-01-11
2	922	3377	2	2004-01-11
3	922	5437	3	2004-01-11
4	922	2313	3	2004-01-11
5	922	9521	1	2004-01-11
6	922	795	2	2004-01-11
7	922	3011	3	2004-01-11
8	922	9181	3	2004-01-11
1	923	2843	2	2004-01-08
2	923	6563	3	2004-01-08
3	923	3897	2	2004-01-08
4	923	9548	3	2004-01-08
5	923	377	1	2004-01-08
1	924	511	1	2004-01-18
2	924	6324	1	2004-01-18
3	924	9638	2	2004-01-18
4	924	5811	1	2004-01-18
5	924	788	3	2004-01-18
6	924	8228	3	2004-01-18
7	924	8094	1	2004-01-18
8	924	692	2	2004-01-18
9	924	5839	2	2004-01-18
1	925	5976	1	2004-01-28
2	925	320	2	2004-01-28
3	925	2443	2	2004-01-28
1	926	513	1	2004-01-09
2	926	6033	1	2004-01-09
3	926	7394	1	2004-01-09
1	927	8149	3	2004-01-02
2	927	9408	3	2004-01-02
3	927	2105	2	2004-01-02
4	927	2375	1	2004-01-02
5	927	7648	2	2004-01-02
6	927	3980	2	2004-01-02
7	927	4665	2	2004-01-02
8	927	9976	3	2004-01-02
1	928	5884	2	2004-01-02
2	928	7157	1	2004-01-02
3	928	6531	2	2004-01-02
4	928	3761	3	2004-01-02
5	928	2731	2	2004-01-02
6	928	5924	1	2004-01-02
1	929	578	1	2004-01-10
2	929	6383	3	2004-01-10
3	929	5840	1	2004-01-10
4	929	1848	1	2004-01-10
5	929	4661	1	2004-01-10
1	930	651	1	2004-01-24
2	930	9858	3	2004-01-24
3	930	2297	2	2004-01-24
4	930	2358	2	2004-01-24
1	931	5968	2	2004-01-11
2	931	4757	2	2004-01-11
3	931	8955	2	2004-01-11
4	931	7782	2	2004-01-11
5	931	3560	2	2004-01-11
6	931	5699	2	2004-01-11
7	931	4125	1	2004-01-11
8	931	7230	1	2004-01-11
9	931	5401	1	2004-01-11
1	932	3859	2	2004-01-17
2	932	1461	2	2004-01-17
3	932	460	2	2004-01-17
4	932	1304	1	2004-01-17
5	932	4388	3	2004-01-17
1	933	4479	1	2004-01-15
2	933	8897	3	2004-01-15
3	933	4361	2	2004-01-15
4	933	3446	3	2004-01-15
1	934	2402	2	2004-01-16
1	935	8912	1	2004-01-20
1	936	313	1	2004-01-21
2	936	5053	2	2004-01-21
3	936	463	3	2004-01-21
4	936	8479	2	2004-01-21
5	936	8751	3	2004-01-21
6	936	2981	1	2004-01-21
7	936	1971	2	2004-01-21
8	936	1597	3	2004-01-21
1	937	7254	2	2004-01-23
2	937	4011	3	2004-01-23
3	937	3948	1	2004-01-23
4	937	9731	1	2004-01-23
5	937	2294	2	2004-01-23
6	937	8208	1	2004-01-23
7	937	7981	1	2004-01-23
8	937	7525	3	2004-01-23
9	937	1272	2	2004-01-23
1	938	3134	2	2004-01-11
2	938	2791	2	2004-01-11
3	938	2275	3	2004-01-11
4	938	6548	3	2004-01-11
5	938	9394	2	2004-01-11
6	938	3237	2	2004-01-11
1	939	7610	3	2004-01-05
2	939	7955	2	2004-01-05
1	940	4378	1	2004-01-04
2	940	4755	3	2004-01-04
3	940	374	3	2004-01-04
4	940	4127	2	2004-01-04
5	940	3484	3	2004-01-04
6	940	8238	2	2004-01-04
7	940	6809	2	2004-01-04
8	940	5311	2	2004-01-04
1	941	5731	2	2004-01-27
1	942	9158	2	2004-01-05
2	942	5331	3	2004-01-05
3	942	4532	3	2004-01-05
4	942	8587	3	2004-01-05
5	942	7470	3	2004-01-05
6	942	7419	1	2004-01-05
7	942	2468	1	2004-01-05
8	942	8514	1	2004-01-05
9	942	6660	2	2004-01-05
1	943	517	1	2004-01-18
2	943	4226	2	2004-01-18
3	943	7062	2	2004-01-18
4	943	9588	1	2004-01-18
1	944	6982	1	2004-01-16
1	945	4529	3	2004-01-01
2	945	9167	3	2004-01-01
3	945	9534	3	2004-01-01
4	945	7701	2	2004-01-01
5	945	3003	1	2004-01-01
6	945	8164	2	2004-01-01
7	945	7267	3	2004-01-01
1	946	7159	2	2004-01-18
2	946	4333	1	2004-01-18
3	946	3261	1	2004-01-18
1	947	5811	2	2004-01-09
2	947	286	1	2004-01-09
3	947	3499	3	2004-01-09
1	948	9226	1	2004-01-23
2	948	8228	3	2004-01-23
3	948	4661	2	2004-01-23
4	948	6070	1	2004-01-23
5	948	6987	1	2004-01-23
1	949	6367	3	2004-01-10
2	949	9093	3	2004-01-10
3	949	9014	1	2004-01-10
4	949	1698	2	2004-01-10
5	949	7614	1	2004-01-10
6	949	5164	1	2004-01-10
7	949	1437	1	2004-01-10
1	950	8705	2	2004-01-13
2	950	759	2	2004-01-13
3	950	1258	3	2004-01-13
4	950	3681	3	2004-01-13
1	951	4079	3	2004-01-25
2	951	2109	1	2004-01-25
3	951	7738	1	2004-01-25
4	951	5918	3	2004-01-25
1	952	4644	1	2004-01-19
1	953	2158	1	2004-01-12
2	953	6910	1	2004-01-12
1	954	6411	3	2004-01-11
2	954	3888	3	2004-01-11
3	954	907	3	2004-01-11
4	954	7555	1	2004-01-11
5	954	1136	2	2004-01-11
6	954	4138	3	2004-01-11
7	954	4729	1	2004-01-11
1	955	9004	2	2004-01-02
2	955	4016	1	2004-01-02
3	955	5949	2	2004-01-02
4	955	556	1	2004-01-02
5	955	9089	2	2004-01-02
1	956	6403	2	2004-01-04
2	956	6234	3	2004-01-04
3	956	3077	2	2004-01-04
4	956	325	2	2004-01-04
5	956	9082	2	2004-01-04
6	956	1266	2	2004-01-04
7	956	4545	1	2004-01-04
1	957	541	1	2004-01-31
2	957	9389	2	2004-01-31
3	957	7265	3	2004-01-31
4	957	9347	2	2004-01-31
5	957	3994	1	2004-01-31
6	957	5187	2	2004-01-31
7	957	7805	1	2004-01-31
8	957	328	2	2004-01-31
9	957	8899	2	2004-01-31
1	958	3685	3	2004-01-25
2	958	718	3	2004-01-25
3	958	731	1	2004-01-25
4	958	3968	3	2004-01-25
5	958	9636	2	2004-01-25
6	958	8900	3	2004-01-25
7	958	998	2	2004-01-25
1	959	715	3	2004-01-28
2	959	8178	3	2004-01-28
3	959	9294	3	2004-01-28
1	960	7417	3	2004-01-08
1	961	9331	3	2004-01-23
2	961	8685	1	2004-01-23
3	961	6943	3	2004-01-23
4	961	7806	2	2004-01-23
5	961	7344	3	2004-01-23
6	961	2007	2	2004-01-23
7	961	9147	2	2004-01-23
8	961	9272	3	2004-01-23
1	962	5954	1	2004-01-07
2	962	9716	3	2004-01-07
1	963	8233	2	2004-01-05
2	963	6624	3	2004-01-05
3	963	4927	2	2004-01-05
4	963	861	1	2004-01-05
5	963	3628	3	2004-01-05
6	963	7711	1	2004-01-05
7	963	7469	3	2004-01-05
8	963	7282	2	2004-01-05
1	964	4002	2	2004-01-14
2	964	7995	3	2004-01-14
3	964	5795	3	2004-01-14
4	964	7819	3	2004-01-14
5	964	4842	2	2004-01-14
6	964	5731	1	2004-01-14
1	965	7663	1	2004-01-04
2	965	7790	1	2004-01-04
3	965	163	2	2004-01-04
4	965	2261	3	2004-01-04
5	965	5219	3	2004-01-04
6	965	4248	3	2004-01-04
1	966	5582	2	2004-01-19
1	967	8493	2	2004-01-01
2	967	3076	2	2004-01-01
3	967	9551	2	2004-01-01
4	967	6579	1	2004-01-01
5	967	9992	2	2004-01-01
6	967	1684	3	2004-01-01
7	967	5531	1	2004-01-01
8	967	3283	3	2004-01-01
1	968	7962	2	2004-01-30
2	968	4450	2	2004-01-30
3	968	3526	1	2004-01-30
4	968	7820	2	2004-01-30
1	969	5933	2	2004-01-05
2	969	4124	2	2004-01-05
3	969	8595	1	2004-01-05
4	969	5670	3	2004-01-05
5	969	4942	3	2004-01-05
6	969	6368	1	2004-01-05
7	969	9201	3	2004-01-05
8	969	8264	3	2004-01-05
9	969	8151	2	2004-01-05
1	970	6	1	2004-01-08
2	970	6885	3	2004-01-08
3	970	6129	3	2004-01-08
4	970	7281	3	2004-01-08
5	970	8192	1	2004-01-08
6	970	2102	1	2004-01-08
7	970	8696	1	2004-01-08
1	971	1719	2	2004-01-10
2	971	8431	1	2004-01-10
3	971	5299	3	2004-01-10
4	971	9598	2	2004-01-10
5	971	2291	1	2004-01-10
6	971	9562	1	2004-01-10
7	971	8856	3	2004-01-10
8	971	3866	2	2004-01-10
1	972	7571	1	2004-01-23
2	972	7886	3	2004-01-23
3	972	4537	2	2004-01-23
4	972	368	3	2004-01-23
5	972	946	3	2004-01-23
1	973	3584	1	2004-01-18
2	973	638	1	2004-01-18
3	973	4045	1	2004-01-18
4	973	5184	2	2004-01-18
1	974	9778	1	2004-01-14
2	974	8102	2	2004-01-14
3	974	5238	2	2004-01-14
4	974	6031	1	2004-01-14
5	974	5345	1	2004-01-14
6	974	9704	2	2004-01-14
7	974	8121	1	2004-01-14
8	974	5361	2	2004-01-14
1	975	1254	3	2004-01-11
2	975	80	2	2004-01-11
3	975	1141	2	2004-01-11
4	975	8904	2	2004-01-11
5	975	9302	1	2004-01-11
6	975	3492	3	2004-01-11
7	975	2642	1	2004-01-11
1	976	1003	1	2004-01-09
2	976	9486	1	2004-01-09
3	976	8323	3	2004-01-09
4	976	1355	2	2004-01-09
5	976	1240	2	2004-01-09
6	976	4341	3	2004-01-09
7	976	1567	2	2004-01-09
8	976	7029	1	2004-01-09
9	976	893	3	2004-01-09
1	977	1874	3	2004-01-22
2	977	5289	2	2004-01-22
3	977	8636	3	2004-01-22
4	977	2395	2	2004-01-22
5	977	7095	2	2004-01-22
6	977	8511	2	2004-01-22
1	978	516	2	2004-01-13
2	978	127	2	2004-01-13
3	978	4241	1	2004-01-13
4	978	452	1	2004-01-13
5	978	3338	1	2004-01-13
1	979	6456	1	2004-01-30
2	979	32	1	2004-01-30
3	979	7529	3	2004-01-30
1	980	3321	1	2004-01-31
2	980	3597	3	2004-01-31
3	980	9911	3	2004-01-31
4	980	2882	1	2004-01-31
5	980	3209	1	2004-01-31
6	980	5283	3	2004-01-31
7	980	4701	2	2004-01-31
1	981	8284	3	2004-01-28
2	981	1144	2	2004-01-28
3	981	1232	1	2004-01-28
4	981	6484	3	2004-01-28
5	981	9841	2	2004-01-28
6	981	8684	2	2004-01-28
7	981	3420	1	2004-01-28
8	981	7485	3	2004-01-28
1	982	7822	3	2004-01-30
2	982	5317	1	2004-01-30
3	982	5456	1	2004-01-30
1	983	2328	2	2004-01-28
2	983	4134	2	2004-01-28
3	983	1078	2	2004-01-28
4	983	4645	3	2004-01-28
5	983	4126	2	2004-01-28
6	983	3965	1	2004-01-28
1	984	4401	2	2004-01-28
2	984	3774	3	2004-01-28
3	984	6550	1	2004-01-28
4	984	7207	1	2004-01-28
5	984	4699	1	2004-01-28
6	984	1883	2	2004-01-28
1	985	6275	2	2004-01-22
2	985	2634	3	2004-01-22
3	985	8953	3	2004-01-22
4	985	4913	1	2004-01-22
5	985	1764	3	2004-01-22
6	985	5888	1	2004-01-22
7	985	6262	1	2004-01-22
8	985	7035	1	2004-01-22
9	985	4941	1	2004-01-22
1	986	3356	3	2004-01-31
2	986	9731	2	2004-01-31
3	986	639	2	2004-01-31
4	986	5175	1	2004-01-31
5	986	5728	1	2004-01-31
6	986	3679	3	2004-01-31
7	986	8802	1	2004-01-31
1	987	2592	1	2004-01-18
2	987	8060	3	2004-01-18
3	987	2296	2	2004-01-18
4	987	9516	3	2004-01-18
5	987	5902	3	2004-01-18
6	987	8727	3	2004-01-18
7	987	6446	1	2004-01-18
1	988	2741	1	2004-01-17
2	988	6135	3	2004-01-17
3	988	3945	3	2004-01-17
4	988	6830	1	2004-01-17
5	988	2443	1	2004-01-17
6	988	6461	3	2004-01-17
1	989	7906	1	2004-01-31
2	989	3027	3	2004-01-31
3	989	9280	3	2004-01-31
4	989	6799	3	2004-01-31
5	989	7233	1	2004-01-31
6	989	88	1	2004-01-31
7	989	9420	3	2004-01-31
8	989	8681	1	2004-01-31
1	990	4627	3	2004-01-31
2	990	6595	3	2004-01-31
3	990	9928	1	2004-01-31
4	990	5222	3	2004-01-31
1	991	7012	1	2004-01-07
1	992	4297	3	2004-01-24
2	992	7476	2	2004-01-24
3	992	9557	3	2004-01-24
4	992	1792	3	2004-01-24
1	993	5543	3	2004-01-29
2	993	7143	1	2004-01-29
3	993	4747	3	2004-01-29
4	993	5193	3	2004-01-29
5	993	6870	3	2004-01-29
6	993	4936	2	2004-01-29
7	993	7312	1	2004-01-29
8	993	5360	2	2004-01-29
9	993	8239	2	2004-01-29
1	994	6919	1	2004-01-28
2	994	3348	3	2004-01-28
3	994	9758	1	2004-01-28
4	994	406	1	2004-01-28
5	994	2087	2	2004-01-28
6	994	485	3	2004-01-28
1	995	5199	1	2004-01-26
2	995	577	1	2004-01-26
3	995	7770	3	2004-01-26
1	996	8175	1	2004-01-07
1	997	1661	1	2004-01-09
2	997	8484	1	2004-01-09
3	997	3813	3	2004-01-09
4	997	4226	2	2004-01-09
5	997	4837	2	2004-01-09
6	997	5128	1	2004-01-09
7	997	9941	1	2004-01-09
8	997	6199	2	2004-01-09
9	997	4595	3	2004-01-09
1	998	5493	3	2004-01-17
2	998	7674	2	2004-01-17
3	998	8909	1	2004-01-17
4	998	3806	3	2004-01-17
5	998	301	2	2004-01-17
6	998	8381	3	2004-01-17
7	998	6884	1	2004-01-17
1	999	5820	1	2004-01-24
2	999	5431	2	2004-01-24
3	999	4647	1	2004-01-24
1	1000	1605	1	2004-01-03
2	1000	3527	3	2004-01-03
3	1000	367	1	2004-01-03
4	1000	764	3	2004-01-03
5	1000	1729	2	2004-01-03
6	1000	6246	1	2004-01-03
1	1001	4380	2	2004-02-07
2	1001	3538	1	2004-02-07
3	1001	2678	1	2004-02-07
4	1001	4440	1	2004-02-07
5	1001	1777	3	2004-02-07
6	1001	5667	2	2004-02-07
7	1001	2599	1	2004-02-07
8	1001	9182	3	2004-02-07
9	1001	8996	2	2004-02-07
1	1002	9276	1	2004-02-15
2	1002	1402	1	2004-02-15
3	1002	7382	2	2004-02-15
4	1002	594	1	2004-02-15
5	1002	2636	2	2004-02-15
6	1002	6816	2	2004-02-15
7	1002	7872	3	2004-02-15
8	1002	8425	1	2004-02-15
1	1003	5819	1	2004-02-28
2	1003	5462	2	2004-02-28
3	1003	2676	2	2004-02-28
4	1003	753	3	2004-02-28
5	1003	8979	2	2004-02-28
1	1004	9171	2	2004-02-17
2	1004	769	3	2004-02-17
3	1004	6597	2	2004-02-17
4	1004	4738	2	2004-02-17
5	1004	9576	1	2004-02-17
6	1004	2906	3	2004-02-17
7	1004	4920	1	2004-02-17
1	1005	7971	2	2004-02-23
2	1005	9020	1	2004-02-23
3	1005	8072	3	2004-02-23
4	1005	8465	3	2004-02-23
1	1006	1426	2	2004-02-13
2	1006	6997	1	2004-02-13
1	1007	7006	2	2004-02-12
2	1007	1585	3	2004-02-12
3	1007	3173	2	2004-02-12
4	1007	2607	1	2004-02-12
5	1007	1651	1	2004-02-12
6	1007	5394	3	2004-02-12
7	1007	4376	2	2004-02-12
8	1007	268	1	2004-02-12
9	1007	4186	3	2004-02-12
1	1008	711	2	2004-02-27
2	1008	9275	3	2004-02-27
3	1008	6596	2	2004-02-27
4	1008	1300	1	2004-02-27
5	1008	2490	3	2004-02-27
1	1009	579	1	2004-02-21
1	1010	1851	2	2004-02-06
2	1010	1719	1	2004-02-06
3	1010	8405	2	2004-02-06
4	1010	851	3	2004-02-06
5	1010	4568	2	2004-02-06
6	1010	2702	2	2004-02-06
7	1010	8229	1	2004-02-06
1	1011	7017	3	2004-02-09
2	1011	2589	2	2004-02-09
3	1011	2054	1	2004-02-09
4	1011	4919	1	2004-02-09
1	1012	4136	3	2004-02-05
2	1012	9165	2	2004-02-05
3	1012	8830	3	2004-02-05
1	1013	3507	3	2004-02-05
2	1013	1605	1	2004-02-05
3	1013	147	2	2004-02-05
4	1013	6560	2	2004-02-05
5	1013	8873	2	2004-02-05
6	1013	3616	1	2004-02-05
1	1014	8302	2	2004-02-23
2	1014	9706	1	2004-02-23
3	1014	7096	2	2004-02-23
1	1015	3828	1	2004-02-28
2	1015	8383	3	2004-02-28
3	1015	7780	1	2004-02-28
4	1015	7467	3	2004-02-28
5	1015	3624	3	2004-02-28
6	1015	3973	1	2004-02-28
7	1015	3250	1	2004-02-28
8	1015	3760	3	2004-02-28
1	1016	4592	1	2004-02-13
2	1016	458	2	2004-02-13
3	1016	4000	3	2004-02-13
4	1016	8139	2	2004-02-13
5	1016	3813	3	2004-02-13
6	1016	2577	3	2004-02-13
1	1017	2848	2	2004-02-27
2	1017	6450	2	2004-02-27
3	1017	2017	1	2004-02-27
4	1017	6655	2	2004-02-27
5	1017	3268	1	2004-02-27
6	1017	2133	3	2004-02-27
7	1017	2130	2	2004-02-27
1	1018	1019	3	2004-02-12
2	1018	2154	3	2004-02-12
3	1018	3377	2	2004-02-12
4	1018	6991	2	2004-02-12
5	1018	3605	2	2004-02-12
1	1019	4944	3	2004-02-20
2	1019	6230	3	2004-02-20
3	1019	216	1	2004-02-20
4	1019	2227	2	2004-02-20
5	1019	3297	2	2004-02-20
6	1019	1056	2	2004-02-20
7	1019	9026	2	2004-02-20
8	1019	2148	2	2004-02-20
9	1019	9799	1	2004-02-20
1	1020	7918	3	2004-02-12
2	1020	3362	1	2004-02-12
3	1020	5591	1	2004-02-12
4	1020	2064	3	2004-02-12
5	1020	31	3	2004-02-12
6	1020	8726	2	2004-02-12
7	1020	3968	3	2004-02-12
1	1021	553	2	2004-02-26
2	1021	7866	3	2004-02-26
3	1021	8678	1	2004-02-26
1	1022	429	2	2004-02-12
2	1022	5550	3	2004-02-12
3	1022	4818	3	2004-02-12
4	1022	9868	1	2004-02-12
5	1022	9183	1	2004-02-12
6	1022	9341	3	2004-02-12
7	1022	8939	3	2004-02-12
8	1022	5473	1	2004-02-12
1	1023	7055	3	2004-02-20
2	1023	2909	2	2004-02-20
3	1023	9232	1	2004-02-20
4	1023	4935	2	2004-02-20
5	1023	63	3	2004-02-20
6	1023	1480	1	2004-02-20
7	1023	3619	3	2004-02-20
8	1023	8836	3	2004-02-20
9	1023	5939	3	2004-02-20
1	1024	4335	3	2004-02-25
2	1024	6250	3	2004-02-25
3	1024	2479	1	2004-02-25
4	1024	4423	1	2004-02-25
5	1024	2687	1	2004-02-25
6	1024	1232	2	2004-02-25
7	1024	6398	1	2004-02-25
8	1024	7181	1	2004-02-25
1	1025	7734	1	2004-02-11
2	1025	2310	2	2004-02-11
3	1025	1503	3	2004-02-11
4	1025	5273	1	2004-02-11
5	1025	3371	2	2004-02-11
1	1026	7512	3	2004-02-24
2	1026	8037	1	2004-02-24
3	1026	9538	1	2004-02-24
4	1026	3411	1	2004-02-24
5	1026	6318	3	2004-02-24
1	1027	742	1	2004-02-04
2	1027	316	3	2004-02-04
3	1027	3654	1	2004-02-04
4	1027	5044	2	2004-02-04
5	1027	875	1	2004-02-04
1	1028	1949	1	2004-02-16
2	1028	8813	3	2004-02-16
3	1028	9660	3	2004-02-16
4	1028	1394	3	2004-02-16
1	1029	4612	1	2004-02-22
2	1029	7387	2	2004-02-22
3	1029	6234	3	2004-02-22
4	1029	6340	2	2004-02-22
1	1030	5150	1	2004-02-19
2	1030	1961	1	2004-02-19
1	1031	9885	2	2004-02-13
2	1031	5703	3	2004-02-13
3	1031	345	3	2004-02-13
4	1031	8742	3	2004-02-13
5	1031	1900	3	2004-02-13
6	1031	1804	2	2004-02-13
1	1032	7318	3	2004-02-28
2	1032	2689	2	2004-02-28
3	1032	8596	1	2004-02-28
4	1032	5565	2	2004-02-28
5	1032	1913	3	2004-02-28
6	1032	4397	2	2004-02-28
1	1033	2577	3	2004-02-16
2	1033	5137	1	2004-02-16
3	1033	5246	2	2004-02-16
4	1033	837	3	2004-02-16
5	1033	2585	1	2004-02-16
6	1033	3657	1	2004-02-16
1	1034	4524	1	2004-02-06
2	1034	3066	1	2004-02-06
3	1034	3182	3	2004-02-06
4	1034	6865	2	2004-02-06
5	1034	6155	1	2004-02-06
6	1034	1299	1	2004-02-06
7	1034	342	2	2004-02-06
8	1034	7455	1	2004-02-06
9	1034	1896	1	2004-02-06
1	1035	4286	3	2004-02-17
2	1035	9314	3	2004-02-17
3	1035	1543	1	2004-02-17
4	1035	3863	1	2004-02-17
5	1035	290	3	2004-02-17
6	1035	1491	2	2004-02-17
7	1035	1505	2	2004-02-17
1	1036	9630	1	2004-02-06
2	1036	2	3	2004-02-06
3	1036	4811	3	2004-02-06
4	1036	2889	3	2004-02-06
5	1036	46	3	2004-02-06
6	1036	3848	2	2004-02-06
7	1036	5401	3	2004-02-06
8	1036	5565	2	2004-02-06
1	1037	7279	2	2004-02-18
2	1037	8324	3	2004-02-18
3	1037	9503	3	2004-02-18
4	1037	3442	1	2004-02-18
5	1037	8197	1	2004-02-18
6	1037	9627	3	2004-02-18
7	1037	4272	3	2004-02-18
8	1037	7797	3	2004-02-18
9	1037	7083	1	2004-02-18
1	1038	3641	2	2004-02-17
2	1038	7769	3	2004-02-17
3	1038	9527	2	2004-02-17
4	1038	6312	2	2004-02-17
5	1038	3782	2	2004-02-17
6	1038	1532	1	2004-02-17
7	1038	2360	1	2004-02-17
8	1038	1933	2	2004-02-17
9	1038	2522	1	2004-02-17
1	1039	1775	2	2004-02-26
2	1039	2363	3	2004-02-26
3	1039	6437	3	2004-02-26
1	1040	660	2	2004-02-17
2	1040	8830	1	2004-02-17
3	1040	9400	2	2004-02-17
4	1040	5570	1	2004-02-17
5	1040	8731	3	2004-02-17
6	1040	5286	1	2004-02-17
7	1040	8135	3	2004-02-17
8	1040	6891	1	2004-02-17
9	1040	7347	2	2004-02-17
1	1041	1054	1	2004-02-08
2	1041	3436	3	2004-02-08
3	1041	9691	3	2004-02-08
4	1041	3338	3	2004-02-08
5	1041	9046	2	2004-02-08
1	1042	3016	3	2004-02-09
2	1042	5613	1	2004-02-09
3	1042	6852	1	2004-02-09
1	1043	5643	2	2004-02-08
2	1043	5625	3	2004-02-08
3	1043	764	2	2004-02-08
4	1043	3026	1	2004-02-08
5	1043	6343	2	2004-02-08
6	1043	9308	2	2004-02-08
7	1043	5882	1	2004-02-08
8	1043	3511	2	2004-02-08
9	1043	6643	2	2004-02-08
1	1044	575	2	2004-02-08
2	1044	7565	3	2004-02-08
3	1044	5486	1	2004-02-08
4	1044	2413	2	2004-02-08
5	1044	127	3	2004-02-08
6	1044	9064	2	2004-02-08
1	1045	1645	3	2004-02-19
2	1045	5989	1	2004-02-19
3	1045	2930	1	2004-02-19
4	1045	3598	2	2004-02-19
5	1045	6798	1	2004-02-19
6	1045	2983	3	2004-02-19
7	1045	1064	1	2004-02-19
8	1045	5419	1	2004-02-19
9	1045	6546	1	2004-02-19
1	1046	5632	2	2004-02-26
2	1046	9534	2	2004-02-26
1	1047	5562	2	2004-02-26
2	1047	6711	1	2004-02-26
3	1047	7119	3	2004-02-26
4	1047	3420	1	2004-02-26
5	1047	6080	1	2004-02-26
6	1047	955	3	2004-02-26
7	1047	9818	1	2004-02-26
8	1047	1020	2	2004-02-26
9	1047	3657	3	2004-02-26
1	1048	4199	2	2004-02-24
2	1048	5112	2	2004-02-24
1	1049	4187	2	2004-02-28
2	1049	610	1	2004-02-28
3	1049	6879	3	2004-02-28
4	1049	537	1	2004-02-28
1	1050	5678	1	2004-02-24
2	1050	1416	3	2004-02-24
3	1050	5568	2	2004-02-24
4	1050	4263	2	2004-02-24
5	1050	7793	2	2004-02-24
6	1050	5388	1	2004-02-24
7	1050	9086	1	2004-02-24
8	1050	5723	3	2004-02-24
9	1050	4871	2	2004-02-24
1	1051	9955	3	2004-02-10
2	1051	1789	1	2004-02-10
3	1051	7995	1	2004-02-10
4	1051	7108	3	2004-02-10
1	1052	9483	2	2004-02-27
1	1053	7603	2	2004-02-18
2	1053	5902	3	2004-02-18
3	1053	4083	1	2004-02-18
4	1053	5696	3	2004-02-18
1	1054	3208	3	2004-02-20
2	1054	5627	2	2004-02-20
3	1054	8456	2	2004-02-20
4	1054	5228	2	2004-02-20
5	1054	2131	2	2004-02-20
6	1054	8348	1	2004-02-20
7	1054	5902	3	2004-02-20
8	1054	5383	1	2004-02-20
1	1055	7162	1	2004-02-05
2	1055	5867	1	2004-02-05
3	1055	3454	1	2004-02-05
4	1055	198	1	2004-02-05
5	1055	710	3	2004-02-05
6	1055	8498	2	2004-02-05
7	1055	6174	2	2004-02-05
8	1055	8913	2	2004-02-05
9	1055	7745	2	2004-02-05
1	1056	848	2	2004-02-01
2	1056	6370	2	2004-02-01
3	1056	6918	3	2004-02-01
4	1056	9808	1	2004-02-01
5	1056	7124	3	2004-02-01
6	1056	4676	1	2004-02-01
7	1056	8214	3	2004-02-01
8	1056	4552	3	2004-02-01
1	1057	9178	1	2004-02-25
2	1057	1318	3	2004-02-25
3	1057	7422	3	2004-02-25
4	1057	2231	3	2004-02-25
5	1057	8938	1	2004-02-25
6	1057	6154	3	2004-02-25
7	1057	6127	1	2004-02-25
1	1058	5891	3	2004-02-17
2	1058	2791	1	2004-02-17
3	1058	581	1	2004-02-17
4	1058	8696	2	2004-02-17
5	1058	9417	3	2004-02-17
6	1058	394	2	2004-02-17
1	1059	7662	2	2004-02-13
2	1059	4964	3	2004-02-13
3	1059	3864	2	2004-02-13
4	1059	1120	1	2004-02-13
5	1059	3685	3	2004-02-13
6	1059	2541	3	2004-02-13
1	1060	600	3	2004-02-01
2	1060	6747	1	2004-02-01
3	1060	9316	2	2004-02-01
4	1060	6314	3	2004-02-01
5	1060	2834	3	2004-02-01
6	1060	4768	3	2004-02-01
1	1061	9846	3	2004-02-18
2	1061	3830	2	2004-02-18
3	1061	2182	2	2004-02-18
4	1061	3727	2	2004-02-18
1	1062	9276	1	2004-02-07
2	1062	8666	3	2004-02-07
3	1062	9396	2	2004-02-07
1	1063	7443	2	2004-02-03
2	1063	4076	1	2004-02-03
3	1063	1106	1	2004-02-03
4	1063	5806	2	2004-02-03
5	1063	4292	2	2004-02-03
6	1063	2706	3	2004-02-03
7	1063	9361	2	2004-02-03
1	1064	9355	2	2004-02-09
2	1064	7750	3	2004-02-09
3	1064	7404	2	2004-02-09
4	1064	8506	3	2004-02-09
5	1064	1829	3	2004-02-09
1	1065	6372	1	2004-02-16
2	1065	5162	3	2004-02-16
3	1065	1359	1	2004-02-16
1	1066	3771	2	2004-02-06
2	1066	9495	3	2004-02-06
3	1066	9066	1	2004-02-06
4	1066	2106	3	2004-02-06
5	1066	6568	3	2004-02-06
1	1067	769	3	2004-02-20
2	1067	5118	2	2004-02-20
3	1067	783	1	2004-02-20
4	1067	9231	3	2004-02-20
5	1067	3053	2	2004-02-20
6	1067	4631	2	2004-02-20
1	1068	1139	2	2004-02-16
2	1068	7954	1	2004-02-16
1	1069	5441	3	2004-02-02
2	1069	2631	1	2004-02-02
3	1069	1420	3	2004-02-02
1	1070	8467	3	2004-02-23
2	1070	5212	3	2004-02-23
3	1070	4937	3	2004-02-23
1	1071	6099	1	2004-02-06
2	1071	9422	3	2004-02-06
3	1071	6568	3	2004-02-06
4	1071	7871	3	2004-02-06
5	1071	4395	3	2004-02-06
6	1071	14	3	2004-02-06
7	1071	6202	1	2004-02-06
1	1072	9810	3	2004-02-07
1	1073	5974	1	2004-02-10
2	1073	7013	3	2004-02-10
3	1073	835	3	2004-02-10
4	1073	5508	3	2004-02-10
5	1073	2426	2	2004-02-10
6	1073	4170	3	2004-02-10
7	1073	2304	1	2004-02-10
8	1073	6231	3	2004-02-10
1	1074	8890	3	2004-02-03
2	1074	4616	1	2004-02-03
3	1074	9230	2	2004-02-03
4	1074	8984	1	2004-02-03
5	1074	2701	2	2004-02-03
6	1074	1515	3	2004-02-03
7	1074	6581	3	2004-02-03
1	1075	4348	1	2004-02-19
2	1075	7172	3	2004-02-19
3	1075	9634	3	2004-02-19
1	1076	2109	1	2004-02-02
2	1076	8345	1	2004-02-02
1	1077	7385	1	2004-02-05
1	1078	8760	1	2004-02-10
2	1078	3597	2	2004-02-10
3	1078	9727	1	2004-02-10
4	1078	7738	2	2004-02-10
5	1078	2455	2	2004-02-10
1	1079	7953	1	2004-02-08
2	1079	4499	1	2004-02-08
3	1079	3259	1	2004-02-08
1	1080	5609	1	2004-02-03
2	1080	2909	3	2004-02-03
3	1080	3274	3	2004-02-03
1	1081	7528	1	2004-02-12
2	1081	9644	2	2004-02-12
3	1081	4750	1	2004-02-12
4	1081	175	3	2004-02-12
5	1081	4187	2	2004-02-12
6	1081	489	1	2004-02-12
7	1081	5114	2	2004-02-12
8	1081	2199	3	2004-02-12
1	1082	5749	3	2004-02-22
2	1082	6822	3	2004-02-22
3	1082	7963	1	2004-02-22
4	1082	7296	1	2004-02-22
1	1083	8922	3	2004-02-06
2	1083	4921	2	2004-02-06
3	1083	1769	2	2004-02-06
4	1083	1012	2	2004-02-06
5	1083	9654	1	2004-02-06
6	1083	8094	2	2004-02-06
7	1083	6487	1	2004-02-06
8	1083	3139	2	2004-02-06
9	1083	3549	2	2004-02-06
1	1084	7954	1	2004-02-23
2	1084	4867	2	2004-02-23
3	1084	5287	3	2004-02-23
4	1084	3494	2	2004-02-23
5	1084	6650	1	2004-02-23
1	1085	6666	3	2004-02-14
2	1085	2708	2	2004-02-14
3	1085	8597	1	2004-02-14
4	1085	1086	2	2004-02-14
5	1085	1093	2	2004-02-14
6	1085	9401	2	2004-02-14
7	1085	552	3	2004-02-14
1	1086	8770	3	2004-02-12
2	1086	7141	2	2004-02-12
1	1087	3050	2	2004-02-12
1	1088	6233	2	2004-02-07
2	1088	5190	2	2004-02-07
3	1088	4614	2	2004-02-07
4	1088	9913	2	2004-02-07
5	1088	499	3	2004-02-07
6	1088	348	1	2004-02-07
7	1088	6664	2	2004-02-07
8	1088	6730	3	2004-02-07
1	1089	9555	3	2004-02-18
2	1089	3953	3	2004-02-18
3	1089	396	3	2004-02-18
1	1090	1472	1	2004-02-10
2	1090	8195	2	2004-02-10
3	1090	7200	1	2004-02-10
4	1090	2936	3	2004-02-10
1	1091	4485	1	2004-02-24
2	1091	3149	1	2004-02-24
3	1091	1875	3	2004-02-24
4	1091	6713	3	2004-02-24
5	1091	2645	2	2004-02-24
6	1091	7413	2	2004-02-24
7	1091	5191	3	2004-02-24
8	1091	3600	3	2004-02-24
1	1092	2107	1	2004-02-02
2	1092	8542	3	2004-02-02
1	1093	4911	1	2004-02-11
2	1093	1229	3	2004-02-11
3	1093	5929	2	2004-02-11
1	1094	5454	2	2004-02-02
2	1094	3589	1	2004-02-02
3	1094	2946	3	2004-02-02
4	1094	676	2	2004-02-02
5	1094	7246	1	2004-02-02
6	1094	6282	1	2004-02-02
7	1094	2966	3	2004-02-02
1	1095	2984	2	2004-02-04
2	1095	7353	3	2004-02-04
3	1095	6951	3	2004-02-04
4	1095	7290	1	2004-02-04
5	1095	2958	3	2004-02-04
1	1096	3011	3	2004-02-02
2	1096	9003	2	2004-02-02
3	1096	7589	3	2004-02-02
4	1096	2502	2	2004-02-02
5	1096	763	3	2004-02-02
6	1096	4928	2	2004-02-02
1	1097	1049	3	2004-02-21
2	1097	8974	3	2004-02-21
3	1097	6113	2	2004-02-21
4	1097	6982	2	2004-02-21
5	1097	8804	3	2004-02-21
1	1098	5622	3	2004-02-04
2	1098	5333	2	2004-02-04
3	1098	5569	1	2004-02-04
4	1098	4302	3	2004-02-04
5	1098	7756	2	2004-02-04
6	1098	6852	1	2004-02-04
1	1099	8886	3	2004-02-25
2	1099	2244	3	2004-02-25
3	1099	8195	3	2004-02-25
4	1099	3784	2	2004-02-25
1	1100	2073	1	2004-02-05
2	1100	9583	3	2004-02-05
3	1100	1330	2	2004-02-05
1	1101	4967	2	2004-02-07
2	1101	1682	1	2004-02-07
3	1101	8275	1	2004-02-07
4	1101	5841	3	2004-02-07
5	1101	4499	2	2004-02-07
6	1101	6813	3	2004-02-07
1	1102	185	3	2004-02-08
2	1102	8955	2	2004-02-08
3	1102	9917	1	2004-02-08
4	1102	7019	3	2004-02-08
5	1102	8721	3	2004-02-08
6	1102	4416	1	2004-02-08
1	1103	7845	3	2004-02-15
1	1104	3138	2	2004-02-06
2	1104	2598	3	2004-02-06
3	1104	1053	2	2004-02-06
4	1104	4959	2	2004-02-06
5	1104	1549	2	2004-02-06
6	1104	3007	1	2004-02-06
7	1104	444	1	2004-02-06
8	1104	1530	3	2004-02-06
1	1105	1289	1	2004-02-07
2	1105	9092	3	2004-02-07
3	1105	1271	3	2004-02-07
4	1105	8285	1	2004-02-07
5	1105	3054	3	2004-02-07
6	1105	1175	2	2004-02-07
7	1105	2408	2	2004-02-07
1	1106	9611	1	2004-02-18
1	1107	5541	1	2004-02-18
2	1107	4149	3	2004-02-18
3	1107	2785	3	2004-02-18
4	1107	4804	2	2004-02-18
5	1107	1017	2	2004-02-18
6	1107	3020	1	2004-02-18
7	1107	830	1	2004-02-18
1	1108	74	1	2004-02-16
2	1108	536	2	2004-02-16
3	1108	5269	3	2004-02-16
4	1108	7315	2	2004-02-16
5	1108	9991	2	2004-02-16
6	1108	7496	1	2004-02-16
7	1108	242	1	2004-02-16
1	1109	4350	2	2004-02-10
2	1109	388	2	2004-02-10
3	1109	9698	2	2004-02-10
4	1109	7654	1	2004-02-10
5	1109	4712	1	2004-02-10
6	1109	4411	2	2004-02-10
1	1110	699	1	2004-02-01
1	1111	1569	2	2004-02-01
1	1112	6201	3	2004-02-03
2	1112	863	1	2004-02-03
3	1112	3403	1	2004-02-03
4	1112	5917	1	2004-02-03
5	1112	4658	2	2004-02-03
1	1113	3481	3	2004-02-11
2	1113	2522	3	2004-02-11
3	1113	7366	1	2004-02-11
4	1113	590	3	2004-02-11
5	1113	1233	2	2004-02-11
6	1113	7422	1	2004-02-11
7	1113	219	3	2004-02-11
8	1113	4611	3	2004-02-11
1	1114	1362	3	2004-02-09
2	1114	5101	3	2004-02-09
3	1114	919	3	2004-02-09
4	1114	850	2	2004-02-09
1	1115	4486	2	2004-02-26
2	1115	2008	1	2004-02-26
3	1115	8326	1	2004-02-26
1	1116	2359	3	2004-02-26
2	1116	5111	3	2004-02-26
3	1116	6290	3	2004-02-26
4	1116	7781	1	2004-02-26
5	1116	1949	3	2004-02-26
6	1116	8525	3	2004-02-26
7	1116	6421	3	2004-02-26
1	1117	4934	2	2004-02-20
2	1117	8541	3	2004-02-20
3	1117	1681	1	2004-02-20
4	1117	1271	1	2004-02-20
5	1117	3145	1	2004-02-20
6	1117	9564	1	2004-02-20
1	1118	8891	3	2004-02-21
2	1118	398	3	2004-02-21
3	1118	8866	1	2004-02-21
1	1119	6834	2	2004-02-17
2	1119	9505	1	2004-02-17
3	1119	2138	2	2004-02-17
1	1120	1226	2	2004-02-21
2	1120	9084	2	2004-02-21
3	1120	5648	3	2004-02-21
4	1120	6767	1	2004-02-21
5	1120	568	3	2004-02-21
6	1120	5137	3	2004-02-21
7	1120	6797	2	2004-02-21
8	1120	6129	2	2004-02-21
9	1120	7882	1	2004-02-21
1	1121	3481	2	2004-02-09
2	1121	709	2	2004-02-09
3	1121	8119	3	2004-02-09
4	1121	6296	1	2004-02-09
5	1121	7184	3	2004-02-09
6	1121	7104	2	2004-02-09
7	1121	1891	1	2004-02-09
8	1121	4914	3	2004-02-09
9	1121	5588	2	2004-02-09
1	1122	6259	1	2004-02-21
2	1122	9752	2	2004-02-21
3	1122	3010	1	2004-02-21
4	1122	1418	3	2004-02-21
1	1123	517	3	2004-02-08
2	1123	1504	3	2004-02-08
3	1123	961	3	2004-02-08
4	1123	4334	3	2004-02-08
1	1124	4881	2	2004-02-14
2	1124	5348	1	2004-02-14
3	1124	7125	1	2004-02-14
4	1124	6265	2	2004-02-14
5	1124	1355	2	2004-02-14
6	1124	7524	2	2004-02-14
7	1124	8820	3	2004-02-14
8	1124	1550	1	2004-02-14
9	1124	3840	1	2004-02-14
1	1125	1169	1	2004-02-14
2	1125	5096	2	2004-02-14
3	1125	426	1	2004-02-14
4	1125	1725	1	2004-02-14
5	1125	9917	2	2004-02-14
6	1125	7641	2	2004-02-14
1	1126	8149	3	2004-02-25
2	1126	1059	2	2004-02-25
3	1126	1269	3	2004-02-25
4	1126	4614	1	2004-02-25
5	1126	1387	3	2004-02-25
1	1127	2702	2	2004-02-15
2	1127	8999	3	2004-02-15
3	1127	9478	3	2004-02-15
4	1127	7847	1	2004-02-15
5	1127	664	3	2004-02-15
6	1127	7808	3	2004-02-15
1	1128	1629	1	2004-02-09
2	1128	5482	1	2004-02-09
3	1128	6890	3	2004-02-09
4	1128	2566	1	2004-02-09
5	1128	9568	2	2004-02-09
6	1128	9956	2	2004-02-09
7	1128	245	1	2004-02-09
8	1128	1439	1	2004-02-09
1	1129	9862	3	2004-02-19
2	1129	7422	1	2004-02-19
3	1129	6353	2	2004-02-19
4	1129	8829	3	2004-02-19
5	1129	1815	1	2004-02-19
6	1129	7956	2	2004-02-19
1	1130	187	3	2004-02-09
1	1131	4556	1	2004-02-05
2	1131	4228	2	2004-02-05
1	1132	7188	2	2004-02-17
2	1132	5173	2	2004-02-17
3	1132	6818	1	2004-02-17
4	1132	9838	2	2004-02-17
5	1132	904	1	2004-02-17
6	1132	7544	3	2004-02-17
1	1133	663	1	2004-02-15
2	1133	9921	1	2004-02-15
1	1134	5463	3	2004-02-07
2	1134	2786	1	2004-02-07
3	1134	8830	3	2004-02-07
4	1134	7885	2	2004-02-07
5	1134	5510	1	2004-02-07
6	1134	626	1	2004-02-07
7	1134	4582	1	2004-02-07
1	1135	4344	3	2004-02-23
2	1135	6174	2	2004-02-23
3	1135	8433	3	2004-02-23
4	1135	9121	3	2004-02-23
5	1135	9006	1	2004-02-23
1	1136	501	1	2004-02-03
2	1136	7687	3	2004-02-03
3	1136	149	2	2004-02-03
4	1136	5347	2	2004-02-03
5	1136	8629	2	2004-02-03
6	1136	7986	1	2004-02-03
1	1137	1474	1	2004-02-19
2	1137	5758	3	2004-02-19
3	1137	9678	2	2004-02-19
4	1137	4484	3	2004-02-19
5	1137	2545	2	2004-02-19
6	1137	154	2	2004-02-19
7	1137	6129	3	2004-02-19
8	1137	9851	2	2004-02-19
1	1138	3109	1	2004-02-26
2	1138	5039	1	2004-02-26
3	1138	7279	1	2004-02-26
4	1138	4947	2	2004-02-26
5	1138	8982	2	2004-02-26
6	1138	2263	1	2004-02-26
7	1138	6680	3	2004-02-26
8	1138	8103	2	2004-02-26
9	1138	2212	1	2004-02-26
1	1139	8222	1	2004-02-15
2	1139	3609	3	2004-02-15
3	1139	8833	1	2004-02-15
4	1139	5610	2	2004-02-15
5	1139	2222	3	2004-02-15
1	1140	285	2	2004-02-18
2	1140	7089	3	2004-02-18
3	1140	9044	3	2004-02-18
4	1140	9722	2	2004-02-18
1	1141	411	3	2004-02-21
2	1141	4338	2	2004-02-21
3	1141	2544	1	2004-02-21
4	1141	8690	2	2004-02-21
5	1141	632	3	2004-02-21
6	1141	8994	2	2004-02-21
7	1141	2315	1	2004-02-21
8	1141	4960	3	2004-02-21
9	1141	8475	2	2004-02-21
1	1142	8025	3	2004-02-06
2	1142	8226	3	2004-02-06
3	1142	5582	2	2004-02-06
4	1142	5570	3	2004-02-06
5	1142	5180	2	2004-02-06
6	1142	4898	3	2004-02-06
7	1142	2465	3	2004-02-06
8	1142	2077	1	2004-02-06
1	1143	8950	1	2004-02-11
2	1143	3802	2	2004-02-11
3	1143	9403	1	2004-02-11
1	1144	63	3	2004-02-27
1	1145	3886	1	2004-02-28
2	1145	3243	3	2004-02-28
3	1145	8354	3	2004-02-28
4	1145	8583	1	2004-02-28
5	1145	5582	1	2004-02-28
6	1145	1973	3	2004-02-28
1	1146	1641	2	2004-02-10
2	1146	6227	1	2004-02-10
3	1146	7840	2	2004-02-10
1	1147	7935	2	2004-02-07
2	1147	582	2	2004-02-07
3	1147	1268	2	2004-02-07
1	1148	2650	1	2004-02-20
2	1148	6285	3	2004-02-20
3	1148	2775	3	2004-02-20
4	1148	7406	2	2004-02-20
5	1148	8907	3	2004-02-20
1	1149	1591	1	2004-02-24
2	1149	236	2	2004-02-24
3	1149	1447	2	2004-02-24
4	1149	6115	3	2004-02-24
5	1149	1612	3	2004-02-24
1	1150	7389	2	2004-02-12
2	1150	6700	1	2004-02-12
1	1151	1243	2	2004-02-20
2	1151	5728	1	2004-02-20
3	1151	4842	2	2004-02-20
4	1151	697	3	2004-02-20
5	1151	8873	1	2004-02-20
6	1151	2145	3	2004-02-20
7	1151	6108	2	2004-02-20
8	1151	5033	1	2004-02-20
9	1151	2972	2	2004-02-20
1	1152	8325	3	2004-02-25
1	1153	8010	2	2004-02-14
2	1153	1175	3	2004-02-14
1	1154	1089	1	2004-02-03
2	1154	5305	3	2004-02-03
3	1154	2384	3	2004-02-03
4	1154	9069	3	2004-02-03
5	1154	1040	2	2004-02-03
6	1154	713	2	2004-02-03
1	1155	9713	3	2004-02-03
1	1156	6080	1	2004-02-21
2	1156	9345	3	2004-02-21
3	1156	1715	1	2004-02-21
4	1156	4157	1	2004-02-21
1	1157	5207	2	2004-02-17
2	1157	8719	2	2004-02-17
1	1158	3770	3	2004-02-06
2	1158	2431	2	2004-02-06
3	1158	9391	1	2004-02-06
1	1159	697	1	2004-02-13
2	1159	1218	1	2004-02-13
3	1159	9967	1	2004-02-13
4	1159	275	2	2004-02-13
5	1159	4047	2	2004-02-13
6	1159	9369	2	2004-02-13
7	1159	7511	2	2004-02-13
8	1159	8855	2	2004-02-13
1	1160	3741	3	2004-02-25
2	1160	6351	2	2004-02-25
3	1160	4631	2	2004-02-25
4	1160	8314	3	2004-02-25
5	1160	2310	2	2004-02-25
6	1160	7687	1	2004-02-25
7	1160	7659	3	2004-02-25
1	1161	1749	2	2004-02-09
2	1161	9563	1	2004-02-09
3	1161	1142	3	2004-02-09
1	1162	938	3	2004-02-16
2	1162	1773	2	2004-02-16
3	1162	9045	3	2004-02-16
4	1162	850	2	2004-02-16
5	1162	3863	3	2004-02-16
1	1163	9178	1	2004-02-08
1	1164	5547	1	2004-02-26
1	1165	2182	3	2004-02-20
2	1165	8055	2	2004-02-20
3	1165	2496	3	2004-02-20
4	1165	4771	2	2004-02-20
5	1165	3670	2	2004-02-20
6	1165	2391	2	2004-02-20
7	1165	7491	2	2004-02-20
8	1165	3683	1	2004-02-20
1	1166	9559	3	2004-02-07
2	1166	3828	3	2004-02-07
1	1167	4485	1	2004-02-02
2	1167	5598	2	2004-02-02
3	1167	303	2	2004-02-02
4	1167	2149	1	2004-02-02
5	1167	2644	3	2004-02-02
6	1167	7067	2	2004-02-02
7	1167	735	3	2004-02-02
1	1168	8323	3	2004-02-03
2	1168	2306	3	2004-02-03
3	1168	9738	1	2004-02-03
4	1168	8302	2	2004-02-03
5	1168	816	3	2004-02-03
1	1169	3259	1	2004-02-09
2	1169	4091	2	2004-02-09
3	1169	5713	2	2004-02-09
4	1169	6359	3	2004-02-09
5	1169	3158	2	2004-02-09
6	1169	4669	2	2004-02-09
7	1169	2882	2	2004-02-09
1	1170	6727	1	2004-02-06
1	1171	31	2	2004-02-26
2	1171	6379	1	2004-02-26
3	1171	5908	1	2004-02-26
4	1171	395	3	2004-02-26
5	1171	4903	2	2004-02-26
6	1171	2727	1	2004-02-26
7	1171	724	3	2004-02-26
1	1172	7775	2	2004-02-26
2	1172	9139	3	2004-02-26
3	1172	3983	3	2004-02-26
4	1172	333	1	2004-02-26
1	1173	6941	3	2004-02-05
2	1173	660	1	2004-02-05
3	1173	175	2	2004-02-05
4	1173	6162	1	2004-02-05
5	1173	5733	1	2004-02-05
6	1173	5055	3	2004-02-05
1	1174	9660	1	2004-02-05
1	1175	7326	3	2004-02-13
2	1175	2579	3	2004-02-13
3	1175	136	2	2004-02-13
4	1175	7144	3	2004-02-13
1	1176	7404	2	2004-02-28
1	1177	4630	1	2004-02-20
2	1177	1131	2	2004-02-20
3	1177	6092	3	2004-02-20
1	1178	3185	2	2004-02-20
2	1178	4667	1	2004-02-20
1	1179	1299	2	2004-02-11
2	1179	1039	1	2004-02-11
3	1179	9397	2	2004-02-11
4	1179	1382	3	2004-02-11
1	1180	992	2	2004-02-01
2	1180	5814	1	2004-02-01
3	1180	1304	1	2004-02-01
4	1180	795	3	2004-02-01
5	1180	7655	3	2004-02-01
1	1181	1350	3	2004-02-27
2	1181	1413	3	2004-02-27
3	1181	1013	1	2004-02-27
4	1181	4831	1	2004-02-27
1	1182	1028	3	2004-02-11
2	1182	3423	1	2004-02-11
3	1182	3347	2	2004-02-11
4	1182	6390	3	2004-02-11
5	1182	6536	3	2004-02-11
1	1183	6851	2	2004-02-03
2	1183	9559	1	2004-02-03
3	1183	9621	1	2004-02-03
4	1183	7823	1	2004-02-03
5	1183	426	3	2004-02-03
6	1183	3744	2	2004-02-03
7	1183	888	3	2004-02-03
8	1183	9484	3	2004-02-03
1	1184	1906	3	2004-02-08
2	1184	404	3	2004-02-08
3	1184	8844	3	2004-02-08
4	1184	5988	3	2004-02-08
5	1184	4270	1	2004-02-08
6	1184	8627	1	2004-02-08
1	1185	9093	3	2004-02-21
2	1185	8046	3	2004-02-21
3	1185	8319	1	2004-02-21
4	1185	4774	3	2004-02-21
5	1185	9253	2	2004-02-21
6	1185	7698	1	2004-02-21
7	1185	4768	2	2004-02-21
1	1186	4969	1	2004-02-22
2	1186	5153	1	2004-02-22
3	1186	2472	3	2004-02-22
4	1186	2896	1	2004-02-22
5	1186	543	1	2004-02-22
6	1186	9283	1	2004-02-22
7	1186	7301	3	2004-02-22
8	1186	1687	2	2004-02-22
1	1187	9212	2	2004-02-23
2	1187	6923	3	2004-02-23
3	1187	8208	1	2004-02-23
1	1188	4230	1	2004-02-03
2	1188	7229	3	2004-02-03
3	1188	4288	3	2004-02-03
4	1188	8805	3	2004-02-03
5	1188	799	3	2004-02-03
1	1189	8455	1	2004-02-21
2	1189	118	2	2004-02-21
3	1189	3242	3	2004-02-21
4	1189	9012	1	2004-02-21
5	1189	3640	2	2004-02-21
1	1190	7864	2	2004-02-27
1	1191	1475	2	2004-02-14
2	1191	1901	1	2004-02-14
1	1192	2780	1	2004-02-03
2	1192	3034	1	2004-02-03
3	1192	4413	1	2004-02-03
4	1192	7580	3	2004-02-03
5	1192	404	2	2004-02-03
6	1192	107	2	2004-02-03
7	1192	2526	3	2004-02-03
8	1192	5891	1	2004-02-03
1	1193	5848	2	2004-02-28
2	1193	6947	3	2004-02-28
3	1193	9064	3	2004-02-28
4	1193	7602	3	2004-02-28
5	1193	1547	3	2004-02-28
1	1194	5559	1	2004-02-23
2	1194	4300	1	2004-02-23
1	1195	8748	1	2004-02-02
1	1196	8393	3	2004-02-01
2	1196	4568	2	2004-02-01
3	1196	4001	1	2004-02-01
4	1196	1563	1	2004-02-01
5	1196	362	3	2004-02-01
6	1196	2918	1	2004-02-01
7	1196	6392	1	2004-02-01
8	1196	6234	2	2004-02-01
9	1196	2181	1	2004-02-01
1	1197	1184	2	2004-02-22
2	1197	8658	3	2004-02-22
3	1197	6917	3	2004-02-22
4	1197	4569	3	2004-02-22
5	1197	8524	1	2004-02-22
6	1197	7867	1	2004-02-22
7	1197	7202	1	2004-02-22
8	1197	4606	3	2004-02-22
1	1198	6875	2	2004-02-14
2	1198	8881	1	2004-02-14
3	1198	9115	1	2004-02-14
4	1198	4900	3	2004-02-14
5	1198	7541	3	2004-02-14
6	1198	4807	3	2004-02-14
7	1198	4491	2	2004-02-14
8	1198	8655	1	2004-02-14
1	1199	6184	3	2004-02-07
1	1200	2150	2	2004-02-11
2	1200	3355	1	2004-02-11
3	1200	3241	1	2004-02-11
4	1200	4398	1	2004-02-11
5	1200	3337	2	2004-02-11
6	1200	3182	3	2004-02-11
7	1200	239	1	2004-02-11
8	1200	8066	2	2004-02-11
1	1201	3963	1	2004-02-27
2	1201	1325	2	2004-02-27
3	1201	1368	3	2004-02-27
4	1201	3288	2	2004-02-27
5	1201	894	2	2004-02-27
6	1201	3539	1	2004-02-27
7	1201	9142	3	2004-02-27
8	1201	3120	1	2004-02-27
1	1202	1030	3	2004-02-20
1	1203	6313	3	2004-02-25
2	1203	9314	2	2004-02-25
3	1203	5954	1	2004-02-25
4	1203	5498	3	2004-02-25
5	1203	7968	3	2004-02-25
6	1203	4787	1	2004-02-25
7	1203	2016	2	2004-02-25
1	1204	2447	1	2004-02-15
2	1204	6527	3	2004-02-15
3	1204	9359	1	2004-02-15
4	1204	26	1	2004-02-15
1	1205	5476	3	2004-02-25
2	1205	4973	2	2004-02-25
3	1205	2790	1	2004-02-25
4	1205	8065	3	2004-02-25
5	1205	8204	2	2004-02-25
6	1205	5153	1	2004-02-25
7	1205	7287	3	2004-02-25
1	1206	6436	2	2004-02-25
2	1206	9233	1	2004-02-25
3	1206	4738	3	2004-02-25
4	1206	3993	2	2004-02-25
5	1206	8981	1	2004-02-25
6	1206	3481	1	2004-02-25
7	1206	9825	3	2004-02-25
1	1207	5723	1	2004-02-25
2	1207	9683	2	2004-02-25
1	1208	2004	2	2004-02-22
2	1208	7420	2	2004-02-22
3	1208	2978	2	2004-02-22
4	1208	9896	1	2004-02-22
5	1208	6819	2	2004-02-22
1	1209	3517	1	2004-02-03
2	1209	420	2	2004-02-03
3	1209	1833	3	2004-02-03
4	1209	8138	2	2004-02-03
5	1209	420	2	2004-02-03
6	1209	7388	1	2004-02-03
7	1209	7787	2	2004-02-03
8	1209	4937	2	2004-02-03
9	1209	359	3	2004-02-03
1	1210	1635	1	2004-02-01
2	1210	5477	3	2004-02-01
3	1210	6196	2	2004-02-01
1	1211	8468	2	2004-02-26
2	1211	6121	1	2004-02-26
3	1211	5506	2	2004-02-26
1	1212	6027	2	2004-02-17
2	1212	8495	1	2004-02-17
3	1212	609	3	2004-02-17
1	1213	4165	3	2004-02-23
2	1213	1133	3	2004-02-23
3	1213	6720	3	2004-02-23
4	1213	5921	2	2004-02-23
5	1213	2920	1	2004-02-23
6	1213	8763	1	2004-02-23
7	1213	8464	2	2004-02-23
8	1213	1688	2	2004-02-23
9	1213	9142	3	2004-02-23
1	1214	3166	3	2004-02-28
2	1214	6885	2	2004-02-28
3	1214	8178	2	2004-02-28
4	1214	4673	2	2004-02-28
5	1214	4358	3	2004-02-28
6	1214	3076	2	2004-02-28
1	1215	5779	2	2004-02-24
2	1215	6382	2	2004-02-24
3	1215	7126	2	2004-02-24
4	1215	9426	3	2004-02-24
1	1216	5827	3	2004-02-25
2	1216	4629	3	2004-02-25
3	1216	6533	1	2004-02-25
4	1216	2768	2	2004-02-25
5	1216	6302	3	2004-02-25
6	1216	9519	1	2004-02-25
7	1216	6277	1	2004-02-25
8	1216	6150	2	2004-02-25
1	1217	4706	2	2004-02-07
2	1217	2711	1	2004-02-07
3	1217	382	1	2004-02-07
4	1217	645	3	2004-02-07
5	1217	704	3	2004-02-07
6	1217	7904	2	2004-02-07
7	1217	4232	1	2004-02-07
8	1217	5523	1	2004-02-07
1	1218	5730	2	2004-02-12
1	1219	6762	3	2004-02-03
2	1219	6122	2	2004-02-03
3	1219	8146	1	2004-02-03
4	1219	1454	1	2004-02-03
5	1219	2659	1	2004-02-03
6	1219	2994	1	2004-02-03
7	1219	1030	2	2004-02-03
1	1220	1466	2	2004-02-01
2	1220	5321	2	2004-02-01
3	1220	4039	1	2004-02-01
4	1220	5858	3	2004-02-01
5	1220	5787	3	2004-02-01
1	1221	3350	1	2004-02-05
2	1221	4452	1	2004-02-05
3	1221	967	2	2004-02-05
4	1221	2353	2	2004-02-05
5	1221	7739	2	2004-02-05
6	1221	6929	3	2004-02-05
7	1221	9042	3	2004-02-05
8	1221	7703	3	2004-02-05
1	1222	4679	3	2004-02-06
2	1222	7927	1	2004-02-06
3	1222	8822	2	2004-02-06
4	1222	7400	1	2004-02-06
5	1222	7085	1	2004-02-06
6	1222	9130	1	2004-02-06
7	1222	1557	2	2004-02-06
1	1223	6150	3	2004-02-06
2	1223	9627	1	2004-02-06
3	1223	5993	3	2004-02-06
4	1223	332	2	2004-02-06
1	1224	9275	3	2004-02-23
2	1224	2006	3	2004-02-23
3	1224	8077	1	2004-02-23
1	1225	6894	1	2004-02-03
2	1225	8433	3	2004-02-03
3	1225	4132	1	2004-02-03
4	1225	975	2	2004-02-03
5	1225	4644	3	2004-02-03
6	1225	840	2	2004-02-03
7	1225	201	3	2004-02-03
8	1225	2939	1	2004-02-03
1	1226	3826	1	2004-02-02
2	1226	928	2	2004-02-02
3	1226	9149	3	2004-02-02
4	1226	6659	1	2004-02-02
1	1227	8631	2	2004-02-13
2	1227	9825	1	2004-02-13
1	1228	7923	3	2004-02-20
2	1228	5769	3	2004-02-20
1	1229	9582	1	2004-02-12
2	1229	7961	2	2004-02-12
3	1229	3277	3	2004-02-12
4	1229	9239	1	2004-02-12
5	1229	7893	2	2004-02-12
1	1230	3747	1	2004-02-07
1	1231	4370	1	2004-02-20
2	1231	5394	1	2004-02-20
3	1231	8964	1	2004-02-20
4	1231	415	1	2004-02-20
1	1232	398	2	2004-02-28
2	1232	2857	2	2004-02-28
3	1232	4433	1	2004-02-28
4	1232	6099	1	2004-02-28
5	1232	7992	3	2004-02-28
6	1232	4698	1	2004-02-28
7	1232	9135	3	2004-02-28
8	1232	4576	2	2004-02-28
9	1232	2015	3	2004-02-28
1	1233	8677	1	2004-02-01
2	1233	6625	3	2004-02-01
3	1233	3668	2	2004-02-01
4	1233	8162	1	2004-02-01
5	1233	5943	3	2004-02-01
1	1234	894	3	2004-02-20
2	1234	3555	3	2004-02-20
1	1235	6697	2	2004-02-20
2	1235	2226	3	2004-02-20
3	1235	5375	1	2004-02-20
4	1235	5096	3	2004-02-20
5	1235	7758	2	2004-02-20
6	1235	7723	2	2004-02-20
1	1236	2643	3	2004-02-09
1	1237	670	2	2004-02-27
2	1237	148	2	2004-02-27
1	1238	3117	3	2004-02-16
2	1238	1680	2	2004-02-16
3	1238	7885	3	2004-02-16
4	1238	7638	1	2004-02-16
5	1238	4121	2	2004-02-16
6	1238	6754	1	2004-02-16
1	1239	644	2	2004-02-28
1	1240	2045	2	2004-02-21
2	1240	9597	1	2004-02-21
3	1240	211	2	2004-02-21
1	1241	1862	1	2004-02-26
2	1241	7715	3	2004-02-26
3	1241	9975	2	2004-02-26
1	1242	5940	1	2004-02-08
2	1242	9098	3	2004-02-08
3	1242	1176	3	2004-02-08
4	1242	5051	3	2004-02-08
5	1242	9971	1	2004-02-08
6	1242	1730	1	2004-02-08
7	1242	6354	1	2004-02-08
8	1242	4207	2	2004-02-08
9	1242	6319	2	2004-02-08
1	1243	481	2	2004-02-26
2	1243	860	1	2004-02-26
1	1244	3067	1	2004-02-25
2	1244	175	1	2004-02-25
3	1244	9665	1	2004-02-25
4	1244	1906	2	2004-02-25
5	1244	9995	1	2004-02-25
6	1244	5084	1	2004-02-25
7	1244	3891	1	2004-02-25
8	1244	3051	3	2004-02-25
9	1244	8002	3	2004-02-25
1	1245	8369	3	2004-02-05
2	1245	950	3	2004-02-05
3	1245	7865	3	2004-02-05
4	1245	2815	1	2004-02-05
5	1245	9505	2	2004-02-05
6	1245	2907	3	2004-02-05
7	1245	8045	1	2004-02-05
1	1246	1827	1	2004-02-03
1	1247	3815	1	2004-02-08
2	1247	5168	2	2004-02-08
3	1247	9064	1	2004-02-08
4	1247	2774	3	2004-02-08
5	1247	9505	2	2004-02-08
6	1247	6661	3	2004-02-08
1	1248	5357	1	2004-02-11
2	1248	2760	2	2004-02-11
3	1248	5264	2	2004-02-11
1	1249	4921	3	2004-02-10
2	1249	896	3	2004-02-10
3	1249	3359	2	2004-02-10
4	1249	536	3	2004-02-10
5	1249	86	3	2004-02-10
1	1250	6583	2	2004-02-02
1	1251	3240	3	2004-02-21
2	1251	9974	2	2004-02-21
3	1251	1926	2	2004-02-21
4	1251	9787	2	2004-02-21
5	1251	7788	2	2004-02-21
6	1251	457	1	2004-02-21
7	1251	2158	1	2004-02-21
1	1252	4043	2	2004-02-05
2	1252	1570	2	2004-02-05
1	1253	2293	1	2004-02-26
2	1253	5749	2	2004-02-26
3	1253	9571	3	2004-02-26
4	1253	3985	3	2004-02-26
5	1253	4986	2	2004-02-26
6	1253	4782	2	2004-02-26
1	1254	5277	1	2004-02-04
2	1254	2998	3	2004-02-04
1	1255	5208	1	2004-02-20
1	1256	9805	1	2004-02-17
1	1257	4542	1	2004-02-08
2	1257	1949	3	2004-02-08
3	1257	6498	3	2004-02-08
1	1258	9332	2	2004-02-13
2	1258	5198	1	2004-02-13
3	1258	1287	1	2004-02-13
4	1258	1388	3	2004-02-13
1	1259	811	3	2004-02-10
2	1259	9628	1	2004-02-10
3	1259	212	1	2004-02-10
4	1259	6169	3	2004-02-10
5	1259	4865	1	2004-02-10
6	1259	7402	3	2004-02-10
7	1259	238	2	2004-02-10
8	1259	3545	2	2004-02-10
9	1259	1585	1	2004-02-10
1	1260	3245	3	2004-02-23
2	1260	5648	2	2004-02-23
3	1260	8675	3	2004-02-23
4	1260	1228	3	2004-02-23
1	1261	2654	3	2004-02-23
2	1261	150	3	2004-02-23
3	1261	4987	2	2004-02-23
4	1261	9533	1	2004-02-23
5	1261	1828	3	2004-02-23
6	1261	6287	2	2004-02-23
7	1261	4307	3	2004-02-23
1	1262	5919	1	2004-02-24
2	1262	4343	1	2004-02-24
3	1262	6664	1	2004-02-24
4	1262	544	3	2004-02-24
5	1262	1911	3	2004-02-24
6	1262	9929	3	2004-02-24
1	1263	1405	1	2004-02-18
2	1263	1457	1	2004-02-18
3	1263	5418	1	2004-02-18
4	1263	707	1	2004-02-18
5	1263	8657	2	2004-02-18
6	1263	9575	3	2004-02-18
1	1264	393	3	2004-02-22
2	1264	5012	3	2004-02-22
3	1264	9868	2	2004-02-22
4	1264	4947	1	2004-02-22
1	1265	7458	3	2004-02-12
1	1266	9798	3	2004-02-20
2	1266	1637	1	2004-02-20
3	1266	9845	1	2004-02-20
4	1266	5518	3	2004-02-20
5	1266	7165	1	2004-02-20
6	1266	7781	3	2004-02-20
7	1266	6492	3	2004-02-20
8	1266	6523	1	2004-02-20
1	1267	8168	1	2004-02-15
1	1268	9510	3	2004-02-15
2	1268	1368	1	2004-02-15
3	1268	6920	1	2004-02-15
1	1269	8850	3	2004-02-02
1	1270	5687	3	2004-02-27
2	1270	5589	1	2004-02-27
3	1270	8228	1	2004-02-27
4	1270	8599	2	2004-02-27
5	1270	991	3	2004-02-27
6	1270	6505	2	2004-02-27
7	1270	6583	3	2004-02-27
1	1271	8325	2	2004-02-24
2	1271	1082	3	2004-02-24
3	1271	2220	1	2004-02-24
4	1271	8915	1	2004-02-24
5	1271	9941	3	2004-02-24
6	1271	7084	1	2004-02-24
7	1271	5965	1	2004-02-24
8	1271	6899	1	2004-02-24
9	1271	4978	2	2004-02-24
1	1272	342	3	2004-02-07
2	1272	9402	3	2004-02-07
3	1272	5092	3	2004-02-07
4	1272	3017	1	2004-02-07
1	1273	38	3	2004-02-23
2	1273	1698	3	2004-02-23
3	1273	8787	1	2004-02-23
4	1273	7502	2	2004-02-23
5	1273	1812	2	2004-02-23
6	1273	8640	3	2004-02-23
7	1273	5020	2	2004-02-23
8	1273	3835	3	2004-02-23
9	1273	7193	2	2004-02-23
1	1274	4459	2	2004-02-03
1	1275	8816	2	2004-02-23
2	1275	4909	3	2004-02-23
3	1275	1304	2	2004-02-23
4	1275	7806	1	2004-02-23
5	1275	8243	2	2004-02-23
6	1275	5961	1	2004-02-23
1	1276	8217	1	2004-02-25
2	1276	1182	2	2004-02-25
3	1276	6845	1	2004-02-25
4	1276	2945	3	2004-02-25
1	1277	4878	1	2004-02-06
1	1278	2548	3	2004-02-18
1	1279	5660	1	2004-02-22
2	1279	5952	2	2004-02-22
3	1279	7887	2	2004-02-22
4	1279	8227	2	2004-02-22
5	1279	7313	3	2004-02-22
6	1279	1513	2	2004-02-22
1	1280	1860	2	2004-02-04
2	1280	3600	3	2004-02-04
3	1280	8767	3	2004-02-04
4	1280	431	2	2004-02-04
1	1281	3331	3	2004-02-03
2	1281	4346	3	2004-02-03
3	1281	2546	1	2004-02-03
4	1281	3425	1	2004-02-03
5	1281	5012	1	2004-02-03
6	1281	6535	1	2004-02-03
7	1281	1060	3	2004-02-03
8	1281	6481	1	2004-02-03
1	1282	5063	3	2004-02-08
2	1282	1099	2	2004-02-08
3	1282	9162	1	2004-02-08
4	1282	8528	3	2004-02-08
1	1283	9720	1	2004-02-13
2	1283	6829	1	2004-02-13
3	1283	3044	1	2004-02-13
4	1283	2697	3	2004-02-13
5	1283	1904	3	2004-02-13
6	1283	379	1	2004-02-13
7	1283	7278	3	2004-02-13
8	1283	5362	3	2004-02-13
1	1284	601	2	2004-02-16
1	1285	9717	1	2004-02-13
2	1285	3380	3	2004-02-13
3	1285	9115	1	2004-02-13
1	1286	6195	3	2004-02-03
2	1286	1963	3	2004-02-03
3	1286	7292	1	2004-02-03
4	1286	1061	2	2004-02-03
1	1287	7604	3	2004-02-26
2	1287	5264	3	2004-02-26
3	1287	3731	3	2004-02-26
4	1287	7967	1	2004-02-26
5	1287	2575	3	2004-02-26
1	1288	9054	2	2004-02-05
1	1289	2479	1	2004-02-20
2	1289	1125	3	2004-02-20
3	1289	4877	1	2004-02-20
1	1290	8777	2	2004-02-13
2	1290	7180	2	2004-02-13
3	1290	4414	1	2004-02-13
4	1290	3696	1	2004-02-13
5	1290	1410	2	2004-02-13
6	1290	64	1	2004-02-13
7	1290	2225	2	2004-02-13
8	1290	4077	1	2004-02-13
1	1291	3937	3	2004-02-08
2	1291	5637	2	2004-02-08
3	1291	7947	1	2004-02-08
1	1292	976	2	2004-02-21
2	1292	2062	3	2004-02-21
3	1292	7407	2	2004-02-21
4	1292	9065	1	2004-02-21
5	1292	8856	1	2004-02-21
6	1292	7373	3	2004-02-21
1	1293	876	3	2004-02-11
2	1293	8647	2	2004-02-11
3	1293	413	1	2004-02-11
4	1293	4748	2	2004-02-11
5	1293	7643	1	2004-02-11
6	1293	6562	2	2004-02-11
7	1293	4980	1	2004-02-11
1	1294	4110	1	2004-02-03
2	1294	9277	1	2004-02-03
3	1294	3026	3	2004-02-03
1	1295	9995	1	2004-02-11
2	1295	5046	1	2004-02-11
3	1295	9146	2	2004-02-11
4	1295	7442	3	2004-02-11
5	1295	6275	1	2004-02-11
6	1295	5607	2	2004-02-11
7	1295	4883	1	2004-02-11
1	1296	5818	3	2004-02-25
2	1296	2347	3	2004-02-25
3	1296	9760	1	2004-02-25
4	1296	3102	1	2004-02-25
5	1296	9756	3	2004-02-25
6	1296	3182	3	2004-02-25
7	1296	4060	1	2004-02-25
8	1296	8642	3	2004-02-25
9	1296	4046	3	2004-02-25
1	1297	3678	1	2004-02-08
2	1297	2988	3	2004-02-08
3	1297	5120	1	2004-02-08
4	1297	8423	3	2004-02-08
5	1297	1338	2	2004-02-08
6	1297	6275	2	2004-02-08
7	1297	4168	2	2004-02-08
8	1297	5307	3	2004-02-08
9	1297	8819	2	2004-02-08
1	1298	5176	1	2004-02-12
2	1298	7183	3	2004-02-12
3	1298	8298	3	2004-02-12
4	1298	710	2	2004-02-12
5	1298	9051	2	2004-02-12
6	1298	8594	1	2004-02-12
7	1298	2947	2	2004-02-12
8	1298	3832	1	2004-02-12
1	1299	8852	3	2004-02-07
2	1299	4461	2	2004-02-07
3	1299	7045	1	2004-02-07
4	1299	9220	1	2004-02-07
5	1299	5280	1	2004-02-07
6	1299	9141	1	2004-02-07
7	1299	1599	2	2004-02-07
8	1299	9677	3	2004-02-07
1	1300	4774	2	2004-02-18
2	1300	7392	3	2004-02-18
3	1300	7845	1	2004-02-18
4	1300	9089	3	2004-02-18
5	1300	6391	2	2004-02-18
1	1301	9401	1	2004-02-24
2	1301	6163	3	2004-02-24
3	1301	2579	1	2004-02-24
1	1302	8042	1	2004-02-28
2	1302	1205	2	2004-02-28
1	1303	874	3	2004-02-06
2	1303	4453	3	2004-02-06
3	1303	8310	2	2004-02-06
4	1303	8714	2	2004-02-06
5	1303	8238	3	2004-02-06
6	1303	9943	1	2004-02-06
7	1303	20	3	2004-02-06
1	1304	7624	3	2004-02-12
2	1304	8524	3	2004-02-12
3	1304	8982	2	2004-02-12
4	1304	1094	1	2004-02-12
5	1304	910	1	2004-02-12
6	1304	6929	1	2004-02-12
7	1304	9786	3	2004-02-12
1	1305	7779	2	2004-02-22
2	1305	704	2	2004-02-22
3	1305	2370	1	2004-02-22
4	1305	8726	1	2004-02-22
5	1305	9990	1	2004-02-22
6	1305	8572	3	2004-02-22
1	1306	5716	2	2004-02-28
2	1306	4846	3	2004-02-28
3	1306	4794	2	2004-02-28
4	1306	9862	1	2004-02-28
5	1306	6361	3	2004-02-28
6	1306	9524	2	2004-02-28
7	1306	3887	2	2004-02-28
8	1306	57	1	2004-02-28
1	1307	1406	2	2004-02-04
2	1307	6034	1	2004-02-04
3	1307	9359	2	2004-02-04
4	1307	9348	3	2004-02-04
1	1308	9582	1	2004-02-03
2	1308	3324	2	2004-02-03
3	1308	7995	1	2004-02-03
4	1308	6098	2	2004-02-03
5	1308	2834	2	2004-02-03
6	1308	8409	3	2004-02-03
1	1309	9224	2	2004-02-05
2	1309	6584	1	2004-02-05
3	1309	2473	1	2004-02-05
1	1310	945	3	2004-02-06
2	1310	6345	3	2004-02-06
1	1311	303	3	2004-02-13
2	1311	1045	2	2004-02-13
3	1311	2929	2	2004-02-13
4	1311	2021	1	2004-02-13
5	1311	598	2	2004-02-13
6	1311	9802	3	2004-02-13
7	1311	6623	3	2004-02-13
8	1311	5048	1	2004-02-13
1	1312	9350	1	2004-02-28
2	1312	3049	1	2004-02-28
1	1313	5320	3	2004-02-03
2	1313	3457	2	2004-02-03
3	1313	7787	2	2004-02-03
4	1313	2022	1	2004-02-03
5	1313	8379	2	2004-02-03
6	1313	2053	3	2004-02-03
1	1314	880	1	2004-02-22
2	1314	7555	1	2004-02-22
3	1314	526	2	2004-02-22
4	1314	2214	3	2004-02-22
1	1315	4656	3	2004-02-18
2	1315	3081	3	2004-02-18
3	1315	8016	2	2004-02-18
4	1315	5597	2	2004-02-18
5	1315	1039	3	2004-02-18
6	1315	6517	3	2004-02-18
7	1315	1660	3	2004-02-18
1	1316	3734	1	2004-02-24
2	1316	9357	1	2004-02-24
3	1316	1838	3	2004-02-24
4	1316	4665	2	2004-02-24
5	1316	9757	1	2004-02-24
6	1316	9313	3	2004-02-24
1	1317	3943	3	2004-02-24
2	1317	8185	3	2004-02-24
1	1318	8641	3	2004-02-08
2	1318	7632	3	2004-02-08
3	1318	8203	3	2004-02-08
4	1318	3386	1	2004-02-08
5	1318	9357	1	2004-02-08
6	1318	3225	1	2004-02-08
7	1318	2625	3	2004-02-08
8	1318	5245	1	2004-02-08
9	1318	8972	2	2004-02-08
1	1319	9185	1	2004-02-07
1	1320	6592	3	2004-02-22
1	1321	2268	2	2004-02-27
2	1321	5076	2	2004-02-27
3	1321	8120	2	2004-02-27
4	1321	8396	1	2004-02-27
5	1321	5627	1	2004-02-27
6	1321	9232	1	2004-02-27
7	1321	3401	3	2004-02-27
1	1322	6745	2	2004-02-16
2	1322	6420	2	2004-02-16
3	1322	2294	3	2004-02-16
4	1322	4854	3	2004-02-16
1	1323	1267	2	2004-02-22
2	1323	1755	2	2004-02-22
3	1323	2038	3	2004-02-22
4	1323	775	1	2004-02-22
5	1323	1218	2	2004-02-22
6	1323	1453	1	2004-02-22
1	1324	562	2	2004-02-21
2	1324	6652	3	2004-02-21
3	1324	9317	1	2004-02-21
1	1325	495	3	2004-02-06
2	1325	930	2	2004-02-06
3	1325	4661	1	2004-02-06
4	1325	997	2	2004-02-06
5	1325	8538	1	2004-02-06
6	1325	6290	3	2004-02-06
7	1325	3468	3	2004-02-06
1	1326	9774	2	2004-02-16
2	1326	5685	1	2004-02-16
3	1326	998	1	2004-02-16
1	1327	1924	3	2004-02-22
2	1327	6157	1	2004-02-22
3	1327	5997	3	2004-02-22
4	1327	7030	1	2004-02-22
5	1327	9281	3	2004-02-22
6	1327	7073	3	2004-02-22
7	1327	1061	2	2004-02-22
8	1327	7131	2	2004-02-22
9	1327	868	1	2004-02-22
1	1328	5429	1	2004-02-27
2	1328	9556	2	2004-02-27
3	1328	3852	3	2004-02-27
4	1328	6741	3	2004-02-27
5	1328	6667	3	2004-02-27
6	1328	6167	1	2004-02-27
7	1328	1082	1	2004-02-27
8	1328	9908	3	2004-02-27
9	1328	2821	3	2004-02-27
1	1329	3255	2	2004-02-18
2	1329	1726	2	2004-02-18
3	1329	6982	1	2004-02-18
4	1329	2945	1	2004-02-18
5	1329	394	3	2004-02-18
6	1329	4327	3	2004-02-18
7	1329	4799	3	2004-02-18
1	1330	204	2	2004-02-21
2	1330	6633	1	2004-02-21
3	1330	5767	2	2004-02-21
4	1330	9397	3	2004-02-21
1	1331	2734	1	2004-02-17
2	1331	6873	2	2004-02-17
3	1331	5856	2	2004-02-17
1	1332	7173	1	2004-02-16
2	1332	5976	1	2004-02-16
3	1332	9169	1	2004-02-16
4	1332	3511	2	2004-02-16
5	1332	6930	2	2004-02-16
6	1332	209	2	2004-02-16
1	1333	4562	2	2004-02-14
2	1333	9931	1	2004-02-14
3	1333	8566	1	2004-02-14
4	1333	4775	2	2004-02-14
1	1334	9431	2	2004-02-20
2	1334	8783	2	2004-02-20
3	1334	6950	2	2004-02-20
1	1335	2725	2	2004-02-25
2	1335	5799	1	2004-02-25
1	1336	5194	2	2004-02-24
2	1336	4302	2	2004-02-24
3	1336	6512	1	2004-02-24
4	1336	7788	1	2004-02-24
5	1336	8306	2	2004-02-24
6	1336	1917	3	2004-02-24
7	1336	7668	1	2004-02-24
8	1336	3556	2	2004-02-24
1	1337	6625	3	2004-02-23
2	1337	8611	3	2004-02-23
3	1337	3889	2	2004-02-23
4	1337	2282	1	2004-02-23
5	1337	5208	1	2004-02-23
6	1337	728	1	2004-02-23
1	1338	7896	1	2004-02-14
2	1338	2457	2	2004-02-14
1	1339	5721	3	2004-02-24
2	1339	2340	2	2004-02-24
3	1339	7861	2	2004-02-24
4	1339	197	2	2004-02-24
5	1339	2630	3	2004-02-24
6	1339	3834	2	2004-02-24
1	1340	7306	3	2004-02-10
2	1340	8824	1	2004-02-10
3	1340	4531	2	2004-02-10
4	1340	3136	1	2004-02-10
5	1340	7661	2	2004-02-10
6	1340	8628	2	2004-02-10
7	1340	9966	1	2004-02-10
8	1340	1775	2	2004-02-10
1	1341	7661	3	2004-02-28
2	1341	2126	1	2004-02-28
3	1341	8360	2	2004-02-28
4	1341	6809	1	2004-02-28
5	1341	2075	2	2004-02-28
6	1341	9999	3	2004-02-28
7	1341	5086	3	2004-02-28
1	1342	2043	1	2004-02-04
2	1342	72	1	2004-02-04
3	1342	6714	1	2004-02-04
4	1342	3097	3	2004-02-04
5	1342	5723	1	2004-02-04
1	1343	4632	1	2004-02-08
1	1344	4567	1	2004-02-02
2	1344	2944	2	2004-02-02
3	1344	56	3	2004-02-02
4	1344	3388	1	2004-02-02
5	1344	7646	2	2004-02-02
6	1344	5880	3	2004-02-02
7	1344	7388	2	2004-02-02
1	1345	2590	1	2004-02-02
2	1345	6331	2	2004-02-02
3	1345	6791	3	2004-02-02
4	1345	5454	1	2004-02-02
1	1346	3366	3	2004-02-27
2	1346	8770	2	2004-02-27
3	1346	3546	3	2004-02-27
4	1346	4338	3	2004-02-27
5	1346	226	1	2004-02-27
6	1346	3492	2	2004-02-27
7	1346	1671	1	2004-02-27
8	1346	2057	1	2004-02-27
1	1347	9757	1	2004-02-14
2	1347	2761	2	2004-02-14
3	1347	8662	3	2004-02-14
4	1347	7970	3	2004-02-14
5	1347	4220	1	2004-02-14
6	1347	6246	3	2004-02-14
7	1347	1364	2	2004-02-14
1	1348	1843	2	2004-02-11
2	1348	213	2	2004-02-11
3	1348	171	1	2004-02-11
4	1348	6214	1	2004-02-11
5	1348	3912	1	2004-02-11
6	1348	272	3	2004-02-11
7	1348	8765	1	2004-02-11
8	1348	1208	1	2004-02-11
1	1349	8022	2	2004-02-19
2	1349	6927	2	2004-02-19
3	1349	1544	3	2004-02-19
4	1349	9282	2	2004-02-19
5	1349	3199	1	2004-02-19
1	1350	376	3	2004-02-11
2	1350	5763	2	2004-02-11
3	1350	9585	3	2004-02-11
4	1350	7785	3	2004-02-11
1	1351	8075	2	2004-02-26
1	1352	1773	3	2004-02-01
2	1352	2433	1	2004-02-01
3	1352	6220	1	2004-02-01
4	1352	8752	3	2004-02-01
5	1352	4836	1	2004-02-01
6	1352	4460	1	2004-02-01
7	1352	6298	2	2004-02-01
8	1352	9379	1	2004-02-01
1	1353	8820	1	2004-02-04
2	1353	5759	3	2004-02-04
3	1353	1081	2	2004-02-04
4	1353	5163	1	2004-02-04
5	1353	1647	2	2004-02-04
6	1353	9392	2	2004-02-04
7	1353	4096	1	2004-02-04
8	1353	6736	1	2004-02-04
9	1353	3538	2	2004-02-04
1	1354	395	2	2004-02-28
2	1354	9028	3	2004-02-28
3	1354	6263	1	2004-02-28
4	1354	8737	3	2004-02-28
1	1355	6260	3	2004-02-28
2	1355	9254	1	2004-02-28
3	1355	1107	1	2004-02-28
4	1355	7588	1	2004-02-28
5	1355	4321	1	2004-02-28
1	1356	6543	1	2004-02-07
2	1356	4234	2	2004-02-07
3	1356	5922	2	2004-02-07
4	1356	8650	2	2004-02-07
5	1356	4402	2	2004-02-07
6	1356	5403	1	2004-02-07
1	1357	487	3	2004-02-09
2	1357	1594	3	2004-02-09
1	1358	3200	2	2004-02-24
2	1358	7645	2	2004-02-24
3	1358	6017	3	2004-02-24
4	1358	1382	1	2004-02-24
5	1358	1372	2	2004-02-24
6	1358	7007	3	2004-02-24
1	1359	570	3	2004-02-01
2	1359	7783	2	2004-02-01
3	1359	2712	3	2004-02-01
4	1359	5193	1	2004-02-01
5	1359	5431	3	2004-02-01
1	1360	9768	1	2004-02-09
2	1360	8541	3	2004-02-09
3	1360	8209	2	2004-02-09
4	1360	7055	3	2004-02-09
1	1361	5720	2	2004-02-20
2	1361	9781	3	2004-02-20
3	1361	92	1	2004-02-20
4	1361	5610	3	2004-02-20
1	1362	1519	1	2004-02-11
2	1362	5810	2	2004-02-11
3	1362	5587	2	2004-02-11
4	1362	8036	2	2004-02-11
5	1362	7984	2	2004-02-11
6	1362	2768	2	2004-02-11
7	1362	1135	3	2004-02-11
8	1362	5783	3	2004-02-11
9	1362	8249	1	2004-02-11
1	1363	1932	2	2004-02-07
2	1363	2508	3	2004-02-07
1	1364	5362	3	2004-02-13
1	1365	6469	3	2004-02-08
2	1365	3476	2	2004-02-08
3	1365	6449	2	2004-02-08
4	1365	645	3	2004-02-08
5	1365	6065	2	2004-02-08
6	1365	5835	2	2004-02-08
7	1365	7415	3	2004-02-08
8	1365	8282	2	2004-02-08
1	1366	7754	2	2004-02-02
2	1366	9215	2	2004-02-02
3	1366	5532	2	2004-02-02
1	1367	6187	1	2004-02-03
2	1367	2700	3	2004-02-03
3	1367	6670	3	2004-02-03
1	1368	3742	1	2004-02-17
2	1368	6282	1	2004-02-17
1	1369	4775	2	2004-02-03
2	1369	4022	1	2004-02-03
1	1370	7813	3	2004-02-01
2	1370	3759	2	2004-02-01
3	1370	9964	3	2004-02-01
4	1370	5777	1	2004-02-01
5	1370	9607	1	2004-02-01
6	1370	1812	2	2004-02-01
1	1371	1109	2	2004-02-28
2	1371	4659	1	2004-02-28
3	1371	8323	3	2004-02-28
4	1371	3031	1	2004-02-28
1	1372	288	1	2004-02-15
2	1372	903	3	2004-02-15
3	1372	8903	2	2004-02-15
4	1372	1660	3	2004-02-15
5	1372	4605	3	2004-02-15
1	1373	9721	3	2004-02-05
2	1373	1884	3	2004-02-05
3	1373	3147	1	2004-02-05
4	1373	960	3	2004-02-05
1	1374	2379	1	2004-02-14
2	1374	4961	3	2004-02-14
3	1374	7728	2	2004-02-14
4	1374	9771	3	2004-02-14
5	1374	3348	3	2004-02-14
6	1374	3290	2	2004-02-14
7	1374	7539	3	2004-02-14
8	1374	2445	3	2004-02-14
1	1375	1972	2	2004-02-06
2	1375	9025	2	2004-02-06
1	1376	9266	1	2004-02-21
2	1376	71	1	2004-02-21
1	1377	279	3	2004-02-09
1	1378	8634	2	2004-02-26
2	1378	451	1	2004-02-26
3	1378	4695	1	2004-02-26
1	1379	1396	2	2004-02-10
2	1379	497	3	2004-02-10
3	1379	3390	2	2004-02-10
4	1379	842	1	2004-02-10
5	1379	3814	1	2004-02-10
1	1380	7363	2	2004-02-13
2	1380	3363	2	2004-02-13
3	1380	9847	1	2004-02-13
4	1380	9188	3	2004-02-13
1	1381	2194	1	2004-02-20
2	1381	8876	2	2004-02-20
1	1382	8952	2	2004-02-24
2	1382	2258	3	2004-02-24
3	1382	6025	2	2004-02-24
4	1382	706	1	2004-02-24
5	1382	2795	2	2004-02-24
6	1382	4269	1	2004-02-24
7	1382	2869	3	2004-02-24
8	1382	6789	1	2004-02-24
1	1383	5614	1	2004-02-26
2	1383	7933	3	2004-02-26
3	1383	3719	3	2004-02-26
4	1383	4382	1	2004-02-26
5	1383	7080	2	2004-02-26
6	1383	898	2	2004-02-26
1	1384	9226	2	2004-02-22
2	1384	4080	1	2004-02-22
3	1384	3178	3	2004-02-22
4	1384	2178	2	2004-02-22
1	1385	4942	3	2004-02-17
2	1385	1222	1	2004-02-17
3	1385	713	3	2004-02-17
4	1385	8363	2	2004-02-17
5	1385	5964	1	2004-02-17
1	1386	9074	2	2004-02-19
2	1386	543	2	2004-02-19
3	1386	8594	3	2004-02-19
4	1386	1429	1	2004-02-19
5	1386	1788	2	2004-02-19
6	1386	1022	2	2004-02-19
7	1386	653	3	2004-02-19
1	1387	9373	1	2004-02-09
2	1387	8427	1	2004-02-09
3	1387	2441	3	2004-02-09
4	1387	4516	3	2004-02-09
5	1387	9533	1	2004-02-09
6	1387	1447	2	2004-02-09
7	1387	8394	1	2004-02-09
8	1387	1475	3	2004-02-09
1	1388	2741	1	2004-02-16
2	1388	1453	2	2004-02-16
3	1388	4455	1	2004-02-16
4	1388	765	3	2004-02-16
5	1388	1520	1	2004-02-16
6	1388	5258	1	2004-02-16
7	1388	6114	2	2004-02-16
1	1389	6957	1	2004-02-03
2	1389	6499	3	2004-02-03
3	1389	6643	2	2004-02-03
4	1389	8923	3	2004-02-03
5	1389	3828	2	2004-02-03
1	1390	3020	1	2004-02-23
1	1391	4861	2	2004-02-14
2	1391	8280	1	2004-02-14
3	1391	7156	2	2004-02-14
4	1391	3802	3	2004-02-14
5	1391	2947	2	2004-02-14
1	1392	8306	1	2004-02-11
1	1393	1569	3	2004-02-15
2	1393	1375	1	2004-02-15
3	1393	8150	2	2004-02-15
4	1393	5396	1	2004-02-15
5	1393	1869	1	2004-02-15
6	1393	8290	3	2004-02-15
7	1393	6403	2	2004-02-15
8	1393	6847	2	2004-02-15
1	1394	4923	2	2004-02-03
2	1394	3811	3	2004-02-03
3	1394	5443	1	2004-02-03
4	1394	125	1	2004-02-03
1	1395	6389	1	2004-02-27
1	1396	7377	3	2004-02-11
2	1396	9204	2	2004-02-11
3	1396	3671	2	2004-02-11
4	1396	2235	1	2004-02-11
5	1396	9165	1	2004-02-11
6	1396	1167	1	2004-02-11
7	1396	7104	2	2004-02-11
8	1396	6174	1	2004-02-11
9	1396	5292	1	2004-02-11
1	1397	4580	1	2004-02-09
2	1397	3287	1	2004-02-09
3	1397	2060	3	2004-02-09
1	1398	4074	2	2004-02-16
2	1398	8549	3	2004-02-16
3	1398	830	1	2004-02-16
1	1399	850	1	2004-02-24
2	1399	5518	3	2004-02-24
3	1399	1996	1	2004-02-24
4	1399	8640	2	2004-02-24
5	1399	6225	1	2004-02-24
6	1399	7399	1	2004-02-24
7	1399	2097	1	2004-02-24
8	1399	1773	2	2004-02-24
9	1399	7640	3	2004-02-24
1	1400	8883	3	2004-02-04
2	1400	3107	3	2004-02-04
3	1400	9495	1	2004-02-04
4	1400	9706	2	2004-02-04
5	1400	798	1	2004-02-04
1	1401	7124	2	2004-02-13
2	1401	1577	2	2004-02-13
3	1401	6933	3	2004-02-13
4	1401	4152	3	2004-02-13
5	1401	9659	2	2004-02-13
6	1401	3186	3	2004-02-13
1	1402	9835	3	2004-02-09
2	1402	2079	1	2004-02-09
3	1402	9551	1	2004-02-09
4	1402	4310	3	2004-02-09
1	1403	1422	3	2004-02-15
2	1403	6154	3	2004-02-15
3	1403	3605	3	2004-02-15
4	1403	1892	1	2004-02-15
5	1403	6704	2	2004-02-15
6	1403	9567	2	2004-02-15
7	1403	1967	1	2004-02-15
8	1403	3661	2	2004-02-15
9	1403	7225	2	2004-02-15
1	1404	1	2	2004-02-24
1	1405	9417	1	2004-02-07
2	1405	6836	1	2004-02-07
3	1405	464	1	2004-02-07
4	1405	9383	2	2004-02-07
5	1405	719	1	2004-02-07
6	1405	4606	3	2004-02-07
7	1405	7317	2	2004-02-07
1	1406	4453	2	2004-02-11
2	1406	2065	1	2004-02-11
3	1406	1206	2	2004-02-11
4	1406	3602	1	2004-02-11
5	1406	531	2	2004-02-11
6	1406	5516	2	2004-02-11
7	1406	3021	2	2004-02-11
1	1407	2846	2	2004-02-20
2	1407	1403	2	2004-02-20
3	1407	6426	2	2004-02-20
4	1407	986	2	2004-02-20
5	1407	179	2	2004-02-20
6	1407	3025	3	2004-02-20
7	1407	2217	3	2004-02-20
1	1408	803	2	2004-02-04
2	1408	3660	1	2004-02-04
3	1408	9854	3	2004-02-04
1	1409	2732	3	2004-02-15
2	1409	9335	2	2004-02-15
1	1410	6746	1	2004-02-15
2	1410	5195	3	2004-02-15
1	1411	5696	2	2004-02-14
2	1411	1395	2	2004-02-14
3	1411	7727	1	2004-02-14
4	1411	227	1	2004-02-14
5	1411	3531	1	2004-02-14
6	1411	561	3	2004-02-14
7	1411	2955	2	2004-02-14
1	1412	1263	3	2004-02-02
2	1412	732	1	2004-02-02
3	1412	1024	3	2004-02-02
4	1412	529	2	2004-02-02
5	1412	4401	2	2004-02-02
6	1412	4437	3	2004-02-02
7	1412	2539	1	2004-02-02
8	1412	3699	2	2004-02-02
9	1412	6293	1	2004-02-02
1	1413	6600	2	2004-02-18
2	1413	8320	3	2004-02-18
3	1413	8041	3	2004-02-18
4	1413	5241	1	2004-02-18
5	1413	8973	2	2004-02-18
6	1413	2155	3	2004-02-18
7	1413	6906	1	2004-02-18
8	1413	7180	3	2004-02-18
9	1413	9395	1	2004-02-18
1	1414	3963	2	2004-02-09
2	1414	9332	1	2004-02-09
3	1414	5130	2	2004-02-09
4	1414	6775	3	2004-02-09
5	1414	5122	2	2004-02-09
1	1415	2419	3	2004-02-04
2	1415	1938	1	2004-02-04
3	1415	4672	2	2004-02-04
4	1415	1095	1	2004-02-04
5	1415	7269	3	2004-02-04
6	1415	9012	2	2004-02-04
7	1415	9855	1	2004-02-04
8	1415	494	3	2004-02-04
9	1415	7271	2	2004-02-04
1	1416	2063	1	2004-02-10
2	1416	6636	3	2004-02-10
3	1416	4861	3	2004-02-10
4	1416	625	3	2004-02-10
5	1416	7304	1	2004-02-10
6	1416	5958	3	2004-02-10
7	1416	4434	1	2004-02-10
8	1416	3333	2	2004-02-10
1	1417	7265	2	2004-02-07
2	1417	3090	3	2004-02-07
1	1418	6962	3	2004-02-10
2	1418	5776	3	2004-02-10
3	1418	8414	1	2004-02-10
4	1418	6209	1	2004-02-10
5	1418	362	3	2004-02-10
6	1418	1063	3	2004-02-10
7	1418	9877	3	2004-02-10
1	1419	9839	3	2004-02-20
1	1420	7298	2	2004-02-03
2	1420	5864	1	2004-02-03
3	1420	4524	3	2004-02-03
4	1420	7896	1	2004-02-03
5	1420	5006	2	2004-02-03
6	1420	509	2	2004-02-03
7	1420	6084	3	2004-02-03
8	1420	6693	2	2004-02-03
1	1421	4776	1	2004-02-10
2	1421	7737	1	2004-02-10
3	1421	1257	3	2004-02-10
4	1421	2281	1	2004-02-10
1	1422	7519	2	2004-02-04
2	1422	9328	1	2004-02-04
3	1422	4144	3	2004-02-04
4	1422	3527	3	2004-02-04
5	1422	896	2	2004-02-04
6	1422	2569	3	2004-02-04
7	1422	753	3	2004-02-04
8	1422	3425	2	2004-02-04
1	1423	8553	2	2004-02-20
2	1423	4219	3	2004-02-20
1	1424	9854	1	2004-02-09
2	1424	2769	3	2004-02-09
3	1424	8173	1	2004-02-09
4	1424	9414	1	2004-02-09
1	1425	6975	2	2004-02-27
1	1426	2029	1	2004-02-21
1	1427	5223	2	2004-02-23
2	1427	6514	3	2004-02-23
3	1427	2822	3	2004-02-23
4	1427	2518	1	2004-02-23
5	1427	526	2	2004-02-23
6	1427	47	3	2004-02-23
7	1427	7382	3	2004-02-23
1	1428	6915	3	2004-02-03
2	1428	6514	2	2004-02-03
3	1428	7101	3	2004-02-03
1	1429	8888	1	2004-02-14
2	1429	9585	2	2004-02-14
3	1429	8546	2	2004-02-14
1	1430	4042	2	2004-02-07
2	1430	177	2	2004-02-07
3	1430	3741	3	2004-02-07
4	1430	3549	2	2004-02-07
5	1430	4258	2	2004-02-07
1	1431	5281	1	2004-02-21
2	1431	3556	1	2004-02-21
3	1431	1554	2	2004-02-21
4	1431	2886	1	2004-02-21
1	1432	8569	3	2004-02-17
2	1432	5809	1	2004-02-17
3	1432	1815	3	2004-02-17
4	1432	8128	1	2004-02-17
1	1433	6623	2	2004-02-12
2	1433	3435	2	2004-02-12
3	1433	4979	3	2004-02-12
4	1433	7605	1	2004-02-12
5	1433	1182	1	2004-02-12
6	1433	266	1	2004-02-12
7	1433	4834	1	2004-02-12
1	1434	5173	2	2004-02-09
2	1434	4654	1	2004-02-09
3	1434	7275	2	2004-02-09
4	1434	831	2	2004-02-09
5	1434	8459	2	2004-02-09
6	1434	7270	3	2004-02-09
7	1434	2255	2	2004-02-09
1	1435	4447	2	2004-02-06
2	1435	7051	2	2004-02-06
3	1435	6513	3	2004-02-06
4	1435	8365	1	2004-02-06
5	1435	468	1	2004-02-06
6	1435	2078	2	2004-02-06
7	1435	9272	3	2004-02-06
1	1436	393	3	2004-02-01
2	1436	2957	3	2004-02-01
3	1436	3830	1	2004-02-01
4	1436	6858	2	2004-02-01
5	1436	4118	3	2004-02-01
6	1436	1773	1	2004-02-01
7	1436	5461	2	2004-02-01
1	1437	9827	1	2004-02-21
2	1437	5078	1	2004-02-21
3	1437	1756	3	2004-02-21
4	1437	6384	1	2004-02-21
1	1438	4217	2	2004-02-13
2	1438	1697	3	2004-02-13
3	1438	4194	2	2004-02-13
1	1439	9720	2	2004-02-21
2	1439	3381	2	2004-02-21
1	1440	4331	3	2004-02-27
2	1440	1663	3	2004-02-27
1	1441	4444	1	2004-02-22
2	1441	858	3	2004-02-22
3	1441	3602	2	2004-02-22
4	1441	4737	2	2004-02-22
1	1442	9981	1	2004-02-07
2	1442	1161	3	2004-02-07
3	1442	5816	2	2004-02-07
4	1442	4882	2	2004-02-07
5	1442	5142	1	2004-02-07
6	1442	6867	3	2004-02-07
7	1442	91	3	2004-02-07
8	1442	8879	3	2004-02-07
9	1442	1947	2	2004-02-07
1	1443	5786	1	2004-02-06
2	1443	8030	1	2004-02-06
3	1443	5306	1	2004-02-06
1	1444	8563	1	2004-02-27
2	1444	9134	2	2004-02-27
3	1444	5625	2	2004-02-27
4	1444	9796	1	2004-02-27
5	1444	6588	2	2004-02-27
6	1444	238	3	2004-02-27
7	1444	5192	3	2004-02-27
8	1444	4580	3	2004-02-27
9	1444	4557	3	2004-02-27
1	1445	970	3	2004-02-10
2	1445	9837	2	2004-02-10
3	1445	7937	3	2004-02-10
4	1445	2404	3	2004-02-10
5	1445	8722	1	2004-02-10
6	1445	8942	3	2004-02-10
7	1445	5345	2	2004-02-10
8	1445	1870	2	2004-02-10
9	1445	5333	3	2004-02-10
1	1446	4686	3	2004-02-06
2	1446	4132	3	2004-02-06
3	1446	6390	3	2004-02-06
4	1446	205	2	2004-02-06
5	1446	6976	1	2004-02-06
6	1446	3681	3	2004-02-06
7	1446	7449	1	2004-02-06
1	1447	819	3	2004-02-18
2	1447	2677	2	2004-02-18
3	1447	2985	2	2004-02-18
4	1447	1302	3	2004-02-18
5	1447	3003	1	2004-02-18
1	1448	7850	2	2004-02-11
2	1448	7814	2	2004-02-11
3	1448	1889	3	2004-02-11
4	1448	260	3	2004-02-11
5	1448	9192	2	2004-02-11
6	1448	5676	2	2004-02-11
7	1448	5559	1	2004-02-11
8	1448	6493	2	2004-02-11
1	1449	3474	2	2004-02-19
2	1449	3820	2	2004-02-19
3	1449	4756	3	2004-02-19
4	1449	7879	3	2004-02-19
5	1449	4959	3	2004-02-19
6	1449	7215	1	2004-02-19
7	1449	2203	2	2004-02-19
8	1449	7048	2	2004-02-19
9	1449	3046	3	2004-02-19
1	1450	8877	3	2004-02-09
2	1450	406	2	2004-02-09
3	1450	1841	3	2004-02-09
4	1450	2681	2	2004-02-09
5	1450	6276	2	2004-02-09
6	1450	1732	1	2004-02-09
7	1450	929	2	2004-02-09
8	1450	6918	3	2004-02-09
1	1451	4686	3	2004-02-15
2	1451	7370	1	2004-02-15
3	1451	3075	1	2004-02-15
1	1452	4659	1	2004-02-26
1	1453	2066	3	2004-02-20
2	1453	4229	3	2004-02-20
3	1453	5732	2	2004-02-20
4	1453	8437	2	2004-02-20
5	1453	2447	2	2004-02-20
6	1453	5468	3	2004-02-20
7	1453	7232	1	2004-02-20
8	1453	9918	1	2004-02-20
9	1453	1233	3	2004-02-20
1	1454	335	1	2004-02-11
2	1454	2980	2	2004-02-11
3	1454	1882	1	2004-02-11
1	1455	8357	1	2004-02-01
2	1455	463	2	2004-02-01
1	1456	4255	2	2004-02-26
2	1456	9221	1	2004-02-26
1	1457	6425	3	2004-02-24
2	1457	4005	2	2004-02-24
3	1457	9746	2	2004-02-24
4	1457	4481	1	2004-02-24
5	1457	9333	2	2004-02-24
6	1457	2800	3	2004-02-24
7	1457	5141	1	2004-02-24
8	1457	1511	2	2004-02-24
9	1457	5050	1	2004-02-24
1	1458	5895	2	2004-02-22
2	1458	4553	2	2004-02-22
3	1458	6615	1	2004-02-22
4	1458	4254	1	2004-02-22
5	1458	2716	1	2004-02-22
6	1458	7072	3	2004-02-22
7	1458	4806	3	2004-02-22
8	1458	1061	3	2004-02-22
1	1459	9782	1	2004-02-27
2	1459	4153	1	2004-02-27
3	1459	4286	3	2004-02-27
1	1460	208	3	2004-02-10
2	1460	9266	2	2004-02-10
3	1460	4462	2	2004-02-10
4	1460	7778	3	2004-02-10
1	1461	7214	2	2004-02-17
2	1461	9788	3	2004-02-17
3	1461	3485	3	2004-02-17
1	1462	9919	2	2004-02-25
2	1462	9742	2	2004-02-25
3	1462	5026	1	2004-02-25
4	1462	6077	3	2004-02-25
5	1462	7146	2	2004-02-25
6	1462	7823	2	2004-02-25
7	1462	1044	1	2004-02-25
8	1462	2291	3	2004-02-25
1	1463	1159	2	2004-02-03
1	1464	276	2	2004-02-13
2	1464	7207	1	2004-02-13
3	1464	1917	3	2004-02-13
4	1464	7771	1	2004-02-13
5	1464	1330	1	2004-02-13
6	1464	4665	3	2004-02-13
7	1464	1274	1	2004-02-13
8	1464	3691	3	2004-02-13
1	1465	3556	1	2004-02-24
1	1466	9396	3	2004-02-25
2	1466	805	2	2004-02-25
3	1466	5437	1	2004-02-25
4	1466	7665	1	2004-02-25
5	1466	3027	3	2004-02-25
6	1466	9768	1	2004-02-25
7	1466	1240	1	2004-02-25
8	1466	3594	2	2004-02-25
9	1466	8504	2	2004-02-25
1	1467	6929	2	2004-02-22
2	1467	6447	1	2004-02-22
3	1467	7721	2	2004-02-22
4	1467	3353	1	2004-02-22
5	1467	5006	1	2004-02-22
6	1467	7853	2	2004-02-22
1	1468	5931	3	2004-02-20
2	1468	4192	2	2004-02-20
3	1468	714	2	2004-02-20
4	1468	6796	2	2004-02-20
5	1468	1335	2	2004-02-20
1	1469	4984	2	2004-02-26
2	1469	8481	1	2004-02-26
3	1469	4906	2	2004-02-26
1	1470	1006	2	2004-02-19
2	1470	7391	3	2004-02-19
1	1471	4197	3	2004-02-22
2	1471	9463	2	2004-02-22
3	1471	2182	2	2004-02-22
4	1471	9217	2	2004-02-22
1	1472	1529	3	2004-02-05
2	1472	3473	1	2004-02-05
3	1472	8978	3	2004-02-05
4	1472	6210	2	2004-02-05
5	1472	6635	1	2004-02-05
6	1472	7135	3	2004-02-05
7	1472	7448	2	2004-02-05
8	1472	5591	2	2004-02-05
9	1472	8806	3	2004-02-05
1	1473	7912	3	2004-02-26
2	1473	4768	3	2004-02-26
3	1473	601	2	2004-02-26
4	1473	5518	1	2004-02-26
5	1473	5375	3	2004-02-26
6	1473	714	3	2004-02-26
7	1473	7055	3	2004-02-26
8	1473	7224	1	2004-02-26
1	1474	1499	2	2004-02-15
2	1474	6904	3	2004-02-15
3	1474	8897	2	2004-02-15
1	1475	6451	2	2004-02-15
1	1476	7543	3	2004-02-21
2	1476	992	1	2004-02-21
3	1476	6314	1	2004-02-21
4	1476	1764	2	2004-02-21
5	1476	1396	3	2004-02-21
6	1476	6634	2	2004-02-21
7	1476	2846	1	2004-02-21
8	1476	9019	2	2004-02-21
1	1477	1632	3	2004-02-18
2	1477	3254	1	2004-02-18
3	1477	6818	3	2004-02-18
4	1477	6966	2	2004-02-18
5	1477	923	1	2004-02-18
1	1478	1382	2	2004-02-06
2	1478	4566	1	2004-02-06
3	1478	9666	2	2004-02-06
1	1479	9100	1	2004-02-06
2	1479	9323	2	2004-02-06
3	1479	7542	1	2004-02-06
4	1479	827	3	2004-02-06
5	1479	7432	2	2004-02-06
1	1480	8292	2	2004-02-27
2	1480	7197	1	2004-02-27
3	1480	3173	3	2004-02-27
4	1480	3022	2	2004-02-27
5	1480	3477	3	2004-02-27
6	1480	7700	1	2004-02-27
1	1481	4811	3	2004-02-10
2	1481	7767	2	2004-02-10
3	1481	4056	2	2004-02-10
4	1481	4891	2	2004-02-10
5	1481	4481	1	2004-02-10
6	1481	8963	2	2004-02-10
1	1482	7457	3	2004-02-19
2	1482	5025	1	2004-02-19
3	1482	4853	3	2004-02-19
4	1482	5184	3	2004-02-19
5	1482	5633	1	2004-02-19
1	1483	5328	3	2004-02-05
1	1484	8403	2	2004-02-27
2	1484	8390	1	2004-02-27
3	1484	8873	3	2004-02-27
4	1484	6881	2	2004-02-27
1	1485	5032	2	2004-02-01
2	1485	8186	3	2004-02-01
3	1485	3377	2	2004-02-01
4	1485	8214	3	2004-02-01
5	1485	6253	3	2004-02-01
6	1485	8189	3	2004-02-01
7	1485	596	2	2004-02-01
1	1486	3555	2	2004-02-19
2	1486	4705	1	2004-02-19
3	1486	7898	2	2004-02-19
4	1486	9296	2	2004-02-19
5	1486	9022	3	2004-02-19
6	1486	2136	3	2004-02-19
7	1486	6953	3	2004-02-19
8	1486	4660	2	2004-02-19
1	1487	7046	2	2004-02-20
2	1487	4951	2	2004-02-20
3	1487	3729	2	2004-02-20
4	1487	8750	1	2004-02-20
5	1487	5595	2	2004-02-20
1	1488	1092	3	2004-02-24
2	1488	6661	1	2004-02-24
3	1488	3050	2	2004-02-24
1	1489	2353	3	2004-02-28
2	1489	1876	3	2004-02-28
3	1489	7706	1	2004-02-28
4	1489	4672	2	2004-02-28
5	1489	5144	3	2004-02-28
6	1489	9985	3	2004-02-28
7	1489	5169	3	2004-02-28
1	1490	9912	2	2004-02-26
2	1490	558	1	2004-02-26
3	1490	2741	3	2004-02-26
4	1490	1392	2	2004-02-26
5	1490	2900	1	2004-02-26
6	1490	975	3	2004-02-26
7	1490	7913	1	2004-02-26
1	1491	171	3	2004-02-22
2	1491	37	2	2004-02-22
3	1491	7025	1	2004-02-22
4	1491	4187	1	2004-02-22
5	1491	8756	1	2004-02-22
1	1492	7320	1	2004-02-09
2	1492	3872	1	2004-02-09
3	1492	8532	2	2004-02-09
1	1493	9342	2	2004-02-17
2	1493	152	3	2004-02-17
3	1493	4138	1	2004-02-17
4	1493	2208	2	2004-02-17
5	1493	286	1	2004-02-17
6	1493	9623	3	2004-02-17
7	1493	2266	2	2004-02-17
1	1494	3872	3	2004-02-27
2	1494	5329	1	2004-02-27
3	1494	9161	3	2004-02-27
1	1495	9123	1	2004-02-04
2	1495	3927	3	2004-02-04
3	1495	5250	2	2004-02-04
4	1495	5386	3	2004-02-04
5	1495	6961	3	2004-02-04
6	1495	3695	3	2004-02-04
7	1495	9838	1	2004-02-04
1	1496	3125	2	2004-02-13
2	1496	6520	3	2004-02-13
3	1496	2063	1	2004-02-13
4	1496	8188	1	2004-02-13
1	1497	6543	3	2004-02-03
2	1497	6411	1	2004-02-03
3	1497	6503	1	2004-02-03
4	1497	4548	1	2004-02-03
5	1497	1046	1	2004-02-03
1	1498	8056	1	2004-02-27
2	1498	1421	2	2004-02-27
3	1498	7368	2	2004-02-27
4	1498	9396	2	2004-02-27
5	1498	1541	1	2004-02-27
6	1498	5737	3	2004-02-27
7	1498	2683	3	2004-02-27
8	1498	9169	1	2004-02-27
9	1498	2296	2	2004-02-27
1	1499	365	1	2004-02-27
2	1499	8027	1	2004-02-27
3	1499	2236	3	2004-02-27
4	1499	6149	1	2004-02-27
5	1499	6826	2	2004-02-27
6	1499	4297	3	2004-02-27
1	1500	5553	2	2004-02-27
2	1500	239	1	2004-02-27
3	1500	4062	1	2004-02-27
4	1500	8074	1	2004-02-27
5	1500	4520	1	2004-02-27
6	1500	8942	2	2004-02-27
7	1500	9074	2	2004-02-27
8	1500	295	3	2004-02-27
1	1501	5829	3	2004-02-17
2	1501	9074	1	2004-02-17
3	1501	1201	2	2004-02-17
4	1501	902	1	2004-02-17
5	1501	5035	2	2004-02-17
6	1501	9365	1	2004-02-17
7	1501	8027	3	2004-02-17
8	1501	1876	1	2004-02-17
1	1502	318	2	2004-02-08
2	1502	1200	3	2004-02-08
3	1502	9382	1	2004-02-08
4	1502	8830	2	2004-02-08
5	1502	9815	3	2004-02-08
6	1502	3317	2	2004-02-08
7	1502	6674	1	2004-02-08
1	1503	8460	1	2004-02-24
2	1503	2894	3	2004-02-24
3	1503	1383	1	2004-02-24
4	1503	7428	1	2004-02-24
5	1503	3008	3	2004-02-24
6	1503	3207	3	2004-02-24
7	1503	6996	2	2004-02-24
8	1503	2586	3	2004-02-24
9	1503	2916	1	2004-02-24
1	1504	1422	1	2004-02-28
2	1504	5147	3	2004-02-28
3	1504	2905	2	2004-02-28
4	1504	5970	3	2004-02-28
5	1504	2644	2	2004-02-28
6	1504	9460	2	2004-02-28
7	1504	2253	1	2004-02-28
8	1504	6458	3	2004-02-28
9	1504	4101	3	2004-02-28
1	1505	832	1	2004-02-27
2	1505	4823	2	2004-02-27
3	1505	2345	2	2004-02-27
4	1505	5492	3	2004-02-27
5	1505	4014	3	2004-02-27
6	1505	59	3	2004-02-27
1	1506	1628	2	2004-02-15
1	1507	1931	3	2004-02-16
2	1507	7339	2	2004-02-16
3	1507	6708	3	2004-02-16
4	1507	3338	2	2004-02-16
5	1507	3598	2	2004-02-16
6	1507	4877	3	2004-02-16
7	1507	7917	3	2004-02-16
1	1508	322	3	2004-02-09
2	1508	6105	2	2004-02-09
3	1508	9787	3	2004-02-09
4	1508	6309	1	2004-02-09
5	1508	3957	1	2004-02-09
6	1508	2503	2	2004-02-09
7	1508	9375	2	2004-02-09
1	1509	3684	2	2004-02-06
2	1509	3192	3	2004-02-06
3	1509	7970	3	2004-02-06
4	1509	5703	2	2004-02-06
5	1509	5290	3	2004-02-06
6	1509	9295	1	2004-02-06
7	1509	5578	3	2004-02-06
8	1509	8878	1	2004-02-06
1	1510	79	2	2004-02-14
2	1510	2972	1	2004-02-14
1	1511	9061	3	2004-02-26
1	1512	26	3	2004-02-28
2	1512	1025	2	2004-02-28
3	1512	5133	2	2004-02-28
1	1513	4044	3	2004-02-13
2	1513	1621	3	2004-02-13
3	1513	5911	1	2004-02-13
4	1513	248	2	2004-02-13
5	1513	6358	1	2004-02-13
6	1513	8571	2	2004-02-13
7	1513	5566	2	2004-02-13
8	1513	6518	2	2004-02-13
9	1513	3060	2	2004-02-13
1	1514	3583	1	2004-02-21
2	1514	3125	3	2004-02-21
3	1514	6576	3	2004-02-21
4	1514	3143	2	2004-02-21
5	1514	7424	3	2004-02-21
6	1514	2191	3	2004-02-21
7	1514	6178	3	2004-02-21
1	1515	9644	1	2004-02-03
2	1515	2858	2	2004-02-03
3	1515	8245	3	2004-02-03
4	1515	9836	1	2004-02-03
5	1515	5657	3	2004-02-03
6	1515	5641	2	2004-02-03
7	1515	4602	3	2004-02-03
1	1516	5212	1	2004-02-15
2	1516	6675	1	2004-02-15
1	1517	6967	1	2004-02-24
2	1517	870	1	2004-02-24
3	1517	148	1	2004-02-24
4	1517	3719	1	2004-02-24
5	1517	5723	1	2004-02-24
1	1518	2763	3	2004-02-07
2	1518	2931	3	2004-02-07
3	1518	8132	3	2004-02-07
4	1518	5091	2	2004-02-07
5	1518	9817	1	2004-02-07
6	1518	7152	2	2004-02-07
7	1518	2937	2	2004-02-07
8	1518	5356	2	2004-02-07
1	1519	3380	3	2004-02-28
1	1520	9061	1	2004-02-04
2	1520	2526	1	2004-02-04
3	1520	919	2	2004-02-04
4	1520	1237	2	2004-02-04
5	1520	2653	3	2004-02-04
6	1520	1936	3	2004-02-04
7	1520	5439	1	2004-02-04
1	1521	8010	2	2004-02-23
1	1522	8606	3	2004-02-16
2	1522	443	3	2004-02-16
3	1522	6397	1	2004-02-16
1	1523	7787	2	2004-02-20
2	1523	4634	3	2004-02-20
3	1523	8596	3	2004-02-20
4	1523	8392	1	2004-02-20
5	1523	5029	2	2004-02-20
6	1523	2282	1	2004-02-20
7	1523	6422	1	2004-02-20
8	1523	4054	2	2004-02-20
9	1523	4122	3	2004-02-20
1	1524	9341	1	2004-02-07
1	1525	1196	3	2004-02-03
2	1525	6926	3	2004-02-03
3	1525	2555	1	2004-02-03
4	1525	8006	1	2004-02-03
5	1525	8845	2	2004-02-03
6	1525	1681	2	2004-02-03
7	1525	228	2	2004-02-03
1	1526	1080	3	2004-02-20
1	1527	4292	3	2004-02-02
2	1527	6284	2	2004-02-02
3	1527	3727	1	2004-02-02
1	1528	3904	1	2004-02-08
2	1528	1118	1	2004-02-08
3	1528	1780	3	2004-02-08
4	1528	8307	2	2004-02-08
5	1528	3837	3	2004-02-08
6	1528	7422	1	2004-02-08
7	1528	5184	1	2004-02-08
8	1528	1784	2	2004-02-08
9	1528	515	1	2004-02-08
1	1529	7154	1	2004-02-28
2	1529	8990	1	2004-02-28
3	1529	2228	1	2004-02-28
4	1529	5803	1	2004-02-28
1	1530	1616	1	2004-02-04
2	1530	2263	3	2004-02-04
3	1530	6172	2	2004-02-04
1	1531	5501	3	2004-02-24
2	1531	9902	2	2004-02-24
3	1531	1100	3	2004-02-24
4	1531	5180	3	2004-02-24
1	1532	3213	1	2004-02-10
2	1532	4095	3	2004-02-10
3	1532	1271	2	2004-02-10
1	1533	4915	3	2004-02-25
1	1534	4680	1	2004-02-01
2	1534	2353	1	2004-02-01
3	1534	1486	1	2004-02-01
4	1534	6197	1	2004-02-01
5	1534	1800	1	2004-02-01
6	1534	9364	2	2004-02-01
7	1534	3709	3	2004-02-01
8	1534	7755	3	2004-02-01
1	1535	7126	2	2004-02-26
1	1536	4541	2	2004-02-08
2	1536	8548	1	2004-02-08
3	1536	3969	1	2004-02-08
4	1536	3297	2	2004-02-08
5	1536	3409	2	2004-02-08
6	1536	8576	3	2004-02-08
7	1536	7368	1	2004-02-08
1	1537	4836	2	2004-02-03
2	1537	1612	2	2004-02-03
3	1537	5262	3	2004-02-03
4	1537	4253	1	2004-02-03
5	1537	2207	3	2004-02-03
1	1538	2457	1	2004-02-20
2	1538	2106	2	2004-02-20
1	1539	185	1	2004-02-17
2	1539	9050	3	2004-02-17
3	1539	1697	1	2004-02-17
4	1539	4284	3	2004-02-17
5	1539	4720	3	2004-02-17
6	1539	767	2	2004-02-17
7	1539	3029	2	2004-02-17
8	1539	3879	3	2004-02-17
9	1539	8415	2	2004-02-17
1	1540	7131	2	2004-02-12
2	1540	1152	3	2004-02-12
3	1540	2169	3	2004-02-12
4	1540	4640	2	2004-02-12
5	1540	6633	2	2004-02-12
6	1540	6236	2	2004-02-12
7	1540	2377	3	2004-02-12
8	1540	5712	2	2004-02-12
1	1541	6761	3	2004-02-15
2	1541	2079	1	2004-02-15
3	1541	6089	1	2004-02-15
4	1541	6726	1	2004-02-15
5	1541	5996	1	2004-02-15
6	1541	8511	1	2004-02-15
1	1542	6850	3	2004-02-17
2	1542	2841	2	2004-02-17
3	1542	1827	3	2004-02-17
4	1542	9164	2	2004-02-17
5	1542	7008	2	2004-02-17
6	1542	864	1	2004-02-17
7	1542	5305	2	2004-02-17
8	1542	8345	1	2004-02-17
1	1543	917	3	2004-02-16
2	1543	1707	3	2004-02-16
1	1544	9879	1	2004-02-27
2	1544	3127	3	2004-02-27
3	1544	9404	2	2004-02-27
4	1544	210	1	2004-02-27
5	1544	5044	3	2004-02-27
1	1545	4345	3	2004-02-16
2	1545	2939	1	2004-02-16
3	1545	1617	3	2004-02-16
4	1545	3114	2	2004-02-16
5	1545	9927	2	2004-02-16
6	1545	3752	1	2004-02-16
1	1546	8395	1	2004-02-03
1	1547	7489	3	2004-02-10
2	1547	4016	1	2004-02-10
3	1547	8038	3	2004-02-10
1	1548	1836	3	2004-02-13
2	1548	1618	2	2004-02-13
3	1548	7072	2	2004-02-13
4	1548	7774	3	2004-02-13
5	1548	8761	1	2004-02-13
6	1548	8631	3	2004-02-13
7	1548	4720	1	2004-02-13
8	1548	684	1	2004-02-13
9	1548	2208	2	2004-02-13
1	1549	9328	1	2004-02-13
2	1549	4656	3	2004-02-13
1	1550	8168	1	2004-02-01
2	1550	4744	3	2004-02-01
3	1550	4937	1	2004-02-01
4	1550	4517	1	2004-02-01
5	1550	8814	1	2004-02-01
6	1550	4235	3	2004-02-01
1	1551	2069	1	2004-02-09
2	1551	7728	3	2004-02-09
3	1551	793	2	2004-02-09
4	1551	8828	1	2004-02-09
1	1552	2723	3	2004-02-16
2	1552	1822	1	2004-02-16
3	1552	8619	2	2004-02-16
4	1552	676	2	2004-02-16
5	1552	8381	2	2004-02-16
6	1552	6266	3	2004-02-16
1	1553	9455	1	2004-02-24
2	1553	5111	1	2004-02-24
1	1554	7418	3	2004-02-08
2	1554	3604	1	2004-02-08
3	1554	536	1	2004-02-08
4	1554	8624	1	2004-02-08
1	1555	7010	2	2004-02-24
2	1555	397	2	2004-02-24
3	1555	16	2	2004-02-24
4	1555	2584	3	2004-02-24
5	1555	7162	3	2004-02-24
6	1555	9932	2	2004-02-24
7	1555	9780	2	2004-02-24
1	1556	5953	2	2004-02-23
2	1556	3418	3	2004-02-23
3	1556	8159	2	2004-02-23
4	1556	646	3	2004-02-23
5	1556	7213	3	2004-02-23
6	1556	7228	1	2004-02-23
1	1557	9627	2	2004-02-16
2	1557	2770	1	2004-02-16
3	1557	4684	3	2004-02-16
4	1557	9430	2	2004-02-16
5	1557	6548	3	2004-02-16
6	1557	9656	2	2004-02-16
1	1558	2832	2	2004-02-05
2	1558	7189	1	2004-02-05
3	1558	8423	3	2004-02-05
4	1558	7773	2	2004-02-05
5	1558	6703	2	2004-02-05
6	1558	6995	1	2004-02-05
7	1558	9236	1	2004-02-05
1	1559	1072	2	2004-02-24
2	1559	1221	1	2004-02-24
1	1560	2454	1	2004-02-25
2	1560	5867	2	2004-02-25
3	1560	9022	3	2004-02-25
4	1560	7973	2	2004-02-25
5	1560	9688	2	2004-02-25
6	1560	4045	3	2004-02-25
7	1560	2030	1	2004-02-25
8	1560	2460	3	2004-02-25
1	1561	558	1	2004-02-09
2	1561	2971	1	2004-02-09
1	1562	1960	1	2004-02-16
2	1562	2652	2	2004-02-16
3	1562	3231	3	2004-02-16
4	1562	7918	1	2004-02-16
1	1563	2286	1	2004-02-21
2	1563	4364	2	2004-02-21
3	1563	3255	3	2004-02-21
4	1563	3339	2	2004-02-21
5	1563	8519	2	2004-02-21
6	1563	8097	3	2004-02-21
7	1563	7122	1	2004-02-21
1	1564	7084	3	2004-02-02
2	1564	4677	3	2004-02-02
3	1564	1632	3	2004-02-02
1	1565	5440	3	2004-02-24
2	1565	2372	3	2004-02-24
3	1565	1129	3	2004-02-24
4	1565	2040	2	2004-02-24
5	1565	3559	2	2004-02-24
1	1566	1154	3	2004-02-03
2	1566	9964	1	2004-02-03
3	1566	804	2	2004-02-03
4	1566	4696	3	2004-02-03
5	1566	2441	3	2004-02-03
6	1566	7623	2	2004-02-03
7	1566	7279	2	2004-02-03
8	1566	3621	3	2004-02-03
9	1566	1343	3	2004-02-03
1	1567	450	3	2004-02-17
2	1567	1572	2	2004-02-17
3	1567	4202	1	2004-02-17
4	1567	6085	2	2004-02-17
5	1567	1268	3	2004-02-17
6	1567	3160	1	2004-02-17
7	1567	9097	2	2004-02-17
1	1568	3164	3	2004-02-19
2	1568	2967	1	2004-02-19
3	1568	5348	2	2004-02-19
4	1568	7879	3	2004-02-19
5	1568	5648	2	2004-02-19
6	1568	405	1	2004-02-19
7	1568	1125	1	2004-02-19
8	1568	1257	1	2004-02-19
9	1568	4862	2	2004-02-19
1	1569	8184	2	2004-02-15
2	1569	7565	3	2004-02-15
3	1569	7701	2	2004-02-15
4	1569	1072	3	2004-02-15
5	1569	2913	2	2004-02-15
6	1569	9024	2	2004-02-15
1	1570	1061	3	2004-02-14
2	1570	6494	1	2004-02-14
3	1570	547	3	2004-02-14
1	1571	7261	2	2004-02-07
2	1571	8126	3	2004-02-07
3	1571	1715	2	2004-02-07
4	1571	1577	3	2004-02-07
5	1571	3589	3	2004-02-07
6	1571	3298	2	2004-02-07
7	1571	8828	2	2004-02-07
1	1572	2222	2	2004-02-25
2	1572	6129	1	2004-02-25
3	1572	2671	1	2004-02-25
4	1572	4748	1	2004-02-25
1	1573	4247	1	2004-02-01
1	1574	8682	1	2004-02-17
2	1574	6927	1	2004-02-17
3	1574	973	1	2004-02-17
4	1574	6932	3	2004-02-17
5	1574	6435	2	2004-02-17
6	1574	7651	3	2004-02-17
7	1574	9400	3	2004-02-17
1	1575	8150	3	2004-02-09
2	1575	8968	3	2004-02-09
3	1575	4969	2	2004-02-09
4	1575	8942	3	2004-02-09
5	1575	6268	2	2004-02-09
6	1575	1588	2	2004-02-09
1	1576	2540	3	2004-02-08
2	1576	9674	3	2004-02-08
3	1576	8855	2	2004-02-08
4	1576	5298	2	2004-02-08
5	1576	4632	2	2004-02-08
6	1576	6377	3	2004-02-08
7	1576	225	3	2004-02-08
8	1576	3463	3	2004-02-08
9	1576	7432	1	2004-02-08
1	1577	1616	1	2004-02-19
2	1577	580	1	2004-02-19
3	1577	9073	1	2004-02-19
4	1577	3472	3	2004-02-19
5	1577	2552	2	2004-02-19
6	1577	6210	1	2004-02-19
1	1578	1569	1	2004-02-16
1	1579	7475	2	2004-02-16
2	1579	4075	2	2004-02-16
3	1579	6570	1	2004-02-16
4	1579	7307	1	2004-02-16
5	1579	6541	3	2004-02-16
6	1579	5673	3	2004-02-16
1	1580	1899	1	2004-02-06
2	1580	1608	3	2004-02-06
3	1580	4999	3	2004-02-06
4	1580	3173	1	2004-02-06
5	1580	7868	2	2004-02-06
6	1580	6296	2	2004-02-06
1	1581	1112	1	2004-02-08
1	1582	668	1	2004-02-15
2	1582	1296	2	2004-02-15
3	1582	7616	2	2004-02-15
1	1583	611	1	2004-02-04
2	1583	1093	2	2004-02-04
3	1583	7713	2	2004-02-04
1	1584	8923	1	2004-02-26
2	1584	2210	3	2004-02-26
3	1584	1850	1	2004-02-26
4	1584	1083	3	2004-02-26
5	1584	1002	2	2004-02-26
1	1585	8010	1	2004-02-27
1	1586	2079	1	2004-02-12
2	1586	3647	1	2004-02-12
3	1586	7205	1	2004-02-12
1	1587	1384	2	2004-02-21
2	1587	8128	2	2004-02-21
3	1587	3826	3	2004-02-21
4	1587	6914	2	2004-02-21
5	1587	6894	3	2004-02-21
6	1587	9945	2	2004-02-21
1	1588	8623	1	2004-02-27
2	1588	6689	3	2004-02-27
3	1588	3798	3	2004-02-27
4	1588	1201	3	2004-02-27
5	1588	1937	3	2004-02-27
6	1588	8804	3	2004-02-27
7	1588	4551	2	2004-02-27
1	1589	9527	2	2004-02-17
2	1589	3915	2	2004-02-17
3	1589	337	1	2004-02-17
4	1589	4355	1	2004-02-17
1	1590	1533	2	2004-02-20
2	1590	4533	3	2004-02-20
3	1590	3985	3	2004-02-20
4	1590	6987	2	2004-02-20
1	1591	8294	3	2004-02-17
2	1591	320	2	2004-02-17
3	1591	4075	1	2004-02-17
4	1591	8041	2	2004-02-17
5	1591	7351	1	2004-02-17
1	1592	7967	3	2004-02-01
2	1592	8333	2	2004-02-01
3	1592	3511	3	2004-02-01
4	1592	8102	3	2004-02-01
1	1593	7271	1	2004-02-23
2	1593	3996	1	2004-02-23
3	1593	6725	1	2004-02-23
4	1593	9001	3	2004-02-23
5	1593	6393	1	2004-02-23
1	1594	6388	3	2004-02-26
2	1594	4003	3	2004-02-26
3	1594	1111	1	2004-02-26
4	1594	8902	3	2004-02-26
5	1594	5694	1	2004-02-26
6	1594	9308	2	2004-02-26
1	1595	2465	1	2004-02-02
2	1595	8977	2	2004-02-02
3	1595	4012	2	2004-02-02
4	1595	8750	1	2004-02-02
5	1595	2746	2	2004-02-02
6	1595	6089	1	2004-02-02
7	1595	9575	1	2004-02-02
1	1596	5111	1	2004-02-23
2	1596	4002	2	2004-02-23
1	1597	3490	3	2004-02-01
2	1597	6733	3	2004-02-01
3	1597	3710	3	2004-02-01
4	1597	2521	1	2004-02-01
5	1597	5658	2	2004-02-01
6	1597	8388	2	2004-02-01
7	1597	9546	1	2004-02-01
8	1597	9549	2	2004-02-01
9	1597	2846	3	2004-02-01
1	1598	2905	1	2004-02-24
2	1598	8467	3	2004-02-24
3	1598	4208	3	2004-02-24
4	1598	6601	1	2004-02-24
5	1598	7840	1	2004-02-24
6	1598	7513	2	2004-02-24
7	1598	9460	1	2004-02-24
8	1598	3770	1	2004-02-24
1	1599	3835	3	2004-02-11
2	1599	3430	2	2004-02-11
3	1599	3693	2	2004-02-11
1	1600	9967	1	2004-02-08
2	1600	7786	3	2004-02-08
3	1600	6959	1	2004-02-08
4	1600	6933	2	2004-02-08
5	1600	2626	2	2004-02-08
6	1600	3649	1	2004-02-08
7	1600	9345	1	2004-02-08
1	1601	2542	2	2004-02-04
2	1601	7565	2	2004-02-04
3	1601	1660	1	2004-02-04
4	1601	9759	2	2004-02-04
5	1601	7268	1	2004-02-04
1	1602	4469	3	2004-02-21
2	1602	5843	1	2004-02-21
3	1602	9633	1	2004-02-21
4	1602	4986	1	2004-02-21
5	1602	7548	3	2004-02-21
6	1602	2395	3	2004-02-21
7	1602	1743	2	2004-02-21
1	1603	432	2	2004-02-01
2	1603	8924	1	2004-02-01
3	1603	7581	3	2004-02-01
1	1604	9264	1	2004-02-21
2	1604	2295	2	2004-02-21
3	1604	8440	3	2004-02-21
4	1604	5159	3	2004-02-21
5	1604	913	1	2004-02-21
1	1605	5353	1	2004-02-01
2	1605	6479	2	2004-02-01
3	1605	7353	2	2004-02-01
1	1606	9876	3	2004-02-23
2	1606	5513	3	2004-02-23
3	1606	4517	2	2004-02-23
4	1606	2205	2	2004-02-23
5	1606	7260	2	2004-02-23
6	1606	7512	2	2004-02-23
7	1606	2636	1	2004-02-23
1	1607	2009	1	2004-02-11
2	1607	6825	3	2004-02-11
3	1607	2114	1	2004-02-11
4	1607	2721	3	2004-02-11
1	1608	7459	3	2004-02-25
1	1609	9431	2	2004-02-02
2	1609	8859	3	2004-02-02
3	1609	1146	2	2004-02-02
4	1609	2390	2	2004-02-02
5	1609	9040	2	2004-02-02
1	1610	3446	3	2004-02-21
2	1610	6700	2	2004-02-21
3	1610	388	3	2004-02-21
4	1610	5025	3	2004-02-21
5	1610	48	1	2004-02-21
6	1610	85	3	2004-02-21
7	1610	9400	1	2004-02-21
8	1610	477	2	2004-02-21
9	1610	5726	3	2004-02-21
1	1611	955	3	2004-02-02
2	1611	5418	3	2004-02-02
1	1612	2085	2	2004-02-15
2	1612	2493	3	2004-02-15
3	1612	853	1	2004-02-15
4	1612	8204	2	2004-02-15
5	1612	2072	3	2004-02-15
1	1613	2804	2	2004-02-23
2	1613	1395	3	2004-02-23
3	1613	6141	1	2004-02-23
4	1613	3114	1	2004-02-23
5	1613	3521	2	2004-02-23
6	1613	1725	3	2004-02-23
7	1613	4063	3	2004-02-23
1	1614	1204	2	2004-02-05
2	1614	2553	1	2004-02-05
3	1614	7652	1	2004-02-05
4	1614	7934	3	2004-02-05
1	1615	3638	2	2004-02-26
2	1615	998	2	2004-02-26
3	1615	3213	3	2004-02-26
4	1615	6916	2	2004-02-26
5	1615	9876	1	2004-02-26
1	1616	8471	1	2004-02-02
2	1616	368	1	2004-02-02
3	1616	4827	1	2004-02-02
4	1616	5522	3	2004-02-02
5	1616	3629	1	2004-02-02
1	1617	7649	2	2004-02-23
2	1617	1906	1	2004-02-23
3	1617	9462	1	2004-02-23
4	1617	6317	1	2004-02-23
5	1617	41	1	2004-02-23
6	1617	9001	3	2004-02-23
7	1617	3668	3	2004-02-23
1	1618	4099	2	2004-02-05
2	1618	736	3	2004-02-05
3	1618	5791	2	2004-02-05
4	1618	6305	3	2004-02-05
5	1618	9431	2	2004-02-05
6	1618	981	1	2004-02-05
7	1618	1582	3	2004-02-05
8	1618	7106	2	2004-02-05
9	1618	9915	2	2004-02-05
1	1619	9464	3	2004-02-18
2	1619	6346	1	2004-02-18
3	1619	7637	3	2004-02-18
4	1619	6173	1	2004-02-18
5	1619	7847	1	2004-02-18
6	1619	5707	3	2004-02-18
1	1620	917	2	2004-02-26
2	1620	9941	1	2004-02-26
3	1620	6597	1	2004-02-26
4	1620	526	2	2004-02-26
5	1620	5010	1	2004-02-26
1	1621	7830	2	2004-02-01
2	1621	7755	2	2004-02-01
3	1621	9266	2	2004-02-01
4	1621	2036	2	2004-02-01
5	1621	6879	3	2004-02-01
6	1621	5711	1	2004-02-01
7	1621	8463	2	2004-02-01
8	1621	4083	1	2004-02-01
9	1621	409	2	2004-02-01
1	1622	1872	3	2004-02-22
2	1622	7870	3	2004-02-22
3	1622	7862	3	2004-02-22
4	1622	8281	2	2004-02-22
1	1623	285	3	2004-02-22
2	1623	798	1	2004-02-22
3	1623	5372	3	2004-02-22
4	1623	2201	1	2004-02-22
5	1623	262	1	2004-02-22
1	1624	9344	1	2004-02-17
2	1624	6748	2	2004-02-17
3	1624	5702	3	2004-02-17
4	1624	3661	2	2004-02-17
5	1624	5502	1	2004-02-17
6	1624	1712	2	2004-02-17
1	1625	4771	1	2004-02-17
2	1625	6656	2	2004-02-17
3	1625	2496	1	2004-02-17
4	1625	3245	2	2004-02-17
5	1625	3110	2	2004-02-17
6	1625	5360	3	2004-02-17
7	1625	7850	3	2004-02-17
1	1626	3432	2	2004-02-16
2	1626	865	3	2004-02-16
3	1626	132	2	2004-02-16
1	1627	1207	1	2004-02-25
2	1627	1391	2	2004-02-25
3	1627	215	3	2004-02-25
4	1627	1546	1	2004-02-25
5	1627	74	2	2004-02-25
1	1628	2283	2	2004-02-21
2	1628	2089	3	2004-02-21
3	1628	3337	1	2004-02-21
1	1629	3860	3	2004-02-01
1	1630	7142	1	2004-02-21
2	1630	7442	3	2004-02-21
3	1630	8665	3	2004-02-21
4	1630	6578	1	2004-02-21
5	1630	366	2	2004-02-21
6	1630	5000	3	2004-02-21
7	1630	9834	1	2004-02-21
1	1631	9896	1	2004-02-02
2	1631	5571	3	2004-02-02
3	1631	9544	2	2004-02-02
1	1632	5877	2	2004-02-03
2	1632	5467	1	2004-02-03
3	1632	8883	1	2004-02-03
4	1632	1550	3	2004-02-03
5	1632	564	3	2004-02-03
6	1632	7757	1	2004-02-03
7	1632	4779	1	2004-02-03
8	1632	8700	2	2004-02-03
1	1633	1858	2	2004-02-17
2	1633	8265	3	2004-02-17
3	1633	6543	3	2004-02-17
4	1633	2505	3	2004-02-17
5	1633	1212	3	2004-02-17
1	1634	107	1	2004-02-16
1	1635	9784	3	2004-02-11
2	1635	5283	2	2004-02-11
3	1635	358	2	2004-02-11
4	1635	9174	2	2004-02-11
1	1636	2524	1	2004-02-10
2	1636	2502	3	2004-02-10
3	1636	7970	2	2004-02-10
4	1636	6417	3	2004-02-10
5	1636	2226	1	2004-02-10
1	1637	7938	2	2004-02-18
2	1637	8032	3	2004-02-18
3	1637	859	3	2004-02-18
4	1637	5383	2	2004-02-18
5	1637	2377	2	2004-02-18
6	1637	123	1	2004-02-18
1	1638	8413	3	2004-02-07
2	1638	4205	1	2004-02-07
3	1638	9039	1	2004-02-07
4	1638	5921	2	2004-02-07
1	1639	3788	1	2004-02-04
2	1639	4000	1	2004-02-04
3	1639	6507	1	2004-02-04
4	1639	9507	3	2004-02-04
5	1639	9847	2	2004-02-04
6	1639	3506	1	2004-02-04
7	1639	628	2	2004-02-04
1	1640	6819	2	2004-02-11
2	1640	1195	1	2004-02-11
1	1641	5689	2	2004-02-18
2	1641	362	1	2004-02-18
1	1642	5874	3	2004-02-07
2	1642	8208	2	2004-02-07
3	1642	6850	3	2004-02-07
4	1642	268	1	2004-02-07
5	1642	277	1	2004-02-07
6	1642	3984	2	2004-02-07
1	1643	6331	2	2004-02-11
1	1644	4840	1	2004-02-05
2	1644	9262	2	2004-02-05
3	1644	5364	1	2004-02-05
4	1644	9351	3	2004-02-05
5	1644	7614	2	2004-02-05
1	1645	3875	1	2004-02-22
2	1645	5031	2	2004-02-22
3	1645	1768	3	2004-02-22
4	1645	8199	2	2004-02-22
5	1645	9964	2	2004-02-22
1	1646	8920	2	2004-02-17
2	1646	2147	2	2004-02-17
3	1646	9018	1	2004-02-17
4	1646	8961	2	2004-02-17
5	1646	2846	3	2004-02-17
6	1646	2723	1	2004-02-17
7	1646	3536	1	2004-02-17
1	1647	5013	1	2004-02-18
1	1648	2218	3	2004-02-13
2	1648	5974	3	2004-02-13
3	1648	5526	2	2004-02-13
1	1649	8204	1	2004-02-16
2	1649	9138	3	2004-02-16
3	1649	5935	1	2004-02-16
4	1649	5476	3	2004-02-16
5	1649	2442	3	2004-02-16
6	1649	9206	3	2004-02-16
7	1649	3152	2	2004-02-16
1	1650	4944	2	2004-02-25
2	1650	5689	3	2004-02-25
3	1650	3183	1	2004-02-25
1	1651	3153	1	2004-02-15
1	1652	8520	3	2004-02-25
2	1652	9737	2	2004-02-25
3	1652	6251	1	2004-02-25
4	1652	3007	2	2004-02-25
5	1652	901	2	2004-02-25
6	1652	9886	3	2004-02-25
7	1652	4323	2	2004-02-25
1	1653	6428	1	2004-02-09
2	1653	312	1	2004-02-09
3	1653	412	3	2004-02-09
4	1653	2621	2	2004-02-09
5	1653	7984	1	2004-02-09
6	1653	4919	3	2004-02-09
7	1653	8992	2	2004-02-09
8	1653	7236	3	2004-02-09
1	1654	8942	1	2004-02-21
1	1655	3397	2	2004-02-19
1	1656	3621	2	2004-02-01
2	1656	8349	2	2004-02-01
3	1656	1388	1	2004-02-01
4	1656	7596	3	2004-02-01
5	1656	2207	1	2004-02-01
6	1656	9014	1	2004-02-01
1	1657	9736	1	2004-02-17
2	1657	3827	3	2004-02-17
3	1657	2640	1	2004-02-17
4	1657	7504	2	2004-02-17
1	1658	2818	1	2004-02-04
2	1658	8151	2	2004-02-04
1	1659	7468	3	2004-02-16
2	1659	6235	3	2004-02-16
3	1659	579	2	2004-02-16
4	1659	872	2	2004-02-16
5	1659	1498	1	2004-02-16
6	1659	9917	1	2004-02-16
7	1659	1629	2	2004-02-16
1	1660	8493	2	2004-02-28
2	1660	8313	3	2004-02-28
3	1660	7051	1	2004-02-28
4	1660	9233	2	2004-02-28
5	1660	7568	2	2004-02-28
6	1660	1700	3	2004-02-28
7	1660	1574	3	2004-02-28
1	1661	3057	3	2004-02-18
2	1661	3212	2	2004-02-18
3	1661	510	1	2004-02-18
4	1661	5788	1	2004-02-18
5	1661	6872	2	2004-02-18
6	1661	6406	1	2004-02-18
7	1661	3110	2	2004-02-18
1	1662	2553	1	2004-02-19
2	1662	8808	1	2004-02-19
3	1662	6105	1	2004-02-19
4	1662	8157	3	2004-02-19
1	1663	940	3	2004-02-28
2	1663	8230	2	2004-02-28
3	1663	3097	3	2004-02-28
4	1663	7280	3	2004-02-28
5	1663	877	2	2004-02-28
6	1663	4581	3	2004-02-28
7	1663	5191	3	2004-02-28
8	1663	2180	1	2004-02-28
1	1664	5738	2	2004-02-26
2	1664	1786	1	2004-02-26
1	1665	4201	2	2004-02-14
2	1665	2863	2	2004-02-14
3	1665	3546	1	2004-02-14
4	1665	9292	2	2004-02-14
1	1666	721	1	2004-02-28
1	1667	7659	3	2004-02-23
1	1668	7175	1	2004-02-13
1	1669	6190	2	2004-02-06
2	1669	6614	3	2004-02-06
1	1670	6802	3	2004-02-27
2	1670	5505	1	2004-02-27
3	1670	684	2	2004-02-27
4	1670	2433	3	2004-02-27
5	1670	2138	1	2004-02-27
6	1670	8844	3	2004-02-27
7	1670	7138	2	2004-02-27
8	1670	2809	2	2004-02-27
9	1670	3606	3	2004-02-27
1	1671	7306	3	2004-02-17
2	1671	876	2	2004-02-17
3	1671	7069	1	2004-02-17
4	1671	4079	3	2004-02-17
5	1671	9452	1	2004-02-17
6	1671	7188	2	2004-02-17
1	1672	6545	1	2004-02-09
2	1672	5867	2	2004-02-09
3	1672	3115	1	2004-02-09
4	1672	8745	2	2004-02-09
5	1672	8716	1	2004-02-09
6	1672	5907	2	2004-02-09
1	1673	5751	1	2004-02-23
2	1673	9272	1	2004-02-23
3	1673	2552	2	2004-02-23
4	1673	33	1	2004-02-23
5	1673	4230	3	2004-02-23
1	1674	3074	1	2004-02-20
2	1674	1460	3	2004-02-20
3	1674	7025	2	2004-02-20
4	1674	1944	2	2004-02-20
5	1674	497	1	2004-02-20
6	1674	8119	2	2004-02-20
7	1674	5446	2	2004-02-20
8	1674	4137	2	2004-02-20
1	1675	2708	1	2004-02-05
1	1676	9960	1	2004-02-12
2	1676	5802	2	2004-02-12
3	1676	8295	3	2004-02-12
4	1676	6688	3	2004-02-12
5	1676	7816	2	2004-02-12
6	1676	4327	3	2004-02-12
7	1676	9481	2	2004-02-12
8	1676	419	3	2004-02-12
1	1677	2467	2	2004-02-04
2	1677	5251	1	2004-02-04
3	1677	6068	3	2004-02-04
4	1677	2295	1	2004-02-04
5	1677	698	2	2004-02-04
1	1678	5709	2	2004-02-24
2	1678	3249	1	2004-02-24
3	1678	3690	1	2004-02-24
4	1678	6108	3	2004-02-24
1	1679	3187	2	2004-02-03
2	1679	7105	3	2004-02-03
1	1680	677	3	2004-02-27
2	1680	2635	1	2004-02-27
3	1680	8501	1	2004-02-27
4	1680	8459	3	2004-02-27
5	1680	3990	2	2004-02-27
1	1681	2094	1	2004-02-05
2	1681	5758	3	2004-02-05
3	1681	9743	2	2004-02-05
4	1681	3789	1	2004-02-05
5	1681	7823	3	2004-02-05
1	1682	4498	2	2004-02-19
2	1682	753	2	2004-02-19
3	1682	4451	2	2004-02-19
4	1682	8145	1	2004-02-19
5	1682	6720	2	2004-02-19
6	1682	24	1	2004-02-19
1	1683	6162	1	2004-02-02
2	1683	468	1	2004-02-02
3	1683	701	1	2004-02-02
4	1683	8501	2	2004-02-02
5	1683	2792	2	2004-02-02
6	1683	1464	3	2004-02-02
7	1683	1250	2	2004-02-02
8	1683	5514	2	2004-02-02
1	1684	9654	3	2004-02-05
2	1684	8944	2	2004-02-05
3	1684	5670	3	2004-02-05
4	1684	7082	2	2004-02-05
5	1684	435	3	2004-02-05
6	1684	5114	2	2004-02-05
1	1685	5791	3	2004-02-28
1	1686	8023	2	2004-02-15
2	1686	2028	2	2004-02-15
3	1686	337	2	2004-02-15
4	1686	9803	1	2004-02-15
5	1686	9562	3	2004-02-15
6	1686	324	3	2004-02-15
1	1687	2366	3	2004-02-17
2	1687	398	3	2004-02-17
3	1687	4502	1	2004-02-17
1	1688	35	2	2004-02-09
2	1688	7435	2	2004-02-09
3	1688	2887	2	2004-02-09
4	1688	7963	2	2004-02-09
5	1688	8993	3	2004-02-09
6	1688	8483	3	2004-02-09
7	1688	9557	3	2004-02-09
8	1688	8250	3	2004-02-09
1	1689	6989	3	2004-02-19
2	1689	1925	3	2004-02-19
3	1689	5716	2	2004-02-19
4	1689	7772	3	2004-02-19
1	1690	5092	2	2004-02-27
2	1690	2853	3	2004-02-27
3	1690	518	1	2004-02-27
4	1690	2892	3	2004-02-27
5	1690	9115	1	2004-02-27
6	1690	8304	3	2004-02-27
7	1690	9418	2	2004-02-27
8	1690	8550	2	2004-02-27
9	1690	633	2	2004-02-27
1	1691	5008	3	2004-02-28
2	1691	8337	1	2004-02-28
1	1692	7261	3	2004-02-21
2	1692	9838	1	2004-02-21
3	1692	4693	1	2004-02-21
4	1692	928	3	2004-02-21
5	1692	9865	1	2004-02-21
1	1693	4722	3	2004-02-26
2	1693	4343	2	2004-02-26
3	1693	1683	2	2004-02-26
4	1693	2975	2	2004-02-26
5	1693	6238	3	2004-02-26
6	1693	2713	2	2004-02-26
7	1693	763	3	2004-02-26
8	1693	2357	1	2004-02-26
1	1694	9729	2	2004-02-13
2	1694	4830	1	2004-02-13
3	1694	1377	2	2004-02-13
4	1694	700	1	2004-02-13
5	1694	2862	3	2004-02-13
1	1695	2937	3	2004-02-25
2	1695	7380	2	2004-02-25
3	1695	2696	2	2004-02-25
1	1696	5270	1	2004-02-11
2	1696	7044	3	2004-02-11
3	1696	165	2	2004-02-11
4	1696	4382	3	2004-02-11
5	1696	9937	3	2004-02-11
1	1697	1647	3	2004-02-02
2	1697	662	1	2004-02-02
1	1698	5690	1	2004-02-13
2	1698	3199	3	2004-02-13
3	1698	4408	3	2004-02-13
4	1698	3794	1	2004-02-13
5	1698	1751	3	2004-02-13
6	1698	3149	3	2004-02-13
7	1698	8970	1	2004-02-13
1	1699	2564	2	2004-02-14
2	1699	6186	2	2004-02-14
3	1699	5008	3	2004-02-14
4	1699	3236	2	2004-02-14
5	1699	8190	3	2004-02-14
1	1700	2389	3	2004-02-09
2	1700	7078	3	2004-02-09
3	1700	5165	1	2004-02-09
4	1700	9396	3	2004-02-09
5	1700	9934	1	2004-02-09
6	1700	5710	3	2004-02-09
7	1700	5857	1	2004-02-09
8	1700	2256	3	2004-02-09
1	1701	1288	3	2004-02-16
2	1701	9539	2	2004-02-16
1	1702	9327	3	2004-02-10
2	1702	5194	1	2004-02-10
3	1702	5052	1	2004-02-10
4	1702	8512	1	2004-02-10
5	1702	3143	3	2004-02-10
6	1702	7132	1	2004-02-10
1	1703	3488	2	2004-02-02
2	1703	5371	3	2004-02-02
3	1703	9055	3	2004-02-02
4	1703	713	1	2004-02-02
5	1703	6020	1	2004-02-02
6	1703	4865	3	2004-02-02
1	1704	3954	1	2004-02-23
2	1704	9021	3	2004-02-23
3	1704	3482	3	2004-02-23
4	1704	9223	2	2004-02-23
5	1704	5439	2	2004-02-23
6	1704	9701	2	2004-02-23
7	1704	9196	1	2004-02-23
1	1705	1691	2	2004-02-07
2	1705	5757	1	2004-02-07
3	1705	5313	1	2004-02-07
4	1705	2654	1	2004-02-07
5	1705	1294	1	2004-02-07
6	1705	7151	3	2004-02-07
7	1705	7939	1	2004-02-07
1	1706	4492	3	2004-02-24
2	1706	8628	3	2004-02-24
1	1707	8	3	2004-02-16
2	1707	7564	2	2004-02-16
3	1707	5578	3	2004-02-16
4	1707	894	1	2004-02-16
5	1707	1657	2	2004-02-16
1	1708	4944	2	2004-02-09
2	1708	1715	1	2004-02-09
3	1708	4638	1	2004-02-09
4	1708	9841	2	2004-02-09
1	1709	4261	3	2004-02-07
1	1710	8092	1	2004-02-26
2	1710	5126	2	2004-02-26
3	1710	1464	2	2004-02-26
4	1710	5003	1	2004-02-26
5	1710	2225	3	2004-02-26
6	1710	7432	3	2004-02-26
7	1710	2515	1	2004-02-26
8	1710	2141	2	2004-02-26
9	1710	5256	3	2004-02-26
1	1711	9428	2	2004-02-13
2	1711	7572	2	2004-02-13
3	1711	5369	3	2004-02-13
4	1711	3767	1	2004-02-13
5	1711	5968	1	2004-02-13
6	1711	2224	1	2004-02-13
7	1711	5527	2	2004-02-13
1	1712	8641	2	2004-02-20
2	1712	7943	1	2004-02-20
3	1712	6613	1	2004-02-20
4	1712	5385	1	2004-02-20
5	1712	6861	3	2004-02-20
6	1712	6964	3	2004-02-20
7	1712	6554	2	2004-02-20
8	1712	3989	2	2004-02-20
9	1712	79	3	2004-02-20
1	1713	5703	1	2004-02-03
2	1713	7950	1	2004-02-03
3	1713	5281	2	2004-02-03
4	1713	1758	1	2004-02-03
5	1713	4396	1	2004-02-03
6	1713	6326	1	2004-02-03
7	1713	1555	1	2004-02-03
1	1714	6789	1	2004-02-07
2	1714	7667	2	2004-02-07
3	1714	8162	1	2004-02-07
4	1714	7467	3	2004-02-07
5	1714	1013	3	2004-02-07
6	1714	2086	1	2004-02-07
7	1714	5216	3	2004-02-07
8	1714	1978	1	2004-02-07
9	1714	9018	3	2004-02-07
1	1715	1174	2	2004-02-24
2	1715	4959	1	2004-02-24
3	1715	8610	3	2004-02-24
1	1716	5186	2	2004-02-28
2	1716	9797	2	2004-02-28
3	1716	5984	3	2004-02-28
4	1716	1587	3	2004-02-28
5	1716	5621	2	2004-02-28
6	1716	7380	1	2004-02-28
1	1717	6615	1	2004-02-05
1	1718	1631	3	2004-02-04
2	1718	5155	1	2004-02-04
3	1718	7186	2	2004-02-04
1	1719	8176	1	2004-02-11
2	1719	2188	2	2004-02-11
3	1719	8336	2	2004-02-11
4	1719	1156	2	2004-02-11
5	1719	7446	3	2004-02-11
6	1719	4793	3	2004-02-11
7	1719	7892	3	2004-02-11
8	1719	9383	2	2004-02-11
1	1720	3062	1	2004-02-03
2	1720	5673	3	2004-02-03
3	1720	2338	1	2004-02-03
4	1720	3036	2	2004-02-03
5	1720	6706	2	2004-02-03
6	1720	4834	2	2004-02-03
1	1721	796	1	2004-02-16
2	1721	7676	3	2004-02-16
3	1721	8731	1	2004-02-16
4	1721	7147	2	2004-02-16
1	1722	7165	1	2004-02-04
2	1722	8148	1	2004-02-04
3	1722	3694	2	2004-02-04
1	1723	2024	2	2004-02-24
2	1723	5788	3	2004-02-24
1	1724	4890	2	2004-02-24
2	1724	7503	1	2004-02-24
3	1724	2917	2	2004-02-24
4	1724	5033	1	2004-02-24
5	1724	2856	2	2004-02-24
6	1724	6593	2	2004-02-24
7	1724	8575	2	2004-02-24
1	1725	542	1	2004-02-16
2	1725	5306	3	2004-02-16
3	1725	3901	3	2004-02-16
4	1725	605	3	2004-02-16
5	1725	4188	3	2004-02-16
6	1725	860	3	2004-02-16
7	1725	6177	2	2004-02-16
8	1725	2742	2	2004-02-16
9	1725	8314	2	2004-02-16
1	1726	9641	1	2004-02-28
2	1726	6753	3	2004-02-28
3	1726	6070	1	2004-02-28
1	1727	2476	3	2004-02-14
2	1727	2697	2	2004-02-14
3	1727	4243	1	2004-02-14
4	1727	6064	3	2004-02-14
5	1727	2172	3	2004-02-14
1	1728	2027	1	2004-02-19
2	1728	4895	1	2004-02-19
3	1728	4333	1	2004-02-19
4	1728	4706	2	2004-02-19
5	1728	2928	1	2004-02-19
6	1728	2187	3	2004-02-19
7	1728	3791	3	2004-02-19
8	1728	9049	2	2004-02-19
9	1728	2600	1	2004-02-19
1	1729	8597	2	2004-02-07
2	1729	4983	1	2004-02-07
3	1729	886	1	2004-02-07
4	1729	9116	2	2004-02-07
5	1729	715	1	2004-02-07
6	1729	4544	2	2004-02-07
1	1730	2848	3	2004-02-09
2	1730	9243	2	2004-02-09
3	1730	8148	1	2004-02-09
4	1730	2157	3	2004-02-09
5	1730	8431	2	2004-02-09
6	1730	8720	1	2004-02-09
7	1730	52	2	2004-02-09
8	1730	7295	3	2004-02-09
1	1731	3756	3	2004-02-02
2	1731	5024	2	2004-02-02
1	1732	8443	2	2004-02-28
2	1732	539	1	2004-02-28
3	1732	5454	3	2004-02-28
1	1733	797	1	2004-02-18
2	1733	3238	3	2004-02-18
3	1733	1987	1	2004-02-18
4	1733	6135	3	2004-02-18
5	1733	1937	3	2004-02-18
6	1733	1559	1	2004-02-18
7	1733	8183	2	2004-02-18
8	1733	9884	1	2004-02-18
1	1734	2311	1	2004-02-28
2	1734	6166	1	2004-02-28
3	1734	2506	1	2004-02-28
4	1734	2630	3	2004-02-28
5	1734	5220	2	2004-02-28
6	1734	7312	2	2004-02-28
7	1734	6688	1	2004-02-28
8	1734	5532	3	2004-02-28
9	1734	3838	1	2004-02-28
1	1735	7127	2	2004-02-23
2	1735	4827	3	2004-02-23
3	1735	9769	2	2004-02-23
4	1735	6568	1	2004-02-23
5	1735	4474	3	2004-02-23
6	1735	3758	1	2004-02-23
7	1735	1727	2	2004-02-23
8	1735	2259	2	2004-02-23
9	1735	5094	3	2004-02-23
1	1736	2954	3	2004-02-28
2	1736	5160	3	2004-02-28
3	1736	690	1	2004-02-28
4	1736	2565	3	2004-02-28
5	1736	2627	3	2004-02-28
6	1736	5634	3	2004-02-28
1	1737	7945	2	2004-02-19
2	1737	2147	1	2004-02-19
3	1737	7176	2	2004-02-19
1	1738	6912	3	2004-02-23
2	1738	5463	1	2004-02-23
3	1738	4515	3	2004-02-23
1	1739	2788	3	2004-02-27
1	1740	2867	2	2004-02-26
2	1740	225	2	2004-02-26
3	1740	7434	3	2004-02-26
4	1740	1466	3	2004-02-26
5	1740	9871	3	2004-02-26
1	1741	894	2	2004-02-10
2	1741	9711	2	2004-02-10
1	1742	3899	3	2004-02-16
2	1742	4938	3	2004-02-16
3	1742	7751	2	2004-02-16
4	1742	2100	2	2004-02-16
5	1742	8949	2	2004-02-16
1	1743	7343	1	2004-02-27
2	1743	6392	3	2004-02-27
3	1743	1	3	2004-02-27
4	1743	5050	3	2004-02-27
5	1743	1526	2	2004-02-27
6	1743	3060	1	2004-02-27
7	1743	2300	3	2004-02-27
1	1744	7051	3	2004-02-16
2	1744	6046	2	2004-02-16
3	1744	2331	3	2004-02-16
4	1744	16	1	2004-02-16
5	1744	3111	3	2004-02-16
6	1744	453	1	2004-02-16
7	1744	6205	3	2004-02-16
8	1744	4366	1	2004-02-16
9	1744	5009	2	2004-02-16
1	1745	6002	2	2004-02-07
2	1745	5203	3	2004-02-07
3	1745	3948	1	2004-02-07
4	1745	5372	3	2004-02-07
1	1746	7224	3	2004-02-01
2	1746	4215	3	2004-02-01
3	1746	9029	3	2004-02-01
4	1746	6633	3	2004-02-01
5	1746	331	1	2004-02-01
6	1746	7277	2	2004-02-01
1	1747	2343	1	2004-02-16
2	1747	1839	3	2004-02-16
3	1747	7000	3	2004-02-16
4	1747	6645	1	2004-02-16
5	1747	7705	1	2004-02-16
6	1747	8162	3	2004-02-16
7	1747	4439	2	2004-02-16
8	1747	3798	1	2004-02-16
1	1748	5338	2	2004-02-04
1	1749	365	2	2004-02-28
2	1749	9402	3	2004-02-28
3	1749	1678	1	2004-02-28
4	1749	927	2	2004-02-28
5	1749	88	3	2004-02-28
6	1749	557	3	2004-02-28
7	1749	8873	3	2004-02-28
1	1750	616	3	2004-02-25
2	1750	4850	1	2004-02-25
3	1750	7799	2	2004-02-25
1	1751	8804	3	2004-02-07
2	1751	9261	3	2004-02-07
1	1752	406	3	2004-02-05
2	1752	6652	1	2004-02-05
3	1752	7446	3	2004-02-05
1	1753	3353	1	2004-02-21
2	1753	9162	2	2004-02-21
3	1753	1247	2	2004-02-21
4	1753	5914	3	2004-02-21
5	1753	7762	3	2004-02-21
6	1753	2181	3	2004-02-21
1	1754	153	2	2004-02-02
2	1754	8284	3	2004-02-02
3	1754	9295	3	2004-02-02
4	1754	8266	2	2004-02-02
5	1754	9183	2	2004-02-02
6	1754	3156	2	2004-02-02
7	1754	2030	3	2004-02-02
8	1754	2383	2	2004-02-02
9	1754	85	1	2004-02-02
1	1755	376	1	2004-02-27
2	1755	3482	1	2004-02-27
3	1755	361	2	2004-02-27
4	1755	3541	2	2004-02-27
5	1755	3466	2	2004-02-27
1	1756	439	1	2004-02-04
1	1757	6030	3	2004-02-19
2	1757	8242	3	2004-02-19
3	1757	3826	3	2004-02-19
4	1757	9956	1	2004-02-19
5	1757	9657	2	2004-02-19
6	1757	8440	1	2004-02-19
7	1757	8826	1	2004-02-19
8	1757	2589	3	2004-02-19
9	1757	5764	2	2004-02-19
1	1758	979	1	2004-02-12
2	1758	5982	1	2004-02-12
3	1758	2965	1	2004-02-12
4	1758	1038	3	2004-02-12
5	1758	2059	3	2004-02-12
1	1759	8625	2	2004-02-22
2	1759	4826	3	2004-02-22
1	1760	5186	1	2004-02-03
2	1760	8955	1	2004-02-03
3	1760	7033	1	2004-02-03
4	1760	179	3	2004-02-03
5	1760	8669	1	2004-02-03
6	1760	9117	2	2004-02-03
7	1760	2574	1	2004-02-03
8	1760	7092	2	2004-02-03
9	1760	1461	3	2004-02-03
1	1761	934	3	2004-02-02
2	1761	1590	2	2004-02-02
3	1761	6356	1	2004-02-02
4	1761	9024	2	2004-02-02
5	1761	2302	2	2004-02-02
6	1761	5574	1	2004-02-02
1	1762	9462	1	2004-02-15
2	1762	6493	3	2004-02-15
3	1762	7775	3	2004-02-15
4	1762	659	2	2004-02-15
5	1762	2678	1	2004-02-15
1	1763	9512	1	2004-02-12
2	1763	1539	1	2004-02-12
3	1763	8095	3	2004-02-12
4	1763	3635	3	2004-02-12
1	1764	7192	2	2004-02-08
2	1764	743	1	2004-02-08
3	1764	1821	1	2004-02-08
4	1764	4775	3	2004-02-08
5	1764	8783	1	2004-02-08
6	1764	7380	3	2004-02-08
7	1764	7416	1	2004-02-08
8	1764	1561	1	2004-02-08
1	1765	5300	2	2004-02-10
2	1765	4025	2	2004-02-10
3	1765	4329	3	2004-02-10
1	1766	5029	1	2004-02-02
2	1766	8325	2	2004-02-02
1	1767	8459	2	2004-02-07
2	1767	9759	2	2004-02-07
3	1767	4200	3	2004-02-07
4	1767	5896	2	2004-02-07
5	1767	8606	3	2004-02-07
6	1767	8724	2	2004-02-07
7	1767	2232	2	2004-02-07
1	1768	3916	3	2004-02-28
2	1768	1157	3	2004-02-28
3	1768	9770	2	2004-02-28
4	1768	8295	3	2004-02-28
1	1769	7938	3	2004-02-06
2	1769	2691	3	2004-02-06
3	1769	2537	3	2004-02-06
4	1769	4870	3	2004-02-06
5	1769	2651	2	2004-02-06
6	1769	7742	1	2004-02-06
7	1769	6977	3	2004-02-06
8	1769	5396	3	2004-02-06
1	1770	744	1	2004-02-18
1	1771	8607	1	2004-02-22
2	1771	6678	3	2004-02-22
3	1771	8408	2	2004-02-22
4	1771	3544	1	2004-02-22
5	1771	2312	2	2004-02-22
6	1771	7989	3	2004-02-22
1	1772	2013	3	2004-02-13
2	1772	2228	3	2004-02-13
3	1772	4547	3	2004-02-13
1	1773	8058	2	2004-02-01
1	1774	7052	3	2004-02-05
1	1775	6558	2	2004-02-20
1	1776	5186	2	2004-02-19
1	1777	4606	2	2004-02-10
2	1777	4007	2	2004-02-10
3	1777	1552	1	2004-02-10
4	1777	5791	3	2004-02-10
5	1777	8865	3	2004-02-10
1	1778	9951	2	2004-02-18
2	1778	8697	2	2004-02-18
3	1778	4753	2	2004-02-18
1	1779	2373	2	2004-02-26
2	1779	5896	2	2004-02-26
3	1779	2183	3	2004-02-26
1	1780	1615	2	2004-02-04
2	1780	7861	3	2004-02-04
3	1780	4163	3	2004-02-04
4	1780	4672	1	2004-02-04
5	1780	7794	1	2004-02-04
1	1781	1194	1	2004-02-11
2	1781	7537	1	2004-02-11
3	1781	2359	3	2004-02-11
1	1782	427	2	2004-02-08
2	1782	5770	1	2004-02-08
3	1782	1294	3	2004-02-08
4	1782	6923	1	2004-02-08
5	1782	3326	2	2004-02-08
6	1782	313	3	2004-02-08
7	1782	1508	2	2004-02-08
8	1782	7837	3	2004-02-08
1	1783	3704	3	2004-02-20
2	1783	4359	1	2004-02-20
3	1783	8691	3	2004-02-20
1	1784	9984	1	2004-02-25
1	1785	4526	1	2004-02-16
2	1785	9605	3	2004-02-16
3	1785	5252	3	2004-02-16
4	1785	5340	3	2004-02-16
5	1785	4901	1	2004-02-16
6	1785	6061	1	2004-02-16
7	1785	4598	1	2004-02-16
1	1786	9541	1	2004-02-15
2	1786	6288	3	2004-02-15
3	1786	1427	3	2004-02-15
4	1786	9016	1	2004-02-15
5	1786	9612	2	2004-02-15
6	1786	7164	1	2004-02-15
7	1786	1117	1	2004-02-15
8	1786	3626	1	2004-02-15
9	1786	9542	3	2004-02-15
1	1787	8057	1	2004-02-02
2	1787	7446	1	2004-02-02
3	1787	4802	1	2004-02-02
4	1787	956	2	2004-02-02
5	1787	2228	1	2004-02-02
1	1788	6252	3	2004-02-18
2	1788	9021	2	2004-02-18
3	1788	2048	2	2004-02-18
4	1788	9020	1	2004-02-18
5	1788	7875	1	2004-02-18
6	1788	3886	3	2004-02-18
7	1788	1521	2	2004-02-18
1	1789	8852	3	2004-02-07
1	1790	9801	1	2004-02-09
2	1790	4460	2	2004-02-09
3	1790	911	1	2004-02-09
4	1790	3596	3	2004-02-09
1	1791	8801	1	2004-02-02
2	1791	5912	3	2004-02-02
3	1791	4690	3	2004-02-02
1	1792	3367	2	2004-02-12
2	1792	6741	1	2004-02-12
3	1792	1894	3	2004-02-12
4	1792	5871	1	2004-02-12
5	1792	3712	2	2004-02-12
6	1792	4455	3	2004-02-12
1	1793	2527	1	2004-02-05
2	1793	7869	2	2004-02-05
3	1793	4690	3	2004-02-05
4	1793	7597	1	2004-02-05
5	1793	3344	1	2004-02-05
1	1794	3821	1	2004-02-02
2	1794	9104	1	2004-02-02
3	1794	4081	1	2004-02-02
4	1794	310	3	2004-02-02
5	1794	3059	2	2004-02-02
1	1795	2878	2	2004-02-16
2	1795	2531	2	2004-02-16
3	1795	5377	1	2004-02-16
4	1795	957	1	2004-02-16
5	1795	7068	3	2004-02-16
6	1795	668	1	2004-02-16
7	1795	839	1	2004-02-16
1	1796	1198	2	2004-02-22
2	1796	2226	2	2004-02-22
1	1797	6556	1	2004-02-17
2	1797	6458	3	2004-02-17
3	1797	8129	3	2004-02-17
4	1797	2183	1	2004-02-17
5	1797	4740	3	2004-02-17
6	1797	1058	2	2004-02-17
7	1797	7626	3	2004-02-17
8	1797	4249	3	2004-02-17
9	1797	8535	2	2004-02-17
1	1798	8043	2	2004-02-27
2	1798	31	1	2004-02-27
3	1798	897	2	2004-02-27
4	1798	2803	2	2004-02-27
5	1798	4861	3	2004-02-27
1	1799	653	1	2004-02-20
2	1799	5762	2	2004-02-20
3	1799	7848	3	2004-02-20
4	1799	1088	2	2004-02-20
5	1799	4944	2	2004-02-20
1	1800	9857	2	2004-02-11
2	1800	8266	3	2004-02-11
3	1800	463	3	2004-02-11
1	1801	7484	3	2004-02-23
1	1802	9562	1	2004-02-01
2	1802	8722	2	2004-02-01
3	1802	6434	2	2004-02-01
4	1802	2142	3	2004-02-01
5	1802	2042	3	2004-02-01
6	1802	2856	2	2004-02-01
7	1802	564	1	2004-02-01
8	1802	8931	1	2004-02-01
1	1803	5493	2	2004-02-23
2	1803	9944	3	2004-02-23
3	1803	7454	3	2004-02-23
4	1803	8777	3	2004-02-23
5	1803	1886	3	2004-02-23
6	1803	6215	1	2004-02-23
7	1803	209	2	2004-02-23
8	1803	6770	2	2004-02-23
1	1804	5997	3	2004-02-05
2	1804	9354	2	2004-02-05
3	1804	296	3	2004-02-05
4	1804	6979	3	2004-02-05
1	1805	1783	3	2004-02-16
1	1806	7018	2	2004-02-02
2	1806	8620	1	2004-02-02
3	1806	7705	3	2004-02-02
4	1806	8167	2	2004-02-02
5	1806	5470	3	2004-02-02
6	1806	3386	3	2004-02-02
7	1806	3218	3	2004-02-02
8	1806	6649	1	2004-02-02
9	1806	5942	3	2004-02-02
1	1807	8218	1	2004-02-03
2	1807	7308	1	2004-02-03
3	1807	9308	3	2004-02-03
4	1807	9237	2	2004-02-03
5	1807	7438	2	2004-02-03
6	1807	9938	2	2004-02-03
1	1808	2117	1	2004-02-27
2	1808	7323	2	2004-02-27
3	1808	9987	1	2004-02-27
4	1808	4884	2	2004-02-27
5	1808	3112	1	2004-02-27
6	1808	3581	2	2004-02-27
7	1808	3746	3	2004-02-27
1	1809	1963	1	2004-02-01
2	1809	5595	1	2004-02-01
3	1809	4291	1	2004-02-01
4	1809	7453	2	2004-02-01
5	1809	9090	3	2004-02-01
6	1809	1871	2	2004-02-01
7	1809	4588	2	2004-02-01
1	1810	2450	2	2004-02-13
2	1810	954	2	2004-02-13
3	1810	5198	2	2004-02-13
4	1810	9528	3	2004-02-13
1	1811	7440	1	2004-02-10
2	1811	5390	1	2004-02-10
3	1811	4067	3	2004-02-10
4	1811	6065	1	2004-02-10
5	1811	3909	2	2004-02-10
1	1812	9766	2	2004-02-24
2	1812	4954	3	2004-02-24
3	1812	7778	3	2004-02-24
1	1813	3265	1	2004-02-11
2	1813	7766	3	2004-02-11
3	1813	2322	3	2004-02-11
4	1813	1518	3	2004-02-11
5	1813	1538	3	2004-02-11
6	1813	2794	2	2004-02-11
7	1813	6588	3	2004-02-11
8	1813	7124	1	2004-02-11
1	1814	8623	2	2004-02-12
2	1814	6603	2	2004-02-12
3	1814	5295	2	2004-02-12
1	1815	7745	2	2004-02-03
2	1815	6436	2	2004-02-03
3	1815	3115	3	2004-02-03
4	1815	4180	2	2004-02-03
1	1816	1323	3	2004-02-24
2	1816	169	3	2004-02-24
1	1817	7324	1	2004-02-25
2	1817	939	2	2004-02-25
3	1817	6224	2	2004-02-25
4	1817	8307	3	2004-02-25
5	1817	5154	1	2004-02-25
1	1818	8408	1	2004-02-04
2	1818	6338	1	2004-02-04
3	1818	5540	2	2004-02-04
4	1818	8306	3	2004-02-04
5	1818	6164	3	2004-02-04
6	1818	5206	2	2004-02-04
7	1818	8074	2	2004-02-04
1	1819	4746	3	2004-02-02
2	1819	1763	1	2004-02-02
3	1819	5897	1	2004-02-02
4	1819	8172	1	2004-02-02
5	1819	1488	3	2004-02-02
6	1819	3949	3	2004-02-02
7	1819	6898	1	2004-02-02
8	1819	190	1	2004-02-02
1	1820	2809	2	2004-02-14
2	1820	2877	3	2004-02-14
3	1820	585	1	2004-02-14
1	1821	8935	3	2004-02-06
1	1822	767	3	2004-02-01
2	1822	7179	1	2004-02-01
3	1822	6253	1	2004-02-01
4	1822	1537	1	2004-02-01
5	1822	3484	1	2004-02-01
6	1822	6386	3	2004-02-01
1	1823	8727	2	2004-02-21
1	1824	409	3	2004-02-24
1	1825	40	2	2004-02-02
1	1826	3061	3	2004-02-20
2	1826	5351	2	2004-02-20
3	1826	1449	3	2004-02-20
4	1826	6323	3	2004-02-20
1	1827	4043	1	2004-02-21
2	1827	3494	1	2004-02-21
3	1827	345	3	2004-02-21
4	1827	2440	1	2004-02-21
5	1827	7551	1	2004-02-21
6	1827	96	2	2004-02-21
7	1827	4043	1	2004-02-21
8	1827	9010	1	2004-02-21
9	1827	943	1	2004-02-21
1	1828	8601	1	2004-02-15
1	1829	8702	1	2004-02-27
2	1829	5696	1	2004-02-27
3	1829	1976	3	2004-02-27
4	1829	5065	1	2004-02-27
5	1829	8186	3	2004-02-27
6	1829	3073	2	2004-02-27
7	1829	629	1	2004-02-27
1	1830	5758	2	2004-02-27
2	1830	9699	1	2004-02-27
3	1830	8249	3	2004-02-27
4	1830	1728	3	2004-02-27
5	1830	9855	1	2004-02-27
6	1830	1772	3	2004-02-27
7	1830	7978	1	2004-02-27
8	1830	9432	2	2004-02-27
1	1831	3727	1	2004-02-10
2	1831	5785	3	2004-02-10
3	1831	6784	2	2004-02-10
4	1831	9968	2	2004-02-10
5	1831	1085	1	2004-02-10
6	1831	5062	3	2004-02-10
7	1831	7518	2	2004-02-10
8	1831	7909	2	2004-02-10
1	1832	859	2	2004-02-11
2	1832	2157	3	2004-02-11
3	1832	4861	1	2004-02-11
4	1832	2509	3	2004-02-11
1	1833	6418	1	2004-02-09
2	1833	3521	1	2004-02-09
3	1833	8558	2	2004-02-09
4	1833	9620	3	2004-02-09
5	1833	6760	2	2004-02-09
6	1833	6484	2	2004-02-09
7	1833	9442	2	2004-02-09
1	1834	6921	2	2004-02-01
2	1834	7045	3	2004-02-01
3	1834	3723	1	2004-02-01
1	1835	1602	2	2004-02-02
2	1835	380	3	2004-02-02
3	1835	8485	2	2004-02-02
4	1835	1220	3	2004-02-02
1	1836	5520	1	2004-02-21
2	1836	8425	2	2004-02-21
3	1836	7560	3	2004-02-21
4	1836	8216	1	2004-02-21
1	1837	4214	1	2004-02-04
2	1837	74	2	2004-02-04
3	1837	6428	1	2004-02-04
4	1837	8537	3	2004-02-04
5	1837	6396	3	2004-02-04
6	1837	6049	2	2004-02-04
7	1837	2817	3	2004-02-04
8	1837	1923	1	2004-02-04
1	1838	1774	1	2004-02-23
2	1838	8589	3	2004-02-23
3	1838	1246	3	2004-02-23
4	1838	921	1	2004-02-23
1	1839	7592	1	2004-02-06
2	1839	1030	2	2004-02-06
3	1839	668	3	2004-02-06
4	1839	2050	3	2004-02-06
5	1839	8483	3	2004-02-06
6	1839	1944	1	2004-02-06
1	1840	2473	2	2004-02-16
2	1840	7102	2	2004-02-16
3	1840	8636	2	2004-02-16
4	1840	3580	3	2004-02-16
1	1841	1896	1	2004-02-07
2	1841	585	3	2004-02-07
3	1841	3401	1	2004-02-07
4	1841	3507	2	2004-02-07
1	1842	3654	1	2004-02-04
2	1842	963	3	2004-02-04
3	1842	6941	1	2004-02-04
4	1842	2495	3	2004-02-04
5	1842	8325	3	2004-02-04
6	1842	3661	3	2004-02-04
7	1842	5285	3	2004-02-04
8	1842	6840	3	2004-02-04
9	1842	1741	3	2004-02-04
1	1843	3124	2	2004-02-07
2	1843	4410	2	2004-02-07
3	1843	9348	2	2004-02-07
1	1844	3553	2	2004-02-07
2	1844	4861	1	2004-02-07
3	1844	8683	3	2004-02-07
4	1844	9908	3	2004-02-07
5	1844	6951	2	2004-02-07
6	1844	3967	1	2004-02-07
1	1845	9896	1	2004-02-03
2	1845	6185	1	2004-02-03
3	1845	5017	3	2004-02-03
1	1846	5016	3	2004-02-20
2	1846	6879	1	2004-02-20
3	1846	3967	1	2004-02-20
4	1846	6485	3	2004-02-20
5	1846	926	2	2004-02-20
6	1846	6182	1	2004-02-20
1	1847	5367	2	2004-02-07
2	1847	6946	2	2004-02-07
3	1847	7757	3	2004-02-07
4	1847	7602	2	2004-02-07
5	1847	8615	1	2004-02-07
6	1847	3249	2	2004-02-07
1	1848	7314	3	2004-02-06
2	1848	7327	1	2004-02-06
3	1848	9378	2	2004-02-06
4	1848	107	1	2004-02-06
5	1848	8978	2	2004-02-06
6	1848	1136	1	2004-02-06
7	1848	9421	2	2004-02-06
1	1849	167	3	2004-02-21
2	1849	1076	3	2004-02-21
3	1849	2442	3	2004-02-21
4	1849	385	2	2004-02-21
1	1850	9486	1	2004-02-15
2	1850	6371	3	2004-02-15
3	1850	3471	2	2004-02-15
4	1850	624	2	2004-02-15
5	1850	6052	3	2004-02-15
6	1850	9867	3	2004-02-15
7	1850	752	3	2004-02-15
1	1851	2277	2	2004-02-08
2	1851	1969	2	2004-02-08
3	1851	2008	2	2004-02-08
4	1851	3043	1	2004-02-08
1	1852	5824	2	2004-02-01
2	1852	7170	1	2004-02-01
3	1852	1118	1	2004-02-01
4	1852	7943	1	2004-02-01
5	1852	4218	2	2004-02-01
1	1853	3371	2	2004-02-04
2	1853	135	3	2004-02-04
1	1854	5765	2	2004-02-21
2	1854	3752	3	2004-02-21
3	1854	6085	2	2004-02-21
4	1854	7206	1	2004-02-21
5	1854	8830	1	2004-02-21
6	1854	5211	2	2004-02-21
7	1854	5224	2	2004-02-21
8	1854	6640	1	2004-02-21
9	1854	8070	1	2004-02-21
1	1855	1505	3	2004-02-21
2	1855	2245	1	2004-02-21
3	1855	5757	3	2004-02-21
4	1855	4051	3	2004-02-21
5	1855	8958	3	2004-02-21
6	1855	1135	1	2004-02-21
7	1855	8622	3	2004-02-21
8	1855	6560	2	2004-02-21
1	1856	1389	2	2004-02-23
2	1856	9662	3	2004-02-23
3	1856	7246	3	2004-02-23
4	1856	8886	2	2004-02-23
1	1857	2140	2	2004-02-20
2	1857	286	3	2004-02-20
3	1857	4605	2	2004-02-20
4	1857	5339	2	2004-02-20
5	1857	4152	2	2004-02-20
6	1857	6271	1	2004-02-20
7	1857	3692	1	2004-02-20
8	1857	8599	1	2004-02-20
1	1858	1535	2	2004-02-24
2	1858	7637	3	2004-02-24
3	1858	2542	2	2004-02-24
4	1858	3184	3	2004-02-24
5	1858	350	2	2004-02-24
6	1858	8331	1	2004-02-24
7	1858	917	3	2004-02-24
8	1858	387	2	2004-02-24
9	1858	2953	2	2004-02-24
1	1859	9876	2	2004-02-26
2	1859	8184	3	2004-02-26
3	1859	7704	2	2004-02-26
4	1859	5930	1	2004-02-26
5	1859	6012	3	2004-02-26
1	1860	172	3	2004-02-22
1	1861	3011	2	2004-02-28
2	1861	6834	2	2004-02-28
3	1861	1792	3	2004-02-28
4	1861	9122	1	2004-02-28
5	1861	6890	1	2004-02-28
6	1861	6229	3	2004-02-28
7	1861	7207	2	2004-02-28
8	1861	5239	2	2004-02-28
1	1862	8631	2	2004-02-03
2	1862	476	2	2004-02-03
3	1862	5628	1	2004-02-03
4	1862	4301	2	2004-02-03
5	1862	1169	3	2004-02-03
6	1862	3734	2	2004-02-03
7	1862	5927	1	2004-02-03
1	1863	8593	3	2004-02-22
2	1863	8015	2	2004-02-22
3	1863	4007	2	2004-02-22
4	1863	9233	3	2004-02-22
5	1863	131	1	2004-02-22
6	1863	413	3	2004-02-22
7	1863	6875	3	2004-02-22
1	1864	7998	3	2004-02-10
2	1864	4458	3	2004-02-10
3	1864	7872	3	2004-02-10
4	1864	3345	2	2004-02-10
5	1864	8758	1	2004-02-10
6	1864	1517	3	2004-02-10
7	1864	7618	1	2004-02-10
8	1864	6353	2	2004-02-10
9	1864	4930	1	2004-02-10
1	1865	4210	1	2004-02-03
1	1866	8434	1	2004-02-25
2	1866	1133	2	2004-02-25
1	1867	3780	3	2004-02-04
2	1867	2862	1	2004-02-04
3	1867	9861	2	2004-02-04
4	1867	1648	3	2004-02-04
5	1867	4487	3	2004-02-04
6	1867	3111	3	2004-02-04
7	1867	8359	2	2004-02-04
8	1867	3579	3	2004-02-04
9	1867	4948	3	2004-02-04
1	1868	6013	3	2004-02-23
2	1868	10	3	2004-02-23
3	1868	3737	1	2004-02-23
4	1868	2735	3	2004-02-23
5	1868	264	2	2004-02-23
6	1868	8274	1	2004-02-23
7	1868	9051	3	2004-02-23
1	1869	8697	3	2004-02-22
2	1869	1405	3	2004-02-22
1	1870	2771	1	2004-02-08
2	1870	1456	1	2004-02-08
3	1870	28	3	2004-02-08
4	1870	8948	1	2004-02-08
5	1870	4614	1	2004-02-08
6	1870	1238	3	2004-02-08
7	1870	2017	1	2004-02-08
1	1871	8425	1	2004-02-11
2	1871	3609	2	2004-02-11
3	1871	4119	1	2004-02-11
1	1872	506	2	2004-02-08
2	1872	3079	1	2004-02-08
3	1872	7371	2	2004-02-08
4	1872	4919	3	2004-02-08
5	1872	2003	2	2004-02-08
1	1873	3963	3	2004-02-21
2	1873	176	3	2004-02-21
3	1873	8858	2	2004-02-21
4	1873	735	3	2004-02-21
5	1873	6932	2	2004-02-21
6	1873	1318	1	2004-02-21
7	1873	6649	2	2004-02-21
8	1873	6573	2	2004-02-21
1	1874	355	3	2004-02-27
2	1874	7134	2	2004-02-27
3	1874	5156	3	2004-02-27
1	1875	1265	3	2004-02-26
2	1875	4257	1	2004-02-26
3	1875	7537	1	2004-02-26
4	1875	6243	3	2004-02-26
5	1875	396	1	2004-02-26
6	1875	2615	1	2004-02-26
1	1876	5274	2	2004-02-12
1	1877	3418	2	2004-02-23
2	1877	3503	3	2004-02-23
3	1877	4178	1	2004-02-23
4	1877	1165	3	2004-02-23
5	1877	8332	1	2004-02-23
6	1877	9643	1	2004-02-23
7	1877	3869	3	2004-02-23
8	1877	5702	1	2004-02-23
1	1878	7810	3	2004-02-16
2	1878	7329	2	2004-02-16
3	1878	8306	1	2004-02-16
4	1878	8909	2	2004-02-16
5	1878	8262	3	2004-02-16
6	1878	4411	1	2004-02-16
7	1878	1860	3	2004-02-16
8	1878	252	2	2004-02-16
1	1879	3844	2	2004-02-02
2	1879	1474	3	2004-02-02
3	1879	2789	3	2004-02-02
4	1879	7823	3	2004-02-02
5	1879	3273	1	2004-02-02
6	1879	6304	1	2004-02-02
7	1879	8616	2	2004-02-02
8	1879	4680	3	2004-02-02
1	1880	405	3	2004-02-18
2	1880	6173	1	2004-02-18
3	1880	5425	2	2004-02-18
4	1880	8303	2	2004-02-18
5	1880	7840	2	2004-02-18
1	1881	9396	1	2004-02-14
2	1881	3514	3	2004-02-14
3	1881	905	3	2004-02-14
4	1881	8327	3	2004-02-14
5	1881	7868	3	2004-02-14
6	1881	840	1	2004-02-14
1	1882	1567	2	2004-02-11
2	1882	4478	3	2004-02-11
3	1882	8804	3	2004-02-11
4	1882	4164	3	2004-02-11
5	1882	5882	1	2004-02-11
6	1882	1376	1	2004-02-11
7	1882	3687	1	2004-02-11
1	1883	302	2	2004-02-20
1	1884	5570	1	2004-02-21
2	1884	7799	3	2004-02-21
3	1884	9945	2	2004-02-21
4	1884	6398	1	2004-02-21
5	1884	472	1	2004-02-21
1	1885	6383	2	2004-02-26
2	1885	5417	3	2004-02-26
3	1885	7406	3	2004-02-26
4	1885	9012	2	2004-02-26
1	1886	7756	1	2004-02-07
2	1886	1115	3	2004-02-07
3	1886	7726	3	2004-02-07
1	1887	9458	1	2004-02-08
2	1887	4114	3	2004-02-08
3	1887	3388	2	2004-02-08
1	1888	824	1	2004-02-26
2	1888	3345	3	2004-02-26
3	1888	1298	1	2004-02-26
4	1888	2720	2	2004-02-26
5	1888	5286	3	2004-02-26
6	1888	5971	1	2004-02-26
1	1889	3769	2	2004-02-01
2	1889	3533	3	2004-02-01
3	1889	8090	1	2004-02-01
4	1889	2398	1	2004-02-01
5	1889	2919	2	2004-02-01
6	1889	5568	1	2004-02-01
7	1889	9950	1	2004-02-01
8	1889	7710	1	2004-02-01
1	1890	3409	1	2004-02-13
2	1890	9321	3	2004-02-13
3	1890	9531	2	2004-02-13
4	1890	1736	3	2004-02-13
5	1890	2376	2	2004-02-13
6	1890	7822	2	2004-02-13
1	1891	4344	3	2004-02-01
2	1891	344	3	2004-02-01
3	1891	4210	2	2004-02-01
4	1891	9385	2	2004-02-01
5	1891	8256	3	2004-02-01
6	1891	4933	1	2004-02-01
7	1891	8149	2	2004-02-01
8	1891	8632	1	2004-02-01
1	1892	3243	1	2004-02-16
2	1892	5000	2	2004-02-16
3	1892	6553	1	2004-02-16
4	1892	1763	2	2004-02-16
5	1892	4175	3	2004-02-16
1	1893	5780	1	2004-02-14
2	1893	999	2	2004-02-14
3	1893	4585	3	2004-02-14
4	1893	2259	3	2004-02-14
5	1893	2050	1	2004-02-14
1	1894	8634	1	2004-02-10
2	1894	4296	1	2004-02-10
3	1894	4205	3	2004-02-10
4	1894	7495	1	2004-02-10
5	1894	2117	3	2004-02-10
6	1894	7361	2	2004-02-10
7	1894	7047	1	2004-02-10
8	1894	4809	1	2004-02-10
9	1894	7192	1	2004-02-10
1	1895	7445	3	2004-02-11
2	1895	7788	3	2004-02-11
3	1895	8418	1	2004-02-11
4	1895	176	1	2004-02-11
5	1895	349	3	2004-02-11
6	1895	2599	2	2004-02-11
7	1895	685	3	2004-02-11
8	1895	3941	3	2004-02-11
1	1896	2348	2	2004-02-22
2	1896	7025	3	2004-02-22
3	1896	7744	2	2004-02-22
4	1896	7743	1	2004-02-22
5	1896	2407	2	2004-02-22
1	1897	9346	3	2004-02-28
2	1897	8727	3	2004-02-28
3	1897	306	3	2004-02-28
4	1897	8330	1	2004-02-28
5	1897	3721	3	2004-02-28
6	1897	9708	3	2004-02-28
7	1897	7193	3	2004-02-28
1	1898	9110	3	2004-02-11
2	1898	3220	3	2004-02-11
3	1898	3431	1	2004-02-11
4	1898	8283	2	2004-02-11
5	1898	4457	3	2004-02-11
6	1898	5689	2	2004-02-11
1	1899	4556	2	2004-02-16
2	1899	3272	1	2004-02-16
3	1899	9095	3	2004-02-16
4	1899	1899	3	2004-02-16
1	1900	3719	3	2004-02-14
2	1900	4434	1	2004-02-14
3	1900	7473	3	2004-02-14
4	1900	9682	1	2004-02-14
5	1900	8616	3	2004-02-14
6	1900	6741	1	2004-02-14
7	1900	5947	1	2004-02-14
8	1900	9035	1	2004-02-14
1	1901	1110	3	2004-02-21
2	1901	4904	1	2004-02-21
1	1902	5892	2	2004-02-17
1	1903	2438	1	2004-02-25
2	1903	986	1	2004-02-25
3	1903	1710	3	2004-02-25
1	1904	879	1	2004-02-01
2	1904	7445	3	2004-02-01
3	1904	6628	1	2004-02-01
4	1904	361	3	2004-02-01
5	1904	1941	2	2004-02-01
6	1904	7942	3	2004-02-01
1	1905	2023	3	2004-02-06
2	1905	7567	2	2004-02-06
3	1905	576	1	2004-02-06
4	1905	6164	1	2004-02-06
5	1905	2124	3	2004-02-06
6	1905	1163	1	2004-02-06
7	1905	6323	2	2004-02-06
8	1905	8235	3	2004-02-06
1	1906	8736	2	2004-02-16
2	1906	9908	1	2004-02-16
1	1907	4796	3	2004-02-04
2	1907	1189	3	2004-02-04
3	1907	4082	3	2004-02-04
1	1908	6219	1	2004-02-07
2	1908	6211	3	2004-02-07
3	1908	3089	1	2004-02-07
4	1908	1217	1	2004-02-07
5	1908	9734	3	2004-02-07
6	1908	7003	2	2004-02-07
7	1908	8931	2	2004-02-07
8	1908	1180	3	2004-02-07
1	1909	5578	1	2004-02-18
2	1909	1746	3	2004-02-18
3	1909	8300	2	2004-02-18
4	1909	5521	1	2004-02-18
5	1909	485	2	2004-02-18
1	1910	4084	3	2004-02-25
2	1910	7555	2	2004-02-25
3	1910	9576	3	2004-02-25
4	1910	2060	2	2004-02-25
5	1910	2565	1	2004-02-25
1	1911	6091	2	2004-02-07
2	1911	3640	1	2004-02-07
3	1911	7995	2	2004-02-07
4	1911	8433	2	2004-02-07
5	1911	1213	2	2004-02-07
6	1911	6768	1	2004-02-07
7	1911	8234	2	2004-02-07
8	1911	8401	2	2004-02-07
1	1912	7784	1	2004-02-02
2	1912	5442	3	2004-02-02
3	1912	7802	3	2004-02-02
4	1912	834	1	2004-02-02
5	1912	1751	1	2004-02-02
6	1912	8850	3	2004-02-02
7	1912	7175	1	2004-02-02
8	1912	9508	2	2004-02-02
1	1913	1895	3	2004-02-23
2	1913	784	1	2004-02-23
3	1913	3808	3	2004-02-23
4	1913	3525	2	2004-02-23
5	1913	1668	2	2004-02-23
6	1913	2560	3	2004-02-23
7	1913	6397	3	2004-02-23
8	1913	9296	2	2004-02-23
9	1913	6007	1	2004-02-23
1	1914	5598	3	2004-02-13
2	1914	5654	2	2004-02-13
3	1914	3133	2	2004-02-13
1	1915	2824	2	2004-02-09
2	1915	5068	2	2004-02-09
3	1915	2582	3	2004-02-09
4	1915	1038	2	2004-02-09
5	1915	3765	2	2004-02-09
1	1916	4359	3	2004-02-11
2	1916	3125	3	2004-02-11
3	1916	5362	2	2004-02-11
1	1917	6065	2	2004-02-06
2	1917	1021	3	2004-02-06
3	1917	9605	2	2004-02-06
4	1917	4050	1	2004-02-06
5	1917	7034	3	2004-02-06
6	1917	9060	3	2004-02-06
7	1917	7710	1	2004-02-06
1	1918	1634	2	2004-02-11
2	1918	562	2	2004-02-11
3	1918	2896	2	2004-02-11
4	1918	4666	3	2004-02-11
5	1918	7602	2	2004-02-11
6	1918	9217	3	2004-02-11
7	1918	3998	2	2004-02-11
1	1919	8654	3	2004-02-13
2	1919	6524	2	2004-02-13
3	1919	7559	2	2004-02-13
4	1919	5303	2	2004-02-13
1	1920	6734	3	2004-02-16
2	1920	4665	3	2004-02-16
3	1920	4367	3	2004-02-16
4	1920	983	3	2004-02-16
5	1920	5818	3	2004-02-16
6	1920	5537	2	2004-02-16
7	1920	8064	3	2004-02-16
8	1920	316	1	2004-02-16
9	1920	4552	2	2004-02-16
1	1921	8892	1	2004-02-19
2	1921	8756	2	2004-02-19
3	1921	5974	2	2004-02-19
1	1922	1089	3	2004-02-10
1	1923	4487	1	2004-02-21
2	1923	6956	1	2004-02-21
3	1923	6886	2	2004-02-21
4	1923	9557	3	2004-02-21
5	1923	7572	2	2004-02-21
6	1923	1908	2	2004-02-21
7	1923	7312	2	2004-02-21
8	1923	7392	2	2004-02-21
1	1924	583	2	2004-02-17
2	1924	4448	2	2004-02-17
1	1925	992	3	2004-02-11
2	1925	9613	2	2004-02-11
1	1926	1586	2	2004-02-03
2	1926	4837	3	2004-02-03
3	1926	9165	3	2004-02-03
4	1926	3377	2	2004-02-03
5	1926	1799	1	2004-02-03
6	1926	2679	3	2004-02-03
7	1926	6915	1	2004-02-03
1	1927	1888	1	2004-02-27
2	1927	9277	2	2004-02-27
3	1927	1924	1	2004-02-27
4	1927	3651	1	2004-02-27
1	1928	2037	3	2004-02-17
2	1928	6306	3	2004-02-17
1	1929	1947	2	2004-02-25
2	1929	2989	2	2004-02-25
1	1930	7400	2	2004-02-09
2	1930	6007	3	2004-02-09
3	1930	5216	2	2004-02-09
1	1931	8676	1	2004-02-12
2	1931	2091	3	2004-02-12
3	1931	2547	2	2004-02-12
4	1931	6467	3	2004-02-12
5	1931	1002	2	2004-02-12
6	1931	4323	2	2004-02-12
7	1931	7533	2	2004-02-12
1	1932	425	3	2004-02-01
2	1932	5276	3	2004-02-01
3	1932	3128	1	2004-02-01
1	1933	5484	1	2004-02-20
2	1933	8841	2	2004-02-20
1	1934	5060	3	2004-02-10
2	1934	4814	2	2004-02-10
3	1934	2716	3	2004-02-10
4	1934	679	1	2004-02-10
5	1934	5404	1	2004-02-10
6	1934	770	2	2004-02-10
1	1935	9018	3	2004-02-11
2	1935	279	2	2004-02-11
3	1935	6366	3	2004-02-11
4	1935	7279	1	2004-02-11
5	1935	8962	2	2004-02-11
6	1935	6007	1	2004-02-11
7	1935	7051	3	2004-02-11
8	1935	8339	1	2004-02-11
9	1935	4348	1	2004-02-11
1	1936	7311	3	2004-02-23
2	1936	9561	3	2004-02-23
3	1936	3990	1	2004-02-23
4	1936	9273	3	2004-02-23
5	1936	2278	3	2004-02-23
6	1936	6905	1	2004-02-23
7	1936	4419	1	2004-02-23
8	1936	9401	1	2004-02-23
1	1937	740	2	2004-02-15
2	1937	8068	3	2004-02-15
1	1938	9477	2	2004-02-20
2	1938	3996	3	2004-02-20
3	1938	2208	2	2004-02-20
4	1938	4867	2	2004-02-20
5	1938	6838	2	2004-02-20
1	1939	1672	3	2004-02-15
2	1939	5254	1	2004-02-15
1	1940	1496	1	2004-02-24
2	1940	1231	3	2004-02-24
3	1940	9253	3	2004-02-24
4	1940	1979	1	2004-02-24
5	1940	3355	1	2004-02-24
6	1940	5999	3	2004-02-24
1	1941	4404	3	2004-02-24
2	1941	7247	3	2004-02-24
3	1941	6859	3	2004-02-24
1	1942	9603	2	2004-02-05
2	1942	7094	3	2004-02-05
3	1942	1433	3	2004-02-05
4	1942	9211	1	2004-02-05
5	1942	8153	3	2004-02-05
6	1942	871	1	2004-02-05
7	1942	9946	2	2004-02-05
1	1943	4151	1	2004-02-05
2	1943	2936	3	2004-02-05
3	1943	225	1	2004-02-05
4	1943	8039	3	2004-02-05
5	1943	9858	3	2004-02-05
6	1943	5614	2	2004-02-05
7	1943	6228	2	2004-02-05
8	1943	1452	1	2004-02-05
9	1943	4253	1	2004-02-05
1	1944	1927	2	2004-02-06
1	1945	7817	1	2004-02-01
2	1945	1608	1	2004-02-01
1	1946	4726	3	2004-02-14
2	1946	2009	2	2004-02-14
3	1946	8067	3	2004-02-14
4	1946	965	2	2004-02-14
5	1946	2838	1	2004-02-14
1	1947	555	1	2004-02-22
2	1947	9591	1	2004-02-22
3	1947	7266	3	2004-02-22
4	1947	4354	3	2004-02-22
5	1947	1565	1	2004-02-22
6	1947	128	1	2004-02-22
7	1947	4138	2	2004-02-22
8	1947	7716	2	2004-02-22
9	1947	9754	1	2004-02-22
1	1948	9385	3	2004-02-10
2	1948	5580	1	2004-02-10
1	1949	2722	3	2004-02-02
2	1949	6553	1	2004-02-02
3	1949	2349	2	2004-02-02
4	1949	2096	3	2004-02-02
5	1949	1726	2	2004-02-02
6	1949	8871	1	2004-02-02
1	1950	7667	2	2004-02-20
2	1950	6989	1	2004-02-20
3	1950	8198	2	2004-02-20
4	1950	2172	3	2004-02-20
5	1950	2000	3	2004-02-20
1	1951	8109	2	2004-02-28
2	1951	8984	2	2004-02-28
3	1951	5979	1	2004-02-28
4	1951	8479	3	2004-02-28
5	1951	8034	1	2004-02-28
6	1951	1735	3	2004-02-28
7	1951	2058	3	2004-02-28
8	1951	9912	3	2004-02-28
9	1951	3115	3	2004-02-28
1	1952	4115	1	2004-02-15
2	1952	953	2	2004-02-15
3	1952	8387	1	2004-02-15
4	1952	8519	3	2004-02-15
1	1953	1289	3	2004-02-28
2	1953	189	3	2004-02-28
3	1953	7051	3	2004-02-28
4	1953	9971	3	2004-02-28
5	1953	5127	1	2004-02-28
6	1953	7353	2	2004-02-28
7	1953	767	1	2004-02-28
8	1953	2618	2	2004-02-28
1	1954	1718	1	2004-02-02
2	1954	800	1	2004-02-02
3	1954	1020	3	2004-02-02
4	1954	9437	1	2004-02-02
5	1954	5946	1	2004-02-02
1	1955	7000	3	2004-02-28
2	1955	8161	3	2004-02-28
3	1955	7248	1	2004-02-28
4	1955	8999	2	2004-02-28
5	1955	8326	3	2004-02-28
6	1955	5067	1	2004-02-28
7	1955	5706	2	2004-02-28
8	1955	2025	2	2004-02-28
9	1955	323	2	2004-02-28
1	1956	440	1	2004-02-15
2	1956	7193	2	2004-02-15
3	1956	5719	3	2004-02-15
4	1956	3619	3	2004-02-15
5	1956	6880	1	2004-02-15
6	1956	5593	2	2004-02-15
1	1957	7441	2	2004-02-22
2	1957	6352	1	2004-02-22
3	1957	7595	1	2004-02-22
4	1957	8146	3	2004-02-22
5	1957	7075	3	2004-02-22
6	1957	3361	1	2004-02-22
1	1958	490	2	2004-02-27
1	1959	3338	3	2004-02-18
1	1960	1772	1	2004-02-02
2	1960	4829	3	2004-02-02
3	1960	9688	1	2004-02-02
4	1960	1721	3	2004-02-02
5	1960	3238	3	2004-02-02
6	1960	6900	1	2004-02-02
7	1960	8333	1	2004-02-02
8	1960	2666	3	2004-02-02
1	1961	7167	2	2004-02-21
2	1961	4164	3	2004-02-21
3	1961	4399	3	2004-02-21
4	1961	9624	2	2004-02-21
5	1961	6432	2	2004-02-21
6	1961	3292	3	2004-02-21
7	1961	7367	3	2004-02-21
8	1961	7416	3	2004-02-21
1	1962	9001	1	2004-02-27
2	1962	2850	3	2004-02-27
3	1962	1494	2	2004-02-27
1	1963	6917	2	2004-02-15
2	1963	7571	1	2004-02-15
3	1963	3958	1	2004-02-15
1	1964	7912	1	2004-02-25
2	1964	3215	2	2004-02-25
3	1964	8433	1	2004-02-25
4	1964	2332	3	2004-02-25
5	1964	9765	2	2004-02-25
1	1965	6099	3	2004-02-01
2	1965	8635	1	2004-02-01
3	1965	8355	2	2004-02-01
1	1966	6350	2	2004-02-13
2	1966	4098	2	2004-02-13
1	1967	1430	1	2004-02-20
2	1967	199	3	2004-02-20
3	1967	3785	1	2004-02-20
4	1967	7595	2	2004-02-20
5	1967	9196	3	2004-02-20
1	1968	6490	3	2004-02-07
2	1968	9766	2	2004-02-07
3	1968	5089	2	2004-02-07
4	1968	114	2	2004-02-07
5	1968	6454	2	2004-02-07
6	1968	7990	1	2004-02-07
7	1968	1394	2	2004-02-07
8	1968	1669	1	2004-02-07
1	1969	2960	3	2004-02-28
1	1970	8419	2	2004-02-08
2	1970	8940	3	2004-02-08
1	1971	272	2	2004-02-08
2	1971	6642	1	2004-02-08
3	1971	8671	1	2004-02-08
1	1972	1659	2	2004-02-20
2	1972	9577	1	2004-02-20
3	1972	8413	2	2004-02-20
4	1972	1697	1	2004-02-20
5	1972	2341	2	2004-02-20
6	1972	1927	2	2004-02-20
7	1972	6189	1	2004-02-20
8	1972	8304	2	2004-02-20
1	1973	3173	1	2004-02-28
2	1973	2880	3	2004-02-28
3	1973	1214	1	2004-02-28
4	1973	2909	3	2004-02-28
5	1973	8210	2	2004-02-28
6	1973	6305	3	2004-02-28
7	1973	1870	2	2004-02-28
8	1973	1447	1	2004-02-28
1	1974	7488	2	2004-02-28
2	1974	6453	2	2004-02-28
3	1974	3928	2	2004-02-28
1	1975	2445	3	2004-02-25
2	1975	188	2	2004-02-25
3	1975	8600	1	2004-02-25
4	1975	6874	1	2004-02-25
5	1975	9465	2	2004-02-25
6	1975	8063	2	2004-02-25
7	1975	4951	3	2004-02-25
8	1975	1650	2	2004-02-25
9	1975	215	1	2004-02-25
1	1976	5452	1	2004-02-27
2	1976	704	3	2004-02-27
3	1976	5094	3	2004-02-27
4	1976	3055	1	2004-02-27
5	1976	8867	2	2004-02-27
6	1976	9491	3	2004-02-27
7	1976	824	3	2004-02-27
1	1977	2780	3	2004-02-02
2	1977	5689	3	2004-02-02
3	1977	7593	3	2004-02-02
4	1977	4128	3	2004-02-02
5	1977	8934	2	2004-02-02
6	1977	9676	1	2004-02-02
7	1977	695	2	2004-02-02
8	1977	3156	1	2004-02-02
9	1977	4506	3	2004-02-02
1	1978	3059	3	2004-02-03
2	1978	8826	2	2004-02-03
3	1978	6536	3	2004-02-03
4	1978	1579	2	2004-02-03
5	1978	9200	2	2004-02-03
6	1978	3795	2	2004-02-03
7	1978	2090	1	2004-02-03
8	1978	2226	2	2004-02-03
9	1978	9194	1	2004-02-03
1	1979	3997	3	2004-02-28
1	1980	6062	2	2004-02-06
2	1980	2654	3	2004-02-06
3	1980	2782	1	2004-02-06
1	1981	5452	3	2004-02-09
2	1981	8940	3	2004-02-09
3	1981	4848	1	2004-02-09
4	1981	633	3	2004-02-09
5	1981	7247	3	2004-02-09
1	1982	7712	1	2004-02-24
2	1982	9341	3	2004-02-24
1	1983	9058	2	2004-02-04
2	1983	6376	1	2004-02-04
3	1983	6705	3	2004-02-04
4	1983	1157	3	2004-02-04
5	1983	3959	2	2004-02-04
6	1983	7424	1	2004-02-04
7	1983	5853	1	2004-02-04
1	1984	6311	3	2004-02-11
2	1984	8306	2	2004-02-11
1	1985	5706	3	2004-02-28
2	1985	3844	3	2004-02-28
3	1985	6148	1	2004-02-28
4	1985	3504	1	2004-02-28
5	1985	4740	1	2004-02-28
6	1985	1901	2	2004-02-28
7	1985	7673	2	2004-02-28
8	1985	2504	2	2004-02-28
9	1985	8759	3	2004-02-28
1	1986	3860	1	2004-02-21
2	1986	4284	1	2004-02-21
3	1986	6159	2	2004-02-21
4	1986	8182	2	2004-02-21
5	1986	3189	2	2004-02-21
6	1986	2748	3	2004-02-21
7	1986	2165	3	2004-02-21
1	1987	5877	1	2004-02-28
2	1987	570	2	2004-02-28
3	1987	9179	1	2004-02-28
4	1987	8645	3	2004-02-28
5	1987	1431	2	2004-02-28
1	1988	7424	3	2004-02-02
2	1988	6648	2	2004-02-02
3	1988	1071	2	2004-02-02
4	1988	7438	2	2004-02-02
5	1988	8716	1	2004-02-02
1	1989	6549	1	2004-02-04
2	1989	5900	1	2004-02-04
1	1990	9543	2	2004-02-11
2	1990	932	1	2004-02-11
3	1990	631	1	2004-02-11
1	1991	356	1	2004-02-21
2	1991	8250	1	2004-02-21
3	1991	7513	2	2004-02-21
4	1991	5686	2	2004-02-21
5	1991	5872	3	2004-02-21
1	1992	5449	2	2004-02-20
2	1992	6083	3	2004-02-20
3	1992	572	1	2004-02-20
4	1992	2259	1	2004-02-20
1	1993	4744	3	2004-02-19
2	1993	657	1	2004-02-19
3	1993	2998	1	2004-02-19
4	1993	3464	1	2004-02-19
5	1993	2439	1	2004-02-19
6	1993	6934	3	2004-02-19
7	1993	7205	1	2004-02-19
1	1994	7972	1	2004-02-15
2	1994	7409	2	2004-02-15
3	1994	2470	3	2004-02-15
1	1995	7918	3	2004-02-18
2	1995	92	1	2004-02-18
3	1995	7512	1	2004-02-18
1	1996	1756	2	2004-02-10
2	1996	7881	3	2004-02-10
3	1996	2324	2	2004-02-10
4	1996	1495	3	2004-02-10
5	1996	9400	3	2004-02-10
6	1996	732	3	2004-02-10
7	1996	2457	3	2004-02-10
1	1997	9654	2	2004-02-04
2	1997	322	3	2004-02-04
3	1997	3397	1	2004-02-04
4	1997	232	1	2004-02-04
5	1997	1162	2	2004-02-04
6	1997	1418	1	2004-02-04
7	1997	577	1	2004-02-04
1	1998	3543	2	2004-02-20
2	1998	6871	1	2004-02-20
3	1998	2609	3	2004-02-20
4	1998	313	2	2004-02-20
5	1998	5743	1	2004-02-20
6	1998	9991	1	2004-02-20
7	1998	9274	3	2004-02-20
8	1998	6081	3	2004-02-20
9	1998	7214	3	2004-02-20
1	1999	1119	1	2004-02-01
2	1999	4092	1	2004-02-01
1	2000	658	2	2004-02-14
2	2000	196	3	2004-02-14
3	2000	6638	1	2004-02-14
4	2000	5130	3	2004-02-14
5	2000	7869	1	2004-02-14
6	2000	8688	3	2004-02-14
7	2000	2737	3	2004-02-14
1	2001	9702	3	2004-03-04
2	2001	3782	3	2004-03-04
3	2001	2714	2	2004-03-04
4	2001	4178	3	2004-03-04
5	2001	4	2	2004-03-04
1	2002	7109	2	2004-03-22
2	2002	8084	2	2004-03-22
3	2002	4034	2	2004-03-22
4	2002	6602	1	2004-03-22
5	2002	7593	2	2004-03-22
6	2002	7983	1	2004-03-22
7	2002	5038	3	2004-03-22
8	2002	503	2	2004-03-22
1	2003	8385	3	2004-03-13
2	2003	1965	1	2004-03-13
3	2003	6491	1	2004-03-13
4	2003	8342	2	2004-03-13
5	2003	9167	3	2004-03-13
6	2003	1545	2	2004-03-13
7	2003	1012	3	2004-03-13
8	2003	556	2	2004-03-13
1	2004	2115	2	2004-03-19
2	2004	3555	3	2004-03-19
3	2004	4071	2	2004-03-19
4	2004	2985	3	2004-03-19
1	2005	4317	3	2004-03-14
2	2005	5209	1	2004-03-14
3	2005	70	2	2004-03-14
1	2006	5511	1	2004-03-14
2	2006	5469	2	2004-03-14
3	2006	6883	1	2004-03-14
4	2006	3223	2	2004-03-14
5	2006	4909	2	2004-03-14
6	2006	9068	3	2004-03-14
1	2007	1352	3	2004-03-08
2	2007	2768	3	2004-03-08
3	2007	9427	3	2004-03-08
4	2007	5591	2	2004-03-08
5	2007	7891	2	2004-03-08
1	2008	8027	1	2004-03-26
2	2008	847	2	2004-03-26
3	2008	6473	3	2004-03-26
4	2008	4888	3	2004-03-26
5	2008	1712	3	2004-03-26
6	2008	5033	1	2004-03-26
7	2008	8260	3	2004-03-26
8	2008	3918	1	2004-03-26
9	2008	2995	2	2004-03-26
1	2009	2847	3	2004-03-24
2	2009	1621	1	2004-03-24
3	2009	4007	3	2004-03-24
4	2009	2924	3	2004-03-24
5	2009	8816	1	2004-03-24
6	2009	9311	3	2004-03-24
7	2009	4446	2	2004-03-24
1	2010	9130	1	2004-03-23
2	2010	9881	3	2004-03-23
3	2010	8034	2	2004-03-23
4	2010	8168	1	2004-03-23
5	2010	9067	2	2004-03-23
6	2010	6790	1	2004-03-23
7	2010	2714	3	2004-03-23
8	2010	170	2	2004-03-23
9	2010	373	2	2004-03-23
1	2011	4247	1	2004-03-13
2	2011	2616	3	2004-03-13
3	2011	8173	1	2004-03-13
1	2012	4164	3	2004-03-25
2	2012	4543	1	2004-03-25
3	2012	2787	1	2004-03-25
4	2012	3224	1	2004-03-25
5	2012	8439	1	2004-03-25
6	2012	3676	1	2004-03-25
7	2012	9650	2	2004-03-25
1	2013	3319	1	2004-03-18
2	2013	2579	3	2004-03-18
3	2013	3490	2	2004-03-18
4	2013	6257	1	2004-03-18
5	2013	5201	2	2004-03-18
6	2013	5314	2	2004-03-18
7	2013	1436	3	2004-03-18
8	2013	3296	2	2004-03-18
9	2013	1673	2	2004-03-18
1	2014	4911	1	2004-03-27
2	2014	8279	2	2004-03-27
3	2014	5454	2	2004-03-27
4	2014	4582	2	2004-03-27
5	2014	3389	3	2004-03-27
6	2014	4575	2	2004-03-27
7	2014	5464	3	2004-03-27
1	2015	6002	2	2004-03-04
2	2015	670	3	2004-03-04
3	2015	4516	2	2004-03-04
4	2015	3415	2	2004-03-04
5	2015	46	1	2004-03-04
6	2015	1086	3	2004-03-04
1	2016	556	2	2004-03-29
2	2016	1275	2	2004-03-29
3	2016	8516	2	2004-03-29
4	2016	3036	1	2004-03-29
5	2016	631	3	2004-03-29
6	2016	1155	1	2004-03-29
7	2016	220	1	2004-03-29
1	2017	3658	1	2004-03-26
2	2017	2788	3	2004-03-26
3	2017	6625	1	2004-03-26
4	2017	9177	3	2004-03-26
5	2017	813	3	2004-03-26
6	2017	3706	1	2004-03-26
7	2017	5919	2	2004-03-26
8	2017	5442	3	2004-03-26
1	2018	7048	1	2004-03-30
2	2018	932	3	2004-03-30
3	2018	4279	1	2004-03-30
1	2019	1257	1	2004-03-29
2	2019	5437	2	2004-03-29
3	2019	8101	1	2004-03-29
4	2019	6877	3	2004-03-29
5	2019	9771	3	2004-03-29
1	2020	7737	2	2004-03-18
2	2020	8797	3	2004-03-18
1	2021	3139	1	2004-03-24
2	2021	2738	3	2004-03-24
3	2021	1649	1	2004-03-24
4	2021	9850	3	2004-03-24
5	2021	6821	1	2004-03-24
1	2022	4319	1	2004-03-01
2	2022	5427	2	2004-03-01
3	2022	9717	1	2004-03-01
4	2022	7564	3	2004-03-01
5	2022	2716	2	2004-03-01
6	2022	1337	1	2004-03-01
7	2022	2434	3	2004-03-01
8	2022	2165	1	2004-03-01
1	2023	2721	2	2004-03-11
2	2023	7919	1	2004-03-11
3	2023	3164	2	2004-03-11
4	2023	3677	1	2004-03-11
5	2023	6997	3	2004-03-11
6	2023	1362	1	2004-03-11
1	2024	7901	1	2004-03-03
1	2025	2128	1	2004-03-26
2	2025	8537	2	2004-03-26
3	2025	2699	1	2004-03-26
4	2025	9596	2	2004-03-26
5	2025	7997	1	2004-03-26
6	2025	9338	2	2004-03-26
7	2025	4886	1	2004-03-26
8	2025	654	3	2004-03-26
9	2025	5714	3	2004-03-26
1	2026	3864	2	2004-03-23
2	2026	8810	1	2004-03-23
3	2026	7335	3	2004-03-23
4	2026	2379	2	2004-03-23
5	2026	6896	2	2004-03-23
6	2026	6301	2	2004-03-23
7	2026	8799	3	2004-03-23
8	2026	7329	3	2004-03-23
1	2027	1241	2	2004-03-13
2	2027	6032	1	2004-03-13
3	2027	4158	1	2004-03-13
4	2027	9545	1	2004-03-13
1	2028	2877	3	2004-03-28
2	2028	4448	1	2004-03-28
3	2028	5781	3	2004-03-28
1	2029	8108	1	2004-03-19
2	2029	1111	2	2004-03-19
1	2030	8834	1	2004-03-27
2	2030	4830	2	2004-03-27
3	2030	3897	3	2004-03-27
4	2030	6612	2	2004-03-27
5	2030	534	2	2004-03-27
6	2030	1950	1	2004-03-27
7	2030	8117	2	2004-03-27
8	2030	8918	1	2004-03-27
9	2030	5037	2	2004-03-27
1	2031	2961	2	2004-03-30
1	2032	9374	1	2004-03-03
2	2032	8615	3	2004-03-03
3	2032	3683	2	2004-03-03
4	2032	3073	3	2004-03-03
5	2032	2433	3	2004-03-03
6	2032	1019	1	2004-03-03
7	2032	5117	1	2004-03-03
8	2032	3286	1	2004-03-03
9	2032	7795	1	2004-03-03
1	2033	3680	2	2004-03-18
2	2033	5912	2	2004-03-18
3	2033	9758	3	2004-03-18
4	2033	711	1	2004-03-18
5	2033	6147	1	2004-03-18
1	2034	8207	1	2004-03-08
2	2034	3618	1	2004-03-08
3	2034	1050	2	2004-03-08
4	2034	3605	2	2004-03-08
5	2034	7605	3	2004-03-08
6	2034	9398	2	2004-03-08
1	2035	383	1	2004-03-29
2	2035	270	2	2004-03-29
3	2035	8550	1	2004-03-29
4	2035	3060	3	2004-03-29
5	2035	703	3	2004-03-29
6	2035	9346	1	2004-03-29
1	2036	9003	1	2004-03-13
2	2036	2814	1	2004-03-13
1	2037	3308	2	2004-03-23
2	2037	354	1	2004-03-23
3	2037	810	3	2004-03-23
4	2037	8395	1	2004-03-23
5	2037	493	3	2004-03-23
1	2038	8304	3	2004-03-24
1	2039	5286	1	2004-03-31
2	2039	5895	2	2004-03-31
3	2039	4265	3	2004-03-31
4	2039	4341	1	2004-03-31
1	2040	6172	3	2004-03-16
2	2040	835	3	2004-03-16
3	2040	5507	3	2004-03-16
4	2040	8173	2	2004-03-16
5	2040	7893	2	2004-03-16
6	2040	5043	2	2004-03-16
7	2040	6203	2	2004-03-16
8	2040	5977	2	2004-03-16
1	2041	9979	2	2004-03-04
2	2041	568	2	2004-03-04
3	2041	4276	2	2004-03-04
4	2041	5859	3	2004-03-04
5	2041	5465	1	2004-03-04
6	2041	7836	1	2004-03-04
1	2042	7898	3	2004-03-29
2	2042	858	2	2004-03-29
3	2042	2449	2	2004-03-29
4	2042	2375	3	2004-03-29
5	2042	9245	3	2004-03-29
1	2043	6518	3	2004-03-15
2	2043	9846	3	2004-03-15
3	2043	1002	2	2004-03-15
4	2043	1994	3	2004-03-15
1	2044	9096	3	2004-03-11
2	2044	28	3	2004-03-11
1	2045	3717	3	2004-03-11
2	2045	255	2	2004-03-11
3	2045	5605	3	2004-03-11
4	2045	4442	1	2004-03-11
1	2046	7980	2	2004-03-31
2	2046	3342	3	2004-03-31
3	2046	8454	2	2004-03-31
4	2046	5843	1	2004-03-31
5	2046	2794	2	2004-03-31
6	2046	3336	1	2004-03-31
1	2047	1289	2	2004-03-12
2	2047	1623	2	2004-03-12
3	2047	1061	1	2004-03-12
4	2047	1096	2	2004-03-12
5	2047	1376	2	2004-03-12
6	2047	6875	1	2004-03-12
7	2047	6759	1	2004-03-12
1	2048	3721	2	2004-03-23
1	2049	4694	3	2004-03-19
2	2049	728	3	2004-03-19
3	2049	2821	1	2004-03-19
4	2049	5731	2	2004-03-19
5	2049	4438	3	2004-03-19
6	2049	9116	2	2004-03-19
7	2049	9229	1	2004-03-19
8	2049	2164	1	2004-03-19
1	2050	399	3	2004-03-18
2	2050	7245	2	2004-03-18
3	2050	9796	1	2004-03-18
1	2051	4680	2	2004-03-01
2	2051	5818	2	2004-03-01
3	2051	3684	3	2004-03-01
4	2051	5738	3	2004-03-01
5	2051	2749	1	2004-03-01
6	2051	6767	1	2004-03-01
1	2052	6600	3	2004-03-18
2	2052	6875	3	2004-03-18
3	2052	329	3	2004-03-18
4	2052	7403	3	2004-03-18
5	2052	3365	3	2004-03-18
6	2052	8538	2	2004-03-18
7	2052	3040	3	2004-03-18
8	2052	9961	3	2004-03-18
1	2053	4417	3	2004-03-14
2	2053	7384	3	2004-03-14
3	2053	9040	2	2004-03-14
4	2053	9028	2	2004-03-14
5	2053	146	1	2004-03-14
6	2053	2551	3	2004-03-14
7	2053	8924	3	2004-03-14
8	2053	5062	3	2004-03-14
1	2054	9664	2	2004-03-21
1	2055	423	3	2004-03-12
2	2055	9404	2	2004-03-12
3	2055	6684	2	2004-03-12
4	2055	2414	2	2004-03-12
1	2056	6167	3	2004-03-04
1	2057	8143	1	2004-03-04
1	2058	4904	1	2004-03-29
2	2058	1479	3	2004-03-29
3	2058	5000	2	2004-03-29
4	2058	2193	2	2004-03-29
5	2058	4621	1	2004-03-29
6	2058	8972	1	2004-03-29
1	2059	2840	2	2004-03-17
2	2059	6414	3	2004-03-17
3	2059	1952	3	2004-03-17
4	2059	7724	3	2004-03-17
5	2059	7566	2	2004-03-17
6	2059	7229	3	2004-03-17
1	2060	2159	2	2004-03-03
2	2060	4179	3	2004-03-03
3	2060	356	2	2004-03-03
4	2060	2580	2	2004-03-03
5	2060	7968	1	2004-03-03
6	2060	6282	2	2004-03-03
1	2061	5243	2	2004-03-10
2	2061	4782	3	2004-03-10
3	2061	3726	1	2004-03-10
4	2061	4254	1	2004-03-10
5	2061	8371	1	2004-03-10
6	2061	8148	3	2004-03-10
1	2062	5568	3	2004-03-05
2	2062	660	2	2004-03-05
3	2062	5238	1	2004-03-05
4	2062	900	1	2004-03-05
1	2063	8834	2	2004-03-15
2	2063	3504	2	2004-03-15
3	2063	2571	3	2004-03-15
4	2063	1272	2	2004-03-15
5	2063	790	2	2004-03-15
6	2063	7587	3	2004-03-15
7	2063	7007	2	2004-03-15
1	2064	1853	1	2004-03-26
2	2064	1792	1	2004-03-26
3	2064	8343	3	2004-03-26
1	2065	6423	3	2004-03-18
1	2066	9334	2	2004-03-26
2	2066	57	1	2004-03-26
1	2067	7	1	2004-03-07
2	2067	5381	3	2004-03-07
3	2067	1487	1	2004-03-07
4	2067	1170	2	2004-03-07
5	2067	4653	1	2004-03-07
6	2067	5851	1	2004-03-07
7	2067	9990	1	2004-03-07
8	2067	2238	1	2004-03-07
9	2067	2144	3	2004-03-07
1	2068	2185	1	2004-03-22
1	2069	3088	3	2004-03-19
2	2069	7710	1	2004-03-19
3	2069	3122	1	2004-03-19
4	2069	1338	2	2004-03-19
5	2069	5323	1	2004-03-19
6	2069	7948	3	2004-03-19
7	2069	5468	2	2004-03-19
8	2069	2971	2	2004-03-19
1	2070	3868	1	2004-03-17
2	2070	7957	3	2004-03-17
3	2070	2964	1	2004-03-17
4	2070	1036	3	2004-03-17
5	2070	2383	2	2004-03-17
6	2070	7030	2	2004-03-17
7	2070	4877	2	2004-03-17
1	2071	2606	1	2004-03-27
2	2071	2409	1	2004-03-27
3	2071	3126	3	2004-03-27
4	2071	4352	2	2004-03-27
5	2071	3334	3	2004-03-27
6	2071	1304	3	2004-03-27
7	2071	7296	2	2004-03-27
8	2071	1739	2	2004-03-27
9	2071	2957	2	2004-03-27
1	2072	8884	1	2004-03-17
2	2072	3244	2	2004-03-17
3	2072	5437	1	2004-03-17
4	2072	1758	1	2004-03-17
5	2072	1709	2	2004-03-17
6	2072	6416	2	2004-03-17
7	2072	4917	3	2004-03-17
1	2073	9020	3	2004-03-07
2	2073	4340	2	2004-03-07
3	2073	2113	2	2004-03-07
4	2073	1566	2	2004-03-07
5	2073	781	3	2004-03-07
1	2074	5147	3	2004-03-29
2	2074	1705	1	2004-03-29
3	2074	9782	2	2004-03-29
4	2074	3848	1	2004-03-29
5	2074	7825	1	2004-03-29
6	2074	5607	1	2004-03-29
7	2074	9805	3	2004-03-29
8	2074	2009	2	2004-03-29
1	2075	7343	2	2004-03-10
2	2075	3341	3	2004-03-10
3	2075	9565	2	2004-03-10
4	2075	5867	3	2004-03-10
5	2075	8570	1	2004-03-10
6	2075	6571	2	2004-03-10
7	2075	8574	3	2004-03-10
1	2076	9845	3	2004-03-14
2	2076	8410	2	2004-03-14
3	2076	2302	3	2004-03-14
4	2076	3050	2	2004-03-14
5	2076	3655	2	2004-03-14
6	2076	5340	2	2004-03-14
7	2076	3237	1	2004-03-14
8	2076	533	2	2004-03-14
1	2077	8723	3	2004-03-05
2	2077	8056	2	2004-03-05
3	2077	2984	2	2004-03-05
4	2077	3569	3	2004-03-05
5	2077	4984	2	2004-03-05
6	2077	5430	2	2004-03-05
7	2077	4866	2	2004-03-05
1	2078	1478	2	2004-03-01
2	2078	9303	3	2004-03-01
3	2078	1745	1	2004-03-01
1	2079	2375	3	2004-03-30
1	2080	6391	1	2004-03-27
2	2080	3232	3	2004-03-27
3	2080	9349	3	2004-03-27
4	2080	5264	2	2004-03-27
5	2080	3044	1	2004-03-27
6	2080	8618	1	2004-03-27
1	2081	6377	2	2004-03-23
2	2081	5591	3	2004-03-23
3	2081	8494	2	2004-03-23
4	2081	400	3	2004-03-23
5	2081	6180	1	2004-03-23
6	2081	7424	2	2004-03-23
7	2081	3872	2	2004-03-23
8	2081	1330	1	2004-03-23
1	2082	2776	2	2004-03-27
2	2082	2697	2	2004-03-27
3	2082	5614	1	2004-03-27
4	2082	9142	1	2004-03-27
5	2082	1984	2	2004-03-27
6	2082	1683	3	2004-03-27
7	2082	1748	3	2004-03-27
8	2082	6483	1	2004-03-27
1	2083	9655	2	2004-03-08
2	2083	3270	2	2004-03-08
3	2083	1781	2	2004-03-08
4	2083	3789	1	2004-03-08
5	2083	9161	2	2004-03-08
6	2083	8271	1	2004-03-08
7	2083	9495	1	2004-03-08
8	2083	7754	2	2004-03-08
1	2084	2688	3	2004-03-08
2	2084	2626	2	2004-03-08
3	2084	6974	3	2004-03-08
4	2084	4677	3	2004-03-08
1	2085	7803	1	2004-03-19
2	2085	9170	3	2004-03-19
3	2085	5749	1	2004-03-19
4	2085	9935	2	2004-03-19
5	2085	6969	3	2004-03-19
6	2085	6844	2	2004-03-19
1	2086	1493	3	2004-03-29
2	2086	5718	2	2004-03-29
1	2087	7451	1	2004-03-29
2	2087	5600	2	2004-03-29
3	2087	5819	2	2004-03-29
4	2087	9083	2	2004-03-29
5	2087	4629	3	2004-03-29
6	2087	3205	1	2004-03-29
1	2088	1343	1	2004-03-04
2	2088	4643	1	2004-03-04
3	2088	6726	2	2004-03-04
4	2088	1968	3	2004-03-04
5	2088	5803	3	2004-03-04
6	2088	2398	2	2004-03-04
7	2088	6029	1	2004-03-04
8	2088	1355	2	2004-03-04
1	2089	434	2	2004-03-14
1	2090	5439	2	2004-03-12
2	2090	86	1	2004-03-12
3	2090	3641	1	2004-03-12
4	2090	2851	3	2004-03-12
5	2090	1943	3	2004-03-12
6	2090	4497	2	2004-03-12
7	2090	7793	1	2004-03-12
1	2091	1202	3	2004-03-05
2	2091	1102	2	2004-03-05
3	2091	3700	3	2004-03-05
4	2091	5627	2	2004-03-05
5	2091	4018	3	2004-03-05
6	2091	9196	3	2004-03-05
7	2091	6318	2	2004-03-05
1	2092	7832	3	2004-03-12
2	2092	5656	3	2004-03-12
3	2092	7782	1	2004-03-12
4	2092	3684	2	2004-03-12
5	2092	451	2	2004-03-12
6	2092	5765	2	2004-03-12
7	2092	2903	3	2004-03-12
1	2093	2022	3	2004-03-09
2	2093	420	2	2004-03-09
3	2093	7469	3	2004-03-09
4	2093	4310	2	2004-03-09
5	2093	4249	3	2004-03-09
6	2093	188	3	2004-03-09
1	2094	7793	2	2004-03-17
1	2095	6756	3	2004-03-04
2	2095	7512	3	2004-03-04
1	2096	6385	2	2004-03-13
2	2096	4469	3	2004-03-13
3	2096	1723	1	2004-03-13
4	2096	6420	2	2004-03-13
5	2096	5722	1	2004-03-13
6	2096	4073	2	2004-03-13
1	2097	554	1	2004-03-01
2	2097	3678	1	2004-03-01
3	2097	3199	2	2004-03-01
4	2097	3443	3	2004-03-01
5	2097	1778	1	2004-03-01
6	2097	9612	2	2004-03-01
7	2097	1052	1	2004-03-01
8	2097	2047	3	2004-03-01
1	2098	8452	1	2004-03-28
1	2099	84	1	2004-03-21
1	2100	5734	2	2004-03-01
1	2101	8886	3	2004-03-09
2	2101	6992	3	2004-03-09
3	2101	5663	3	2004-03-09
4	2101	1771	3	2004-03-09
5	2101	5480	1	2004-03-09
6	2101	4225	3	2004-03-09
1	2102	6850	1	2004-03-05
2	2102	8902	3	2004-03-05
3	2102	3309	3	2004-03-05
4	2102	945	1	2004-03-05
5	2102	9992	3	2004-03-05
6	2102	6358	1	2004-03-05
7	2102	5610	2	2004-03-05
8	2102	8624	2	2004-03-05
1	2103	3660	2	2004-03-15
1	2104	8859	3	2004-03-25
2	2104	4826	3	2004-03-25
1	2105	8609	2	2004-03-16
2	2105	3087	3	2004-03-16
3	2105	7246	1	2004-03-16
4	2105	6231	2	2004-03-16
1	2106	6337	1	2004-03-18
2	2106	9905	3	2004-03-18
3	2106	2937	2	2004-03-18
4	2106	4095	1	2004-03-18
1	2107	6484	3	2004-03-09
2	2107	798	1	2004-03-09
1	2108	5994	3	2004-03-30
2	2108	7674	1	2004-03-30
3	2108	1580	2	2004-03-30
4	2108	6843	3	2004-03-30
5	2108	5746	2	2004-03-30
6	2108	1533	1	2004-03-30
7	2108	7733	1	2004-03-30
8	2108	1412	1	2004-03-30
1	2109	5092	2	2004-03-16
2	2109	9263	1	2004-03-16
3	2109	2379	1	2004-03-16
4	2109	3073	1	2004-03-16
5	2109	1802	3	2004-03-16
6	2109	12	3	2004-03-16
7	2109	6990	3	2004-03-16
1	2110	5814	3	2004-03-04
2	2110	2890	3	2004-03-04
3	2110	9417	1	2004-03-04
4	2110	8784	1	2004-03-04
5	2110	1292	2	2004-03-04
6	2110	6335	1	2004-03-04
7	2110	1486	1	2004-03-04
8	2110	7365	1	2004-03-04
1	2111	1634	1	2004-03-10
2	2111	4561	1	2004-03-10
3	2111	405	1	2004-03-10
4	2111	9330	1	2004-03-10
5	2111	120	1	2004-03-10
6	2111	9318	2	2004-03-10
1	2112	2830	1	2004-03-26
2	2112	8500	2	2004-03-26
3	2112	5847	2	2004-03-26
4	2112	6944	3	2004-03-26
5	2112	6260	2	2004-03-26
6	2112	8081	3	2004-03-26
7	2112	4051	3	2004-03-26
1	2113	7329	1	2004-03-17
2	2113	1444	2	2004-03-17
3	2113	3342	1	2004-03-17
4	2113	7578	1	2004-03-17
5	2113	7496	2	2004-03-17
6	2113	4866	1	2004-03-17
7	2113	3504	3	2004-03-17
8	2113	2839	1	2004-03-17
9	2113	1816	3	2004-03-17
1	2114	3068	2	2004-03-22
2	2114	2355	3	2004-03-22
3	2114	2987	3	2004-03-22
1	2115	6386	3	2004-03-09
1	2116	2386	3	2004-03-22
2	2116	199	3	2004-03-22
3	2116	8858	2	2004-03-22
4	2116	4946	1	2004-03-22
1	2117	5521	2	2004-03-18
2	2117	5637	3	2004-03-18
3	2117	496	3	2004-03-18
1	2118	7966	1	2004-03-18
2	2118	8637	2	2004-03-18
3	2118	2283	2	2004-03-18
4	2118	4078	1	2004-03-18
5	2118	9792	2	2004-03-18
6	2118	951	3	2004-03-18
7	2118	3715	3	2004-03-18
8	2118	3693	3	2004-03-18
1	2119	1938	1	2004-03-05
2	2119	8282	3	2004-03-05
1	2120	2260	1	2004-03-30
2	2120	3739	1	2004-03-30
3	2120	4501	1	2004-03-30
4	2120	4576	3	2004-03-30
5	2120	7800	3	2004-03-30
1	2121	7582	3	2004-03-30
1	2122	671	1	2004-03-02
2	2122	3798	1	2004-03-02
1	2123	856	2	2004-03-12
2	2123	8611	1	2004-03-12
3	2123	6987	1	2004-03-12
4	2123	3340	1	2004-03-12
1	2124	6569	3	2004-03-15
2	2124	114	1	2004-03-15
3	2124	8526	3	2004-03-15
1	2125	850	3	2004-03-02
2	2125	917	2	2004-03-02
3	2125	2246	2	2004-03-02
4	2125	6726	1	2004-03-02
5	2125	8146	3	2004-03-02
6	2125	8172	3	2004-03-02
7	2125	697	2	2004-03-02
8	2125	9105	2	2004-03-02
1	2126	6350	3	2004-03-21
2	2126	2840	2	2004-03-21
3	2126	205	1	2004-03-21
4	2126	4158	1	2004-03-21
5	2126	301	1	2004-03-21
1	2127	5797	2	2004-03-28
2	2127	4412	1	2004-03-28
3	2127	7438	1	2004-03-28
4	2127	104	2	2004-03-28
5	2127	9314	1	2004-03-28
6	2127	767	3	2004-03-28
7	2127	4837	3	2004-03-28
8	2127	2246	3	2004-03-28
9	2127	2330	3	2004-03-28
1	2128	6533	3	2004-03-17
2	2128	6233	3	2004-03-17
3	2128	2343	2	2004-03-17
4	2128	7983	2	2004-03-17
5	2128	4604	2	2004-03-17
1	2129	1572	2	2004-03-01
2	2129	3165	1	2004-03-01
3	2129	7204	2	2004-03-01
4	2129	9303	1	2004-03-01
5	2129	1345	1	2004-03-01
6	2129	8828	2	2004-03-01
7	2129	143	2	2004-03-01
1	2130	4418	2	2004-03-28
2	2130	2208	3	2004-03-28
3	2130	840	1	2004-03-28
4	2130	1868	2	2004-03-28
5	2130	3968	1	2004-03-28
1	2131	6673	1	2004-03-14
2	2131	6914	2	2004-03-14
3	2131	6640	2	2004-03-14
4	2131	5917	3	2004-03-14
5	2131	7764	2	2004-03-14
6	2131	1657	3	2004-03-14
1	2132	5873	3	2004-03-28
2	2132	4406	3	2004-03-28
3	2132	4284	2	2004-03-28
4	2132	8269	2	2004-03-28
5	2132	688	1	2004-03-28
6	2132	8138	2	2004-03-28
7	2132	2506	3	2004-03-28
8	2132	1174	3	2004-03-28
1	2133	4304	3	2004-03-02
2	2133	5011	1	2004-03-02
3	2133	3715	3	2004-03-02
4	2133	9972	1	2004-03-02
5	2133	7166	1	2004-03-02
6	2133	1121	1	2004-03-02
7	2133	603	2	2004-03-02
1	2134	1037	1	2004-03-04
2	2134	1623	3	2004-03-04
3	2134	6604	2	2004-03-04
4	2134	6855	3	2004-03-04
5	2134	3306	3	2004-03-04
6	2134	5865	2	2004-03-04
7	2134	4269	1	2004-03-04
8	2134	5331	3	2004-03-04
9	2134	2235	3	2004-03-04
1	2135	5285	1	2004-03-19
2	2135	6149	2	2004-03-19
3	2135	8285	3	2004-03-19
1	2136	515	3	2004-03-03
2	2136	984	3	2004-03-03
1	2137	5080	1	2004-03-08
2	2137	2069	3	2004-03-08
3	2137	928	3	2004-03-08
4	2137	8628	1	2004-03-08
5	2137	6444	2	2004-03-08
6	2137	5369	3	2004-03-08
1	2138	6540	3	2004-03-24
2	2138	1098	3	2004-03-24
3	2138	8183	3	2004-03-24
4	2138	9123	3	2004-03-24
1	2139	7945	1	2004-03-19
2	2139	4135	1	2004-03-19
3	2139	1469	2	2004-03-19
4	2139	2373	1	2004-03-19
5	2139	3603	1	2004-03-19
6	2139	5559	1	2004-03-19
7	2139	5574	1	2004-03-19
8	2139	8129	1	2004-03-19
1	2140	8098	3	2004-03-05
2	2140	5432	2	2004-03-05
3	2140	5938	2	2004-03-05
4	2140	4977	1	2004-03-05
5	2140	4661	1	2004-03-05
6	2140	388	1	2004-03-05
7	2140	1499	2	2004-03-05
8	2140	5629	1	2004-03-05
1	2141	9002	1	2004-03-03
2	2141	4374	2	2004-03-03
3	2141	1850	1	2004-03-03
4	2141	7833	2	2004-03-03
1	2142	3111	3	2004-03-05
2	2142	5851	3	2004-03-05
3	2142	1535	1	2004-03-05
4	2142	1010	2	2004-03-05
5	2142	1617	1	2004-03-05
6	2142	8799	1	2004-03-05
7	2142	5920	2	2004-03-05
8	2142	6083	2	2004-03-05
9	2142	2429	1	2004-03-05
1	2143	6004	2	2004-03-04
2	2143	7850	2	2004-03-04
3	2143	7649	3	2004-03-04
4	2143	8759	3	2004-03-04
5	2143	8894	1	2004-03-04
1	2144	5570	1	2004-03-20
2	2144	3906	3	2004-03-20
3	2144	3323	1	2004-03-20
4	2144	302	3	2004-03-20
5	2144	7132	2	2004-03-20
6	2144	5888	3	2004-03-20
7	2144	7832	3	2004-03-20
1	2145	4422	1	2004-03-04
2	2145	829	1	2004-03-04
3	2145	9381	3	2004-03-04
4	2145	1268	3	2004-03-04
5	2145	1456	3	2004-03-04
6	2145	3018	1	2004-03-04
7	2145	5156	3	2004-03-04
1	2146	1766	2	2004-03-14
2	2146	6863	3	2004-03-14
3	2146	2460	1	2004-03-14
4	2146	8457	1	2004-03-14
5	2146	9611	3	2004-03-14
6	2146	492	1	2004-03-14
7	2146	6438	2	2004-03-14
1	2147	6853	3	2004-03-06
2	2147	9532	3	2004-03-06
1	2148	1138	2	2004-03-18
1	2149	2987	3	2004-03-31
2	2149	575	2	2004-03-31
1	2150	8476	2	2004-03-07
2	2150	3642	2	2004-03-07
1	2151	6776	3	2004-03-04
2	2151	6375	2	2004-03-04
3	2151	7340	1	2004-03-04
4	2151	8858	3	2004-03-04
5	2151	2919	3	2004-03-04
6	2151	2998	1	2004-03-04
7	2151	6907	2	2004-03-04
8	2151	4508	3	2004-03-04
1	2152	4112	1	2004-03-16
2	2152	9093	1	2004-03-16
3	2152	7303	1	2004-03-16
4	2152	7500	3	2004-03-16
5	2152	8252	3	2004-03-16
6	2152	6567	2	2004-03-16
7	2152	8710	1	2004-03-16
1	2153	4069	3	2004-03-05
1	2154	2663	2	2004-03-01
2	2154	6986	3	2004-03-01
3	2154	347	1	2004-03-01
4	2154	4992	2	2004-03-01
5	2154	3398	2	2004-03-01
6	2154	7046	1	2004-03-01
7	2154	6818	2	2004-03-01
1	2155	97	1	2004-03-29
2	2155	8651	1	2004-03-29
3	2155	8982	2	2004-03-29
4	2155	1623	1	2004-03-29
5	2155	1589	1	2004-03-29
6	2155	116	1	2004-03-29
1	2156	500	3	2004-03-28
2	2156	8210	2	2004-03-28
3	2156	2418	1	2004-03-28
4	2156	9575	3	2004-03-28
5	2156	2308	2	2004-03-28
6	2156	4008	1	2004-03-28
1	2157	1165	2	2004-03-05
2	2157	2988	1	2004-03-05
1	2158	6419	1	2004-03-30
1	2159	1207	2	2004-03-11
1	2160	1024	1	2004-03-28
2	2160	855	1	2004-03-28
1	2161	3094	1	2004-03-25
2	2161	1066	2	2004-03-25
3	2161	7749	2	2004-03-25
4	2161	4404	3	2004-03-25
5	2161	8664	3	2004-03-25
6	2161	8276	2	2004-03-25
7	2161	911	1	2004-03-25
8	2161	403	3	2004-03-25
9	2161	2695	1	2004-03-25
1	2162	3060	1	2004-03-12
2	2162	7327	2	2004-03-12
3	2162	5379	2	2004-03-12
4	2162	8776	1	2004-03-12
5	2162	4882	1	2004-03-12
6	2162	2099	2	2004-03-12
1	2163	7066	3	2004-03-19
1	2164	7020	2	2004-03-26
2	2164	6043	3	2004-03-26
3	2164	5756	3	2004-03-26
4	2164	1383	3	2004-03-26
5	2164	5304	2	2004-03-26
6	2164	8828	1	2004-03-26
7	2164	8357	2	2004-03-26
8	2164	8003	3	2004-03-26
9	2164	4366	1	2004-03-26
1	2165	6312	3	2004-03-28
2	2165	5660	2	2004-03-28
3	2165	7493	2	2004-03-28
4	2165	8719	1	2004-03-28
5	2165	2832	2	2004-03-28
1	2166	8507	3	2004-03-17
2	2166	7920	2	2004-03-17
1	2167	954	2	2004-03-04
2	2167	6766	2	2004-03-04
3	2167	7326	2	2004-03-04
4	2167	1785	2	2004-03-04
5	2167	896	3	2004-03-04
6	2167	4986	2	2004-03-04
7	2167	1474	1	2004-03-04
8	2167	346	1	2004-03-04
9	2167	3717	1	2004-03-04
1	2168	241	1	2004-03-19
2	2168	8216	3	2004-03-19
1	2169	9126	2	2004-03-14
1	2170	1658	1	2004-03-17
2	2170	8728	1	2004-03-17
3	2170	1061	2	2004-03-17
1	2171	2726	3	2004-03-29
2	2171	2633	3	2004-03-29
3	2171	9009	2	2004-03-29
4	2171	37	3	2004-03-29
5	2171	5241	3	2004-03-29
6	2171	7409	3	2004-03-29
7	2171	7745	1	2004-03-29
8	2171	413	3	2004-03-29
9	2171	8176	2	2004-03-29
1	2172	2320	3	2004-03-09
2	2172	6973	2	2004-03-09
3	2172	674	2	2004-03-09
4	2172	5914	3	2004-03-09
1	2173	7295	2	2004-03-18
2	2173	2853	3	2004-03-18
3	2173	5031	3	2004-03-18
4	2173	5584	1	2004-03-18
5	2173	7701	1	2004-03-18
6	2173	4754	3	2004-03-18
7	2173	198	1	2004-03-18
8	2173	3774	1	2004-03-18
1	2174	8966	2	2004-03-08
2	2174	7985	3	2004-03-08
3	2174	431	2	2004-03-08
4	2174	6504	2	2004-03-08
5	2174	2538	1	2004-03-08
1	2175	7164	2	2004-03-13
2	2175	5084	1	2004-03-13
3	2175	6528	1	2004-03-13
4	2175	6075	1	2004-03-13
5	2175	898	2	2004-03-13
6	2175	4210	2	2004-03-13
7	2175	9231	2	2004-03-13
1	2176	957	3	2004-03-21
2	2176	5280	1	2004-03-21
3	2176	2981	1	2004-03-21
4	2176	7355	2	2004-03-21
5	2176	5061	1	2004-03-21
6	2176	5351	2	2004-03-21
1	2177	5261	2	2004-03-27
2	2177	6349	1	2004-03-27
3	2177	6016	3	2004-03-27
4	2177	7608	1	2004-03-27
1	2178	3447	3	2004-03-06
2	2178	4235	2	2004-03-06
3	2178	6902	3	2004-03-06
4	2178	5791	3	2004-03-06
5	2178	1298	1	2004-03-06
6	2178	5401	2	2004-03-06
7	2178	4638	1	2004-03-06
8	2178	477	1	2004-03-06
1	2179	3419	1	2004-03-11
2	2179	9860	3	2004-03-11
3	2179	278	3	2004-03-11
4	2179	9661	1	2004-03-11
5	2179	4306	2	2004-03-11
6	2179	788	3	2004-03-11
7	2179	4199	2	2004-03-11
8	2179	2156	1	2004-03-11
1	2180	1092	2	2004-03-15
2	2180	2191	2	2004-03-15
3	2180	7133	1	2004-03-15
4	2180	8848	1	2004-03-15
5	2180	1351	2	2004-03-15
6	2180	8922	2	2004-03-15
1	2181	6248	2	2004-03-27
2	2181	1035	1	2004-03-27
3	2181	245	1	2004-03-27
4	2181	8306	2	2004-03-27
5	2181	6844	1	2004-03-27
6	2181	5543	1	2004-03-27
7	2181	8407	2	2004-03-27
8	2181	7211	3	2004-03-27
1	2182	2068	2	2004-03-10
1	2183	8189	3	2004-03-02
2	2183	8138	1	2004-03-02
3	2183	7008	2	2004-03-02
4	2183	6257	3	2004-03-02
5	2183	4939	2	2004-03-02
6	2183	9865	1	2004-03-02
7	2183	944	3	2004-03-02
8	2183	3705	2	2004-03-02
9	2183	8087	1	2004-03-02
1	2184	4698	3	2004-03-10
2	2184	5957	3	2004-03-10
3	2184	910	2	2004-03-10
4	2184	185	1	2004-03-10
5	2184	5750	3	2004-03-10
6	2184	8682	2	2004-03-10
1	2185	3732	1	2004-03-03
2	2185	3523	2	2004-03-03
3	2185	6454	2	2004-03-03
4	2185	305	1	2004-03-03
5	2185	953	3	2004-03-03
6	2185	2269	2	2004-03-03
7	2185	3688	2	2004-03-03
1	2186	5151	1	2004-03-31
2	2186	2230	2	2004-03-31
3	2186	2136	3	2004-03-31
4	2186	3708	1	2004-03-31
5	2186	1866	2	2004-03-31
6	2186	6506	1	2004-03-31
1	2187	3834	3	2004-03-05
2	2187	9482	2	2004-03-05
3	2187	9957	1	2004-03-05
4	2187	2529	1	2004-03-05
5	2187	4397	2	2004-03-05
1	2188	114	3	2004-03-19
2	2188	8437	1	2004-03-19
3	2188	5087	1	2004-03-19
4	2188	322	3	2004-03-19
5	2188	1390	1	2004-03-19
6	2188	3265	3	2004-03-19
7	2188	2324	2	2004-03-19
1	2189	5470	3	2004-03-26
2	2189	6104	2	2004-03-26
1	2190	4848	2	2004-03-31
2	2190	8361	3	2004-03-31
3	2190	569	3	2004-03-31
4	2190	9200	3	2004-03-31
1	2191	3079	1	2004-03-03
2	2191	3325	2	2004-03-03
1	2192	1318	1	2004-03-28
2	2192	8960	3	2004-03-28
3	2192	127	2	2004-03-28
4	2192	2213	3	2004-03-28
5	2192	3696	3	2004-03-28
6	2192	3898	3	2004-03-28
7	2192	3618	1	2004-03-28
1	2193	3192	1	2004-03-25
2	2193	1475	1	2004-03-25
3	2193	2688	2	2004-03-25
4	2193	3735	2	2004-03-25
5	2193	897	1	2004-03-25
6	2193	1661	1	2004-03-25
7	2193	9590	1	2004-03-25
1	2194	3613	1	2004-03-09
2	2194	2812	3	2004-03-09
3	2194	1841	3	2004-03-09
1	2195	9644	3	2004-03-19
2	2195	1030	1	2004-03-19
3	2195	1249	1	2004-03-19
4	2195	5604	2	2004-03-19
1	2196	1934	1	2004-03-22
2	2196	9952	1	2004-03-22
3	2196	4587	1	2004-03-22
4	2196	73	2	2004-03-22
5	2196	5822	2	2004-03-22
6	2196	6327	3	2004-03-22
7	2196	994	3	2004-03-22
8	2196	5342	3	2004-03-22
1	2197	4008	1	2004-03-12
2	2197	6104	2	2004-03-12
3	2197	4217	1	2004-03-12
1	2198	9228	1	2004-03-29
2	2198	751	3	2004-03-29
3	2198	4502	2	2004-03-29
4	2198	2003	2	2004-03-29
5	2198	9687	3	2004-03-29
6	2198	8259	2	2004-03-29
7	2198	6456	3	2004-03-29
8	2198	4180	1	2004-03-29
9	2198	6096	3	2004-03-29
1	2199	8492	3	2004-03-19
1	2200	3982	3	2004-03-17
2	2200	3706	1	2004-03-17
3	2200	2905	2	2004-03-17
4	2200	2389	3	2004-03-17
5	2200	9792	2	2004-03-17
1	2201	5491	3	2004-03-07
1	2202	7474	2	2004-03-30
2	2202	2364	3	2004-03-30
3	2202	6688	1	2004-03-30
4	2202	5722	1	2004-03-30
5	2202	3563	2	2004-03-30
6	2202	6622	3	2004-03-30
1	2203	4782	1	2004-03-15
2	2203	4840	2	2004-03-15
3	2203	7531	3	2004-03-15
4	2203	4051	3	2004-03-15
5	2203	7057	3	2004-03-15
6	2203	8415	2	2004-03-15
7	2203	9211	3	2004-03-15
1	2204	5231	1	2004-03-07
2	2204	5348	1	2004-03-07
3	2204	4200	3	2004-03-07
4	2204	5557	1	2004-03-07
5	2204	6454	1	2004-03-07
1	2205	347	1	2004-03-04
2	2205	503	3	2004-03-04
3	2205	9180	2	2004-03-04
4	2205	7622	2	2004-03-04
5	2205	4095	2	2004-03-04
6	2205	2781	1	2004-03-04
1	2206	9404	2	2004-03-16
1	2207	3661	1	2004-03-08
2	2207	7536	1	2004-03-08
3	2207	1817	3	2004-03-08
4	2207	7320	3	2004-03-08
5	2207	4614	3	2004-03-08
6	2207	1699	2	2004-03-08
7	2207	5544	1	2004-03-08
1	2208	9202	3	2004-03-30
2	2208	7071	2	2004-03-30
3	2208	4805	3	2004-03-30
4	2208	4492	2	2004-03-30
1	2209	3721	1	2004-03-08
2	2209	183	1	2004-03-08
3	2209	2732	1	2004-03-08
4	2209	9940	1	2004-03-08
5	2209	1338	2	2004-03-08
6	2209	7717	1	2004-03-08
7	2209	9670	1	2004-03-08
8	2209	3915	3	2004-03-08
1	2210	922	1	2004-03-20
2	2210	9745	2	2004-03-20
3	2210	7234	2	2004-03-20
4	2210	9933	3	2004-03-20
5	2210	1242	3	2004-03-20
6	2210	7968	2	2004-03-20
1	2211	150	2	2004-03-05
2	2211	4291	1	2004-03-05
3	2211	711	1	2004-03-05
4	2211	4524	1	2004-03-05
1	2212	9466	1	2004-03-17
2	2212	7317	1	2004-03-17
1	2213	1297	2	2004-03-10
1	2214	7500	2	2004-03-31
2	2214	5863	2	2004-03-31
3	2214	685	2	2004-03-31
4	2214	9875	2	2004-03-31
5	2214	7500	1	2004-03-31
6	2214	6983	1	2004-03-31
7	2214	965	1	2004-03-31
1	2215	3507	1	2004-03-02
2	2215	314	2	2004-03-02
3	2215	8316	2	2004-03-02
4	2215	6734	3	2004-03-02
5	2215	2471	2	2004-03-02
6	2215	2151	3	2004-03-02
7	2215	4191	3	2004-03-02
8	2215	3851	1	2004-03-02
9	2215	3368	2	2004-03-02
1	2216	3828	2	2004-03-19
2	2216	5589	2	2004-03-19
3	2216	8742	2	2004-03-19
4	2216	5477	1	2004-03-19
1	2217	5486	1	2004-03-19
2	2217	2718	1	2004-03-19
3	2217	1864	2	2004-03-19
4	2217	8699	2	2004-03-19
5	2217	2594	1	2004-03-19
6	2217	3664	2	2004-03-19
1	2218	273	1	2004-03-10
2	2218	2573	2	2004-03-10
3	2218	6984	3	2004-03-10
4	2218	8893	2	2004-03-10
5	2218	4212	2	2004-03-10
6	2218	8406	1	2004-03-10
7	2218	3351	1	2004-03-10
8	2218	6481	3	2004-03-10
9	2218	4593	3	2004-03-10
1	2219	470	3	2004-03-04
2	2219	2645	2	2004-03-04
3	2219	3423	2	2004-03-04
4	2219	1164	2	2004-03-04
5	2219	4593	1	2004-03-04
6	2219	4894	3	2004-03-04
7	2219	5536	1	2004-03-04
8	2219	5326	2	2004-03-04
9	2219	7602	3	2004-03-04
1	2220	8348	2	2004-03-28
2	2220	984	1	2004-03-28
1	2221	1796	3	2004-03-17
2	2221	6767	2	2004-03-17
3	2221	3998	1	2004-03-17
4	2221	26	2	2004-03-17
5	2221	4593	2	2004-03-17
6	2221	6597	3	2004-03-17
7	2221	1784	1	2004-03-17
8	2221	1363	3	2004-03-17
9	2221	6561	3	2004-03-17
1	2222	7504	1	2004-03-21
2	2222	2578	3	2004-03-21
3	2222	6258	3	2004-03-21
4	2222	528	2	2004-03-21
5	2222	7769	1	2004-03-21
6	2222	5518	2	2004-03-21
1	2223	4676	3	2004-03-21
2	2223	1407	1	2004-03-21
3	2223	8804	1	2004-03-21
4	2223	3405	1	2004-03-21
5	2223	299	3	2004-03-21
6	2223	9129	3	2004-03-21
7	2223	5323	2	2004-03-21
1	2224	1314	2	2004-03-11
2	2224	3875	1	2004-03-11
3	2224	9328	1	2004-03-11
4	2224	4164	2	2004-03-11
5	2224	6180	1	2004-03-11
6	2224	4361	1	2004-03-11
1	2225	309	3	2004-03-24
2	2225	2311	2	2004-03-24
3	2225	9191	1	2004-03-24
4	2225	3679	3	2004-03-24
5	2225	9555	3	2004-03-24
6	2225	2419	1	2004-03-24
7	2225	1828	3	2004-03-24
8	2225	8765	1	2004-03-24
9	2225	3510	1	2004-03-24
1	2226	7683	1	2004-03-16
2	2226	72	1	2004-03-16
3	2226	1367	3	2004-03-16
4	2226	1079	1	2004-03-16
5	2226	6908	1	2004-03-16
6	2226	614	3	2004-03-16
7	2226	5101	3	2004-03-16
8	2226	1829	3	2004-03-16
9	2226	8124	1	2004-03-16
1	2227	378	1	2004-03-25
2	2227	2748	2	2004-03-25
3	2227	5658	3	2004-03-25
4	2227	6725	3	2004-03-25
5	2227	6875	2	2004-03-25
6	2227	402	3	2004-03-25
7	2227	6451	1	2004-03-25
8	2227	4734	3	2004-03-25
9	2227	3356	1	2004-03-25
1	2228	3774	1	2004-03-28
2	2228	2796	1	2004-03-28
3	2228	4071	1	2004-03-28
4	2228	2440	3	2004-03-28
1	2229	6704	3	2004-03-01
2	2229	661	2	2004-03-01
3	2229	6940	3	2004-03-01
1	2230	9109	3	2004-03-25
2	2230	1815	1	2004-03-25
3	2230	857	1	2004-03-25
4	2230	6435	1	2004-03-25
1	2231	2106	3	2004-03-15
2	2231	8119	2	2004-03-15
3	2231	6800	3	2004-03-15
4	2231	7361	3	2004-03-15
5	2231	1234	2	2004-03-15
6	2231	5142	1	2004-03-15
7	2231	7493	1	2004-03-15
1	2232	9613	3	2004-03-30
2	2232	3128	1	2004-03-30
3	2232	997	2	2004-03-30
4	2232	2157	3	2004-03-30
1	2233	4446	3	2004-03-18
1	2234	866	1	2004-03-27
2	2234	3519	1	2004-03-27
3	2234	5714	3	2004-03-27
4	2234	3994	1	2004-03-27
5	2234	742	2	2004-03-27
1	2235	8695	1	2004-03-27
2	2235	9573	3	2004-03-27
3	2235	4449	1	2004-03-27
4	2235	7121	1	2004-03-27
5	2235	8633	2	2004-03-27
6	2235	252	1	2004-03-27
7	2235	4504	3	2004-03-27
8	2235	5642	3	2004-03-27
1	2236	8607	2	2004-03-14
2	2236	6387	1	2004-03-14
3	2236	9361	3	2004-03-14
4	2236	6024	3	2004-03-14
5	2236	7292	2	2004-03-14
6	2236	6040	2	2004-03-14
7	2236	3825	2	2004-03-14
1	2237	8421	2	2004-03-18
2	2237	7556	3	2004-03-18
3	2237	9052	1	2004-03-18
1	2238	1201	1	2004-03-24
2	2238	9438	3	2004-03-24
1	2239	2952	3	2004-03-24
2	2239	4702	1	2004-03-24
3	2239	1791	1	2004-03-24
4	2239	6229	2	2004-03-24
5	2239	6354	1	2004-03-24
6	2239	3888	2	2004-03-24
7	2239	4701	1	2004-03-24
1	2240	4317	3	2004-03-30
2	2240	3414	2	2004-03-30
3	2240	194	2	2004-03-30
4	2240	6460	3	2004-03-30
5	2240	4421	2	2004-03-30
6	2240	5455	3	2004-03-30
7	2240	714	3	2004-03-30
8	2240	5259	2	2004-03-30
1	2241	2665	1	2004-03-27
2	2241	6782	2	2004-03-27
3	2241	6207	1	2004-03-27
4	2241	8860	2	2004-03-27
5	2241	3739	3	2004-03-27
1	2242	3222	3	2004-03-15
2	2242	2623	3	2004-03-15
3	2242	8146	3	2004-03-15
4	2242	3588	2	2004-03-15
5	2242	3871	2	2004-03-15
6	2242	2006	3	2004-03-15
7	2242	9717	1	2004-03-15
8	2242	6178	2	2004-03-15
1	2243	5394	2	2004-03-18
2	2243	3795	2	2004-03-18
3	2243	466	3	2004-03-18
1	2244	3071	3	2004-03-13
2	2244	931	2	2004-03-13
3	2244	8492	3	2004-03-13
1	2245	6381	2	2004-03-09
2	2245	5737	2	2004-03-09
3	2245	5336	1	2004-03-09
4	2245	1972	1	2004-03-09
5	2245	757	1	2004-03-09
6	2245	3181	2	2004-03-09
1	2246	4509	2	2004-03-16
2	2246	476	1	2004-03-16
3	2246	6910	2	2004-03-16
4	2246	8908	3	2004-03-16
5	2246	9239	3	2004-03-16
1	2247	8584	2	2004-03-22
2	2247	4273	2	2004-03-22
3	2247	1958	3	2004-03-22
4	2247	6234	2	2004-03-22
5	2247	476	3	2004-03-22
6	2247	4286	2	2004-03-22
7	2247	3140	3	2004-03-22
8	2247	631	2	2004-03-22
9	2247	4648	2	2004-03-22
1	2248	8668	2	2004-03-25
2	2248	2786	3	2004-03-25
3	2248	1545	3	2004-03-25
4	2248	9883	1	2004-03-25
5	2248	9292	3	2004-03-25
1	2249	3173	3	2004-03-22
2	2249	2770	2	2004-03-22
3	2249	6009	3	2004-03-22
4	2249	7304	3	2004-03-22
5	2249	6289	3	2004-03-22
6	2249	2690	1	2004-03-22
7	2249	3075	1	2004-03-22
8	2249	6058	3	2004-03-22
1	2250	2632	2	2004-03-18
2	2250	8157	1	2004-03-18
3	2250	5024	3	2004-03-18
4	2250	980	1	2004-03-18
5	2250	1013	2	2004-03-18
6	2250	747	2	2004-03-18
7	2250	2784	2	2004-03-18
8	2250	7833	3	2004-03-18
1	2251	3071	1	2004-03-02
2	2251	7795	2	2004-03-02
3	2251	1355	2	2004-03-02
4	2251	4456	3	2004-03-02
5	2251	8578	3	2004-03-02
6	2251	5483	1	2004-03-02
7	2251	913	2	2004-03-02
1	2252	7843	1	2004-03-12
2	2252	8468	3	2004-03-12
3	2252	6286	1	2004-03-12
4	2252	2106	2	2004-03-12
5	2252	44	1	2004-03-12
1	2253	8613	3	2004-03-29
2	2253	8468	3	2004-03-29
3	2253	1184	1	2004-03-29
1	2254	970	1	2004-03-22
2	2254	6116	2	2004-03-22
3	2254	6684	3	2004-03-22
1	2255	3116	2	2004-03-30
2	2255	9114	2	2004-03-30
3	2255	9708	3	2004-03-30
4	2255	7899	3	2004-03-30
5	2255	7141	3	2004-03-30
6	2255	1285	2	2004-03-30
7	2255	4767	3	2004-03-30
8	2255	5721	2	2004-03-30
1	2256	5191	3	2004-03-09
2	2256	3258	1	2004-03-09
3	2256	1372	3	2004-03-09
1	2257	8630	3	2004-03-27
2	2257	3404	3	2004-03-27
3	2257	2805	1	2004-03-27
4	2257	6901	1	2004-03-27
5	2257	2072	2	2004-03-27
6	2257	8139	2	2004-03-27
7	2257	9794	1	2004-03-27
8	2257	3109	2	2004-03-27
1	2258	8296	2	2004-03-28
2	2258	1243	1	2004-03-28
3	2258	4723	1	2004-03-28
4	2258	1495	1	2004-03-28
5	2258	3381	2	2004-03-28
1	2259	9753	2	2004-03-04
2	2259	7561	2	2004-03-04
3	2259	7052	3	2004-03-04
4	2259	694	2	2004-03-04
5	2259	2988	1	2004-03-04
1	2260	1882	2	2004-03-26
2	2260	1512	1	2004-03-26
3	2260	7645	1	2004-03-26
4	2260	1731	1	2004-03-26
5	2260	5368	1	2004-03-26
6	2260	5600	3	2004-03-26
7	2260	9186	2	2004-03-26
1	2261	9078	3	2004-03-03
1	2262	1319	1	2004-03-23
2	2262	8343	3	2004-03-23
3	2262	7373	2	2004-03-23
4	2262	6361	3	2004-03-23
5	2262	8571	3	2004-03-23
6	2262	9431	2	2004-03-23
7	2262	625	1	2004-03-23
8	2262	8582	2	2004-03-23
1	2263	828	2	2004-03-14
2	2263	6301	1	2004-03-14
3	2263	6006	2	2004-03-14
4	2263	580	1	2004-03-14
1	2264	144	3	2004-03-05
2	2264	2240	3	2004-03-05
3	2264	3709	3	2004-03-05
1	2265	8494	3	2004-03-21
2	2265	7362	3	2004-03-21
3	2265	3089	1	2004-03-21
4	2265	1257	3	2004-03-21
5	2265	5318	1	2004-03-21
6	2265	3324	1	2004-03-21
1	2266	2497	3	2004-03-13
2	2266	3455	2	2004-03-13
3	2266	1332	2	2004-03-13
4	2266	2886	2	2004-03-13
5	2266	1115	2	2004-03-13
1	2267	4085	3	2004-03-07
2	2267	5739	1	2004-03-07
3	2267	4441	3	2004-03-07
4	2267	3193	2	2004-03-07
5	2267	6655	3	2004-03-07
6	2267	7781	3	2004-03-07
7	2267	129	1	2004-03-07
8	2267	9307	3	2004-03-07
1	2268	5322	3	2004-03-20
2	2268	3429	3	2004-03-20
3	2268	534	2	2004-03-20
4	2268	4801	1	2004-03-20
5	2268	2427	2	2004-03-20
6	2268	1347	2	2004-03-20
7	2268	1040	3	2004-03-20
8	2268	7958	2	2004-03-20
9	2268	5912	1	2004-03-20
1	2269	2544	3	2004-03-04
2	2269	746	1	2004-03-04
3	2269	6914	3	2004-03-04
4	2269	3652	1	2004-03-04
5	2269	6952	3	2004-03-04
6	2269	9507	1	2004-03-04
7	2269	7180	1	2004-03-04
8	2269	4923	1	2004-03-04
9	2269	2745	3	2004-03-04
1	2270	1177	1	2004-03-18
2	2270	2173	3	2004-03-18
3	2270	2968	2	2004-03-18
4	2270	9655	1	2004-03-18
5	2270	2307	1	2004-03-18
6	2270	2415	1	2004-03-18
7	2270	4048	3	2004-03-18
1	2271	6673	1	2004-03-01
2	2271	7505	2	2004-03-01
3	2271	1418	1	2004-03-01
4	2271	5833	2	2004-03-01
5	2271	9778	1	2004-03-01
6	2271	8253	2	2004-03-01
7	2271	8180	3	2004-03-01
1	2272	3701	2	2004-03-17
2	2272	1049	2	2004-03-17
3	2272	8371	2	2004-03-17
4	2272	9060	1	2004-03-17
5	2272	2791	3	2004-03-17
6	2272	117	2	2004-03-17
7	2272	6358	3	2004-03-17
8	2272	6040	2	2004-03-17
1	2273	1619	2	2004-03-02
2	2273	7961	3	2004-03-02
3	2273	9706	2	2004-03-02
4	2273	9302	2	2004-03-02
5	2273	6492	2	2004-03-02
6	2273	3584	1	2004-03-02
1	2274	8095	2	2004-03-07
1	2275	5548	1	2004-03-09
2	2275	9686	1	2004-03-09
3	2275	4712	1	2004-03-09
1	2276	7070	2	2004-03-29
1	2277	1936	3	2004-03-02
2	2277	5654	2	2004-03-02
3	2277	7584	3	2004-03-02
4	2277	151	2	2004-03-02
5	2277	8007	3	2004-03-02
6	2277	9041	1	2004-03-02
7	2277	9132	2	2004-03-02
8	2277	3682	2	2004-03-02
9	2277	4380	2	2004-03-02
1	2278	94	1	2004-03-20
2	2278	5971	3	2004-03-20
3	2278	5256	2	2004-03-20
4	2278	3939	2	2004-03-20
5	2278	6340	2	2004-03-20
1	2279	9638	1	2004-03-12
2	2279	4916	3	2004-03-12
1	2280	7488	1	2004-03-31
2	2280	3599	1	2004-03-31
3	2280	5478	3	2004-03-31
4	2280	959	3	2004-03-31
5	2280	5172	1	2004-03-31
6	2280	9666	1	2004-03-31
7	2280	8216	2	2004-03-31
8	2280	7646	1	2004-03-31
9	2280	1078	2	2004-03-31
1	2281	5760	2	2004-03-25
2	2281	965	1	2004-03-25
3	2281	3260	1	2004-03-25
4	2281	4631	1	2004-03-25
5	2281	9674	1	2004-03-25
6	2281	3801	1	2004-03-25
7	2281	3985	3	2004-03-25
8	2281	3136	2	2004-03-25
9	2281	8449	3	2004-03-25
1	2282	3036	3	2004-03-19
2	2282	6366	2	2004-03-19
3	2282	1079	2	2004-03-19
4	2282	8740	3	2004-03-19
1	2283	5174	2	2004-03-12
2	2283	5532	3	2004-03-12
3	2283	7622	2	2004-03-12
4	2283	1922	1	2004-03-12
5	2283	8478	2	2004-03-12
1	2284	9920	3	2004-03-03
2	2284	7263	3	2004-03-03
3	2284	1056	1	2004-03-03
4	2284	6462	3	2004-03-03
5	2284	4411	3	2004-03-03
6	2284	1815	1	2004-03-03
7	2284	4597	2	2004-03-03
8	2284	7650	3	2004-03-03
9	2284	406	1	2004-03-03
1	2285	1143	2	2004-03-10
1	2286	1234	1	2004-03-07
2	2286	2090	1	2004-03-07
3	2286	8149	3	2004-03-07
1	2287	6626	2	2004-03-02
2	2287	4523	3	2004-03-02
3	2287	7212	3	2004-03-02
4	2287	4068	2	2004-03-02
5	2287	6387	2	2004-03-02
6	2287	7685	3	2004-03-02
7	2287	411	1	2004-03-02
1	2288	1174	2	2004-03-02
2	2288	5591	1	2004-03-02
3	2288	6621	3	2004-03-02
1	2289	3974	3	2004-03-12
2	2289	1063	1	2004-03-12
3	2289	744	2	2004-03-12
4	2289	9039	3	2004-03-12
1	2290	7580	1	2004-03-15
1	2291	9543	2	2004-03-03
1	2292	3123	3	2004-03-12
2	2292	7003	3	2004-03-12
3	2292	2379	2	2004-03-12
4	2292	762	2	2004-03-12
5	2292	719	1	2004-03-12
6	2292	6951	1	2004-03-12
7	2292	7409	2	2004-03-12
8	2292	9418	1	2004-03-12
9	2292	9095	1	2004-03-12
1	2293	4664	2	2004-03-10
2	2293	4962	2	2004-03-10
3	2293	9221	3	2004-03-10
4	2293	4923	1	2004-03-10
1	2294	4726	1	2004-03-25
2	2294	9054	2	2004-03-25
3	2294	6550	3	2004-03-25
4	2294	7311	2	2004-03-25
5	2294	1235	2	2004-03-25
1	2295	2887	1	2004-03-30
2	2295	5257	2	2004-03-30
3	2295	3912	3	2004-03-30
4	2295	9170	3	2004-03-30
5	2295	4126	3	2004-03-30
6	2295	7567	3	2004-03-30
7	2295	8600	2	2004-03-30
8	2295	7093	2	2004-03-30
1	2296	7306	1	2004-03-02
2	2296	9427	2	2004-03-02
3	2296	6666	1	2004-03-02
4	2296	9335	2	2004-03-02
5	2296	1314	2	2004-03-02
6	2296	4737	2	2004-03-02
7	2296	6198	3	2004-03-02
8	2296	9823	1	2004-03-02
9	2296	9913	3	2004-03-02
1	2297	3087	2	2004-03-28
2	2297	2130	1	2004-03-28
3	2297	2401	1	2004-03-28
4	2297	1998	3	2004-03-28
5	2297	2386	3	2004-03-28
6	2297	2183	1	2004-03-28
1	2298	5003	2	2004-03-13
2	2298	9420	3	2004-03-13
3	2298	7989	2	2004-03-13
1	2299	6802	2	2004-03-31
2	2299	3683	2	2004-03-31
3	2299	1255	3	2004-03-31
4	2299	164	2	2004-03-31
5	2299	6948	1	2004-03-31
6	2299	6116	3	2004-03-31
7	2299	1581	3	2004-03-31
8	2299	8249	2	2004-03-31
9	2299	313	1	2004-03-31
1	2300	6574	2	2004-03-09
2	2300	7353	2	2004-03-09
3	2300	460	3	2004-03-09
4	2300	2373	2	2004-03-09
5	2300	6729	3	2004-03-09
6	2300	894	1	2004-03-09
7	2300	3356	1	2004-03-09
1	2301	6083	1	2004-03-23
2	2301	3073	3	2004-03-23
3	2301	149	1	2004-03-23
4	2301	1426	1	2004-03-23
1	2302	1651	3	2004-03-11
2	2302	3756	3	2004-03-11
3	2302	4383	2	2004-03-11
4	2302	6088	3	2004-03-11
5	2302	401	1	2004-03-11
6	2302	5928	1	2004-03-11
7	2302	3226	3	2004-03-11
8	2302	3442	1	2004-03-11
9	2302	2804	3	2004-03-11
1	2303	6548	1	2004-03-15
2	2303	8925	3	2004-03-15
3	2303	1231	1	2004-03-15
4	2303	2011	2	2004-03-15
5	2303	1327	2	2004-03-15
6	2303	4298	2	2004-03-15
7	2303	2664	3	2004-03-15
1	2304	1567	1	2004-03-29
2	2304	991	2	2004-03-29
3	2304	646	2	2004-03-29
4	2304	5197	2	2004-03-29
5	2304	3408	3	2004-03-29
6	2304	2335	2	2004-03-29
7	2304	7331	3	2004-03-29
8	2304	4800	2	2004-03-29
9	2304	6856	2	2004-03-29
1	2305	2527	2	2004-03-27
2	2305	5077	2	2004-03-27
3	2305	3486	2	2004-03-27
4	2305	3942	3	2004-03-27
5	2305	4071	2	2004-03-27
6	2305	281	2	2004-03-27
7	2305	300	1	2004-03-27
8	2305	9494	2	2004-03-27
9	2305	4376	1	2004-03-27
1	2306	5592	1	2004-03-17
2	2306	8810	1	2004-03-17
3	2306	7761	3	2004-03-17
1	2307	3074	1	2004-03-05
2	2307	9030	2	2004-03-05
3	2307	6925	1	2004-03-05
4	2307	5478	1	2004-03-05
1	2308	6685	2	2004-03-27
2	2308	4275	1	2004-03-27
3	2308	8449	3	2004-03-27
4	2308	7770	2	2004-03-27
5	2308	2053	2	2004-03-27
6	2308	7109	1	2004-03-27
7	2308	5807	2	2004-03-27
8	2308	8342	3	2004-03-27
1	2309	8368	3	2004-03-10
2	2309	2770	2	2004-03-10
3	2309	2958	3	2004-03-10
4	2309	6287	1	2004-03-10
5	2309	4006	1	2004-03-10
6	2309	214	1	2004-03-10
1	2310	3986	3	2004-03-25
2	2310	1718	2	2004-03-25
3	2310	2880	3	2004-03-25
4	2310	6901	3	2004-03-25
5	2310	3696	2	2004-03-25
6	2310	5806	3	2004-03-25
1	2311	6751	2	2004-03-04
2	2311	4716	3	2004-03-04
3	2311	4060	1	2004-03-04
4	2311	1144	3	2004-03-04
5	2311	3344	1	2004-03-04
6	2311	8756	1	2004-03-04
7	2311	5845	1	2004-03-04
8	2311	7573	3	2004-03-04
9	2311	26	3	2004-03-04
1	2312	1593	1	2004-03-19
2	2312	8010	3	2004-03-19
3	2312	8645	3	2004-03-19
1	2313	7500	1	2004-03-13
1	2314	9625	3	2004-03-02
2	2314	3121	3	2004-03-02
1	2315	8797	3	2004-03-28
2	2315	5650	2	2004-03-28
3	2315	1818	2	2004-03-28
4	2315	7433	2	2004-03-28
5	2315	5579	2	2004-03-28
6	2315	808	2	2004-03-28
1	2316	5882	2	2004-03-14
2	2316	6208	2	2004-03-14
3	2316	4969	1	2004-03-14
1	2317	2975	3	2004-03-26
2	2317	351	1	2004-03-26
1	2318	3812	1	2004-03-10
2	2318	2527	1	2004-03-10
3	2318	6000	3	2004-03-10
4	2318	6688	3	2004-03-10
5	2318	2329	1	2004-03-10
6	2318	1778	3	2004-03-10
7	2318	4198	3	2004-03-10
8	2318	1648	1	2004-03-10
1	2319	1211	3	2004-03-13
2	2319	3811	2	2004-03-13
3	2319	5541	2	2004-03-13
1	2320	7412	3	2004-03-19
2	2320	9408	3	2004-03-19
3	2320	8365	2	2004-03-19
4	2320	8045	2	2004-03-19
5	2320	2216	1	2004-03-19
6	2320	6248	2	2004-03-19
7	2320	8611	1	2004-03-19
1	2321	6876	1	2004-03-06
2	2321	8237	3	2004-03-06
3	2321	457	1	2004-03-06
4	2321	2271	2	2004-03-06
5	2321	6209	3	2004-03-06
6	2321	4649	3	2004-03-06
1	2322	1999	2	2004-03-16
2	2322	9950	1	2004-03-16
3	2322	53	1	2004-03-16
4	2322	416	2	2004-03-16
5	2322	6158	3	2004-03-16
1	2323	3622	2	2004-03-21
2	2323	9265	1	2004-03-21
3	2323	4248	3	2004-03-21
4	2323	3906	2	2004-03-21
5	2323	5718	1	2004-03-21
6	2323	4835	1	2004-03-21
7	2323	9632	3	2004-03-21
1	2324	1271	2	2004-03-08
2	2324	4467	1	2004-03-08
3	2324	6626	2	2004-03-08
4	2324	7624	1	2004-03-08
1	2325	1964	2	2004-03-13
2	2325	9355	1	2004-03-13
3	2325	6073	2	2004-03-13
1	2326	92	2	2004-03-03
2	2326	7031	3	2004-03-03
3	2326	4923	3	2004-03-03
4	2326	5993	3	2004-03-03
5	2326	3880	3	2004-03-03
6	2326	3893	3	2004-03-03
1	2327	3303	3	2004-03-27
2	2327	577	2	2004-03-27
3	2327	332	1	2004-03-27
4	2327	8110	3	2004-03-27
5	2327	3768	2	2004-03-27
6	2327	3288	2	2004-03-27
1	2328	8362	3	2004-03-13
2	2328	3975	1	2004-03-13
3	2328	7867	3	2004-03-13
4	2328	2717	1	2004-03-13
1	2329	7129	1	2004-03-23
2	2329	2023	1	2004-03-23
3	2329	460	1	2004-03-23
4	2329	4326	1	2004-03-23
5	2329	5139	1	2004-03-23
6	2329	477	3	2004-03-23
1	2330	7173	2	2004-03-21
1	2331	8818	1	2004-03-16
2	2331	8966	1	2004-03-16
3	2331	3026	2	2004-03-16
4	2331	8144	1	2004-03-16
5	2331	2009	2	2004-03-16
6	2331	6439	2	2004-03-16
7	2331	5702	3	2004-03-16
8	2331	6629	1	2004-03-16
9	2331	7689	1	2004-03-16
1	2332	1930	2	2004-03-08
2	2332	9851	3	2004-03-08
3	2332	9297	2	2004-03-08
4	2332	4636	1	2004-03-08
5	2332	3875	2	2004-03-08
6	2332	3989	1	2004-03-08
7	2332	4987	3	2004-03-08
8	2332	9034	1	2004-03-08
9	2332	132	1	2004-03-08
1	2333	3468	1	2004-03-27
2	2333	4132	1	2004-03-27
3	2333	3468	2	2004-03-27
4	2333	9322	2	2004-03-27
1	2334	353	3	2004-03-18
2	2334	396	2	2004-03-18
3	2334	443	2	2004-03-18
4	2334	8441	2	2004-03-18
5	2334	7109	2	2004-03-18
1	2335	7184	2	2004-03-05
2	2335	8147	1	2004-03-05
1	2336	2771	3	2004-03-29
2	2336	9788	1	2004-03-29
3	2336	1565	2	2004-03-29
1	2337	7735	1	2004-03-11
2	2337	8682	3	2004-03-11
3	2337	5642	3	2004-03-11
4	2337	2610	1	2004-03-11
1	2338	5632	2	2004-03-02
2	2338	2065	2	2004-03-02
3	2338	8331	1	2004-03-02
4	2338	5393	1	2004-03-02
5	2338	4323	3	2004-03-02
6	2338	9710	2	2004-03-02
7	2338	254	1	2004-03-02
1	2339	7290	3	2004-03-30
1	2340	3093	3	2004-03-06
2	2340	306	2	2004-03-06
3	2340	3851	3	2004-03-06
4	2340	747	3	2004-03-06
5	2340	5275	1	2004-03-06
6	2340	3260	2	2004-03-06
7	2340	3940	3	2004-03-06
1	2341	2372	3	2004-03-19
2	2341	6876	1	2004-03-19
3	2341	664	3	2004-03-19
4	2341	2480	3	2004-03-19
5	2341	7161	2	2004-03-19
6	2341	3925	2	2004-03-19
1	2342	659	3	2004-03-07
2	2342	1454	1	2004-03-07
3	2342	7477	3	2004-03-07
1	2343	9389	2	2004-03-14
2	2343	6420	2	2004-03-14
3	2343	1828	3	2004-03-14
4	2343	3271	3	2004-03-14
5	2343	728	2	2004-03-14
6	2343	6854	1	2004-03-14
7	2343	1887	2	2004-03-14
8	2343	7601	2	2004-03-14
1	2344	1806	2	2004-03-26
2	2344	502	1	2004-03-26
3	2344	4893	3	2004-03-26
1	2345	7267	3	2004-03-31
1	2346	2477	3	2004-03-21
2	2346	7078	1	2004-03-21
3	2346	1512	2	2004-03-21
4	2346	6412	2	2004-03-21
5	2346	7946	2	2004-03-21
6	2346	9210	2	2004-03-21
7	2346	3563	1	2004-03-21
8	2346	8816	2	2004-03-21
1	2347	7296	3	2004-03-18
1	2348	4116	2	2004-03-30
2	2348	480	3	2004-03-30
3	2348	3857	1	2004-03-30
4	2348	6000	1	2004-03-30
5	2348	6160	3	2004-03-30
6	2348	4865	1	2004-03-30
7	2348	909	1	2004-03-30
1	2349	2156	3	2004-03-21
1	2350	8097	2	2004-03-18
2	2350	2757	3	2004-03-18
3	2350	559	1	2004-03-18
4	2350	4417	2	2004-03-18
1	2351	7851	3	2004-03-23
1	2352	6583	3	2004-03-07
2	2352	9640	1	2004-03-07
3	2352	7633	3	2004-03-07
4	2352	3315	3	2004-03-07
5	2352	6693	3	2004-03-07
6	2352	7468	2	2004-03-07
7	2352	2972	2	2004-03-07
1	2353	7420	3	2004-03-27
2	2353	3723	2	2004-03-27
3	2353	2499	3	2004-03-27
4	2353	5624	1	2004-03-27
5	2353	5913	3	2004-03-27
6	2353	4361	1	2004-03-27
7	2353	4417	1	2004-03-27
8	2353	33	2	2004-03-27
9	2353	4110	3	2004-03-27
1	2354	6253	2	2004-03-09
2	2354	3451	3	2004-03-09
3	2354	485	1	2004-03-09
4	2354	4953	2	2004-03-09
5	2354	991	1	2004-03-09
6	2354	1275	2	2004-03-09
7	2354	6966	2	2004-03-09
8	2354	1532	1	2004-03-09
9	2354	4122	3	2004-03-09
1	2355	9425	3	2004-03-01
2	2355	8648	2	2004-03-01
3	2355	7659	1	2004-03-01
4	2355	958	2	2004-03-01
5	2355	968	3	2004-03-01
1	2356	6360	1	2004-03-01
1	2357	2065	1	2004-03-13
2	2357	9234	2	2004-03-13
3	2357	3313	2	2004-03-13
4	2357	1040	2	2004-03-13
5	2357	1838	1	2004-03-13
1	2358	4797	3	2004-03-26
2	2358	8191	2	2004-03-26
3	2358	3767	3	2004-03-26
4	2358	2965	2	2004-03-26
5	2358	3577	3	2004-03-26
6	2358	4314	3	2004-03-26
7	2358	787	3	2004-03-26
1	2359	5270	1	2004-03-23
2	2359	2947	3	2004-03-23
3	2359	6550	2	2004-03-23
4	2359	2071	3	2004-03-23
5	2359	4989	1	2004-03-23
6	2359	9650	2	2004-03-23
7	2359	6882	2	2004-03-23
8	2359	4639	2	2004-03-23
9	2359	200	3	2004-03-23
1	2360	2564	2	2004-03-14
2	2360	7745	2	2004-03-14
3	2360	5016	2	2004-03-14
4	2360	7895	3	2004-03-14
5	2360	4383	1	2004-03-14
6	2360	2172	3	2004-03-14
7	2360	1746	3	2004-03-14
8	2360	1317	2	2004-03-14
1	2361	2289	1	2004-03-23
2	2361	1204	3	2004-03-23
3	2361	5924	1	2004-03-23
4	2361	5333	1	2004-03-23
5	2361	4568	3	2004-03-23
6	2361	7963	3	2004-03-23
7	2361	4052	2	2004-03-23
1	2362	8044	2	2004-03-02
2	2362	1539	1	2004-03-02
3	2362	2451	1	2004-03-02
4	2362	8936	2	2004-03-02
5	2362	7101	2	2004-03-02
6	2362	72	1	2004-03-02
7	2362	2802	1	2004-03-02
8	2362	1920	2	2004-03-02
1	2363	7998	3	2004-03-29
2	2363	2155	2	2004-03-29
3	2363	7107	2	2004-03-29
4	2363	1667	3	2004-03-29
5	2363	5274	1	2004-03-29
1	2364	3533	3	2004-03-19
2	2364	783	1	2004-03-19
3	2364	3744	3	2004-03-19
4	2364	8513	2	2004-03-19
5	2364	8953	1	2004-03-19
6	2364	6175	1	2004-03-19
7	2364	5319	2	2004-03-19
1	2365	704	1	2004-03-28
2	2365	2673	3	2004-03-28
3	2365	8443	2	2004-03-28
4	2365	5397	2	2004-03-28
5	2365	6744	1	2004-03-28
6	2365	7034	2	2004-03-28
7	2365	8857	1	2004-03-28
1	2366	7523	1	2004-03-14
2	2366	1805	2	2004-03-14
3	2366	2860	3	2004-03-14
4	2366	7349	3	2004-03-14
5	2366	3441	2	2004-03-14
6	2366	8906	2	2004-03-14
7	2366	2778	3	2004-03-14
8	2366	5759	2	2004-03-14
1	2367	7917	2	2004-03-23
2	2367	4173	2	2004-03-23
3	2367	801	1	2004-03-23
1	2368	3036	1	2004-03-18
2	2368	94	2	2004-03-18
3	2368	6667	1	2004-03-18
4	2368	2819	2	2004-03-18
5	2368	1132	2	2004-03-18
6	2368	79	1	2004-03-18
7	2368	9782	1	2004-03-18
8	2368	9647	2	2004-03-18
1	2369	9882	3	2004-03-26
2	2369	4627	2	2004-03-26
3	2369	2608	2	2004-03-26
4	2369	7083	3	2004-03-26
5	2369	473	3	2004-03-26
6	2369	6672	2	2004-03-26
7	2369	9942	3	2004-03-26
8	2369	8347	2	2004-03-26
1	2370	7425	1	2004-03-31
1	2371	2746	1	2004-03-03
1	2372	145	2	2004-03-24
2	2372	1533	1	2004-03-24
3	2372	12	3	2004-03-24
4	2372	876	1	2004-03-24
5	2372	8367	3	2004-03-24
6	2372	3992	3	2004-03-24
7	2372	4313	1	2004-03-24
1	2373	4880	1	2004-03-16
2	2373	6241	2	2004-03-16
3	2373	8133	3	2004-03-16
4	2373	6299	1	2004-03-16
5	2373	1664	2	2004-03-16
1	2374	6208	1	2004-03-11
2	2374	6263	2	2004-03-11
3	2374	1522	3	2004-03-11
4	2374	6703	3	2004-03-11
1	2375	3033	1	2004-03-15
2	2375	3028	2	2004-03-15
3	2375	8652	3	2004-03-15
4	2375	7463	2	2004-03-15
5	2375	3674	2	2004-03-15
6	2375	4692	3	2004-03-15
7	2375	6474	2	2004-03-15
8	2375	3868	3	2004-03-15
9	2375	7978	2	2004-03-15
1	2376	405	3	2004-03-11
2	2376	6749	3	2004-03-11
3	2376	9558	1	2004-03-11
4	2376	7802	3	2004-03-11
5	2376	432	1	2004-03-11
6	2376	867	2	2004-03-11
7	2376	7370	3	2004-03-11
8	2376	1367	2	2004-03-11
9	2376	4411	2	2004-03-11
1	2377	5459	3	2004-03-02
2	2377	6739	2	2004-03-02
3	2377	4122	1	2004-03-02
4	2377	7622	1	2004-03-02
5	2377	9698	3	2004-03-02
6	2377	1940	2	2004-03-02
7	2377	5135	1	2004-03-02
1	2378	3771	1	2004-03-25
2	2378	1771	1	2004-03-25
3	2378	9636	1	2004-03-25
4	2378	5972	2	2004-03-25
5	2378	8178	2	2004-03-25
6	2378	3149	1	2004-03-25
7	2378	3299	3	2004-03-25
8	2378	2071	1	2004-03-25
1	2379	8462	3	2004-03-07
2	2379	7692	1	2004-03-07
3	2379	6268	1	2004-03-07
4	2379	1898	2	2004-03-07
5	2379	5762	1	2004-03-07
6	2379	2460	3	2004-03-07
7	2379	1265	2	2004-03-07
8	2379	672	1	2004-03-07
9	2379	7367	2	2004-03-07
1	2380	8734	2	2004-03-16
2	2380	6702	1	2004-03-16
3	2380	6377	3	2004-03-16
4	2380	6996	2	2004-03-16
5	2380	8410	2	2004-03-16
6	2380	6322	2	2004-03-16
7	2380	5858	1	2004-03-16
8	2380	8927	3	2004-03-16
1	2381	4220	1	2004-03-21
2	2381	3427	2	2004-03-21
3	2381	1069	1	2004-03-21
4	2381	1534	2	2004-03-21
5	2381	6337	2	2004-03-21
6	2381	4110	2	2004-03-21
7	2381	915	1	2004-03-21
8	2381	5875	3	2004-03-21
9	2381	9556	1	2004-03-21
1	2382	4067	2	2004-03-12
1	2383	7680	1	2004-03-09
2	2383	8635	1	2004-03-09
3	2383	1013	1	2004-03-09
4	2383	6790	1	2004-03-09
5	2383	2853	3	2004-03-09
6	2383	8096	3	2004-03-09
7	2383	2899	1	2004-03-09
8	2383	4260	2	2004-03-09
9	2383	3016	1	2004-03-09
1	2384	538	1	2004-03-04
2	2384	5006	2	2004-03-04
3	2384	5515	3	2004-03-04
4	2384	7596	3	2004-03-04
5	2384	7144	2	2004-03-04
1	2385	7838	2	2004-03-26
2	2385	1392	1	2004-03-26
3	2385	2288	3	2004-03-26
4	2385	9880	2	2004-03-26
5	2385	1692	2	2004-03-26
6	2385	8999	2	2004-03-26
7	2385	4272	1	2004-03-26
8	2385	7280	3	2004-03-26
9	2385	4995	3	2004-03-26
1	2386	7706	1	2004-03-27
2	2386	1575	2	2004-03-27
3	2386	5293	3	2004-03-27
4	2386	627	1	2004-03-27
1	2387	9155	3	2004-03-29
1	2388	3174	1	2004-03-01
2	2388	6463	3	2004-03-01
1	2389	1560	1	2004-03-10
2	2389	7999	2	2004-03-10
3	2389	7443	2	2004-03-10
4	2389	3997	3	2004-03-10
5	2389	553	3	2004-03-10
6	2389	8891	1	2004-03-10
7	2389	1755	3	2004-03-10
8	2389	9644	3	2004-03-10
1	2390	7833	1	2004-03-27
2	2390	469	1	2004-03-27
3	2390	3711	3	2004-03-27
4	2390	8451	3	2004-03-27
5	2390	675	1	2004-03-27
6	2390	4713	1	2004-03-27
7	2390	6494	1	2004-03-27
8	2390	6214	2	2004-03-27
1	2391	9498	1	2004-03-27
2	2391	146	1	2004-03-27
3	2391	9919	3	2004-03-27
4	2391	9439	3	2004-03-27
5	2391	8587	2	2004-03-27
6	2391	7283	2	2004-03-27
7	2391	7151	3	2004-03-27
8	2391	7425	1	2004-03-27
9	2391	4683	2	2004-03-27
1	2392	7591	2	2004-03-24
2	2392	5000	2	2004-03-24
3	2392	9475	2	2004-03-24
1	2393	4272	1	2004-03-13
2	2393	4764	2	2004-03-13
3	2393	2314	2	2004-03-13
4	2393	2759	1	2004-03-13
1	2394	7791	2	2004-03-02
2	2394	8557	1	2004-03-02
3	2394	619	2	2004-03-02
4	2394	7831	3	2004-03-02
5	2394	8421	2	2004-03-02
6	2394	5202	2	2004-03-02
7	2394	9224	2	2004-03-02
1	2395	6747	1	2004-03-22
2	2395	1739	1	2004-03-22
3	2395	5565	2	2004-03-22
4	2395	5712	3	2004-03-22
5	2395	4954	2	2004-03-22
6	2395	8364	1	2004-03-22
7	2395	3951	2	2004-03-22
8	2395	7017	1	2004-03-22
9	2395	8628	3	2004-03-22
1	2396	1879	1	2004-03-27
2	2396	480	1	2004-03-27
3	2396	7176	3	2004-03-27
4	2396	4339	2	2004-03-27
5	2396	6527	1	2004-03-27
6	2396	5655	3	2004-03-27
7	2396	2595	1	2004-03-27
1	2397	4562	3	2004-03-08
2	2397	9544	3	2004-03-08
3	2397	4060	2	2004-03-08
4	2397	1019	1	2004-03-08
5	2397	4196	3	2004-03-08
6	2397	9146	1	2004-03-08
7	2397	6717	1	2004-03-08
1	2398	4510	2	2004-03-13
2	2398	5451	1	2004-03-13
1	2399	2325	1	2004-03-24
1	2400	9774	3	2004-03-27
2	2400	1523	2	2004-03-27
3	2400	4991	1	2004-03-27
1	2401	682	3	2004-03-21
2	2401	6689	2	2004-03-21
3	2401	6111	3	2004-03-21
4	2401	5848	1	2004-03-21
5	2401	5277	1	2004-03-21
6	2401	1656	1	2004-03-21
1	2402	2573	1	2004-03-08
2	2402	6596	1	2004-03-08
3	2402	4426	2	2004-03-08
4	2402	9891	2	2004-03-08
5	2402	202	2	2004-03-08
1	2403	2388	2	2004-03-27
1	2404	7890	2	2004-03-30
2	2404	6333	1	2004-03-30
3	2404	6573	3	2004-03-30
4	2404	5991	3	2004-03-30
5	2404	8943	3	2004-03-30
6	2404	3705	1	2004-03-30
1	2405	6669	1	2004-03-02
2	2405	746	3	2004-03-02
3	2405	7748	3	2004-03-02
4	2405	3593	1	2004-03-02
5	2405	9920	2	2004-03-02
1	2406	5234	1	2004-03-21
2	2406	1269	1	2004-03-21
3	2406	6114	3	2004-03-21
4	2406	9553	1	2004-03-21
5	2406	6818	3	2004-03-21
6	2406	1060	1	2004-03-21
1	2407	6229	3	2004-03-01
2	2407	5851	3	2004-03-01
3	2407	4362	2	2004-03-01
1	2408	3935	1	2004-03-20
2	2408	5649	3	2004-03-20
3	2408	7976	1	2004-03-20
4	2408	1939	3	2004-03-20
5	2408	2447	3	2004-03-20
6	2408	7086	1	2004-03-20
1	2409	4425	1	2004-03-01
2	2409	2646	2	2004-03-01
1	2410	5849	3	2004-03-11
2	2410	2940	1	2004-03-11
3	2410	5053	3	2004-03-11
4	2410	8183	3	2004-03-11
5	2410	337	2	2004-03-11
6	2410	7979	3	2004-03-11
7	2410	4713	3	2004-03-11
8	2410	7555	3	2004-03-11
9	2410	7969	2	2004-03-11
1	2411	9338	1	2004-03-29
2	2411	160	1	2004-03-29
3	2411	8215	2	2004-03-29
4	2411	858	1	2004-03-29
5	2411	2991	3	2004-03-29
6	2411	8051	2	2004-03-29
7	2411	8761	1	2004-03-29
8	2411	4286	3	2004-03-29
9	2411	2090	2	2004-03-29
1	2412	9985	1	2004-03-03
2	2412	2647	3	2004-03-03
3	2412	5128	1	2004-03-03
4	2412	6077	2	2004-03-03
5	2412	1460	2	2004-03-03
1	2413	5269	3	2004-03-21
2	2413	5804	3	2004-03-21
3	2413	4960	2	2004-03-21
4	2413	4190	2	2004-03-21
5	2413	6956	3	2004-03-21
1	2414	9114	2	2004-03-03
2	2414	6925	3	2004-03-03
1	2415	1377	1	2004-03-21
2	2415	5315	1	2004-03-21
1	2416	6804	3	2004-03-27
2	2416	4192	1	2004-03-27
3	2416	7982	3	2004-03-27
4	2416	6461	1	2004-03-27
5	2416	2871	2	2004-03-27
6	2416	647	2	2004-03-27
1	2417	9772	1	2004-03-08
2	2417	674	2	2004-03-08
1	2418	853	1	2004-03-05
2	2418	5681	3	2004-03-05
3	2418	5200	1	2004-03-05
1	2419	4610	3	2004-03-17
2	2419	8674	1	2004-03-17
3	2419	10	1	2004-03-17
4	2419	4486	1	2004-03-17
5	2419	5078	3	2004-03-17
6	2419	4398	1	2004-03-17
7	2419	8522	2	2004-03-17
8	2419	1947	3	2004-03-17
9	2419	459	2	2004-03-17
1	2420	1639	1	2004-03-22
2	2420	7167	3	2004-03-22
3	2420	2074	1	2004-03-22
4	2420	8841	1	2004-03-22
5	2420	2021	2	2004-03-22
6	2420	9769	1	2004-03-22
7	2420	4521	3	2004-03-22
1	2421	5953	2	2004-03-07
2	2421	7366	2	2004-03-07
3	2421	9000	3	2004-03-07
4	2421	3671	3	2004-03-07
5	2421	2727	1	2004-03-07
6	2421	7850	3	2004-03-07
7	2421	8363	3	2004-03-07
1	2422	8027	2	2004-03-03
2	2422	4928	1	2004-03-03
3	2422	8616	2	2004-03-03
1	2423	2142	2	2004-03-03
2	2423	293	3	2004-03-03
3	2423	9736	3	2004-03-03
1	2424	8194	3	2004-03-08
2	2424	6830	2	2004-03-08
3	2424	8682	2	2004-03-08
4	2424	5531	3	2004-03-08
5	2424	722	1	2004-03-08
6	2424	2603	3	2004-03-08
1	2425	2227	3	2004-03-22
2	2425	8773	3	2004-03-22
3	2425	2513	1	2004-03-22
4	2425	1605	1	2004-03-22
5	2425	9010	1	2004-03-22
6	2425	463	1	2004-03-22
1	2426	7129	2	2004-03-01
2	2426	4312	2	2004-03-01
3	2426	9841	3	2004-03-01
4	2426	5415	1	2004-03-01
5	2426	1698	3	2004-03-01
6	2426	9310	3	2004-03-01
7	2426	5549	3	2004-03-01
8	2426	4356	3	2004-03-01
1	2427	4044	2	2004-03-24
1	2428	4631	3	2004-03-10
2	2428	851	1	2004-03-10
3	2428	5760	3	2004-03-10
4	2428	7097	1	2004-03-10
1	2429	7499	1	2004-03-12
2	2429	7222	3	2004-03-12
3	2429	329	1	2004-03-12
4	2429	4912	2	2004-03-12
5	2429	544	1	2004-03-12
6	2429	7813	2	2004-03-12
7	2429	2701	1	2004-03-12
8	2429	1095	2	2004-03-12
9	2429	4909	3	2004-03-12
1	2430	1989	1	2004-03-29
2	2430	7905	3	2004-03-29
3	2430	1834	1	2004-03-29
4	2430	6022	1	2004-03-29
5	2430	897	2	2004-03-29
6	2430	3357	3	2004-03-29
7	2430	328	2	2004-03-29
8	2430	887	2	2004-03-29
9	2430	8369	1	2004-03-29
1	2431	8038	3	2004-03-25
1	2432	2485	1	2004-03-20
2	2432	5147	2	2004-03-20
3	2432	3819	1	2004-03-20
4	2432	3558	2	2004-03-20
5	2432	4744	3	2004-03-20
1	2433	3758	2	2004-03-23
1	2434	6074	2	2004-03-14
2	2434	8989	1	2004-03-14
3	2434	6944	3	2004-03-14
1	2435	8311	1	2004-03-01
2	2435	8171	2	2004-03-01
3	2435	6929	1	2004-03-01
4	2435	6509	1	2004-03-01
5	2435	7641	1	2004-03-01
6	2435	66	2	2004-03-01
1	2436	6592	1	2004-03-22
1	2437	1712	1	2004-03-17
2	2437	3888	3	2004-03-17
1	2438	66	1	2004-03-29
2	2438	1482	3	2004-03-29
3	2438	3514	3	2004-03-29
4	2438	225	1	2004-03-29
5	2438	8898	3	2004-03-29
6	2438	1274	3	2004-03-29
7	2438	2905	3	2004-03-29
8	2438	2129	3	2004-03-29
9	2438	8815	3	2004-03-29
1	2439	5474	2	2004-03-28
2	2439	4000	3	2004-03-28
1	2440	2081	2	2004-03-14
2	2440	6144	2	2004-03-14
3	2440	1613	3	2004-03-14
4	2440	1973	1	2004-03-14
5	2440	9679	1	2004-03-14
6	2440	9702	1	2004-03-14
1	2441	1304	3	2004-03-31
2	2441	681	1	2004-03-31
1	2442	346	2	2004-03-07
2	2442	6875	2	2004-03-07
3	2442	9258	1	2004-03-07
4	2442	777	1	2004-03-07
5	2442	3562	3	2004-03-07
6	2442	4900	2	2004-03-07
7	2442	6578	3	2004-03-07
1	2443	7207	3	2004-03-22
2	2443	9319	2	2004-03-22
3	2443	9535	1	2004-03-22
4	2443	4256	1	2004-03-22
5	2443	857	2	2004-03-22
6	2443	4873	1	2004-03-22
7	2443	3808	2	2004-03-22
1	2444	868	1	2004-03-29
2	2444	9861	2	2004-03-29
3	2444	7603	2	2004-03-29
4	2444	9603	2	2004-03-29
5	2444	1633	2	2004-03-29
6	2444	435	3	2004-03-29
7	2444	3326	3	2004-03-29
8	2444	6949	1	2004-03-29
1	2445	6699	2	2004-03-13
2	2445	4516	1	2004-03-13
3	2445	7185	3	2004-03-13
4	2445	6789	2	2004-03-13
5	2445	9006	3	2004-03-13
6	2445	4972	3	2004-03-13
7	2445	7377	2	2004-03-13
8	2445	4302	2	2004-03-13
1	2446	517	3	2004-03-30
2	2446	599	2	2004-03-30
1	2447	4031	3	2004-03-23
2	2447	9423	1	2004-03-23
1	2448	2262	3	2004-03-13
1	2449	1140	1	2004-03-24
2	2449	7313	2	2004-03-24
3	2449	8136	3	2004-03-24
1	2450	6888	3	2004-03-29
2	2450	3703	2	2004-03-29
3	2450	6274	1	2004-03-29
4	2450	5323	1	2004-03-29
5	2450	9942	2	2004-03-29
6	2450	1033	2	2004-03-29
7	2450	8684	1	2004-03-29
8	2450	4877	1	2004-03-29
9	2450	2420	1	2004-03-29
1	2451	1358	1	2004-03-07
2	2451	8793	3	2004-03-07
3	2451	9085	3	2004-03-07
4	2451	6788	3	2004-03-07
1	2452	7797	1	2004-03-25
2	2452	1889	1	2004-03-25
1	2453	5647	2	2004-03-08
2	2453	6881	1	2004-03-08
3	2453	7494	3	2004-03-08
4	2453	2910	3	2004-03-08
1	2454	9957	1	2004-03-24
2	2454	8352	3	2004-03-24
3	2454	9987	2	2004-03-24
4	2454	6254	3	2004-03-24
5	2454	8814	1	2004-03-24
6	2454	9685	2	2004-03-24
7	2454	4407	1	2004-03-24
8	2454	9730	3	2004-03-24
1	2455	4143	3	2004-03-11
2	2455	9573	1	2004-03-11
3	2455	6652	1	2004-03-11
4	2455	1343	2	2004-03-11
5	2455	260	2	2004-03-11
6	2455	3010	1	2004-03-11
7	2455	6251	1	2004-03-11
8	2455	9258	2	2004-03-11
9	2455	6500	2	2004-03-11
1	2456	1922	1	2004-03-14
2	2456	5479	1	2004-03-14
3	2456	9033	3	2004-03-14
4	2456	9246	3	2004-03-14
1	2457	5025	2	2004-03-25
2	2457	9986	2	2004-03-25
3	2457	7660	1	2004-03-25
4	2457	768	1	2004-03-25
5	2457	461	3	2004-03-25
6	2457	2029	3	2004-03-25
7	2457	3256	3	2004-03-25
1	2458	1384	2	2004-03-17
2	2458	5043	3	2004-03-17
3	2458	7413	2	2004-03-17
1	2459	47	1	2004-03-18
2	2459	1178	2	2004-03-18
3	2459	3944	1	2004-03-18
4	2459	1438	1	2004-03-18
1	2460	9224	2	2004-03-05
2	2460	1587	1	2004-03-05
1	2461	9748	1	2004-03-09
2	2461	2428	2	2004-03-09
3	2461	8202	3	2004-03-09
4	2461	8866	2	2004-03-09
5	2461	6500	1	2004-03-09
6	2461	7620	2	2004-03-09
1	2462	9961	1	2004-03-09
2	2462	8427	1	2004-03-09
3	2462	5259	1	2004-03-09
4	2462	3238	2	2004-03-09
5	2462	4996	2	2004-03-09
6	2462	6961	3	2004-03-09
7	2462	1639	3	2004-03-09
1	2463	6176	2	2004-03-14
2	2463	6758	2	2004-03-14
3	2463	404	1	2004-03-14
4	2463	7486	3	2004-03-14
5	2463	9803	1	2004-03-14
6	2463	6821	1	2004-03-14
7	2463	7191	3	2004-03-14
1	2464	6314	1	2004-03-14
2	2464	4214	1	2004-03-14
3	2464	6212	1	2004-03-14
4	2464	9132	3	2004-03-14
5	2464	8092	2	2004-03-14
6	2464	9237	2	2004-03-14
7	2464	538	2	2004-03-14
8	2464	2807	3	2004-03-14
9	2464	454	1	2004-03-14
1	2465	8306	3	2004-03-02
1	2466	1113	1	2004-03-06
2	2466	5978	3	2004-03-06
3	2466	4375	1	2004-03-06
4	2466	8736	1	2004-03-06
5	2466	1366	3	2004-03-06
6	2466	8438	3	2004-03-06
1	2467	3086	3	2004-03-05
2	2467	9321	2	2004-03-05
1	2468	229	3	2004-03-06
2	2468	1109	1	2004-03-06
3	2468	5280	2	2004-03-06
1	2469	3818	1	2004-03-26
2	2469	4418	1	2004-03-26
3	2469	3893	2	2004-03-26
4	2469	421	1	2004-03-26
1	2470	3934	1	2004-03-17
1	2471	3128	3	2004-03-30
2	2471	4533	2	2004-03-30
1	2472	1586	2	2004-03-25
2	2472	9560	1	2004-03-25
3	2472	7832	2	2004-03-25
1	2473	8031	2	2004-03-12
2	2473	45	1	2004-03-12
3	2473	8259	1	2004-03-12
4	2473	4317	1	2004-03-12
5	2473	3137	2	2004-03-12
6	2473	5447	3	2004-03-12
7	2473	5451	3	2004-03-12
1	2474	5625	3	2004-03-25
2	2474	8925	3	2004-03-25
3	2474	893	3	2004-03-25
4	2474	7728	3	2004-03-25
5	2474	1861	1	2004-03-25
6	2474	972	3	2004-03-25
1	2475	2274	1	2004-03-29
2	2475	9358	2	2004-03-29
3	2475	4590	1	2004-03-29
4	2475	563	1	2004-03-29
5	2475	2259	2	2004-03-29
6	2475	8610	1	2004-03-29
7	2475	5997	1	2004-03-29
8	2475	5885	1	2004-03-29
9	2475	7827	2	2004-03-29
1	2476	7443	2	2004-03-28
2	2476	8109	3	2004-03-28
3	2476	2943	3	2004-03-28
4	2476	7417	3	2004-03-28
5	2476	6684	3	2004-03-28
6	2476	9482	2	2004-03-28
1	2477	4108	1	2004-03-20
2	2477	2854	1	2004-03-20
3	2477	922	3	2004-03-20
4	2477	3257	3	2004-03-20
5	2477	471	1	2004-03-20
6	2477	1615	3	2004-03-20
7	2477	9803	2	2004-03-20
1	2478	5659	1	2004-03-19
2	2478	1343	1	2004-03-19
3	2478	86	3	2004-03-19
4	2478	2764	3	2004-03-19
1	2479	5883	3	2004-03-13
2	2479	3400	3	2004-03-13
3	2479	463	2	2004-03-13
1	2480	4804	1	2004-03-24
2	2480	7359	2	2004-03-24
3	2480	7648	1	2004-03-24
4	2480	1851	3	2004-03-24
5	2480	7188	3	2004-03-24
6	2480	710	3	2004-03-24
7	2480	584	1	2004-03-24
8	2480	6558	2	2004-03-24
1	2481	3231	3	2004-03-02
2	2481	1746	2	2004-03-02
3	2481	7007	1	2004-03-02
4	2481	950	2	2004-03-02
1	2482	4817	1	2004-03-19
1	2483	172	1	2004-03-17
2	2483	4696	1	2004-03-17
3	2483	8943	2	2004-03-17
4	2483	1676	2	2004-03-17
5	2483	8625	1	2004-03-17
6	2483	6126	1	2004-03-17
7	2483	6037	3	2004-03-17
1	2484	9990	3	2004-03-29
2	2484	884	2	2004-03-29
3	2484	9012	2	2004-03-29
4	2484	6648	2	2004-03-29
5	2484	3538	1	2004-03-29
6	2484	6293	3	2004-03-29
1	2485	7345	2	2004-03-29
2	2485	9143	3	2004-03-29
3	2485	1618	3	2004-03-29
4	2485	1057	3	2004-03-29
1	2486	4875	1	2004-03-28
2	2486	4358	2	2004-03-28
3	2486	21	2	2004-03-28
4	2486	782	3	2004-03-28
5	2486	8773	3	2004-03-28
6	2486	2861	1	2004-03-28
7	2486	9412	3	2004-03-28
8	2486	9073	3	2004-03-28
1	2487	2365	1	2004-03-18
2	2487	1982	2	2004-03-18
3	2487	9358	1	2004-03-18
1	2488	6205	2	2004-03-06
2	2488	1912	1	2004-03-06
3	2488	9871	1	2004-03-06
4	2488	5803	1	2004-03-06
5	2488	964	2	2004-03-06
6	2488	8081	2	2004-03-06
7	2488	6885	3	2004-03-06
8	2488	2979	2	2004-03-06
1	2489	1558	2	2004-03-19
2	2489	110	2	2004-03-19
3	2489	8551	3	2004-03-19
4	2489	6578	1	2004-03-19
5	2489	7606	3	2004-03-19
6	2489	9103	2	2004-03-19
7	2489	1716	1	2004-03-19
8	2489	4372	1	2004-03-19
1	2490	4749	1	2004-03-10
2	2490	7735	1	2004-03-10
3	2490	7812	1	2004-03-10
4	2490	7589	2	2004-03-10
1	2491	4360	1	2004-03-29
1	2492	3187	3	2004-03-14
1	2493	3304	3	2004-03-24
2	2493	993	2	2004-03-24
3	2493	7944	1	2004-03-24
4	2493	160	1	2004-03-24
5	2493	3550	3	2004-03-24
6	2493	4325	1	2004-03-24
7	2493	8607	1	2004-03-24
8	2493	5248	3	2004-03-24
9	2493	1705	3	2004-03-24
1	2494	8975	1	2004-03-28
2	2494	4167	1	2004-03-28
3	2494	1742	1	2004-03-28
1	2495	2910	1	2004-03-14
2	2495	4005	1	2004-03-14
3	2495	5486	2	2004-03-14
4	2495	3546	3	2004-03-14
5	2495	2059	3	2004-03-14
6	2495	397	1	2004-03-14
7	2495	9784	2	2004-03-14
1	2496	7552	2	2004-03-27
2	2496	546	2	2004-03-27
3	2496	5622	2	2004-03-27
4	2496	8687	3	2004-03-27
5	2496	6570	1	2004-03-27
6	2496	2503	3	2004-03-27
7	2496	893	2	2004-03-27
1	2497	9062	3	2004-03-01
2	2497	4607	1	2004-03-01
3	2497	7682	2	2004-03-01
4	2497	1786	3	2004-03-01
5	2497	648	1	2004-03-01
6	2497	8953	2	2004-03-01
1	2498	3031	1	2004-03-24
2	2498	2986	1	2004-03-24
3	2498	398	3	2004-03-24
4	2498	4855	1	2004-03-24
5	2498	7387	2	2004-03-24
6	2498	8312	3	2004-03-24
7	2498	644	2	2004-03-24
8	2498	3044	3	2004-03-24
1	2499	2654	1	2004-03-14
2	2499	9535	1	2004-03-14
1	2500	4992	2	2004-03-10
1	2501	9739	3	2004-03-28
2	2501	1518	2	2004-03-28
1	2502	6377	1	2004-03-04
2	2502	3880	3	2004-03-04
3	2502	690	3	2004-03-04
4	2502	7072	1	2004-03-04
5	2502	338	3	2004-03-04
6	2502	4126	3	2004-03-04
7	2502	3026	3	2004-03-04
8	2502	8359	1	2004-03-04
9	2502	7807	2	2004-03-04
1	2503	8747	1	2004-03-16
2	2503	719	1	2004-03-16
3	2503	5704	1	2004-03-16
1	2504	7030	2	2004-03-29
2	2504	4967	3	2004-03-29
3	2504	3161	1	2004-03-29
4	2504	9234	2	2004-03-29
5	2504	1763	2	2004-03-29
1	2505	5061	3	2004-03-11
2	2505	5078	3	2004-03-11
1	2506	7559	2	2004-03-16
2	2506	4063	1	2004-03-16
3	2506	5050	1	2004-03-16
4	2506	9307	2	2004-03-16
1	2507	4056	2	2004-03-28
2	2507	5782	1	2004-03-28
3	2507	7614	3	2004-03-28
4	2507	6649	1	2004-03-28
1	2508	5377	3	2004-03-08
2	2508	7385	1	2004-03-08
3	2508	4236	1	2004-03-08
4	2508	4225	1	2004-03-08
5	2508	3344	3	2004-03-08
6	2508	5057	3	2004-03-08
7	2508	1518	2	2004-03-08
1	2509	4039	2	2004-03-14
2	2509	9526	3	2004-03-14
3	2509	8045	3	2004-03-14
4	2509	7363	2	2004-03-14
5	2509	8123	3	2004-03-14
1	2510	8621	2	2004-03-06
2	2510	7605	1	2004-03-06
3	2510	4476	1	2004-03-06
4	2510	4651	3	2004-03-06
5	2510	116	3	2004-03-06
6	2510	6212	1	2004-03-06
7	2510	4070	1	2004-03-06
1	2511	9524	2	2004-03-06
2	2511	5786	3	2004-03-06
3	2511	2742	1	2004-03-06
4	2511	2260	1	2004-03-06
5	2511	2843	2	2004-03-06
6	2511	1698	3	2004-03-06
1	2512	3175	3	2004-03-04
2	2512	673	3	2004-03-04
3	2512	6696	1	2004-03-04
4	2512	7531	1	2004-03-04
5	2512	2422	1	2004-03-04
6	2512	3574	2	2004-03-04
7	2512	6369	3	2004-03-04
8	2512	317	2	2004-03-04
1	2513	9252	2	2004-03-17
2	2513	8859	1	2004-03-17
3	2513	9782	1	2004-03-17
4	2513	2024	1	2004-03-17
5	2513	875	2	2004-03-17
6	2513	9864	2	2004-03-17
7	2513	5301	1	2004-03-17
8	2513	1873	1	2004-03-17
1	2514	1004	3	2004-03-05
2	2514	8097	3	2004-03-05
3	2514	8127	3	2004-03-05
4	2514	3266	2	2004-03-05
1	2515	2446	1	2004-03-14
2	2515	5861	1	2004-03-14
3	2515	788	3	2004-03-14
4	2515	3248	1	2004-03-14
1	2516	3648	3	2004-03-14
2	2516	1606	2	2004-03-14
3	2516	6987	2	2004-03-14
4	2516	8719	3	2004-03-14
5	2516	4987	3	2004-03-14
6	2516	5364	1	2004-03-14
7	2516	5229	3	2004-03-14
8	2516	6492	3	2004-03-14
9	2516	5355	3	2004-03-14
1	2517	28	3	2004-03-11
2	2517	7257	1	2004-03-11
3	2517	545	1	2004-03-11
4	2517	6386	2	2004-03-11
5	2517	1174	1	2004-03-11
6	2517	3838	1	2004-03-11
7	2517	5005	1	2004-03-11
8	2517	9289	2	2004-03-11
9	2517	8816	2	2004-03-11
1	2518	2809	2	2004-03-02
2	2518	5512	3	2004-03-02
3	2518	1743	3	2004-03-02
4	2518	5965	3	2004-03-02
5	2518	8396	2	2004-03-02
6	2518	8721	2	2004-03-02
1	2519	5520	3	2004-03-29
2	2519	5685	3	2004-03-29
3	2519	1170	1	2004-03-29
4	2519	183	1	2004-03-29
5	2519	4414	3	2004-03-29
6	2519	4734	2	2004-03-29
1	2520	6000	2	2004-03-10
2	2520	4151	3	2004-03-10
3	2520	5254	1	2004-03-10
4	2520	7581	2	2004-03-10
5	2520	6106	2	2004-03-10
6	2520	9301	2	2004-03-10
1	2521	4908	3	2004-03-18
1	2522	6536	1	2004-03-02
1	2523	3389	3	2004-03-30
2	2523	8788	3	2004-03-30
3	2523	3713	1	2004-03-30
1	2524	2616	3	2004-03-23
2	2524	1011	1	2004-03-23
3	2524	4530	2	2004-03-23
4	2524	8433	2	2004-03-23
5	2524	7663	2	2004-03-23
1	2525	8731	2	2004-03-08
2	2525	1471	3	2004-03-08
3	2525	7220	3	2004-03-08
4	2525	1156	1	2004-03-08
5	2525	5717	3	2004-03-08
6	2525	9997	3	2004-03-08
7	2525	2881	3	2004-03-08
8	2525	8396	2	2004-03-08
9	2525	1838	1	2004-03-08
1	2526	9425	1	2004-03-16
2	2526	5173	3	2004-03-16
3	2526	4698	3	2004-03-16
4	2526	5192	2	2004-03-16
5	2526	7095	2	2004-03-16
6	2526	65	3	2004-03-16
7	2526	2277	3	2004-03-16
8	2526	6800	2	2004-03-16
9	2526	7894	1	2004-03-16
1	2527	5017	1	2004-03-11
2	2527	2188	3	2004-03-11
3	2527	1351	3	2004-03-11
4	2527	9702	2	2004-03-11
5	2527	6899	3	2004-03-11
6	2527	5635	1	2004-03-11
1	2528	4446	2	2004-03-20
2	2528	5328	2	2004-03-20
1	2529	1035	3	2004-03-17
2	2529	4481	2	2004-03-17
1	2530	6765	1	2004-03-24
2	2530	9449	3	2004-03-24
3	2530	131	3	2004-03-24
1	2531	9100	2	2004-03-08
2	2531	8357	3	2004-03-08
3	2531	5896	1	2004-03-08
4	2531	5206	1	2004-03-08
5	2531	7313	1	2004-03-08
6	2531	8826	3	2004-03-08
7	2531	2336	3	2004-03-08
8	2531	8796	3	2004-03-08
1	2532	8969	1	2004-03-14
2	2532	7787	3	2004-03-14
3	2532	8119	3	2004-03-14
4	2532	7568	1	2004-03-14
5	2532	4946	2	2004-03-14
1	2533	2651	2	2004-03-27
2	2533	9693	3	2004-03-27
3	2533	7452	3	2004-03-27
4	2533	8227	2	2004-03-27
5	2533	6112	1	2004-03-27
6	2533	6139	2	2004-03-27
7	2533	7377	1	2004-03-27
1	2534	621	1	2004-03-04
1	2535	9249	2	2004-03-27
2	2535	2077	3	2004-03-27
3	2535	39	1	2004-03-27
4	2535	4673	1	2004-03-27
5	2535	8640	2	2004-03-27
6	2535	546	2	2004-03-27
1	2536	9335	3	2004-03-05
2	2536	2389	3	2004-03-05
3	2536	8916	2	2004-03-05
4	2536	7328	2	2004-03-05
5	2536	3918	3	2004-03-05
6	2536	7389	1	2004-03-05
7	2536	6688	3	2004-03-05
1	2537	3718	2	2004-03-28
1	2538	2756	3	2004-03-11
2	2538	8032	2	2004-03-11
1	2539	8907	2	2004-03-21
2	2539	2520	3	2004-03-21
3	2539	7665	3	2004-03-21
4	2539	2081	1	2004-03-21
5	2539	7797	3	2004-03-21
6	2539	4166	2	2004-03-21
1	2540	3873	2	2004-03-25
2	2540	6800	3	2004-03-25
3	2540	2529	2	2004-03-25
1	2541	9409	3	2004-03-29
2	2541	7547	1	2004-03-29
3	2541	3942	2	2004-03-29
4	2541	5012	2	2004-03-29
5	2541	4275	1	2004-03-29
6	2541	6310	2	2004-03-29
7	2541	4259	2	2004-03-29
1	2542	1405	3	2004-03-19
2	2542	6060	2	2004-03-19
3	2542	3147	1	2004-03-19
4	2542	2451	2	2004-03-19
1	2543	8712	1	2004-03-22
2	2543	6606	2	2004-03-22
3	2543	1383	1	2004-03-22
4	2543	2711	2	2004-03-22
5	2543	7009	3	2004-03-22
6	2543	9070	1	2004-03-22
7	2543	3340	1	2004-03-22
8	2543	7424	3	2004-03-22
1	2544	5022	3	2004-03-06
2	2544	8432	3	2004-03-06
3	2544	1808	1	2004-03-06
1	2545	7095	1	2004-03-12
2	2545	5169	2	2004-03-12
3	2545	7417	2	2004-03-12
4	2545	4247	1	2004-03-12
5	2545	2946	1	2004-03-12
1	2546	5344	1	2004-03-23
1	2547	250	1	2004-03-30
2	2547	1453	3	2004-03-30
3	2547	1201	1	2004-03-30
1	2548	9845	3	2004-03-30
2	2548	3169	2	2004-03-30
1	2549	712	2	2004-03-09
2	2549	8178	3	2004-03-09
3	2549	6525	1	2004-03-09
4	2549	8274	1	2004-03-09
5	2549	4749	3	2004-03-09
6	2549	8963	1	2004-03-09
7	2549	392	3	2004-03-09
1	2550	5105	3	2004-03-18
2	2550	2035	3	2004-03-18
3	2550	9467	1	2004-03-18
4	2550	5963	1	2004-03-18
5	2550	6892	3	2004-03-18
6	2550	3221	3	2004-03-18
7	2550	5560	2	2004-03-18
1	2551	6488	1	2004-03-10
2	2551	1358	1	2004-03-10
3	2551	7916	1	2004-03-10
4	2551	3996	3	2004-03-10
5	2551	9532	3	2004-03-10
6	2551	152	3	2004-03-10
7	2551	6778	2	2004-03-10
8	2551	4881	3	2004-03-10
9	2551	2244	2	2004-03-10
1	2552	6843	1	2004-03-03
2	2552	6039	1	2004-03-03
3	2552	4134	3	2004-03-03
4	2552	6139	2	2004-03-03
5	2552	8493	1	2004-03-03
6	2552	5916	3	2004-03-03
7	2552	3864	2	2004-03-03
1	2553	7646	1	2004-03-01
2	2553	7125	2	2004-03-01
3	2553	7548	1	2004-03-01
4	2553	3236	3	2004-03-01
5	2553	6352	2	2004-03-01
6	2553	7996	1	2004-03-01
7	2553	1510	2	2004-03-01
8	2553	3535	3	2004-03-01
9	2553	7241	3	2004-03-01
1	2554	6006	3	2004-03-21
2	2554	4893	3	2004-03-21
3	2554	3304	2	2004-03-21
4	2554	7729	2	2004-03-21
5	2554	4763	2	2004-03-21
1	2555	3893	1	2004-03-24
2	2555	5071	1	2004-03-24
3	2555	6960	1	2004-03-24
4	2555	3577	3	2004-03-24
5	2555	7906	3	2004-03-24
1	2556	8526	3	2004-03-19
2	2556	7610	2	2004-03-19
3	2556	7808	1	2004-03-19
1	2557	6554	1	2004-03-14
2	2557	7503	2	2004-03-14
1	2558	332	2	2004-03-14
2	2558	8350	3	2004-03-14
3	2558	7704	1	2004-03-14
4	2558	5761	2	2004-03-14
5	2558	9037	1	2004-03-14
6	2558	755	2	2004-03-14
7	2558	4344	3	2004-03-14
8	2558	2152	1	2004-03-14
1	2559	1071	1	2004-03-12
2	2559	340	3	2004-03-12
3	2559	4347	3	2004-03-12
4	2559	1910	3	2004-03-12
5	2559	5142	1	2004-03-12
6	2559	6668	2	2004-03-12
7	2559	6112	2	2004-03-12
8	2559	2765	2	2004-03-12
1	2560	302	1	2004-03-22
2	2560	9796	2	2004-03-22
3	2560	9458	1	2004-03-22
4	2560	6598	1	2004-03-22
5	2560	1907	1	2004-03-22
6	2560	1481	1	2004-03-22
1	2561	9662	1	2004-03-10
2	2561	5979	2	2004-03-10
3	2561	3985	1	2004-03-10
4	2561	277	1	2004-03-10
5	2561	7663	1	2004-03-10
6	2561	3911	2	2004-03-10
7	2561	1566	2	2004-03-10
1	2562	6512	1	2004-03-02
1	2563	4162	3	2004-03-08
2	2563	7211	3	2004-03-08
3	2563	9539	3	2004-03-08
4	2563	4651	3	2004-03-08
1	2564	3275	2	2004-03-01
2	2564	4400	1	2004-03-01
3	2564	7321	3	2004-03-01
4	2564	5544	3	2004-03-01
1	2565	6509	3	2004-03-06
2	2565	8126	3	2004-03-06
3	2565	374	2	2004-03-06
4	2565	3069	2	2004-03-06
5	2565	2083	1	2004-03-06
1	2566	822	3	2004-03-06
2	2566	7049	2	2004-03-06
3	2566	2713	1	2004-03-06
4	2566	9105	3	2004-03-06
5	2566	1261	2	2004-03-06
6	2566	5422	3	2004-03-06
1	2567	2221	3	2004-03-17
2	2567	3328	1	2004-03-17
3	2567	8277	2	2004-03-17
4	2567	4709	1	2004-03-17
5	2567	8237	3	2004-03-17
6	2567	1625	1	2004-03-17
1	2568	8123	2	2004-03-27
2	2568	4058	1	2004-03-27
3	2568	3795	1	2004-03-27
4	2568	7947	2	2004-03-27
5	2568	9586	2	2004-03-27
6	2568	1860	2	2004-03-27
7	2568	433	2	2004-03-27
8	2568	958	1	2004-03-27
9	2568	4233	2	2004-03-27
1	2569	3855	2	2004-03-10
2	2569	4499	2	2004-03-10
3	2569	6228	1	2004-03-10
4	2569	5193	1	2004-03-10
5	2569	2143	1	2004-03-10
6	2569	6123	2	2004-03-10
7	2569	4150	3	2004-03-10
1	2570	5465	3	2004-03-30
2	2570	3842	2	2004-03-30
3	2570	1624	2	2004-03-30
4	2570	8550	2	2004-03-30
5	2570	9085	1	2004-03-30
6	2570	8366	3	2004-03-30
7	2570	9256	1	2004-03-30
8	2570	3293	2	2004-03-30
9	2570	7699	3	2004-03-30
1	2571	6206	3	2004-03-21
2	2571	5005	1	2004-03-21
3	2571	8210	2	2004-03-21
4	2571	2452	1	2004-03-21
5	2571	3312	3	2004-03-21
6	2571	14	3	2004-03-21
7	2571	3813	1	2004-03-21
8	2571	1953	1	2004-03-21
1	2572	8108	1	2004-03-24
2	2572	8078	1	2004-03-24
3	2572	6919	2	2004-03-24
4	2572	921	2	2004-03-24
5	2572	8667	1	2004-03-24
6	2572	2388	2	2004-03-24
1	2573	1758	3	2004-03-05
2	2573	2776	2	2004-03-05
3	2573	5594	1	2004-03-05
4	2573	2223	3	2004-03-05
5	2573	4427	2	2004-03-05
6	2573	1768	1	2004-03-05
7	2573	5212	2	2004-03-05
8	2573	7778	1	2004-03-05
9	2573	8843	2	2004-03-05
1	2574	9343	1	2004-03-15
2	2574	8731	1	2004-03-15
3	2574	5169	1	2004-03-15
4	2574	9123	1	2004-03-15
5	2574	9709	1	2004-03-15
6	2574	8074	1	2004-03-15
1	2575	3072	3	2004-03-19
2	2575	2347	2	2004-03-19
3	2575	1620	3	2004-03-19
4	2575	517	3	2004-03-19
5	2575	878	3	2004-03-19
6	2575	5254	2	2004-03-19
7	2575	5120	3	2004-03-19
8	2575	1236	2	2004-03-19
1	2576	82	2	2004-03-23
2	2576	2747	3	2004-03-23
3	2576	6196	1	2004-03-23
1	2577	318	3	2004-03-08
2	2577	7249	1	2004-03-08
3	2577	2398	3	2004-03-08
4	2577	224	1	2004-03-08
5	2577	8267	1	2004-03-08
6	2577	2272	2	2004-03-08
7	2577	6697	3	2004-03-08
1	2578	7899	3	2004-03-02
2	2578	9937	3	2004-03-02
3	2578	3361	1	2004-03-02
4	2578	7770	3	2004-03-02
5	2578	3504	1	2004-03-02
6	2578	1702	3	2004-03-02
7	2578	7594	1	2004-03-02
1	2579	3711	2	2004-03-18
2	2579	859	1	2004-03-18
3	2579	6008	1	2004-03-18
4	2579	5497	1	2004-03-18
5	2579	522	2	2004-03-18
6	2579	636	1	2004-03-18
7	2579	3487	3	2004-03-18
8	2579	420	2	2004-03-18
1	2580	3337	3	2004-03-21
2	2580	4329	2	2004-03-21
3	2580	7600	1	2004-03-21
4	2580	7057	1	2004-03-21
1	2581	6648	1	2004-03-21
1	2582	5359	2	2004-03-08
2	2582	3849	2	2004-03-08
3	2582	7977	3	2004-03-08
4	2582	4530	3	2004-03-08
5	2582	759	1	2004-03-08
6	2582	2177	3	2004-03-08
7	2582	5328	2	2004-03-08
8	2582	6475	3	2004-03-08
1	2583	7221	3	2004-03-02
2	2583	9349	3	2004-03-02
3	2583	8816	2	2004-03-02
4	2583	263	1	2004-03-02
5	2583	8652	2	2004-03-02
6	2583	9216	2	2004-03-02
7	2583	945	1	2004-03-02
1	2584	7317	1	2004-03-01
2	2584	5579	3	2004-03-01
3	2584	8024	1	2004-03-01
4	2584	5007	2	2004-03-01
5	2584	563	2	2004-03-01
1	2585	482	1	2004-03-27
2	2585	4106	3	2004-03-27
3	2585	8511	2	2004-03-27
4	2585	566	3	2004-03-27
5	2585	9711	3	2004-03-27
6	2585	1173	1	2004-03-27
1	2586	5712	3	2004-03-09
2	2586	4405	1	2004-03-09
3	2586	6386	1	2004-03-09
1	2587	6950	2	2004-03-07
2	2587	4900	1	2004-03-07
3	2587	1294	2	2004-03-07
1	2588	9767	2	2004-03-09
2	2588	8301	3	2004-03-09
1	2589	651	3	2004-03-16
2	2589	1119	2	2004-03-16
3	2589	6600	2	2004-03-16
4	2589	7653	1	2004-03-16
5	2589	7953	3	2004-03-16
6	2589	4377	2	2004-03-16
7	2589	2608	1	2004-03-16
8	2589	381	3	2004-03-16
1	2590	7074	3	2004-03-05
2	2590	5208	3	2004-03-05
3	2590	2812	2	2004-03-05
4	2590	6318	3	2004-03-05
1	2591	6157	3	2004-03-10
2	2591	9995	1	2004-03-10
3	2591	2351	3	2004-03-10
4	2591	5741	1	2004-03-10
1	2592	1444	2	2004-03-24
1	2593	6953	2	2004-03-24
1	2594	5669	3	2004-03-25
1	2595	2282	1	2004-03-28
2	2595	1248	1	2004-03-28
3	2595	2830	2	2004-03-28
4	2595	9923	3	2004-03-28
1	2596	7520	1	2004-03-13
2	2596	4649	2	2004-03-13
3	2596	3016	1	2004-03-13
4	2596	5625	3	2004-03-13
5	2596	6198	2	2004-03-13
6	2596	2128	3	2004-03-13
7	2596	4562	3	2004-03-13
8	2596	4817	1	2004-03-13
9	2596	6445	3	2004-03-13
1	2597	1002	1	2004-03-24
2	2597	2539	1	2004-03-24
3	2597	209	2	2004-03-24
4	2597	8342	3	2004-03-24
5	2597	5524	2	2004-03-24
6	2597	9029	1	2004-03-24
7	2597	990	1	2004-03-24
8	2597	2059	2	2004-03-24
9	2597	2011	3	2004-03-24
1	2598	1934	1	2004-03-01
2	2598	8136	3	2004-03-01
3	2598	9155	2	2004-03-01
4	2598	7104	3	2004-03-01
5	2598	4768	3	2004-03-01
1	2599	3745	3	2004-03-30
2	2599	8707	3	2004-03-30
3	2599	3232	3	2004-03-30
4	2599	9441	2	2004-03-30
5	2599	9779	1	2004-03-30
6	2599	837	1	2004-03-30
7	2599	9755	1	2004-03-30
8	2599	5928	2	2004-03-30
9	2599	6002	3	2004-03-30
1	2600	9965	2	2004-03-18
2	2600	2896	2	2004-03-18
3	2600	1448	1	2004-03-18
4	2600	2038	1	2004-03-18
5	2600	2307	2	2004-03-18
1	2601	8749	2	2004-03-25
1	2602	317	2	2004-03-17
2	2602	7276	2	2004-03-17
3	2602	1104	1	2004-03-17
4	2602	4104	3	2004-03-17
5	2602	7414	1	2004-03-17
6	2602	1815	3	2004-03-17
1	2603	7208	2	2004-03-12
2	2603	5609	3	2004-03-12
3	2603	9932	2	2004-03-12
4	2603	528	2	2004-03-12
5	2603	4536	3	2004-03-12
1	2604	5974	3	2004-03-30
2	2604	1211	1	2004-03-30
3	2604	4363	1	2004-03-30
4	2604	6526	3	2004-03-30
5	2604	9196	2	2004-03-30
1	2605	5721	2	2004-03-28
2	2605	7624	1	2004-03-28
3	2605	7577	1	2004-03-28
1	2606	2491	1	2004-03-08
2	2606	2245	1	2004-03-08
3	2606	1060	1	2004-03-08
1	2607	283	1	2004-03-24
2	2607	956	3	2004-03-24
3	2607	996	1	2004-03-24
4	2607	747	3	2004-03-24
5	2607	1162	1	2004-03-24
6	2607	2296	3	2004-03-24
7	2607	5494	3	2004-03-24
8	2607	9810	1	2004-03-24
1	2608	5220	1	2004-03-10
2	2608	1061	3	2004-03-10
3	2608	5034	1	2004-03-10
4	2608	7512	1	2004-03-10
5	2608	9154	2	2004-03-10
6	2608	1105	3	2004-03-10
7	2608	8208	1	2004-03-10
8	2608	6243	3	2004-03-10
9	2608	2211	3	2004-03-10
1	2609	255	2	2004-03-28
2	2609	1223	1	2004-03-28
1	2610	4211	3	2004-03-24
2	2610	1264	2	2004-03-24
3	2610	5000	2	2004-03-24
4	2610	7392	1	2004-03-24
5	2610	8761	2	2004-03-24
6	2610	8190	3	2004-03-24
7	2610	5981	2	2004-03-24
8	2610	1925	1	2004-03-24
1	2611	7508	3	2004-03-18
2	2611	5913	3	2004-03-18
3	2611	2815	3	2004-03-18
4	2611	7826	1	2004-03-18
5	2611	1509	1	2004-03-18
1	2612	991	1	2004-03-27
2	2612	6188	3	2004-03-27
3	2612	5187	2	2004-03-27
4	2612	4928	2	2004-03-27
5	2612	4813	1	2004-03-27
6	2612	9773	3	2004-03-27
7	2612	3132	2	2004-03-27
8	2612	873	1	2004-03-27
9	2612	9984	3	2004-03-27
1	2613	3032	2	2004-03-02
2	2613	3859	2	2004-03-02
3	2613	4110	1	2004-03-02
4	2613	259	1	2004-03-02
1	2614	9633	3	2004-03-08
2	2614	3513	2	2004-03-08
3	2614	3022	3	2004-03-08
4	2614	5468	1	2004-03-08
5	2614	5063	3	2004-03-08
6	2614	8169	2	2004-03-08
7	2614	943	3	2004-03-08
8	2614	4316	1	2004-03-08
1	2615	4427	3	2004-03-13
2	2615	1619	3	2004-03-13
3	2615	1327	1	2004-03-13
4	2615	321	2	2004-03-13
5	2615	3127	2	2004-03-13
6	2615	2268	1	2004-03-13
7	2615	4427	2	2004-03-13
1	2616	243	3	2004-03-23
2	2616	1385	3	2004-03-23
3	2616	5103	1	2004-03-23
1	2617	9877	3	2004-03-21
1	2618	2840	3	2004-03-24
2	2618	1185	1	2004-03-24
3	2618	2732	2	2004-03-24
4	2618	7941	2	2004-03-24
5	2618	7070	1	2004-03-24
6	2618	781	2	2004-03-24
7	2618	9815	2	2004-03-24
8	2618	7174	1	2004-03-24
9	2618	4054	3	2004-03-24
1	2619	8575	2	2004-03-27
2	2619	5643	3	2004-03-27
3	2619	3629	1	2004-03-27
4	2619	2755	1	2004-03-27
5	2619	2640	2	2004-03-27
1	2620	8135	3	2004-03-02
2	2620	8093	2	2004-03-02
3	2620	9061	3	2004-03-02
1	2621	8933	3	2004-03-30
2	2621	5323	3	2004-03-30
3	2621	6967	2	2004-03-30
4	2621	2435	2	2004-03-30
5	2621	973	3	2004-03-30
6	2621	3993	2	2004-03-30
7	2621	1410	3	2004-03-30
1	2622	7873	1	2004-03-19
2	2622	9386	2	2004-03-19
3	2622	7789	3	2004-03-19
4	2622	1211	3	2004-03-19
5	2622	6350	1	2004-03-19
6	2622	5725	1	2004-03-19
1	2623	2060	2	2004-03-24
2	2623	9097	2	2004-03-24
3	2623	426	1	2004-03-24
1	2624	1164	1	2004-03-08
2	2624	8029	2	2004-03-08
3	2624	6898	2	2004-03-08
4	2624	4599	2	2004-03-08
1	2625	9236	1	2004-03-06
2	2625	3922	2	2004-03-06
3	2625	218	1	2004-03-06
1	2626	3021	2	2004-03-30
2	2626	6170	2	2004-03-30
1	2627	2721	3	2004-03-11
2	2627	8821	1	2004-03-11
3	2627	2531	2	2004-03-11
4	2627	6651	3	2004-03-11
5	2627	2001	3	2004-03-11
6	2627	9517	2	2004-03-11
7	2627	1678	3	2004-03-11
8	2627	5872	2	2004-03-11
1	2628	4225	1	2004-03-12
2	2628	5005	3	2004-03-12
3	2628	4945	1	2004-03-12
1	2629	6708	1	2004-03-03
2	2629	7580	2	2004-03-03
3	2629	3385	1	2004-03-03
4	2629	1246	1	2004-03-03
5	2629	7241	1	2004-03-03
6	2629	8593	3	2004-03-03
7	2629	9007	1	2004-03-03
8	2629	5509	2	2004-03-03
1	2630	2549	2	2004-03-19
2	2630	4426	3	2004-03-19
3	2630	2438	3	2004-03-19
1	2631	1682	2	2004-03-28
2	2631	1277	3	2004-03-28
3	2631	97	2	2004-03-28
4	2631	9372	1	2004-03-28
5	2631	4695	2	2004-03-28
6	2631	4589	1	2004-03-28
7	2631	3369	2	2004-03-28
8	2631	3558	3	2004-03-28
1	2632	2384	1	2004-03-27
2	2632	4634	3	2004-03-27
3	2632	8197	3	2004-03-27
4	2632	6179	3	2004-03-27
5	2632	200	2	2004-03-27
6	2632	5565	1	2004-03-27
7	2632	8608	3	2004-03-27
8	2632	1142	3	2004-03-27
9	2632	1502	1	2004-03-27
1	2633	9483	1	2004-03-01
2	2633	8231	1	2004-03-01
3	2633	9370	3	2004-03-01
4	2633	2466	3	2004-03-01
5	2633	6145	2	2004-03-01
1	2634	7850	3	2004-03-26
2	2634	3230	3	2004-03-26
3	2634	1876	3	2004-03-26
4	2634	9930	1	2004-03-26
5	2634	5635	1	2004-03-26
6	2634	9188	3	2004-03-26
1	2635	3869	1	2004-03-05
2	2635	9203	1	2004-03-05
3	2635	5855	3	2004-03-05
4	2635	8803	3	2004-03-05
5	2635	6037	2	2004-03-05
6	2635	3170	2	2004-03-05
7	2635	5725	2	2004-03-05
8	2635	452	2	2004-03-05
1	2636	2475	1	2004-03-09
2	2636	5021	3	2004-03-09
3	2636	2623	2	2004-03-09
4	2636	5246	2	2004-03-09
5	2636	3442	3	2004-03-09
1	2637	9410	3	2004-03-10
2	2637	690	3	2004-03-10
1	2638	871	3	2004-03-18
2	2638	3565	1	2004-03-18
3	2638	2458	2	2004-03-18
4	2638	5003	2	2004-03-18
5	2638	766	3	2004-03-18
6	2638	5632	2	2004-03-18
7	2638	5586	3	2004-03-18
8	2638	9995	1	2004-03-18
1	2639	747	1	2004-03-08
2	2639	7497	1	2004-03-08
3	2639	8048	3	2004-03-08
4	2639	8367	2	2004-03-08
5	2639	4912	1	2004-03-08
1	2640	7104	1	2004-03-08
2	2640	2145	1	2004-03-08
3	2640	6945	1	2004-03-08
4	2640	9583	1	2004-03-08
5	2640	8696	2	2004-03-08
6	2640	832	3	2004-03-08
1	2641	8672	1	2004-03-19
2	2641	6208	2	2004-03-19
3	2641	3029	2	2004-03-19
4	2641	4353	1	2004-03-19
5	2641	7871	3	2004-03-19
1	2642	6141	1	2004-03-10
2	2642	6193	3	2004-03-10
3	2642	4256	1	2004-03-10
1	2643	9006	2	2004-03-04
2	2643	8580	2	2004-03-04
3	2643	9839	1	2004-03-04
4	2643	412	3	2004-03-04
5	2643	3579	2	2004-03-04
6	2643	4677	2	2004-03-04
7	2643	875	3	2004-03-04
8	2643	8002	3	2004-03-04
9	2643	8294	1	2004-03-04
1	2644	5490	1	2004-03-28
2	2644	3395	3	2004-03-28
3	2644	3580	2	2004-03-28
4	2644	3584	3	2004-03-28
5	2644	4480	1	2004-03-28
1	2645	3766	3	2004-03-19
2	2645	4186	3	2004-03-19
3	2645	4625	3	2004-03-19
4	2645	3951	2	2004-03-19
5	2645	7893	1	2004-03-19
6	2645	4245	2	2004-03-19
1	2646	8323	2	2004-03-09
2	2646	7565	1	2004-03-09
3	2646	4762	1	2004-03-09
4	2646	6307	3	2004-03-09
5	2646	437	1	2004-03-09
6	2646	935	2	2004-03-09
7	2646	3847	3	2004-03-09
1	2647	4956	1	2004-03-07
2	2647	4999	3	2004-03-07
3	2647	6659	1	2004-03-07
4	2647	858	1	2004-03-07
5	2647	9078	2	2004-03-07
6	2647	4117	3	2004-03-07
1	2648	4157	3	2004-03-03
2	2648	9563	1	2004-03-03
3	2648	6725	3	2004-03-03
4	2648	1250	3	2004-03-03
5	2648	6274	2	2004-03-03
6	2648	6188	3	2004-03-03
7	2648	2708	1	2004-03-03
8	2648	4361	3	2004-03-03
1	2649	2251	3	2004-03-13
1	2650	9931	1	2004-03-05
2	2650	7998	2	2004-03-05
3	2650	432	1	2004-03-05
4	2650	1930	3	2004-03-05
5	2650	2618	3	2004-03-05
6	2650	9992	2	2004-03-05
1	2651	4489	1	2004-03-20
2	2651	5224	3	2004-03-20
3	2651	9335	3	2004-03-20
1	2652	3332	1	2004-03-26
1	2653	6504	2	2004-03-06
2	2653	5265	3	2004-03-06
1	2654	5849	3	2004-03-22
2	2654	3282	1	2004-03-22
3	2654	3185	1	2004-03-22
4	2654	4663	3	2004-03-22
5	2654	3916	3	2004-03-22
6	2654	6522	1	2004-03-22
7	2654	8991	2	2004-03-22
8	2654	9155	3	2004-03-22
9	2654	5189	1	2004-03-22
1	2655	8689	2	2004-03-31
2	2655	1009	2	2004-03-31
3	2655	415	3	2004-03-31
4	2655	1148	3	2004-03-31
5	2655	7220	3	2004-03-31
6	2655	4262	1	2004-03-31
1	2656	5119	2	2004-03-29
2	2656	3707	1	2004-03-29
3	2656	9911	1	2004-03-29
4	2656	6371	3	2004-03-29
1	2657	8533	3	2004-03-05
1	2658	1175	1	2004-03-23
2	2658	6230	1	2004-03-23
3	2658	9767	2	2004-03-23
4	2658	9319	2	2004-03-23
5	2658	3950	3	2004-03-23
6	2658	1475	3	2004-03-23
7	2658	2296	2	2004-03-23
8	2658	3355	2	2004-03-23
1	2659	2331	1	2004-03-26
2	2659	6165	2	2004-03-26
3	2659	1080	2	2004-03-26
4	2659	2411	3	2004-03-26
5	2659	1918	2	2004-03-26
1	2660	5415	2	2004-03-22
2	2660	6600	2	2004-03-22
3	2660	641	1	2004-03-22
1	2661	8709	1	2004-03-10
2	2661	1506	3	2004-03-10
3	2661	3864	1	2004-03-10
4	2661	1549	2	2004-03-10
5	2661	234	3	2004-03-10
1	2662	9810	2	2004-03-01
2	2662	6907	3	2004-03-01
3	2662	7419	2	2004-03-01
1	2663	7566	1	2004-03-31
2	2663	7029	1	2004-03-31
3	2663	3118	2	2004-03-31
4	2663	6277	1	2004-03-31
5	2663	4871	3	2004-03-31
6	2663	8770	3	2004-03-31
1	2664	8032	2	2004-03-25
2	2664	9534	1	2004-03-25
3	2664	7489	3	2004-03-25
4	2664	4767	2	2004-03-25
5	2664	6073	1	2004-03-25
6	2664	8146	2	2004-03-25
7	2664	5018	3	2004-03-25
8	2664	2432	1	2004-03-25
1	2665	3733	3	2004-03-30
2	2665	4454	3	2004-03-30
3	2665	7416	1	2004-03-30
1	2666	3623	1	2004-03-23
2	2666	7265	1	2004-03-23
3	2666	2012	2	2004-03-23
1	2667	8964	3	2004-03-08
2	2667	4524	2	2004-03-08
3	2667	5801	3	2004-03-08
4	2667	6565	2	2004-03-08
5	2667	6416	3	2004-03-08
6	2667	7938	1	2004-03-08
7	2667	9555	1	2004-03-08
8	2667	8751	3	2004-03-08
1	2668	8350	2	2004-03-18
2	2668	726	2	2004-03-18
3	2668	9153	1	2004-03-18
4	2668	368	1	2004-03-18
5	2668	9517	3	2004-03-18
6	2668	223	3	2004-03-18
7	2668	6809	2	2004-03-18
8	2668	2461	1	2004-03-18
9	2668	1701	3	2004-03-18
1	2669	8266	3	2004-03-25
2	2669	8249	3	2004-03-25
3	2669	5473	2	2004-03-25
4	2669	3103	3	2004-03-25
5	2669	3016	1	2004-03-25
6	2669	3843	2	2004-03-25
1	2670	4647	2	2004-03-22
2	2670	6950	2	2004-03-22
3	2670	4475	2	2004-03-22
4	2670	9614	3	2004-03-22
5	2670	6368	1	2004-03-22
6	2670	5961	2	2004-03-22
7	2670	9432	2	2004-03-22
1	2671	4713	3	2004-03-01
2	2671	2257	3	2004-03-01
3	2671	6728	2	2004-03-01
4	2671	9268	1	2004-03-01
5	2671	9014	2	2004-03-01
6	2671	3565	2	2004-03-01
7	2671	3768	3	2004-03-01
8	2671	1487	1	2004-03-01
1	2672	2897	1	2004-03-10
2	2672	4008	3	2004-03-10
3	2672	5132	2	2004-03-10
1	2673	3673	2	2004-03-12
2	2673	6055	2	2004-03-12
3	2673	3663	1	2004-03-12
4	2673	1201	1	2004-03-12
5	2673	3353	1	2004-03-12
6	2673	9265	3	2004-03-12
7	2673	5706	1	2004-03-12
1	2674	3154	3	2004-03-16
2	2674	899	2	2004-03-16
3	2674	9068	2	2004-03-16
4	2674	4907	2	2004-03-16
5	2674	8345	3	2004-03-16
6	2674	9477	3	2004-03-16
7	2674	5844	1	2004-03-16
8	2674	5328	1	2004-03-16
1	2675	1921	3	2004-03-29
1	2676	4217	1	2004-03-02
2	2676	3389	3	2004-03-02
3	2676	8284	2	2004-03-02
4	2676	6191	3	2004-03-02
5	2676	2592	2	2004-03-02
6	2676	4089	3	2004-03-02
1	2677	1913	1	2004-03-30
2	2677	2082	3	2004-03-30
3	2677	3912	1	2004-03-30
4	2677	6230	3	2004-03-30
5	2677	1436	3	2004-03-30
6	2677	6626	1	2004-03-30
7	2677	9335	1	2004-03-30
8	2677	8124	2	2004-03-30
9	2677	1653	1	2004-03-30
1	2678	9119	1	2004-03-05
2	2678	2966	1	2004-03-05
3	2678	8145	1	2004-03-05
4	2678	5640	2	2004-03-05
5	2678	1357	3	2004-03-05
6	2678	6326	2	2004-03-05
7	2678	4793	1	2004-03-05
1	2679	9172	2	2004-03-15
2	2679	7960	3	2004-03-15
3	2679	7029	2	2004-03-15
4	2679	2058	3	2004-03-15
5	2679	7595	2	2004-03-15
6	2679	8618	2	2004-03-15
1	2680	943	2	2004-03-04
2	2680	6671	2	2004-03-04
3	2680	8753	3	2004-03-04
4	2680	4136	2	2004-03-04
1	2681	9950	2	2004-03-05
2	2681	2094	3	2004-03-05
3	2681	9596	1	2004-03-05
4	2681	7629	2	2004-03-05
5	2681	6136	3	2004-03-05
6	2681	5307	2	2004-03-05
1	2682	1660	2	2004-03-11
2	2682	8790	1	2004-03-11
3	2682	114	2	2004-03-11
4	2682	9185	3	2004-03-11
5	2682	3487	1	2004-03-11
1	2683	1012	1	2004-03-13
2	2683	3399	1	2004-03-13
3	2683	1320	1	2004-03-13
4	2683	3158	3	2004-03-13
5	2683	9620	3	2004-03-13
6	2683	8634	2	2004-03-13
7	2683	3023	1	2004-03-13
8	2683	8849	1	2004-03-13
9	2683	6436	1	2004-03-13
1	2684	687	1	2004-03-26
2	2684	7053	2	2004-03-26
3	2684	5616	1	2004-03-26
4	2684	9124	3	2004-03-26
5	2684	252	1	2004-03-26
6	2684	61	2	2004-03-26
7	2684	3241	1	2004-03-26
8	2684	6646	2	2004-03-26
1	2685	1191	3	2004-03-02
2	2685	855	1	2004-03-02
3	2685	1114	3	2004-03-02
4	2685	548	3	2004-03-02
5	2685	2517	2	2004-03-02
6	2685	7376	1	2004-03-02
7	2685	5953	2	2004-03-02
8	2685	7376	1	2004-03-02
9	2685	5424	2	2004-03-02
1	2686	9327	3	2004-03-30
2	2686	872	2	2004-03-30
3	2686	6274	1	2004-03-30
4	2686	2237	1	2004-03-30
5	2686	161	2	2004-03-30
6	2686	676	1	2004-03-30
7	2686	3466	1	2004-03-30
8	2686	8306	2	2004-03-30
9	2686	977	1	2004-03-30
1	2687	2781	1	2004-03-24
2	2687	5190	3	2004-03-24
3	2687	7900	2	2004-03-24
4	2687	3880	2	2004-03-24
1	2688	9178	1	2004-03-13
2	2688	6182	1	2004-03-13
3	2688	2647	2	2004-03-13
4	2688	4840	1	2004-03-13
5	2688	7357	3	2004-03-13
1	2689	6485	3	2004-03-16
2	2689	4442	1	2004-03-16
3	2689	3610	3	2004-03-16
4	2689	1910	3	2004-03-16
5	2689	5426	3	2004-03-16
6	2689	3420	3	2004-03-16
1	2690	2513	1	2004-03-14
2	2690	9438	3	2004-03-14
3	2690	3103	1	2004-03-14
4	2690	5037	3	2004-03-14
5	2690	5408	1	2004-03-14
6	2690	6249	1	2004-03-14
7	2690	8055	3	2004-03-14
8	2690	6609	2	2004-03-14
1	2691	8272	3	2004-03-27
2	2691	963	2	2004-03-27
1	2692	1913	2	2004-03-21
2	2692	9867	2	2004-03-21
1	2693	1390	3	2004-03-23
1	2694	7317	3	2004-03-26
2	2694	3064	2	2004-03-26
3	2694	3144	1	2004-03-26
4	2694	4975	3	2004-03-26
5	2694	3781	1	2004-03-26
1	2695	9126	3	2004-03-16
2	2695	3030	1	2004-03-16
1	2696	2202	3	2004-03-17
2	2696	2971	2	2004-03-17
3	2696	6740	1	2004-03-17
1	2697	5893	3	2004-03-02
2	2697	1630	3	2004-03-02
3	2697	399	2	2004-03-02
4	2697	7227	2	2004-03-02
5	2697	9850	1	2004-03-02
6	2697	8923	3	2004-03-02
7	2697	4295	3	2004-03-02
1	2698	222	2	2004-03-21
2	2698	4862	1	2004-03-21
1	2699	9051	2	2004-03-10
2	2699	7164	2	2004-03-10
3	2699	4105	1	2004-03-10
4	2699	3550	2	2004-03-10
5	2699	2091	2	2004-03-10
6	2699	2338	3	2004-03-10
7	2699	8127	1	2004-03-10
8	2699	1695	3	2004-03-10
9	2699	8980	2	2004-03-10
1	2700	7915	2	2004-03-16
2	2700	8737	1	2004-03-16
3	2700	5959	1	2004-03-16
4	2700	608	1	2004-03-16
1	2701	4427	1	2004-03-06
2	2701	1966	3	2004-03-06
3	2701	8210	2	2004-03-06
4	2701	1923	1	2004-03-06
5	2701	3374	1	2004-03-06
6	2701	2734	2	2004-03-06
7	2701	7099	1	2004-03-06
8	2701	1059	1	2004-03-06
9	2701	7431	2	2004-03-06
1	2702	8122	2	2004-03-20
2	2702	6991	3	2004-03-20
3	2702	5838	3	2004-03-20
4	2702	8387	2	2004-03-20
5	2702	7647	1	2004-03-20
1	2703	3669	1	2004-03-21
2	2703	5440	3	2004-03-21
3	2703	2761	3	2004-03-21
4	2703	2111	3	2004-03-21
5	2703	9886	1	2004-03-21
1	2704	2662	2	2004-03-07
2	2704	3559	1	2004-03-07
3	2704	9317	1	2004-03-07
4	2704	9511	2	2004-03-07
5	2704	9286	3	2004-03-07
6	2704	9362	3	2004-03-07
7	2704	711	2	2004-03-07
8	2704	6545	1	2004-03-07
1	2705	7255	3	2004-03-03
2	2705	4550	3	2004-03-03
3	2705	6830	2	2004-03-03
4	2705	2535	3	2004-03-03
5	2705	1753	1	2004-03-03
6	2705	7325	2	2004-03-03
1	2706	1432	2	2004-03-18
2	2706	9997	1	2004-03-18
3	2706	2605	3	2004-03-18
4	2706	7650	1	2004-03-18
5	2706	5404	2	2004-03-18
1	2707	2719	1	2004-03-15
2	2707	5993	3	2004-03-15
3	2707	1027	1	2004-03-15
4	2707	1705	2	2004-03-15
5	2707	1708	2	2004-03-15
6	2707	3637	3	2004-03-15
7	2707	7871	3	2004-03-15
8	2707	9915	1	2004-03-15
9	2707	4005	1	2004-03-15
1	2708	3360	3	2004-03-25
1	2709	5105	3	2004-03-12
2	2709	7528	3	2004-03-12
3	2709	9977	2	2004-03-12
4	2709	5093	1	2004-03-12
5	2709	6342	3	2004-03-12
6	2709	4564	3	2004-03-12
7	2709	255	3	2004-03-12
8	2709	7081	3	2004-03-12
1	2710	8343	3	2004-03-23
2	2710	5368	1	2004-03-23
1	2711	7490	2	2004-03-29
2	2711	1540	1	2004-03-29
3	2711	2345	3	2004-03-29
1	2712	3325	3	2004-03-02
2	2712	2310	3	2004-03-02
3	2712	6978	1	2004-03-02
4	2712	6087	2	2004-03-02
5	2712	689	2	2004-03-02
1	2713	845	1	2004-03-04
2	2713	9803	1	2004-03-04
3	2713	8909	3	2004-03-04
4	2713	3221	2	2004-03-04
5	2713	3953	2	2004-03-04
6	2713	8994	2	2004-03-04
7	2713	3828	3	2004-03-04
8	2713	8619	2	2004-03-04
9	2713	4924	1	2004-03-04
1	2714	9797	2	2004-03-17
2	2714	6379	1	2004-03-17
3	2714	9366	3	2004-03-17
1	2715	4363	2	2004-03-08
2	2715	3396	1	2004-03-08
3	2715	6553	2	2004-03-08
1	2716	6802	2	2004-03-30
2	2716	8076	2	2004-03-30
3	2716	1618	1	2004-03-30
4	2716	7363	3	2004-03-30
5	2716	232	3	2004-03-30
6	2716	9283	1	2004-03-30
7	2716	3109	2	2004-03-30
8	2716	513	1	2004-03-30
1	2717	6086	1	2004-03-10
2	2717	6550	3	2004-03-10
3	2717	4288	1	2004-03-10
4	2717	6097	2	2004-03-10
5	2717	3608	3	2004-03-10
6	2717	2622	1	2004-03-10
7	2717	2677	1	2004-03-10
8	2717	5830	2	2004-03-10
9	2717	3697	1	2004-03-10
1	2718	3956	2	2004-03-04
1	2719	7345	1	2004-03-20
2	2719	9212	2	2004-03-20
3	2719	3636	2	2004-03-20
4	2719	2911	3	2004-03-20
5	2719	8864	3	2004-03-20
6	2719	1882	1	2004-03-20
7	2719	6481	2	2004-03-20
8	2719	2881	3	2004-03-20
9	2719	5202	3	2004-03-20
1	2720	2826	1	2004-03-11
2	2720	5244	3	2004-03-11
3	2720	5779	1	2004-03-11
4	2720	1249	1	2004-03-11
5	2720	732	3	2004-03-11
1	2721	5705	2	2004-03-14
2	2721	5924	2	2004-03-14
3	2721	3941	3	2004-03-14
4	2721	7040	1	2004-03-14
5	2721	2309	3	2004-03-14
6	2721	9578	3	2004-03-14
7	2721	8631	1	2004-03-14
8	2721	6407	1	2004-03-14
1	2722	6013	3	2004-03-24
2	2722	4418	3	2004-03-24
3	2722	343	2	2004-03-24
1	2723	2706	1	2004-03-19
2	2723	2810	3	2004-03-19
3	2723	5366	3	2004-03-19
4	2723	6434	1	2004-03-19
5	2723	7172	3	2004-03-19
6	2723	2325	3	2004-03-19
7	2723	6252	1	2004-03-19
8	2723	9777	1	2004-03-19
1	2724	488	3	2004-03-05
2	2724	2907	2	2004-03-05
3	2724	5165	1	2004-03-05
4	2724	55	1	2004-03-05
1	2725	5945	1	2004-03-25
1	2726	3715	2	2004-03-29
2	2726	4467	2	2004-03-29
3	2726	2377	1	2004-03-29
4	2726	6994	1	2004-03-29
5	2726	3377	3	2004-03-29
6	2726	9664	2	2004-03-29
1	2727	5056	3	2004-03-09
2	2727	8947	2	2004-03-09
3	2727	9355	3	2004-03-09
4	2727	259	3	2004-03-09
5	2727	7565	2	2004-03-09
6	2727	9956	3	2004-03-09
1	2728	4039	3	2004-03-24
2	2728	7266	2	2004-03-24
1	2729	2742	3	2004-03-25
2	2729	6409	2	2004-03-25
1	2730	7915	1	2004-03-26
2	2730	8551	3	2004-03-26
3	2730	7079	3	2004-03-26
4	2730	5520	2	2004-03-26
1	2731	3887	2	2004-03-16
2	2731	3751	3	2004-03-16
3	2731	1123	1	2004-03-16
1	2732	28	3	2004-03-14
2	2732	1142	2	2004-03-14
3	2732	3549	3	2004-03-14
1	2733	4954	1	2004-03-19
2	2733	1199	1	2004-03-19
3	2733	325	3	2004-03-19
4	2733	6675	2	2004-03-19
1	2734	2249	1	2004-03-07
2	2734	4004	2	2004-03-07
3	2734	2626	3	2004-03-07
4	2734	2258	3	2004-03-07
5	2734	1253	1	2004-03-07
6	2734	5916	1	2004-03-07
1	2735	4242	2	2004-03-28
2	2735	8663	3	2004-03-28
3	2735	6400	3	2004-03-28
4	2735	1229	3	2004-03-28
5	2735	6580	3	2004-03-28
1	2736	4851	3	2004-03-07
2	2736	1528	3	2004-03-07
3	2736	1695	2	2004-03-07
4	2736	7198	2	2004-03-07
5	2736	2052	3	2004-03-07
6	2736	6237	3	2004-03-07
7	2736	844	2	2004-03-07
8	2736	7432	1	2004-03-07
9	2736	9690	1	2004-03-07
1	2737	8214	1	2004-03-24
2	2737	769	2	2004-03-24
3	2737	10000	1	2004-03-24
4	2737	3565	2	2004-03-24
1	2738	7270	2	2004-03-09
2	2738	8425	2	2004-03-09
3	2738	46	1	2004-03-09
4	2738	2917	2	2004-03-09
1	2739	6522	1	2004-03-27
2	2739	7549	2	2004-03-27
3	2739	9280	3	2004-03-27
4	2739	8213	3	2004-03-27
5	2739	515	3	2004-03-27
6	2739	2286	1	2004-03-27
1	2740	4266	1	2004-03-06
2	2740	8826	1	2004-03-06
3	2740	7083	3	2004-03-06
4	2740	6001	3	2004-03-06
5	2740	7728	3	2004-03-06
1	2741	2047	3	2004-03-11
2	2741	5575	3	2004-03-11
3	2741	3366	2	2004-03-11
4	2741	8014	1	2004-03-11
5	2741	2347	3	2004-03-11
1	2742	484	2	2004-03-02
2	2742	6922	2	2004-03-02
3	2742	6621	2	2004-03-02
1	2743	831	1	2004-03-20
2	2743	1201	2	2004-03-20
3	2743	6897	2	2004-03-20
1	2744	8539	2	2004-03-28
2	2744	9315	2	2004-03-28
3	2744	8019	1	2004-03-28
4	2744	5081	3	2004-03-28
5	2744	6294	2	2004-03-28
1	2745	1526	2	2004-03-03
2	2745	3615	3	2004-03-03
3	2745	80	2	2004-03-03
4	2745	92	1	2004-03-03
5	2745	7337	1	2004-03-03
6	2745	5150	2	2004-03-03
7	2745	5170	2	2004-03-03
8	2745	3176	3	2004-03-03
1	2746	8267	1	2004-03-27
2	2746	9473	2	2004-03-27
3	2746	1283	2	2004-03-27
4	2746	7471	1	2004-03-27
5	2746	2544	3	2004-03-27
6	2746	95	2	2004-03-27
7	2746	3604	2	2004-03-27
8	2746	1878	2	2004-03-27
1	2747	3262	3	2004-03-01
2	2747	1891	3	2004-03-01
3	2747	3780	2	2004-03-01
4	2747	6677	1	2004-03-01
5	2747	6781	1	2004-03-01
6	2747	89	2	2004-03-01
7	2747	4067	3	2004-03-01
1	2748	7577	3	2004-03-27
2	2748	3092	3	2004-03-27
3	2748	1941	3	2004-03-27
4	2748	1381	2	2004-03-27
5	2748	378	1	2004-03-27
6	2748	5788	2	2004-03-27
1	2749	7481	3	2004-03-30
2	2749	6315	2	2004-03-30
1	2750	8142	3	2004-03-03
1	2751	2401	1	2004-03-02
2	2751	3619	2	2004-03-02
3	2751	181	2	2004-03-02
4	2751	2187	1	2004-03-02
5	2751	9378	1	2004-03-02
6	2751	3262	2	2004-03-02
1	2752	3869	1	2004-03-24
2	2752	742	1	2004-03-24
3	2752	5852	1	2004-03-24
1	2753	956	1	2004-03-11
2	2753	7955	2	2004-03-11
1	2754	5848	3	2004-03-27
2	2754	7713	3	2004-03-27
1	2755	2256	3	2004-03-01
2	2755	6021	2	2004-03-01
3	2755	382	3	2004-03-01
4	2755	8165	1	2004-03-01
1	2756	5386	2	2004-03-01
2	2756	4768	2	2004-03-01
3	2756	7790	1	2004-03-01
4	2756	2230	2	2004-03-01
1	2757	9206	2	2004-03-10
2	2757	6959	3	2004-03-10
3	2757	3280	3	2004-03-10
4	2757	2746	2	2004-03-10
5	2757	5691	3	2004-03-10
6	2757	2006	2	2004-03-10
7	2757	8655	1	2004-03-10
8	2757	7196	3	2004-03-10
9	2757	4186	3	2004-03-10
1	2758	5912	1	2004-03-07
2	2758	9565	3	2004-03-07
3	2758	8944	1	2004-03-07
4	2758	8768	3	2004-03-07
5	2758	1566	3	2004-03-07
6	2758	3610	3	2004-03-07
7	2758	7319	3	2004-03-07
1	2759	8830	2	2004-03-19
2	2759	7843	3	2004-03-19
1	2760	4868	3	2004-03-15
2	2760	8357	3	2004-03-15
3	2760	5129	2	2004-03-15
4	2760	2319	2	2004-03-15
5	2760	2410	1	2004-03-15
6	2760	7335	1	2004-03-15
7	2760	8683	3	2004-03-15
8	2760	9152	1	2004-03-15
1	2761	6533	1	2004-03-24
2	2761	5275	2	2004-03-24
3	2761	6035	1	2004-03-24
4	2761	2846	1	2004-03-24
1	2762	7343	3	2004-03-26
2	2762	2721	1	2004-03-26
3	2762	2047	2	2004-03-26
1	2763	5634	2	2004-03-23
2	2763	3398	2	2004-03-23
3	2763	7274	1	2004-03-23
4	2763	1254	2	2004-03-23
5	2763	4324	3	2004-03-23
1	2764	2715	2	2004-03-25
2	2764	4729	1	2004-03-25
3	2764	5051	2	2004-03-25
4	2764	3893	1	2004-03-25
1	2765	1652	1	2004-03-06
2	2765	8429	3	2004-03-06
3	2765	6526	2	2004-03-06
4	2765	2935	3	2004-03-06
1	2766	6663	2	2004-03-28
1	2767	8816	3	2004-03-25
1	2768	7694	1	2004-03-22
2	2768	4475	3	2004-03-22
1	2769	1367	1	2004-03-28
1	2770	7816	2	2004-03-26
2	2770	1502	3	2004-03-26
1	2771	2886	3	2004-03-16
2	2771	3957	1	2004-03-16
3	2771	5672	1	2004-03-16
1	2772	6065	3	2004-03-17
2	2772	2561	2	2004-03-17
3	2772	6881	2	2004-03-17
1	2773	6139	2	2004-03-17
2	2773	4877	2	2004-03-17
3	2773	9193	2	2004-03-17
4	2773	2514	2	2004-03-17
1	2774	4432	1	2004-03-15
2	2774	9130	1	2004-03-15
3	2774	2090	2	2004-03-15
4	2774	4025	2	2004-03-15
5	2774	7315	1	2004-03-15
6	2774	2700	3	2004-03-15
7	2774	4909	3	2004-03-15
1	2775	3718	2	2004-03-19
2	2775	8466	3	2004-03-19
3	2775	7920	3	2004-03-19
4	2775	4972	1	2004-03-19
1	2776	6942	1	2004-03-06
2	2776	134	2	2004-03-06
3	2776	1107	1	2004-03-06
4	2776	446	2	2004-03-06
5	2776	7381	3	2004-03-06
6	2776	5220	1	2004-03-06
7	2776	7636	1	2004-03-06
8	2776	9660	2	2004-03-06
9	2776	263	3	2004-03-06
1	2777	2574	3	2004-03-25
2	2777	3993	3	2004-03-25
3	2777	9804	2	2004-03-25
4	2777	7059	2	2004-03-25
5	2777	4907	2	2004-03-25
6	2777	7381	2	2004-03-25
1	2778	3618	2	2004-03-01
1	2779	8966	2	2004-03-26
2	2779	9577	3	2004-03-26
3	2779	1869	3	2004-03-26
4	2779	3208	1	2004-03-26
5	2779	3780	2	2004-03-26
6	2779	2691	3	2004-03-26
1	2780	8871	3	2004-03-11
1	2781	4738	1	2004-03-14
2	2781	4974	3	2004-03-14
3	2781	5502	1	2004-03-14
4	2781	7193	1	2004-03-14
5	2781	9164	2	2004-03-14
1	2782	6185	3	2004-03-15
2	2782	9795	3	2004-03-15
3	2782	4376	1	2004-03-15
4	2782	7736	3	2004-03-15
5	2782	4979	1	2004-03-15
6	2782	8088	2	2004-03-15
1	2783	6930	2	2004-03-31
2	2783	4393	1	2004-03-31
3	2783	3193	3	2004-03-31
4	2783	5155	1	2004-03-31
1	2784	3058	1	2004-03-01
2	2784	1201	3	2004-03-01
3	2784	525	1	2004-03-01
4	2784	9205	2	2004-03-01
5	2784	3480	3	2004-03-01
1	2785	2308	3	2004-03-09
1	2786	7245	2	2004-03-10
1	2787	822	2	2004-03-07
2	2787	1468	3	2004-03-07
3	2787	928	2	2004-03-07
4	2787	9297	1	2004-03-07
5	2787	3767	3	2004-03-07
6	2787	3123	1	2004-03-07
7	2787	4722	2	2004-03-07
1	2788	8014	3	2004-03-31
2	2788	6497	1	2004-03-31
3	2788	9777	3	2004-03-31
4	2788	1268	3	2004-03-31
5	2788	4483	1	2004-03-31
6	2788	7458	1	2004-03-31
7	2788	414	3	2004-03-31
8	2788	6769	1	2004-03-31
1	2789	9824	1	2004-03-18
2	2789	4764	1	2004-03-18
3	2789	3144	3	2004-03-18
4	2789	9549	1	2004-03-18
5	2789	6810	2	2004-03-18
1	2790	5999	1	2004-03-04
2	2790	6080	3	2004-03-04
3	2790	8775	1	2004-03-04
4	2790	530	2	2004-03-04
5	2790	1130	1	2004-03-04
6	2790	4512	3	2004-03-04
7	2790	2824	1	2004-03-04
8	2790	5593	3	2004-03-04
1	2791	8362	1	2004-03-16
2	2791	9348	3	2004-03-16
3	2791	5601	2	2004-03-16
4	2791	2519	3	2004-03-16
5	2791	981	2	2004-03-16
6	2791	4677	3	2004-03-16
7	2791	6250	1	2004-03-16
8	2791	4245	2	2004-03-16
9	2791	1320	2	2004-03-16
1	2792	346	3	2004-03-04
2	2792	5924	2	2004-03-04
3	2792	7771	1	2004-03-04
4	2792	1354	3	2004-03-04
5	2792	886	3	2004-03-04
6	2792	9720	1	2004-03-04
1	2793	2211	3	2004-03-24
1	2794	7644	3	2004-03-15
1	2795	1411	3	2004-03-19
2	2795	2938	1	2004-03-19
3	2795	7625	3	2004-03-19
4	2795	7695	2	2004-03-19
5	2795	9884	3	2004-03-19
6	2795	2568	1	2004-03-19
7	2795	8764	1	2004-03-19
1	2796	6532	3	2004-03-04
2	2796	4764	1	2004-03-04
3	2796	6705	3	2004-03-04
4	2796	2062	2	2004-03-04
5	2796	7707	3	2004-03-04
6	2796	3311	1	2004-03-04
7	2796	5146	2	2004-03-04
1	2797	6945	2	2004-03-01
2	2797	3177	3	2004-03-01
3	2797	3220	2	2004-03-01
4	2797	7598	1	2004-03-01
5	2797	8031	3	2004-03-01
6	2797	8371	2	2004-03-01
7	2797	5992	2	2004-03-01
8	2797	5456	1	2004-03-01
1	2798	6508	3	2004-03-19
2	2798	6112	3	2004-03-19
3	2798	8647	1	2004-03-19
4	2798	4540	3	2004-03-19
5	2798	9340	1	2004-03-19
6	2798	6587	2	2004-03-19
7	2798	5188	3	2004-03-19
8	2798	3112	3	2004-03-19
1	2799	9308	3	2004-03-18
2	2799	9176	2	2004-03-18
3	2799	3663	2	2004-03-18
4	2799	6054	3	2004-03-18
1	2800	3494	2	2004-03-22
2	2800	3118	1	2004-03-22
3	2800	5240	3	2004-03-22
1	2801	863	2	2004-03-03
2	2801	7296	2	2004-03-03
3	2801	2269	1	2004-03-03
4	2801	4684	1	2004-03-03
5	2801	6340	2	2004-03-03
6	2801	1419	2	2004-03-03
7	2801	9291	2	2004-03-03
1	2802	1265	1	2004-03-01
2	2802	237	2	2004-03-01
3	2802	6675	2	2004-03-01
4	2802	6900	1	2004-03-01
5	2802	1010	3	2004-03-01
6	2802	6494	3	2004-03-01
7	2802	5377	3	2004-03-01
1	2803	5474	2	2004-03-11
2	2803	8470	1	2004-03-11
3	2803	6	3	2004-03-11
4	2803	7329	3	2004-03-11
5	2803	4971	3	2004-03-11
6	2803	4640	3	2004-03-11
1	2804	663	3	2004-03-14
2	2804	8002	3	2004-03-14
3	2804	1070	3	2004-03-14
4	2804	5407	3	2004-03-14
5	2804	8695	1	2004-03-14
1	2805	8050	3	2004-03-16
2	2805	2267	2	2004-03-16
3	2805	742	1	2004-03-16
4	2805	6409	3	2004-03-16
5	2805	1567	1	2004-03-16
6	2805	5546	2	2004-03-16
1	2806	4606	1	2004-03-04
2	2806	2806	1	2004-03-04
3	2806	334	2	2004-03-04
4	2806	1619	2	2004-03-04
1	2807	2551	3	2004-03-05
2	2807	2612	1	2004-03-05
3	2807	8906	2	2004-03-05
4	2807	7120	3	2004-03-05
5	2807	7149	2	2004-03-05
6	2807	7718	3	2004-03-05
1	2808	3221	3	2004-03-16
2	2808	9725	3	2004-03-16
3	2808	9801	1	2004-03-16
4	2808	434	1	2004-03-16
5	2808	6405	1	2004-03-16
6	2808	5874	3	2004-03-16
1	2809	2374	3	2004-03-08
2	2809	5517	1	2004-03-08
3	2809	1692	1	2004-03-08
4	2809	927	3	2004-03-08
5	2809	6163	3	2004-03-08
1	2810	7145	2	2004-03-24
2	2810	9505	3	2004-03-24
3	2810	2953	3	2004-03-24
1	2811	5439	2	2004-03-30
2	2811	3648	3	2004-03-30
3	2811	7709	3	2004-03-30
4	2811	2720	1	2004-03-30
5	2811	4666	3	2004-03-30
6	2811	1361	2	2004-03-30
1	2812	931	1	2004-03-03
2	2812	8104	1	2004-03-03
3	2812	5228	2	2004-03-03
4	2812	7965	2	2004-03-03
5	2812	2119	1	2004-03-03
6	2812	4038	1	2004-03-03
7	2812	4304	2	2004-03-03
1	2813	7546	2	2004-03-23
1	2814	8502	3	2004-03-28
2	2814	9842	3	2004-03-28
3	2814	229	2	2004-03-28
4	2814	6408	1	2004-03-28
1	2815	9761	1	2004-03-25
2	2815	7751	1	2004-03-25
3	2815	2879	1	2004-03-25
1	2816	6925	2	2004-03-11
1	2817	4736	3	2004-03-06
1	2818	2611	2	2004-03-13
2	2818	8871	3	2004-03-13
3	2818	6465	2	2004-03-13
4	2818	3530	1	2004-03-13
1	2819	5168	2	2004-03-31
2	2819	9221	3	2004-03-31
3	2819	2484	2	2004-03-31
4	2819	9280	3	2004-03-31
5	2819	8541	1	2004-03-31
6	2819	3879	3	2004-03-31
7	2819	1471	3	2004-03-31
1	2820	9292	2	2004-03-20
2	2820	6611	3	2004-03-20
1	2821	3537	2	2004-03-11
2	2821	301	2	2004-03-11
3	2821	1937	2	2004-03-11
4	2821	1261	1	2004-03-11
5	2821	4032	2	2004-03-11
6	2821	5643	1	2004-03-11
7	2821	3153	2	2004-03-11
1	2822	5646	3	2004-03-14
2	2822	1209	3	2004-03-14
3	2822	814	1	2004-03-14
4	2822	1960	3	2004-03-14
5	2822	8663	2	2004-03-14
6	2822	501	2	2004-03-14
1	2823	9996	3	2004-03-08
2	2823	8221	1	2004-03-08
3	2823	1085	1	2004-03-08
1	2824	911	3	2004-03-16
2	2824	5183	2	2004-03-16
3	2824	5590	1	2004-03-16
4	2824	3697	3	2004-03-16
5	2824	8326	2	2004-03-16
6	2824	7299	1	2004-03-16
7	2824	1935	2	2004-03-16
8	2824	5727	1	2004-03-16
1	2825	930	2	2004-03-30
2	2825	7368	3	2004-03-30
3	2825	7722	3	2004-03-30
4	2825	1404	1	2004-03-30
5	2825	5180	3	2004-03-30
6	2825	874	2	2004-03-30
7	2825	6811	2	2004-03-30
1	2826	9198	2	2004-03-01
2	2826	8485	2	2004-03-01
3	2826	5495	1	2004-03-01
4	2826	2457	1	2004-03-01
1	2827	9344	1	2004-03-09
2	2827	5792	3	2004-03-09
3	2827	9479	2	2004-03-09
4	2827	5164	1	2004-03-09
5	2827	6235	1	2004-03-09
6	2827	7851	3	2004-03-09
7	2827	6432	2	2004-03-09
8	2827	3164	3	2004-03-09
9	2827	7061	1	2004-03-09
1	2828	2755	1	2004-03-03
2	2828	9587	2	2004-03-03
3	2828	1972	1	2004-03-03
4	2828	7115	1	2004-03-03
5	2828	1766	2	2004-03-03
6	2828	1698	3	2004-03-03
7	2828	3169	1	2004-03-03
8	2828	1071	3	2004-03-03
9	2828	2060	3	2004-03-03
1	2829	4571	3	2004-03-27
2	2829	1816	1	2004-03-27
3	2829	7624	1	2004-03-27
4	2829	7890	1	2004-03-27
5	2829	1668	1	2004-03-27
1	2830	3695	1	2004-03-12
2	2830	6973	2	2004-03-12
3	2830	9427	3	2004-03-12
4	2830	3019	1	2004-03-12
5	2830	9847	2	2004-03-12
6	2830	927	1	2004-03-12
1	2831	4708	2	2004-03-05
2	2831	3384	2	2004-03-05
3	2831	8018	1	2004-03-05
4	2831	9023	2	2004-03-05
5	2831	3887	1	2004-03-05
6	2831	6550	3	2004-03-05
1	2832	5373	1	2004-03-07
2	2832	1100	2	2004-03-07
3	2832	8763	2	2004-03-07
4	2832	7394	3	2004-03-07
5	2832	8208	3	2004-03-07
6	2832	515	3	2004-03-07
1	2833	8717	3	2004-03-25
2	2833	9152	3	2004-03-25
3	2833	9799	3	2004-03-25
1	2834	1202	1	2004-03-09
2	2834	1594	2	2004-03-09
3	2834	6447	3	2004-03-09
4	2834	4414	3	2004-03-09
5	2834	1766	1	2004-03-09
6	2834	1665	3	2004-03-09
7	2834	1785	3	2004-03-09
8	2834	7480	1	2004-03-09
9	2834	9474	2	2004-03-09
1	2835	3674	3	2004-03-15
2	2835	81	2	2004-03-15
3	2835	5356	1	2004-03-15
4	2835	7157	2	2004-03-15
1	2836	2680	1	2004-03-06
2	2836	470	3	2004-03-06
3	2836	9021	1	2004-03-06
4	2836	269	1	2004-03-06
1	2837	4353	1	2004-03-05
2	2837	4276	3	2004-03-05
3	2837	4912	1	2004-03-05
4	2837	2330	3	2004-03-05
5	2837	9487	1	2004-03-05
6	2837	2058	2	2004-03-05
7	2837	5130	3	2004-03-05
8	2837	9063	3	2004-03-05
1	2838	5564	1	2004-03-24
1	2839	5270	2	2004-03-23
2	2839	9666	2	2004-03-23
3	2839	3516	2	2004-03-23
4	2839	5856	3	2004-03-23
5	2839	3001	1	2004-03-23
6	2839	97	2	2004-03-23
7	2839	9352	3	2004-03-23
1	2840	623	2	2004-03-24
2	2840	9909	3	2004-03-24
3	2840	7578	1	2004-03-24
1	2841	7726	2	2004-03-27
2	2841	3402	1	2004-03-27
3	2841	9355	1	2004-03-27
4	2841	8822	1	2004-03-27
5	2841	7086	2	2004-03-27
6	2841	662	1	2004-03-27
1	2842	342	1	2004-03-17
2	2842	6205	2	2004-03-17
3	2842	6026	3	2004-03-17
4	2842	8256	2	2004-03-17
5	2842	5022	2	2004-03-17
1	2843	9257	3	2004-03-20
2	2843	2562	1	2004-03-20
3	2843	9697	1	2004-03-20
4	2843	5726	3	2004-03-20
5	2843	4787	1	2004-03-20
6	2843	3194	2	2004-03-20
7	2843	2898	3	2004-03-20
8	2843	6207	3	2004-03-20
1	2844	1317	3	2004-03-11
2	2844	6464	3	2004-03-11
3	2844	3430	1	2004-03-11
4	2844	5406	3	2004-03-11
5	2844	4952	2	2004-03-11
6	2844	7664	2	2004-03-11
7	2844	1082	1	2004-03-11
8	2844	6866	1	2004-03-11
9	2844	2142	1	2004-03-11
1	2845	2377	3	2004-03-29
2	2845	1126	3	2004-03-29
3	2845	6613	2	2004-03-29
1	2846	5580	1	2004-03-16
2	2846	6019	3	2004-03-16
3	2846	2144	1	2004-03-16
4	2846	8824	3	2004-03-16
5	2846	5806	2	2004-03-16
6	2846	1302	3	2004-03-16
1	2847	758	3	2004-03-21
2	2847	5781	2	2004-03-21
3	2847	9448	3	2004-03-21
4	2847	4457	1	2004-03-21
5	2847	6740	1	2004-03-21
6	2847	5132	1	2004-03-21
7	2847	9154	3	2004-03-21
8	2847	8318	2	2004-03-21
1	2848	5761	1	2004-03-31
2	2848	9223	1	2004-03-31
1	2849	8692	2	2004-03-29
2	2849	4617	3	2004-03-29
3	2849	3075	1	2004-03-29
4	2849	5607	1	2004-03-29
5	2849	8555	1	2004-03-29
6	2849	3096	2	2004-03-29
1	2850	7554	2	2004-03-04
1	2851	9668	2	2004-03-16
2	2851	1327	3	2004-03-16
3	2851	7144	1	2004-03-16
4	2851	9416	2	2004-03-16
5	2851	6143	3	2004-03-16
6	2851	1712	1	2004-03-16
7	2851	7555	2	2004-03-16
8	2851	1158	1	2004-03-16
1	2852	5006	2	2004-03-23
1	2853	7652	3	2004-03-27
2	2853	3725	3	2004-03-27
3	2853	8427	2	2004-03-27
4	2853	3047	3	2004-03-27
5	2853	2283	1	2004-03-27
6	2853	133	1	2004-03-27
1	2854	7035	3	2004-03-18
2	2854	2282	3	2004-03-18
3	2854	521	3	2004-03-18
4	2854	7905	2	2004-03-18
5	2854	9995	1	2004-03-18
6	2854	8105	3	2004-03-18
7	2854	5081	1	2004-03-18
1	2855	201	1	2004-03-15
2	2855	1929	1	2004-03-15
3	2855	595	2	2004-03-15
4	2855	3438	1	2004-03-15
5	2855	5909	3	2004-03-15
6	2855	7002	2	2004-03-15
7	2855	6718	2	2004-03-15
8	2855	3072	3	2004-03-15
1	2856	7338	3	2004-03-07
1	2857	8192	1	2004-03-10
2	2857	855	1	2004-03-10
3	2857	559	1	2004-03-10
4	2857	1448	1	2004-03-10
5	2857	4303	1	2004-03-10
6	2857	6698	3	2004-03-10
7	2857	2770	1	2004-03-10
8	2857	6962	3	2004-03-10
1	2858	2680	2	2004-03-26
2	2858	4983	1	2004-03-26
1	2859	7762	3	2004-03-20
2	2859	7333	2	2004-03-20
3	2859	9088	3	2004-03-20
4	2859	6560	3	2004-03-20
5	2859	9242	3	2004-03-20
6	2859	2133	2	2004-03-20
7	2859	50	3	2004-03-20
8	2859	1285	1	2004-03-20
9	2859	1436	3	2004-03-20
1	2860	1145	2	2004-03-09
2	2860	2432	2	2004-03-09
3	2860	5875	3	2004-03-09
4	2860	8446	2	2004-03-09
5	2860	7809	2	2004-03-09
6	2860	2794	2	2004-03-09
1	2861	1527	1	2004-03-07
2	2861	6727	2	2004-03-07
3	2861	6115	3	2004-03-07
4	2861	2490	3	2004-03-07
5	2861	9595	2	2004-03-07
6	2861	5645	1	2004-03-07
7	2861	3679	3	2004-03-07
8	2861	8580	2	2004-03-07
1	2862	9611	3	2004-03-07
2	2862	3779	3	2004-03-07
3	2862	5603	2	2004-03-07
4	2862	2560	3	2004-03-07
5	2862	8452	2	2004-03-07
6	2862	6482	3	2004-03-07
7	2862	8458	1	2004-03-07
8	2862	3638	2	2004-03-07
1	2863	52	3	2004-03-31
2	2863	1763	2	2004-03-31
3	2863	5187	1	2004-03-31
4	2863	8554	3	2004-03-31
5	2863	1354	3	2004-03-31
6	2863	5412	1	2004-03-31
7	2863	8898	3	2004-03-31
8	2863	8382	2	2004-03-31
9	2863	5762	1	2004-03-31
1	2864	4192	2	2004-03-08
2	2864	1953	3	2004-03-08
3	2864	9859	1	2004-03-08
4	2864	3957	1	2004-03-08
5	2864	1516	2	2004-03-08
6	2864	9446	1	2004-03-08
7	2864	7739	2	2004-03-08
8	2864	3620	2	2004-03-08
1	2865	5936	2	2004-03-07
2	2865	6595	2	2004-03-07
3	2865	9191	1	2004-03-07
4	2865	5260	1	2004-03-07
5	2865	6569	1	2004-03-07
6	2865	196	1	2004-03-07
7	2865	7377	1	2004-03-07
1	2866	9065	2	2004-03-27
2	2866	6554	3	2004-03-27
3	2866	8878	2	2004-03-27
1	2867	7470	2	2004-03-10
2	2867	2540	2	2004-03-10
3	2867	1068	3	2004-03-10
4	2867	7724	1	2004-03-10
5	2867	1490	1	2004-03-10
1	2868	8819	1	2004-03-06
2	2868	4055	3	2004-03-06
1	2869	3739	2	2004-03-31
2	2869	7258	1	2004-03-31
3	2869	798	1	2004-03-31
4	2869	5113	1	2004-03-31
5	2869	5533	1	2004-03-31
6	2869	7758	3	2004-03-31
7	2869	5988	3	2004-03-31
8	2869	7207	2	2004-03-31
1	2870	6755	1	2004-03-29
1	2871	2982	2	2004-03-09
2	2871	4896	1	2004-03-09
3	2871	2643	3	2004-03-09
4	2871	9443	3	2004-03-09
5	2871	1251	1	2004-03-09
6	2871	299	2	2004-03-09
7	2871	1621	2	2004-03-09
1	2872	8203	1	2004-03-28
2	2872	8644	3	2004-03-28
3	2872	9806	2	2004-03-28
4	2872	8081	2	2004-03-28
5	2872	7102	1	2004-03-28
1	2873	5210	1	2004-03-07
2	2873	8052	3	2004-03-07
3	2873	1068	3	2004-03-07
4	2873	7753	1	2004-03-07
5	2873	7734	3	2004-03-07
1	2874	8732	3	2004-03-27
2	2874	2560	3	2004-03-27
3	2874	8895	1	2004-03-27
4	2874	4221	3	2004-03-27
5	2874	6540	1	2004-03-27
6	2874	5260	2	2004-03-27
7	2874	3083	3	2004-03-27
1	2875	3054	1	2004-03-16
1	2876	6440	2	2004-03-25
2	2876	3819	2	2004-03-25
3	2876	5141	3	2004-03-25
4	2876	2748	2	2004-03-25
5	2876	5486	2	2004-03-25
6	2876	806	2	2004-03-25
1	2877	7327	3	2004-03-21
2	2877	6689	1	2004-03-21
3	2877	5732	1	2004-03-21
1	2878	8801	3	2004-03-04
2	2878	8204	3	2004-03-04
3	2878	5589	2	2004-03-04
4	2878	2641	3	2004-03-04
1	2879	1653	1	2004-03-31
2	2879	7818	1	2004-03-31
3	2879	6973	2	2004-03-31
1	2880	8390	2	2004-03-24
2	2880	5219	2	2004-03-24
3	2880	5708	2	2004-03-24
4	2880	2363	3	2004-03-24
5	2880	331	1	2004-03-24
1	2881	3177	1	2004-03-23
2	2881	2332	1	2004-03-23
3	2881	8439	3	2004-03-23
1	2882	2550	3	2004-03-17
2	2882	7596	1	2004-03-17
3	2882	9055	2	2004-03-17
1	2883	1566	2	2004-03-16
1	2884	5092	3	2004-03-20
2	2884	5173	1	2004-03-20
3	2884	2517	3	2004-03-20
4	2884	3768	2	2004-03-20
5	2884	1290	1	2004-03-20
6	2884	4288	3	2004-03-20
1	2885	5324	3	2004-03-08
2	2885	4880	2	2004-03-08
3	2885	2576	3	2004-03-08
4	2885	1823	1	2004-03-08
5	2885	9784	2	2004-03-08
1	2886	2732	1	2004-03-20
2	2886	8207	3	2004-03-20
3	2886	5518	1	2004-03-20
4	2886	6254	3	2004-03-20
5	2886	5572	3	2004-03-20
6	2886	1491	3	2004-03-20
7	2886	4284	2	2004-03-20
8	2886	6179	2	2004-03-20
1	2887	5880	2	2004-03-27
2	2887	3236	3	2004-03-27
3	2887	6084	1	2004-03-27
4	2887	1091	1	2004-03-27
1	2888	816	3	2004-03-29
2	2888	9749	2	2004-03-29
1	2889	3546	3	2004-03-31
2	2889	5416	3	2004-03-31
3	2889	895	1	2004-03-31
4	2889	2122	3	2004-03-31
5	2889	3095	2	2004-03-31
6	2889	3042	3	2004-03-31
1	2890	9296	3	2004-03-27
2	2890	7013	3	2004-03-27
3	2890	6173	3	2004-03-27
4	2890	252	3	2004-03-27
5	2890	7327	1	2004-03-27
1	2891	2867	3	2004-03-11
2	2891	6044	3	2004-03-11
3	2891	7378	3	2004-03-11
4	2891	9875	3	2004-03-11
5	2891	6466	1	2004-03-11
6	2891	3516	3	2004-03-11
7	2891	1945	1	2004-03-11
8	2891	5784	3	2004-03-11
9	2891	6577	2	2004-03-11
1	2892	1655	2	2004-03-20
2	2892	9547	3	2004-03-20
3	2892	3740	1	2004-03-20
1	2893	9291	3	2004-03-20
2	2893	7439	3	2004-03-20
3	2893	4786	3	2004-03-20
4	2893	6168	1	2004-03-20
5	2893	283	3	2004-03-20
6	2893	759	1	2004-03-20
7	2893	1688	2	2004-03-20
8	2893	847	3	2004-03-20
9	2893	1622	3	2004-03-20
1	2894	8848	3	2004-03-06
2	2894	2490	1	2004-03-06
3	2894	2205	3	2004-03-06
4	2894	2330	2	2004-03-06
1	2895	8289	2	2004-03-25
2	2895	2689	2	2004-03-25
3	2895	7892	1	2004-03-25
4	2895	4139	3	2004-03-25
5	2895	5199	2	2004-03-25
1	2896	3278	2	2004-03-17
2	2896	1922	1	2004-03-17
3	2896	9454	1	2004-03-17
4	2896	2408	1	2004-03-17
5	2896	3358	2	2004-03-17
6	2896	724	2	2004-03-17
7	2896	8621	3	2004-03-17
1	2897	7118	3	2004-03-23
2	2897	51	2	2004-03-23
3	2897	9696	2	2004-03-23
4	2897	3659	2	2004-03-23
5	2897	17	3	2004-03-23
6	2897	940	2	2004-03-23
1	2898	7287	3	2004-03-18
2	2898	8356	3	2004-03-18
3	2898	1450	1	2004-03-18
4	2898	4307	1	2004-03-18
5	2898	7399	1	2004-03-18
6	2898	834	2	2004-03-18
7	2898	3404	2	2004-03-18
1	2899	5530	1	2004-03-01
1	2900	8039	3	2004-03-15
2	2900	8666	2	2004-03-15
3	2900	1341	3	2004-03-15
4	2900	1288	3	2004-03-15
5	2900	8225	3	2004-03-15
1	2901	1848	3	2004-03-26
2	2901	5556	1	2004-03-26
3	2901	3461	3	2004-03-26
1	2902	4114	2	2004-03-24
2	2902	434	3	2004-03-24
3	2902	4199	2	2004-03-24
4	2902	3213	1	2004-03-24
5	2902	3741	1	2004-03-24
6	2902	5940	2	2004-03-24
7	2902	597	3	2004-03-24
8	2902	3708	3	2004-03-24
9	2902	6871	1	2004-03-24
1	2903	6981	1	2004-03-27
1	2904	4203	3	2004-03-10
1	2905	6971	3	2004-03-31
1	2906	2062	2	2004-03-21
1	2907	1481	1	2004-03-18
2	2907	1326	3	2004-03-18
3	2907	8361	2	2004-03-18
4	2907	321	2	2004-03-18
5	2907	6193	2	2004-03-18
6	2907	5783	2	2004-03-18
7	2907	3920	3	2004-03-18
8	2907	4015	2	2004-03-18
9	2907	8301	3	2004-03-18
1	2908	5454	2	2004-03-12
1	2909	175	2	2004-03-04
2	2909	5955	1	2004-03-04
3	2909	5064	3	2004-03-04
4	2909	1631	2	2004-03-04
5	2909	3261	1	2004-03-04
6	2909	8766	3	2004-03-04
1	2910	4533	3	2004-03-17
2	2910	2854	1	2004-03-17
3	2910	6508	2	2004-03-17
4	2910	8104	1	2004-03-17
5	2910	7202	2	2004-03-17
6	2910	7673	3	2004-03-17
7	2910	1073	3	2004-03-17
8	2910	4928	1	2004-03-17
9	2910	4268	1	2004-03-17
1	2911	2755	1	2004-03-09
2	2911	6484	1	2004-03-09
3	2911	877	1	2004-03-09
4	2911	6068	2	2004-03-09
5	2911	995	1	2004-03-09
1	2912	491	1	2004-03-15
1	2913	5962	2	2004-03-10
1	2914	1772	1	2004-03-01
2	2914	3686	3	2004-03-01
3	2914	4845	2	2004-03-01
4	2914	1356	1	2004-03-01
1	2915	7926	2	2004-03-25
2	2915	4627	1	2004-03-25
3	2915	7950	3	2004-03-25
4	2915	3487	3	2004-03-25
1	2916	7313	1	2004-03-30
2	2916	852	3	2004-03-30
3	2916	2983	3	2004-03-30
4	2916	1755	2	2004-03-30
5	2916	8576	2	2004-03-30
1	2917	4747	3	2004-03-15
2	2917	8273	3	2004-03-15
3	2917	3866	2	2004-03-15
4	2917	1955	3	2004-03-15
5	2917	8651	3	2004-03-15
6	2917	6551	1	2004-03-15
1	2918	831	2	2004-03-26
2	2918	6569	1	2004-03-26
3	2918	3412	3	2004-03-26
4	2918	9945	2	2004-03-26
5	2918	4305	3	2004-03-26
1	2919	5033	3	2004-03-02
2	2919	2323	1	2004-03-02
3	2919	4540	2	2004-03-02
1	2920	6399	1	2004-03-30
2	2920	291	2	2004-03-30
3	2920	7375	3	2004-03-30
4	2920	9218	3	2004-03-30
5	2920	5002	2	2004-03-30
6	2920	9888	3	2004-03-30
7	2920	5337	3	2004-03-30
8	2920	3579	3	2004-03-30
1	2921	6668	2	2004-03-26
1	2922	5178	2	2004-03-22
2	2922	8013	3	2004-03-22
1	2923	9154	3	2004-03-15
2	2923	3906	3	2004-03-15
3	2923	6669	3	2004-03-15
4	2923	4157	2	2004-03-15
5	2923	7320	3	2004-03-15
1	2924	5081	3	2004-03-20
2	2924	5035	1	2004-03-20
3	2924	1430	1	2004-03-20
4	2924	738	3	2004-03-20
5	2924	3531	2	2004-03-20
1	2925	5955	3	2004-03-16
2	2925	4415	2	2004-03-16
3	2925	5324	3	2004-03-16
4	2925	3478	1	2004-03-16
5	2925	7228	3	2004-03-16
6	2925	8549	2	2004-03-16
7	2925	7128	2	2004-03-16
8	2925	5445	2	2004-03-16
9	2925	9681	1	2004-03-16
1	2926	6728	1	2004-03-13
2	2926	3856	1	2004-03-13
3	2926	8926	3	2004-03-13
4	2926	1801	2	2004-03-13
5	2926	8226	3	2004-03-13
1	2927	961	2	2004-03-05
2	2927	8876	3	2004-03-05
3	2927	3975	3	2004-03-05
4	2927	2735	1	2004-03-05
5	2927	2363	3	2004-03-05
6	2927	7363	1	2004-03-05
7	2927	8704	1	2004-03-05
1	2928	3986	1	2004-03-21
2	2928	3742	1	2004-03-21
3	2928	9430	2	2004-03-21
4	2928	7610	3	2004-03-21
1	2929	6052	1	2004-03-11
2	2929	2500	2	2004-03-11
3	2929	9444	2	2004-03-11
4	2929	2352	1	2004-03-11
5	2929	7575	2	2004-03-11
6	2929	356	2	2004-03-11
1	2930	36	1	2004-03-21
2	2930	6996	2	2004-03-21
3	2930	3875	1	2004-03-21
4	2930	6933	1	2004-03-21
1	2931	3711	1	2004-03-20
2	2931	5736	3	2004-03-20
3	2931	2512	3	2004-03-20
4	2931	4690	1	2004-03-20
5	2931	4709	3	2004-03-20
6	2931	4133	1	2004-03-20
7	2931	1754	2	2004-03-20
8	2931	7220	3	2004-03-20
9	2931	3548	2	2004-03-20
1	2932	7605	1	2004-03-07
2	2932	9754	2	2004-03-07
3	2932	3897	2	2004-03-07
4	2932	9080	2	2004-03-07
5	2932	5610	1	2004-03-07
6	2932	6113	1	2004-03-07
7	2932	2552	3	2004-03-07
8	2932	9580	3	2004-03-07
9	2932	580	2	2004-03-07
1	2933	9200	2	2004-03-14
2	2933	4544	1	2004-03-14
3	2933	7337	2	2004-03-14
4	2933	6331	2	2004-03-14
5	2933	5581	2	2004-03-14
6	2933	4648	2	2004-03-14
1	2934	3402	3	2004-03-27
2	2934	341	3	2004-03-27
3	2934	8322	1	2004-03-27
4	2934	8139	3	2004-03-27
5	2934	134	3	2004-03-27
6	2934	2189	2	2004-03-27
7	2934	3429	3	2004-03-27
1	2935	5376	3	2004-03-02
2	2935	1557	1	2004-03-02
3	2935	3943	3	2004-03-02
4	2935	5641	3	2004-03-02
5	2935	2472	2	2004-03-02
1	2936	815	1	2004-03-23
1	2937	7037	2	2004-03-01
2	2937	6906	3	2004-03-01
3	2937	9447	1	2004-03-01
4	2937	7985	3	2004-03-01
5	2937	2963	1	2004-03-01
6	2937	4889	3	2004-03-01
7	2937	423	2	2004-03-01
8	2937	44	2	2004-03-01
1	2938	9798	1	2004-03-12
2	2938	9892	1	2004-03-12
3	2938	625	1	2004-03-12
4	2938	3467	1	2004-03-12
5	2938	9842	3	2004-03-12
6	2938	8864	3	2004-03-12
1	2939	6104	2	2004-03-11
2	2939	2738	3	2004-03-11
3	2939	4623	3	2004-03-11
1	2940	9409	3	2004-03-23
2	2940	3133	1	2004-03-23
3	2940	3707	1	2004-03-23
4	2940	2452	2	2004-03-23
5	2940	4392	1	2004-03-23
6	2940	4305	3	2004-03-23
7	2940	3752	2	2004-03-23
1	2941	8385	3	2004-03-20
2	2941	2460	2	2004-03-20
3	2941	1214	2	2004-03-20
4	2941	3555	2	2004-03-20
5	2941	2823	1	2004-03-20
6	2941	881	3	2004-03-20
7	2941	8407	1	2004-03-20
8	2941	4548	1	2004-03-20
9	2941	2653	3	2004-03-20
1	2942	8181	2	2004-03-14
2	2942	6719	1	2004-03-14
3	2942	303	1	2004-03-14
4	2942	4548	1	2004-03-14
5	2942	2558	1	2004-03-14
6	2942	8453	2	2004-03-14
7	2942	7420	3	2004-03-14
8	2942	214	1	2004-03-14
1	2943	9931	1	2004-03-18
2	2943	6673	2	2004-03-18
3	2943	1878	3	2004-03-18
4	2943	2732	2	2004-03-18
5	2943	4431	2	2004-03-18
6	2943	5208	1	2004-03-18
1	2944	4866	3	2004-03-03
1	2945	2439	3	2004-03-08
1	2946	5688	1	2004-03-02
2	2946	2375	2	2004-03-02
3	2946	2685	3	2004-03-02
4	2946	96	2	2004-03-02
5	2946	8374	1	2004-03-02
6	2946	910	1	2004-03-02
1	2947	8043	3	2004-03-23
2	2947	9198	1	2004-03-23
3	2947	9048	1	2004-03-23
4	2947	331	1	2004-03-23
5	2947	2393	1	2004-03-23
6	2947	510	1	2004-03-23
7	2947	5421	1	2004-03-23
8	2947	8874	1	2004-03-23
1	2948	296	3	2004-03-11
2	2948	518	3	2004-03-11
3	2948	9649	1	2004-03-11
4	2948	1472	3	2004-03-11
5	2948	7544	3	2004-03-11
6	2948	5214	2	2004-03-11
1	2949	5980	3	2004-03-22
2	2949	6960	3	2004-03-22
3	2949	1594	3	2004-03-22
4	2949	1254	3	2004-03-22
5	2949	8394	1	2004-03-22
6	2949	8123	1	2004-03-22
1	2950	1671	3	2004-03-05
2	2950	338	1	2004-03-05
1	2951	8696	2	2004-03-30
2	2951	2694	2	2004-03-30
3	2951	8004	1	2004-03-30
4	2951	1429	2	2004-03-30
5	2951	12	3	2004-03-30
6	2951	2356	1	2004-03-30
7	2951	5859	2	2004-03-30
1	2952	5917	2	2004-03-27
2	2952	1590	2	2004-03-27
3	2952	6779	1	2004-03-27
4	2952	1674	3	2004-03-27
5	2952	4579	1	2004-03-27
6	2952	8926	1	2004-03-27
7	2952	8345	3	2004-03-27
1	2953	2227	2	2004-03-21
2	2953	8538	1	2004-03-21
3	2953	2977	1	2004-03-21
4	2953	3844	3	2004-03-21
5	2953	4502	1	2004-03-21
1	2954	3346	1	2004-03-10
2	2954	2540	1	2004-03-10
3	2954	4052	2	2004-03-10
4	2954	7241	3	2004-03-10
5	2954	5450	2	2004-03-10
6	2954	1588	2	2004-03-10
7	2954	3787	3	2004-03-10
8	2954	4833	3	2004-03-10
9	2954	2692	3	2004-03-10
1	2955	2122	1	2004-03-05
2	2955	3343	2	2004-03-05
3	2955	5602	2	2004-03-05
4	2955	4860	2	2004-03-05
5	2955	5433	3	2004-03-05
1	2956	2186	2	2004-03-18
2	2956	8277	3	2004-03-18
3	2956	1736	3	2004-03-18
4	2956	1430	2	2004-03-18
5	2956	8002	2	2004-03-18
6	2956	2467	1	2004-03-18
7	2956	3321	2	2004-03-18
8	2956	1921	1	2004-03-18
9	2956	8508	2	2004-03-18
1	2957	8280	2	2004-03-18
2	2957	6164	2	2004-03-18
1	2958	1407	2	2004-03-12
2	2958	7629	3	2004-03-12
1	2959	4887	3	2004-03-05
2	2959	9198	3	2004-03-05
3	2959	8242	1	2004-03-05
1	2960	4204	1	2004-03-05
2	2960	1709	2	2004-03-05
3	2960	2253	3	2004-03-05
4	2960	392	3	2004-03-05
5	2960	3700	2	2004-03-05
6	2960	176	2	2004-03-05
7	2960	6179	1	2004-03-05
8	2960	9255	2	2004-03-05
9	2960	1267	1	2004-03-05
1	2961	8364	1	2004-03-10
2	2961	5411	2	2004-03-10
3	2961	5411	3	2004-03-10
4	2961	6767	1	2004-03-10
5	2961	6621	1	2004-03-10
6	2961	1441	3	2004-03-10
7	2961	5839	2	2004-03-10
8	2961	8317	2	2004-03-10
1	2962	7402	2	2004-03-07
2	2962	3868	2	2004-03-07
3	2962	337	2	2004-03-07
1	2963	1566	2	2004-03-23
1	2964	3738	3	2004-03-13
2	2964	9961	1	2004-03-13
3	2964	8654	1	2004-03-13
4	2964	8688	2	2004-03-13
5	2964	5095	3	2004-03-13
6	2964	722	3	2004-03-13
7	2964	9022	1	2004-03-13
8	2964	9489	2	2004-03-13
9	2964	7602	2	2004-03-13
1	2965	1447	2	2004-03-10
1	2966	9988	3	2004-03-05
2	2966	5022	2	2004-03-05
3	2966	7352	2	2004-03-05
4	2966	4084	2	2004-03-05
5	2966	6384	1	2004-03-05
6	2966	497	1	2004-03-05
1	2967	2291	3	2004-03-31
2	2967	5221	3	2004-03-31
3	2967	1527	3	2004-03-31
4	2967	7831	1	2004-03-31
5	2967	8793	3	2004-03-31
6	2967	4457	1	2004-03-31
7	2967	2289	1	2004-03-31
8	2967	6006	1	2004-03-31
1	2968	6010	1	2004-03-09
1	2969	3871	1	2004-03-20
2	2969	7947	1	2004-03-20
3	2969	1433	1	2004-03-20
4	2969	722	2	2004-03-20
5	2969	129	1	2004-03-20
6	2969	4953	3	2004-03-20
7	2969	2265	2	2004-03-20
1	2970	9931	1	2004-03-23
2	2970	1802	1	2004-03-23
3	2970	1176	3	2004-03-23
4	2970	3035	3	2004-03-23
5	2970	7890	3	2004-03-23
6	2970	9578	1	2004-03-23
7	2970	5996	2	2004-03-23
8	2970	3381	2	2004-03-23
9	2970	6001	2	2004-03-23
1	2971	8971	2	2004-03-13
2	2971	2268	1	2004-03-13
3	2971	164	3	2004-03-13
4	2971	7957	2	2004-03-13
1	2972	695	2	2004-03-28
1	2973	2997	1	2004-03-27
2	2973	7271	3	2004-03-27
3	2973	5841	1	2004-03-27
4	2973	2935	1	2004-03-27
5	2973	5465	3	2004-03-27
6	2973	8564	3	2004-03-27
1	2974	8769	2	2004-03-05
2	2974	3193	3	2004-03-05
3	2974	7818	1	2004-03-05
4	2974	4613	1	2004-03-05
1	2975	9037	1	2004-03-10
2	2975	8212	1	2004-03-10
1	2976	6134	2	2004-03-10
2	2976	786	1	2004-03-10
3	2976	1075	3	2004-03-10
4	2976	8530	1	2004-03-10
5	2976	6883	1	2004-03-10
6	2976	6186	2	2004-03-10
7	2976	5392	3	2004-03-10
8	2976	2377	1	2004-03-10
9	2976	1600	3	2004-03-10
1	2977	6340	1	2004-03-17
2	2977	4094	2	2004-03-17
3	2977	3367	3	2004-03-17
4	2977	33	2	2004-03-17
1	2978	7766	3	2004-03-20
2	2978	6278	2	2004-03-20
3	2978	1924	1	2004-03-20
4	2978	8174	3	2004-03-20
5	2978	8811	2	2004-03-20
6	2978	7487	1	2004-03-20
7	2978	6774	3	2004-03-20
1	2979	5635	1	2004-03-26
1	2980	6928	2	2004-03-06
2	2980	9565	1	2004-03-06
3	2980	826	3	2004-03-06
4	2980	10000	3	2004-03-06
5	2980	7346	2	2004-03-06
1	2981	7379	3	2004-03-16
2	2981	6625	2	2004-03-16
3	2981	9435	2	2004-03-16
1	2982	8085	1	2004-03-13
2	2982	7767	3	2004-03-13
3	2982	1016	1	2004-03-13
4	2982	5063	3	2004-03-13
5	2982	7053	2	2004-03-13
6	2982	1013	3	2004-03-13
7	2982	2545	1	2004-03-13
1	2983	9160	3	2004-03-21
2	2983	4416	2	2004-03-21
1	2984	4438	2	2004-03-16
2	2984	2021	1	2004-03-16
3	2984	3044	1	2004-03-16
4	2984	1378	1	2004-03-16
1	2985	336	1	2004-03-31
2	2985	9684	1	2004-03-31
3	2985	8135	1	2004-03-31
4	2985	2361	2	2004-03-31
5	2985	2118	3	2004-03-31
1	2986	7815	1	2004-03-19
1	2987	4572	3	2004-03-05
2	2987	5945	3	2004-03-05
3	2987	7884	3	2004-03-05
4	2987	8425	3	2004-03-05
5	2987	9715	1	2004-03-05
6	2987	2934	1	2004-03-05
1	2988	4846	2	2004-03-06
1	2989	8241	3	2004-03-15
1	2990	5273	3	2004-03-03
2	2990	8231	3	2004-03-03
3	2990	4672	2	2004-03-03
1	2991	432	1	2004-03-24
2	2991	7512	2	2004-03-24
3	2991	1260	3	2004-03-24
4	2991	5984	1	2004-03-24
5	2991	9415	1	2004-03-24
6	2991	6416	2	2004-03-24
1	2992	9606	2	2004-03-25
2	2992	2087	1	2004-03-25
3	2992	7960	3	2004-03-25
4	2992	7632	2	2004-03-25
5	2992	7204	1	2004-03-25
6	2992	366	2	2004-03-25
1	2993	3073	3	2004-03-16
2	2993	8655	2	2004-03-16
3	2993	7454	2	2004-03-16
4	2993	6990	3	2004-03-16
5	2993	5467	2	2004-03-16
1	2994	9291	1	2004-03-03
2	2994	1112	1	2004-03-03
3	2994	3573	3	2004-03-03
4	2994	8737	1	2004-03-03
5	2994	5262	2	2004-03-03
1	2995	7489	1	2004-03-11
2	2995	3652	1	2004-03-11
3	2995	9207	1	2004-03-11
4	2995	4894	2	2004-03-11
5	2995	6945	1	2004-03-11
6	2995	3529	1	2004-03-11
7	2995	5289	2	2004-03-11
8	2995	5670	3	2004-03-11
1	2996	6338	2	2004-03-31
1	2997	1015	3	2004-03-01
2	2997	1036	1	2004-03-01
3	2997	7995	3	2004-03-01
4	2997	2765	1	2004-03-01
5	2997	9086	1	2004-03-01
1	2998	5864	1	2004-03-13
1	2999	9669	2	2004-03-11
2	2999	3939	1	2004-03-11
3	2999	7633	1	2004-03-11
4	2999	5940	3	2004-03-11
5	2999	5351	1	2004-03-11
6	2999	3188	2	2004-03-11
7	2999	1696	2	2004-03-11
8	2999	7983	3	2004-03-11
9	2999	2748	1	2004-03-11
1	3000	5813	1	2004-03-05
2	3000	6185	1	2004-03-05
3	3000	3509	3	2004-03-05
4	3000	2828	1	2004-03-05
5	3000	8471	1	2004-03-05
1	3001	9972	3	2004-04-30
2	3001	3979	3	2004-04-30
1	3002	8151	2	2004-04-08
2	3002	8161	2	2004-04-08
3	3002	5191	2	2004-04-08
4	3002	4900	3	2004-04-08
5	3002	1942	1	2004-04-08
6	3002	7829	3	2004-04-08
7	3002	9029	2	2004-04-08
8	3002	5604	3	2004-04-08
1	3003	15	2	2004-04-14
2	3003	5458	3	2004-04-14
3	3003	1266	3	2004-04-14
4	3003	8393	2	2004-04-14
1	3004	5820	1	2004-04-16
2	3004	7032	1	2004-04-16
3	3004	6455	1	2004-04-16
4	3004	8548	3	2004-04-16
1	3005	2414	1	2004-04-14
2	3005	371	3	2004-04-14
3	3005	5613	3	2004-04-14
4	3005	1073	2	2004-04-14
1	3006	5968	2	2004-04-07
2	3006	7457	1	2004-04-07
3	3006	6252	3	2004-04-07
4	3006	4528	1	2004-04-07
1	3007	3490	1	2004-04-02
2	3007	5237	3	2004-04-02
3	3007	8005	1	2004-04-02
4	3007	1654	1	2004-04-02
5	3007	3239	1	2004-04-02
6	3007	7263	3	2004-04-02
7	3007	9739	3	2004-04-02
1	3008	5603	1	2004-04-14
1	3009	2900	2	2004-04-13
1	3010	128	1	2004-04-08
2	3010	7129	2	2004-04-08
3	3010	9639	2	2004-04-08
4	3010	6800	1	2004-04-08
5	3010	5550	1	2004-04-08
1	3011	1148	2	2004-04-10
2	3011	5092	2	2004-04-10
3	3011	3459	1	2004-04-10
1	3012	7904	2	2004-04-21
2	3012	5382	1	2004-04-21
3	3012	9940	2	2004-04-21
4	3012	5823	1	2004-04-21
5	3012	5054	1	2004-04-21
6	3012	5432	2	2004-04-21
7	3012	8083	1	2004-04-21
8	3012	5983	2	2004-04-21
1	3013	2353	3	2004-04-07
2	3013	4525	3	2004-04-07
1	3014	5538	1	2004-04-11
1	3015	3764	3	2004-04-28
2	3015	8154	3	2004-04-28
3	3015	8553	1	2004-04-28
4	3015	2536	2	2004-04-28
5	3015	7899	1	2004-04-28
1	3016	3180	1	2004-04-19
2	3016	9642	2	2004-04-19
3	3016	8288	2	2004-04-19
4	3016	2977	1	2004-04-19
5	3016	2148	1	2004-04-19
6	3016	2343	3	2004-04-19
7	3016	3007	1	2004-04-19
8	3016	1126	1	2004-04-19
1	3017	4474	3	2004-04-19
2	3017	7685	3	2004-04-19
3	3017	2572	2	2004-04-19
4	3017	7628	3	2004-04-19
5	3017	9464	1	2004-04-19
1	3018	8176	1	2004-04-22
2	3018	1077	1	2004-04-22
3	3018	2752	1	2004-04-22
4	3018	2267	2	2004-04-22
5	3018	910	2	2004-04-22
6	3018	6737	1	2004-04-22
7	3018	6825	1	2004-04-22
1	3019	5449	2	2004-04-21
2	3019	8407	3	2004-04-21
1	3020	7912	2	2004-04-03
1	3021	1344	1	2004-04-09
1	3022	9191	2	2004-04-07
2	3022	9778	2	2004-04-07
3	3022	8231	2	2004-04-07
4	3022	8988	2	2004-04-07
5	3022	3462	2	2004-04-07
1	3023	6929	1	2004-04-20
2	3023	994	2	2004-04-20
3	3023	2821	3	2004-04-20
4	3023	7811	2	2004-04-20
5	3023	9389	3	2004-04-20
1	3024	4829	2	2004-04-21
2	3024	3563	2	2004-04-21
3	3024	2343	2	2004-04-21
4	3024	9946	1	2004-04-21
5	3024	9941	3	2004-04-21
6	3024	5728	2	2004-04-21
7	3024	5458	1	2004-04-21
8	3024	2312	3	2004-04-21
9	3024	7239	3	2004-04-21
1	3025	7137	1	2004-04-30
2	3025	8310	2	2004-04-30
3	3025	9583	2	2004-04-30
1	3026	6590	3	2004-04-22
2	3026	6104	3	2004-04-22
1	3027	4981	2	2004-04-04
1	3028	7644	2	2004-04-14
2	3028	5984	3	2004-04-14
3	3028	2983	3	2004-04-14
4	3028	9978	1	2004-04-14
5	3028	9745	3	2004-04-14
6	3028	6644	3	2004-04-14
7	3028	3417	2	2004-04-14
1	3029	5353	1	2004-04-30
2	3029	5292	2	2004-04-30
3	3029	8138	2	2004-04-30
4	3029	7472	1	2004-04-30
5	3029	30	1	2004-04-30
6	3029	3557	3	2004-04-30
1	3030	8601	2	2004-04-26
2	3030	3588	3	2004-04-26
3	3030	5394	1	2004-04-26
4	3030	6866	1	2004-04-26
5	3030	2659	1	2004-04-26
1	3031	8788	1	2004-04-18
2	3031	4012	2	2004-04-18
1	3032	5268	3	2004-04-30
2	3032	9054	3	2004-04-30
3	3032	6446	3	2004-04-30
4	3032	24	3	2004-04-30
5	3032	2328	3	2004-04-30
6	3032	4014	2	2004-04-30
7	3032	7202	3	2004-04-30
1	3033	4348	3	2004-04-28
2	3033	4334	1	2004-04-28
1	3034	7200	2	2004-04-28
2	3034	5463	2	2004-04-28
3	3034	2301	1	2004-04-28
1	3035	9053	3	2004-04-15
2	3035	163	1	2004-04-15
1	3036	3583	2	2004-04-25
2	3036	9468	2	2004-04-25
3	3036	8447	2	2004-04-25
4	3036	2405	1	2004-04-25
5	3036	6049	1	2004-04-25
1	3037	6671	1	2004-04-18
2	3037	9174	3	2004-04-18
3	3037	1212	2	2004-04-18
1	3038	342	2	2004-04-01
2	3038	758	3	2004-04-01
3	3038	9915	3	2004-04-01
4	3038	3943	2	2004-04-01
5	3038	4594	2	2004-04-01
6	3038	8522	1	2004-04-01
7	3038	7227	1	2004-04-01
8	3038	5819	1	2004-04-01
9	3038	2632	1	2004-04-01
1	3039	8134	2	2004-04-15
2	3039	438	3	2004-04-15
1	3040	141	1	2004-04-25
2	3040	9457	1	2004-04-25
3	3040	8992	3	2004-04-25
4	3040	8951	1	2004-04-25
1	3041	6584	2	2004-04-09
2	3041	2314	1	2004-04-09
1	3042	2597	3	2004-04-21
2	3042	3109	1	2004-04-21
1	3043	4309	1	2004-04-09
1	3044	5348	3	2004-04-15
2	3044	3618	2	2004-04-15
3	3044	2558	2	2004-04-15
4	3044	7843	3	2004-04-15
1	3045	6829	3	2004-04-24
1	3046	9889	2	2004-04-16
2	3046	8458	1	2004-04-16
3	3046	7618	3	2004-04-16
4	3046	3890	1	2004-04-16
5	3046	8715	3	2004-04-16
6	3046	6376	3	2004-04-16
7	3046	2927	1	2004-04-16
1	3047	3029	2	2004-04-27
2	3047	431	1	2004-04-27
1	3048	2225	2	2004-04-25
2	3048	6067	1	2004-04-25
3	3048	3948	2	2004-04-25
4	3048	7259	1	2004-04-25
5	3048	8773	2	2004-04-25
1	3049	1342	1	2004-04-03
2	3049	8999	2	2004-04-03
3	3049	4900	3	2004-04-03
4	3049	812	1	2004-04-03
5	3049	9498	2	2004-04-03
6	3049	4784	3	2004-04-03
7	3049	4741	1	2004-04-03
8	3049	2832	2	2004-04-03
9	3049	8190	2	2004-04-03
1	3050	211	2	2004-04-07
2	3050	8402	3	2004-04-07
3	3050	377	3	2004-04-07
4	3050	1645	3	2004-04-07
5	3050	8991	1	2004-04-07
6	3050	356	3	2004-04-07
1	3051	6177	2	2004-04-22
2	3051	1904	1	2004-04-22
3	3051	5385	2	2004-04-22
4	3051	4033	3	2004-04-22
5	3051	2473	1	2004-04-22
6	3051	3272	2	2004-04-22
7	3051	6478	1	2004-04-22
8	3051	516	3	2004-04-22
1	3052	8256	3	2004-04-22
2	3052	4571	3	2004-04-22
3	3052	300	2	2004-04-22
4	3052	5235	3	2004-04-22
5	3052	182	1	2004-04-22
6	3052	5618	2	2004-04-22
7	3052	6650	3	2004-04-22
1	3053	250	2	2004-04-22
2	3053	3572	2	2004-04-22
1	3054	6737	1	2004-04-04
2	3054	591	1	2004-04-04
1	3055	6092	1	2004-04-29
2	3055	8942	1	2004-04-29
3	3055	7575	3	2004-04-29
4	3055	2519	1	2004-04-29
1	3056	1202	2	2004-04-17
2	3056	4147	1	2004-04-17
3	3056	1516	3	2004-04-17
1	3057	4348	2	2004-04-15
1	3058	3784	2	2004-04-07
2	3058	5522	3	2004-04-07
1	3059	3586	2	2004-04-20
2	3059	7421	3	2004-04-20
3	3059	2887	3	2004-04-20
4	3059	1864	2	2004-04-20
1	3060	3728	1	2004-04-10
2	3060	7201	1	2004-04-10
3	3060	522	1	2004-04-10
4	3060	5999	1	2004-04-10
5	3060	6486	1	2004-04-10
1	3061	144	2	2004-04-13
2	3061	4074	1	2004-04-13
3	3061	425	3	2004-04-13
4	3061	5063	3	2004-04-13
5	3061	6726	3	2004-04-13
6	3061	5980	3	2004-04-13
7	3061	2038	3	2004-04-13
8	3061	4599	3	2004-04-13
9	3061	3518	3	2004-04-13
1	3062	2267	2	2004-04-25
2	3062	1194	3	2004-04-25
3	3062	8729	2	2004-04-25
4	3062	9021	3	2004-04-25
5	3062	4893	3	2004-04-25
6	3062	4467	3	2004-04-25
7	3062	508	2	2004-04-25
8	3062	6626	2	2004-04-25
1	3063	1941	2	2004-04-09
2	3063	7707	2	2004-04-09
3	3063	3135	1	2004-04-09
4	3063	4866	1	2004-04-09
5	3063	1942	2	2004-04-09
6	3063	9836	2	2004-04-09
7	3063	507	1	2004-04-09
8	3063	2960	3	2004-04-09
1	3064	1145	1	2004-04-19
2	3064	172	1	2004-04-19
1	3065	149	1	2004-04-21
2	3065	8316	1	2004-04-21
3	3065	6299	2	2004-04-21
4	3065	8629	3	2004-04-21
5	3065	7246	2	2004-04-21
6	3065	657	3	2004-04-21
7	3065	8181	1	2004-04-21
8	3065	3395	3	2004-04-21
9	3065	1521	2	2004-04-21
1	3066	9037	3	2004-04-24
2	3066	7400	3	2004-04-24
3	3066	1132	2	2004-04-24
4	3066	6005	3	2004-04-24
5	3066	3863	2	2004-04-24
1	3067	8201	3	2004-04-28
2	3067	4826	2	2004-04-28
3	3067	365	2	2004-04-28
4	3067	4633	3	2004-04-28
5	3067	5974	3	2004-04-28
1	3068	5326	1	2004-04-22
2	3068	584	2	2004-04-22
3	3068	2194	3	2004-04-22
4	3068	3571	1	2004-04-22
5	3068	2247	3	2004-04-22
1	3069	8288	2	2004-04-06
1	3070	1933	1	2004-04-19
1	3071	4591	3	2004-04-20
2	3071	9942	3	2004-04-20
3	3071	2139	2	2004-04-20
1	3072	705	1	2004-04-06
2	3072	7204	1	2004-04-06
3	3072	2775	3	2004-04-06
4	3072	9060	3	2004-04-06
1	3073	3835	1	2004-04-29
2	3073	6816	2	2004-04-29
3	3073	4520	1	2004-04-29
4	3073	2332	2	2004-04-29
5	3073	5738	3	2004-04-29
6	3073	1253	2	2004-04-29
1	3074	6113	1	2004-04-18
2	3074	1458	3	2004-04-18
3	3074	3776	3	2004-04-18
4	3074	9768	2	2004-04-18
5	3074	7543	3	2004-04-18
6	3074	5054	3	2004-04-18
7	3074	6174	3	2004-04-18
1	3075	5774	2	2004-04-10
2	3075	3126	3	2004-04-10
3	3075	9630	3	2004-04-10
4	3075	5028	1	2004-04-10
5	3075	4543	1	2004-04-10
6	3075	4274	2	2004-04-10
7	3075	8500	1	2004-04-10
8	3075	6066	3	2004-04-10
9	3075	7203	3	2004-04-10
1	3076	5796	1	2004-04-26
2	3076	3359	1	2004-04-26
3	3076	8971	2	2004-04-26
4	3076	1977	3	2004-04-26
5	3076	6216	3	2004-04-26
6	3076	5172	3	2004-04-26
1	3077	5685	1	2004-04-18
1	3078	344	2	2004-04-06
1	3079	4516	1	2004-04-01
2	3079	5040	1	2004-04-01
3	3079	1978	3	2004-04-01
4	3079	2281	1	2004-04-01
5	3079	4779	2	2004-04-01
6	3079	761	1	2004-04-01
7	3079	2008	2	2004-04-01
8	3079	335	3	2004-04-01
1	3080	1287	1	2004-04-03
2	3080	6377	3	2004-04-03
3	3080	854	3	2004-04-03
4	3080	3824	1	2004-04-03
5	3080	4267	3	2004-04-03
6	3080	9994	3	2004-04-03
1	3081	3432	1	2004-04-26
1	3082	9204	3	2004-04-05
2	3082	8119	3	2004-04-05
1	3083	5271	3	2004-04-17
2	3083	4796	1	2004-04-17
3	3083	8885	2	2004-04-17
4	3083	8367	1	2004-04-17
1	3084	1415	3	2004-04-21
2	3084	1791	1	2004-04-21
3	3084	9651	2	2004-04-21
4	3084	1880	1	2004-04-21
5	3084	3432	3	2004-04-21
6	3084	3262	1	2004-04-21
7	3084	5146	1	2004-04-21
1	3085	4892	2	2004-04-07
1	3086	5337	2	2004-04-29
2	3086	1205	1	2004-04-29
3	3086	8149	1	2004-04-29
4	3086	8858	3	2004-04-29
5	3086	1053	1	2004-04-29
6	3086	70	1	2004-04-29
7	3086	5870	1	2004-04-29
8	3086	1779	3	2004-04-29
1	3087	6421	2	2004-04-29
2	3087	5251	2	2004-04-29
3	3087	4357	1	2004-04-29
4	3087	2155	2	2004-04-29
5	3087	9830	3	2004-04-29
1	3088	7267	1	2004-04-08
2	3088	5549	2	2004-04-08
3	3088	2531	2	2004-04-08
4	3088	6773	1	2004-04-08
1	3089	1944	2	2004-04-22
2	3089	4124	2	2004-04-22
3	3089	8613	1	2004-04-22
4	3089	7988	2	2004-04-22
5	3089	7196	1	2004-04-22
6	3089	4004	3	2004-04-22
7	3089	6313	2	2004-04-22
8	3089	8654	3	2004-04-22
9	3089	9000	2	2004-04-22
1	3090	2391	3	2004-04-08
2	3090	4596	3	2004-04-08
3	3090	1571	1	2004-04-08
4	3090	1806	2	2004-04-08
5	3090	982	2	2004-04-08
6	3090	129	2	2004-04-08
7	3090	7629	3	2004-04-08
8	3090	5649	2	2004-04-08
1	3091	2195	2	2004-04-08
2	3091	440	1	2004-04-08
3	3091	3050	3	2004-04-08
4	3091	4321	2	2004-04-08
5	3091	5706	1	2004-04-08
6	3091	3491	3	2004-04-08
1	3092	9985	3	2004-04-30
2	3092	7423	1	2004-04-30
1	3093	6292	1	2004-04-09
1	3094	5500	3	2004-04-19
2	3094	8295	2	2004-04-19
3	3094	7605	1	2004-04-19
4	3094	5379	1	2004-04-19
1	3095	9181	1	2004-04-21
1	3096	5506	1	2004-04-26
2	3096	9367	3	2004-04-26
3	3096	8694	2	2004-04-26
4	3096	8766	2	2004-04-26
5	3096	7157	2	2004-04-26
6	3096	3878	1	2004-04-26
7	3096	8848	3	2004-04-26
8	3096	8476	3	2004-04-26
1	3097	8006	2	2004-04-16
1	3098	3109	2	2004-04-06
1	3099	7970	1	2004-04-23
2	3099	1228	2	2004-04-23
3	3099	7276	3	2004-04-23
1	3100	6151	2	2004-04-05
2	3100	4903	2	2004-04-05
3	3100	807	1	2004-04-05
4	3100	707	3	2004-04-05
5	3100	917	3	2004-04-05
1	3101	3657	1	2004-04-14
1	3102	3964	3	2004-04-14
2	3102	8655	2	2004-04-14
3	3102	3972	2	2004-04-14
4	3102	5184	2	2004-04-14
5	3102	362	1	2004-04-14
6	3102	1144	2	2004-04-14
7	3102	3668	2	2004-04-14
1	3103	3768	3	2004-04-04
2	3103	558	3	2004-04-04
1	3104	2473	1	2004-04-30
2	3104	4592	1	2004-04-30
3	3104	9822	3	2004-04-30
4	3104	9120	3	2004-04-30
1	3105	8710	2	2004-04-12
2	3105	8932	3	2004-04-12
3	3105	1279	1	2004-04-12
4	3105	5899	1	2004-04-12
5	3105	7075	1	2004-04-12
6	3105	4262	1	2004-04-12
7	3105	9347	2	2004-04-12
8	3105	9228	3	2004-04-12
9	3105	4779	3	2004-04-12
1	3106	9063	1	2004-04-09
2	3106	5906	3	2004-04-09
3	3106	9190	3	2004-04-09
4	3106	1274	2	2004-04-09
5	3106	8581	3	2004-04-09
6	3106	8364	3	2004-04-09
7	3106	9835	3	2004-04-09
1	3107	7898	2	2004-04-01
2	3107	8029	3	2004-04-01
3	3107	1138	3	2004-04-01
4	3107	6470	2	2004-04-01
5	3107	5143	3	2004-04-01
6	3107	3168	2	2004-04-01
7	3107	6580	1	2004-04-01
1	3108	2136	1	2004-04-21
2	3108	9534	1	2004-04-21
3	3108	1668	3	2004-04-21
4	3108	8230	1	2004-04-21
5	3108	7539	3	2004-04-21
6	3108	7236	3	2004-04-21
1	3109	2378	3	2004-04-17
2	3109	812	3	2004-04-17
3	3109	2969	2	2004-04-17
4	3109	8076	2	2004-04-17
1	3110	7140	3	2004-04-06
2	3110	4674	3	2004-04-06
3	3110	463	2	2004-04-06
4	3110	9992	1	2004-04-06
5	3110	2104	3	2004-04-06
6	3110	3633	3	2004-04-06
7	3110	6562	1	2004-04-06
8	3110	9239	1	2004-04-06
1	3111	2207	2	2004-04-19
2	3111	7226	2	2004-04-19
3	3111	2412	2	2004-04-19
4	3111	1311	2	2004-04-19
5	3111	9956	3	2004-04-19
6	3111	3136	3	2004-04-19
7	3111	8454	3	2004-04-19
8	3111	6370	3	2004-04-19
1	3112	4582	2	2004-04-07
2	3112	3762	1	2004-04-07
3	3112	5545	1	2004-04-07
4	3112	3233	1	2004-04-07
1	3113	5335	3	2004-04-25
1	3114	2146	1	2004-04-17
2	3114	6525	2	2004-04-17
3	3114	9503	2	2004-04-17
4	3114	3089	2	2004-04-17
5	3114	3893	2	2004-04-17
6	3114	2233	2	2004-04-17
7	3114	9225	3	2004-04-17
1	3115	5987	1	2004-04-29
2	3115	6707	2	2004-04-29
3	3115	67	2	2004-04-29
4	3115	4504	2	2004-04-29
5	3115	3782	1	2004-04-29
1	3116	8642	2	2004-04-10
2	3116	573	3	2004-04-10
3	3116	8390	2	2004-04-10
4	3116	4016	1	2004-04-10
5	3116	8766	2	2004-04-10
1	3117	977	1	2004-04-22
2	3117	1996	3	2004-04-22
3	3117	2208	3	2004-04-22
4	3117	1106	1	2004-04-22
5	3117	5333	2	2004-04-22
6	3117	7675	3	2004-04-22
7	3117	5649	1	2004-04-22
1	3118	5948	3	2004-04-17
2	3118	2133	2	2004-04-17
3	3118	347	2	2004-04-17
4	3118	6619	3	2004-04-17
1	3119	674	3	2004-04-08
2	3119	6477	1	2004-04-08
3	3119	5043	3	2004-04-08
4	3119	1372	2	2004-04-08
5	3119	957	3	2004-04-08
1	3120	9452	1	2004-04-06
2	3120	9940	2	2004-04-06
3	3120	5156	2	2004-04-06
4	3120	2250	3	2004-04-06
5	3120	224	1	2004-04-06
6	3120	3437	3	2004-04-06
7	3120	1709	2	2004-04-06
1	3121	6890	3	2004-04-03
2	3121	4024	1	2004-04-03
1	3122	2099	3	2004-04-20
2	3122	6038	3	2004-04-20
3	3122	7238	2	2004-04-20
4	3122	9084	3	2004-04-20
5	3122	1054	2	2004-04-20
6	3122	3064	1	2004-04-20
7	3122	1529	1	2004-04-20
1	3123	798	1	2004-04-18
2	3123	6419	1	2004-04-18
3	3123	2163	1	2004-04-18
4	3123	9855	2	2004-04-18
5	3123	5240	2	2004-04-18
6	3123	1581	1	2004-04-18
7	3123	3711	2	2004-04-18
1	3124	5237	1	2004-04-10
1	3125	9594	2	2004-04-23
1	3126	3101	1	2004-04-12
2	3126	4853	3	2004-04-12
3	3126	4299	3	2004-04-12
4	3126	2828	2	2004-04-12
1	3127	1385	2	2004-04-10
2	3127	8460	2	2004-04-10
3	3127	3915	1	2004-04-10
4	3127	4926	3	2004-04-10
5	3127	735	1	2004-04-10
1	3128	2103	3	2004-04-17
2	3128	526	2	2004-04-17
3	3128	1080	2	2004-04-17
4	3128	5727	2	2004-04-17
5	3128	3147	1	2004-04-17
1	3129	4041	2	2004-04-09
2	3129	928	2	2004-04-09
3	3129	8801	3	2004-04-09
4	3129	9962	1	2004-04-09
5	3129	9442	2	2004-04-09
6	3129	1866	1	2004-04-09
1	3130	2338	3	2004-04-23
1	3131	6490	3	2004-04-23
2	3131	4545	3	2004-04-23
3	3131	7202	3	2004-04-23
4	3131	5610	1	2004-04-23
5	3131	3638	3	2004-04-23
6	3131	6014	2	2004-04-23
7	3131	5076	2	2004-04-23
8	3131	3951	2	2004-04-23
1	3132	3569	3	2004-04-23
2	3132	6700	3	2004-04-23
3	3132	7801	3	2004-04-23
4	3132	7333	2	2004-04-23
5	3132	1900	3	2004-04-23
6	3132	3948	3	2004-04-23
7	3132	5960	3	2004-04-23
8	3132	8025	1	2004-04-23
9	3132	5982	2	2004-04-23
1	3133	4184	3	2004-04-14
1	3134	1526	1	2004-04-17
2	3134	2292	2	2004-04-17
3	3134	624	3	2004-04-17
1	3135	3759	3	2004-04-14
2	3135	608	3	2004-04-14
1	3136	9729	1	2004-04-25
2	3136	9974	2	2004-04-25
3	3136	1798	1	2004-04-25
4	3136	4823	2	2004-04-25
5	3136	1616	1	2004-04-25
6	3136	4115	2	2004-04-25
1	3137	733	3	2004-04-10
2	3137	4372	2	2004-04-10
3	3137	7381	1	2004-04-10
4	3137	7051	1	2004-04-10
5	3137	2327	3	2004-04-10
1	3138	6983	2	2004-04-27
2	3138	7222	3	2004-04-27
3	3138	8222	3	2004-04-27
4	3138	214	1	2004-04-27
5	3138	5001	1	2004-04-27
1	3139	4755	2	2004-04-10
2	3139	1705	2	2004-04-10
3	3139	4131	2	2004-04-10
4	3139	713	1	2004-04-10
5	3139	8475	3	2004-04-10
6	3139	2651	1	2004-04-10
1	3140	6539	3	2004-04-17
2	3140	3597	2	2004-04-17
3	3140	5383	1	2004-04-17
4	3140	2780	2	2004-04-17
5	3140	4862	3	2004-04-17
6	3140	7426	3	2004-04-17
7	3140	6894	2	2004-04-17
8	3140	4420	1	2004-04-17
9	3140	9442	2	2004-04-17
1	3141	5084	1	2004-04-22
2	3141	5610	3	2004-04-22
3	3141	1476	1	2004-04-22
4	3141	9231	1	2004-04-22
5	3141	674	2	2004-04-22
6	3141	1346	2	2004-04-22
7	3141	9529	3	2004-04-22
8	3141	6088	1	2004-04-22
1	3142	9045	3	2004-04-07
2	3142	4016	2	2004-04-07
3	3142	8629	2	2004-04-07
4	3142	9589	2	2004-04-07
5	3142	7029	1	2004-04-07
6	3142	3611	1	2004-04-07
7	3142	2464	3	2004-04-07
8	3142	9846	2	2004-04-07
9	3142	249	3	2004-04-07
1	3143	5192	2	2004-04-21
2	3143	4932	1	2004-04-21
3	3143	6682	3	2004-04-21
4	3143	2228	3	2004-04-21
5	3143	7004	1	2004-04-21
6	3143	3750	1	2004-04-21
7	3143	4738	1	2004-04-21
8	3143	4476	2	2004-04-21
1	3144	3616	3	2004-04-25
2	3144	971	2	2004-04-25
1	3145	2141	3	2004-04-08
2	3145	7581	3	2004-04-08
3	3145	1755	1	2004-04-08
4	3145	8612	3	2004-04-08
5	3145	9766	1	2004-04-08
6	3145	5205	3	2004-04-08
7	3145	2113	3	2004-04-08
8	3145	7788	3	2004-04-08
9	3145	1332	1	2004-04-08
1	3146	1223	3	2004-04-04
2	3146	5870	1	2004-04-04
3	3146	845	3	2004-04-04
4	3146	3412	2	2004-04-04
5	3146	7764	2	2004-04-04
6	3146	763	2	2004-04-04
7	3146	2885	1	2004-04-04
1	3147	2335	2	2004-04-24
2	3147	4390	2	2004-04-24
3	3147	5111	1	2004-04-24
4	3147	1297	2	2004-04-24
5	3147	4441	1	2004-04-24
6	3147	5914	3	2004-04-24
7	3147	9765	3	2004-04-24
1	3148	4021	1	2004-04-17
2	3148	9817	1	2004-04-17
3	3148	8293	1	2004-04-17
4	3148	7128	1	2004-04-17
5	3148	3095	2	2004-04-17
6	3148	2672	2	2004-04-17
1	3149	9454	2	2004-04-08
2	3149	9169	1	2004-04-08
3	3149	1756	2	2004-04-08
4	3149	3224	3	2004-04-08
5	3149	1817	1	2004-04-08
6	3149	4805	3	2004-04-08
7	3149	8621	2	2004-04-08
1	3150	4426	2	2004-04-12
2	3150	4238	1	2004-04-12
3	3150	6343	3	2004-04-12
4	3150	6535	3	2004-04-12
1	3151	6129	2	2004-04-05
2	3151	6899	2	2004-04-05
1	3152	6323	1	2004-04-13
2	3152	437	1	2004-04-13
3	3152	8129	3	2004-04-13
4	3152	5261	1	2004-04-13
5	3152	1699	1	2004-04-13
6	3152	5631	2	2004-04-13
7	3152	7301	3	2004-04-13
1	3153	2658	3	2004-04-24
2	3153	3348	3	2004-04-24
3	3153	165	3	2004-04-24
4	3153	155	3	2004-04-24
1	3154	1829	1	2004-04-15
2	3154	4399	1	2004-04-15
3	3154	3167	1	2004-04-15
4	3154	1323	3	2004-04-15
1	3155	9145	3	2004-04-14
1	3156	1032	2	2004-04-30
2	3156	5780	2	2004-04-30
3	3156	843	2	2004-04-30
4	3156	3856	1	2004-04-30
5	3156	3008	3	2004-04-30
6	3156	5377	3	2004-04-30
7	3156	2305	3	2004-04-30
1	3157	9231	1	2004-04-03
2	3157	2356	2	2004-04-03
3	3157	3814	1	2004-04-03
4	3157	3858	1	2004-04-03
1	3158	1054	1	2004-04-03
2	3158	6449	3	2004-04-03
3	3158	5191	3	2004-04-03
1	3159	7674	2	2004-04-09
2	3159	4509	3	2004-04-09
3	3159	869	2	2004-04-09
4	3159	6682	1	2004-04-09
5	3159	9200	2	2004-04-09
6	3159	1132	1	2004-04-09
1	3160	7903	2	2004-04-29
2	3160	7353	3	2004-04-29
3	3160	7537	3	2004-04-29
4	3160	8493	2	2004-04-29
1	3161	2729	3	2004-04-16
2	3161	3801	1	2004-04-16
3	3161	3227	3	2004-04-16
4	3161	380	2	2004-04-16
5	3161	3580	3	2004-04-16
6	3161	4435	1	2004-04-16
7	3161	2973	2	2004-04-16
8	3161	4335	1	2004-04-16
1	3162	4058	2	2004-04-02
2	3162	6095	1	2004-04-02
3	3162	1868	2	2004-04-02
4	3162	5578	3	2004-04-02
5	3162	8270	3	2004-04-02
6	3162	5124	1	2004-04-02
7	3162	6416	3	2004-04-02
8	3162	1400	3	2004-04-02
1	3163	8840	3	2004-04-22
1	3164	4425	2	2004-04-11
2	3164	6733	1	2004-04-11
3	3164	2660	1	2004-04-11
4	3164	3997	3	2004-04-11
5	3164	2384	2	2004-04-11
6	3164	3342	3	2004-04-11
7	3164	2972	1	2004-04-11
8	3164	4815	3	2004-04-11
1	3165	871	2	2004-04-08
2	3165	5786	2	2004-04-08
3	3165	5064	2	2004-04-08
4	3165	2778	3	2004-04-08
1	3166	761	1	2004-04-20
1	3167	2176	2	2004-04-05
2	3167	1258	2	2004-04-05
3	3167	4448	2	2004-04-05
4	3167	7127	3	2004-04-05
5	3167	2323	3	2004-04-05
1	3168	3592	3	2004-04-02
2	3168	5970	3	2004-04-02
1	3169	5262	2	2004-04-13
1	3170	9443	1	2004-04-05
2	3170	8245	1	2004-04-05
3	3170	7792	3	2004-04-05
1	3171	1501	2	2004-04-22
2	3171	3995	1	2004-04-22
3	3171	5395	3	2004-04-22
4	3171	3355	3	2004-04-22
1	3172	8071	2	2004-04-22
2	3172	2009	1	2004-04-22
1	3173	6315	3	2004-04-27
2	3173	7350	2	2004-04-27
3	3173	415	2	2004-04-27
4	3173	4062	3	2004-04-27
5	3173	7381	3	2004-04-27
6	3173	1810	3	2004-04-27
1	3174	3541	2	2004-04-12
2	3174	8226	1	2004-04-12
3	3174	3552	2	2004-04-12
4	3174	2222	1	2004-04-12
5	3174	817	2	2004-04-12
6	3174	4955	3	2004-04-12
7	3174	7694	2	2004-04-12
8	3174	5702	2	2004-04-12
9	3174	3106	1	2004-04-12
1	3175	1070	2	2004-04-26
2	3175	421	1	2004-04-26
3	3175	4455	2	2004-04-26
1	3176	9556	1	2004-04-27
2	3176	3028	1	2004-04-27
3	3176	7598	2	2004-04-27
1	3177	8072	3	2004-04-15
2	3177	3992	2	2004-04-15
3	3177	1181	3	2004-04-15
4	3177	6825	3	2004-04-15
5	3177	619	2	2004-04-15
6	3177	2377	1	2004-04-15
7	3177	591	1	2004-04-15
8	3177	4566	2	2004-04-15
9	3177	7063	1	2004-04-15
1	3178	2300	3	2004-04-02
2	3178	3035	3	2004-04-02
3	3178	3748	3	2004-04-02
4	3178	8311	1	2004-04-02
5	3178	7447	2	2004-04-02
6	3178	401	1	2004-04-02
7	3178	156	1	2004-04-02
8	3178	8537	3	2004-04-02
9	3178	1329	3	2004-04-02
1	3179	6502	2	2004-04-06
2	3179	7635	2	2004-04-06
3	3179	8657	3	2004-04-06
1	3180	2628	1	2004-04-13
2	3180	6329	2	2004-04-13
3	3180	8735	2	2004-04-13
4	3180	9603	2	2004-04-13
5	3180	1022	1	2004-04-13
6	3180	7621	1	2004-04-13
1	3181	5312	1	2004-04-05
2	3181	6619	2	2004-04-05
3	3181	2746	1	2004-04-05
1	3182	8388	1	2004-04-05
1	3183	7295	2	2004-04-14
2	3183	3350	2	2004-04-14
3	3183	8215	1	2004-04-14
4	3183	2210	3	2004-04-14
5	3183	2955	3	2004-04-14
6	3183	413	2	2004-04-14
7	3183	5987	3	2004-04-14
1	3184	7452	1	2004-04-23
2	3184	7190	3	2004-04-23
3	3184	1852	2	2004-04-23
4	3184	9234	1	2004-04-23
1	3185	556	2	2004-04-15
2	3185	5515	2	2004-04-15
1	3186	2965	3	2004-04-30
2	3186	1925	2	2004-04-30
1	3187	9208	1	2004-04-14
2	3187	5873	2	2004-04-14
1	3188	6937	2	2004-04-07
2	3188	4236	1	2004-04-07
3	3188	8488	1	2004-04-07
4	3188	3565	3	2004-04-07
1	3189	2809	3	2004-04-14
2	3189	6636	2	2004-04-14
3	3189	9618	3	2004-04-14
4	3189	9151	2	2004-04-14
5	3189	6470	1	2004-04-14
1	3190	2337	2	2004-04-18
2	3190	4707	3	2004-04-18
1	3191	3270	1	2004-04-24
2	3191	2948	3	2004-04-24
1	3192	2144	3	2004-04-02
2	3192	3204	3	2004-04-02
3	3192	4496	1	2004-04-02
4	3192	7339	2	2004-04-02
1	3193	9486	2	2004-04-21
2	3193	4206	1	2004-04-21
3	3193	432	3	2004-04-21
1	3194	493	2	2004-04-30
2	3194	4156	2	2004-04-30
3	3194	660	2	2004-04-30
1	3195	5297	1	2004-04-04
2	3195	1966	3	2004-04-04
3	3195	4026	3	2004-04-04
1	3196	3377	1	2004-04-11
2	3196	4696	3	2004-04-11
3	3196	4419	2	2004-04-11
4	3196	6495	2	2004-04-11
5	3196	3471	3	2004-04-11
6	3196	7001	2	2004-04-11
7	3196	876	1	2004-04-11
8	3196	7404	1	2004-04-11
1	3197	1633	2	2004-04-18
2	3197	4967	2	2004-04-18
3	3197	3197	3	2004-04-18
4	3197	2901	2	2004-04-18
1	3198	8609	3	2004-04-30
2	3198	767	1	2004-04-30
3	3198	4637	3	2004-04-30
1	3199	2071	2	2004-04-22
2	3199	5434	3	2004-04-22
3	3199	6723	1	2004-04-22
4	3199	7920	2	2004-04-22
1	3200	3150	1	2004-04-15
2	3200	8914	2	2004-04-15
3	3200	8068	3	2004-04-15
4	3200	2063	1	2004-04-15
5	3200	1905	1	2004-04-15
6	3200	2393	1	2004-04-15
7	3200	3698	3	2004-04-15
8	3200	9932	1	2004-04-15
9	3200	5137	2	2004-04-15
1	3201	6681	2	2004-04-16
1	3202	4152	3	2004-04-06
2	3202	6755	3	2004-04-06
3	3202	656	2	2004-04-06
4	3202	3352	3	2004-04-06
5	3202	4389	2	2004-04-06
6	3202	1606	2	2004-04-06
7	3202	6085	2	2004-04-06
1	3203	756	2	2004-04-27
2	3203	3139	2	2004-04-27
3	3203	3371	1	2004-04-27
4	3203	6692	1	2004-04-27
5	3203	8721	3	2004-04-27
6	3203	4651	3	2004-04-27
7	3203	5402	3	2004-04-27
8	3203	8927	1	2004-04-27
9	3203	6104	3	2004-04-27
1	3204	4869	3	2004-04-24
2	3204	8504	1	2004-04-24
1	3205	6363	1	2004-04-12
2	3205	1100	3	2004-04-12
3	3205	7497	2	2004-04-12
4	3205	2069	2	2004-04-12
5	3205	4522	1	2004-04-12
1	3206	7976	3	2004-04-09
2	3206	314	2	2004-04-09
3	3206	9003	3	2004-04-09
4	3206	3534	3	2004-04-09
5	3206	348	3	2004-04-09
6	3206	7217	3	2004-04-09
7	3206	9355	1	2004-04-09
8	3206	6319	1	2004-04-09
1	3207	2181	3	2004-04-19
2	3207	1632	2	2004-04-19
3	3207	3262	2	2004-04-19
4	3207	5040	2	2004-04-19
5	3207	5327	2	2004-04-19
6	3207	4176	1	2004-04-19
7	3207	4955	2	2004-04-19
1	3208	1264	1	2004-04-23
1	3209	9606	3	2004-04-28
2	3209	8759	2	2004-04-28
3	3209	822	1	2004-04-28
4	3209	2828	1	2004-04-28
5	3209	9410	2	2004-04-28
6	3209	7252	1	2004-04-28
7	3209	614	1	2004-04-28
8	3209	8689	2	2004-04-28
1	3210	7352	2	2004-04-24
2	3210	6735	3	2004-04-24
3	3210	7538	3	2004-04-24
1	3211	5524	2	2004-04-09
2	3211	2912	2	2004-04-09
3	3211	1751	2	2004-04-09
4	3211	4618	2	2004-04-09
5	3211	6735	2	2004-04-09
1	3212	6278	2	2004-04-28
2	3212	5592	2	2004-04-28
3	3212	8251	2	2004-04-28
4	3212	6881	2	2004-04-28
5	3212	1458	2	2004-04-28
6	3212	5579	3	2004-04-28
7	3212	1614	3	2004-04-28
8	3212	5848	3	2004-04-28
9	3212	3298	1	2004-04-28
1	3213	9942	1	2004-04-13
2	3213	505	3	2004-04-13
3	3213	4296	3	2004-04-13
4	3213	663	1	2004-04-13
5	3213	9195	3	2004-04-13
6	3213	6381	2	2004-04-13
1	3214	233	1	2004-04-04
2	3214	1537	2	2004-04-04
3	3214	73	1	2004-04-04
4	3214	4338	2	2004-04-04
5	3214	1242	3	2004-04-04
6	3214	7292	2	2004-04-04
7	3214	3844	1	2004-04-04
8	3214	1343	2	2004-04-04
1	3215	1391	1	2004-04-10
2	3215	8502	1	2004-04-10
3	3215	8065	2	2004-04-10
4	3215	5372	3	2004-04-10
5	3215	9513	2	2004-04-10
6	3215	7029	3	2004-04-10
7	3215	6071	3	2004-04-10
1	3216	2064	1	2004-04-17
2	3216	7529	3	2004-04-17
3	3216	8374	1	2004-04-17
4	3216	2298	3	2004-04-17
5	3216	5158	2	2004-04-17
6	3216	1565	2	2004-04-17
7	3216	3018	1	2004-04-17
8	3216	6745	1	2004-04-17
9	3216	3540	2	2004-04-17
1	3217	3904	1	2004-04-20
2	3217	5659	3	2004-04-20
3	3217	9509	1	2004-04-20
4	3217	6117	1	2004-04-20
5	3217	1108	3	2004-04-20
6	3217	4181	3	2004-04-20
1	3218	2271	2	2004-04-23
2	3218	5341	2	2004-04-23
3	3218	786	3	2004-04-23
4	3218	6789	3	2004-04-23
5	3218	9878	1	2004-04-23
6	3218	2339	2	2004-04-23
7	3218	9240	2	2004-04-23
8	3218	2192	1	2004-04-23
9	3218	7198	3	2004-04-23
1	3219	7930	1	2004-04-10
2	3219	7414	1	2004-04-10
3	3219	8809	2	2004-04-10
4	3219	4664	3	2004-04-10
5	3219	4780	3	2004-04-10
6	3219	3984	1	2004-04-10
7	3219	768	2	2004-04-10
8	3219	8479	3	2004-04-10
9	3219	2300	3	2004-04-10
1	3220	893	3	2004-04-24
2	3220	267	3	2004-04-24
3	3220	4677	2	2004-04-24
4	3220	4798	2	2004-04-24
5	3220	2618	1	2004-04-24
6	3220	3914	1	2004-04-24
7	3220	4837	1	2004-04-24
1	3221	6434	2	2004-04-15
2	3221	9879	3	2004-04-15
3	3221	294	3	2004-04-15
4	3221	4758	1	2004-04-15
5	3221	6714	1	2004-04-15
6	3221	7232	1	2004-04-15
7	3221	9766	3	2004-04-15
8	3221	8175	1	2004-04-15
9	3221	6216	1	2004-04-15
1	3222	3740	1	2004-04-11
2	3222	6065	3	2004-04-11
3	3222	3228	1	2004-04-11
4	3222	8077	2	2004-04-11
5	3222	802	2	2004-04-11
6	3222	292	1	2004-04-11
1	3223	3178	2	2004-04-06
2	3223	9110	1	2004-04-06
3	3223	7099	3	2004-04-06
4	3223	8534	2	2004-04-06
5	3223	8907	2	2004-04-06
6	3223	8124	1	2004-04-06
1	3224	5222	2	2004-04-18
2	3224	8078	3	2004-04-18
3	3224	5463	2	2004-04-18
4	3224	3217	2	2004-04-18
5	3224	664	2	2004-04-18
6	3224	6946	1	2004-04-18
7	3224	4093	2	2004-04-18
8	3224	8844	3	2004-04-18
9	3224	1735	3	2004-04-18
1	3225	4107	2	2004-04-24
2	3225	962	1	2004-04-24
3	3225	8056	3	2004-04-24
4	3225	6947	2	2004-04-24
5	3225	6224	1	2004-04-24
6	3225	830	2	2004-04-24
1	3226	2558	1	2004-04-02
2	3226	7341	3	2004-04-02
3	3226	3494	1	2004-04-02
4	3226	5487	1	2004-04-02
1	3227	6055	3	2004-04-27
2	3227	2595	1	2004-04-27
3	3227	2850	2	2004-04-27
4	3227	2392	1	2004-04-27
5	3227	280	3	2004-04-27
6	3227	7316	2	2004-04-27
1	3228	4439	1	2004-04-05
2	3228	5954	3	2004-04-05
1	3229	4728	1	2004-04-08
2	3229	8209	2	2004-04-08
3	3229	9207	3	2004-04-08
4	3229	9813	2	2004-04-08
5	3229	5614	1	2004-04-08
6	3229	5422	3	2004-04-08
1	3230	7151	3	2004-04-18
2	3230	2746	3	2004-04-18
3	3230	4830	2	2004-04-18
4	3230	777	3	2004-04-18
5	3230	4809	3	2004-04-18
6	3230	6265	3	2004-04-18
1	3231	4749	1	2004-04-01
2	3231	8182	2	2004-04-01
3	3231	9763	3	2004-04-01
4	3231	9216	2	2004-04-01
5	3231	401	2	2004-04-01
1	3232	2607	3	2004-04-12
2	3232	9894	2	2004-04-12
3	3232	8258	2	2004-04-12
1	3233	5766	1	2004-04-27
2	3233	897	2	2004-04-27
3	3233	3019	2	2004-04-27
4	3233	542	3	2004-04-27
1	3234	6718	1	2004-04-16
2	3234	360	3	2004-04-16
3	3234	5576	2	2004-04-16
4	3234	3483	3	2004-04-16
5	3234	7409	2	2004-04-16
1	3235	2025	1	2004-04-23
2	3235	4921	2	2004-04-23
3	3235	4053	1	2004-04-23
4	3235	6272	2	2004-04-23
5	3235	6476	3	2004-04-23
6	3235	8903	3	2004-04-23
1	3236	9105	1	2004-04-22
2	3236	9717	3	2004-04-22
3	3236	9578	2	2004-04-22
4	3236	3664	1	2004-04-22
5	3236	3319	1	2004-04-22
6	3236	9150	1	2004-04-22
7	3236	8374	1	2004-04-22
8	3236	6834	1	2004-04-22
1	3237	2440	1	2004-04-03
2	3237	9933	3	2004-04-03
3	3237	1977	3	2004-04-03
4	3237	5934	3	2004-04-03
5	3237	2957	1	2004-04-03
1	3238	1527	2	2004-04-24
2	3238	2821	2	2004-04-24
3	3238	6773	2	2004-04-24
4	3238	6262	2	2004-04-24
5	3238	7087	2	2004-04-24
6	3238	6512	2	2004-04-24
7	3238	5034	3	2004-04-24
1	3239	4135	1	2004-04-18
2	3239	7028	2	2004-04-18
3	3239	1193	1	2004-04-18
4	3239	5144	2	2004-04-18
5	3239	4636	1	2004-04-18
6	3239	6212	3	2004-04-18
7	3239	485	3	2004-04-18
8	3239	2482	1	2004-04-18
1	3240	5176	2	2004-04-09
2	3240	3824	1	2004-04-09
3	3240	451	3	2004-04-09
4	3240	9130	2	2004-04-09
5	3240	305	1	2004-04-09
6	3240	4236	2	2004-04-09
7	3240	3914	1	2004-04-09
8	3240	550	2	2004-04-09
9	3240	4225	2	2004-04-09
1	3241	7630	3	2004-04-28
2	3241	3205	1	2004-04-28
3	3241	2440	2	2004-04-28
4	3241	9366	1	2004-04-28
5	3241	5320	2	2004-04-28
1	3242	8000	2	2004-04-26
2	3242	4989	3	2004-04-26
3	3242	6913	3	2004-04-26
4	3242	2744	1	2004-04-26
5	3242	488	1	2004-04-26
6	3242	5932	2	2004-04-26
7	3242	8987	2	2004-04-26
8	3242	3572	3	2004-04-26
1	3243	1313	3	2004-04-02
2	3243	9991	1	2004-04-02
3	3243	1094	2	2004-04-02
4	3243	5219	3	2004-04-02
1	3244	6804	2	2004-04-14
2	3244	758	2	2004-04-14
3	3244	2585	2	2004-04-14
1	3245	7784	2	2004-04-14
1	3246	2557	1	2004-04-17
2	3246	175	2	2004-04-17
3	3246	9398	1	2004-04-17
4	3246	4547	1	2004-04-17
5	3246	5475	3	2004-04-17
6	3246	9999	3	2004-04-17
1	3247	1732	1	2004-04-04
2	3247	1731	2	2004-04-04
3	3247	6640	2	2004-04-04
4	3247	7389	2	2004-04-04
5	3247	6746	2	2004-04-04
6	3247	9215	1	2004-04-04
7	3247	6528	1	2004-04-04
8	3247	8722	3	2004-04-04
1	3248	9061	3	2004-04-09
2	3248	2709	2	2004-04-09
1	3249	1078	3	2004-04-22
2	3249	6489	1	2004-04-22
3	3249	9984	3	2004-04-22
4	3249	7126	2	2004-04-22
5	3249	4490	2	2004-04-22
6	3249	58	1	2004-04-22
7	3249	9686	3	2004-04-22
8	3249	3642	2	2004-04-22
1	3250	1259	3	2004-04-06
2	3250	6942	1	2004-04-06
3	3250	5748	3	2004-04-06
4	3250	4856	1	2004-04-06
5	3250	2357	3	2004-04-06
1	3251	6244	2	2004-04-05
2	3251	6192	2	2004-04-05
3	3251	2772	1	2004-04-05
4	3251	7884	1	2004-04-05
5	3251	1917	3	2004-04-05
6	3251	2101	2	2004-04-05
7	3251	3782	2	2004-04-05
8	3251	7920	3	2004-04-05
1	3252	9499	1	2004-04-27
2	3252	5321	2	2004-04-27
3	3252	6086	3	2004-04-27
4	3252	3674	3	2004-04-27
5	3252	1112	3	2004-04-27
6	3252	5544	3	2004-04-27
1	3253	2417	3	2004-04-18
2	3253	1586	2	2004-04-18
3	3253	6177	2	2004-04-18
4	3253	9890	3	2004-04-18
5	3253	7691	3	2004-04-18
6	3253	9037	2	2004-04-18
7	3253	6989	2	2004-04-18
8	3253	2091	2	2004-04-18
1	3254	5089	2	2004-04-29
2	3254	3096	2	2004-04-29
3	3254	4352	3	2004-04-29
4	3254	3556	1	2004-04-29
5	3254	375	2	2004-04-29
1	3255	7123	3	2004-04-28
1	3256	4823	3	2004-04-14
2	3256	8475	1	2004-04-14
1	3257	7977	3	2004-04-14
2	3257	9386	1	2004-04-14
3	3257	3653	1	2004-04-14
4	3257	9265	3	2004-04-14
1	3258	7100	3	2004-04-04
2	3258	4285	3	2004-04-04
1	3259	8421	3	2004-04-25
2	3259	4535	1	2004-04-25
3	3259	6129	1	2004-04-25
1	3260	4412	1	2004-04-16
2	3260	2490	2	2004-04-16
3	3260	4615	2	2004-04-16
4	3260	6279	2	2004-04-16
1	3261	8894	2	2004-04-13
2	3261	9923	1	2004-04-13
3	3261	3785	3	2004-04-13
1	3262	905	2	2004-04-14
2	3262	6249	3	2004-04-14
3	3262	8059	1	2004-04-14
1	3263	3183	3	2004-04-23
2	3263	5793	3	2004-04-23
1	3264	9470	3	2004-04-10
2	3264	9920	3	2004-04-10
3	3264	2175	3	2004-04-10
4	3264	1542	2	2004-04-10
5	3264	7880	2	2004-04-10
6	3264	8793	3	2004-04-10
7	3264	9133	3	2004-04-10
1	3265	6684	2	2004-04-11
2	3265	3137	1	2004-04-11
1	3266	4117	1	2004-04-19
2	3266	4172	2	2004-04-19
1	3267	2004	2	2004-04-28
2	3267	8960	2	2004-04-28
3	3267	2303	3	2004-04-28
4	3267	9672	1	2004-04-28
5	3267	5235	3	2004-04-28
6	3267	792	3	2004-04-28
7	3267	4186	3	2004-04-28
8	3267	185	1	2004-04-28
9	3267	1836	1	2004-04-28
1	3268	246	2	2004-04-07
1	3269	8058	2	2004-04-08
2	3269	764	1	2004-04-08
1	3270	6563	1	2004-04-01
2	3270	3464	1	2004-04-01
3	3270	2082	2	2004-04-01
1	3271	7136	2	2004-04-02
1	3272	25	1	2004-04-12
2	3272	7384	1	2004-04-12
3	3272	6419	3	2004-04-12
4	3272	4121	2	2004-04-12
1	3273	4609	3	2004-04-02
1	3274	2969	2	2004-04-10
2	3274	810	2	2004-04-10
3	3274	9770	1	2004-04-10
4	3274	4109	3	2004-04-10
5	3274	6199	3	2004-04-10
6	3274	6245	3	2004-04-10
1	3275	8743	2	2004-04-06
2	3275	6038	1	2004-04-06
3	3275	853	3	2004-04-06
4	3275	7748	2	2004-04-06
5	3275	7418	1	2004-04-06
6	3275	3532	1	2004-04-06
7	3275	3527	2	2004-04-06
8	3275	7063	2	2004-04-06
9	3275	8455	3	2004-04-06
1	3276	5129	2	2004-04-30
2	3276	2143	1	2004-04-30
3	3276	4612	2	2004-04-30
4	3276	7642	2	2004-04-30
1	3277	9248	1	2004-04-09
2	3277	5694	3	2004-04-09
3	3277	7187	1	2004-04-09
4	3277	9352	1	2004-04-09
5	3277	3620	1	2004-04-09
6	3277	5671	1	2004-04-09
7	3277	9374	2	2004-04-09
8	3277	8555	3	2004-04-09
9	3277	2349	3	2004-04-09
1	3278	8850	1	2004-04-11
2	3278	9368	2	2004-04-11
3	3278	4849	1	2004-04-11
4	3278	2875	2	2004-04-11
5	3278	1328	1	2004-04-11
1	3279	132	3	2004-04-23
2	3279	5497	2	2004-04-23
3	3279	1348	1	2004-04-23
4	3279	4433	1	2004-04-23
5	3279	5293	1	2004-04-23
1	3280	5117	3	2004-04-01
2	3280	8908	2	2004-04-01
3	3280	7947	3	2004-04-01
4	3280	457	1	2004-04-01
1	3281	5454	2	2004-04-02
2	3281	8952	2	2004-04-02
1	3282	2834	2	2004-04-03
2	3282	7624	3	2004-04-03
3	3282	5110	1	2004-04-03
4	3282	254	2	2004-04-03
5	3282	557	1	2004-04-03
6	3282	8546	2	2004-04-03
1	3283	5728	1	2004-04-30
2	3283	660	2	2004-04-30
3	3283	3427	3	2004-04-30
4	3283	8262	3	2004-04-30
5	3283	5430	3	2004-04-30
6	3283	3452	2	2004-04-30
7	3283	6297	2	2004-04-30
8	3283	2845	3	2004-04-30
1	3284	3384	2	2004-04-03
2	3284	1134	2	2004-04-03
3	3284	8903	3	2004-04-03
4	3284	9613	3	2004-04-03
5	3284	7132	3	2004-04-03
6	3284	6686	1	2004-04-03
1	3285	6594	3	2004-04-29
2	3285	1654	1	2004-04-29
3	3285	4665	2	2004-04-29
1	3286	93	1	2004-04-26
2	3286	1726	2	2004-04-26
1	3287	9050	1	2004-04-26
2	3287	9278	3	2004-04-26
3	3287	864	2	2004-04-26
4	3287	7915	3	2004-04-26
5	3287	9269	3	2004-04-26
6	3287	4894	3	2004-04-26
7	3287	35	1	2004-04-26
8	3287	5910	1	2004-04-26
9	3287	3512	1	2004-04-26
1	3288	3182	1	2004-04-21
2	3288	867	2	2004-04-21
3	3288	8117	3	2004-04-21
4	3288	17	1	2004-04-21
5	3288	8931	3	2004-04-21
6	3288	3299	3	2004-04-21
7	3288	7729	2	2004-04-21
8	3288	4618	2	2004-04-21
1	3289	2345	1	2004-04-06
2	3289	8094	3	2004-04-06
3	3289	4628	1	2004-04-06
4	3289	8828	1	2004-04-06
5	3289	3529	1	2004-04-06
6	3289	9812	3	2004-04-06
1	3290	10	1	2004-04-06
1	3291	7149	3	2004-04-05
2	3291	8825	1	2004-04-05
3	3291	4071	1	2004-04-05
4	3291	5653	3	2004-04-05
5	3291	7142	3	2004-04-05
1	3292	6839	2	2004-04-30
2	3292	5962	1	2004-04-30
3	3292	5442	2	2004-04-30
4	3292	7076	3	2004-04-30
5	3292	6450	3	2004-04-30
1	3293	5400	1	2004-04-23
2	3293	3564	1	2004-04-23
3	3293	9453	1	2004-04-23
4	3293	4314	2	2004-04-23
5	3293	2925	3	2004-04-23
6	3293	497	1	2004-04-23
7	3293	7963	1	2004-04-23
8	3293	5300	2	2004-04-23
9	3293	4950	1	2004-04-23
1	3294	6683	3	2004-04-28
2	3294	2165	1	2004-04-28
3	3294	8273	3	2004-04-28
4	3294	9592	3	2004-04-28
5	3294	8606	2	2004-04-28
1	3295	4558	1	2004-04-29
2	3295	2597	3	2004-04-29
3	3295	1817	1	2004-04-29
4	3295	7548	3	2004-04-29
5	3295	3503	1	2004-04-29
6	3295	3993	3	2004-04-29
7	3295	4986	1	2004-04-29
8	3295	9363	3	2004-04-29
9	3295	8018	2	2004-04-29
1	3296	9886	3	2004-04-22
2	3296	3940	3	2004-04-22
3	3296	3761	2	2004-04-22
4	3296	661	1	2004-04-22
5	3296	2636	2	2004-04-22
1	3297	8325	1	2004-04-10
2	3297	4747	1	2004-04-10
3	3297	3095	3	2004-04-10
4	3297	280	3	2004-04-10
5	3297	2024	3	2004-04-10
1	3298	224	2	2004-04-17
2	3298	7983	1	2004-04-17
3	3298	3636	1	2004-04-17
1	3299	8696	3	2004-04-26
2	3299	4479	1	2004-04-26
3	3299	3351	3	2004-04-26
4	3299	6813	1	2004-04-26
5	3299	7427	1	2004-04-26
6	3299	3503	1	2004-04-26
7	3299	298	2	2004-04-26
8	3299	8602	1	2004-04-26
9	3299	3424	2	2004-04-26
1	3300	3977	2	2004-04-08
2	3300	2696	3	2004-04-08
3	3300	6716	1	2004-04-08
1	3301	319	2	2004-04-16
2	3301	5551	2	2004-04-16
3	3301	2215	1	2004-04-16
4	3301	5345	3	2004-04-16
1	3302	2628	3	2004-04-12
2	3302	6541	2	2004-04-12
3	3302	2935	3	2004-04-12
4	3302	5162	3	2004-04-12
1	3303	6751	1	2004-04-05
2	3303	5479	1	2004-04-05
3	3303	3456	2	2004-04-05
4	3303	5465	2	2004-04-05
1	3304	3379	1	2004-04-04
2	3304	2926	3	2004-04-04
3	3304	1635	1	2004-04-04
1	3305	314	2	2004-04-05
2	3305	6965	2	2004-04-05
3	3305	4532	3	2004-04-05
4	3305	4613	3	2004-04-05
5	3305	2635	1	2004-04-05
6	3305	327	3	2004-04-05
7	3305	3123	2	2004-04-05
8	3305	4150	3	2004-04-05
1	3306	8506	1	2004-04-23
2	3306	7788	1	2004-04-23
3	3306	284	3	2004-04-23
4	3306	4519	1	2004-04-23
5	3306	3684	2	2004-04-23
1	3307	9472	2	2004-04-30
2	3307	5282	2	2004-04-30
3	3307	4756	3	2004-04-30
4	3307	5448	2	2004-04-30
5	3307	6031	3	2004-04-30
6	3307	8865	1	2004-04-30
7	3307	7159	2	2004-04-30
1	3308	9743	3	2004-04-17
2	3308	5336	1	2004-04-17
3	3308	8630	3	2004-04-17
4	3308	1831	1	2004-04-17
1	3309	8526	2	2004-04-19
2	3309	3062	2	2004-04-19
3	3309	9868	3	2004-04-19
4	3309	1725	2	2004-04-19
5	3309	2900	3	2004-04-19
6	3309	3886	1	2004-04-19
7	3309	7934	1	2004-04-19
1	3310	7239	3	2004-04-25
2	3310	8815	1	2004-04-25
3	3310	7575	3	2004-04-25
4	3310	2429	3	2004-04-25
5	3310	9758	3	2004-04-25
6	3310	1101	2	2004-04-25
7	3310	6028	3	2004-04-25
8	3310	1852	3	2004-04-25
9	3310	3434	1	2004-04-25
1	3311	2913	1	2004-04-21
2	3311	1569	1	2004-04-21
3	3311	1963	3	2004-04-21
4	3311	4181	3	2004-04-21
5	3311	9360	1	2004-04-21
6	3311	7317	3	2004-04-21
7	3311	3993	2	2004-04-21
8	3311	5618	2	2004-04-21
9	3311	4295	2	2004-04-21
1	3312	5022	1	2004-04-16
1	3313	3614	1	2004-04-01
2	3313	6899	2	2004-04-01
3	3313	2965	3	2004-04-01
4	3313	7373	2	2004-04-01
5	3313	8221	1	2004-04-01
6	3313	4696	3	2004-04-01
7	3313	2972	1	2004-04-01
1	3314	3386	1	2004-04-18
2	3314	6746	3	2004-04-18
1	3315	1486	3	2004-04-20
2	3315	69	2	2004-04-20
1	3316	209	1	2004-04-21
2	3316	2209	3	2004-04-21
3	3316	6438	1	2004-04-21
4	3316	9135	1	2004-04-21
1	3317	9071	1	2004-04-25
2	3317	5131	1	2004-04-25
3	3317	1245	1	2004-04-25
4	3317	915	3	2004-04-25
1	3318	222	3	2004-04-01
2	3318	8051	3	2004-04-01
1	3319	8105	1	2004-04-10
2	3319	990	2	2004-04-10
3	3319	3443	1	2004-04-10
4	3319	5675	1	2004-04-10
1	3320	8867	1	2004-04-07
2	3320	3757	1	2004-04-07
1	3321	5146	3	2004-04-07
2	3321	3838	2	2004-04-07
3	3321	6916	1	2004-04-07
1	3322	3526	2	2004-04-08
2	3322	6252	2	2004-04-08
3	3322	1129	3	2004-04-08
1	3323	5623	2	2004-04-14
2	3323	8168	2	2004-04-14
3	3323	6696	1	2004-04-14
4	3323	4600	3	2004-04-14
5	3323	6596	1	2004-04-14
6	3323	1200	1	2004-04-14
7	3323	9944	2	2004-04-14
1	3324	6976	2	2004-04-22
2	3324	2776	1	2004-04-22
3	3324	1994	3	2004-04-22
4	3324	5016	1	2004-04-22
5	3324	8721	3	2004-04-22
6	3324	9926	3	2004-04-22
7	3324	6522	2	2004-04-22
8	3324	6218	2	2004-04-22
9	3324	36	1	2004-04-22
1	3325	7182	1	2004-04-20
2	3325	4949	3	2004-04-20
3	3325	8064	1	2004-04-20
1	3326	395	2	2004-04-12
1	3327	5512	1	2004-04-05
2	3327	6129	2	2004-04-05
3	3327	1980	1	2004-04-05
4	3327	984	3	2004-04-05
5	3327	7341	1	2004-04-05
6	3327	1111	2	2004-04-05
1	3328	5966	1	2004-04-17
2	3328	9961	2	2004-04-17
3	3328	4166	2	2004-04-17
1	3329	130	2	2004-04-28
2	3329	1801	2	2004-04-28
3	3329	2840	3	2004-04-28
4	3329	5643	3	2004-04-28
5	3329	2749	3	2004-04-28
6	3329	1619	2	2004-04-28
7	3329	5820	3	2004-04-28
8	3329	4752	3	2004-04-28
9	3329	2913	1	2004-04-28
1	3330	2185	1	2004-04-30
2	3330	9864	2	2004-04-30
3	3330	7147	3	2004-04-30
4	3330	2110	1	2004-04-30
5	3330	8294	1	2004-04-30
6	3330	8415	1	2004-04-30
1	3331	222	1	2004-04-18
2	3331	9030	1	2004-04-18
1	3332	1780	2	2004-04-12
2	3332	9044	1	2004-04-12
3	3332	3785	1	2004-04-12
4	3332	7484	2	2004-04-12
5	3332	5488	3	2004-04-12
6	3332	2319	1	2004-04-12
7	3332	6228	2	2004-04-12
8	3332	4685	2	2004-04-12
1	3333	4353	1	2004-04-20
2	3333	3839	2	2004-04-20
3	3333	2176	1	2004-04-20
1	3334	4700	3	2004-04-20
2	3334	924	2	2004-04-20
3	3334	1146	2	2004-04-20
4	3334	6028	3	2004-04-20
5	3334	678	1	2004-04-20
6	3334	5976	1	2004-04-20
7	3334	4149	1	2004-04-20
1	3335	1933	1	2004-04-23
2	3335	6522	2	2004-04-23
3	3335	3361	1	2004-04-23
4	3335	861	2	2004-04-23
1	3336	4488	2	2004-04-10
1	3337	121	2	2004-04-02
2	3337	215	1	2004-04-02
1	3338	8393	1	2004-04-23
2	3338	564	2	2004-04-23
1	3339	8783	3	2004-04-16
2	3339	2188	3	2004-04-16
1	3340	6358	1	2004-04-17
2	3340	3247	3	2004-04-17
3	3340	6818	1	2004-04-17
4	3340	8384	3	2004-04-17
5	3340	9353	3	2004-04-17
6	3340	7736	3	2004-04-17
7	3340	4788	1	2004-04-17
1	3341	8297	3	2004-04-26
2	3341	1724	2	2004-04-26
3	3341	9879	1	2004-04-26
4	3341	4570	1	2004-04-26
5	3341	148	3	2004-04-26
6	3341	7481	3	2004-04-26
7	3341	6872	2	2004-04-26
8	3341	8470	1	2004-04-26
9	3341	636	2	2004-04-26
1	3342	7618	3	2004-04-11
2	3342	9690	1	2004-04-11
3	3342	1489	3	2004-04-11
1	3343	2285	3	2004-04-17
2	3343	8634	1	2004-04-17
3	3343	9809	1	2004-04-17
4	3343	4230	3	2004-04-17
1	3344	5548	2	2004-04-10
2	3344	114	2	2004-04-10
3	3344	779	2	2004-04-10
4	3344	5203	1	2004-04-10
5	3344	6273	1	2004-04-10
6	3344	2964	2	2004-04-10
7	3344	5224	2	2004-04-10
8	3344	4315	1	2004-04-10
9	3344	8685	1	2004-04-10
1	3345	3133	1	2004-04-15
2	3345	6525	3	2004-04-15
3	3345	964	3	2004-04-15
1	3346	3477	3	2004-04-28
2	3346	802	2	2004-04-28
3	3346	3276	2	2004-04-28
4	3346	7259	3	2004-04-28
5	3346	8824	1	2004-04-28
1	3347	4856	2	2004-04-17
2	3347	1721	3	2004-04-17
3	3347	4327	1	2004-04-17
4	3347	2867	3	2004-04-17
5	3347	3926	3	2004-04-17
6	3347	4821	2	2004-04-17
7	3347	9041	2	2004-04-17
8	3347	2874	3	2004-04-17
9	3347	8511	2	2004-04-17
1	3348	5317	3	2004-04-26
2	3348	1269	2	2004-04-26
1	3349	6605	1	2004-04-25
2	3349	6118	3	2004-04-25
3	3349	2589	1	2004-04-25
1	3350	4846	1	2004-04-04
2	3350	57	2	2004-04-04
3	3350	6616	1	2004-04-04
4	3350	2573	2	2004-04-04
5	3350	9282	1	2004-04-04
1	3351	7753	2	2004-04-14
2	3351	3894	2	2004-04-14
3	3351	785	1	2004-04-14
4	3351	8599	3	2004-04-14
5	3351	5126	2	2004-04-14
6	3351	5714	3	2004-04-14
7	3351	5160	3	2004-04-14
8	3351	3168	1	2004-04-14
9	3351	2126	3	2004-04-14
1	3352	5113	2	2004-04-18
2	3352	7527	2	2004-04-18
3	3352	5489	1	2004-04-18
1	3353	2232	2	2004-04-13
2	3353	7873	1	2004-04-13
1	3354	1187	2	2004-04-24
2	3354	532	2	2004-04-24
3	3354	3076	2	2004-04-24
1	3355	7383	2	2004-04-29
2	3355	7595	1	2004-04-29
3	3355	8085	2	2004-04-29
4	3355	6889	2	2004-04-29
5	3355	7086	1	2004-04-29
1	3356	4416	1	2004-04-06
2	3356	7047	1	2004-04-06
3	3356	7548	3	2004-04-06
4	3356	4928	3	2004-04-06
1	3357	9159	2	2004-04-11
2	3357	1846	1	2004-04-11
3	3357	9682	3	2004-04-11
4	3357	4485	3	2004-04-11
5	3357	1723	1	2004-04-11
6	3357	2398	3	2004-04-11
1	3358	8287	1	2004-04-19
2	3358	1973	1	2004-04-19
3	3358	4062	3	2004-04-19
4	3358	4811	1	2004-04-19
5	3358	6470	3	2004-04-19
6	3358	345	1	2004-04-19
7	3358	5197	2	2004-04-19
8	3358	6685	2	2004-04-19
1	3359	7758	3	2004-04-30
2	3359	6872	3	2004-04-30
3	3359	2281	3	2004-04-30
4	3359	8091	3	2004-04-30
5	3359	8752	3	2004-04-30
6	3359	6366	3	2004-04-30
7	3359	858	3	2004-04-30
8	3359	9740	2	2004-04-30
9	3359	7358	2	2004-04-30
1	3360	3867	3	2004-04-20
2	3360	2298	1	2004-04-20
3	3360	3839	1	2004-04-20
4	3360	9081	3	2004-04-20
5	3360	1807	3	2004-04-20
6	3360	8776	3	2004-04-20
7	3360	6318	1	2004-04-20
1	3361	2281	2	2004-04-24
2	3361	3735	1	2004-04-24
3	3361	4184	2	2004-04-24
4	3361	8057	1	2004-04-24
5	3361	8024	2	2004-04-24
6	3361	5369	1	2004-04-24
7	3361	1458	3	2004-04-24
1	3362	5966	3	2004-04-06
2	3362	4697	3	2004-04-06
3	3362	5707	2	2004-04-06
4	3362	6450	1	2004-04-06
5	3362	4528	2	2004-04-06
6	3362	6433	2	2004-04-06
1	3363	1852	2	2004-04-04
2	3363	8302	3	2004-04-04
3	3363	5577	2	2004-04-04
4	3363	4494	1	2004-04-04
5	3363	8635	2	2004-04-04
1	3364	6060	2	2004-04-01
2	3364	8837	1	2004-04-01
3	3364	3444	2	2004-04-01
4	3364	4228	3	2004-04-01
5	3364	6568	3	2004-04-01
6	3364	4288	1	2004-04-01
7	3364	2763	2	2004-04-01
8	3364	1714	1	2004-04-01
9	3364	208	2	2004-04-01
1	3365	4835	3	2004-04-20
2	3365	3173	2	2004-04-20
3	3365	3918	2	2004-04-20
1	3366	9295	1	2004-04-12
2	3366	712	1	2004-04-12
3	3366	6703	2	2004-04-12
4	3366	2631	1	2004-04-12
5	3366	3694	3	2004-04-12
6	3366	6270	2	2004-04-12
7	3366	2299	3	2004-04-12
8	3366	9070	1	2004-04-12
9	3366	1549	2	2004-04-12
1	3367	2989	1	2004-04-04
2	3367	9319	3	2004-04-04
3	3367	4471	1	2004-04-04
4	3367	530	3	2004-04-04
5	3367	3172	3	2004-04-04
6	3367	9953	2	2004-04-04
1	3368	9925	1	2004-04-08
2	3368	2110	2	2004-04-08
3	3368	8970	2	2004-04-08
4	3368	4178	3	2004-04-08
5	3368	6915	2	2004-04-08
1	3369	3780	2	2004-04-12
2	3369	2820	1	2004-04-12
1	3370	5085	3	2004-04-02
2	3370	997	2	2004-04-02
1	3371	8751	1	2004-04-11
2	3371	4703	1	2004-04-11
1	3372	1712	1	2004-04-24
2	3372	7716	2	2004-04-24
1	3373	2201	3	2004-04-01
2	3373	6991	1	2004-04-01
3	3373	7283	1	2004-04-01
4	3373	4017	1	2004-04-01
1	3374	8573	3	2004-04-09
2	3374	8346	3	2004-04-09
3	3374	713	1	2004-04-09
4	3374	8183	3	2004-04-09
5	3374	6721	2	2004-04-09
6	3374	514	3	2004-04-09
1	3375	6693	1	2004-04-17
2	3375	9635	3	2004-04-17
3	3375	1064	2	2004-04-17
4	3375	1737	3	2004-04-17
5	3375	9929	2	2004-04-17
6	3375	712	1	2004-04-17
1	3376	7210	3	2004-04-03
2	3376	6663	3	2004-04-03
3	3376	270	2	2004-04-03
4	3376	6447	3	2004-04-03
5	3376	8295	3	2004-04-03
6	3376	5422	2	2004-04-03
7	3376	5189	3	2004-04-03
8	3376	9669	1	2004-04-03
9	3376	395	3	2004-04-03
1	3377	9805	2	2004-04-03
2	3377	8265	1	2004-04-03
3	3377	8576	3	2004-04-03
1	3378	4672	2	2004-04-26
2	3378	3763	2	2004-04-26
3	3378	9879	1	2004-04-26
4	3378	1931	3	2004-04-26
5	3378	7170	3	2004-04-26
6	3378	2099	1	2004-04-26
1	3379	1072	2	2004-04-21
2	3379	8528	3	2004-04-21
3	3379	7526	3	2004-04-21
4	3379	2858	2	2004-04-21
5	3379	8848	1	2004-04-21
6	3379	4823	3	2004-04-21
7	3379	8884	1	2004-04-21
1	3380	8496	3	2004-04-10
2	3380	7290	1	2004-04-10
3	3380	6280	2	2004-04-10
4	3380	7779	3	2004-04-10
5	3380	6818	2	2004-04-10
6	3380	145	1	2004-04-10
7	3380	1522	1	2004-04-10
1	3381	8381	1	2004-04-19
2	3381	9386	3	2004-04-19
3	3381	2506	2	2004-04-19
4	3381	4706	1	2004-04-19
1	3382	5104	2	2004-04-23
2	3382	3736	1	2004-04-23
3	3382	3867	1	2004-04-23
4	3382	6853	1	2004-04-23
5	3382	8393	2	2004-04-23
6	3382	6098	3	2004-04-23
1	3383	7669	3	2004-04-15
1	3384	3278	1	2004-04-14
2	3384	7987	3	2004-04-14
3	3384	2936	2	2004-04-14
4	3384	6006	3	2004-04-14
1	3385	3504	2	2004-04-04
2	3385	4769	1	2004-04-04
3	3385	6830	1	2004-04-04
4	3385	4027	1	2004-04-04
5	3385	1698	3	2004-04-04
1	3386	9420	2	2004-04-02
2	3386	4265	3	2004-04-02
3	3386	7723	3	2004-04-02
4	3386	8	2	2004-04-02
5	3386	5524	1	2004-04-02
6	3386	1097	1	2004-04-02
7	3386	823	1	2004-04-02
8	3386	2640	1	2004-04-02
1	3387	6500	2	2004-04-21
2	3387	4796	1	2004-04-21
1	3388	7945	3	2004-04-22
2	3388	5845	3	2004-04-22
3	3388	2775	1	2004-04-22
4	3388	5825	1	2004-04-22
5	3388	7651	2	2004-04-22
6	3388	6207	1	2004-04-22
7	3388	8776	3	2004-04-22
1	3389	1739	2	2004-04-15
2	3389	3487	3	2004-04-15
3	3389	7919	3	2004-04-15
4	3389	3222	1	2004-04-15
5	3389	512	1	2004-04-15
6	3389	9207	3	2004-04-15
7	3389	7936	3	2004-04-15
1	3390	3890	1	2004-04-26
2	3390	1894	1	2004-04-26
1	3391	5403	3	2004-04-19
2	3391	4546	2	2004-04-19
3	3391	6764	2	2004-04-19
4	3391	1103	1	2004-04-19
5	3391	5351	3	2004-04-19
1	3392	8878	1	2004-04-01
1	3393	594	1	2004-04-02
2	3393	558	2	2004-04-02
3	3393	2948	1	2004-04-02
4	3393	6024	3	2004-04-02
5	3393	551	1	2004-04-02
6	3393	4069	2	2004-04-02
7	3393	159	3	2004-04-02
8	3393	773	3	2004-04-02
9	3393	4899	1	2004-04-02
1	3394	8821	1	2004-04-22
2	3394	8156	3	2004-04-22
3	3394	3571	3	2004-04-22
4	3394	4511	1	2004-04-22
5	3394	7856	2	2004-04-22
6	3394	4271	3	2004-04-22
7	3394	9588	3	2004-04-22
1	3395	6351	1	2004-04-03
2	3395	7368	2	2004-04-03
1	3396	15	1	2004-04-28
2	3396	4168	1	2004-04-28
3	3396	8009	1	2004-04-28
4	3396	3540	2	2004-04-28
1	3397	8773	1	2004-04-03
2	3397	301	1	2004-04-03
3	3397	1128	3	2004-04-03
4	3397	262	1	2004-04-03
5	3397	5500	2	2004-04-03
1	3398	8359	2	2004-04-11
1	3399	2390	2	2004-04-27
2	3399	9837	1	2004-04-27
3	3399	7101	2	2004-04-27
4	3399	6563	3	2004-04-27
5	3399	485	1	2004-04-27
6	3399	2983	3	2004-04-27
7	3399	4136	1	2004-04-27
8	3399	2301	2	2004-04-27
9	3399	3171	1	2004-04-27
1	3400	521	2	2004-04-22
1	3401	668	1	2004-04-05
1	3402	3455	2	2004-04-28
2	3402	2482	1	2004-04-28
3	3402	1145	1	2004-04-28
4	3402	1438	2	2004-04-28
5	3402	2224	2	2004-04-28
6	3402	7410	2	2004-04-28
7	3402	836	1	2004-04-28
8	3402	7088	3	2004-04-28
9	3402	9251	2	2004-04-28
1	3403	8651	2	2004-04-27
1	3404	2375	1	2004-04-02
2	3404	8902	2	2004-04-02
3	3404	6378	1	2004-04-02
4	3404	5846	3	2004-04-02
5	3404	4350	3	2004-04-02
6	3404	1650	2	2004-04-02
7	3404	2856	3	2004-04-02
8	3404	1098	2	2004-04-02
9	3404	9640	3	2004-04-02
1	3405	8662	3	2004-04-06
1	3406	6630	3	2004-04-03
2	3406	1029	3	2004-04-03
1	3407	1313	1	2004-04-04
2	3407	5153	2	2004-04-04
3	3407	7962	3	2004-04-04
4	3407	2235	1	2004-04-04
5	3407	5862	1	2004-04-04
6	3407	4510	2	2004-04-04
7	3407	1517	2	2004-04-04
1	3408	2806	3	2004-04-14
2	3408	366	2	2004-04-14
3	3408	8763	3	2004-04-14
1	3409	9721	1	2004-04-08
2	3409	1392	1	2004-04-08
3	3409	1511	2	2004-04-08
4	3409	6695	3	2004-04-08
1	3410	2261	2	2004-04-11
2	3410	4709	2	2004-04-11
3	3410	1090	3	2004-04-11
4	3410	9730	3	2004-04-11
5	3410	2153	1	2004-04-11
6	3410	5438	1	2004-04-11
7	3410	6812	2	2004-04-11
8	3410	9513	3	2004-04-11
9	3410	3992	2	2004-04-11
1	3411	4745	3	2004-04-10
2	3411	1017	1	2004-04-10
3	3411	7326	2	2004-04-10
4	3411	368	3	2004-04-10
5	3411	3571	1	2004-04-10
1	3412	7378	2	2004-04-08
2	3412	1413	3	2004-04-08
3	3412	8670	3	2004-04-08
4	3412	2047	2	2004-04-08
1	3413	7071	3	2004-04-04
2	3413	8754	2	2004-04-04
3	3413	2357	2	2004-04-04
4	3413	1268	2	2004-04-04
5	3413	4938	3	2004-04-04
1	3414	7934	3	2004-04-24
2	3414	9585	2	2004-04-24
1	3415	6492	3	2004-04-07
2	3415	389	3	2004-04-07
3	3415	4625	1	2004-04-07
4	3415	97	3	2004-04-07
1	3416	581	3	2004-04-20
2	3416	8733	1	2004-04-20
3	3416	3039	2	2004-04-20
4	3416	441	1	2004-04-20
5	3416	8976	2	2004-04-20
1	3417	1248	3	2004-04-07
2	3417	8628	1	2004-04-07
1	3418	3657	2	2004-04-03
2	3418	2766	2	2004-04-03
1	3419	4481	1	2004-04-15
2	3419	1893	1	2004-04-15
3	3419	3349	2	2004-04-15
1	3420	439	3	2004-04-21
2	3420	2768	2	2004-04-21
3	3420	9454	2	2004-04-21
4	3420	3110	3	2004-04-21
5	3420	5738	2	2004-04-21
6	3420	3199	2	2004-04-21
1	3421	609	3	2004-04-17
2	3421	7388	1	2004-04-17
3	3421	9238	1	2004-04-17
4	3421	3031	1	2004-04-17
5	3421	5082	2	2004-04-17
6	3421	6062	1	2004-04-17
7	3421	169	1	2004-04-17
8	3421	7825	1	2004-04-17
1	3422	4609	3	2004-04-29
2	3422	7090	1	2004-04-29
3	3422	3477	1	2004-04-29
4	3422	6950	3	2004-04-29
5	3422	7144	3	2004-04-29
6	3422	6993	3	2004-04-29
7	3422	6055	2	2004-04-29
8	3422	9282	2	2004-04-29
9	3422	6249	1	2004-04-29
1	3423	3296	3	2004-04-20
2	3423	4254	1	2004-04-20
3	3423	9468	2	2004-04-20
1	3424	5215	3	2004-04-06
2	3424	6668	3	2004-04-06
3	3424	196	2	2004-04-06
4	3424	7544	3	2004-04-06
5	3424	2660	2	2004-04-06
6	3424	5091	3	2004-04-06
1	3425	6683	1	2004-04-27
2	3425	6494	2	2004-04-27
3	3425	2916	3	2004-04-27
4	3425	4235	3	2004-04-27
5	3425	910	2	2004-04-27
1	3426	8945	2	2004-04-03
2	3426	3703	2	2004-04-03
3	3426	3395	2	2004-04-03
4	3426	9228	1	2004-04-03
1	3427	603	2	2004-04-04
2	3427	697	2	2004-04-04
3	3427	9553	3	2004-04-04
4	3427	5040	2	2004-04-04
5	3427	2754	3	2004-04-04
6	3427	5836	3	2004-04-04
1	3428	9369	1	2004-04-16
2	3428	9897	3	2004-04-16
3	3428	4881	2	2004-04-16
4	3428	3925	3	2004-04-16
5	3428	7497	1	2004-04-16
6	3428	9212	3	2004-04-16
1	3429	9074	2	2004-04-16
2	3429	252	3	2004-04-16
3	3429	3135	2	2004-04-16
4	3429	4673	2	2004-04-16
5	3429	3247	1	2004-04-16
6	3429	2876	3	2004-04-16
1	3430	3744	2	2004-04-22
2	3430	4935	3	2004-04-22
3	3430	7966	3	2004-04-22
4	3430	6899	2	2004-04-22
5	3430	2012	2	2004-04-22
6	3430	4195	3	2004-04-22
1	3431	5007	1	2004-04-03
2	3431	8495	3	2004-04-03
3	3431	8238	1	2004-04-03
4	3431	4030	1	2004-04-03
5	3431	3674	3	2004-04-03
6	3431	9855	1	2004-04-03
7	3431	471	2	2004-04-03
8	3431	7549	2	2004-04-03
9	3431	8693	1	2004-04-03
1	3432	2121	2	2004-04-09
2	3432	5846	2	2004-04-09
3	3432	407	2	2004-04-09
4	3432	5567	1	2004-04-09
5	3432	6510	1	2004-04-09
6	3432	6047	2	2004-04-09
7	3432	8715	2	2004-04-09
8	3432	8171	1	2004-04-09
9	3432	5768	1	2004-04-09
1	3433	9947	1	2004-04-29
1	3434	5297	2	2004-04-14
2	3434	6908	3	2004-04-14
3	3434	7501	1	2004-04-14
4	3434	3732	3	2004-04-14
5	3434	9395	3	2004-04-14
6	3434	1007	2	2004-04-14
7	3434	9873	3	2004-04-14
1	3435	1332	3	2004-04-03
2	3435	923	1	2004-04-03
3	3435	2727	2	2004-04-03
4	3435	1102	1	2004-04-03
5	3435	4014	2	2004-04-03
6	3435	1313	3	2004-04-03
7	3435	2608	2	2004-04-03
8	3435	963	3	2004-04-03
9	3435	4027	3	2004-04-03
1	3436	7057	3	2004-04-07
2	3436	7569	3	2004-04-07
1	3437	7555	3	2004-04-14
2	3437	2869	3	2004-04-14
3	3437	7829	2	2004-04-14
4	3437	2172	3	2004-04-14
5	3437	8269	2	2004-04-14
6	3437	4367	3	2004-04-14
1	3438	6490	1	2004-04-10
2	3438	2429	3	2004-04-10
3	3438	7974	3	2004-04-10
4	3438	423	2	2004-04-10
1	3439	6467	3	2004-04-19
1	3440	2500	1	2004-04-20
2	3440	4830	2	2004-04-20
3	3440	1083	1	2004-04-20
4	3440	856	2	2004-04-20
5	3440	2679	2	2004-04-20
6	3440	2423	3	2004-04-20
7	3440	7824	3	2004-04-20
8	3440	9083	1	2004-04-20
9	3440	7672	3	2004-04-20
1	3441	6085	2	2004-04-28
2	3441	5825	1	2004-04-28
3	3441	1524	1	2004-04-28
4	3441	6574	2	2004-04-28
5	3441	1426	3	2004-04-28
1	3442	9354	2	2004-04-24
2	3442	4531	1	2004-04-24
3	3442	8457	3	2004-04-24
4	3442	899	2	2004-04-24
5	3442	5867	3	2004-04-24
6	3442	6531	2	2004-04-24
7	3442	7039	2	2004-04-24
8	3442	1632	3	2004-04-24
9	3442	804	3	2004-04-24
1	3443	8819	3	2004-04-10
2	3443	544	1	2004-04-10
3	3443	5914	3	2004-04-10
4	3443	6499	3	2004-04-10
5	3443	7626	2	2004-04-10
1	3444	9110	3	2004-04-13
2	3444	8990	2	2004-04-13
3	3444	8765	2	2004-04-13
1	3445	4930	1	2004-04-26
1	3446	2800	3	2004-04-24
2	3446	4972	2	2004-04-24
3	3446	7594	1	2004-04-24
4	3446	1887	2	2004-04-24
5	3446	541	3	2004-04-24
6	3446	9944	2	2004-04-24
7	3446	1669	3	2004-04-24
8	3446	7506	1	2004-04-24
1	3447	2015	2	2004-04-20
2	3447	1178	1	2004-04-20
3	3447	4415	2	2004-04-20
4	3447	5020	1	2004-04-20
5	3447	4210	2	2004-04-20
1	3448	353	3	2004-04-02
2	3448	6263	1	2004-04-02
3	3448	2586	3	2004-04-02
4	3448	1752	1	2004-04-02
5	3448	1599	2	2004-04-02
1	3449	5599	3	2004-04-02
2	3449	2342	3	2004-04-02
3	3449	4221	2	2004-04-02
4	3449	729	3	2004-04-02
5	3449	9626	2	2004-04-02
6	3449	911	2	2004-04-02
7	3449	9300	1	2004-04-02
1	3450	8695	1	2004-04-03
2	3450	3437	1	2004-04-03
1	3451	8609	2	2004-04-30
2	3451	464	1	2004-04-30
1	3452	3675	3	2004-04-04
2	3452	6995	2	2004-04-04
3	3452	5614	2	2004-04-04
4	3452	152	2	2004-04-04
1	3453	9653	2	2004-04-02
2	3453	2496	3	2004-04-02
1	3454	1121	2	2004-04-23
2	3454	8616	3	2004-04-23
3	3454	7606	3	2004-04-23
4	3454	2535	3	2004-04-23
5	3454	5142	2	2004-04-23
6	3454	2216	3	2004-04-23
7	3454	2272	3	2004-04-23
1	3455	4409	2	2004-04-10
2	3455	2823	1	2004-04-10
3	3455	7584	1	2004-04-10
4	3455	6786	1	2004-04-10
1	3456	1536	3	2004-04-03
1	3457	9232	3	2004-04-12
2	3457	234	2	2004-04-12
1	3458	1659	2	2004-04-15
2	3458	4845	3	2004-04-15
3	3458	9779	3	2004-04-15
4	3458	3774	1	2004-04-15
5	3458	1503	1	2004-04-15
6	3458	5077	3	2004-04-15
7	3458	1435	2	2004-04-15
1	3459	4577	1	2004-04-08
2	3459	4257	1	2004-04-08
3	3459	1732	2	2004-04-08
4	3459	831	1	2004-04-08
1	3460	2477	2	2004-04-24
1	3461	6574	3	2004-04-23
2	3461	9838	3	2004-04-23
3	3461	8690	2	2004-04-23
4	3461	6365	1	2004-04-23
5	3461	814	3	2004-04-23
6	3461	7571	3	2004-04-23
7	3461	3038	1	2004-04-23
1	3462	782	2	2004-04-23
2	3462	1096	3	2004-04-23
3	3462	9931	2	2004-04-23
4	3462	9692	1	2004-04-23
5	3462	1581	3	2004-04-23
6	3462	9729	2	2004-04-23
7	3462	4385	2	2004-04-23
8	3462	2475	2	2004-04-23
9	3462	4379	1	2004-04-23
1	3463	9676	3	2004-04-28
2	3463	7114	1	2004-04-28
3	3463	1007	2	2004-04-28
4	3463	7	2	2004-04-28
5	3463	3646	1	2004-04-28
6	3463	9003	2	2004-04-28
7	3463	9431	3	2004-04-28
8	3463	250	3	2004-04-28
9	3463	1341	1	2004-04-28
1	3464	7371	3	2004-04-19
1	3465	2491	1	2004-04-15
2	3465	3966	1	2004-04-15
3	3465	761	1	2004-04-15
4	3465	4880	1	2004-04-15
1	3466	5676	2	2004-04-17
2	3466	3979	2	2004-04-17
3	3466	4292	2	2004-04-17
4	3466	4229	2	2004-04-17
5	3466	6060	1	2004-04-17
6	3466	6701	1	2004-04-17
7	3466	1155	2	2004-04-17
8	3466	2479	2	2004-04-17
9	3466	5820	1	2004-04-17
1	3467	477	2	2004-04-01
2	3467	5092	2	2004-04-01
3	3467	7520	1	2004-04-01
4	3467	244	2	2004-04-01
1	3468	1025	2	2004-04-30
2	3468	8128	2	2004-04-30
3	3468	9159	2	2004-04-30
4	3468	5752	2	2004-04-30
1	3469	2939	2	2004-04-22
2	3469	2788	1	2004-04-22
3	3469	4059	3	2004-04-22
4	3469	6999	2	2004-04-22
5	3469	3532	1	2004-04-22
6	3469	9893	1	2004-04-22
7	3469	2774	1	2004-04-22
8	3469	4927	1	2004-04-22
9	3469	6055	2	2004-04-22
1	3470	2333	3	2004-04-20
2	3470	8910	3	2004-04-20
3	3470	2704	2	2004-04-20
4	3470	4991	1	2004-04-20
5	3470	5826	3	2004-04-20
1	3471	6394	3	2004-04-26
2	3471	6977	3	2004-04-26
3	3471	4	3	2004-04-26
1	3472	5473	1	2004-04-03
2	3472	65	1	2004-04-03
3	3472	138	3	2004-04-03
4	3472	6791	1	2004-04-03
5	3472	4598	2	2004-04-03
6	3472	555	3	2004-04-03
1	3473	3475	3	2004-04-06
2	3473	6268	2	2004-04-06
3	3473	758	1	2004-04-06
4	3473	2304	3	2004-04-06
5	3473	2587	1	2004-04-06
6	3473	4603	2	2004-04-06
7	3473	5086	1	2004-04-06
1	3474	2626	2	2004-04-29
2	3474	7283	3	2004-04-29
3	3474	7274	1	2004-04-29
4	3474	5117	3	2004-04-29
5	3474	9182	3	2004-04-29
6	3474	3374	3	2004-04-29
7	3474	4599	3	2004-04-29
8	3474	7433	1	2004-04-29
9	3474	1238	3	2004-04-29
1	3475	5849	1	2004-04-11
2	3475	9676	1	2004-04-11
3	3475	2133	3	2004-04-11
4	3475	1492	3	2004-04-11
5	3475	8673	2	2004-04-11
6	3475	1601	2	2004-04-11
1	3476	6703	3	2004-04-11
2	3476	5594	1	2004-04-11
3	3476	6132	1	2004-04-11
4	3476	6923	2	2004-04-11
5	3476	1059	3	2004-04-11
6	3476	1754	2	2004-04-11
7	3476	1702	3	2004-04-11
8	3476	699	3	2004-04-11
1	3477	9516	3	2004-04-25
1	3478	4143	3	2004-04-22
2	3478	7607	1	2004-04-22
3	3478	6272	2	2004-04-22
4	3478	8993	1	2004-04-22
5	3478	4385	2	2004-04-22
6	3478	2058	1	2004-04-22
7	3478	8688	1	2004-04-22
8	3478	9468	1	2004-04-22
1	3479	8718	2	2004-04-24
2	3479	8773	3	2004-04-24
3	3479	6657	3	2004-04-24
4	3479	7174	2	2004-04-24
5	3479	6476	1	2004-04-24
6	3479	2522	1	2004-04-24
7	3479	8887	1	2004-04-24
8	3479	2595	2	2004-04-24
1	3480	6712	3	2004-04-14
2	3480	130	2	2004-04-14
3	3480	2196	3	2004-04-14
4	3480	5841	3	2004-04-14
5	3480	766	2	2004-04-14
6	3480	8296	3	2004-04-14
7	3480	280	3	2004-04-14
8	3480	6683	3	2004-04-14
1	3481	5120	1	2004-04-17
2	3481	2450	2	2004-04-17
1	3482	6631	2	2004-04-11
2	3482	6634	2	2004-04-11
3	3482	5267	3	2004-04-11
4	3482	8742	3	2004-04-11
5	3482	6359	2	2004-04-11
6	3482	7359	3	2004-04-11
7	3482	8541	2	2004-04-11
8	3482	6608	3	2004-04-11
1	3483	7147	2	2004-04-09
2	3483	9910	1	2004-04-09
3	3483	9725	1	2004-04-09
4	3483	6272	1	2004-04-09
5	3483	7403	2	2004-04-09
6	3483	911	2	2004-04-09
7	3483	1621	3	2004-04-09
8	3483	7376	3	2004-04-09
1	3484	699	1	2004-04-13
1	3485	8060	1	2004-04-24
2	3485	7686	2	2004-04-24
3	3485	8163	2	2004-04-24
4	3485	295	3	2004-04-24
1	3486	3119	3	2004-04-22
2	3486	8803	2	2004-04-22
3	3486	1867	1	2004-04-22
4	3486	1572	3	2004-04-22
1	3487	6541	2	2004-04-22
2	3487	3368	2	2004-04-22
1	3488	814	2	2004-04-16
2	3488	7172	3	2004-04-16
3	3488	1242	3	2004-04-16
4	3488	7049	3	2004-04-16
1	3489	5313	1	2004-04-23
1	3490	6421	3	2004-04-14
2	3490	2079	1	2004-04-14
3	3490	9904	3	2004-04-14
4	3490	7838	1	2004-04-14
5	3490	2949	1	2004-04-14
6	3490	4001	1	2004-04-14
1	3491	3791	3	2004-04-20
2	3491	1129	1	2004-04-20
3	3491	7663	3	2004-04-20
4	3491	8318	3	2004-04-20
1	3492	808	1	2004-04-28
2	3492	50	3	2004-04-28
3	3492	9057	1	2004-04-28
4	3492	9009	3	2004-04-28
1	3493	9981	2	2004-04-03
2	3493	5370	2	2004-04-03
3	3493	1046	2	2004-04-03
4	3493	136	2	2004-04-03
1	3494	9877	2	2004-04-09
1	3495	2941	3	2004-04-30
2	3495	499	1	2004-04-30
3	3495	5657	3	2004-04-30
4	3495	5120	2	2004-04-30
5	3495	8515	2	2004-04-30
6	3495	1511	1	2004-04-30
7	3495	9565	1	2004-04-30
8	3495	6977	2	2004-04-30
9	3495	7964	3	2004-04-30
1	3496	9363	3	2004-04-26
2	3496	1600	3	2004-04-26
1	3497	1094	1	2004-04-08
1	3498	1148	3	2004-04-26
2	3498	8889	3	2004-04-26
3	3498	5251	1	2004-04-26
4	3498	409	2	2004-04-26
1	3499	5407	3	2004-04-06
2	3499	7954	3	2004-04-06
3	3499	9296	3	2004-04-06
4	3499	6794	1	2004-04-06
5	3499	6556	3	2004-04-06
6	3499	2303	2	2004-04-06
7	3499	9455	2	2004-04-06
8	3499	6163	3	2004-04-06
9	3499	4989	1	2004-04-06
1	3500	5800	2	2004-04-07
2	3500	1536	2	2004-04-07
1	3501	3281	3	2004-04-30
2	3501	7757	1	2004-04-30
3	3501	7264	3	2004-04-30
4	3501	8552	2	2004-04-30
5	3501	7949	2	2004-04-30
6	3501	3371	1	2004-04-30
7	3501	9996	1	2004-04-30
8	3501	3648	2	2004-04-30
9	3501	848	3	2004-04-30
1	3502	4230	1	2004-04-20
2	3502	1453	2	2004-04-20
3	3502	6780	1	2004-04-20
4	3502	9192	1	2004-04-20
5	3502	950	1	2004-04-20
6	3502	9371	3	2004-04-20
1	3503	691	2	2004-04-12
2	3503	7365	2	2004-04-12
3	3503	3958	3	2004-04-12
1	3504	6241	1	2004-04-21
2	3504	829	1	2004-04-21
3	3504	6496	2	2004-04-21
4	3504	1586	3	2004-04-21
5	3504	824	3	2004-04-21
6	3504	9276	1	2004-04-21
7	3504	8737	1	2004-04-21
1	3505	4741	2	2004-04-08
2	3505	8451	2	2004-04-08
3	3505	8396	2	2004-04-08
4	3505	9494	1	2004-04-08
5	3505	3176	2	2004-04-08
6	3505	9957	3	2004-04-08
1	3506	7212	1	2004-04-13
2	3506	2	3	2004-04-13
3	3506	1240	1	2004-04-13
4	3506	7162	1	2004-04-13
5	3506	840	2	2004-04-13
1	3507	9519	3	2004-04-03
2	3507	4360	3	2004-04-03
3	3507	4177	1	2004-04-03
4	3507	3786	2	2004-04-03
5	3507	5108	3	2004-04-03
6	3507	50	2	2004-04-03
7	3507	3656	2	2004-04-03
8	3507	1262	1	2004-04-03
9	3507	9107	3	2004-04-03
1	3508	9934	2	2004-04-12
2	3508	5499	1	2004-04-12
3	3508	329	2	2004-04-12
4	3508	4099	2	2004-04-12
5	3508	5910	2	2004-04-12
1	3509	3025	2	2004-04-10
2	3509	926	3	2004-04-10
3	3509	2334	1	2004-04-10
4	3509	3196	2	2004-04-10
5	3509	5140	2	2004-04-10
6	3509	6440	2	2004-04-10
7	3509	2931	1	2004-04-10
1	3510	4632	1	2004-04-11
2	3510	4061	2	2004-04-11
3	3510	6902	3	2004-04-11
1	3511	3081	2	2004-04-28
2	3511	9628	2	2004-04-28
3	3511	8737	1	2004-04-28
1	3512	7059	3	2004-04-13
2	3512	1890	2	2004-04-13
3	3512	915	2	2004-04-13
4	3512	3680	2	2004-04-13
5	3512	5022	3	2004-04-13
6	3512	7557	3	2004-04-13
7	3512	9509	1	2004-04-13
1	3513	9221	1	2004-04-14
2	3513	6280	1	2004-04-14
3	3513	4918	2	2004-04-14
4	3513	8406	2	2004-04-14
1	3514	75	1	2004-04-20
2	3514	4658	1	2004-04-20
3	3514	5280	2	2004-04-20
4	3514	6786	3	2004-04-20
5	3514	9841	1	2004-04-20
6	3514	7805	3	2004-04-20
7	3514	1459	3	2004-04-20
8	3514	9015	2	2004-04-20
1	3515	346	2	2004-04-12
2	3515	5245	2	2004-04-12
3	3515	2166	2	2004-04-12
1	3516	6616	2	2004-04-27
2	3516	5424	1	2004-04-27
3	3516	8332	1	2004-04-27
4	3516	6845	2	2004-04-27
1	3517	4081	3	2004-04-29
2	3517	4780	1	2004-04-29
3	3517	4455	3	2004-04-29
4	3517	1887	2	2004-04-29
5	3517	1446	1	2004-04-29
6	3517	692	3	2004-04-29
7	3517	7495	1	2004-04-29
1	3518	54	3	2004-04-02
2	3518	3000	2	2004-04-02
3	3518	9371	1	2004-04-02
4	3518	6180	2	2004-04-02
5	3518	6449	2	2004-04-02
6	3518	2900	2	2004-04-02
1	3519	76	2	2004-04-10
2	3519	6590	1	2004-04-10
3	3519	641	3	2004-04-10
4	3519	4194	1	2004-04-10
5	3519	4725	1	2004-04-10
6	3519	4190	2	2004-04-10
7	3519	8101	2	2004-04-10
8	3519	1698	3	2004-04-10
1	3520	6029	3	2004-04-12
2	3520	9357	1	2004-04-12
3	3520	5650	1	2004-04-12
1	3521	7046	3	2004-04-18
2	3521	3810	2	2004-04-18
3	3521	1273	2	2004-04-18
4	3521	1669	2	2004-04-18
5	3521	5783	2	2004-04-18
6	3521	7155	3	2004-04-18
7	3521	1458	2	2004-04-18
1	3522	7852	3	2004-04-17
2	3522	2556	2	2004-04-17
3	3522	6847	1	2004-04-17
4	3522	6358	1	2004-04-17
5	3522	4167	1	2004-04-17
6	3522	1455	2	2004-04-17
7	3522	9809	3	2004-04-17
8	3522	2713	2	2004-04-17
9	3522	2134	2	2004-04-17
1	3523	196	2	2004-04-25
2	3523	3824	1	2004-04-25
3	3523	1862	3	2004-04-25
4	3523	4808	2	2004-04-25
1	3524	6540	3	2004-04-27
2	3524	3348	1	2004-04-27
1	3525	916	2	2004-04-05
2	3525	1604	2	2004-04-05
3	3525	8530	2	2004-04-05
1	3526	450	3	2004-04-23
2	3526	3672	2	2004-04-23
3	3526	9390	2	2004-04-23
4	3526	3742	2	2004-04-23
5	3526	804	1	2004-04-23
6	3526	6857	1	2004-04-23
7	3526	4061	2	2004-04-23
1	3527	4923	1	2004-04-07
2	3527	7020	2	2004-04-07
3	3527	6307	3	2004-04-07
4	3527	9467	2	2004-04-07
1	3528	4146	1	2004-04-08
2	3528	7637	3	2004-04-08
3	3528	6158	3	2004-04-08
4	3528	3352	3	2004-04-08
5	3528	1223	2	2004-04-08
6	3528	2523	3	2004-04-08
7	3528	7265	2	2004-04-08
8	3528	1476	3	2004-04-08
9	3528	3991	3	2004-04-08
1	3529	4752	2	2004-04-11
1	3530	1299	1	2004-04-28
2	3530	1350	2	2004-04-28
1	3531	6012	2	2004-04-11
2	3531	9682	3	2004-04-11
3	3531	767	1	2004-04-11
4	3531	5315	3	2004-04-11
5	3531	8786	3	2004-04-11
6	3531	7562	1	2004-04-11
7	3531	4559	1	2004-04-11
8	3531	1690	2	2004-04-11
9	3531	1471	2	2004-04-11
1	3532	2007	1	2004-04-28
2	3532	1243	2	2004-04-28
3	3532	7401	2	2004-04-28
4	3532	2343	1	2004-04-28
5	3532	4651	3	2004-04-28
6	3532	7275	2	2004-04-28
7	3532	5589	3	2004-04-28
8	3532	6536	1	2004-04-28
9	3532	6073	2	2004-04-28
1	3533	4640	3	2004-04-24
2	3533	5975	2	2004-04-24
3	3533	6228	2	2004-04-24
1	3534	8842	2	2004-04-21
2	3534	2031	2	2004-04-21
3	3534	781	2	2004-04-21
4	3534	6904	2	2004-04-21
5	3534	2728	2	2004-04-21
6	3534	9763	3	2004-04-21
7	3534	2219	2	2004-04-21
8	3534	9220	3	2004-04-21
1	3535	9164	2	2004-04-05
2	3535	9504	2	2004-04-05
3	3535	2675	2	2004-04-05
4	3535	306	3	2004-04-05
5	3535	2616	2	2004-04-05
6	3535	8017	1	2004-04-05
7	3535	888	1	2004-04-05
8	3535	7699	1	2004-04-05
9	3535	4421	2	2004-04-05
1	3536	5465	1	2004-04-22
2	3536	3159	2	2004-04-22
3	3536	9290	2	2004-04-22
4	3536	1596	1	2004-04-22
5	3536	4495	1	2004-04-22
6	3536	7779	2	2004-04-22
7	3536	5896	1	2004-04-22
1	3537	1177	3	2004-04-30
2	3537	3803	1	2004-04-30
3	3537	7859	1	2004-04-30
1	3538	9427	2	2004-04-12
1	3539	9574	2	2004-04-24
1	3540	1928	2	2004-04-17
1	3541	4024	2	2004-04-13
2	3541	6197	2	2004-04-13
3	3541	2220	3	2004-04-13
4	3541	7264	1	2004-04-13
1	3542	1827	1	2004-04-05
2	3542	2484	3	2004-04-05
3	3542	6673	3	2004-04-05
4	3542	369	2	2004-04-05
5	3542	3532	2	2004-04-05
6	3542	7416	3	2004-04-05
7	3542	6121	3	2004-04-05
1	3543	4094	1	2004-04-13
2	3543	3099	1	2004-04-13
3	3543	6389	2	2004-04-13
4	3543	288	2	2004-04-13
5	3543	5396	1	2004-04-13
6	3543	4647	3	2004-04-13
7	3543	9390	2	2004-04-13
8	3543	9534	1	2004-04-13
1	3544	2454	2	2004-04-18
2	3544	2357	3	2004-04-18
3	3544	3682	3	2004-04-18
4	3544	9212	3	2004-04-18
5	3544	8719	2	2004-04-18
6	3544	6448	1	2004-04-18
1	3545	4864	2	2004-04-23
2	3545	7606	1	2004-04-23
3	3545	5177	1	2004-04-23
4	3545	8011	2	2004-04-23
1	3546	3751	3	2004-04-27
2	3546	1076	2	2004-04-27
3	3546	442	2	2004-04-27
4	3546	6073	2	2004-04-27
5	3546	1909	2	2004-04-27
1	3547	3439	3	2004-04-06
2	3547	7875	2	2004-04-06
3	3547	3181	1	2004-04-06
4	3547	9929	1	2004-04-06
5	3547	2998	2	2004-04-06
6	3547	3039	1	2004-04-06
7	3547	9671	1	2004-04-06
8	3547	8551	2	2004-04-06
1	3548	8506	1	2004-04-20
2	3548	987	2	2004-04-20
3	3548	7349	1	2004-04-20
4	3548	9863	3	2004-04-20
5	3548	3522	1	2004-04-20
6	3548	7560	3	2004-04-20
7	3548	751	2	2004-04-20
1	3549	4718	1	2004-04-11
2	3549	8534	3	2004-04-11
3	3549	2177	3	2004-04-11
4	3549	9521	1	2004-04-11
1	3550	3556	1	2004-04-13
2	3550	322	2	2004-04-13
3	3550	6113	3	2004-04-13
4	3550	7438	2	2004-04-13
5	3550	6901	1	2004-04-13
6	3550	7499	2	2004-04-13
7	3550	7920	3	2004-04-13
1	3551	4850	3	2004-04-30
2	3551	9236	2	2004-04-30
3	3551	4656	1	2004-04-30
4	3551	1588	2	2004-04-30
5	3551	2140	2	2004-04-30
6	3551	178	2	2004-04-30
7	3551	2997	2	2004-04-30
8	3551	6703	1	2004-04-30
1	3552	8791	3	2004-04-25
2	3552	6673	2	2004-04-25
3	3552	2350	2	2004-04-25
4	3552	4539	1	2004-04-25
5	3552	6014	3	2004-04-25
6	3552	310	1	2004-04-25
1	3553	958	2	2004-04-11
2	3553	2451	1	2004-04-11
3	3553	1734	1	2004-04-11
4	3553	8266	2	2004-04-11
5	3553	6361	2	2004-04-11
6	3553	8050	2	2004-04-11
7	3553	7784	3	2004-04-11
8	3553	350	2	2004-04-11
1	3554	1616	3	2004-04-21
2	3554	1521	3	2004-04-21
3	3554	4120	1	2004-04-21
4	3554	8492	3	2004-04-21
5	3554	1376	1	2004-04-21
6	3554	6012	1	2004-04-21
7	3554	8570	3	2004-04-21
8	3554	5430	1	2004-04-21
9	3554	1090	2	2004-04-21
1	3555	2087	2	2004-04-16
2	3555	2121	1	2004-04-16
3	3555	3019	3	2004-04-16
1	3556	3281	3	2004-04-29
1	3557	5138	1	2004-04-27
2	3557	9931	1	2004-04-27
3	3557	5382	3	2004-04-27
4	3557	9611	1	2004-04-27
5	3557	8804	1	2004-04-27
6	3557	4505	2	2004-04-27
7	3557	8150	1	2004-04-27
1	3558	2672	1	2004-04-21
2	3558	8089	1	2004-04-21
3	3558	8511	2	2004-04-21
4	3558	3205	1	2004-04-21
5	3558	6259	1	2004-04-21
6	3558	9191	3	2004-04-21
7	3558	9102	2	2004-04-21
8	3558	982	3	2004-04-21
9	3558	5477	2	2004-04-21
1	3559	5786	1	2004-04-23
2	3559	174	2	2004-04-23
3	3559	4847	3	2004-04-23
4	3559	4171	2	2004-04-23
5	3559	6136	3	2004-04-23
6	3559	7089	2	2004-04-23
1	3560	7389	3	2004-04-27
2	3560	4084	2	2004-04-27
1	3561	2218	2	2004-04-15
2	3561	2175	3	2004-04-15
3	3561	1469	3	2004-04-15
4	3561	6087	3	2004-04-15
5	3561	1028	2	2004-04-15
6	3561	1191	2	2004-04-15
1	3562	2204	3	2004-04-11
2	3562	3715	1	2004-04-11
3	3562	3019	2	2004-04-11
4	3562	3353	1	2004-04-11
5	3562	1248	3	2004-04-11
6	3562	6987	2	2004-04-11
7	3562	622	3	2004-04-11
8	3562	1887	1	2004-04-11
9	3562	4276	2	2004-04-11
1	3563	3000	2	2004-04-08
2	3563	4936	2	2004-04-08
3	3563	312	3	2004-04-08
4	3563	9551	1	2004-04-08
5	3563	7780	1	2004-04-08
6	3563	8065	1	2004-04-08
7	3563	2930	1	2004-04-08
8	3563	5846	2	2004-04-08
1	3564	3171	2	2004-04-05
2	3564	6372	2	2004-04-05
3	3564	7178	1	2004-04-05
4	3564	9119	3	2004-04-05
5	3564	6393	1	2004-04-05
6	3564	8442	3	2004-04-05
7	3564	6965	2	2004-04-05
8	3564	3582	3	2004-04-05
1	3565	4887	2	2004-04-06
2	3565	941	3	2004-04-06
3	3565	7068	3	2004-04-06
4	3565	4098	3	2004-04-06
5	3565	3881	3	2004-04-06
6	3565	7037	3	2004-04-06
7	3565	2155	2	2004-04-06
8	3565	2108	3	2004-04-06
9	3565	4056	1	2004-04-06
1	3566	9840	1	2004-04-28
2	3566	918	2	2004-04-28
3	3566	7995	1	2004-04-28
4	3566	6553	2	2004-04-28
5	3566	2032	1	2004-04-28
6	3566	1899	1	2004-04-28
7	3566	9255	3	2004-04-28
1	3567	1167	2	2004-04-30
2	3567	691	1	2004-04-30
3	3567	7970	1	2004-04-30
4	3567	2653	1	2004-04-30
1	3568	9292	1	2004-04-13
2	3568	8495	1	2004-04-13
3	3568	5733	2	2004-04-13
4	3568	2795	1	2004-04-13
5	3568	2404	2	2004-04-13
6	3568	3724	2	2004-04-13
7	3568	7799	1	2004-04-13
1	3569	1198	3	2004-04-10
1	3570	4687	2	2004-04-17
2	3570	5350	3	2004-04-17
3	3570	5222	3	2004-04-17
1	3571	4723	2	2004-04-20
2	3571	1471	3	2004-04-20
3	3571	8153	2	2004-04-20
4	3571	2343	1	2004-04-20
5	3571	8176	1	2004-04-20
1	3572	2237	3	2004-04-15
2	3572	8682	3	2004-04-15
1	3573	2970	2	2004-04-03
2	3573	4182	3	2004-04-03
3	3573	4088	1	2004-04-03
4	3573	2706	2	2004-04-03
5	3573	5650	3	2004-04-03
1	3574	994	3	2004-04-01
2	3574	118	3	2004-04-01
3	3574	7430	2	2004-04-01
4	3574	613	2	2004-04-01
5	3574	6157	1	2004-04-01
6	3574	4026	2	2004-04-01
7	3574	441	2	2004-04-01
8	3574	4337	1	2004-04-01
1	3575	5499	1	2004-04-01
2	3575	5131	3	2004-04-01
3	3575	5930	1	2004-04-01
4	3575	5633	2	2004-04-01
5	3575	7900	1	2004-04-01
1	3576	8063	2	2004-04-13
2	3576	9350	3	2004-04-13
3	3576	423	2	2004-04-13
4	3576	1525	2	2004-04-13
1	3577	3320	3	2004-04-02
2	3577	1987	1	2004-04-02
3	3577	4005	3	2004-04-02
4	3577	2648	3	2004-04-02
5	3577	5690	3	2004-04-02
1	3578	1899	3	2004-04-30
2	3578	6709	3	2004-04-30
3	3578	3234	2	2004-04-30
4	3578	5059	1	2004-04-30
5	3578	3446	2	2004-04-30
6	3578	8089	2	2004-04-30
7	3578	9930	3	2004-04-30
8	3578	6934	3	2004-04-30
1	3579	1193	1	2004-04-10
2	3579	2584	2	2004-04-10
3	3579	1869	3	2004-04-10
4	3579	2418	1	2004-04-10
5	3579	9595	3	2004-04-10
1	3580	1257	3	2004-04-29
2	3580	1078	2	2004-04-29
3	3580	1686	2	2004-04-29
4	3580	1796	3	2004-04-29
5	3580	9492	1	2004-04-29
6	3580	8205	2	2004-04-29
1	3581	6416	3	2004-04-03
2	3581	2378	3	2004-04-03
3	3581	1711	2	2004-04-03
4	3581	7272	2	2004-04-03
5	3581	6031	3	2004-04-03
6	3581	1141	2	2004-04-03
7	3581	8359	3	2004-04-03
8	3581	1937	3	2004-04-03
9	3581	6112	1	2004-04-03
1	3582	7571	3	2004-04-18
2	3582	9452	2	2004-04-18
3	3582	3454	1	2004-04-18
4	3582	7093	1	2004-04-18
5	3582	10	2	2004-04-18
6	3582	8002	1	2004-04-18
7	3582	2507	3	2004-04-18
1	3583	6645	2	2004-04-20
2	3583	8295	2	2004-04-20
3	3583	1990	1	2004-04-20
1	3584	5899	1	2004-04-14
1	3585	9245	1	2004-04-25
2	3585	8091	2	2004-04-25
3	3585	1396	3	2004-04-25
4	3585	9845	3	2004-04-25
5	3585	487	1	2004-04-25
6	3585	9110	3	2004-04-25
7	3585	2129	1	2004-04-25
1	3586	3776	3	2004-04-30
2	3586	8311	3	2004-04-30
3	3586	8021	1	2004-04-30
4	3586	8943	2	2004-04-30
5	3586	2339	3	2004-04-30
6	3586	7389	1	2004-04-30
7	3586	4942	2	2004-04-30
8	3586	1414	1	2004-04-30
1	3587	2207	1	2004-04-09
2	3587	5165	1	2004-04-09
3	3587	8739	3	2004-04-09
1	3588	6604	3	2004-04-13
2	3588	2115	2	2004-04-13
1	3589	4054	3	2004-04-25
2	3589	4395	1	2004-04-25
3	3589	8959	3	2004-04-25
4	3589	8075	1	2004-04-25
5	3589	2368	1	2004-04-25
6	3589	3182	2	2004-04-25
7	3589	3859	2	2004-04-25
1	3590	6317	1	2004-04-16
2	3590	2381	1	2004-04-16
3	3590	3167	3	2004-04-16
4	3590	2225	2	2004-04-16
1	3591	7638	3	2004-04-12
1	3592	1368	3	2004-04-28
2	3592	8509	2	2004-04-28
3	3592	32	1	2004-04-28
4	3592	7235	2	2004-04-28
5	3592	7079	1	2004-04-28
6	3592	2914	2	2004-04-28
7	3592	6210	3	2004-04-28
8	3592	4756	3	2004-04-28
1	3593	3204	1	2004-04-05
2	3593	4297	3	2004-04-05
3	3593	1840	1	2004-04-05
4	3593	8090	1	2004-04-05
1	3594	7988	3	2004-04-12
2	3594	9070	3	2004-04-12
3	3594	9352	2	2004-04-12
4	3594	1909	2	2004-04-12
5	3594	8658	2	2004-04-12
1	3595	3456	2	2004-04-01
2	3595	2892	1	2004-04-01
3	3595	9502	2	2004-04-01
4	3595	2501	2	2004-04-01
5	3595	4715	2	2004-04-01
1	3596	1806	2	2004-04-18
2	3596	5032	3	2004-04-18
3	3596	2172	2	2004-04-18
4	3596	7812	1	2004-04-18
5	3596	406	3	2004-04-18
6	3596	7954	3	2004-04-18
7	3596	4543	3	2004-04-18
8	3596	3930	3	2004-04-18
9	3596	3137	3	2004-04-18
1	3597	2123	1	2004-04-13
2	3597	7558	3	2004-04-13
3	3597	5254	1	2004-04-13
4	3597	9642	1	2004-04-13
1	3598	1241	3	2004-04-09
2	3598	2120	3	2004-04-09
3	3598	8815	1	2004-04-09
4	3598	8773	3	2004-04-09
5	3598	1589	1	2004-04-09
6	3598	4935	2	2004-04-09
7	3598	1909	3	2004-04-09
8	3598	2902	2	2004-04-09
1	3599	2230	3	2004-04-13
2	3599	3059	3	2004-04-13
3	3599	773	1	2004-04-13
4	3599	8093	2	2004-04-13
5	3599	4148	1	2004-04-13
6	3599	1778	2	2004-04-13
1	3600	6423	1	2004-04-02
2	3600	6085	3	2004-04-02
3	3600	6527	1	2004-04-02
4	3600	3528	3	2004-04-02
5	3600	9090	2	2004-04-02
6	3600	4601	1	2004-04-02
7	3600	7746	2	2004-04-02
8	3600	9410	3	2004-04-02
9	3600	2011	1	2004-04-02
1	3601	6542	3	2004-04-23
2	3601	8763	3	2004-04-23
3	3601	4705	3	2004-04-23
4	3601	2217	3	2004-04-23
5	3601	8584	3	2004-04-23
1	3602	5688	1	2004-04-08
2	3602	7317	2	2004-04-08
3	3602	6608	1	2004-04-08
4	3602	7966	2	2004-04-08
5	3602	6445	3	2004-04-08
6	3602	4328	3	2004-04-08
7	3602	9844	1	2004-04-08
8	3602	1238	2	2004-04-08
1	3603	6100	3	2004-04-23
2	3603	5364	3	2004-04-23
3	3603	8180	2	2004-04-23
4	3603	6956	1	2004-04-23
5	3603	8616	2	2004-04-23
6	3603	9419	2	2004-04-23
1	3604	8654	3	2004-04-12
1	3605	3553	2	2004-04-15
2	3605	856	2	2004-04-15
3	3605	9277	3	2004-04-15
4	3605	2571	2	2004-04-15
5	3605	4288	3	2004-04-15
6	3605	2641	3	2004-04-15
7	3605	6986	1	2004-04-15
8	3605	3600	2	2004-04-15
9	3605	1357	1	2004-04-15
1	3606	7511	2	2004-04-23
2	3606	1719	2	2004-04-23
1	3607	5533	2	2004-04-08
2	3607	1329	2	2004-04-08
3	3607	9606	1	2004-04-08
4	3607	4578	1	2004-04-08
5	3607	4211	3	2004-04-08
6	3607	846	3	2004-04-08
7	3607	8518	3	2004-04-08
1	3608	4332	3	2004-04-24
2	3608	9803	1	2004-04-24
3	3608	645	3	2004-04-24
4	3608	6448	1	2004-04-24
5	3608	3478	3	2004-04-24
6	3608	8825	2	2004-04-24
7	3608	6156	2	2004-04-24
8	3608	9556	3	2004-04-24
9	3608	745	3	2004-04-24
1	3609	4188	1	2004-04-25
2	3609	9151	1	2004-04-25
3	3609	13	3	2004-04-25
1	3610	1100	2	2004-04-15
2	3610	1	1	2004-04-15
3	3610	2966	2	2004-04-15
4	3610	4108	2	2004-04-15
5	3610	5539	1	2004-04-15
6	3610	1184	1	2004-04-15
7	3610	7290	1	2004-04-15
8	3610	9178	3	2004-04-15
9	3610	9901	3	2004-04-15
1	3611	3420	3	2004-04-11
2	3611	247	2	2004-04-11
3	3611	5537	2	2004-04-11
4	3611	5216	1	2004-04-11
5	3611	4219	2	2004-04-11
6	3611	7037	2	2004-04-11
7	3611	8060	1	2004-04-11
1	3612	5099	3	2004-04-02
2	3612	7900	1	2004-04-02
3	3612	8368	3	2004-04-02
4	3612	422	3	2004-04-02
5	3612	4343	2	2004-04-02
6	3612	9505	2	2004-04-02
1	3613	6357	3	2004-04-04
2	3613	6633	1	2004-04-04
1	3614	5070	2	2004-04-29
2	3614	6582	2	2004-04-29
3	3614	8113	1	2004-04-29
4	3614	1943	1	2004-04-29
5	3614	656	3	2004-04-29
6	3614	5600	3	2004-04-29
1	3615	9798	3	2004-04-21
2	3615	5169	1	2004-04-21
1	3616	5948	3	2004-04-30
2	3616	7647	2	2004-04-30
3	3616	167	2	2004-04-30
4	3616	2070	2	2004-04-30
5	3616	1479	3	2004-04-30
6	3616	973	3	2004-04-30
1	3617	2757	3	2004-04-06
2	3617	1358	3	2004-04-06
3	3617	4423	3	2004-04-06
1	3618	5337	2	2004-04-03
2	3618	3895	3	2004-04-03
3	3618	1234	3	2004-04-03
4	3618	7335	3	2004-04-03
5	3618	5332	3	2004-04-03
6	3618	4413	3	2004-04-03
1	3619	5483	3	2004-04-09
2	3619	6626	3	2004-04-09
3	3619	67	3	2004-04-09
4	3619	6688	1	2004-04-09
1	3620	5330	2	2004-04-28
2	3620	6100	1	2004-04-28
3	3620	672	3	2004-04-28
4	3620	8687	1	2004-04-28
5	3620	9835	2	2004-04-28
6	3620	786	2	2004-04-28
7	3620	3523	2	2004-04-28
8	3620	2568	2	2004-04-28
9	3620	1091	3	2004-04-28
1	3621	4859	2	2004-04-30
2	3621	5978	1	2004-04-30
3	3621	7844	2	2004-04-30
4	3621	2656	3	2004-04-30
5	3621	5030	3	2004-04-30
6	3621	3427	1	2004-04-30
1	3622	6005	1	2004-04-26
2	3622	3361	3	2004-04-26
3	3622	6124	3	2004-04-26
4	3622	1989	3	2004-04-26
5	3622	3143	1	2004-04-26
6	3622	7312	1	2004-04-26
7	3622	9653	2	2004-04-26
1	3623	6058	3	2004-04-30
2	3623	722	3	2004-04-30
3	3623	5843	2	2004-04-30
4	3623	6699	3	2004-04-30
5	3623	6880	2	2004-04-30
6	3623	3368	3	2004-04-30
1	3624	6163	2	2004-04-09
2	3624	2934	3	2004-04-09
3	3624	3774	2	2004-04-09
4	3624	1231	1	2004-04-09
5	3624	9188	1	2004-04-09
6	3624	4751	3	2004-04-09
1	3625	2763	2	2004-04-17
2	3625	165	3	2004-04-17
1	3626	2215	1	2004-04-04
2	3626	5935	2	2004-04-04
3	3626	614	2	2004-04-04
4	3626	956	3	2004-04-04
5	3626	9977	2	2004-04-04
6	3626	4927	2	2004-04-04
7	3626	9965	2	2004-04-04
8	3626	4836	3	2004-04-04
1	3627	4421	1	2004-04-22
2	3627	3885	3	2004-04-22
3	3627	7931	2	2004-04-22
1	3628	6917	1	2004-04-18
2	3628	4904	1	2004-04-18
3	3628	8031	2	2004-04-18
4	3628	7745	3	2004-04-18
1	3629	1471	1	2004-04-07
2	3629	3375	2	2004-04-07
3	3629	1992	1	2004-04-07
4	3629	5892	1	2004-04-07
5	3629	2847	1	2004-04-07
6	3629	2667	3	2004-04-07
7	3629	7495	1	2004-04-07
1	3630	6945	2	2004-04-03
2	3630	4816	1	2004-04-03
1	3631	1832	3	2004-04-29
2	3631	4813	2	2004-04-29
3	3631	6875	2	2004-04-29
4	3631	7547	1	2004-04-29
5	3631	2589	3	2004-04-29
6	3631	664	3	2004-04-29
7	3631	9576	2	2004-04-29
1	3632	2840	1	2004-04-27
2	3632	9569	1	2004-04-27
3	3632	2711	2	2004-04-27
4	3632	8918	3	2004-04-27
5	3632	8360	3	2004-04-27
6	3632	372	2	2004-04-27
1	3633	6911	1	2004-04-17
1	3634	3994	1	2004-04-20
2	3634	7521	2	2004-04-20
3	3634	6680	2	2004-04-20
4	3634	5811	3	2004-04-20
5	3634	2597	3	2004-04-20
6	3634	7941	1	2004-04-20
7	3634	1072	1	2004-04-20
8	3634	8677	3	2004-04-20
9	3634	8177	3	2004-04-20
1	3635	752	3	2004-04-25
2	3635	3783	3	2004-04-25
3	3635	398	1	2004-04-25
4	3635	2118	1	2004-04-25
1	3636	9681	1	2004-04-28
2	3636	3108	2	2004-04-28
3	3636	9673	2	2004-04-28
4	3636	4142	3	2004-04-28
5	3636	7869	2	2004-04-28
6	3636	8264	2	2004-04-28
7	3636	5202	2	2004-04-28
1	3637	7070	2	2004-04-11
2	3637	4486	1	2004-04-11
3	3637	3402	2	2004-04-11
4	3637	1087	2	2004-04-11
5	3637	7786	1	2004-04-11
6	3637	1631	2	2004-04-11
1	3638	6802	2	2004-04-22
1	3639	6157	1	2004-04-18
2	3639	384	1	2004-04-18
3	3639	8600	2	2004-04-18
4	3639	4815	2	2004-04-18
1	3640	2736	1	2004-04-01
2	3640	9677	2	2004-04-01
3	3640	8249	3	2004-04-01
4	3640	4186	3	2004-04-01
5	3640	1321	1	2004-04-01
1	3641	4213	3	2004-04-04
2	3641	8936	3	2004-04-04
3	3641	1420	2	2004-04-04
4	3641	268	1	2004-04-04
5	3641	6451	3	2004-04-04
6	3641	5769	1	2004-04-04
7	3641	2456	2	2004-04-04
8	3641	3149	1	2004-04-04
1	3642	9707	1	2004-04-03
1	3643	5237	2	2004-04-25
2	3643	7261	3	2004-04-25
3	3643	1823	1	2004-04-25
4	3643	4429	1	2004-04-25
5	3643	9582	2	2004-04-25
6	3643	5851	3	2004-04-25
7	3643	7651	1	2004-04-25
8	3643	8717	2	2004-04-25
9	3643	3566	1	2004-04-25
1	3644	2599	3	2004-04-29
1	3645	6197	1	2004-04-03
2	3645	8253	1	2004-04-03
3	3645	6698	2	2004-04-03
4	3645	8281	3	2004-04-03
5	3645	6988	1	2004-04-03
6	3645	9280	2	2004-04-03
7	3645	8558	2	2004-04-03
8	3645	6418	2	2004-04-03
9	3645	7431	2	2004-04-03
1	3646	7711	3	2004-04-29
2	3646	9490	1	2004-04-29
3	3646	6726	1	2004-04-29
4	3646	2615	3	2004-04-29
5	3646	9326	3	2004-04-29
6	3646	9821	3	2004-04-29
7	3646	245	2	2004-04-29
8	3646	3093	3	2004-04-29
9	3646	5039	1	2004-04-29
1	3647	9448	1	2004-04-04
2	3647	6001	3	2004-04-04
3	3647	8201	2	2004-04-04
4	3647	7875	2	2004-04-04
5	3647	4751	2	2004-04-04
6	3647	3766	2	2004-04-04
7	3647	5895	1	2004-04-04
8	3647	4643	3	2004-04-04
9	3647	7445	2	2004-04-04
1	3648	3783	2	2004-04-22
2	3648	6089	3	2004-04-22
3	3648	4719	3	2004-04-22
4	3648	3140	1	2004-04-22
5	3648	7116	1	2004-04-22
6	3648	4433	1	2004-04-22
7	3648	9466	1	2004-04-22
1	3649	2926	1	2004-04-27
2	3649	7735	3	2004-04-27
3	3649	1395	1	2004-04-27
4	3649	7330	3	2004-04-27
1	3650	2213	3	2004-04-20
2	3650	2533	3	2004-04-20
3	3650	8708	3	2004-04-20
4	3650	5626	1	2004-04-20
5	3650	8618	1	2004-04-20
6	3650	4434	1	2004-04-20
7	3650	5858	2	2004-04-20
8	3650	5683	2	2004-04-20
1	3651	3725	2	2004-04-04
2	3651	2985	2	2004-04-04
3	3651	8209	1	2004-04-04
4	3651	3959	2	2004-04-04
1	3652	9948	2	2004-04-15
2	3652	5477	3	2004-04-15
3	3652	2231	1	2004-04-15
4	3652	502	1	2004-04-15
5	3652	3843	2	2004-04-15
6	3652	3899	3	2004-04-15
7	3652	8833	3	2004-04-15
1	3653	4236	2	2004-04-13
2	3653	8229	3	2004-04-13
3	3653	1245	2	2004-04-13
1	3654	5265	2	2004-04-23
2	3654	9671	2	2004-04-23
3	3654	8419	2	2004-04-23
1	3655	1498	1	2004-04-12
2	3655	9303	2	2004-04-12
3	3655	9791	3	2004-04-12
4	3655	4977	2	2004-04-12
1	3656	3504	2	2004-04-25
2	3656	9663	2	2004-04-25
3	3656	1155	3	2004-04-25
1	3657	5586	3	2004-04-30
2	3657	426	2	2004-04-30
3	3657	4511	2	2004-04-30
4	3657	4655	1	2004-04-30
5	3657	8661	2	2004-04-30
1	3658	6098	2	2004-04-03
1	3659	6746	3	2004-04-15
2	3659	5938	2	2004-04-15
1	3660	9239	1	2004-04-07
2	3660	7316	2	2004-04-07
1	3661	2034	2	2004-04-08
2	3661	7930	1	2004-04-08
3	3661	9635	3	2004-04-08
4	3661	8658	1	2004-04-08
5	3661	9419	2	2004-04-08
6	3661	7706	2	2004-04-08
7	3661	9059	1	2004-04-08
1	3662	2213	1	2004-04-17
2	3662	8400	2	2004-04-17
1	3663	2462	1	2004-04-10
1	3664	4773	3	2004-04-25
1	3665	5590	2	2004-04-04
2	3665	4463	1	2004-04-04
3	3665	9222	2	2004-04-04
4	3665	4902	2	2004-04-04
5	3665	9325	2	2004-04-04
6	3665	5898	1	2004-04-04
7	3665	5078	2	2004-04-04
8	3665	7354	3	2004-04-04
9	3665	1935	2	2004-04-04
1	3666	5688	3	2004-04-27
2	3666	7602	1	2004-04-27
3	3666	4060	3	2004-04-27
4	3666	4868	3	2004-04-27
5	3666	8360	1	2004-04-27
6	3666	4785	1	2004-04-27
7	3666	3752	2	2004-04-27
1	3667	2567	2	2004-04-20
2	3667	7205	3	2004-04-20
3	3667	8793	2	2004-04-20
4	3667	5987	1	2004-04-20
5	3667	1026	2	2004-04-20
6	3667	5124	3	2004-04-20
1	3668	1271	1	2004-04-07
2	3668	8410	2	2004-04-07
3	3668	225	3	2004-04-07
4	3668	6595	2	2004-04-07
5	3668	9592	1	2004-04-07
6	3668	9015	2	2004-04-07
7	3668	8999	3	2004-04-07
8	3668	1602	1	2004-04-07
9	3668	2107	3	2004-04-07
1	3669	1626	2	2004-04-28
2	3669	106	3	2004-04-28
3	3669	3657	1	2004-04-28
4	3669	7561	1	2004-04-28
5	3669	2018	3	2004-04-28
1	3670	7197	1	2004-04-02
1	3671	2721	1	2004-04-18
2	3671	2481	2	2004-04-18
3	3671	2475	2	2004-04-18
4	3671	3128	1	2004-04-18
5	3671	5487	2	2004-04-18
1	3672	3863	2	2004-04-21
2	3672	9246	1	2004-04-21
3	3672	4648	1	2004-04-21
4	3672	255	2	2004-04-21
5	3672	1691	2	2004-04-21
6	3672	6114	3	2004-04-21
7	3672	6789	1	2004-04-21
1	3673	9608	3	2004-04-18
2	3673	2716	1	2004-04-18
3	3673	3905	2	2004-04-18
4	3673	3767	3	2004-04-18
5	3673	2336	1	2004-04-18
6	3673	6504	1	2004-04-18
7	3673	7631	1	2004-04-18
8	3673	7757	3	2004-04-18
1	3674	7674	3	2004-04-06
2	3674	7268	2	2004-04-06
1	3675	2755	1	2004-04-27
2	3675	2784	1	2004-04-27
3	3675	1907	2	2004-04-27
4	3675	4445	2	2004-04-27
1	3676	8857	1	2004-04-05
2	3676	6897	2	2004-04-05
3	3676	2071	2	2004-04-05
4	3676	3364	2	2004-04-05
1	3677	1333	1	2004-04-22
2	3677	8519	1	2004-04-22
3	3677	7226	2	2004-04-22
4	3677	4438	3	2004-04-22
5	3677	6863	3	2004-04-22
1	3678	4580	2	2004-04-08
2	3678	4998	3	2004-04-08
3	3678	7743	2	2004-04-08
4	3678	1487	2	2004-04-08
5	3678	342	2	2004-04-08
6	3678	9293	2	2004-04-08
7	3678	7417	2	2004-04-08
1	3679	6489	3	2004-04-16
2	3679	6589	2	2004-04-16
3	3679	3874	1	2004-04-16
4	3679	3695	1	2004-04-16
5	3679	8248	2	2004-04-16
6	3679	9505	1	2004-04-16
1	3680	3866	1	2004-04-09
2	3680	1678	2	2004-04-09
3	3680	7414	1	2004-04-09
4	3680	8910	3	2004-04-09
5	3680	5724	2	2004-04-09
6	3680	3059	1	2004-04-09
7	3680	9647	2	2004-04-09
8	3680	7471	2	2004-04-09
1	3681	5086	2	2004-04-12
2	3681	8353	2	2004-04-12
3	3681	9583	3	2004-04-12
4	3681	4303	1	2004-04-12
5	3681	1942	3	2004-04-12
6	3681	231	2	2004-04-12
7	3681	2110	1	2004-04-12
1	3682	6231	3	2004-04-04
1	3683	3430	3	2004-04-20
2	3683	2177	3	2004-04-20
3	3683	2110	1	2004-04-20
4	3683	4790	3	2004-04-20
5	3683	5572	1	2004-04-20
6	3683	530	2	2004-04-20
1	3684	4167	3	2004-04-03
2	3684	8747	2	2004-04-03
3	3684	9700	3	2004-04-03
1	3685	3277	2	2004-04-18
2	3685	1319	2	2004-04-18
1	3686	1922	2	2004-04-08
2	3686	6616	3	2004-04-08
3	3686	1213	1	2004-04-08
4	3686	9853	1	2004-04-08
5	3686	7341	1	2004-04-08
1	3687	2693	1	2004-04-20
1	3688	6019	1	2004-04-22
2	3688	4847	3	2004-04-22
3	3688	8788	2	2004-04-22
1	3689	5788	1	2004-04-10
2	3689	9075	1	2004-04-10
3	3689	9545	1	2004-04-10
4	3689	4590	3	2004-04-10
5	3689	2029	1	2004-04-10
1	3690	9343	3	2004-04-01
2	3690	6576	2	2004-04-01
3	3690	1916	3	2004-04-01
4	3690	9175	3	2004-04-01
1	3691	187	1	2004-04-05
1	3692	3935	2	2004-04-05
2	3692	9612	2	2004-04-05
3	3692	4800	2	2004-04-05
4	3692	2876	3	2004-04-05
5	3692	6131	1	2004-04-05
6	3692	5430	1	2004-04-05
7	3692	7162	2	2004-04-05
1	3693	2756	1	2004-04-08
2	3693	2336	2	2004-04-08
3	3693	4327	3	2004-04-08
4	3693	4414	2	2004-04-08
1	3694	3044	3	2004-04-30
2	3694	9898	1	2004-04-30
3	3694	3027	2	2004-04-30
4	3694	6857	2	2004-04-30
5	3694	1525	1	2004-04-30
1	3695	1727	3	2004-04-28
2	3695	9926	1	2004-04-28
3	3695	2834	1	2004-04-28
4	3695	3163	2	2004-04-28
5	3695	6872	3	2004-04-28
6	3695	4735	1	2004-04-28
1	3696	66	1	2004-04-07
2	3696	7163	3	2004-04-07
3	3696	2817	1	2004-04-07
4	3696	4660	3	2004-04-07
5	3696	6091	2	2004-04-07
6	3696	2660	2	2004-04-07
7	3696	3140	3	2004-04-07
1	3697	7724	3	2004-04-04
2	3697	3910	1	2004-04-04
1	3698	2066	1	2004-04-16
2	3698	4461	3	2004-04-16
3	3698	7993	2	2004-04-16
4	3698	9348	2	2004-04-16
5	3698	4489	1	2004-04-16
6	3698	5344	3	2004-04-16
7	3698	1838	1	2004-04-16
8	3698	5333	2	2004-04-16
9	3698	6552	3	2004-04-16
1	3699	9084	1	2004-04-10
1	3700	3775	1	2004-04-01
2	3700	4847	2	2004-04-01
3	3700	699	3	2004-04-01
4	3700	5026	3	2004-04-01
5	3700	3833	2	2004-04-01
1	3701	7469	3	2004-04-12
2	3701	626	1	2004-04-12
3	3701	2872	3	2004-04-12
4	3701	1274	2	2004-04-12
5	3701	5032	2	2004-04-12
6	3701	6124	2	2004-04-12
7	3701	5674	2	2004-04-12
8	3701	7109	3	2004-04-12
9	3701	1213	1	2004-04-12
1	3702	5367	1	2004-04-24
2	3702	7333	3	2004-04-24
3	3702	6123	1	2004-04-24
4	3702	7520	1	2004-04-24
5	3702	371	2	2004-04-24
6	3702	1034	1	2004-04-24
7	3702	7790	2	2004-04-24
8	3702	8172	3	2004-04-24
1	3703	7319	3	2004-04-30
2	3703	2150	2	2004-04-30
3	3703	6969	2	2004-04-30
4	3703	5310	2	2004-04-30
5	3703	9422	1	2004-04-30
6	3703	3552	2	2004-04-30
1	3704	2064	1	2004-04-12
2	3704	2565	1	2004-04-12
3	3704	6493	2	2004-04-12
4	3704	3430	2	2004-04-12
5	3704	7502	1	2004-04-12
6	3704	3346	3	2004-04-12
7	3704	4805	3	2004-04-12
8	3704	3387	1	2004-04-12
9	3704	6370	2	2004-04-12
1	3705	8249	3	2004-04-20
2	3705	3893	1	2004-04-20
1	3706	7581	2	2004-04-10
2	3706	8600	1	2004-04-10
3	3706	7182	2	2004-04-10
4	3706	3742	1	2004-04-10
5	3706	9375	1	2004-04-10
6	3706	2212	1	2004-04-10
7	3706	8626	3	2004-04-10
1	3707	7549	2	2004-04-30
2	3707	9448	2	2004-04-30
3	3707	7546	3	2004-04-30
4	3707	4768	1	2004-04-30
5	3707	9497	3	2004-04-30
6	3707	9113	1	2004-04-30
1	3708	6837	2	2004-04-15
2	3708	8662	1	2004-04-15
3	3708	4721	3	2004-04-15
4	3708	1821	3	2004-04-15
1	3709	2458	1	2004-04-03
1	3710	6453	2	2004-04-20
2	3710	3751	1	2004-04-20
3	3710	7755	1	2004-04-20
4	3710	9097	3	2004-04-20
5	3710	5428	2	2004-04-20
6	3710	3560	1	2004-04-20
1	3711	975	1	2004-04-23
2	3711	4335	1	2004-04-23
3	3711	8119	2	2004-04-23
4	3711	3241	1	2004-04-23
5	3711	5589	2	2004-04-23
6	3711	5151	1	2004-04-23
1	3712	240	1	2004-04-18
2	3712	3378	3	2004-04-18
1	3713	6542	3	2004-04-16
1	3714	477	3	2004-04-10
2	3714	682	2	2004-04-10
3	3714	2587	3	2004-04-10
4	3714	9902	2	2004-04-10
5	3714	865	2	2004-04-10
6	3714	1526	2	2004-04-10
7	3714	7685	3	2004-04-10
8	3714	9938	2	2004-04-10
9	3714	9387	1	2004-04-10
1	3715	5238	1	2004-04-24
2	3715	3852	1	2004-04-24
3	3715	1454	3	2004-04-24
1	3716	63	3	2004-04-18
2	3716	1244	1	2004-04-18
3	3716	5857	1	2004-04-18
4	3716	8478	3	2004-04-18
5	3716	6636	1	2004-04-18
6	3716	2737	2	2004-04-18
1	3717	2852	3	2004-04-22
2	3717	9382	1	2004-04-22
3	3717	1364	2	2004-04-22
4	3717	4056	2	2004-04-22
5	3717	6398	2	2004-04-22
6	3717	2096	1	2004-04-22
1	3718	5528	1	2004-04-18
2	3718	8493	1	2004-04-18
3	3718	1176	3	2004-04-18
4	3718	8105	3	2004-04-18
5	3718	6973	1	2004-04-18
6	3718	2131	2	2004-04-18
1	3719	569	1	2004-04-11
2	3719	7390	1	2004-04-11
3	3719	4824	1	2004-04-11
4	3719	7148	1	2004-04-11
5	3719	6955	3	2004-04-11
6	3719	3576	1	2004-04-11
1	3720	2394	3	2004-04-24
2	3720	4627	2	2004-04-24
3	3720	4040	1	2004-04-24
1	3721	5216	3	2004-04-05
2	3721	5894	2	2004-04-05
3	3721	3456	2	2004-04-05
4	3721	6243	1	2004-04-05
1	3722	2287	3	2004-04-26
2	3722	4787	2	2004-04-26
3	3722	1980	1	2004-04-26
4	3722	8225	1	2004-04-26
5	3722	5745	1	2004-04-26
1	3723	3103	2	2004-04-23
2	3723	2677	3	2004-04-23
1	3724	3931	3	2004-04-28
2	3724	1435	1	2004-04-28
3	3724	8065	3	2004-04-28
4	3724	1238	1	2004-04-28
5	3724	5374	2	2004-04-28
1	3725	2662	3	2004-04-29
2	3725	2136	3	2004-04-29
1	3726	1427	1	2004-04-25
2	3726	7984	2	2004-04-25
3	3726	8555	3	2004-04-25
1	3727	9538	2	2004-04-06
2	3727	6098	3	2004-04-06
3	3727	3298	3	2004-04-06
4	3727	7957	3	2004-04-06
5	3727	861	3	2004-04-06
6	3727	8831	1	2004-04-06
1	3728	9898	2	2004-04-28
2	3728	1034	3	2004-04-28
1	3729	6562	3	2004-04-26
2	3729	3550	3	2004-04-26
3	3729	1426	2	2004-04-26
4	3729	4482	1	2004-04-26
5	3729	9052	1	2004-04-26
6	3729	8564	1	2004-04-26
1	3730	4078	3	2004-04-24
2	3730	9022	1	2004-04-24
3	3730	1343	3	2004-04-24
4	3730	4486	1	2004-04-24
5	3730	2967	2	2004-04-24
6	3730	9915	1	2004-04-24
7	3730	7979	1	2004-04-24
8	3730	7959	2	2004-04-24
1	3731	7092	3	2004-04-29
1	3732	8493	2	2004-04-06
1	3733	9363	2	2004-04-22
2	3733	4339	1	2004-04-22
1	3734	4343	1	2004-04-03
2	3734	5182	1	2004-04-03
3	3734	2328	1	2004-04-03
4	3734	6861	1	2004-04-03
1	3735	7534	2	2004-04-14
2	3735	7883	2	2004-04-14
1	3736	5887	2	2004-04-17
2	3736	3562	2	2004-04-17
3	3736	472	3	2004-04-17
1	3737	4928	1	2004-04-18
2	3737	9762	1	2004-04-18
3	3737	3389	1	2004-04-18
4	3737	3249	1	2004-04-18
5	3737	3992	3	2004-04-18
6	3737	206	3	2004-04-18
7	3737	9638	3	2004-04-18
8	3737	1759	3	2004-04-18
1	3738	9586	3	2004-04-11
2	3738	1795	1	2004-04-11
3	3738	5032	1	2004-04-11
4	3738	1048	1	2004-04-11
5	3738	3483	3	2004-04-11
1	3739	8519	1	2004-04-27
2	3739	739	1	2004-04-27
3	3739	2477	2	2004-04-27
4	3739	9665	1	2004-04-27
5	3739	1625	3	2004-04-27
6	3739	422	2	2004-04-27
7	3739	6822	2	2004-04-27
8	3739	532	1	2004-04-27
1	3740	3266	2	2004-04-28
1	3741	2085	2	2004-04-10
2	3741	4993	1	2004-04-10
3	3741	4052	2	2004-04-10
4	3741	3152	2	2004-04-10
5	3741	5278	2	2004-04-10
6	3741	9521	2	2004-04-10
1	3742	4528	1	2004-04-25
2	3742	2583	2	2004-04-25
3	3742	1780	1	2004-04-25
4	3742	5177	1	2004-04-25
5	3742	2458	3	2004-04-25
6	3742	7806	2	2004-04-25
7	3742	2755	2	2004-04-25
8	3742	2143	2	2004-04-25
1	3743	646	3	2004-04-30
2	3743	8566	2	2004-04-30
3	3743	4543	3	2004-04-30
4	3743	865	1	2004-04-30
1	3744	6173	2	2004-04-28
2	3744	8819	3	2004-04-28
3	3744	5790	2	2004-04-28
4	3744	230	3	2004-04-28
1	3745	2355	2	2004-04-08
2	3745	32	1	2004-04-08
3	3745	3084	2	2004-04-08
4	3745	5853	2	2004-04-08
5	3745	4710	2	2004-04-08
1	3746	2106	1	2004-04-29
1	3747	7857	2	2004-04-17
2	3747	9748	2	2004-04-17
1	3748	8012	2	2004-04-25
1	3749	2444	2	2004-04-18
2	3749	1767	3	2004-04-18
3	3749	8460	2	2004-04-18
4	3749	2715	3	2004-04-18
5	3749	5729	2	2004-04-18
6	3749	8627	3	2004-04-18
1	3750	6046	3	2004-04-21
2	3750	6766	2	2004-04-21
3	3750	3026	2	2004-04-21
1	3751	620	1	2004-04-18
2	3751	4147	1	2004-04-18
3	3751	7736	2	2004-04-18
4	3751	7000	3	2004-04-18
1	3752	3571	1	2004-04-15
2	3752	2822	1	2004-04-15
3	3752	9543	3	2004-04-15
4	3752	6447	1	2004-04-15
5	3752	2228	1	2004-04-15
6	3752	446	3	2004-04-15
7	3752	8284	2	2004-04-15
1	3753	7834	3	2004-04-13
2	3753	1656	1	2004-04-13
3	3753	1279	3	2004-04-13
4	3753	8571	3	2004-04-13
5	3753	8894	2	2004-04-13
6	3753	3738	2	2004-04-13
7	3753	1060	3	2004-04-13
8	3753	6582	2	2004-04-13
9	3753	9505	2	2004-04-13
1	3754	8442	3	2004-04-11
2	3754	4878	3	2004-04-11
3	3754	1106	3	2004-04-11
4	3754	779	3	2004-04-11
5	3754	8839	3	2004-04-11
6	3754	8508	1	2004-04-11
1	3755	8065	3	2004-04-02
2	3755	2619	1	2004-04-02
3	3755	3652	2	2004-04-02
4	3755	9110	1	2004-04-02
5	3755	7559	3	2004-04-02
6	3755	6357	1	2004-04-02
7	3755	4564	2	2004-04-02
8	3755	7101	1	2004-04-02
9	3755	1180	1	2004-04-02
1	3756	1782	3	2004-04-30
1	3757	75	1	2004-04-28
2	3757	8875	3	2004-04-28
3	3757	8922	1	2004-04-28
4	3757	9941	1	2004-04-28
5	3757	5171	3	2004-04-28
6	3757	2807	1	2004-04-28
7	3757	7664	3	2004-04-28
8	3757	3945	1	2004-04-28
9	3757	2708	1	2004-04-28
1	3758	6172	2	2004-04-16
2	3758	5471	3	2004-04-16
3	3758	3712	2	2004-04-16
4	3758	8242	2	2004-04-16
5	3758	4305	3	2004-04-16
1	3759	4672	2	2004-04-13
2	3759	5606	3	2004-04-13
3	3759	5447	3	2004-04-13
1	3760	5337	1	2004-04-08
2	3760	7562	1	2004-04-08
3	3760	4168	1	2004-04-08
4	3760	5531	1	2004-04-08
5	3760	4533	1	2004-04-08
6	3760	8293	3	2004-04-08
1	3761	4851	2	2004-04-17
2	3761	3076	1	2004-04-17
3	3761	9356	3	2004-04-17
4	3761	7703	2	2004-04-17
5	3761	7589	1	2004-04-17
6	3761	3373	1	2004-04-17
7	3761	6258	1	2004-04-17
8	3761	6677	1	2004-04-17
9	3761	1229	2	2004-04-17
1	3762	5736	3	2004-04-07
2	3762	8696	2	2004-04-07
3	3762	7600	2	2004-04-07
4	3762	562	3	2004-04-07
5	3762	4187	2	2004-04-07
6	3762	6137	3	2004-04-07
7	3762	6719	2	2004-04-07
1	3763	7570	2	2004-04-16
2	3763	2758	2	2004-04-16
3	3763	4773	3	2004-04-16
1	3764	1398	3	2004-04-17
2	3764	5279	3	2004-04-17
3	3764	7850	2	2004-04-17
4	3764	1161	2	2004-04-17
5	3764	8263	1	2004-04-17
6	3764	5263	1	2004-04-17
7	3764	7135	1	2004-04-17
1	3765	8274	3	2004-04-30
2	3765	7316	2	2004-04-30
3	3765	1168	1	2004-04-30
4	3765	9671	2	2004-04-30
5	3765	9508	2	2004-04-30
1	3766	1675	3	2004-04-06
2	3766	472	3	2004-04-06
3	3766	1930	1	2004-04-06
4	3766	4974	1	2004-04-06
1	3767	1634	1	2004-04-11
1	3768	5867	2	2004-04-14
2	3768	8459	3	2004-04-14
3	3768	4458	3	2004-04-14
1	3769	7145	2	2004-04-09
2	3769	8255	3	2004-04-09
3	3769	3854	3	2004-04-09
4	3769	8343	2	2004-04-09
5	3769	358	1	2004-04-09
1	3770	4200	2	2004-04-18
2	3770	967	3	2004-04-18
3	3770	3711	3	2004-04-18
4	3770	1156	3	2004-04-18
5	3770	2420	3	2004-04-18
6	3770	6611	3	2004-04-18
7	3770	7744	3	2004-04-18
8	3770	843	1	2004-04-18
1	3771	6807	1	2004-04-14
2	3771	1482	2	2004-04-14
3	3771	6501	1	2004-04-14
1	3772	1092	3	2004-04-26
2	3772	7205	1	2004-04-26
1	3773	491	1	2004-04-25
2	3773	9060	3	2004-04-25
3	3773	9390	3	2004-04-25
4	3773	6687	1	2004-04-25
5	3773	7769	1	2004-04-25
6	3773	8220	2	2004-04-25
7	3773	3945	2	2004-04-25
8	3773	5350	2	2004-04-25
9	3773	176	1	2004-04-25
1	3774	659	2	2004-04-22
2	3774	2563	3	2004-04-22
3	3774	7475	1	2004-04-22
1	3775	79	3	2004-04-27
2	3775	6370	3	2004-04-27
3	3775	6160	1	2004-04-27
4	3775	9700	2	2004-04-27
5	3775	4246	3	2004-04-27
6	3775	8560	3	2004-04-27
7	3775	2945	2	2004-04-27
8	3775	3615	1	2004-04-27
9	3775	5759	1	2004-04-27
1	3776	5502	2	2004-04-06
2	3776	283	1	2004-04-06
3	3776	7108	3	2004-04-06
1	3777	6761	2	2004-04-02
1	3778	6850	1	2004-04-01
2	3778	7706	2	2004-04-01
3	3778	190	1	2004-04-01
4	3778	9318	2	2004-04-01
5	3778	3771	2	2004-04-01
6	3778	4684	2	2004-04-01
7	3778	5162	3	2004-04-01
8	3778	7952	1	2004-04-01
9	3778	4632	3	2004-04-01
1	3779	9143	2	2004-04-11
2	3779	4800	2	2004-04-11
3	3779	322	2	2004-04-11
4	3779	8825	3	2004-04-11
1	3780	1083	1	2004-04-15
2	3780	3031	1	2004-04-15
3	3780	4073	3	2004-04-15
1	3781	7133	1	2004-04-17
1	3782	3503	2	2004-04-04
2	3782	9118	1	2004-04-04
3	3782	1435	2	2004-04-04
4	3782	8549	1	2004-04-04
5	3782	8804	3	2004-04-04
1	3783	5857	2	2004-04-30
2	3783	180	3	2004-04-30
3	3783	4531	2	2004-04-30
4	3783	5689	1	2004-04-30
5	3783	3009	3	2004-04-30
6	3783	646	1	2004-04-30
7	3783	8306	1	2004-04-30
8	3783	1905	3	2004-04-30
9	3783	6884	2	2004-04-30
1	3784	9918	2	2004-04-08
2	3784	5827	3	2004-04-08
3	3784	3974	2	2004-04-08
4	3784	2198	3	2004-04-08
1	3785	6942	2	2004-04-17
2	3785	4	1	2004-04-17
3	3785	5689	1	2004-04-17
4	3785	652	2	2004-04-17
5	3785	3152	3	2004-04-17
6	3785	8280	2	2004-04-17
1	3786	1165	3	2004-04-18
2	3786	2485	1	2004-04-18
3	3786	5115	3	2004-04-18
4	3786	9803	3	2004-04-18
5	3786	3971	1	2004-04-18
6	3786	6110	3	2004-04-18
7	3786	54	3	2004-04-18
8	3786	5294	3	2004-04-18
1	3787	8308	1	2004-04-09
2	3787	4963	1	2004-04-09
3	3787	9232	1	2004-04-09
4	3787	6516	2	2004-04-09
5	3787	8407	3	2004-04-09
6	3787	3427	3	2004-04-09
7	3787	5492	2	2004-04-09
8	3787	654	1	2004-04-09
1	3788	2455	2	2004-04-13
2	3788	7736	1	2004-04-13
3	3788	3064	1	2004-04-13
4	3788	9502	2	2004-04-13
5	3788	8325	3	2004-04-13
6	3788	4633	2	2004-04-13
7	3788	9401	3	2004-04-13
8	3788	8092	3	2004-04-13
1	3789	1584	3	2004-04-09
2	3789	817	3	2004-04-09
1	3790	1925	3	2004-04-09
2	3790	5398	2	2004-04-09
3	3790	3179	1	2004-04-09
4	3790	6888	2	2004-04-09
5	3790	6161	2	2004-04-09
6	3790	2247	2	2004-04-09
7	3790	5515	3	2004-04-09
1	3791	3549	3	2004-04-04
2	3791	3815	3	2004-04-04
3	3791	560	2	2004-04-04
4	3791	4264	1	2004-04-04
5	3791	2475	3	2004-04-04
6	3791	2846	1	2004-04-04
7	3791	4451	2	2004-04-04
8	3791	7532	3	2004-04-04
9	3791	9150	1	2004-04-04
1	3792	2426	3	2004-04-09
2	3792	3627	3	2004-04-09
3	3792	6078	2	2004-04-09
4	3792	2856	1	2004-04-09
5	3792	3953	2	2004-04-09
6	3792	1867	3	2004-04-09
7	3792	3597	1	2004-04-09
8	3792	3167	3	2004-04-09
9	3792	3802	2	2004-04-09
1	3793	1417	1	2004-04-16
2	3793	9405	1	2004-04-16
3	3793	4038	1	2004-04-16
4	3793	6603	1	2004-04-16
5	3793	1527	3	2004-04-16
6	3793	188	2	2004-04-16
7	3793	6968	2	2004-04-16
8	3793	9898	3	2004-04-16
9	3793	8819	2	2004-04-16
1	3794	3111	2	2004-04-19
2	3794	7683	3	2004-04-19
3	3794	426	1	2004-04-19
4	3794	3558	2	2004-04-19
5	3794	2345	2	2004-04-19
6	3794	9549	1	2004-04-19
7	3794	5540	2	2004-04-19
8	3794	4135	1	2004-04-19
9	3794	4576	2	2004-04-19
1	3795	1029	1	2004-04-04
2	3795	7961	3	2004-04-04
3	3795	4562	2	2004-04-04
4	3795	532	2	2004-04-04
5	3795	4010	2	2004-04-04
6	3795	964	1	2004-04-04
7	3795	554	1	2004-04-04
8	3795	4481	2	2004-04-04
1	3796	8574	2	2004-04-23
2	3796	744	1	2004-04-23
3	3796	6768	2	2004-04-23
4	3796	8369	3	2004-04-23
5	3796	82	3	2004-04-23
6	3796	6076	1	2004-04-23
7	3796	9894	2	2004-04-23
1	3797	635	1	2004-04-03
2	3797	5131	1	2004-04-03
1	3798	9794	1	2004-04-12
2	3798	5231	3	2004-04-12
3	3798	7756	2	2004-04-12
4	3798	3504	3	2004-04-12
5	3798	6513	1	2004-04-12
6	3798	3819	2	2004-04-12
7	3798	8208	2	2004-04-12
8	3798	4063	2	2004-04-12
1	3799	8411	2	2004-04-16
2	3799	7456	3	2004-04-16
3	3799	8776	1	2004-04-16
4	3799	643	1	2004-04-16
5	3799	8270	2	2004-04-16
6	3799	1107	3	2004-04-16
1	3800	142	1	2004-04-13
2	3800	482	2	2004-04-13
1	3801	8200	2	2004-04-03
2	3801	3206	1	2004-04-03
3	3801	9554	1	2004-04-03
4	3801	9177	3	2004-04-03
5	3801	8066	2	2004-04-03
6	3801	7009	3	2004-04-03
7	3801	9219	3	2004-04-03
8	3801	9542	3	2004-04-03
9	3801	1282	1	2004-04-03
1	3802	7491	3	2004-04-17
2	3802	2937	3	2004-04-17
3	3802	3783	2	2004-04-17
1	3803	915	2	2004-04-07
1	3804	8433	2	2004-04-12
2	3804	9489	2	2004-04-12
3	3804	2212	3	2004-04-12
1	3805	2402	1	2004-04-10
2	3805	9884	3	2004-04-10
3	3805	4236	3	2004-04-10
4	3805	6517	3	2004-04-10
1	3806	5617	2	2004-04-17
2	3806	8088	2	2004-04-17
3	3806	9180	1	2004-04-17
4	3806	7000	2	2004-04-17
5	3806	4623	2	2004-04-17
6	3806	1854	2	2004-04-17
7	3806	874	2	2004-04-17
1	3807	8343	3	2004-04-09
2	3807	755	3	2004-04-09
3	3807	7608	2	2004-04-09
4	3807	5601	2	2004-04-09
5	3807	2162	1	2004-04-09
6	3807	4424	1	2004-04-09
7	3807	8565	1	2004-04-09
8	3807	6385	2	2004-04-09
9	3807	6571	2	2004-04-09
1	3808	9003	2	2004-04-26
2	3808	7153	3	2004-04-26
3	3808	7966	3	2004-04-26
1	3809	2003	3	2004-04-12
2	3809	412	3	2004-04-12
1	3810	6959	3	2004-04-15
2	3810	9872	2	2004-04-15
3	3810	8197	2	2004-04-15
4	3810	2174	2	2004-04-15
5	3810	1820	1	2004-04-15
6	3810	8338	2	2004-04-15
7	3810	3634	3	2004-04-15
1	3811	757	1	2004-04-24
2	3811	9516	3	2004-04-24
3	3811	3245	1	2004-04-24
4	3811	9472	2	2004-04-24
5	3811	1128	2	2004-04-24
6	3811	9668	2	2004-04-24
1	3812	2148	1	2004-04-04
1	3813	4915	2	2004-04-22
2	3813	2895	3	2004-04-22
3	3813	1662	1	2004-04-22
4	3813	9335	3	2004-04-22
5	3813	6395	1	2004-04-22
6	3813	9938	2	2004-04-22
7	3813	9827	1	2004-04-22
8	3813	7428	3	2004-04-22
9	3813	6838	3	2004-04-22
1	3814	3132	2	2004-04-11
2	3814	5526	2	2004-04-11
3	3814	7654	1	2004-04-11
4	3814	9601	2	2004-04-11
5	3814	1761	2	2004-04-11
1	3815	5317	1	2004-04-24
2	3815	8497	1	2004-04-24
3	3815	2487	3	2004-04-24
4	3815	7621	1	2004-04-24
5	3815	1616	2	2004-04-24
6	3815	1612	3	2004-04-24
7	3815	3604	2	2004-04-24
8	3815	4959	3	2004-04-24
9	3815	9679	3	2004-04-24
1	3816	7938	1	2004-04-11
2	3816	4749	3	2004-04-11
1	3817	2325	3	2004-04-23
1	3818	9255	3	2004-04-09
2	3818	7743	1	2004-04-09
3	3818	4048	3	2004-04-09
4	3818	9323	3	2004-04-09
5	3818	4460	2	2004-04-09
1	3819	9343	2	2004-04-15
2	3819	9246	3	2004-04-15
3	3819	8707	2	2004-04-15
4	3819	6979	2	2004-04-15
5	3819	6701	1	2004-04-15
6	3819	6735	3	2004-04-15
7	3819	1001	3	2004-04-15
8	3819	9847	1	2004-04-15
1	3820	9970	2	2004-04-16
2	3820	2204	3	2004-04-16
3	3820	3080	2	2004-04-16
1	3821	5887	1	2004-04-11
2	3821	1679	2	2004-04-11
3	3821	7425	1	2004-04-11
4	3821	9126	2	2004-04-11
5	3821	6574	2	2004-04-11
6	3821	5736	1	2004-04-11
1	3822	9117	3	2004-04-15
2	3822	3798	1	2004-04-15
3	3822	942	2	2004-04-15
4	3822	5925	1	2004-04-15
5	3822	3059	3	2004-04-15
1	3823	2572	1	2004-04-30
1	3824	4635	3	2004-04-03
2	3824	2584	1	2004-04-03
3	3824	2726	3	2004-04-03
4	3824	4518	3	2004-04-03
5	3824	5056	3	2004-04-03
6	3824	2274	2	2004-04-03
7	3824	5596	2	2004-04-03
8	3824	4669	2	2004-04-03
1	3825	9598	3	2004-04-30
2	3825	9528	2	2004-04-30
3	3825	102	1	2004-04-30
1	3826	9036	1	2004-04-27
2	3826	3673	1	2004-04-27
3	3826	2194	2	2004-04-27
4	3826	9938	3	2004-04-27
5	3826	3975	2	2004-04-27
6	3826	4214	2	2004-04-27
7	3826	9166	3	2004-04-27
1	3827	4428	2	2004-04-07
2	3827	5056	2	2004-04-07
1	3828	6683	3	2004-04-17
2	3828	6480	1	2004-04-17
3	3828	6150	2	2004-04-17
4	3828	4017	3	2004-04-17
5	3828	7135	2	2004-04-17
6	3828	6220	3	2004-04-17
1	3829	6442	1	2004-04-09
2	3829	6945	3	2004-04-09
3	3829	5064	1	2004-04-09
4	3829	920	3	2004-04-09
5	3829	9322	2	2004-04-09
6	3829	3517	2	2004-04-09
7	3829	558	2	2004-04-09
1	3830	273	3	2004-04-02
2	3830	2461	2	2004-04-02
3	3830	9245	3	2004-04-02
4	3830	500	2	2004-04-02
5	3830	6667	2	2004-04-02
6	3830	5658	3	2004-04-02
7	3830	555	1	2004-04-02
1	3831	790	1	2004-04-30
2	3831	4517	1	2004-04-30
3	3831	7754	3	2004-04-30
4	3831	4954	3	2004-04-30
5	3831	1929	2	2004-04-30
1	3832	4626	2	2004-04-17
2	3832	115	2	2004-04-17
3	3832	4420	1	2004-04-17
4	3832	9335	1	2004-04-17
5	3832	4034	2	2004-04-17
6	3832	9818	2	2004-04-17
1	3833	4805	1	2004-04-22
2	3833	9730	3	2004-04-22
3	3833	2988	3	2004-04-22
4	3833	7354	3	2004-04-22
5	3833	5795	3	2004-04-22
6	3833	3360	1	2004-04-22
7	3833	4484	2	2004-04-22
8	3833	7171	3	2004-04-22
1	3834	7899	1	2004-04-02
2	3834	6056	1	2004-04-02
3	3834	7305	2	2004-04-02
4	3834	6521	2	2004-04-02
5	3834	5653	3	2004-04-02
1	3835	9777	2	2004-04-08
2	3835	9559	3	2004-04-08
1	3836	6699	1	2004-04-08
2	3836	1495	2	2004-04-08
3	3836	5	1	2004-04-08
4	3836	1155	1	2004-04-08
5	3836	7013	3	2004-04-08
6	3836	5298	1	2004-04-08
1	3837	6998	2	2004-04-03
2	3837	6113	3	2004-04-03
3	3837	5049	3	2004-04-03
4	3837	1419	2	2004-04-03
5	3837	2068	1	2004-04-03
6	3837	1955	2	2004-04-03
7	3837	6331	3	2004-04-03
1	3838	6899	3	2004-04-01
2	3838	3790	3	2004-04-01
1	3839	3869	3	2004-04-07
2	3839	149	1	2004-04-07
3	3839	5596	3	2004-04-07
4	3839	7402	1	2004-04-07
5	3839	6489	1	2004-04-07
6	3839	9306	3	2004-04-07
7	3839	7276	1	2004-04-07
1	3840	7596	2	2004-04-27
2	3840	8245	3	2004-04-27
3	3840	7850	2	2004-04-27
4	3840	6124	1	2004-04-27
5	3840	3197	3	2004-04-27
1	3841	8392	2	2004-04-08
2	3841	9120	2	2004-04-08
3	3841	3215	2	2004-04-08
4	3841	5696	3	2004-04-08
5	3841	8971	2	2004-04-08
6	3841	7612	2	2004-04-08
1	3842	1712	1	2004-04-20
2	3842	8331	3	2004-04-20
3	3842	9930	2	2004-04-20
1	3843	4426	1	2004-04-16
2	3843	8597	1	2004-04-16
3	3843	6572	3	2004-04-16
4	3843	6415	2	2004-04-16
5	3843	976	3	2004-04-16
6	3843	2212	3	2004-04-16
7	3843	9333	1	2004-04-16
8	3843	1672	3	2004-04-16
1	3844	273	2	2004-04-23
2	3844	5976	3	2004-04-23
3	3844	5107	2	2004-04-23
1	3845	8502	2	2004-04-15
2	3845	2865	3	2004-04-15
3	3845	6729	3	2004-04-15
1	3846	2773	3	2004-04-13
2	3846	1732	1	2004-04-13
3	3846	8522	2	2004-04-13
4	3846	9049	2	2004-04-13
5	3846	1449	1	2004-04-13
1	3847	324	1	2004-04-27
2	3847	736	2	2004-04-27
3	3847	2952	1	2004-04-27
4	3847	7711	1	2004-04-27
5	3847	9076	1	2004-04-27
1	3848	8948	2	2004-04-26
2	3848	7697	1	2004-04-26
3	3848	2478	3	2004-04-26
1	3849	6950	2	2004-04-12
2	3849	5361	2	2004-04-12
3	3849	6001	1	2004-04-12
1	3850	1432	3	2004-04-02
2	3850	4062	3	2004-04-02
1	3851	8942	3	2004-04-01
2	3851	1333	3	2004-04-01
3	3851	4870	3	2004-04-01
4	3851	9610	3	2004-04-01
5	3851	8457	2	2004-04-01
6	3851	8347	1	2004-04-01
7	3851	6306	2	2004-04-01
8	3851	5568	1	2004-04-01
1	3852	7892	1	2004-04-04
2	3852	3101	3	2004-04-04
1	3853	299	3	2004-04-28
2	3853	7950	3	2004-04-28
3	3853	7916	3	2004-04-28
4	3853	7130	1	2004-04-28
5	3853	8312	3	2004-04-28
6	3853	132	3	2004-04-28
7	3853	173	3	2004-04-28
8	3853	8056	2	2004-04-28
9	3853	3774	2	2004-04-28
1	3854	6605	1	2004-04-25
2	3854	3218	3	2004-04-25
3	3854	2406	1	2004-04-25
1	3855	9057	3	2004-04-21
2	3855	6406	3	2004-04-21
3	3855	8805	2	2004-04-21
4	3855	9757	3	2004-04-21
5	3855	274	3	2004-04-21
6	3855	3884	1	2004-04-21
7	3855	8367	1	2004-04-21
1	3856	7013	1	2004-04-21
2	3856	7878	2	2004-04-21
3	3856	3835	1	2004-04-21
4	3856	3322	2	2004-04-21
5	3856	3418	1	2004-04-21
1	3857	4514	2	2004-04-22
2	3857	3140	1	2004-04-22
3	3857	7293	1	2004-04-22
4	3857	434	3	2004-04-22
5	3857	2784	2	2004-04-22
6	3857	8013	1	2004-04-22
1	3858	6	1	2004-04-19
2	3858	2570	3	2004-04-19
1	3859	2644	1	2004-04-12
2	3859	7428	3	2004-04-12
3	3859	7388	2	2004-04-12
4	3859	5923	1	2004-04-12
5	3859	8538	3	2004-04-12
6	3859	5219	2	2004-04-12
7	3859	1959	2	2004-04-12
1	3860	5893	2	2004-04-11
2	3860	6346	3	2004-04-11
1	3861	4234	2	2004-04-25
1	3862	5610	3	2004-04-22
2	3862	9415	1	2004-04-22
3	3862	2849	2	2004-04-22
4	3862	4898	1	2004-04-22
5	3862	4400	1	2004-04-22
6	3862	7217	2	2004-04-22
7	3862	5769	1	2004-04-22
8	3862	1101	2	2004-04-22
9	3862	2022	3	2004-04-22
1	3863	4717	2	2004-04-06
1	3864	2164	3	2004-04-02
2	3864	7292	3	2004-04-02
3	3864	7770	3	2004-04-02
4	3864	770	1	2004-04-02
5	3864	2044	2	2004-04-02
6	3864	2004	2	2004-04-02
7	3864	5784	3	2004-04-02
1	3865	7290	1	2004-04-09
2	3865	896	3	2004-04-09
3	3865	221	3	2004-04-09
4	3865	9257	2	2004-04-09
1	3866	7506	2	2004-04-09
2	3866	1492	2	2004-04-09
1	3867	9879	2	2004-04-12
2	3867	260	1	2004-04-12
3	3867	9990	2	2004-04-12
4	3867	1103	1	2004-04-12
5	3867	7595	1	2004-04-12
1	3868	4136	1	2004-04-21
2	3868	4662	2	2004-04-21
3	3868	7948	3	2004-04-21
4	3868	3266	1	2004-04-21
5	3868	9182	1	2004-04-21
6	3868	7887	1	2004-04-21
7	3868	5569	1	2004-04-21
1	3869	619	2	2004-04-30
2	3869	1696	1	2004-04-30
3	3869	2605	1	2004-04-30
4	3869	3401	1	2004-04-30
5	3869	3735	1	2004-04-30
6	3869	5083	2	2004-04-30
7	3869	7685	3	2004-04-30
8	3869	9534	1	2004-04-30
9	3869	2611	3	2004-04-30
1	3870	6647	3	2004-04-30
2	3870	9591	1	2004-04-30
3	3870	8913	3	2004-04-30
4	3870	9288	2	2004-04-30
5	3870	9338	3	2004-04-30
6	3870	1777	1	2004-04-30
7	3870	516	2	2004-04-30
8	3870	3832	2	2004-04-30
9	3870	4580	3	2004-04-30
1	3871	8881	2	2004-04-13
2	3871	4041	1	2004-04-13
1	3872	2696	2	2004-04-04
1	3873	1811	2	2004-04-23
2	3873	1752	1	2004-04-23
3	3873	5422	2	2004-04-23
4	3873	2183	2	2004-04-23
5	3873	7909	2	2004-04-23
6	3873	9853	1	2004-04-23
1	3874	5557	1	2004-04-11
2	3874	1294	3	2004-04-11
3	3874	2524	1	2004-04-11
4	3874	3375	3	2004-04-11
5	3874	2820	2	2004-04-11
6	3874	3904	1	2004-04-11
7	3874	8356	1	2004-04-11
1	3875	1315	1	2004-04-21
2	3875	2260	2	2004-04-21
3	3875	7007	1	2004-04-21
4	3875	9512	3	2004-04-21
5	3875	2657	1	2004-04-21
6	3875	722	2	2004-04-21
7	3875	762	2	2004-04-21
8	3875	5840	1	2004-04-21
1	3876	8253	3	2004-04-18
2	3876	5320	1	2004-04-18
3	3876	7718	2	2004-04-18
4	3876	2289	2	2004-04-18
5	3876	3841	3	2004-04-18
6	3876	3430	2	2004-04-18
7	3876	9006	2	2004-04-18
8	3876	8653	2	2004-04-18
9	3876	5858	3	2004-04-18
1	3877	3322	1	2004-04-09
2	3877	9872	3	2004-04-09
3	3877	4071	2	2004-04-09
4	3877	7524	3	2004-04-09
1	3878	7933	2	2004-04-15
1	3879	8157	1	2004-04-12
2	3879	2987	3	2004-04-12
3	3879	7332	1	2004-04-12
4	3879	3176	1	2004-04-12
5	3879	9803	2	2004-04-12
6	3879	1703	1	2004-04-12
7	3879	9640	2	2004-04-12
8	3879	3074	3	2004-04-12
1	3880	5669	1	2004-04-13
2	3880	7484	1	2004-04-13
1	3881	5637	1	2004-04-02
2	3881	2393	2	2004-04-02
3	3881	4835	2	2004-04-02
4	3881	956	1	2004-04-02
5	3881	7020	2	2004-04-02
1	3882	7880	3	2004-04-17
2	3882	2082	1	2004-04-17
3	3882	9329	2	2004-04-17
4	3882	8098	2	2004-04-17
5	3882	7974	2	2004-04-17
6	3882	4842	2	2004-04-17
7	3882	5232	2	2004-04-17
1	3883	3404	1	2004-04-03
2	3883	303	3	2004-04-03
3	3883	7747	1	2004-04-03
4	3883	406	2	2004-04-03
5	3883	5389	2	2004-04-03
6	3883	1588	2	2004-04-03
1	3884	421	2	2004-04-09
2	3884	1167	3	2004-04-09
3	3884	9299	3	2004-04-09
4	3884	2284	2	2004-04-09
5	3884	4598	3	2004-04-09
1	3885	1980	1	2004-04-29
2	3885	1892	1	2004-04-29
3	3885	9369	3	2004-04-29
4	3885	3539	3	2004-04-29
5	3885	4404	3	2004-04-29
6	3885	5535	2	2004-04-29
7	3885	4494	3	2004-04-29
8	3885	5459	3	2004-04-29
9	3885	3253	2	2004-04-29
1	3886	3560	3	2004-04-14
2	3886	8028	3	2004-04-14
3	3886	4196	3	2004-04-14
4	3886	3628	1	2004-04-14
1	3887	7888	1	2004-04-22
2	3887	8635	1	2004-04-22
3	3887	2195	1	2004-04-22
4	3887	355	3	2004-04-22
5	3887	9030	2	2004-04-22
6	3887	6082	2	2004-04-22
7	3887	4726	3	2004-04-22
8	3887	367	3	2004-04-22
9	3887	3755	2	2004-04-22
1	3888	5472	2	2004-04-10
2	3888	8809	3	2004-04-10
1	3889	4909	1	2004-04-23
1	3890	6581	2	2004-04-10
2	3890	2959	2	2004-04-10
3	3890	9224	3	2004-04-10
4	3890	98	2	2004-04-10
5	3890	8375	1	2004-04-10
1	3891	9444	3	2004-04-10
2	3891	7697	2	2004-04-10
3	3891	2312	2	2004-04-10
4	3891	4015	3	2004-04-10
5	3891	2419	3	2004-04-10
6	3891	488	3	2004-04-10
1	3892	8751	3	2004-04-04
2	3892	9710	1	2004-04-04
3	3892	3062	3	2004-04-04
4	3892	750	1	2004-04-04
5	3892	2882	3	2004-04-04
1	3893	2612	1	2004-04-11
2	3893	5524	1	2004-04-11
3	3893	5612	3	2004-04-11
4	3893	6815	3	2004-04-11
5	3893	7710	3	2004-04-11
6	3893	8347	3	2004-04-11
7	3893	6561	3	2004-04-11
8	3893	1719	3	2004-04-11
1	3894	2179	3	2004-04-15
2	3894	3639	1	2004-04-15
3	3894	1104	2	2004-04-15
4	3894	2052	2	2004-04-15
5	3894	2666	1	2004-04-15
1	3895	5586	3	2004-04-11
2	3895	6939	1	2004-04-11
3	3895	9240	2	2004-04-11
4	3895	1633	3	2004-04-11
5	3895	2845	3	2004-04-11
6	3895	7248	2	2004-04-11
7	3895	5624	1	2004-04-11
8	3895	5033	1	2004-04-11
9	3895	6950	3	2004-04-11
1	3896	7109	1	2004-04-26
2	3896	4279	3	2004-04-26
3	3896	5495	3	2004-04-26
4	3896	5052	3	2004-04-26
5	3896	6960	1	2004-04-26
6	3896	9110	2	2004-04-26
7	3896	3037	3	2004-04-26
8	3896	8546	2	2004-04-26
9	3896	5936	1	2004-04-26
1	3897	5427	1	2004-04-09
2	3897	8991	1	2004-04-09
3	3897	8197	3	2004-04-09
4	3897	2964	3	2004-04-09
5	3897	6992	1	2004-04-09
6	3897	525	1	2004-04-09
7	3897	9846	2	2004-04-09
8	3897	9128	2	2004-04-09
1	3898	9986	3	2004-04-17
2	3898	2975	3	2004-04-17
3	3898	3240	3	2004-04-17
4	3898	9922	2	2004-04-17
5	3898	2092	2	2004-04-17
1	3899	9894	2	2004-04-14
2	3899	1015	1	2004-04-14
3	3899	3391	3	2004-04-14
4	3899	2929	2	2004-04-14
1	3900	7671	2	2004-04-28
2	3900	4491	1	2004-04-28
3	3900	75	2	2004-04-28
4	3900	1775	1	2004-04-28
5	3900	3007	2	2004-04-28
6	3900	1958	1	2004-04-28
7	3900	1114	2	2004-04-28
8	3900	8803	2	2004-04-28
1	3901	720	1	2004-04-05
2	3901	4318	2	2004-04-05
1	3902	21	3	2004-04-25
2	3902	5974	3	2004-04-25
3	3902	3409	1	2004-04-25
4	3902	896	2	2004-04-25
5	3902	4939	1	2004-04-25
6	3902	6532	3	2004-04-25
7	3902	7683	3	2004-04-25
1	3903	4496	2	2004-04-03
2	3903	5339	2	2004-04-03
3	3903	5568	2	2004-04-03
4	3903	4059	3	2004-04-03
5	3903	169	1	2004-04-03
6	3903	7132	3	2004-04-03
7	3903	9925	3	2004-04-03
8	3903	6153	2	2004-04-03
9	3903	4843	3	2004-04-03
1	3904	8408	3	2004-04-20
2	3904	9246	2	2004-04-20
1	3905	9794	3	2004-04-25
1	3906	1190	3	2004-04-15
1	3907	9552	3	2004-04-01
2	3907	4445	2	2004-04-01
3	3907	5386	3	2004-04-01
4	3907	5266	1	2004-04-01
5	3907	5027	3	2004-04-01
6	3907	3049	2	2004-04-01
7	3907	7886	1	2004-04-01
1	3908	6555	1	2004-04-29
2	3908	3792	1	2004-04-29
3	3908	7338	3	2004-04-29
4	3908	1542	3	2004-04-29
1	3909	8997	3	2004-04-13
2	3909	3203	2	2004-04-13
3	3909	5141	3	2004-04-13
4	3909	2730	1	2004-04-13
1	3910	1190	2	2004-04-02
2	3910	5680	1	2004-04-02
3	3910	2554	3	2004-04-02
4	3910	5125	3	2004-04-02
1	3911	5859	1	2004-04-01
2	3911	6163	1	2004-04-01
3	3911	3618	2	2004-04-01
4	3911	3726	1	2004-04-01
5	3911	5485	3	2004-04-01
6	3911	6057	1	2004-04-01
7	3911	5518	3	2004-04-01
1	3912	9239	3	2004-04-04
2	3912	6351	2	2004-04-04
3	3912	8446	3	2004-04-04
4	3912	3009	2	2004-04-04
5	3912	8012	1	2004-04-04
6	3912	2486	3	2004-04-04
7	3912	942	3	2004-04-04
8	3912	299	3	2004-04-04
9	3912	8354	2	2004-04-04
1	3913	9008	1	2004-04-10
2	3913	9262	2	2004-04-10
3	3913	1374	1	2004-04-10
4	3913	379	3	2004-04-10
5	3913	42	3	2004-04-10
6	3913	5647	2	2004-04-10
7	3913	4534	2	2004-04-10
8	3913	5297	3	2004-04-10
1	3914	1693	1	2004-04-23
1	3915	5907	1	2004-04-26
2	3915	8923	1	2004-04-26
3	3915	683	3	2004-04-26
4	3915	5024	3	2004-04-26
5	3915	2456	2	2004-04-26
6	3915	237	1	2004-04-26
7	3915	4312	1	2004-04-26
1	3916	4051	1	2004-04-08
2	3916	4526	1	2004-04-08
3	3916	5275	2	2004-04-08
4	3916	1860	3	2004-04-08
5	3916	7166	1	2004-04-08
6	3916	8958	2	2004-04-08
7	3916	7194	2	2004-04-08
1	3917	4047	1	2004-04-25
2	3917	8736	2	2004-04-25
3	3917	8722	3	2004-04-25
4	3917	9336	1	2004-04-25
5	3917	9251	1	2004-04-25
6	3917	2992	2	2004-04-25
7	3917	8768	3	2004-04-25
8	3917	7887	1	2004-04-25
1	3918	128	2	2004-04-27
1	3919	3949	1	2004-04-03
2	3919	4276	1	2004-04-03
3	3919	8796	3	2004-04-03
4	3919	3574	3	2004-04-03
5	3919	4825	1	2004-04-03
6	3919	6503	2	2004-04-03
7	3919	5328	2	2004-04-03
8	3919	5945	3	2004-04-03
1	3920	8006	2	2004-04-06
2	3920	2721	3	2004-04-06
3	3920	4732	1	2004-04-06
4	3920	2510	2	2004-04-06
5	3920	1933	2	2004-04-06
6	3920	3856	2	2004-04-06
7	3920	4409	3	2004-04-06
8	3920	7131	1	2004-04-06
9	3920	6455	1	2004-04-06
1	3921	5439	3	2004-04-03
2	3921	2989	1	2004-04-03
3	3921	6643	2	2004-04-03
4	3921	6095	1	2004-04-03
5	3921	4220	2	2004-04-03
6	3921	6121	3	2004-04-03
7	3921	775	1	2004-04-03
1	3922	7689	1	2004-04-30
2	3922	7602	1	2004-04-30
1	3923	5435	2	2004-04-26
2	3923	6269	3	2004-04-26
3	3923	3272	1	2004-04-26
4	3923	6757	2	2004-04-26
5	3923	3090	2	2004-04-26
1	3924	3285	1	2004-04-03
2	3924	2081	2	2004-04-03
3	3924	2375	1	2004-04-03
4	3924	7343	3	2004-04-03
5	3924	3590	2	2004-04-03
1	3925	5924	1	2004-04-28
2	3925	2855	1	2004-04-28
3	3925	8465	3	2004-04-28
4	3925	9790	1	2004-04-28
5	3925	831	2	2004-04-28
6	3925	7997	2	2004-04-28
7	3925	9945	3	2004-04-28
8	3925	3104	2	2004-04-28
1	3926	447	3	2004-04-13
2	3926	8008	3	2004-04-13
3	3926	8169	1	2004-04-13
4	3926	2821	3	2004-04-13
5	3926	2789	3	2004-04-13
6	3926	5361	3	2004-04-13
1	3927	7339	3	2004-04-08
1	3928	2089	2	2004-04-08
1	3929	1581	3	2004-04-29
2	3929	9691	1	2004-04-29
3	3929	7814	3	2004-04-29
4	3929	9817	2	2004-04-29
1	3930	2588	3	2004-04-28
2	3930	796	2	2004-04-28
1	3931	726	3	2004-04-22
2	3931	2564	3	2004-04-22
3	3931	8968	2	2004-04-22
4	3931	3482	3	2004-04-22
1	3932	3749	1	2004-04-30
2	3932	3452	1	2004-04-30
1	3933	5906	1	2004-04-29
2	3933	783	3	2004-04-29
3	3933	9865	1	2004-04-29
4	3933	3460	3	2004-04-29
5	3933	2445	3	2004-04-29
6	3933	1315	1	2004-04-29
7	3933	7661	2	2004-04-29
8	3933	301	2	2004-04-29
1	3934	8962	3	2004-04-26
2	3934	9800	1	2004-04-26
3	3934	8808	1	2004-04-26
4	3934	4273	3	2004-04-26
5	3934	6520	1	2004-04-26
6	3934	6909	1	2004-04-26
7	3934	2842	3	2004-04-26
8	3934	919	1	2004-04-26
1	3935	3648	1	2004-04-28
2	3935	4885	1	2004-04-28
1	3936	8967	1	2004-04-15
2	3936	1723	3	2004-04-15
3	3936	129	1	2004-04-15
4	3936	639	3	2004-04-15
1	3937	6728	2	2004-04-15
2	3937	3720	3	2004-04-15
1	3938	9016	1	2004-04-06
1	3939	3972	3	2004-04-09
2	3939	2800	1	2004-04-09
3	3939	1003	1	2004-04-09
4	3939	4934	1	2004-04-09
5	3939	9695	2	2004-04-09
6	3939	4248	1	2004-04-09
7	3939	3999	3	2004-04-09
1	3940	5199	2	2004-04-16
2	3940	1539	3	2004-04-16
1	3941	5711	1	2004-04-27
2	3941	354	3	2004-04-27
3	3941	8306	2	2004-04-27
4	3941	6204	1	2004-04-27
5	3941	6233	3	2004-04-27
6	3941	2872	1	2004-04-27
7	3941	9932	1	2004-04-27
1	3942	3202	3	2004-04-19
1	3943	7554	1	2004-04-05
2	3943	3514	2	2004-04-05
3	3943	5462	1	2004-04-05
4	3943	3919	1	2004-04-05
5	3943	2164	2	2004-04-05
6	3943	9722	1	2004-04-05
1	3944	3132	2	2004-04-26
2	3944	5996	1	2004-04-26
3	3944	7011	1	2004-04-26
4	3944	7243	3	2004-04-26
5	3944	2451	1	2004-04-26
1	3945	391	1	2004-04-25
2	3945	9809	2	2004-04-25
3	3945	7745	2	2004-04-25
4	3945	5378	1	2004-04-25
5	3945	6443	3	2004-04-25
6	3945	5935	2	2004-04-25
7	3945	8011	2	2004-04-25
8	3945	2090	3	2004-04-25
1	3946	8285	1	2004-04-29
2	3946	7579	2	2004-04-29
3	3946	950	1	2004-04-29
4	3946	5973	3	2004-04-29
5	3946	3851	3	2004-04-29
1	3947	8146	3	2004-04-22
2	3947	2236	2	2004-04-22
3	3947	858	3	2004-04-22
4	3947	1065	3	2004-04-22
5	3947	4844	3	2004-04-22
6	3947	1324	3	2004-04-22
7	3947	8661	1	2004-04-22
1	3948	3732	2	2004-04-07
1	3949	3680	3	2004-04-18
2	3949	1874	1	2004-04-18
1	3950	2519	1	2004-04-06
2	3950	3408	2	2004-04-06
3	3950	8718	2	2004-04-06
4	3950	168	2	2004-04-06
5	3950	3548	1	2004-04-06
6	3950	494	1	2004-04-06
7	3950	2175	1	2004-04-06
8	3950	4899	3	2004-04-06
9	3950	3087	3	2004-04-06
1	3951	992	3	2004-04-06
2	3951	2975	1	2004-04-06
3	3951	7828	2	2004-04-06
4	3951	6188	2	2004-04-06
5	3951	4598	3	2004-04-06
1	3952	2477	1	2004-04-18
2	3952	7946	2	2004-04-18
3	3952	3740	3	2004-04-18
4	3952	8233	2	2004-04-18
1	3953	1761	2	2004-04-04
2	3953	3225	2	2004-04-04
3	3953	1436	2	2004-04-04
4	3953	2063	2	2004-04-04
1	3954	5520	2	2004-04-22
2	3954	1975	1	2004-04-22
3	3954	1726	2	2004-04-22
1	3955	227	1	2004-04-17
2	3955	1957	3	2004-04-17
3	3955	5959	1	2004-04-17
4	3955	1590	1	2004-04-17
1	3956	8423	3	2004-04-22
1	3957	376	1	2004-04-14
2	3957	5003	2	2004-04-14
1	3958	1032	1	2004-04-15
2	3958	659	3	2004-04-15
3	3958	6173	1	2004-04-15
4	3958	7382	3	2004-04-15
5	3958	9345	2	2004-04-15
6	3958	1172	1	2004-04-15
1	3959	8824	1	2004-04-11
2	3959	6948	2	2004-04-11
3	3959	3193	3	2004-04-11
4	3959	5212	2	2004-04-11
5	3959	9847	1	2004-04-11
6	3959	9465	2	2004-04-11
7	3959	7190	2	2004-04-11
8	3959	1035	3	2004-04-11
9	3959	9202	1	2004-04-11
1	3960	3505	1	2004-04-17
2	3960	6280	2	2004-04-17
3	3960	2856	3	2004-04-17
1	3961	9848	2	2004-04-10
2	3961	5363	1	2004-04-10
1	3962	788	2	2004-04-15
2	3962	9383	3	2004-04-15
3	3962	2620	1	2004-04-15
4	3962	6199	1	2004-04-15
5	3962	2110	1	2004-04-15
1	3963	6609	1	2004-04-22
1	3964	6605	3	2004-04-17
2	3964	321	2	2004-04-17
3	3964	5981	2	2004-04-17
4	3964	9492	1	2004-04-17
5	3964	6257	2	2004-04-17
6	3964	5743	3	2004-04-17
7	3964	2174	2	2004-04-17
8	3964	5022	2	2004-04-17
1	3965	2978	2	2004-04-17
2	3965	2339	3	2004-04-17
3	3965	4511	3	2004-04-17
4	3965	8652	3	2004-04-17
5	3965	8412	3	2004-04-17
6	3965	8323	2	2004-04-17
7	3965	9192	3	2004-04-17
1	3966	6110	1	2004-04-05
1	3967	6978	1	2004-04-22
2	3967	4026	1	2004-04-22
3	3967	3869	1	2004-04-22
4	3967	172	3	2004-04-22
5	3967	4450	1	2004-04-22
6	3967	4521	3	2004-04-22
7	3967	1457	1	2004-04-22
8	3967	8847	3	2004-04-22
9	3967	2506	3	2004-04-22
1	3968	6868	1	2004-04-15
2	3968	7311	1	2004-04-15
3	3968	722	2	2004-04-15
4	3968	4830	3	2004-04-15
5	3968	3602	1	2004-04-15
6	3968	998	3	2004-04-15
1	3969	1713	1	2004-04-13
2	3969	7009	2	2004-04-13
3	3969	1676	3	2004-04-13
4	3969	9404	1	2004-04-13
5	3969	8334	1	2004-04-13
1	3970	9570	1	2004-04-24
2	3970	3642	3	2004-04-24
3	3970	3451	2	2004-04-24
4	3970	1250	3	2004-04-24
1	3971	2479	2	2004-04-09
2	3971	8577	1	2004-04-09
3	3971	8914	1	2004-04-09
4	3971	3461	2	2004-04-09
1	3972	5658	1	2004-04-20
2	3972	7835	2	2004-04-20
3	3972	5938	1	2004-04-20
4	3972	6852	2	2004-04-20
5	3972	1913	1	2004-04-20
6	3972	2388	2	2004-04-20
1	3973	8489	2	2004-04-15
2	3973	1280	1	2004-04-15
3	3973	8145	3	2004-04-15
4	3973	1712	3	2004-04-15
5	3973	145	2	2004-04-15
6	3973	2980	2	2004-04-15
7	3973	308	3	2004-04-15
1	3974	9314	2	2004-04-08
1	3975	6659	2	2004-04-06
2	3975	9141	1	2004-04-06
3	3975	7555	1	2004-04-06
4	3975	9086	2	2004-04-06
1	3976	222	3	2004-04-20
2	3976	1716	1	2004-04-20
3	3976	3892	2	2004-04-20
4	3976	7032	2	2004-04-20
5	3976	2062	3	2004-04-20
1	3977	8171	1	2004-04-01
2	3977	5644	3	2004-04-01
3	3977	5689	1	2004-04-01
4	3977	3619	2	2004-04-01
5	3977	3819	1	2004-04-01
6	3977	7612	1	2004-04-01
7	3977	7216	2	2004-04-01
8	3977	3270	2	2004-04-01
9	3977	8783	2	2004-04-01
1	3978	5194	1	2004-04-09
2	3978	1038	3	2004-04-09
3	3978	512	1	2004-04-09
4	3978	9402	1	2004-04-09
5	3978	681	3	2004-04-09
6	3978	2471	2	2004-04-09
7	3978	7273	3	2004-04-09
1	3979	2065	1	2004-04-26
2	3979	5350	3	2004-04-26
3	3979	4725	3	2004-04-26
1	3980	4005	2	2004-04-11
2	3980	3289	3	2004-04-11
3	3980	6858	2	2004-04-11
4	3980	6453	3	2004-04-11
5	3980	5528	2	2004-04-11
6	3980	7929	2	2004-04-11
1	3981	8559	1	2004-04-11
1	3982	2148	3	2004-04-05
2	3982	2936	3	2004-04-05
3	3982	7574	2	2004-04-05
4	3982	380	3	2004-04-05
1	3983	3583	1	2004-04-09
2	3983	507	1	2004-04-09
3	3983	9880	2	2004-04-09
4	3983	5890	3	2004-04-09
5	3983	2242	3	2004-04-09
6	3983	8207	2	2004-04-09
1	3984	8313	3	2004-04-01
2	3984	5261	1	2004-04-01
1	3985	4637	3	2004-04-26
2	3985	5749	3	2004-04-26
3	3985	2096	1	2004-04-26
4	3985	3710	2	2004-04-26
5	3985	3913	2	2004-04-26
6	3985	5714	2	2004-04-26
1	3986	919	3	2004-04-01
2	3986	7265	1	2004-04-01
3	3986	6573	1	2004-04-01
1	3987	5345	1	2004-04-08
2	3987	5996	1	2004-04-08
3	3987	7285	1	2004-04-08
4	3987	389	1	2004-04-08
5	3987	8162	1	2004-04-08
6	3987	4435	1	2004-04-08
7	3987	8162	3	2004-04-08
8	3987	6086	2	2004-04-08
1	3988	8827	2	2004-04-07
2	3988	3548	2	2004-04-07
3	3988	7330	1	2004-04-07
4	3988	9286	3	2004-04-07
1	3989	3239	2	2004-04-16
1	3990	3557	1	2004-04-10
2	3990	5900	3	2004-04-10
3	3990	4329	2	2004-04-10
4	3990	6339	1	2004-04-10
1	3991	2219	2	2004-04-24
2	3991	9810	2	2004-04-24
3	3991	1666	3	2004-04-24
4	3991	5888	1	2004-04-24
1	3992	1244	2	2004-04-22
2	3992	8339	2	2004-04-22
3	3992	6732	1	2004-04-22
4	3992	7687	1	2004-04-22
5	3992	5094	2	2004-04-22
1	3993	9836	2	2004-04-25
2	3993	3097	2	2004-04-25
3	3993	8997	2	2004-04-25
4	3993	2161	3	2004-04-25
5	3993	1082	2	2004-04-25
1	3994	7861	3	2004-04-18
2	3994	7625	3	2004-04-18
3	3994	3956	2	2004-04-18
1	3995	975	2	2004-04-11
1	3996	3872	1	2004-04-14
2	3996	7877	3	2004-04-14
3	3996	9534	3	2004-04-14
1	3997	5522	1	2004-04-07
2	3997	332	1	2004-04-07
3	3997	4574	3	2004-04-07
4	3997	8047	1	2004-04-07
1	3998	2689	3	2004-04-22
1	3999	2917	2	2004-04-06
2	3999	8673	3	2004-04-06
3	3999	6514	2	2004-04-06
4	3999	3756	2	2004-04-06
5	3999	3423	2	2004-04-06
6	3999	7742	3	2004-04-06
1	4000	3563	2	2004-04-29
2	4000	7925	1	2004-04-29
3	4000	7497	2	2004-04-29
4	4000	3612	2	2004-04-29
5	4000	5893	2	2004-04-29
6	4000	2419	3	2004-04-29
7	4000	9965	1	2004-04-29
8	4000	4004	1	2004-04-29
9	4000	6435	1	2004-04-29
1	4001	306	3	2004-05-12
2	4001	4226	3	2004-05-12
3	4001	7657	1	2004-05-12
4	4001	3611	1	2004-05-12
5	4001	1378	2	2004-05-12
6	4001	4489	2	2004-05-12
7	4001	6552	2	2004-05-12
1	4002	1755	3	2004-05-25
2	4002	1662	1	2004-05-25
1	4003	9977	3	2004-05-28
2	4003	9950	3	2004-05-28
3	4003	7019	1	2004-05-28
1	4004	3803	1	2004-05-28
2	4004	9037	2	2004-05-28
3	4004	9028	2	2004-05-28
4	4004	434	2	2004-05-28
5	4004	7482	3	2004-05-28
6	4004	2034	2	2004-05-28
1	4005	3961	1	2004-05-30
1	4006	9694	2	2004-05-16
2	4006	3643	3	2004-05-16
3	4006	5174	1	2004-05-16
4	4006	7956	2	2004-05-16
5	4006	8746	1	2004-05-16
1	4007	1306	3	2004-05-21
2	4007	1307	3	2004-05-21
3	4007	5627	2	2004-05-21
4	4007	2299	2	2004-05-21
5	4007	7128	2	2004-05-21
6	4007	6109	1	2004-05-21
1	4008	5936	1	2004-05-23
2	4008	7301	3	2004-05-23
3	4008	7511	1	2004-05-23
1	4009	7225	1	2004-05-07
1	4010	1535	1	2004-05-27
2	4010	8565	3	2004-05-27
3	4010	3678	1	2004-05-27
4	4010	2198	1	2004-05-27
5	4010	6255	3	2004-05-27
6	4010	1894	2	2004-05-27
7	4010	9341	1	2004-05-27
8	4010	6050	2	2004-05-27
9	4010	3798	2	2004-05-27
1	4011	6775	1	2004-05-16
2	4011	7488	2	2004-05-16
3	4011	5734	2	2004-05-16
4	4011	8163	2	2004-05-16
5	4011	5735	3	2004-05-16
6	4011	5105	2	2004-05-16
7	4011	6858	3	2004-05-16
1	4012	7362	1	2004-05-16
2	4012	5083	3	2004-05-16
1	4013	4483	3	2004-05-14
2	4013	9587	1	2004-05-14
3	4013	3633	2	2004-05-14
4	4013	2735	1	2004-05-14
5	4013	361	3	2004-05-14
6	4013	7079	3	2004-05-14
7	4013	3235	1	2004-05-14
8	4013	8220	3	2004-05-14
1	4014	4132	3	2004-05-23
2	4014	3688	1	2004-05-23
3	4014	8190	3	2004-05-23
1	4015	948	2	2004-05-26
1	4016	6895	3	2004-05-22
1	4017	5779	3	2004-05-06
2	4017	1654	2	2004-05-06
3	4017	7465	3	2004-05-06
4	4017	9074	2	2004-05-06
5	4017	1038	1	2004-05-06
6	4017	1294	2	2004-05-06
7	4017	4699	3	2004-05-06
8	4017	3494	1	2004-05-06
1	4018	7779	1	2004-05-07
2	4018	3636	1	2004-05-07
3	4018	719	1	2004-05-07
1	4019	1322	2	2004-05-31
2	4019	4911	1	2004-05-31
3	4019	7562	1	2004-05-31
4	4019	1741	2	2004-05-31
5	4019	6960	1	2004-05-31
6	4019	9841	3	2004-05-31
1	4020	7433	3	2004-05-24
1	4021	578	2	2004-05-14
2	4021	4637	1	2004-05-14
1	4022	313	2	2004-05-23
2	4022	8508	2	2004-05-23
3	4022	8072	2	2004-05-23
4	4022	7597	3	2004-05-23
5	4022	2704	2	2004-05-23
1	4023	7083	1	2004-05-09
1	4024	5015	2	2004-05-04
2	4024	7647	2	2004-05-04
3	4024	57	1	2004-05-04
4	4024	6888	3	2004-05-04
5	4024	6812	1	2004-05-04
1	4025	2347	2	2004-05-07
1	4026	4500	2	2004-05-21
2	4026	1980	3	2004-05-21
3	4026	6324	3	2004-05-21
4	4026	7857	3	2004-05-21
5	4026	3576	3	2004-05-21
6	4026	2888	3	2004-05-21
7	4026	1724	1	2004-05-21
8	4026	4183	1	2004-05-21
9	4026	2818	1	2004-05-21
1	4027	6754	3	2004-05-28
2	4027	1818	3	2004-05-28
1	4028	7987	2	2004-05-05
2	4028	1198	3	2004-05-05
3	4028	853	3	2004-05-05
4	4028	9028	3	2004-05-05
5	4028	4933	1	2004-05-05
1	4029	8355	2	2004-05-22
2	4029	508	1	2004-05-22
3	4029	6447	3	2004-05-22
4	4029	803	3	2004-05-22
5	4029	654	3	2004-05-22
6	4029	5671	1	2004-05-22
7	4029	6656	3	2004-05-22
8	4029	1022	2	2004-05-22
1	4030	8974	1	2004-05-07
2	4030	679	3	2004-05-07
3	4030	8804	2	2004-05-07
1	4031	4535	1	2004-05-02
2	4031	7175	2	2004-05-02
1	4032	1801	2	2004-05-10
2	4032	1316	3	2004-05-10
3	4032	7669	3	2004-05-10
4	4032	4464	3	2004-05-10
1	4033	9580	3	2004-05-12
2	4033	3006	1	2004-05-12
3	4033	4672	1	2004-05-12
1	4034	7074	1	2004-05-19
2	4034	1084	2	2004-05-19
3	4034	7191	2	2004-05-19
4	4034	7870	1	2004-05-19
5	4034	7801	3	2004-05-19
6	4034	6931	3	2004-05-19
7	4034	7141	2	2004-05-19
8	4034	7088	1	2004-05-19
9	4034	3289	1	2004-05-19
1	4035	7657	3	2004-05-25
2	4035	7864	1	2004-05-25
3	4035	8484	2	2004-05-25
4	4035	7603	2	2004-05-25
5	4035	3030	2	2004-05-25
6	4035	8249	2	2004-05-25
7	4035	8924	2	2004-05-25
1	4036	6463	2	2004-05-26
2	4036	5069	2	2004-05-26
3	4036	8704	1	2004-05-26
4	4036	5208	1	2004-05-26
5	4036	2914	1	2004-05-26
6	4036	2978	2	2004-05-26
1	4037	2962	1	2004-05-03
2	4037	2436	1	2004-05-03
3	4037	7840	2	2004-05-03
4	4037	5240	2	2004-05-03
5	4037	9578	2	2004-05-03
6	4037	1528	3	2004-05-03
7	4037	957	3	2004-05-03
8	4037	3684	3	2004-05-03
1	4038	909	2	2004-05-09
2	4038	3500	2	2004-05-09
1	4039	7111	2	2004-05-30
1	4040	636	1	2004-05-28
2	4040	6908	2	2004-05-28
1	4041	4216	1	2004-05-29
1	4042	6651	3	2004-05-30
2	4042	3869	3	2004-05-30
3	4042	5664	3	2004-05-30
1	4043	5431	1	2004-05-05
2	4043	5448	2	2004-05-05
1	4044	4091	1	2004-05-04
2	4044	7537	2	2004-05-04
1	4045	8570	2	2004-05-29
2	4045	1387	3	2004-05-29
3	4045	6195	3	2004-05-29
4	4045	6418	1	2004-05-29
1	4046	7208	1	2004-05-18
2	4046	8764	1	2004-05-18
3	4046	2231	2	2004-05-18
4	4046	7075	1	2004-05-18
5	4046	5060	1	2004-05-18
6	4046	4919	3	2004-05-18
7	4046	5744	1	2004-05-18
1	4047	8505	3	2004-05-08
2	4047	681	3	2004-05-08
3	4047	5582	3	2004-05-08
4	4047	7930	1	2004-05-08
5	4047	6938	2	2004-05-08
6	4047	4080	2	2004-05-08
7	4047	504	1	2004-05-08
1	4048	3478	1	2004-05-18
2	4048	1130	3	2004-05-18
3	4048	3955	2	2004-05-18
4	4048	7689	3	2004-05-18
5	4048	8503	1	2004-05-18
6	4048	4714	3	2004-05-18
7	4048	7107	1	2004-05-18
8	4048	7132	3	2004-05-18
1	4049	4712	1	2004-05-10
1	4050	79	1	2004-05-15
2	4050	4337	2	2004-05-15
3	4050	9483	3	2004-05-15
4	4050	5002	1	2004-05-15
5	4050	6353	3	2004-05-15
1	4051	4300	2	2004-05-21
2	4051	3694	1	2004-05-21
3	4051	6587	1	2004-05-21
4	4051	9194	3	2004-05-21
5	4051	3538	2	2004-05-21
1	4052	7041	1	2004-05-03
2	4052	372	3	2004-05-03
3	4052	3029	2	2004-05-03
4	4052	1122	1	2004-05-03
5	4052	2523	2	2004-05-03
1	4053	2916	2	2004-05-10
2	4053	4944	3	2004-05-10
3	4053	7101	3	2004-05-10
4	4053	8621	2	2004-05-10
5	4053	9462	3	2004-05-10
6	4053	3384	1	2004-05-10
7	4053	1669	2	2004-05-10
8	4053	1248	3	2004-05-10
9	4053	9421	3	2004-05-10
1	4054	4501	2	2004-05-27
2	4054	4081	3	2004-05-27
1	4055	6986	3	2004-05-09
2	4055	1463	1	2004-05-09
3	4055	6028	3	2004-05-09
4	4055	565	2	2004-05-09
5	4055	2251	1	2004-05-09
6	4055	2463	2	2004-05-09
7	4055	3025	2	2004-05-09
1	4056	2559	3	2004-05-31
2	4056	8966	3	2004-05-31
3	4056	1364	2	2004-05-31
4	4056	4493	2	2004-05-31
5	4056	489	3	2004-05-31
6	4056	2648	2	2004-05-31
7	4056	4873	3	2004-05-31
8	4056	5200	2	2004-05-31
9	4056	1561	1	2004-05-31
1	4057	2152	3	2004-05-16
2	4057	2783	2	2004-05-16
3	4057	2471	1	2004-05-16
4	4057	9447	2	2004-05-16
5	4057	1708	1	2004-05-16
6	4057	3517	1	2004-05-16
7	4057	9971	2	2004-05-16
1	4058	1606	1	2004-05-13
2	4058	1015	2	2004-05-13
3	4058	2603	2	2004-05-13
4	4058	2814	2	2004-05-13
5	4058	7442	3	2004-05-13
1	4059	1658	3	2004-05-20
2	4059	3616	2	2004-05-20
3	4059	179	1	2004-05-20
4	4059	7852	1	2004-05-20
5	4059	5068	1	2004-05-20
6	4059	2560	2	2004-05-20
7	4059	6248	3	2004-05-20
8	4059	9502	2	2004-05-20
1	4060	7586	1	2004-05-05
2	4060	8554	1	2004-05-05
3	4060	6308	2	2004-05-05
1	4061	1037	1	2004-05-26
2	4061	619	2	2004-05-26
3	4061	5101	1	2004-05-26
1	4062	4320	2	2004-05-24
2	4062	7821	1	2004-05-24
3	4062	1942	3	2004-05-24
1	4063	5607	2	2004-05-23
2	4063	8823	2	2004-05-23
3	4063	6414	2	2004-05-23
4	4063	156	2	2004-05-23
5	4063	7727	3	2004-05-23
6	4063	7500	3	2004-05-23
7	4063	442	3	2004-05-23
1	4064	8494	1	2004-05-11
2	4064	3913	1	2004-05-11
1	4065	9056	1	2004-05-22
2	4065	2049	3	2004-05-22
3	4065	7194	3	2004-05-22
4	4065	3498	2	2004-05-22
5	4065	1816	3	2004-05-22
6	4065	1146	1	2004-05-22
7	4065	4437	3	2004-05-22
8	4065	1441	1	2004-05-22
1	4066	7424	3	2004-05-24
1	4067	8730	3	2004-05-07
2	4067	7826	1	2004-05-07
3	4067	6188	3	2004-05-07
4	4067	2624	3	2004-05-07
5	4067	4365	3	2004-05-07
6	4067	5893	3	2004-05-07
1	4068	9678	1	2004-05-19
2	4068	5850	1	2004-05-19
3	4068	4147	2	2004-05-19
4	4068	3000	2	2004-05-19
5	4068	4534	1	2004-05-19
6	4068	3167	3	2004-05-19
7	4068	6340	2	2004-05-19
1	4069	7177	3	2004-05-09
1	4070	9617	1	2004-05-24
2	4070	9738	2	2004-05-24
1	4071	9722	3	2004-05-29
2	4071	9958	2	2004-05-29
3	4071	1760	1	2004-05-29
4	4071	8067	2	2004-05-29
5	4071	3380	1	2004-05-29
6	4071	3006	3	2004-05-29
7	4071	4965	2	2004-05-29
8	4071	4788	2	2004-05-29
1	4072	1765	3	2004-05-20
2	4072	5829	1	2004-05-20
3	4072	444	2	2004-05-20
4	4072	6830	3	2004-05-20
1	4073	7532	3	2004-05-10
2	4073	6666	3	2004-05-10
3	4073	1358	2	2004-05-10
1	4074	4456	1	2004-05-18
2	4074	4401	3	2004-05-18
3	4074	7034	1	2004-05-18
4	4074	1208	1	2004-05-18
5	4074	4795	1	2004-05-18
6	4074	9450	1	2004-05-18
7	4074	4353	3	2004-05-18
8	4074	6189	1	2004-05-18
1	4075	2064	3	2004-05-30
2	4075	6344	3	2004-05-30
3	4075	7260	3	2004-05-30
4	4075	3463	1	2004-05-30
5	4075	2439	3	2004-05-30
6	4075	1432	3	2004-05-30
7	4075	360	2	2004-05-30
8	4075	6138	3	2004-05-30
1	4076	317	3	2004-05-21
2	4076	2091	2	2004-05-21
1	4077	7544	2	2004-05-23
2	4077	4636	3	2004-05-23
3	4077	4258	1	2004-05-23
4	4077	8337	1	2004-05-23
5	4077	8681	1	2004-05-23
6	4077	4360	1	2004-05-23
7	4077	1227	2	2004-05-23
1	4078	8980	3	2004-05-25
2	4078	1494	3	2004-05-25
3	4078	9763	1	2004-05-25
4	4078	4136	1	2004-05-25
1	4079	8025	3	2004-05-21
2	4079	8620	1	2004-05-21
3	4079	7282	1	2004-05-21
1	4080	7416	3	2004-05-12
2	4080	3439	3	2004-05-12
3	4080	4545	1	2004-05-12
1	4081	4462	3	2004-05-01
2	4081	6043	2	2004-05-01
3	4081	8905	1	2004-05-01
4	4081	6077	2	2004-05-01
5	4081	1509	2	2004-05-01
6	4081	7715	3	2004-05-01
7	4081	3883	2	2004-05-01
8	4081	2194	1	2004-05-01
9	4081	9212	2	2004-05-01
1	4082	2360	1	2004-05-22
2	4082	2841	3	2004-05-22
3	4082	3042	1	2004-05-22
4	4082	3071	3	2004-05-22
1	4083	1757	2	2004-05-08
2	4083	8500	3	2004-05-08
3	4083	23	1	2004-05-08
4	4083	4041	3	2004-05-08
5	4083	9542	3	2004-05-08
6	4083	4072	1	2004-05-08
7	4083	9088	1	2004-05-08
8	4083	7567	2	2004-05-08
1	4084	7310	1	2004-05-22
2	4084	6154	1	2004-05-22
3	4084	5977	3	2004-05-22
4	4084	8992	3	2004-05-22
5	4084	6757	2	2004-05-22
6	4084	6578	3	2004-05-22
7	4084	9365	2	2004-05-22
8	4084	6346	3	2004-05-22
9	4084	5086	1	2004-05-22
1	4085	6361	3	2004-05-23
2	4085	4479	2	2004-05-23
1	4086	617	3	2004-05-11
2	4086	6239	3	2004-05-11
3	4086	7308	1	2004-05-11
1	4087	1026	3	2004-05-19
2	4087	1265	1	2004-05-19
3	4087	2127	3	2004-05-19
1	4088	1839	2	2004-05-31
2	4088	8098	3	2004-05-31
3	4088	3702	1	2004-05-31
4	4088	2127	3	2004-05-31
5	4088	3944	1	2004-05-31
6	4088	298	2	2004-05-31
7	4088	8731	2	2004-05-31
1	4089	2339	3	2004-05-05
2	4089	77	2	2004-05-05
3	4089	6272	1	2004-05-05
4	4089	3755	3	2004-05-05
5	4089	8951	2	2004-05-05
6	4089	5610	3	2004-05-05
7	4089	435	3	2004-05-05
1	4090	1108	3	2004-05-11
2	4090	3918	2	2004-05-11
3	4090	9547	2	2004-05-11
4	4090	9612	3	2004-05-11
5	4090	752	1	2004-05-11
6	4090	4317	3	2004-05-11
7	4090	8269	2	2004-05-11
1	4091	9687	2	2004-05-28
2	4091	3396	3	2004-05-28
3	4091	7307	3	2004-05-28
4	4091	5583	3	2004-05-28
5	4091	6452	3	2004-05-28
1	4092	9872	3	2004-05-20
2	4092	2433	3	2004-05-20
3	4092	3919	1	2004-05-20
4	4092	7697	2	2004-05-20
5	4092	2987	1	2004-05-20
6	4092	4174	1	2004-05-20
7	4092	8668	1	2004-05-20
1	4093	2462	1	2004-05-30
2	4093	7923	3	2004-05-30
3	4093	296	2	2004-05-30
4	4093	7509	3	2004-05-30
5	4093	2339	2	2004-05-30
6	4093	8846	3	2004-05-30
7	4093	1163	3	2004-05-30
8	4093	7827	2	2004-05-30
9	4093	8136	1	2004-05-30
1	4094	7845	1	2004-05-18
2	4094	9879	2	2004-05-18
3	4094	3489	3	2004-05-18
4	4094	5200	1	2004-05-18
5	4094	8764	3	2004-05-18
6	4094	2677	3	2004-05-18
7	4094	7428	1	2004-05-18
8	4094	191	2	2004-05-18
1	4095	652	3	2004-05-31
2	4095	7284	3	2004-05-31
3	4095	3475	2	2004-05-31
4	4095	224	3	2004-05-31
5	4095	1251	2	2004-05-31
6	4095	7738	3	2004-05-31
7	4095	7230	3	2004-05-31
8	4095	5608	1	2004-05-31
1	4096	8467	2	2004-05-22
2	4096	2544	2	2004-05-22
3	4096	7753	1	2004-05-22
4	4096	831	3	2004-05-22
5	4096	5263	3	2004-05-22
6	4096	6039	2	2004-05-22
1	4097	8741	2	2004-05-30
2	4097	2017	3	2004-05-30
3	4097	1257	3	2004-05-30
1	4098	9206	2	2004-05-29
2	4098	5501	1	2004-05-29
3	4098	321	2	2004-05-29
4	4098	6091	1	2004-05-29
5	4098	9861	2	2004-05-29
1	4099	241	3	2004-05-18
1	4100	2573	3	2004-05-21
2	4100	5783	2	2004-05-21
1	4101	5526	1	2004-05-30
2	4101	3191	2	2004-05-30
3	4101	6175	3	2004-05-30
4	4101	6041	2	2004-05-30
5	4101	2658	1	2004-05-30
6	4101	9360	1	2004-05-30
7	4101	5975	2	2004-05-30
8	4101	3211	3	2004-05-30
1	4102	3120	2	2004-05-19
2	4102	3756	2	2004-05-19
3	4102	4739	3	2004-05-19
1	4103	2645	1	2004-05-01
2	4103	6336	2	2004-05-01
3	4103	6836	1	2004-05-01
4	4103	4526	1	2004-05-01
5	4103	9006	3	2004-05-01
1	4104	3322	1	2004-05-16
1	4105	1727	3	2004-05-26
2	4105	8238	2	2004-05-26
3	4105	5175	1	2004-05-26
1	4106	80	3	2004-05-16
2	4106	3702	2	2004-05-16
1	4107	3413	3	2004-05-18
1	4108	9402	3	2004-05-23
2	4108	9927	3	2004-05-23
3	4108	8752	2	2004-05-23
4	4108	589	1	2004-05-23
5	4108	5773	3	2004-05-23
6	4108	5961	1	2004-05-23
7	4108	1802	1	2004-05-23
1	4109	8694	2	2004-05-20
2	4109	2897	2	2004-05-20
3	4109	6817	1	2004-05-20
4	4109	4425	1	2004-05-20
5	4109	9751	1	2004-05-20
6	4109	8649	2	2004-05-20
1	4110	5723	2	2004-05-28
2	4110	4968	2	2004-05-28
3	4110	4890	1	2004-05-28
4	4110	5136	1	2004-05-28
5	4110	1688	3	2004-05-28
6	4110	1831	3	2004-05-28
7	4110	5862	2	2004-05-28
8	4110	4573	2	2004-05-28
1	4111	9291	1	2004-05-03
2	4111	7735	3	2004-05-03
3	4111	5012	2	2004-05-03
4	4111	5085	2	2004-05-03
5	4111	4434	1	2004-05-03
6	4111	2440	1	2004-05-03
7	4111	5157	3	2004-05-03
1	4112	897	3	2004-05-21
2	4112	8538	1	2004-05-21
1	4113	8955	3	2004-05-25
2	4113	9967	3	2004-05-25
3	4113	5329	3	2004-05-25
1	4114	9447	2	2004-05-04
2	4114	9855	2	2004-05-04
3	4114	4127	1	2004-05-04
4	4114	4035	3	2004-05-04
5	4114	9703	1	2004-05-04
6	4114	9330	3	2004-05-04
1	4115	2952	2	2004-05-07
1	4116	7911	3	2004-05-16
2	4116	1798	1	2004-05-16
3	4116	7331	1	2004-05-16
4	4116	6303	2	2004-05-16
1	4117	9629	1	2004-05-28
2	4117	1121	2	2004-05-28
3	4117	2421	1	2004-05-28
4	4117	4163	1	2004-05-28
5	4117	8673	2	2004-05-28
6	4117	1975	2	2004-05-28
7	4117	6903	2	2004-05-28
8	4117	1966	1	2004-05-28
1	4118	8146	3	2004-05-16
2	4118	6164	2	2004-05-16
3	4118	611	1	2004-05-16
1	4119	8408	3	2004-05-04
1	4120	352	2	2004-05-11
2	4120	7421	3	2004-05-11
3	4120	1934	3	2004-05-11
4	4120	5382	3	2004-05-11
5	4120	4321	3	2004-05-11
6	4120	778	3	2004-05-11
1	4121	4444	3	2004-05-24
2	4121	1042	2	2004-05-24
3	4121	887	1	2004-05-24
4	4121	4636	3	2004-05-24
5	4121	2260	1	2004-05-24
6	4121	6946	2	2004-05-24
1	4122	4123	3	2004-05-08
2	4122	1949	2	2004-05-08
3	4122	7998	3	2004-05-08
1	4123	1651	1	2004-05-16
2	4123	2383	2	2004-05-16
3	4123	7662	3	2004-05-16
4	4123	2328	3	2004-05-16
5	4123	1881	1	2004-05-16
6	4123	849	2	2004-05-16
1	4124	8620	1	2004-05-08
2	4124	7716	3	2004-05-08
3	4124	5056	1	2004-05-08
4	4124	8405	3	2004-05-08
5	4124	7895	2	2004-05-08
6	4124	4333	1	2004-05-08
7	4124	8720	3	2004-05-08
8	4124	8460	1	2004-05-08
9	4124	1105	1	2004-05-08
1	4125	7469	3	2004-05-14
2	4125	9821	3	2004-05-14
3	4125	6065	1	2004-05-14
4	4125	1426	2	2004-05-14
5	4125	1400	1	2004-05-14
6	4125	7755	3	2004-05-14
1	4126	9813	3	2004-05-31
2	4126	4654	2	2004-05-31
3	4126	1636	2	2004-05-31
4	4126	3155	1	2004-05-31
5	4126	3744	2	2004-05-31
6	4126	937	3	2004-05-31
7	4126	3025	3	2004-05-31
8	4126	4628	1	2004-05-31
1	4127	6585	1	2004-05-26
2	4127	9841	3	2004-05-26
3	4127	281	3	2004-05-26
4	4127	7100	1	2004-05-26
1	4128	6901	1	2004-05-02
1	4129	8631	1	2004-05-14
2	4129	1776	3	2004-05-14
3	4129	8172	2	2004-05-14
4	4129	8172	1	2004-05-14
5	4129	5293	2	2004-05-14
6	4129	7247	2	2004-05-14
7	4129	542	2	2004-05-14
1	4130	7977	3	2004-05-14
2	4130	4746	3	2004-05-14
3	4130	6969	1	2004-05-14
4	4130	8598	2	2004-05-14
5	4130	6159	1	2004-05-14
1	4131	2715	1	2004-05-08
1	4132	3685	1	2004-05-02
2	4132	5096	1	2004-05-02
3	4132	6448	2	2004-05-02
4	4132	4763	1	2004-05-02
5	4132	6019	2	2004-05-02
6	4132	5403	2	2004-05-02
7	4132	5494	1	2004-05-02
8	4132	2376	1	2004-05-02
1	4133	3934	3	2004-05-11
2	4133	1996	2	2004-05-11
3	4133	9768	2	2004-05-11
4	4133	6664	1	2004-05-11
5	4133	5596	2	2004-05-11
6	4133	9141	3	2004-05-11
7	4133	6062	2	2004-05-11
8	4133	211	1	2004-05-11
9	4133	9874	2	2004-05-11
1	4134	9888	3	2004-05-11
2	4134	8843	1	2004-05-11
3	4134	9507	1	2004-05-11
4	4134	3237	2	2004-05-11
5	4134	1547	3	2004-05-11
6	4134	4571	2	2004-05-11
7	4134	1582	2	2004-05-11
8	4134	8252	3	2004-05-11
1	4135	3127	3	2004-05-15
2	4135	8084	2	2004-05-15
3	4135	532	3	2004-05-15
4	4135	8310	2	2004-05-15
1	4136	6905	1	2004-05-12
2	4136	5999	2	2004-05-12
3	4136	3479	3	2004-05-12
4	4136	2248	2	2004-05-12
1	4137	1157	3	2004-05-20
2	4137	6233	2	2004-05-20
3	4137	666	3	2004-05-20
4	4137	9711	2	2004-05-20
5	4137	6217	3	2004-05-20
6	4137	7130	3	2004-05-20
7	4137	5751	2	2004-05-20
8	4137	573	3	2004-05-20
1	4138	4455	3	2004-05-17
2	4138	8616	3	2004-05-17
1	4139	7681	1	2004-05-27
2	4139	2959	3	2004-05-27
3	4139	8343	3	2004-05-27
4	4139	4702	3	2004-05-27
5	4139	7385	2	2004-05-27
1	4140	350	3	2004-05-09
2	4140	5369	1	2004-05-09
3	4140	7556	1	2004-05-09
4	4140	4016	1	2004-05-09
5	4140	2873	3	2004-05-09
6	4140	222	1	2004-05-09
7	4140	6403	3	2004-05-09
8	4140	2351	3	2004-05-09
9	4140	3760	1	2004-05-09
1	4141	5909	2	2004-05-03
2	4141	8234	1	2004-05-03
3	4141	7983	1	2004-05-03
4	4141	6895	1	2004-05-03
5	4141	964	3	2004-05-03
6	4141	8146	2	2004-05-03
7	4141	8167	2	2004-05-03
8	4141	7001	1	2004-05-03
9	4141	6591	3	2004-05-03
1	4142	5600	2	2004-05-03
2	4142	6415	3	2004-05-03
3	4142	3743	3	2004-05-03
4	4142	6078	1	2004-05-03
5	4142	6525	1	2004-05-03
6	4142	6181	2	2004-05-03
7	4142	5280	2	2004-05-03
1	4143	9419	1	2004-05-18
2	4143	3088	3	2004-05-18
3	4143	8198	1	2004-05-18
4	4143	9767	2	2004-05-18
5	4143	9962	1	2004-05-18
6	4143	1600	1	2004-05-18
7	4143	7474	3	2004-05-18
1	4144	1187	1	2004-05-16
2	4144	1387	3	2004-05-16
3	4144	4623	3	2004-05-16
4	4144	2471	3	2004-05-16
5	4144	1730	3	2004-05-16
6	4144	2076	2	2004-05-16
7	4144	5019	1	2004-05-16
8	4144	8579	3	2004-05-16
1	4145	1564	3	2004-05-29
2	4145	9265	1	2004-05-29
3	4145	9479	3	2004-05-29
4	4145	362	2	2004-05-29
5	4145	626	3	2004-05-29
6	4145	3288	1	2004-05-29
7	4145	9556	2	2004-05-29
8	4145	9525	2	2004-05-29
1	4146	257	2	2004-05-07
2	4146	52	2	2004-05-07
3	4146	7650	3	2004-05-07
4	4146	3381	3	2004-05-07
1	4147	9731	2	2004-05-17
2	4147	134	3	2004-05-17
3	4147	1578	1	2004-05-17
4	4147	3721	1	2004-05-17
5	4147	7415	3	2004-05-17
6	4147	4016	3	2004-05-17
7	4147	1682	2	2004-05-17
1	4148	7893	2	2004-05-04
2	4148	1381	3	2004-05-04
3	4148	1066	3	2004-05-04
4	4148	6575	2	2004-05-04
5	4148	5759	1	2004-05-04
1	4149	6173	3	2004-05-19
2	4149	4960	3	2004-05-19
3	4149	9579	3	2004-05-19
4	4149	9954	3	2004-05-19
5	4149	5688	2	2004-05-19
6	4149	3963	3	2004-05-19
1	4150	335	3	2004-05-24
2	4150	8833	1	2004-05-24
3	4150	7128	3	2004-05-24
1	4151	5683	1	2004-05-03
2	4151	7837	2	2004-05-03
3	4151	6116	2	2004-05-03
4	4151	3717	1	2004-05-03
5	4151	1760	1	2004-05-03
6	4151	9755	1	2004-05-03
1	4152	2812	1	2004-05-01
2	4152	9360	2	2004-05-01
3	4152	6231	3	2004-05-01
4	4152	3287	2	2004-05-01
1	4153	4116	3	2004-05-05
2	4153	8659	3	2004-05-05
1	4154	504	3	2004-05-30
2	4154	6859	1	2004-05-30
3	4154	1442	2	2004-05-30
4	4154	3976	1	2004-05-30
5	4154	2056	3	2004-05-30
6	4154	5980	2	2004-05-30
1	4155	5034	1	2004-05-09
2	4155	4137	2	2004-05-09
3	4155	2670	3	2004-05-09
4	4155	8599	3	2004-05-09
5	4155	8400	3	2004-05-09
6	4155	6583	3	2004-05-09
7	4155	3753	1	2004-05-09
8	4155	3851	2	2004-05-09
9	4155	9160	1	2004-05-09
1	4156	2331	3	2004-05-21
1	4157	3649	1	2004-05-01
2	4157	2068	3	2004-05-01
3	4157	5470	2	2004-05-01
1	4158	4924	2	2004-05-16
2	4158	983	1	2004-05-16
3	4158	1767	2	2004-05-16
4	4158	2520	2	2004-05-16
1	4159	2282	2	2004-05-28
2	4159	6004	2	2004-05-28
3	4159	3024	2	2004-05-28
4	4159	2921	3	2004-05-28
5	4159	9147	2	2004-05-28
1	4160	7418	1	2004-05-02
2	4160	4089	1	2004-05-02
3	4160	4103	3	2004-05-02
4	4160	6418	2	2004-05-02
5	4160	519	3	2004-05-02
6	4160	9819	1	2004-05-02
1	4161	4319	3	2004-05-12
1	4162	6475	2	2004-05-12
2	4162	4064	2	2004-05-12
3	4162	1102	2	2004-05-12
4	4162	6834	2	2004-05-12
5	4162	494	2	2004-05-12
6	4162	6731	2	2004-05-12
7	4162	6970	1	2004-05-12
1	4163	1571	2	2004-05-12
2	4163	7152	2	2004-05-12
3	4163	4546	1	2004-05-12
4	4163	5498	3	2004-05-12
1	4164	6066	2	2004-05-28
1	4165	4673	3	2004-05-16
2	4165	2468	2	2004-05-16
3	4165	2365	3	2004-05-16
4	4165	9749	3	2004-05-16
5	4165	31	2	2004-05-16
6	4165	2721	2	2004-05-16
1	4166	9663	2	2004-05-24
2	4166	6479	2	2004-05-24
3	4166	5093	2	2004-05-24
4	4166	4430	2	2004-05-24
5	4166	5831	1	2004-05-24
1	4167	6960	2	2004-05-31
2	4167	9330	3	2004-05-31
1	4168	1029	3	2004-05-02
1	4169	8040	2	2004-05-12
1	4170	2862	3	2004-05-18
2	4170	7443	3	2004-05-18
1	4171	4117	3	2004-05-06
2	4171	3038	1	2004-05-06
1	4172	4062	3	2004-05-12
2	4172	4380	2	2004-05-12
3	4172	7785	3	2004-05-12
4	4172	8839	1	2004-05-12
1	4173	4580	1	2004-05-28
2	4173	6651	3	2004-05-28
3	4173	8797	2	2004-05-28
4	4173	4731	1	2004-05-28
5	4173	7365	1	2004-05-28
1	4174	2558	2	2004-05-08
2	4174	7907	1	2004-05-08
3	4174	8802	1	2004-05-08
4	4174	2191	1	2004-05-08
5	4174	7057	3	2004-05-08
1	4175	2773	1	2004-05-04
1	4176	4793	1	2004-05-15
2	4176	5353	3	2004-05-15
1	4177	4200	1	2004-05-06
2	4177	9745	3	2004-05-06
3	4177	7598	3	2004-05-06
4	4177	9819	2	2004-05-06
1	4178	1984	1	2004-05-30
2	4178	2571	2	2004-05-30
3	4178	749	2	2004-05-30
4	4178	5384	2	2004-05-30
5	4178	2696	3	2004-05-30
6	4178	6620	3	2004-05-30
7	4178	8633	1	2004-05-30
1	4179	4541	3	2004-05-22
2	4179	2016	2	2004-05-22
3	4179	5647	3	2004-05-22
4	4179	1936	2	2004-05-22
5	4179	6013	1	2004-05-22
6	4179	7475	2	2004-05-22
7	4179	8229	3	2004-05-22
8	4179	6287	1	2004-05-22
9	4179	3805	3	2004-05-22
1	4180	6798	3	2004-05-20
2	4180	6325	2	2004-05-20
3	4180	985	2	2004-05-20
4	4180	5766	2	2004-05-20
5	4180	2385	1	2004-05-20
6	4180	4565	2	2004-05-20
7	4180	4591	1	2004-05-20
8	4180	4014	2	2004-05-20
1	4181	5619	2	2004-05-18
2	4181	2609	1	2004-05-18
3	4181	7107	2	2004-05-18
1	4182	2085	1	2004-05-28
2	4182	346	3	2004-05-28
1	4183	7006	2	2004-05-25
2	4183	3900	1	2004-05-25
3	4183	8529	3	2004-05-25
4	4183	1782	1	2004-05-25
1	4184	609	3	2004-05-16
2	4184	9404	1	2004-05-16
3	4184	93	2	2004-05-16
1	4185	366	1	2004-05-30
2	4185	7629	1	2004-05-30
3	4185	252	2	2004-05-30
4	4185	2043	1	2004-05-30
5	4185	9051	3	2004-05-30
1	4186	1441	1	2004-05-19
2	4186	7193	2	2004-05-19
3	4186	9859	3	2004-05-19
4	4186	9552	1	2004-05-19
5	4186	7948	3	2004-05-19
1	4187	7072	2	2004-05-12
2	4187	8546	3	2004-05-12
3	4187	7067	2	2004-05-12
1	4188	9313	1	2004-05-26
1	4189	86	2	2004-05-29
2	4189	2260	3	2004-05-29
3	4189	1529	1	2004-05-29
4	4189	7039	1	2004-05-29
5	4189	2587	2	2004-05-29
6	4189	36	2	2004-05-29
7	4189	3025	2	2004-05-29
8	4189	9586	1	2004-05-29
9	4189	725	3	2004-05-29
1	4190	5108	2	2004-05-24
2	4190	5875	2	2004-05-24
3	4190	6620	2	2004-05-24
4	4190	9855	1	2004-05-24
5	4190	4974	3	2004-05-24
6	4190	5324	3	2004-05-24
1	4191	7932	1	2004-05-23
2	4191	9242	3	2004-05-23
3	4191	8210	1	2004-05-23
4	4191	3469	3	2004-05-23
1	4192	1983	1	2004-05-08
2	4192	5581	3	2004-05-08
3	4192	6169	1	2004-05-08
4	4192	1511	1	2004-05-08
5	4192	6570	1	2004-05-08
6	4192	3040	1	2004-05-08
7	4192	1306	3	2004-05-08
8	4192	8778	3	2004-05-08
9	4192	5215	3	2004-05-08
1	4193	1114	3	2004-05-09
2	4193	4288	2	2004-05-09
1	4194	6549	1	2004-05-19
2	4194	2231	1	2004-05-19
1	4195	1188	1	2004-05-25
2	4195	724	2	2004-05-25
3	4195	1697	1	2004-05-25
4	4195	2590	1	2004-05-25
5	4195	552	3	2004-05-25
6	4195	8603	1	2004-05-25
7	4195	951	3	2004-05-25
8	4195	5352	1	2004-05-25
9	4195	6948	3	2004-05-25
1	4196	5019	1	2004-05-21
2	4196	6178	3	2004-05-21
3	4196	4968	2	2004-05-21
4	4196	5649	3	2004-05-21
5	4196	3383	3	2004-05-21
1	4197	6135	2	2004-05-27
1	4198	16	1	2004-05-03
2	4198	8147	2	2004-05-03
3	4198	4472	2	2004-05-03
4	4198	5008	1	2004-05-03
5	4198	8115	1	2004-05-03
6	4198	6539	1	2004-05-03
7	4198	4138	1	2004-05-03
8	4198	383	3	2004-05-03
9	4198	6741	2	2004-05-03
1	4199	4230	2	2004-05-24
2	4199	6760	1	2004-05-24
3	4199	7582	3	2004-05-24
4	4199	7049	3	2004-05-24
5	4199	7108	3	2004-05-24
6	4199	1445	2	2004-05-24
1	4200	7034	3	2004-05-08
2	4200	8739	2	2004-05-08
3	4200	1595	1	2004-05-08
4	4200	6287	1	2004-05-08
5	4200	1983	1	2004-05-08
6	4200	8009	3	2004-05-08
7	4200	3151	1	2004-05-08
1	4201	7743	1	2004-05-19
2	4201	389	2	2004-05-19
3	4201	1423	3	2004-05-19
1	4202	8783	1	2004-05-06
2	4202	1729	2	2004-05-06
3	4202	1558	1	2004-05-06
4	4202	9387	1	2004-05-06
1	4203	8700	1	2004-05-11
2	4203	4965	1	2004-05-11
3	4203	4013	1	2004-05-11
4	4203	9230	3	2004-05-11
5	4203	3720	3	2004-05-11
1	4204	1605	2	2004-05-04
2	4204	5492	2	2004-05-04
3	4204	7908	2	2004-05-04
1	4205	104	3	2004-05-24
2	4205	2162	2	2004-05-24
3	4205	5148	3	2004-05-24
4	4205	8774	2	2004-05-24
5	4205	429	2	2004-05-24
6	4205	5697	2	2004-05-24
7	4205	4701	2	2004-05-24
8	4205	3259	3	2004-05-24
9	4205	1899	2	2004-05-24
1	4206	7282	1	2004-05-08
2	4206	8488	2	2004-05-08
3	4206	6850	2	2004-05-08
4	4206	4826	3	2004-05-08
1	4207	8377	1	2004-05-16
2	4207	4399	3	2004-05-16
3	4207	5407	2	2004-05-16
4	4207	888	1	2004-05-16
5	4207	9269	2	2004-05-16
6	4207	6030	1	2004-05-16
7	4207	4009	3	2004-05-16
1	4208	673	3	2004-05-22
2	4208	6648	3	2004-05-22
3	4208	4063	2	2004-05-22
4	4208	5099	3	2004-05-22
1	4209	7154	1	2004-05-02
2	4209	8407	1	2004-05-02
3	4209	9344	2	2004-05-02
4	4209	6380	1	2004-05-02
5	4209	4917	2	2004-05-02
6	4209	5820	1	2004-05-02
7	4209	8174	3	2004-05-02
1	4210	9233	3	2004-05-28
1	4211	9377	1	2004-05-29
2	4211	2290	3	2004-05-29
3	4211	1344	2	2004-05-29
4	4211	6658	3	2004-05-29
1	4212	8877	2	2004-05-26
2	4212	7877	2	2004-05-26
3	4212	2076	2	2004-05-26
4	4212	4739	1	2004-05-26
5	4212	3525	2	2004-05-26
6	4212	5411	3	2004-05-26
7	4212	4079	2	2004-05-26
1	4213	6819	3	2004-05-22
2	4213	4428	3	2004-05-22
3	4213	9710	2	2004-05-22
1	4214	1431	2	2004-05-17
2	4214	1162	1	2004-05-17
3	4214	745	3	2004-05-17
4	4214	4099	1	2004-05-17
1	4215	2451	3	2004-05-09
2	4215	6151	2	2004-05-09
3	4215	3123	1	2004-05-09
4	4215	9948	2	2004-05-09
5	4215	6213	3	2004-05-09
6	4215	3543	1	2004-05-09
1	4216	9618	1	2004-05-19
1	4217	1355	2	2004-05-15
2	4217	4807	2	2004-05-15
3	4217	8561	3	2004-05-15
4	4217	4291	1	2004-05-15
5	4217	3800	3	2004-05-15
6	4217	111	3	2004-05-15
1	4218	6877	3	2004-05-11
2	4218	9985	1	2004-05-11
3	4218	9885	2	2004-05-11
1	4219	6975	1	2004-05-12
2	4219	4336	1	2004-05-12
3	4219	7324	2	2004-05-12
1	4220	9671	2	2004-05-24
2	4220	7902	2	2004-05-24
3	4220	2176	3	2004-05-24
4	4220	3420	2	2004-05-24
5	4220	1246	2	2004-05-24
6	4220	8665	3	2004-05-24
1	4221	4507	1	2004-05-18
2	4221	1876	1	2004-05-18
3	4221	5498	3	2004-05-18
4	4221	3011	3	2004-05-18
5	4221	820	1	2004-05-18
6	4221	5523	3	2004-05-18
1	4222	2100	1	2004-05-08
2	4222	5604	2	2004-05-08
1	4223	5476	3	2004-05-03
2	4223	82	1	2004-05-03
1	4224	833	3	2004-05-22
2	4224	2996	2	2004-05-22
1	4225	6340	1	2004-05-24
2	4225	6825	3	2004-05-24
3	4225	8351	1	2004-05-24
4	4225	938	1	2004-05-24
5	4225	4329	2	2004-05-24
6	4225	4725	2	2004-05-24
7	4225	5566	2	2004-05-24
8	4225	7004	1	2004-05-24
1	4226	5707	3	2004-05-09
2	4226	1405	2	2004-05-09
3	4226	7589	2	2004-05-09
4	4226	2869	2	2004-05-09
5	4226	406	3	2004-05-09
6	4226	3360	3	2004-05-09
7	4226	716	1	2004-05-09
8	4226	5550	3	2004-05-09
9	4226	1810	2	2004-05-09
1	4227	1182	3	2004-05-30
2	4227	8685	3	2004-05-30
3	4227	9634	1	2004-05-30
4	4227	5270	1	2004-05-30
1	4228	7515	3	2004-05-05
2	4228	7183	1	2004-05-05
3	4228	3460	3	2004-05-05
1	4229	7003	3	2004-05-30
1	4230	4952	3	2004-05-29
2	4230	2952	2	2004-05-29
3	4230	7992	1	2004-05-29
4	4230	4318	3	2004-05-29
5	4230	3151	3	2004-05-29
6	4230	9471	2	2004-05-29
7	4230	563	1	2004-05-29
8	4230	7312	3	2004-05-29
1	4231	2083	3	2004-05-27
2	4231	8952	2	2004-05-27
1	4232	4768	1	2004-05-25
2	4232	5914	3	2004-05-25
3	4232	2065	3	2004-05-25
4	4232	5852	1	2004-05-25
5	4232	502	1	2004-05-25
6	4232	7682	2	2004-05-25
7	4232	9756	3	2004-05-25
1	4233	8397	2	2004-05-26
2	4233	9988	3	2004-05-26
3	4233	8237	1	2004-05-26
4	4233	4733	3	2004-05-26
5	4233	8486	1	2004-05-26
1	4234	7450	2	2004-05-10
2	4234	7629	3	2004-05-10
3	4234	4718	2	2004-05-10
4	4234	9571	2	2004-05-10
5	4234	3649	3	2004-05-10
6	4234	8872	2	2004-05-10
7	4234	4405	3	2004-05-10
8	4234	3724	1	2004-05-10
1	4235	8978	2	2004-05-08
2	4235	4606	2	2004-05-08
3	4235	3362	1	2004-05-08
1	4236	4415	2	2004-05-20
2	4236	2239	1	2004-05-20
3	4236	4838	3	2004-05-20
4	4236	5524	2	2004-05-20
5	4236	2176	3	2004-05-20
6	4236	1661	1	2004-05-20
1	4237	7899	1	2004-05-08
2	4237	8420	2	2004-05-08
3	4237	3183	3	2004-05-08
4	4237	2009	3	2004-05-08
5	4237	1107	2	2004-05-08
6	4237	878	3	2004-05-08
1	4238	4075	2	2004-05-06
2	4238	8334	3	2004-05-06
3	4238	3135	2	2004-05-06
4	4238	3321	2	2004-05-06
5	4238	3029	2	2004-05-06
6	4238	6357	2	2004-05-06
1	4239	5104	1	2004-05-04
2	4239	4780	3	2004-05-04
3	4239	7721	3	2004-05-04
4	4239	6074	3	2004-05-04
5	4239	2160	3	2004-05-04
6	4239	6381	2	2004-05-04
7	4239	5703	1	2004-05-04
8	4239	325	3	2004-05-04
9	4239	6500	3	2004-05-04
1	4240	4944	2	2004-05-27
2	4240	6992	1	2004-05-27
1	4241	6982	1	2004-05-04
2	4241	3378	1	2004-05-04
3	4241	9147	1	2004-05-04
1	4242	2171	2	2004-05-27
1	4243	7651	1	2004-05-15
2	4243	3726	2	2004-05-15
3	4243	2760	2	2004-05-15
4	4243	8350	3	2004-05-15
5	4243	1785	2	2004-05-15
1	4244	5988	1	2004-05-28
2	4244	5620	3	2004-05-28
3	4244	2122	2	2004-05-28
4	4244	463	1	2004-05-28
5	4244	9985	1	2004-05-28
1	4245	29	1	2004-05-05
2	4245	1189	3	2004-05-05
3	4245	6445	2	2004-05-05
4	4245	4019	3	2004-05-05
5	4245	1156	1	2004-05-05
6	4245	6907	1	2004-05-05
1	4246	668	1	2004-05-24
1	4247	1052	1	2004-05-05
2	4247	4240	1	2004-05-05
3	4247	2076	2	2004-05-05
4	4247	3192	3	2004-05-05
1	4248	900	3	2004-05-06
2	4248	7843	2	2004-05-06
3	4248	7737	3	2004-05-06
1	4249	552	3	2004-05-23
2	4249	6084	1	2004-05-23
3	4249	9673	3	2004-05-23
4	4249	7507	1	2004-05-23
5	4249	1101	3	2004-05-23
1	4250	960	1	2004-05-09
2	4250	3432	1	2004-05-09
3	4250	6007	2	2004-05-09
4	4250	5627	3	2004-05-09
5	4250	4053	2	2004-05-09
1	4251	6433	2	2004-05-06
2	4251	4104	3	2004-05-06
3	4251	2216	1	2004-05-06
4	4251	8205	1	2004-05-06
5	4251	7719	2	2004-05-06
6	4251	2787	3	2004-05-06
7	4251	4269	2	2004-05-06
8	4251	4160	2	2004-05-06
9	4251	35	2	2004-05-06
1	4252	8986	2	2004-05-21
2	4252	9563	1	2004-05-21
3	4252	6913	1	2004-05-21
1	4253	3785	2	2004-05-15
2	4253	8246	2	2004-05-15
1	4254	2161	1	2004-05-15
2	4254	1321	2	2004-05-15
3	4254	6048	2	2004-05-15
1	4255	9549	3	2004-05-01
2	4255	9598	3	2004-05-01
3	4255	1861	3	2004-05-01
4	4255	1573	3	2004-05-01
5	4255	545	2	2004-05-01
6	4255	8154	1	2004-05-01
7	4255	7661	1	2004-05-01
1	4256	2357	2	2004-05-18
1	4257	947	1	2004-05-10
2	4257	9723	1	2004-05-10
3	4257	8632	1	2004-05-10
4	4257	8180	3	2004-05-10
1	4258	6937	3	2004-05-28
1	4259	8520	1	2004-05-30
2	4259	9463	2	2004-05-30
3	4259	8254	3	2004-05-30
4	4259	4575	1	2004-05-30
5	4259	3226	3	2004-05-30
6	4259	5128	3	2004-05-30
7	4259	1738	2	2004-05-30
1	4260	1782	2	2004-05-08
1	4261	1118	1	2004-05-29
2	4261	4086	1	2004-05-29
3	4261	7688	3	2004-05-29
4	4261	8016	2	2004-05-29
5	4261	1119	3	2004-05-29
6	4261	364	3	2004-05-29
1	4262	2434	2	2004-05-16
2	4262	7830	2	2004-05-16
3	4262	1184	1	2004-05-16
4	4262	5631	3	2004-05-16
5	4262	1013	3	2004-05-16
6	4262	3989	1	2004-05-16
7	4262	7931	3	2004-05-16
8	4262	5899	3	2004-05-16
1	4263	8757	3	2004-05-24
2	4263	1360	3	2004-05-24
3	4263	5032	1	2004-05-24
4	4263	9246	3	2004-05-24
5	4263	6661	3	2004-05-24
1	4264	3265	2	2004-05-25
2	4264	5948	3	2004-05-25
3	4264	4016	3	2004-05-25
4	4264	6307	3	2004-05-25
5	4264	7059	2	2004-05-25
6	4264	5262	1	2004-05-25
1	4265	7878	1	2004-05-11
2	4265	379	3	2004-05-11
3	4265	1572	2	2004-05-11
1	4266	45	1	2004-05-03
2	4266	6716	2	2004-05-03
3	4266	9175	3	2004-05-03
4	4266	9901	2	2004-05-03
5	4266	8877	2	2004-05-03
6	4266	2082	2	2004-05-03
7	4266	1920	3	2004-05-03
1	4267	9907	2	2004-05-30
2	4267	5532	3	2004-05-30
3	4267	6735	2	2004-05-30
1	4268	9124	2	2004-05-22
2	4268	5605	3	2004-05-22
3	4268	9972	1	2004-05-22
4	4268	3550	3	2004-05-22
5	4268	2302	2	2004-05-22
6	4268	4268	1	2004-05-22
7	4268	7366	2	2004-05-22
8	4268	6361	3	2004-05-22
1	4269	8487	2	2004-05-18
2	4269	2624	2	2004-05-18
3	4269	4157	3	2004-05-18
4	4269	9928	1	2004-05-18
5	4269	7665	1	2004-05-18
6	4269	9162	3	2004-05-18
7	4269	7888	2	2004-05-18
1	4270	7006	3	2004-05-19
2	4270	2955	1	2004-05-19
3	4270	566	1	2004-05-19
4	4270	7624	3	2004-05-19
5	4270	9606	1	2004-05-19
6	4270	2707	2	2004-05-19
7	4270	699	1	2004-05-19
8	4270	2444	1	2004-05-19
9	4270	5211	2	2004-05-19
1	4271	6386	3	2004-05-09
1	4272	2133	3	2004-05-23
2	4272	2594	3	2004-05-23
3	4272	8181	2	2004-05-23
1	4273	5673	2	2004-05-02
2	4273	1148	3	2004-05-02
3	4273	1546	1	2004-05-02
4	4273	9571	2	2004-05-02
5	4273	5167	2	2004-05-02
6	4273	590	3	2004-05-02
7	4273	9919	3	2004-05-02
8	4273	8191	2	2004-05-02
1	4274	8411	1	2004-05-17
2	4274	5809	1	2004-05-17
3	4274	1849	2	2004-05-17
4	4274	6552	1	2004-05-17
5	4274	2736	1	2004-05-17
6	4274	296	3	2004-05-17
7	4274	7895	1	2004-05-17
1	4275	3430	3	2004-05-22
2	4275	1138	2	2004-05-22
3	4275	6302	1	2004-05-22
4	4275	2389	2	2004-05-22
5	4275	7361	3	2004-05-22
6	4275	9815	3	2004-05-22
1	4276	9229	1	2004-05-15
1	4277	8201	2	2004-05-14
2	4277	5653	2	2004-05-14
3	4277	6494	1	2004-05-14
4	4277	5535	3	2004-05-14
5	4277	8796	3	2004-05-14
6	4277	8237	3	2004-05-14
7	4277	2984	2	2004-05-14
1	4278	3069	3	2004-05-04
2	4278	6287	3	2004-05-04
3	4278	7069	3	2004-05-04
4	4278	8302	2	2004-05-04
5	4278	9430	1	2004-05-04
6	4278	2079	2	2004-05-04
7	4278	57	1	2004-05-04
8	4278	9237	2	2004-05-04
1	4279	5513	3	2004-05-20
2	4279	872	2	2004-05-20
1	4280	9227	3	2004-05-22
2	4280	6216	1	2004-05-22
3	4280	6158	1	2004-05-22
4	4280	76	1	2004-05-22
5	4280	9437	3	2004-05-22
6	4280	9524	3	2004-05-22
7	4280	1188	1	2004-05-22
8	4280	3053	1	2004-05-22
1	4281	8021	2	2004-05-06
2	4281	163	2	2004-05-06
3	4281	2046	1	2004-05-06
4	4281	7281	3	2004-05-06
5	4281	4889	2	2004-05-06
6	4281	6789	2	2004-05-06
7	4281	2881	1	2004-05-06
8	4281	6410	3	2004-05-06
1	4282	4861	1	2004-05-18
2	4282	3810	2	2004-05-18
3	4282	3390	3	2004-05-18
4	4282	7293	2	2004-05-18
5	4282	9152	2	2004-05-18
1	4283	704	1	2004-05-11
2	4283	4722	3	2004-05-11
3	4283	316	3	2004-05-11
4	4283	3551	3	2004-05-11
1	4284	5469	2	2004-05-12
1	4285	9522	2	2004-05-21
2	4285	7529	1	2004-05-21
1	4286	9067	1	2004-05-04
1	4287	9808	1	2004-05-24
2	4287	6243	1	2004-05-24
3	4287	9725	3	2004-05-24
4	4287	7227	2	2004-05-24
5	4287	6224	3	2004-05-24
6	4287	3585	1	2004-05-24
7	4287	2950	1	2004-05-24
8	4287	9425	2	2004-05-24
1	4288	1857	3	2004-05-06
2	4288	4032	1	2004-05-06
3	4288	9489	1	2004-05-06
4	4288	1745	3	2004-05-06
5	4288	1513	3	2004-05-06
6	4288	5301	1	2004-05-06
7	4288	7253	1	2004-05-06
8	4288	1443	3	2004-05-06
9	4288	1336	3	2004-05-06
1	4289	9251	3	2004-05-02
2	4289	4214	3	2004-05-02
3	4289	2460	2	2004-05-02
4	4289	7622	1	2004-05-02
1	4290	9517	3	2004-05-16
2	4290	2238	1	2004-05-16
3	4290	5972	2	2004-05-16
4	4290	8399	1	2004-05-16
5	4290	5071	2	2004-05-16
6	4290	2814	2	2004-05-16
7	4290	2629	2	2004-05-16
8	4290	5181	1	2004-05-16
9	4290	1708	1	2004-05-16
1	4291	9633	1	2004-05-22
2	4291	7178	3	2004-05-22
1	4292	1424	2	2004-05-10
2	4292	1301	2	2004-05-10
3	4292	7509	3	2004-05-10
1	4293	1559	1	2004-05-23
2	4293	8994	2	2004-05-23
3	4293	5506	2	2004-05-23
1	4294	8171	2	2004-05-23
2	4294	5591	3	2004-05-23
3	4294	8090	1	2004-05-23
4	4294	5058	1	2004-05-23
1	4295	8037	2	2004-05-16
2	4295	137	2	2004-05-16
3	4295	1964	3	2004-05-16
4	4295	1453	1	2004-05-16
5	4295	28	1	2004-05-16
6	4295	1863	3	2004-05-16
1	4296	4582	3	2004-05-23
2	4296	8751	1	2004-05-23
3	4296	4048	2	2004-05-23
4	4296	557	1	2004-05-23
1	4297	7403	2	2004-05-23
2	4297	8636	2	2004-05-23
1	4298	6319	1	2004-05-04
2	4298	3709	2	2004-05-04
3	4298	5448	2	2004-05-04
1	4299	7087	3	2004-05-17
2	4299	7116	2	2004-05-17
3	4299	276	1	2004-05-17
4	4299	178	1	2004-05-17
5	4299	3299	3	2004-05-17
6	4299	6446	2	2004-05-17
7	4299	9446	2	2004-05-17
8	4299	3004	3	2004-05-17
1	4300	7446	1	2004-05-29
1	4301	6727	2	2004-05-09
2	4301	803	3	2004-05-09
3	4301	3446	3	2004-05-09
4	4301	7190	1	2004-05-09
5	4301	3726	3	2004-05-09
6	4301	1724	2	2004-05-09
7	4301	8297	2	2004-05-09
8	4301	1189	2	2004-05-09
1	4302	8715	3	2004-05-05
2	4302	8723	2	2004-05-05
3	4302	8150	2	2004-05-05
4	4302	8737	1	2004-05-05
5	4302	7323	3	2004-05-05
1	4303	3717	2	2004-05-28
2	4303	7707	1	2004-05-28
3	4303	7142	1	2004-05-28
4	4303	8371	3	2004-05-28
5	4303	5336	3	2004-05-28
6	4303	3887	2	2004-05-28
7	4303	1411	2	2004-05-28
8	4303	7159	1	2004-05-28
9	4303	9845	2	2004-05-28
1	4304	4737	1	2004-05-25
2	4304	6888	1	2004-05-25
3	4304	8430	2	2004-05-25
4	4304	6108	1	2004-05-25
5	4304	5720	3	2004-05-25
6	4304	8147	2	2004-05-25
1	4305	4154	1	2004-05-03
2	4305	5769	3	2004-05-03
3	4305	6718	3	2004-05-03
4	4305	3405	2	2004-05-03
5	4305	7180	1	2004-05-03
6	4305	9749	2	2004-05-03
7	4305	1817	1	2004-05-03
8	4305	1087	2	2004-05-03
9	4305	1366	3	2004-05-03
1	4306	1360	3	2004-05-27
2	4306	4544	3	2004-05-27
3	4306	3022	2	2004-05-27
4	4306	4795	3	2004-05-27
5	4306	4374	3	2004-05-27
1	4307	7321	1	2004-05-26
2	4307	8665	2	2004-05-26
3	4307	3641	3	2004-05-26
4	4307	9559	2	2004-05-26
5	4307	9603	1	2004-05-26
1	4308	763	1	2004-05-07
1	4309	1629	2	2004-05-17
2	4309	5157	2	2004-05-17
3	4309	2992	3	2004-05-17
4	4309	5370	1	2004-05-17
5	4309	9673	1	2004-05-17
6	4309	5852	3	2004-05-17
7	4309	2748	2	2004-05-17
8	4309	1494	2	2004-05-17
9	4309	2929	1	2004-05-17
1	4310	3499	1	2004-05-06
2	4310	4476	2	2004-05-06
3	4310	2813	3	2004-05-06
4	4310	6383	2	2004-05-06
1	4311	4434	1	2004-05-31
2	4311	4385	3	2004-05-31
3	4311	4070	2	2004-05-31
4	4311	2160	3	2004-05-31
5	4311	1051	2	2004-05-31
1	4312	3597	1	2004-05-14
2	4312	9897	2	2004-05-14
3	4312	6995	2	2004-05-14
4	4312	5611	1	2004-05-14
5	4312	7656	3	2004-05-14
6	4312	1285	2	2004-05-14
7	4312	3326	1	2004-05-14
1	4313	6349	1	2004-05-07
2	4313	6286	1	2004-05-07
3	4313	4279	3	2004-05-07
4	4313	339	2	2004-05-07
5	4313	3352	2	2004-05-07
6	4313	7873	2	2004-05-07
1	4314	6762	2	2004-05-07
2	4314	5431	1	2004-05-07
1	4315	7124	2	2004-05-20
2	4315	8518	3	2004-05-20
3	4315	7463	2	2004-05-20
4	4315	5656	2	2004-05-20
5	4315	4577	1	2004-05-20
6	4315	4228	3	2004-05-20
7	4315	386	2	2004-05-20
1	4316	8384	1	2004-05-13
2	4316	3524	2	2004-05-13
1	4317	2658	3	2004-05-11
2	4317	2033	2	2004-05-11
3	4317	4739	3	2004-05-11
4	4317	7574	1	2004-05-11
5	4317	8330	2	2004-05-11
6	4317	7612	2	2004-05-11
7	4317	8846	1	2004-05-11
8	4317	5926	1	2004-05-11
9	4317	1043	2	2004-05-11
1	4318	7281	3	2004-05-24
2	4318	8462	1	2004-05-24
3	4318	4603	1	2004-05-24
4	4318	1091	2	2004-05-24
5	4318	926	2	2004-05-24
6	4318	2759	1	2004-05-24
7	4318	7201	3	2004-05-24
1	4319	9810	3	2004-05-07
1	4320	1729	1	2004-05-14
1	4321	6350	2	2004-05-21
2	4321	5146	2	2004-05-21
3	4321	4908	3	2004-05-21
4	4321	6790	2	2004-05-21
5	4321	5304	3	2004-05-21
6	4321	9745	3	2004-05-21
7	4321	674	3	2004-05-21
1	4322	3234	1	2004-05-18
2	4322	4680	3	2004-05-18
3	4322	184	2	2004-05-18
4	4322	8018	1	2004-05-18
5	4322	6829	2	2004-05-18
6	4322	1282	2	2004-05-18
1	4323	2442	1	2004-05-05
2	4323	6292	3	2004-05-05
3	4323	8658	1	2004-05-05
4	4323	6946	3	2004-05-05
5	4323	9658	3	2004-05-05
6	4323	5348	2	2004-05-05
1	4324	8596	2	2004-05-02
2	4324	1305	3	2004-05-02
3	4324	1445	3	2004-05-02
4	4324	692	3	2004-05-02
1	4325	9604	3	2004-05-13
2	4325	1947	1	2004-05-13
3	4325	2337	3	2004-05-13
4	4325	1276	1	2004-05-13
5	4325	9833	3	2004-05-13
1	4326	4709	2	2004-05-30
2	4326	1812	2	2004-05-30
3	4326	9890	1	2004-05-30
4	4326	2452	1	2004-05-30
5	4326	9186	2	2004-05-30
1	4327	1851	2	2004-05-02
2	4327	9927	1	2004-05-02
3	4327	3769	1	2004-05-02
4	4327	3499	2	2004-05-02
5	4327	111	2	2004-05-02
1	4328	9435	3	2004-05-23
2	4328	1242	2	2004-05-23
3	4328	5082	1	2004-05-23
4	4328	383	2	2004-05-23
5	4328	3460	1	2004-05-23
6	4328	6165	1	2004-05-23
1	4329	1204	2	2004-05-21
2	4329	2989	1	2004-05-21
3	4329	5828	3	2004-05-21
4	4329	3003	3	2004-05-21
5	4329	2863	1	2004-05-21
6	4329	4100	3	2004-05-21
7	4329	3058	3	2004-05-21
8	4329	6460	1	2004-05-21
9	4329	5928	3	2004-05-21
1	4330	5979	2	2004-05-21
2	4330	9851	1	2004-05-21
3	4330	6860	2	2004-05-21
4	4330	8824	3	2004-05-21
5	4330	5476	1	2004-05-21
6	4330	3756	3	2004-05-21
7	4330	1157	3	2004-05-21
1	4331	7274	1	2004-05-17
2	4331	8047	1	2004-05-17
3	4331	102	2	2004-05-17
4	4331	2823	2	2004-05-17
5	4331	2206	3	2004-05-17
6	4331	7038	1	2004-05-17
7	4331	6475	1	2004-05-17
8	4331	7174	2	2004-05-17
1	4332	3415	3	2004-05-16
2	4332	4008	3	2004-05-16
3	4332	6844	2	2004-05-16
4	4332	6754	1	2004-05-16
1	4333	8671	3	2004-05-29
2	4333	6928	3	2004-05-29
3	4333	2700	3	2004-05-29
4	4333	4802	2	2004-05-29
5	4333	9208	1	2004-05-29
6	4333	7865	2	2004-05-29
1	4334	9071	2	2004-05-16
1	4335	9655	1	2004-05-13
2	4335	3166	2	2004-05-13
3	4335	2197	1	2004-05-13
4	4335	2071	1	2004-05-13
5	4335	9086	1	2004-05-13
6	4335	539	2	2004-05-13
7	4335	9515	1	2004-05-13
8	4335	5764	2	2004-05-13
1	4336	654	1	2004-05-26
2	4336	1046	1	2004-05-26
3	4336	1020	1	2004-05-26
4	4336	7570	2	2004-05-26
5	4336	2601	1	2004-05-26
6	4336	3015	1	2004-05-26
1	4337	8669	1	2004-05-04
2	4337	5532	3	2004-05-04
3	4337	1476	2	2004-05-04
1	4338	5306	3	2004-05-12
2	4338	4503	1	2004-05-12
3	4338	3458	2	2004-05-12
4	4338	2468	2	2004-05-12
5	4338	7816	2	2004-05-12
6	4338	4619	2	2004-05-12
7	4338	8501	3	2004-05-12
8	4338	6245	1	2004-05-12
9	4338	9474	3	2004-05-12
1	4339	8872	2	2004-05-24
2	4339	4116	1	2004-05-24
3	4339	2024	3	2004-05-24
4	4339	1338	1	2004-05-24
5	4339	7414	2	2004-05-24
6	4339	8781	1	2004-05-24
1	4340	6742	2	2004-05-26
1	4341	8579	2	2004-05-13
2	4341	4072	3	2004-05-13
3	4341	3753	1	2004-05-13
1	4342	128	1	2004-05-20
2	4342	5409	1	2004-05-20
3	4342	126	3	2004-05-20
4	4342	3482	3	2004-05-20
5	4342	3388	1	2004-05-20
1	4343	2060	1	2004-05-30
2	4343	1415	2	2004-05-30
3	4343	2601	1	2004-05-30
4	4343	8674	1	2004-05-30
5	4343	8206	1	2004-05-30
6	4343	9232	1	2004-05-30
1	4344	483	2	2004-05-14
2	4344	4883	2	2004-05-14
3	4344	8411	2	2004-05-14
1	4345	4154	1	2004-05-09
2	4345	7514	3	2004-05-09
3	4345	8531	3	2004-05-09
4	4345	9895	3	2004-05-09
5	4345	5690	1	2004-05-09
6	4345	1634	2	2004-05-09
1	4346	1797	1	2004-05-12
2	4346	8327	3	2004-05-12
3	4346	4261	3	2004-05-12
1	4347	4151	3	2004-05-13
2	4347	4492	3	2004-05-13
3	4347	3358	3	2004-05-13
1	4348	445	3	2004-05-27
2	4348	7178	2	2004-05-27
3	4348	9689	3	2004-05-27
4	4348	498	2	2004-05-27
5	4348	8651	3	2004-05-27
6	4348	6268	1	2004-05-27
7	4348	9228	2	2004-05-27
1	4349	2631	3	2004-05-26
2	4349	5164	3	2004-05-26
3	4349	5436	3	2004-05-26
1	4350	9665	2	2004-05-11
2	4350	9415	1	2004-05-11
1	4351	5404	3	2004-05-09
2	4351	5845	2	2004-05-09
3	4351	4348	1	2004-05-09
1	4352	7064	1	2004-05-14
2	4352	5441	3	2004-05-14
3	4352	8211	1	2004-05-14
1	4353	2441	3	2004-05-21
2	4353	2138	1	2004-05-21
3	4353	4161	1	2004-05-21
4	4353	2215	3	2004-05-21
5	4353	8144	3	2004-05-21
6	4353	9436	2	2004-05-21
7	4353	5198	2	2004-05-21
8	4353	7602	3	2004-05-21
9	4353	7393	1	2004-05-21
1	4354	4208	1	2004-05-10
1	4355	6066	1	2004-05-31
2	4355	6309	3	2004-05-31
3	4355	9845	3	2004-05-31
4	4355	611	2	2004-05-31
5	4355	9998	1	2004-05-31
6	4355	960	3	2004-05-31
1	4356	5676	3	2004-05-04
2	4356	6025	1	2004-05-04
3	4356	1393	3	2004-05-04
4	4356	7167	2	2004-05-04
5	4356	9328	1	2004-05-04
6	4356	6792	3	2004-05-04
1	4357	9101	1	2004-05-12
2	4357	8364	3	2004-05-12
3	4357	311	3	2004-05-12
4	4357	2951	1	2004-05-12
5	4357	1800	2	2004-05-12
6	4357	8450	1	2004-05-12
7	4357	4307	1	2004-05-12
8	4357	9563	3	2004-05-12
9	4357	9429	2	2004-05-12
1	4358	7194	2	2004-05-10
1	4359	1802	3	2004-05-05
2	4359	5243	1	2004-05-05
3	4359	684	2	2004-05-05
4	4359	9847	1	2004-05-05
5	4359	2581	1	2004-05-05
1	4360	7463	1	2004-05-05
2	4360	9888	3	2004-05-05
3	4360	997	3	2004-05-05
4	4360	2612	2	2004-05-05
5	4360	138	3	2004-05-05
6	4360	4265	3	2004-05-05
7	4360	1401	2	2004-05-05
8	4360	1316	2	2004-05-05
9	4360	1241	1	2004-05-05
1	4361	90	2	2004-05-11
2	4361	5159	1	2004-05-11
3	4361	6663	2	2004-05-11
4	4361	7051	2	2004-05-11
1	4362	1538	2	2004-05-20
2	4362	5414	2	2004-05-20
3	4362	9428	2	2004-05-20
4	4362	1491	2	2004-05-20
5	4362	2882	1	2004-05-20
6	4362	9549	2	2004-05-20
1	4363	7273	1	2004-05-24
1	4364	33	1	2004-05-17
1	4365	1596	3	2004-05-22
2	4365	9125	1	2004-05-22
3	4365	4995	2	2004-05-22
1	4366	8115	1	2004-05-23
2	4366	1664	3	2004-05-23
3	4366	7168	3	2004-05-23
4	4366	8452	2	2004-05-23
5	4366	255	2	2004-05-23
6	4366	5815	2	2004-05-23
7	4366	3087	1	2004-05-23
8	4366	5816	1	2004-05-23
1	4367	5661	1	2004-05-09
2	4367	7714	2	2004-05-09
3	4367	4931	1	2004-05-09
4	4367	9323	1	2004-05-09
5	4367	7131	3	2004-05-09
6	4367	984	2	2004-05-09
7	4367	2380	1	2004-05-09
8	4367	2908	3	2004-05-09
1	4368	7083	3	2004-05-06
2	4368	7577	1	2004-05-06
1	4369	6026	2	2004-05-03
2	4369	1827	1	2004-05-03
3	4369	5289	3	2004-05-03
4	4369	6471	1	2004-05-03
1	4370	5203	2	2004-05-07
2	4370	4624	3	2004-05-07
3	4370	6063	3	2004-05-07
4	4370	7130	3	2004-05-07
5	4370	8889	1	2004-05-07
6	4370	50	2	2004-05-07
7	4370	1002	3	2004-05-07
8	4370	6142	1	2004-05-07
9	4370	1018	3	2004-05-07
1	4371	8729	3	2004-05-18
2	4371	6948	2	2004-05-18
3	4371	8430	3	2004-05-18
4	4371	991	1	2004-05-18
5	4371	8575	2	2004-05-18
6	4371	4276	1	2004-05-18
7	4371	3776	1	2004-05-18
1	4372	2064	3	2004-05-03
2	4372	5589	1	2004-05-03
3	4372	5943	1	2004-05-03
4	4372	4921	3	2004-05-03
5	4372	1160	1	2004-05-03
6	4372	4003	2	2004-05-03
7	4372	7910	1	2004-05-03
8	4372	2291	2	2004-05-03
9	4372	7929	1	2004-05-03
1	4373	5114	2	2004-05-13
2	4373	5826	3	2004-05-13
3	4373	6195	2	2004-05-13
1	4374	2779	1	2004-05-31
2	4374	4923	3	2004-05-31
1	4375	345	3	2004-05-11
2	4375	8730	3	2004-05-11
3	4375	2414	1	2004-05-11
4	4375	3111	1	2004-05-11
5	4375	1739	3	2004-05-11
1	4376	9175	2	2004-05-29
2	4376	3265	2	2004-05-29
3	4376	2170	1	2004-05-29
4	4376	9832	3	2004-05-29
1	4377	1332	2	2004-05-16
2	4377	9683	3	2004-05-16
3	4377	8235	1	2004-05-16
4	4377	6696	3	2004-05-16
5	4377	8281	3	2004-05-16
6	4377	7984	1	2004-05-16
7	4377	9452	3	2004-05-16
8	4377	8554	3	2004-05-16
9	4377	3042	3	2004-05-16
1	4378	7586	2	2004-05-10
2	4378	9414	3	2004-05-10
3	4378	4469	2	2004-05-10
4	4378	28	2	2004-05-10
5	4378	4172	1	2004-05-10
6	4378	8153	2	2004-05-10
1	4379	3352	1	2004-05-26
2	4379	4174	1	2004-05-26
3	4379	3551	2	2004-05-26
4	4379	1059	1	2004-05-26
5	4379	2339	2	2004-05-26
1	4380	1783	2	2004-05-02
2	4380	537	1	2004-05-02
3	4380	1321	2	2004-05-02
4	4380	5528	1	2004-05-02
1	4381	3553	1	2004-05-30
2	4381	4112	3	2004-05-30
3	4381	6142	3	2004-05-30
4	4381	9594	1	2004-05-30
5	4381	8799	1	2004-05-30
6	4381	3941	3	2004-05-30
7	4381	5248	2	2004-05-30
1	4382	103	2	2004-05-13
1	4383	5645	1	2004-05-13
2	4383	6845	2	2004-05-13
3	4383	9913	3	2004-05-13
4	4383	2940	2	2004-05-13
5	4383	627	3	2004-05-13
1	4384	7083	1	2004-05-03
1	4385	7303	3	2004-05-12
2	4385	4578	3	2004-05-12
3	4385	7404	2	2004-05-12
4	4385	2500	1	2004-05-12
5	4385	5320	3	2004-05-12
6	4385	7079	1	2004-05-12
7	4385	7400	2	2004-05-12
8	4385	6180	3	2004-05-12
1	4386	6171	1	2004-05-11
2	4386	869	1	2004-05-11
3	4386	2166	3	2004-05-11
4	4386	3998	2	2004-05-11
1	4387	4298	3	2004-05-28
2	4387	5286	1	2004-05-28
3	4387	3940	3	2004-05-28
4	4387	3282	3	2004-05-28
5	4387	4971	1	2004-05-28
6	4387	223	1	2004-05-28
1	4388	5522	1	2004-05-14
2	4388	1858	1	2004-05-14
3	4388	2134	1	2004-05-14
4	4388	2377	2	2004-05-14
5	4388	677	2	2004-05-14
6	4388	98	3	2004-05-14
7	4388	3543	2	2004-05-14
1	4389	9540	3	2004-05-19
2	4389	8998	1	2004-05-19
1	4390	6338	3	2004-05-23
2	4390	3861	2	2004-05-23
3	4390	5221	3	2004-05-23
4	4390	6479	3	2004-05-23
5	4390	1074	3	2004-05-23
6	4390	9804	2	2004-05-23
7	4390	2910	1	2004-05-23
1	4391	7788	2	2004-05-31
2	4391	1207	1	2004-05-31
3	4391	7271	1	2004-05-31
4	4391	9805	2	2004-05-31
1	4392	4500	2	2004-05-12
2	4392	4212	3	2004-05-12
3	4392	2593	3	2004-05-12
4	4392	7743	3	2004-05-12
5	4392	6510	3	2004-05-12
6	4392	7683	2	2004-05-12
7	4392	2267	1	2004-05-12
1	4393	5459	1	2004-05-22
2	4393	2983	2	2004-05-22
3	4393	3214	1	2004-05-22
4	4393	7412	1	2004-05-22
5	4393	6520	1	2004-05-22
6	4393	59	3	2004-05-22
7	4393	7728	2	2004-05-22
1	4394	1372	1	2004-05-11
2	4394	4992	3	2004-05-11
3	4394	9478	1	2004-05-11
4	4394	4195	1	2004-05-11
5	4394	3268	1	2004-05-11
6	4394	3835	3	2004-05-11
1	4395	5958	1	2004-05-25
1	4396	4349	2	2004-05-04
2	4396	4421	1	2004-05-04
3	4396	9104	3	2004-05-04
4	4396	4016	1	2004-05-04
5	4396	3670	2	2004-05-04
6	4396	2683	3	2004-05-04
7	4396	3268	1	2004-05-04
1	4397	8450	3	2004-05-05
2	4397	1471	2	2004-05-05
3	4397	7031	3	2004-05-05
4	4397	7256	1	2004-05-05
5	4397	1195	3	2004-05-05
1	4398	227	1	2004-05-20
1	4399	1353	1	2004-05-09
2	4399	2184	2	2004-05-09
3	4399	569	2	2004-05-09
4	4399	6195	1	2004-05-09
5	4399	2914	1	2004-05-09
6	4399	6508	1	2004-05-09
7	4399	7837	3	2004-05-09
1	4400	7856	3	2004-05-24
2	4400	3383	2	2004-05-24
3	4400	4580	3	2004-05-24
4	4400	4920	2	2004-05-24
5	4400	9941	3	2004-05-24
1	4401	85	3	2004-05-13
2	4401	9524	1	2004-05-13
3	4401	2134	2	2004-05-13
4	4401	2558	2	2004-05-13
5	4401	5818	3	2004-05-13
1	4402	8522	2	2004-05-20
2	4402	9114	2	2004-05-20
3	4402	3647	1	2004-05-20
4	4402	591	3	2004-05-20
1	4403	3211	3	2004-05-07
2	4403	66	3	2004-05-07
1	4404	804	2	2004-05-09
2	4404	7900	2	2004-05-09
1	4405	7371	3	2004-05-05
2	4405	2112	2	2004-05-05
3	4405	4220	1	2004-05-05
4	4405	2269	3	2004-05-05
5	4405	3722	1	2004-05-05
6	4405	6093	2	2004-05-05
7	4405	8370	3	2004-05-05
8	4405	7557	1	2004-05-05
1	4406	7773	2	2004-05-20
2	4406	1132	3	2004-05-20
3	4406	203	3	2004-05-20
4	4406	1937	1	2004-05-20
5	4406	2748	2	2004-05-20
6	4406	9751	1	2004-05-20
7	4406	3834	1	2004-05-20
8	4406	6010	3	2004-05-20
9	4406	3088	3	2004-05-20
1	4407	2479	3	2004-05-19
2	4407	1136	1	2004-05-19
1	4408	6380	2	2004-05-04
1	4409	6543	2	2004-05-13
2	4409	6031	3	2004-05-13
3	4409	305	2	2004-05-13
4	4409	9409	2	2004-05-13
1	4410	3697	3	2004-05-24
1	4411	4343	1	2004-05-24
1	4412	5807	2	2004-05-01
2	4412	3142	3	2004-05-01
3	4412	2579	3	2004-05-01
4	4412	4120	3	2004-05-01
5	4412	3089	1	2004-05-01
6	4412	8412	2	2004-05-01
7	4412	5932	3	2004-05-01
1	4413	4307	3	2004-05-24
2	4413	7836	1	2004-05-24
3	4413	1769	3	2004-05-24
4	4413	1867	2	2004-05-24
5	4413	9216	1	2004-05-24
6	4413	1541	3	2004-05-24
7	4413	9634	3	2004-05-24
8	4413	2970	1	2004-05-24
9	4413	7209	2	2004-05-24
1	4414	1479	1	2004-05-31
2	4414	6405	3	2004-05-31
3	4414	900	2	2004-05-31
1	4415	1071	1	2004-05-04
2	4415	7139	1	2004-05-04
3	4415	9456	3	2004-05-04
4	4415	8951	3	2004-05-04
5	4415	926	1	2004-05-04
1	4416	3334	2	2004-05-21
2	4416	5093	1	2004-05-21
3	4416	6376	3	2004-05-21
4	4416	6267	3	2004-05-21
5	4416	2842	1	2004-05-21
6	4416	5265	2	2004-05-21
7	4416	6609	2	2004-05-21
8	4416	7879	1	2004-05-21
9	4416	1541	3	2004-05-21
1	4417	7684	1	2004-05-06
2	4417	9896	3	2004-05-06
1	4418	6015	1	2004-05-04
2	4418	4116	1	2004-05-04
3	4418	5759	1	2004-05-04
4	4418	869	1	2004-05-04
5	4418	8346	2	2004-05-04
6	4418	4697	2	2004-05-04
7	4418	7452	1	2004-05-04
8	4418	9860	2	2004-05-04
9	4418	1576	1	2004-05-04
1	4419	4568	3	2004-05-14
2	4419	6806	2	2004-05-14
3	4419	6373	3	2004-05-14
4	4419	935	2	2004-05-14
5	4419	7104	3	2004-05-14
6	4419	8045	1	2004-05-14
1	4420	5828	1	2004-05-25
2	4420	2635	1	2004-05-25
3	4420	3667	1	2004-05-25
4	4420	1829	2	2004-05-25
5	4420	5416	2	2004-05-25
6	4420	4927	3	2004-05-25
7	4420	6748	2	2004-05-25
8	4420	5761	1	2004-05-25
9	4420	2769	1	2004-05-25
1	4421	4683	3	2004-05-18
2	4421	3662	1	2004-05-18
3	4421	8925	1	2004-05-18
4	4421	6530	1	2004-05-18
5	4421	643	1	2004-05-18
6	4421	692	1	2004-05-18
7	4421	2882	2	2004-05-18
1	4422	8115	1	2004-05-11
2	4422	8473	2	2004-05-11
3	4422	7816	2	2004-05-11
4	4422	6178	1	2004-05-11
5	4422	6799	1	2004-05-11
6	4422	9726	3	2004-05-11
7	4422	8670	2	2004-05-11
8	4422	5105	1	2004-05-11
1	4423	4664	2	2004-05-23
2	4423	6022	2	2004-05-23
3	4423	7970	3	2004-05-23
4	4423	9715	1	2004-05-23
1	4424	410	3	2004-05-12
2	4424	6589	3	2004-05-12
1	4425	4722	3	2004-05-09
2	4425	7016	2	2004-05-09
3	4425	2944	1	2004-05-09
4	4425	5723	1	2004-05-09
5	4425	6148	3	2004-05-09
6	4425	3743	1	2004-05-09
7	4425	4464	3	2004-05-09
8	4425	6168	1	2004-05-09
9	4425	8666	2	2004-05-09
1	4426	4005	2	2004-05-12
2	4426	2461	1	2004-05-12
3	4426	2116	2	2004-05-12
4	4426	3359	1	2004-05-12
1	4427	1472	1	2004-05-16
2	4427	4029	3	2004-05-16
1	4428	988	1	2004-05-08
2	4428	5987	3	2004-05-08
3	4428	3864	2	2004-05-08
4	4428	3037	3	2004-05-08
5	4428	6930	2	2004-05-08
6	4428	1506	1	2004-05-08
1	4429	9243	2	2004-05-02
2	4429	3448	2	2004-05-02
3	4429	2965	1	2004-05-02
1	4430	1631	3	2004-05-19
1	4431	28	1	2004-05-01
2	4431	8393	2	2004-05-01
1	4432	7947	1	2004-05-15
2	4432	2516	3	2004-05-15
1	4433	8926	2	2004-05-22
2	4433	369	1	2004-05-22
3	4433	7231	2	2004-05-22
4	4433	6326	1	2004-05-22
5	4433	6488	3	2004-05-22
6	4433	332	3	2004-05-22
1	4434	4347	2	2004-05-21
2	4434	472	3	2004-05-21
3	4434	7797	1	2004-05-21
4	4434	582	2	2004-05-21
5	4434	5015	1	2004-05-21
6	4434	4097	1	2004-05-21
1	4435	9296	3	2004-05-23
2	4435	7954	2	2004-05-23
3	4435	5020	2	2004-05-23
4	4435	9067	1	2004-05-23
5	4435	2236	3	2004-05-23
6	4435	8244	3	2004-05-23
1	4436	2586	2	2004-05-12
2	4436	7090	1	2004-05-12
3	4436	7831	3	2004-05-12
4	4436	6126	1	2004-05-12
5	4436	768	1	2004-05-12
6	4436	4850	3	2004-05-12
7	4436	5195	1	2004-05-12
8	4436	3968	2	2004-05-12
1	4437	6200	1	2004-05-06
2	4437	8220	3	2004-05-06
3	4437	9480	2	2004-05-06
4	4437	7224	1	2004-05-06
5	4437	2682	1	2004-05-06
6	4437	1315	2	2004-05-06
7	4437	8434	3	2004-05-06
1	4438	9110	3	2004-05-18
2	4438	1997	2	2004-05-18
1	4439	1682	3	2004-05-15
2	4439	635	1	2004-05-15
3	4439	5452	3	2004-05-15
4	4439	2780	2	2004-05-15
5	4439	5270	1	2004-05-15
6	4439	134	1	2004-05-15
7	4439	5484	1	2004-05-15
8	4439	5087	3	2004-05-15
1	4440	9784	1	2004-05-26
2	4440	5504	3	2004-05-26
3	4440	8118	3	2004-05-26
4	4440	2852	1	2004-05-26
1	4441	8637	1	2004-05-15
2	4441	9070	2	2004-05-15
3	4441	9047	1	2004-05-15
4	4441	7758	2	2004-05-15
5	4441	4110	3	2004-05-15
6	4441	6811	3	2004-05-15
1	4442	5416	1	2004-05-03
2	4442	2516	2	2004-05-03
3	4442	2868	3	2004-05-03
4	4442	4092	1	2004-05-03
5	4442	5519	3	2004-05-03
6	4442	3849	1	2004-05-03
7	4442	6841	2	2004-05-03
8	4442	6581	2	2004-05-03
1	4443	7499	3	2004-05-24
2	4443	1002	1	2004-05-24
3	4443	5213	3	2004-05-24
4	4443	1201	2	2004-05-24
5	4443	9708	3	2004-05-24
6	4443	4704	2	2004-05-24
7	4443	9183	3	2004-05-24
1	4444	3034	1	2004-05-02
2	4444	1357	3	2004-05-02
3	4444	966	3	2004-05-02
4	4444	2308	3	2004-05-02
1	4445	6630	1	2004-05-12
2	4445	559	3	2004-05-12
3	4445	2303	2	2004-05-12
1	4446	1094	2	2004-05-17
2	4446	274	1	2004-05-17
3	4446	3612	1	2004-05-17
4	4446	2326	3	2004-05-17
5	4446	5011	2	2004-05-17
1	4447	4565	2	2004-05-30
1	4448	1475	1	2004-05-26
2	4448	2007	1	2004-05-26
1	4449	7812	3	2004-05-28
2	4449	9345	3	2004-05-28
3	4449	5885	3	2004-05-28
4	4449	9182	3	2004-05-28
1	4450	6866	3	2004-05-01
2	4450	1595	3	2004-05-01
3	4450	8522	2	2004-05-01
4	4450	3654	2	2004-05-01
5	4450	4397	3	2004-05-01
1	4451	7906	3	2004-05-25
2	4451	4265	2	2004-05-25
3	4451	2216	1	2004-05-25
4	4451	5202	1	2004-05-25
5	4451	982	1	2004-05-25
6	4451	1180	1	2004-05-25
7	4451	581	1	2004-05-25
8	4451	1670	3	2004-05-25
9	4451	6622	3	2004-05-25
1	4452	4375	1	2004-05-22
2	4452	2035	3	2004-05-22
3	4452	9441	3	2004-05-22
4	4452	4643	3	2004-05-22
5	4452	9941	1	2004-05-22
1	4453	6281	2	2004-05-21
2	4453	507	3	2004-05-21
3	4453	4544	1	2004-05-21
4	4453	7425	2	2004-05-21
5	4453	3082	3	2004-05-21
6	4453	4051	3	2004-05-21
7	4453	7630	1	2004-05-21
8	4453	7918	2	2004-05-21
9	4453	6323	1	2004-05-21
1	4454	8342	2	2004-05-21
2	4454	4716	3	2004-05-21
3	4454	8254	1	2004-05-21
4	4454	2487	2	2004-05-21
5	4454	392	3	2004-05-21
6	4454	9969	1	2004-05-21
1	4455	9638	2	2004-05-19
2	4455	2548	2	2004-05-19
3	4455	5369	1	2004-05-19
4	4455	4614	1	2004-05-19
1	4456	9295	2	2004-05-17
2	4456	8020	3	2004-05-17
1	4457	4181	3	2004-05-08
1	4458	5471	1	2004-05-23
2	4458	1592	3	2004-05-23
3	4458	6653	1	2004-05-23
4	4458	3721	3	2004-05-23
5	4458	4917	3	2004-05-23
6	4458	9377	3	2004-05-23
7	4458	2375	2	2004-05-23
1	4459	4594	2	2004-05-02
2	4459	7398	3	2004-05-02
3	4459	7593	1	2004-05-02
4	4459	7542	1	2004-05-02
5	4459	1721	2	2004-05-02
6	4459	6345	3	2004-05-02
7	4459	1731	1	2004-05-02
8	4459	2092	1	2004-05-02
9	4459	9870	3	2004-05-02
1	4460	2678	3	2004-05-15
2	4460	8999	2	2004-05-15
3	4460	2146	3	2004-05-15
4	4460	3005	3	2004-05-15
5	4460	9227	3	2004-05-15
6	4460	3841	2	2004-05-15
7	4460	4540	1	2004-05-15
8	4460	9942	1	2004-05-15
9	4460	3206	1	2004-05-15
1	4461	1366	1	2004-05-21
2	4461	1787	1	2004-05-21
3	4461	1390	2	2004-05-21
4	4461	4825	3	2004-05-21
5	4461	5805	3	2004-05-21
6	4461	6655	2	2004-05-21
7	4461	2555	3	2004-05-21
8	4461	4269	2	2004-05-21
1	4462	121	3	2004-05-25
2	4462	3057	1	2004-05-25
1	4463	5814	1	2004-05-31
2	4463	4976	3	2004-05-31
3	4463	4925	3	2004-05-31
4	4463	8415	2	2004-05-31
5	4463	3100	1	2004-05-31
6	4463	5648	3	2004-05-31
1	4464	1101	3	2004-05-03
2	4464	8855	3	2004-05-03
3	4464	1471	1	2004-05-03
1	4465	1653	3	2004-05-02
2	4465	9828	2	2004-05-02
3	4465	6003	2	2004-05-02
4	4465	5655	1	2004-05-02
1	4466	6893	1	2004-05-09
2	4466	4474	1	2004-05-09
1	4467	8510	2	2004-05-31
2	4467	1427	3	2004-05-31
3	4467	4826	1	2004-05-31
4	4467	9378	2	2004-05-31
1	4468	8580	3	2004-05-14
2	4468	9519	2	2004-05-14
3	4468	4367	2	2004-05-14
4	4468	5562	3	2004-05-14
5	4468	5752	1	2004-05-14
6	4468	8422	1	2004-05-14
1	4469	8109	1	2004-05-13
2	4469	7338	2	2004-05-13
3	4469	5968	3	2004-05-13
4	4469	3983	1	2004-05-13
1	4470	2450	2	2004-05-06
2	4470	2292	1	2004-05-06
3	4470	3751	1	2004-05-06
4	4470	5612	3	2004-05-06
5	4470	6984	1	2004-05-06
6	4470	5304	1	2004-05-06
1	4471	6620	1	2004-05-14
2	4471	2504	2	2004-05-14
3	4471	590	3	2004-05-14
4	4471	1346	2	2004-05-14
5	4471	8606	2	2004-05-14
6	4471	7352	1	2004-05-14
7	4471	8688	2	2004-05-14
8	4471	6418	1	2004-05-14
1	4472	520	3	2004-05-27
2	4472	372	3	2004-05-27
3	4472	8951	2	2004-05-27
1	4473	2044	2	2004-05-01
2	4473	6182	2	2004-05-01
3	4473	747	3	2004-05-01
4	4473	4389	1	2004-05-01
5	4473	3329	1	2004-05-01
6	4473	7419	1	2004-05-01
1	4474	7244	1	2004-05-11
2	4474	8387	3	2004-05-11
3	4474	4918	3	2004-05-11
4	4474	7187	2	2004-05-11
5	4474	6408	2	2004-05-11
6	4474	964	2	2004-05-11
7	4474	9564	1	2004-05-11
8	4474	2263	1	2004-05-11
9	4474	6383	3	2004-05-11
1	4475	9220	3	2004-05-20
1	4476	2745	2	2004-05-11
2	4476	6476	3	2004-05-11
3	4476	6047	2	2004-05-11
4	4476	9397	1	2004-05-11
5	4476	3768	2	2004-05-11
6	4476	6253	1	2004-05-11
7	4476	2721	3	2004-05-11
1	4477	3891	2	2004-05-22
2	4477	7526	1	2004-05-22
3	4477	1092	1	2004-05-22
4	4477	589	1	2004-05-22
5	4477	1283	2	2004-05-22
6	4477	6950	1	2004-05-22
7	4477	924	3	2004-05-22
8	4477	3889	3	2004-05-22
9	4477	9682	3	2004-05-22
1	4478	5662	3	2004-05-08
2	4478	6204	3	2004-05-08
3	4478	4369	1	2004-05-08
4	4478	666	1	2004-05-08
5	4478	2107	2	2004-05-08
6	4478	5912	3	2004-05-08
1	4479	7315	2	2004-05-15
2	4479	9317	2	2004-05-15
3	4479	4160	1	2004-05-15
4	4479	3958	3	2004-05-15
5	4479	7639	2	2004-05-15
1	4480	5927	3	2004-05-25
2	4480	6034	1	2004-05-25
3	4480	6762	1	2004-05-25
4	4480	5153	3	2004-05-25
5	4480	2350	3	2004-05-25
6	4480	1983	3	2004-05-25
7	4480	6891	2	2004-05-25
8	4480	5264	3	2004-05-25
1	4481	6842	3	2004-05-06
1	4482	4440	1	2004-05-05
2	4482	8867	3	2004-05-05
3	4482	1990	2	2004-05-05
4	4482	5537	3	2004-05-05
5	4482	6922	1	2004-05-05
6	4482	8425	1	2004-05-05
7	4482	9724	1	2004-05-05
8	4482	9334	1	2004-05-05
9	4482	9035	2	2004-05-05
1	4483	6877	3	2004-05-26
1	4484	4518	1	2004-05-04
2	4484	1451	3	2004-05-04
3	4484	3709	1	2004-05-04
1	4485	3721	1	2004-05-19
2	4485	3948	1	2004-05-19
1	4486	5378	1	2004-05-13
2	4486	9662	2	2004-05-13
3	4486	6253	2	2004-05-13
4	4486	3731	1	2004-05-13
1	4487	7366	1	2004-05-11
2	4487	9626	3	2004-05-11
3	4487	322	2	2004-05-11
4	4487	9133	2	2004-05-11
5	4487	9033	2	2004-05-11
6	4487	8086	1	2004-05-11
7	4487	6271	1	2004-05-11
8	4487	4898	1	2004-05-11
9	4487	5705	3	2004-05-11
1	4488	4750	2	2004-05-12
2	4488	8622	3	2004-05-12
3	4488	9151	1	2004-05-12
4	4488	3364	2	2004-05-12
1	4489	9546	3	2004-05-04
1	4490	2919	1	2004-05-13
2	4490	5940	3	2004-05-13
3	4490	4237	1	2004-05-13
1	4491	1025	3	2004-05-30
2	4491	6852	2	2004-05-30
3	4491	4446	2	2004-05-30
4	4491	4255	2	2004-05-30
1	4492	8348	3	2004-05-24
2	4492	9655	3	2004-05-24
3	4492	4639	2	2004-05-24
4	4492	6570	3	2004-05-24
5	4492	6995	3	2004-05-24
6	4492	961	1	2004-05-24
7	4492	8677	2	2004-05-24
8	4492	3771	3	2004-05-24
1	4493	849	3	2004-05-16
2	4493	1937	2	2004-05-16
3	4493	3942	2	2004-05-16
4	4493	8891	1	2004-05-16
5	4493	3808	3	2004-05-16
6	4493	418	1	2004-05-16
1	4494	3881	2	2004-05-17
1	4495	3809	2	2004-05-28
2	4495	4992	3	2004-05-28
3	4495	3024	1	2004-05-28
4	4495	5	2	2004-05-28
5	4495	6293	1	2004-05-28
6	4495	3111	3	2004-05-28
7	4495	6147	3	2004-05-28
8	4495	4420	2	2004-05-28
9	4495	8635	3	2004-05-28
1	4496	9125	1	2004-05-11
2	4496	9040	1	2004-05-11
3	4496	7048	3	2004-05-11
4	4496	3880	1	2004-05-11
5	4496	7670	3	2004-05-11
6	4496	7936	1	2004-05-11
7	4496	5268	1	2004-05-11
8	4496	2793	2	2004-05-11
9	4496	5601	3	2004-05-11
1	4497	5763	1	2004-05-19
2	4497	7309	2	2004-05-19
3	4497	9961	1	2004-05-19
1	4498	773	3	2004-05-11
2	4498	5578	3	2004-05-11
3	4498	6705	3	2004-05-11
1	4499	7036	1	2004-05-04
2	4499	9869	3	2004-05-04
3	4499	7685	2	2004-05-04
4	4499	8913	2	2004-05-04
5	4499	4181	2	2004-05-04
6	4499	6080	3	2004-05-04
7	4499	7960	2	2004-05-04
8	4499	4341	3	2004-05-04
9	4499	4218	3	2004-05-04
1	4500	2837	2	2004-05-26
2	4500	6856	3	2004-05-26
3	4500	5398	3	2004-05-26
4	4500	3915	1	2004-05-26
5	4500	6740	1	2004-05-26
6	4500	4955	2	2004-05-26
7	4500	778	1	2004-05-26
8	4500	2078	3	2004-05-26
9	4500	6448	2	2004-05-26
1	4501	5916	1	2004-05-19
2	4501	1795	1	2004-05-19
3	4501	8331	1	2004-05-19
4	4501	4140	3	2004-05-19
1	4502	6518	1	2004-05-29
2	4502	3777	1	2004-05-29
3	4502	2573	1	2004-05-29
4	4502	1383	3	2004-05-29
5	4502	7124	1	2004-05-29
6	4502	167	3	2004-05-29
1	4503	9142	1	2004-05-06
2	4503	1642	2	2004-05-06
3	4503	2201	2	2004-05-06
4	4503	5190	1	2004-05-06
5	4503	3494	3	2004-05-06
6	4503	9224	1	2004-05-06
7	4503	6306	2	2004-05-06
1	4504	3255	2	2004-05-27
2	4504	2825	2	2004-05-27
3	4504	3988	3	2004-05-27
1	4505	769	2	2004-05-22
2	4505	6414	3	2004-05-22
3	4505	6267	3	2004-05-22
4	4505	4967	3	2004-05-22
5	4505	1492	1	2004-05-22
6	4505	8998	2	2004-05-22
7	4505	9486	3	2004-05-22
8	4505	7570	2	2004-05-22
1	4506	8411	1	2004-05-07
2	4506	2426	1	2004-05-07
3	4506	6507	2	2004-05-07
4	4506	1183	1	2004-05-07
5	4506	567	1	2004-05-07
6	4506	1951	1	2004-05-07
1	4507	6420	2	2004-05-16
2	4507	9671	3	2004-05-16
1	4508	6890	1	2004-05-20
2	4508	1645	3	2004-05-20
3	4508	6568	1	2004-05-20
4	4508	4934	2	2004-05-20
5	4508	2128	3	2004-05-20
6	4508	6213	3	2004-05-20
1	4509	7726	2	2004-05-12
2	4509	5674	1	2004-05-12
3	4509	2252	3	2004-05-12
4	4509	3868	3	2004-05-12
1	4510	2207	3	2004-05-10
2	4510	5351	3	2004-05-10
3	4510	9945	3	2004-05-10
4	4510	8064	2	2004-05-10
5	4510	7253	1	2004-05-10
6	4510	1490	3	2004-05-10
7	4510	356	3	2004-05-10
8	4510	8014	2	2004-05-10
9	4510	5097	3	2004-05-10
1	4511	5485	2	2004-05-27
2	4511	1060	3	2004-05-27
3	4511	4760	2	2004-05-27
4	4511	2891	1	2004-05-27
1	4512	4193	1	2004-05-12
2	4512	6032	1	2004-05-12
3	4512	7276	1	2004-05-12
4	4512	5253	3	2004-05-12
5	4512	2664	2	2004-05-12
6	4512	6467	1	2004-05-12
7	4512	9737	1	2004-05-12
8	4512	628	3	2004-05-12
9	4512	4385	2	2004-05-12
1	4513	9222	2	2004-05-08
2	4513	7593	1	2004-05-08
3	4513	6654	1	2004-05-08
4	4513	7209	3	2004-05-08
1	4514	3658	2	2004-05-01
2	4514	9632	3	2004-05-01
3	4514	4279	1	2004-05-01
4	4514	4519	1	2004-05-01
5	4514	2973	2	2004-05-01
6	4514	2308	2	2004-05-01
1	4515	6562	3	2004-05-08
2	4515	8207	2	2004-05-08
3	4515	3929	2	2004-05-08
4	4515	7895	1	2004-05-08
5	4515	7079	2	2004-05-08
1	4516	3743	1	2004-05-25
2	4516	1807	2	2004-05-25
3	4516	9073	2	2004-05-25
4	4516	5670	2	2004-05-25
5	4516	6830	3	2004-05-25
6	4516	7847	3	2004-05-25
1	4517	5109	1	2004-05-07
1	4518	9114	2	2004-05-28
2	4518	3434	2	2004-05-28
3	4518	1171	1	2004-05-28
1	4519	7838	3	2004-05-12
2	4519	704	3	2004-05-12
3	4519	5675	2	2004-05-12
4	4519	502	1	2004-05-12
5	4519	5016	3	2004-05-12
6	4519	1642	3	2004-05-12
7	4519	8655	3	2004-05-12
1	4520	7078	3	2004-05-24
2	4520	9336	2	2004-05-24
3	4520	4100	1	2004-05-24
4	4520	2383	2	2004-05-24
5	4520	4258	2	2004-05-24
6	4520	2947	1	2004-05-24
1	4521	7695	3	2004-05-11
2	4521	377	3	2004-05-11
3	4521	9809	2	2004-05-11
4	4521	6545	1	2004-05-11
1	4522	8963	3	2004-05-09
1	4523	2231	1	2004-05-21
2	4523	8802	2	2004-05-21
3	4523	6183	1	2004-05-21
4	4523	583	3	2004-05-21
5	4523	5100	2	2004-05-21
6	4523	9913	3	2004-05-21
1	4524	5803	2	2004-05-25
2	4524	3655	1	2004-05-25
3	4524	5291	2	2004-05-25
4	4524	7547	2	2004-05-25
5	4524	6517	2	2004-05-25
6	4524	2989	1	2004-05-25
7	4524	2549	3	2004-05-25
8	4524	9246	2	2004-05-25
1	4525	1107	3	2004-05-03
2	4525	6023	2	2004-05-03
3	4525	3857	2	2004-05-03
4	4525	2936	1	2004-05-03
5	4525	3542	3	2004-05-03
6	4525	5	3	2004-05-03
7	4525	811	2	2004-05-03
1	4526	311	2	2004-05-06
2	4526	5747	1	2004-05-06
3	4526	9693	3	2004-05-06
4	4526	3101	3	2004-05-06
5	4526	3074	2	2004-05-06
6	4526	6986	1	2004-05-06
7	4526	708	3	2004-05-06
8	4526	2439	3	2004-05-06
9	4526	4299	2	2004-05-06
1	4527	4203	3	2004-05-09
2	4527	5550	2	2004-05-09
3	4527	1700	3	2004-05-09
4	4527	1115	1	2004-05-09
5	4527	6479	1	2004-05-09
6	4527	8142	1	2004-05-09
1	4528	6772	2	2004-05-15
2	4528	1637	2	2004-05-15
3	4528	6058	1	2004-05-15
4	4528	1849	3	2004-05-15
5	4528	9075	2	2004-05-15
6	4528	4791	1	2004-05-15
7	4528	3381	1	2004-05-15
8	4528	7945	3	2004-05-15
1	4529	736	2	2004-05-03
2	4529	4229	3	2004-05-03
3	4529	5136	1	2004-05-03
1	4530	7685	3	2004-05-30
2	4530	3553	3	2004-05-30
3	4530	733	3	2004-05-30
4	4530	1666	1	2004-05-30
5	4530	8107	1	2004-05-30
6	4530	8729	1	2004-05-30
7	4530	2479	1	2004-05-30
8	4530	5724	1	2004-05-30
9	4530	9693	2	2004-05-30
1	4531	6001	2	2004-05-13
2	4531	1867	1	2004-05-13
3	4531	5757	1	2004-05-13
4	4531	997	2	2004-05-13
5	4531	1266	3	2004-05-13
1	4532	4429	3	2004-05-10
2	4532	6249	1	2004-05-10
3	4532	407	2	2004-05-10
4	4532	5433	1	2004-05-10
1	4533	7748	3	2004-05-22
2	4533	9069	3	2004-05-22
3	4533	1878	2	2004-05-22
4	4533	292	2	2004-05-22
5	4533	6206	2	2004-05-22
6	4533	5051	3	2004-05-22
7	4533	2008	2	2004-05-22
1	4534	8610	2	2004-05-19
2	4534	3551	2	2004-05-19
3	4534	8098	2	2004-05-19
4	4534	9835	2	2004-05-19
1	4535	3699	1	2004-05-22
1	4536	7837	3	2004-05-23
2	4536	2996	2	2004-05-23
3	4536	5680	3	2004-05-23
4	4536	1244	3	2004-05-23
5	4536	4361	3	2004-05-23
6	4536	2630	2	2004-05-23
7	4536	1010	1	2004-05-23
8	4536	1056	2	2004-05-23
9	4536	6097	3	2004-05-23
1	4537	2851	3	2004-05-27
2	4537	5507	2	2004-05-27
3	4537	9806	1	2004-05-27
4	4537	9317	3	2004-05-27
5	4537	2131	3	2004-05-27
1	4538	3171	1	2004-05-28
2	4538	2145	3	2004-05-28
3	4538	9564	2	2004-05-28
4	4538	3025	1	2004-05-28
5	4538	6013	2	2004-05-28
1	4539	8040	2	2004-05-16
2	4539	9011	1	2004-05-16
3	4539	3288	2	2004-05-16
4	4539	7440	1	2004-05-16
1	4540	3909	1	2004-05-23
2	4540	4654	2	2004-05-23
3	4540	5475	3	2004-05-23
4	4540	7540	3	2004-05-23
5	4540	5356	3	2004-05-23
6	4540	2392	3	2004-05-23
7	4540	7677	3	2004-05-23
8	4540	2462	1	2004-05-23
9	4540	513	2	2004-05-23
1	4541	9443	2	2004-05-21
2	4541	9990	3	2004-05-21
3	4541	7991	3	2004-05-21
4	4541	3638	1	2004-05-21
5	4541	6915	3	2004-05-21
1	4542	9394	1	2004-05-04
2	4542	4339	2	2004-05-04
3	4542	7291	3	2004-05-04
4	4542	3130	2	2004-05-04
5	4542	5134	2	2004-05-04
6	4542	7777	2	2004-05-04
7	4542	1285	2	2004-05-04
1	4543	7794	3	2004-05-14
2	4543	523	2	2004-05-14
3	4543	7086	2	2004-05-14
4	4543	6014	2	2004-05-14
1	4544	3981	2	2004-05-06
2	4544	4542	3	2004-05-06
3	4544	9711	1	2004-05-06
4	4544	5049	1	2004-05-06
1	4545	5829	3	2004-05-22
2	4545	8813	1	2004-05-22
3	4545	2612	3	2004-05-22
4	4545	3667	1	2004-05-22
5	4545	8221	2	2004-05-22
1	4546	9306	1	2004-05-20
2	4546	9463	2	2004-05-20
1	4547	1762	3	2004-05-14
2	4547	783	3	2004-05-14
3	4547	2385	3	2004-05-14
4	4547	6993	1	2004-05-14
5	4547	2155	1	2004-05-14
6	4547	531	1	2004-05-14
7	4547	2848	1	2004-05-14
8	4547	9490	2	2004-05-14
9	4547	3548	3	2004-05-14
1	4548	1940	1	2004-05-03
2	4548	9105	1	2004-05-03
3	4548	7196	2	2004-05-03
4	4548	4846	3	2004-05-03
5	4548	2464	2	2004-05-03
6	4548	6576	1	2004-05-03
7	4548	3418	3	2004-05-03
8	4548	827	1	2004-05-03
9	4548	9776	1	2004-05-03
1	4549	3449	2	2004-05-11
2	4549	2591	3	2004-05-11
3	4549	1148	1	2004-05-11
4	4549	6732	2	2004-05-11
5	4549	2344	3	2004-05-11
6	4549	6486	1	2004-05-11
1	4550	711	3	2004-05-01
2	4550	1526	3	2004-05-01
3	4550	673	2	2004-05-01
4	4550	6247	1	2004-05-01
5	4550	5353	2	2004-05-01
1	4551	4661	3	2004-05-14
2	4551	1867	3	2004-05-14
3	4551	6772	1	2004-05-14
4	4551	545	2	2004-05-14
5	4551	7179	1	2004-05-14
6	4551	2175	2	2004-05-14
7	4551	4337	1	2004-05-14
8	4551	7345	3	2004-05-14
1	4552	5342	3	2004-05-23
2	4552	3637	1	2004-05-23
3	4552	8895	3	2004-05-23
4	4552	7610	2	2004-05-23
5	4552	7572	2	2004-05-23
6	4552	1804	1	2004-05-23
7	4552	3714	2	2004-05-23
8	4552	9484	1	2004-05-23
1	4553	2916	2	2004-05-21
2	4553	7528	3	2004-05-21
3	4553	8411	2	2004-05-21
4	4553	6550	2	2004-05-21
1	4554	670	3	2004-05-10
2	4554	9857	3	2004-05-10
3	4554	6896	3	2004-05-10
4	4554	2939	2	2004-05-10
5	4554	1404	2	2004-05-10
6	4554	6700	2	2004-05-10
7	4554	8413	2	2004-05-10
8	4554	5602	2	2004-05-10
1	4555	5752	2	2004-05-20
2	4555	6379	2	2004-05-20
3	4555	1361	1	2004-05-20
4	4555	9740	2	2004-05-20
5	4555	6201	2	2004-05-20
6	4555	2557	3	2004-05-20
7	4555	1919	1	2004-05-20
8	4555	6434	3	2004-05-20
9	4555	9879	3	2004-05-20
1	4556	6400	1	2004-05-11
2	4556	6165	1	2004-05-11
3	4556	7624	1	2004-05-11
4	4556	1591	2	2004-05-11
5	4556	1502	3	2004-05-11
6	4556	3074	3	2004-05-11
7	4556	1505	2	2004-05-11
8	4556	808	1	2004-05-11
9	4556	8722	3	2004-05-11
1	4557	3691	1	2004-05-17
2	4557	5988	2	2004-05-17
3	4557	9684	3	2004-05-17
4	4557	4852	2	2004-05-17
5	4557	9250	1	2004-05-17
6	4557	6325	2	2004-05-17
7	4557	3252	2	2004-05-17
1	4558	2185	2	2004-05-25
2	4558	7171	2	2004-05-25
3	4558	8041	3	2004-05-25
4	4558	4934	3	2004-05-25
5	4558	4986	1	2004-05-25
6	4558	8040	3	2004-05-25
7	4558	7363	1	2004-05-25
8	4558	9175	2	2004-05-25
9	4558	5300	3	2004-05-25
1	4559	1402	3	2004-05-09
2	4559	7283	2	2004-05-09
1	4560	4363	1	2004-05-10
2	4560	7068	1	2004-05-10
3	4560	5369	2	2004-05-10
4	4560	9510	1	2004-05-10
1	4561	3359	3	2004-05-06
2	4561	1641	1	2004-05-06
3	4561	1204	3	2004-05-06
4	4561	1392	2	2004-05-06
5	4561	7091	2	2004-05-06
6	4561	5691	3	2004-05-06
7	4561	3029	1	2004-05-06
8	4561	3145	2	2004-05-06
9	4561	8045	1	2004-05-06
1	4562	3941	3	2004-05-30
2	4562	1596	2	2004-05-30
3	4562	9991	2	2004-05-30
4	4562	7945	1	2004-05-30
5	4562	3377	1	2004-05-30
6	4562	8336	2	2004-05-30
1	4563	3361	3	2004-05-12
2	4563	9277	3	2004-05-12
3	4563	7539	1	2004-05-12
4	4563	2024	1	2004-05-12
5	4563	8263	1	2004-05-12
1	4564	4168	2	2004-05-11
2	4564	7331	2	2004-05-11
3	4564	9867	3	2004-05-11
4	4564	9229	3	2004-05-11
5	4564	7803	1	2004-05-11
6	4564	9114	2	2004-05-11
7	4564	7622	1	2004-05-11
1	4565	8627	3	2004-05-18
2	4565	8088	2	2004-05-18
3	4565	9759	1	2004-05-18
4	4565	6849	3	2004-05-18
5	4565	180	1	2004-05-18
6	4565	5702	1	2004-05-18
7	4565	7814	3	2004-05-18
8	4565	9073	2	2004-05-18
9	4565	5632	3	2004-05-18
1	4566	7465	2	2004-05-08
1	4567	4666	3	2004-05-20
2	4567	1117	1	2004-05-20
1	4568	9315	2	2004-05-14
2	4568	2223	3	2004-05-14
3	4568	6476	3	2004-05-14
4	4568	2151	2	2004-05-14
1	4569	162	1	2004-05-25
2	4569	8283	3	2004-05-25
3	4569	2163	2	2004-05-25
4	4569	2774	3	2004-05-25
1	4570	8577	1	2004-05-03
2	4570	8790	1	2004-05-03
3	4570	967	3	2004-05-03
4	4570	7223	1	2004-05-03
5	4570	4551	3	2004-05-03
1	4571	5315	2	2004-05-31
2	4571	3149	2	2004-05-31
1	4572	221	3	2004-05-27
2	4572	2616	1	2004-05-27
3	4572	7371	2	2004-05-27
4	4572	4581	3	2004-05-27
5	4572	8948	1	2004-05-27
6	4572	9780	3	2004-05-27
7	4572	6179	1	2004-05-27
1	4573	2847	1	2004-05-19
1	4574	5378	2	2004-05-05
2	4574	1620	2	2004-05-05
3	4574	9187	3	2004-05-05
4	4574	832	3	2004-05-05
5	4574	7066	2	2004-05-05
6	4574	2403	2	2004-05-05
7	4574	6897	3	2004-05-05
1	4575	3582	2	2004-05-08
2	4575	2979	3	2004-05-08
3	4575	9721	2	2004-05-08
1	4576	2783	3	2004-05-01
2	4576	8533	3	2004-05-01
1	4577	8413	1	2004-05-11
2	4577	2007	2	2004-05-11
3	4577	6404	2	2004-05-11
1	4578	9144	1	2004-05-31
2	4578	4600	1	2004-05-31
3	4578	7851	3	2004-05-31
1	4579	138	2	2004-05-08
2	4579	4048	1	2004-05-08
3	4579	3924	1	2004-05-08
1	4580	9934	1	2004-05-04
2	4580	6161	1	2004-05-04
3	4580	6622	1	2004-05-04
1	4581	8904	2	2004-05-20
2	4581	9270	2	2004-05-20
3	4581	7733	3	2004-05-20
4	4581	1081	1	2004-05-20
5	4581	4691	1	2004-05-20
6	4581	2412	2	2004-05-20
7	4581	9052	2	2004-05-20
1	4582	311	1	2004-05-25
2	4582	2035	1	2004-05-25
3	4582	2912	3	2004-05-25
4	4582	2183	3	2004-05-25
5	4582	760	3	2004-05-25
6	4582	6070	2	2004-05-25
7	4582	6269	2	2004-05-25
8	4582	1631	2	2004-05-25
1	4583	9386	3	2004-05-27
2	4583	2220	1	2004-05-27
3	4583	2179	1	2004-05-27
4	4583	8255	3	2004-05-27
5	4583	4247	3	2004-05-27
6	4583	8756	2	2004-05-27
7	4583	9060	1	2004-05-27
8	4583	4800	1	2004-05-27
9	4583	8986	3	2004-05-27
1	4584	6368	1	2004-05-05
2	4584	2547	3	2004-05-05
3	4584	7320	1	2004-05-05
4	4584	7362	3	2004-05-05
5	4584	580	3	2004-05-05
6	4584	7329	1	2004-05-05
7	4584	8544	3	2004-05-05
1	4585	4089	3	2004-05-13
2	4585	2872	1	2004-05-13
3	4585	8980	3	2004-05-13
4	4585	5119	3	2004-05-13
5	4585	4654	2	2004-05-13
6	4585	7710	1	2004-05-13
7	4585	4197	2	2004-05-13
8	4585	1948	3	2004-05-13
1	4586	9247	3	2004-05-07
2	4586	6184	2	2004-05-07
3	4586	1144	2	2004-05-07
4	4586	6083	2	2004-05-07
5	4586	1524	2	2004-05-07
6	4586	3530	2	2004-05-07
7	4586	3706	2	2004-05-07
8	4586	8761	1	2004-05-07
9	4586	4073	2	2004-05-07
1	4587	8893	2	2004-05-03
2	4587	2435	1	2004-05-03
3	4587	1441	2	2004-05-03
4	4587	109	3	2004-05-03
5	4587	3947	3	2004-05-03
6	4587	7552	1	2004-05-03
7	4587	5932	3	2004-05-03
8	4587	4857	1	2004-05-03
1	4588	1993	1	2004-05-13
2	4588	3839	1	2004-05-13
3	4588	3920	3	2004-05-13
4	4588	4634	2	2004-05-13
5	4588	6638	2	2004-05-13
6	4588	2927	2	2004-05-13
7	4588	9834	2	2004-05-13
1	4589	482	2	2004-05-20
2	4589	5837	3	2004-05-20
3	4589	3948	1	2004-05-20
4	4589	6728	3	2004-05-20
5	4589	3782	1	2004-05-20
6	4589	5185	1	2004-05-20
1	4590	7931	2	2004-05-26
2	4590	9823	1	2004-05-26
1	4591	1991	3	2004-05-04
2	4591	9321	3	2004-05-04
3	4591	8809	3	2004-05-04
4	4591	4843	3	2004-05-04
1	4592	2446	2	2004-05-10
2	4592	5762	2	2004-05-10
3	4592	4685	1	2004-05-10
4	4592	7538	1	2004-05-10
5	4592	8123	1	2004-05-10
6	4592	4670	2	2004-05-10
7	4592	6549	2	2004-05-10
1	4593	1541	1	2004-05-27
2	4593	3852	1	2004-05-27
3	4593	1305	1	2004-05-27
4	4593	52	2	2004-05-27
5	4593	1950	1	2004-05-27
6	4593	6825	3	2004-05-27
1	4594	5497	3	2004-05-01
2	4594	6724	1	2004-05-01
3	4594	763	2	2004-05-01
4	4594	3118	2	2004-05-01
5	4594	900	3	2004-05-01
6	4594	9924	3	2004-05-01
1	4595	3818	3	2004-05-23
2	4595	9648	2	2004-05-23
3	4595	2348	3	2004-05-23
4	4595	1268	2	2004-05-23
5	4595	2760	3	2004-05-23
6	4595	3569	1	2004-05-23
7	4595	7362	3	2004-05-23
8	4595	8556	1	2004-05-23
1	4596	126	3	2004-05-16
2	4596	1089	1	2004-05-16
3	4596	8677	1	2004-05-16
4	4596	543	2	2004-05-16
5	4596	1887	2	2004-05-16
6	4596	4712	2	2004-05-16
1	4597	4059	1	2004-05-19
2	4597	2710	3	2004-05-19
3	4597	185	2	2004-05-19
4	4597	9596	3	2004-05-19
5	4597	3168	3	2004-05-19
6	4597	405	3	2004-05-19
7	4597	3431	2	2004-05-19
8	4597	3720	2	2004-05-19
1	4598	5820	2	2004-05-17
2	4598	9908	3	2004-05-17
3	4598	1502	2	2004-05-17
4	4598	3411	3	2004-05-17
1	4599	6329	3	2004-05-28
2	4599	9855	2	2004-05-28
3	4599	4967	3	2004-05-28
1	4600	6197	1	2004-05-13
2	4600	760	3	2004-05-13
3	4600	4588	2	2004-05-13
4	4600	4724	3	2004-05-13
5	4600	52	1	2004-05-13
1	4601	4578	1	2004-05-14
2	4601	3358	2	2004-05-14
3	4601	5897	3	2004-05-14
4	4601	6593	1	2004-05-14
5	4601	8026	2	2004-05-14
6	4601	8738	1	2004-05-14
1	4602	7258	3	2004-05-19
2	4602	4531	3	2004-05-19
3	4602	7239	3	2004-05-19
4	4602	4085	1	2004-05-19
1	4603	4095	1	2004-05-26
2	4603	8369	3	2004-05-26
3	4603	2415	1	2004-05-26
1	4604	536	3	2004-05-07
2	4604	5268	3	2004-05-07
3	4604	2080	1	2004-05-07
4	4604	2069	1	2004-05-07
5	4604	4665	3	2004-05-07
6	4604	529	3	2004-05-07
7	4604	7344	3	2004-05-07
8	4604	8314	1	2004-05-07
1	4605	9175	3	2004-05-31
2	4605	2986	3	2004-05-31
3	4605	8330	2	2004-05-31
1	4606	9379	2	2004-05-29
1	4607	5812	2	2004-05-30
2	4607	4705	1	2004-05-30
1	4608	3000	3	2004-05-16
2	4608	3685	1	2004-05-16
3	4608	4583	3	2004-05-16
1	4609	1301	3	2004-05-16
2	4609	3346	1	2004-05-16
3	4609	7794	3	2004-05-16
4	4609	902	3	2004-05-16
5	4609	1304	1	2004-05-16
6	4609	1818	2	2004-05-16
7	4609	1820	3	2004-05-16
8	4609	411	2	2004-05-16
1	4610	7581	2	2004-05-26
2	4610	5759	1	2004-05-26
3	4610	7485	1	2004-05-26
4	4610	514	1	2004-05-26
5	4610	4099	3	2004-05-26
6	4610	390	2	2004-05-26
7	4610	6655	2	2004-05-26
1	4611	1620	1	2004-05-19
2	4611	7191	2	2004-05-19
3	4611	6919	3	2004-05-19
4	4611	1065	3	2004-05-19
5	4611	5535	3	2004-05-19
6	4611	2653	3	2004-05-19
7	4611	6944	1	2004-05-19
1	4612	3043	1	2004-05-07
2	4612	1979	3	2004-05-07
3	4612	1431	1	2004-05-07
4	4612	2540	3	2004-05-07
5	4612	6105	3	2004-05-07
6	4612	2534	3	2004-05-07
7	4612	5377	2	2004-05-07
8	4612	8994	1	2004-05-07
9	4612	7589	2	2004-05-07
1	4613	7823	2	2004-05-05
2	4613	4404	2	2004-05-05
3	4613	6128	2	2004-05-05
4	4613	7467	3	2004-05-05
5	4613	5987	1	2004-05-05
6	4613	9638	3	2004-05-05
7	4613	7650	1	2004-05-05
1	4614	8697	1	2004-05-02
2	4614	3337	2	2004-05-02
3	4614	5839	1	2004-05-02
4	4614	6641	2	2004-05-02
5	4614	8242	3	2004-05-02
6	4614	2082	1	2004-05-02
1	4615	4669	2	2004-05-17
2	4615	6185	1	2004-05-17
3	4615	1130	1	2004-05-17
4	4615	2645	1	2004-05-17
5	4615	138	1	2004-05-17
6	4615	1835	1	2004-05-17
7	4615	484	1	2004-05-17
8	4615	6912	3	2004-05-17
9	4615	2674	1	2004-05-17
1	4616	1941	1	2004-05-11
2	4616	8114	2	2004-05-11
3	4616	2302	2	2004-05-11
4	4616	3925	3	2004-05-11
5	4616	3175	3	2004-05-11
6	4616	3182	3	2004-05-11
7	4616	729	2	2004-05-11
8	4616	1532	2	2004-05-11
9	4616	5078	1	2004-05-11
1	4617	7900	3	2004-05-12
2	4617	3332	1	2004-05-12
3	4617	9301	2	2004-05-12
4	4617	9086	1	2004-05-12
1	4618	5048	2	2004-05-21
2	4618	8036	3	2004-05-21
3	4618	4676	1	2004-05-21
4	4618	7565	3	2004-05-21
5	4618	570	3	2004-05-21
1	4619	3770	2	2004-05-07
2	4619	4157	2	2004-05-07
3	4619	9484	1	2004-05-07
4	4619	4964	1	2004-05-07
5	4619	2629	2	2004-05-07
6	4619	9401	1	2004-05-07
7	4619	6142	2	2004-05-07
1	4620	3836	3	2004-05-09
2	4620	6760	3	2004-05-09
3	4620	9722	2	2004-05-09
4	4620	6367	1	2004-05-09
5	4620	2617	3	2004-05-09
6	4620	2392	2	2004-05-09
7	4620	5779	2	2004-05-09
8	4620	9616	3	2004-05-09
1	4621	1914	2	2004-05-07
2	4621	1300	1	2004-05-07
3	4621	6333	3	2004-05-07
4	4621	7196	3	2004-05-07
5	4621	6279	3	2004-05-07
6	4621	6861	1	2004-05-07
7	4621	6181	2	2004-05-07
1	4622	6193	1	2004-05-27
2	4622	3525	3	2004-05-27
3	4622	4842	3	2004-05-27
4	4622	4746	2	2004-05-27
5	4622	9238	3	2004-05-27
1	4623	5846	2	2004-05-12
2	4623	6784	1	2004-05-12
3	4623	2594	2	2004-05-12
4	4623	1251	3	2004-05-12
5	4623	1649	3	2004-05-12
1	4624	3731	3	2004-05-28
2	4624	2602	3	2004-05-28
3	4624	233	2	2004-05-28
4	4624	8508	2	2004-05-28
5	4624	5430	1	2004-05-28
6	4624	9532	2	2004-05-28
7	4624	71	1	2004-05-28
1	4625	9077	2	2004-05-19
2	4625	3916	1	2004-05-19
1	4626	3277	3	2004-05-29
1	4627	4680	3	2004-05-28
2	4627	2449	2	2004-05-28
3	4627	5868	1	2004-05-28
1	4628	5964	2	2004-05-31
2	4628	2605	1	2004-05-31
3	4628	8203	1	2004-05-31
4	4628	3595	3	2004-05-31
5	4628	6499	3	2004-05-31
6	4628	8950	2	2004-05-31
7	4628	2677	3	2004-05-31
8	4628	6782	2	2004-05-31
9	4628	9023	2	2004-05-31
1	4629	5905	1	2004-05-03
2	4629	554	1	2004-05-03
3	4629	1505	1	2004-05-03
4	4629	3070	2	2004-05-03
5	4629	58	3	2004-05-03
6	4629	9991	1	2004-05-03
1	4630	5472	1	2004-05-03
2	4630	1995	2	2004-05-03
3	4630	6138	2	2004-05-03
4	4630	3915	1	2004-05-03
5	4630	626	1	2004-05-03
1	4631	7228	2	2004-05-27
2	4631	7146	3	2004-05-27
3	4631	6778	3	2004-05-27
4	4631	8321	3	2004-05-27
5	4631	4363	3	2004-05-27
6	4631	8880	2	2004-05-27
1	4632	4253	3	2004-05-04
2	4632	5185	2	2004-05-04
3	4632	2439	1	2004-05-04
4	4632	920	2	2004-05-04
5	4632	4240	1	2004-05-04
1	4633	9331	1	2004-05-29
2	4633	3396	2	2004-05-29
3	4633	8141	1	2004-05-29
4	4633	5126	2	2004-05-29
5	4633	20	3	2004-05-29
6	4633	4840	3	2004-05-29
7	4633	3841	2	2004-05-29
8	4633	8668	2	2004-05-29
1	4634	9168	3	2004-05-03
2	4634	7250	1	2004-05-03
3	4634	3197	1	2004-05-03
4	4634	1633	1	2004-05-03
5	4634	4225	2	2004-05-03
6	4634	878	2	2004-05-03
1	4635	4446	2	2004-05-16
2	4635	9727	2	2004-05-16
3	4635	4644	2	2004-05-16
1	4636	4872	1	2004-05-11
2	4636	4951	3	2004-05-11
1	4637	4206	3	2004-05-23
2	4637	5860	2	2004-05-23
3	4637	1802	1	2004-05-23
4	4637	604	1	2004-05-23
1	4638	8994	1	2004-05-12
2	4638	8825	3	2004-05-12
3	4638	5862	2	2004-05-12
4	4638	3287	3	2004-05-12
1	4639	4925	2	2004-05-07
2	4639	6101	1	2004-05-07
3	4639	323	1	2004-05-07
4	4639	6415	2	2004-05-07
5	4639	1535	1	2004-05-07
6	4639	367	2	2004-05-07
7	4639	2357	1	2004-05-07
1	4640	9664	2	2004-05-19
2	4640	4364	3	2004-05-19
3	4640	4413	1	2004-05-19
1	4641	1433	1	2004-05-07
2	4641	736	2	2004-05-07
3	4641	6909	3	2004-05-07
4	4641	8402	3	2004-05-07
1	4642	7090	1	2004-05-29
1	4643	5442	3	2004-05-13
2	4643	2908	2	2004-05-13
3	4643	5486	3	2004-05-13
4	4643	3594	3	2004-05-13
5	4643	7496	2	2004-05-13
6	4643	7597	3	2004-05-13
7	4643	9462	3	2004-05-13
8	4643	7649	1	2004-05-13
9	4643	5386	2	2004-05-13
1	4644	8603	2	2004-05-22
2	4644	6681	2	2004-05-22
3	4644	5674	1	2004-05-22
4	4644	5138	3	2004-05-22
5	4644	547	1	2004-05-22
6	4644	8563	2	2004-05-22
1	4645	3947	3	2004-05-18
2	4645	4829	1	2004-05-18
3	4645	5166	2	2004-05-18
4	4645	572	1	2004-05-18
5	4645	4488	2	2004-05-18
6	4645	7372	1	2004-05-18
7	4645	9745	3	2004-05-18
8	4645	7612	3	2004-05-18
9	4645	2708	2	2004-05-18
1	4646	7150	2	2004-05-13
2	4646	9757	2	2004-05-13
3	4646	8898	2	2004-05-13
4	4646	9760	3	2004-05-13
5	4646	4718	2	2004-05-13
6	4646	7843	3	2004-05-13
7	4646	5250	1	2004-05-13
8	4646	3836	2	2004-05-13
9	4646	5822	3	2004-05-13
1	4647	2354	3	2004-05-06
2	4647	9871	2	2004-05-06
1	4648	3086	1	2004-05-06
2	4648	2090	1	2004-05-06
3	4648	6303	1	2004-05-06
4	4648	8283	2	2004-05-06
5	4648	610	1	2004-05-06
6	4648	9769	3	2004-05-06
1	4649	840	3	2004-05-08
2	4649	4705	1	2004-05-08
3	4649	475	2	2004-05-08
4	4649	4142	1	2004-05-08
5	4649	2006	2	2004-05-08
6	4649	7890	2	2004-05-08
1	4650	1922	1	2004-05-25
1	4651	4287	2	2004-05-12
2	4651	5131	2	2004-05-12
1	4652	4058	3	2004-05-08
2	4652	1277	3	2004-05-08
3	4652	2533	1	2004-05-08
4	4652	3312	3	2004-05-08
1	4653	9071	3	2004-05-15
2	4653	3802	3	2004-05-15
3	4653	9612	2	2004-05-15
1	4654	5591	3	2004-05-07
2	4654	9517	1	2004-05-07
3	4654	2290	1	2004-05-07
4	4654	8397	1	2004-05-07
5	4654	6049	1	2004-05-07
1	4655	9078	2	2004-05-04
2	4655	482	2	2004-05-04
3	4655	9844	1	2004-05-04
4	4655	6128	3	2004-05-04
1	4656	5653	1	2004-05-31
2	4656	2845	3	2004-05-31
3	4656	5774	3	2004-05-31
4	4656	7834	2	2004-05-31
5	4656	9156	1	2004-05-31
6	4656	7344	3	2004-05-31
7	4656	1486	2	2004-05-31
8	4656	6	1	2004-05-31
9	4656	718	1	2004-05-31
1	4657	3453	2	2004-05-21
2	4657	8219	3	2004-05-21
3	4657	4507	3	2004-05-21
4	4657	9509	1	2004-05-21
5	4657	7376	2	2004-05-21
6	4657	3232	1	2004-05-21
7	4657	4761	3	2004-05-21
1	4658	2717	1	2004-05-27
2	4658	5362	2	2004-05-27
3	4658	5032	2	2004-05-27
4	4658	6964	2	2004-05-27
5	4658	6589	2	2004-05-27
6	4658	5545	1	2004-05-27
7	4658	587	3	2004-05-27
8	4658	7929	3	2004-05-27
1	4659	5326	2	2004-05-27
2	4659	3247	3	2004-05-27
3	4659	4392	3	2004-05-27
4	4659	7562	1	2004-05-27
5	4659	602	1	2004-05-27
6	4659	856	1	2004-05-27
7	4659	3497	2	2004-05-27
8	4659	7521	3	2004-05-27
1	4660	8019	3	2004-05-05
2	4660	511	3	2004-05-05
3	4660	8820	3	2004-05-05
4	4660	7410	3	2004-05-05
5	4660	875	2	2004-05-05
6	4660	5482	2	2004-05-05
7	4660	8378	3	2004-05-05
8	4660	4757	1	2004-05-05
1	4661	4175	3	2004-05-21
2	4661	655	3	2004-05-21
3	4661	2889	3	2004-05-21
4	4661	6201	2	2004-05-21
5	4661	2659	1	2004-05-21
6	4661	2648	1	2004-05-21
7	4661	302	1	2004-05-21
1	4662	6518	1	2004-05-29
2	4662	897	1	2004-05-29
3	4662	8673	3	2004-05-29
4	4662	729	2	2004-05-29
5	4662	2044	3	2004-05-29
6	4662	5747	3	2004-05-29
7	4662	4801	3	2004-05-29
1	4663	3631	2	2004-05-15
2	4663	1891	2	2004-05-15
3	4663	4272	2	2004-05-15
4	4663	6967	2	2004-05-15
5	4663	7696	2	2004-05-15
6	4663	3695	3	2004-05-15
7	4663	2939	1	2004-05-15
1	4664	3110	1	2004-05-06
1	4665	3013	2	2004-05-12
2	4665	9535	3	2004-05-12
3	4665	661	3	2004-05-12
4	4665	4959	2	2004-05-12
5	4665	921	3	2004-05-12
6	4665	581	2	2004-05-12
7	4665	1387	3	2004-05-12
8	4665	9766	3	2004-05-12
9	4665	3794	2	2004-05-12
1	4666	568	2	2004-05-26
1	4667	8831	3	2004-05-02
2	4667	4063	1	2004-05-02
3	4667	4433	2	2004-05-02
4	4667	9384	2	2004-05-02
5	4667	725	2	2004-05-02
1	4668	6837	1	2004-05-30
2	4668	7511	2	2004-05-30
3	4668	1662	1	2004-05-30
4	4668	63	1	2004-05-30
5	4668	8037	2	2004-05-30
6	4668	180	3	2004-05-30
7	4668	9620	1	2004-05-30
8	4668	2280	3	2004-05-30
9	4668	5210	1	2004-05-30
1	4669	2869	1	2004-05-24
2	4669	7197	2	2004-05-24
1	4670	6544	1	2004-05-21
2	4670	449	2	2004-05-21
3	4670	8677	1	2004-05-21
4	4670	5359	3	2004-05-21
5	4670	2148	2	2004-05-21
6	4670	2474	1	2004-05-21
7	4670	1998	1	2004-05-21
8	4670	3089	2	2004-05-21
1	4671	7570	3	2004-05-02
2	4671	311	1	2004-05-02
3	4671	676	3	2004-05-02
4	4671	4030	3	2004-05-02
5	4671	4088	3	2004-05-02
6	4671	5224	1	2004-05-02
7	4671	1340	2	2004-05-02
8	4671	4686	1	2004-05-02
1	4672	3438	1	2004-05-25
2	4672	2259	2	2004-05-25
3	4672	3322	2	2004-05-25
4	4672	9713	2	2004-05-25
5	4672	3645	2	2004-05-25
6	4672	2065	1	2004-05-25
7	4672	3439	1	2004-05-25
8	4672	1651	2	2004-05-25
9	4672	9883	2	2004-05-25
1	4673	4601	2	2004-05-05
2	4673	2363	3	2004-05-05
3	4673	6303	1	2004-05-05
4	4673	9330	2	2004-05-05
5	4673	76	1	2004-05-05
6	4673	6286	1	2004-05-05
7	4673	8202	3	2004-05-05
1	4674	3013	2	2004-05-24
2	4674	2539	2	2004-05-24
1	4675	9869	1	2004-05-25
2	4675	1756	2	2004-05-25
3	4675	8723	2	2004-05-25
4	4675	1102	1	2004-05-25
5	4675	5643	3	2004-05-25
6	4675	1231	2	2004-05-25
7	4675	2461	1	2004-05-25
8	4675	7738	3	2004-05-25
1	4676	3853	1	2004-05-12
2	4676	2645	3	2004-05-12
1	4677	9373	2	2004-05-23
2	4677	3032	3	2004-05-23
3	4677	5913	2	2004-05-23
4	4677	4057	2	2004-05-23
5	4677	1144	2	2004-05-23
1	4678	1757	2	2004-05-18
2	4678	8258	3	2004-05-18
3	4678	3770	1	2004-05-18
4	4678	5434	1	2004-05-18
5	4678	3218	3	2004-05-18
6	4678	3938	2	2004-05-18
7	4678	6151	1	2004-05-18
1	4679	3347	3	2004-05-04
1	4680	3894	2	2004-05-30
2	4680	8874	3	2004-05-30
3	4680	2274	1	2004-05-30
4	4680	6566	2	2004-05-30
1	4681	6720	3	2004-05-21
1	4682	5799	2	2004-05-08
2	4682	7568	3	2004-05-08
3	4682	3861	2	2004-05-08
4	4682	7262	3	2004-05-08
5	4682	3652	3	2004-05-08
6	4682	6467	3	2004-05-08
1	4683	9975	2	2004-05-02
2	4683	944	2	2004-05-02
3	4683	9788	3	2004-05-02
4	4683	1363	1	2004-05-02
5	4683	7632	3	2004-05-02
6	4683	2271	3	2004-05-02
7	4683	8018	1	2004-05-02
8	4683	6269	2	2004-05-02
9	4683	4909	2	2004-05-02
1	4684	5978	1	2004-05-03
2	4684	4843	1	2004-05-03
3	4684	9577	2	2004-05-03
4	4684	2805	1	2004-05-03
5	4684	4986	1	2004-05-03
6	4684	8819	2	2004-05-03
7	4684	9319	3	2004-05-03
8	4684	3333	1	2004-05-03
1	4685	945	3	2004-05-06
2	4685	4703	3	2004-05-06
3	4685	597	3	2004-05-06
4	4685	1049	1	2004-05-06
1	4686	559	2	2004-05-26
2	4686	6803	1	2004-05-26
3	4686	9500	3	2004-05-26
4	4686	3196	2	2004-05-26
1	4687	620	2	2004-05-08
2	4687	2386	1	2004-05-08
1	4688	7928	1	2004-05-15
2	4688	2868	3	2004-05-15
3	4688	1041	2	2004-05-15
4	4688	9782	3	2004-05-15
5	4688	2893	3	2004-05-15
6	4688	3780	2	2004-05-15
1	4689	189	3	2004-05-10
2	4689	6970	1	2004-05-10
3	4689	8796	3	2004-05-10
1	4690	1953	2	2004-05-14
2	4690	7812	3	2004-05-14
3	4690	1496	2	2004-05-14
4	4690	108	2	2004-05-14
5	4690	4264	1	2004-05-14
6	4690	8278	2	2004-05-14
1	4691	4621	2	2004-05-02
2	4691	4931	3	2004-05-02
3	4691	8475	2	2004-05-02
4	4691	4988	2	2004-05-02
1	4692	3198	2	2004-05-24
2	4692	8636	2	2004-05-24
1	4693	2186	2	2004-05-31
2	4693	5658	2	2004-05-31
1	4694	5106	2	2004-05-16
2	4694	2	3	2004-05-16
3	4694	9491	2	2004-05-16
4	4694	7933	3	2004-05-16
5	4694	52	1	2004-05-16
6	4694	3409	3	2004-05-16
1	4695	195	3	2004-05-21
2	4695	5050	3	2004-05-21
3	4695	4799	3	2004-05-21
4	4695	1289	3	2004-05-21
5	4695	2815	3	2004-05-21
6	4695	3432	3	2004-05-21
7	4695	881	2	2004-05-21
8	4695	3551	2	2004-05-21
9	4695	7426	2	2004-05-21
1	4696	4881	3	2004-05-18
2	4696	6564	3	2004-05-18
3	4696	6280	1	2004-05-18
4	4696	4526	2	2004-05-18
1	4697	4714	3	2004-05-10
2	4697	7093	2	2004-05-10
3	4697	6130	3	2004-05-10
4	4697	2947	3	2004-05-10
5	4697	7805	2	2004-05-10
6	4697	3487	1	2004-05-10
7	4697	9813	1	2004-05-10
8	4697	4906	2	2004-05-10
1	4698	1924	2	2004-05-25
2	4698	998	3	2004-05-25
3	4698	8997	2	2004-05-25
1	4699	376	2	2004-05-14
2	4699	7694	3	2004-05-14
3	4699	958	2	2004-05-14
4	4699	7375	2	2004-05-14
5	4699	3385	2	2004-05-14
6	4699	7732	3	2004-05-14
7	4699	6533	3	2004-05-14
8	4699	7783	1	2004-05-14
1	4700	8319	3	2004-05-10
2	4700	7969	3	2004-05-10
3	4700	4955	3	2004-05-10
1	4701	7702	3	2004-05-16
2	4701	39	2	2004-05-16
3	4701	6970	1	2004-05-16
4	4701	9219	2	2004-05-16
5	4701	4902	1	2004-05-16
1	4702	178	3	2004-05-30
2	4702	7492	1	2004-05-30
3	4702	2868	1	2004-05-30
4	4702	5483	1	2004-05-30
5	4702	9070	2	2004-05-30
6	4702	503	2	2004-05-30
1	4703	425	1	2004-05-02
2	4703	9046	1	2004-05-02
3	4703	6276	2	2004-05-02
4	4703	1460	2	2004-05-02
5	4703	359	2	2004-05-02
6	4703	8098	3	2004-05-02
7	4703	8994	3	2004-05-02
8	4703	5935	3	2004-05-02
9	4703	4831	2	2004-05-02
1	4704	8885	2	2004-05-08
2	4704	1351	3	2004-05-08
3	4704	8838	1	2004-05-08
4	4704	4729	1	2004-05-08
5	4704	1311	2	2004-05-08
6	4704	2895	1	2004-05-08
7	4704	5616	3	2004-05-08
8	4704	6371	3	2004-05-08
1	4705	6611	1	2004-05-15
2	4705	335	1	2004-05-15
3	4705	1602	2	2004-05-15
1	4706	1918	1	2004-05-19
2	4706	6529	1	2004-05-19
1	4707	7380	2	2004-05-04
2	4707	1015	1	2004-05-04
3	4707	6703	2	2004-05-04
4	4707	9444	1	2004-05-04
5	4707	3706	2	2004-05-04
6	4707	9804	3	2004-05-04
1	4708	8958	1	2004-05-22
2	4708	2368	2	2004-05-22
3	4708	5193	2	2004-05-22
4	4708	6643	3	2004-05-22
5	4708	6978	1	2004-05-22
6	4708	380	3	2004-05-22
7	4708	8537	2	2004-05-22
1	4709	6191	3	2004-05-13
2	4709	1620	2	2004-05-13
3	4709	1540	2	2004-05-13
4	4709	9741	1	2004-05-13
5	4709	2469	2	2004-05-13
1	4710	3216	2	2004-05-25
2	4710	1643	3	2004-05-25
3	4710	1409	3	2004-05-25
4	4710	5519	3	2004-05-25
5	4710	1457	2	2004-05-25
6	4710	6499	3	2004-05-25
7	4710	1314	1	2004-05-25
1	4711	1542	3	2004-05-19
2	4711	7733	1	2004-05-19
1	4712	4082	1	2004-05-08
2	4712	6918	3	2004-05-08
3	4712	8895	1	2004-05-08
4	4712	4071	1	2004-05-08
5	4712	8541	2	2004-05-08
1	4713	9957	1	2004-05-28
1	4714	4346	2	2004-05-01
2	4714	8280	2	2004-05-01
3	4714	3382	2	2004-05-01
4	4714	8968	2	2004-05-01
5	4714	3485	2	2004-05-01
6	4714	666	3	2004-05-01
1	4715	7716	3	2004-05-18
2	4715	5004	2	2004-05-18
3	4715	5010	2	2004-05-18
4	4715	315	3	2004-05-18
5	4715	4106	1	2004-05-18
1	4716	558	2	2004-05-29
1	4717	4849	1	2004-05-20
2	4717	5546	3	2004-05-20
3	4717	4130	2	2004-05-20
4	4717	5901	3	2004-05-20
5	4717	3796	1	2004-05-20
6	4717	4169	1	2004-05-20
7	4717	891	3	2004-05-20
8	4717	7767	2	2004-05-20
9	4717	2999	3	2004-05-20
1	4718	1481	3	2004-05-15
2	4718	4090	1	2004-05-15
3	4718	5777	1	2004-05-15
4	4718	876	3	2004-05-15
1	4719	4058	1	2004-05-01
2	4719	1979	3	2004-05-01
3	4719	2119	2	2004-05-01
4	4719	1319	2	2004-05-01
5	4719	7285	1	2004-05-01
6	4719	5458	2	2004-05-01
1	4720	5560	1	2004-05-26
2	4720	6898	3	2004-05-26
3	4720	1377	1	2004-05-26
1	4721	4701	1	2004-05-29
2	4721	5678	1	2004-05-29
3	4721	7439	3	2004-05-29
4	4721	5404	3	2004-05-29
5	4721	9694	3	2004-05-29
6	4721	5190	1	2004-05-29
7	4721	3808	1	2004-05-29
8	4721	3221	3	2004-05-29
9	4721	7526	1	2004-05-29
1	4722	2143	1	2004-05-24
2	4722	321	2	2004-05-24
3	4722	2100	3	2004-05-24
1	4723	5223	2	2004-05-03
2	4723	8359	1	2004-05-03
3	4723	4765	2	2004-05-03
4	4723	2078	2	2004-05-03
5	4723	1284	3	2004-05-03
1	4724	4358	3	2004-05-17
2	4724	21	1	2004-05-17
3	4724	7924	2	2004-05-17
4	4724	5361	1	2004-05-17
5	4724	5346	2	2004-05-17
6	4724	3585	3	2004-05-17
7	4724	5081	2	2004-05-17
8	4724	997	2	2004-05-17
1	4725	8880	2	2004-05-30
2	4725	1748	1	2004-05-30
3	4725	8684	1	2004-05-30
4	4725	8225	2	2004-05-30
5	4725	8124	3	2004-05-30
6	4725	2844	1	2004-05-30
7	4725	5232	1	2004-05-30
8	4725	4561	1	2004-05-30
1	4726	5603	3	2004-05-23
2	4726	9889	1	2004-05-23
3	4726	1061	1	2004-05-23
1	4727	8674	2	2004-05-16
2	4727	8802	1	2004-05-16
3	4727	6941	3	2004-05-16
4	4727	3453	2	2004-05-16
5	4727	1638	1	2004-05-16
1	4728	7345	3	2004-05-10
2	4728	1518	2	2004-05-10
3	4728	8540	2	2004-05-10
4	4728	6886	2	2004-05-10
5	4728	1544	3	2004-05-10
6	4728	4825	1	2004-05-10
7	4728	7659	3	2004-05-10
8	4728	3292	2	2004-05-10
1	4729	2386	3	2004-05-14
2	4729	802	2	2004-05-14
3	4729	2852	1	2004-05-14
1	4730	4344	2	2004-05-23
2	4730	93	2	2004-05-23
1	4731	2774	1	2004-05-27
2	4731	2367	3	2004-05-27
3	4731	4749	1	2004-05-27
4	4731	7538	3	2004-05-27
5	4731	4788	1	2004-05-27
6	4731	6	2	2004-05-27
1	4732	8231	2	2004-05-17
2	4732	8610	2	2004-05-17
3	4732	2054	2	2004-05-17
4	4732	7120	2	2004-05-17
5	4732	9795	3	2004-05-17
6	4732	2260	3	2004-05-17
1	4733	5003	2	2004-05-19
2	4733	6216	3	2004-05-19
3	4733	6486	2	2004-05-19
4	4733	7792	1	2004-05-19
5	4733	5805	3	2004-05-19
6	4733	6807	1	2004-05-19
7	4733	189	1	2004-05-19
8	4733	7344	3	2004-05-19
1	4734	1483	1	2004-05-19
2	4734	4551	1	2004-05-19
3	4734	8394	3	2004-05-19
4	4734	9779	2	2004-05-19
5	4734	9669	2	2004-05-19
6	4734	2855	2	2004-05-19
7	4734	332	3	2004-05-19
8	4734	4423	3	2004-05-19
1	4735	12	2	2004-05-09
2	4735	9801	1	2004-05-09
3	4735	4924	3	2004-05-09
4	4735	8618	1	2004-05-09
5	4735	3098	1	2004-05-09
6	4735	9175	2	2004-05-09
7	4735	3864	2	2004-05-09
8	4735	5858	1	2004-05-09
1	4736	9509	3	2004-05-02
1	4737	6658	1	2004-05-16
2	4737	1511	2	2004-05-16
3	4737	9868	1	2004-05-16
4	4737	9645	3	2004-05-16
5	4737	1721	2	2004-05-16
6	4737	6813	1	2004-05-16
7	4737	5591	3	2004-05-16
8	4737	3019	2	2004-05-16
9	4737	4491	3	2004-05-16
1	4738	5985	2	2004-05-27
2	4738	9228	2	2004-05-27
3	4738	4981	2	2004-05-27
4	4738	5334	2	2004-05-27
5	4738	3398	1	2004-05-27
6	4738	4639	2	2004-05-27
7	4738	6740	2	2004-05-27
8	4738	6431	2	2004-05-27
9	4738	4175	3	2004-05-27
1	4739	897	1	2004-05-03
2	4739	1307	2	2004-05-03
3	4739	8391	3	2004-05-03
4	4739	5736	3	2004-05-03
5	4739	8822	1	2004-05-03
6	4739	3162	3	2004-05-03
1	4740	1542	2	2004-05-23
2	4740	4540	2	2004-05-23
3	4740	457	1	2004-05-23
1	4741	5039	3	2004-05-03
2	4741	5847	2	2004-05-03
3	4741	5157	3	2004-05-03
4	4741	5037	2	2004-05-03
5	4741	2131	2	2004-05-03
1	4742	9588	2	2004-05-20
2	4742	3130	3	2004-05-20
3	4742	2260	2	2004-05-20
4	4742	9350	2	2004-05-20
5	4742	827	2	2004-05-20
1	4743	8170	1	2004-05-31
1	4744	6736	2	2004-05-18
2	4744	8118	1	2004-05-18
1	4745	8115	2	2004-05-10
2	4745	4407	3	2004-05-10
3	4745	271	3	2004-05-10
4	4745	4505	1	2004-05-10
5	4745	2816	2	2004-05-10
6	4745	6331	2	2004-05-10
7	4745	7744	2	2004-05-10
8	4745	4925	1	2004-05-10
9	4745	6979	1	2004-05-10
1	4746	3880	1	2004-05-18
2	4746	3790	1	2004-05-18
3	4746	4810	3	2004-05-18
4	4746	2245	1	2004-05-18
5	4746	6180	1	2004-05-18
6	4746	6161	1	2004-05-18
7	4746	8062	2	2004-05-18
1	4747	6420	2	2004-05-26
1	4748	7075	3	2004-05-15
2	4748	2599	1	2004-05-15
3	4748	1087	3	2004-05-15
4	4748	5	2	2004-05-15
5	4748	1938	2	2004-05-15
6	4748	6963	3	2004-05-15
7	4748	648	3	2004-05-15
8	4748	6754	3	2004-05-15
9	4748	9567	1	2004-05-15
1	4749	195	3	2004-05-23
2	4749	6472	2	2004-05-23
3	4749	3596	1	2004-05-23
4	4749	778	2	2004-05-23
5	4749	556	3	2004-05-23
1	4750	2054	1	2004-05-12
2	4750	9832	2	2004-05-12
3	4750	4467	3	2004-05-12
4	4750	738	2	2004-05-12
5	4750	6002	3	2004-05-12
1	4751	3198	3	2004-05-07
2	4751	4888	2	2004-05-07
3	4751	8054	1	2004-05-07
4	4751	8	1	2004-05-07
5	4751	2412	1	2004-05-07
6	4751	6848	1	2004-05-07
7	4751	8637	1	2004-05-07
8	4751	6121	3	2004-05-07
9	4751	5493	3	2004-05-07
1	4752	2119	1	2004-05-31
2	4752	9558	3	2004-05-31
3	4752	394	1	2004-05-31
4	4752	3690	1	2004-05-31
1	4753	280	3	2004-05-03
2	4753	7100	1	2004-05-03
3	4753	249	3	2004-05-03
4	4753	1072	3	2004-05-03
5	4753	2477	3	2004-05-03
6	4753	7723	3	2004-05-03
1	4754	8539	3	2004-05-28
2	4754	3434	1	2004-05-28
3	4754	1840	1	2004-05-28
4	4754	8778	1	2004-05-28
5	4754	4491	1	2004-05-28
6	4754	3031	2	2004-05-28
7	4754	9354	2	2004-05-28
8	4754	1082	3	2004-05-28
9	4754	2176	3	2004-05-28
1	4755	9520	1	2004-05-31
1	4756	457	2	2004-05-03
2	4756	8702	3	2004-05-03
3	4756	4475	1	2004-05-03
4	4756	9652	2	2004-05-03
5	4756	5128	3	2004-05-03
6	4756	8547	3	2004-05-03
7	4756	895	1	2004-05-03
8	4756	4960	1	2004-05-03
9	4756	5153	2	2004-05-03
1	4757	9753	1	2004-05-31
2	4757	792	3	2004-05-31
3	4757	2081	1	2004-05-31
4	4757	6514	1	2004-05-31
5	4757	1202	3	2004-05-31
6	4757	6383	3	2004-05-31
7	4757	5964	1	2004-05-31
8	4757	2039	2	2004-05-31
9	4757	7171	3	2004-05-31
1	4758	7294	1	2004-05-13
2	4758	5187	1	2004-05-13
3	4758	7785	2	2004-05-13
4	4758	9775	1	2004-05-13
5	4758	4869	3	2004-05-13
1	4759	7152	2	2004-05-13
2	4759	6846	3	2004-05-13
3	4759	2281	1	2004-05-13
4	4759	8257	3	2004-05-13
5	4759	4085	1	2004-05-13
6	4759	3860	1	2004-05-13
1	4760	2843	2	2004-05-24
2	4760	5986	3	2004-05-24
3	4760	6712	2	2004-05-24
4	4760	3098	2	2004-05-24
1	4761	3627	2	2004-05-18
2	4761	5696	1	2004-05-18
3	4761	122	1	2004-05-18
4	4761	9131	1	2004-05-18
5	4761	5769	3	2004-05-18
6	4761	648	3	2004-05-18
7	4761	7682	2	2004-05-18
8	4761	1108	2	2004-05-18
9	4761	2411	3	2004-05-18
1	4762	3282	3	2004-05-30
2	4762	9140	2	2004-05-30
3	4762	5541	2	2004-05-30
4	4762	4345	1	2004-05-30
5	4762	4612	3	2004-05-30
1	4763	2848	3	2004-05-20
2	4763	8887	3	2004-05-20
3	4763	5268	3	2004-05-20
4	4763	8470	1	2004-05-20
5	4763	4041	3	2004-05-20
6	4763	8091	2	2004-05-20
1	4764	2846	2	2004-05-24
1	4765	6902	2	2004-05-29
2	4765	6148	1	2004-05-29
3	4765	3682	1	2004-05-29
4	4765	1820	1	2004-05-29
5	4765	8995	2	2004-05-29
1	4766	7415	1	2004-05-01
2	4766	8527	1	2004-05-01
3	4766	1332	2	2004-05-01
4	4766	7907	3	2004-05-01
5	4766	4093	3	2004-05-01
6	4766	8989	3	2004-05-01
1	4767	2640	2	2004-05-15
2	4767	1673	3	2004-05-15
3	4767	7338	2	2004-05-15
4	4767	1299	3	2004-05-15
5	4767	7785	1	2004-05-15
6	4767	3826	3	2004-05-15
1	4768	8864	1	2004-05-26
2	4768	7044	1	2004-05-26
3	4768	8816	2	2004-05-26
4	4768	9184	1	2004-05-26
5	4768	4562	3	2004-05-26
6	4768	9846	3	2004-05-26
1	4769	4593	3	2004-05-20
2	4769	7644	1	2004-05-20
3	4769	2149	3	2004-05-20
4	4769	1088	3	2004-05-20
5	4769	9235	2	2004-05-20
6	4769	8029	3	2004-05-20
7	4769	2023	1	2004-05-20
8	4769	2997	1	2004-05-20
1	4770	4990	1	2004-05-13
2	4770	5624	3	2004-05-13
3	4770	8439	2	2004-05-13
1	4771	3512	3	2004-05-27
2	4771	625	1	2004-05-27
3	4771	762	1	2004-05-27
4	4771	97	1	2004-05-27
1	4772	6740	3	2004-05-09
1	4773	9775	1	2004-05-08
2	4773	9051	2	2004-05-08
3	4773	1019	2	2004-05-08
4	4773	4316	3	2004-05-08
5	4773	145	1	2004-05-08
6	4773	4112	2	2004-05-08
1	4774	8778	2	2004-05-22
2	4774	252	3	2004-05-22
3	4774	5824	1	2004-05-22
4	4774	8206	1	2004-05-22
5	4774	3691	2	2004-05-22
6	4774	1371	2	2004-05-22
7	4774	4681	1	2004-05-22
1	4775	9220	1	2004-05-08
2	4775	6186	2	2004-05-08
1	4776	712	2	2004-05-08
2	4776	4004	2	2004-05-08
3	4776	895	1	2004-05-08
4	4776	7900	1	2004-05-08
5	4776	1657	2	2004-05-08
6	4776	4103	3	2004-05-08
1	4777	3918	3	2004-05-20
2	4777	8720	2	2004-05-20
3	4777	3943	1	2004-05-20
4	4777	7889	1	2004-05-20
5	4777	3327	2	2004-05-20
6	4777	6697	2	2004-05-20
7	4777	404	1	2004-05-20
1	4778	5041	3	2004-05-07
2	4778	8763	1	2004-05-07
3	4778	8712	1	2004-05-07
4	4778	6662	1	2004-05-07
5	4778	281	1	2004-05-07
6	4778	607	2	2004-05-07
1	4779	903	3	2004-05-03
2	4779	9883	3	2004-05-03
3	4779	1681	1	2004-05-03
4	4779	2865	3	2004-05-03
5	4779	8806	1	2004-05-03
6	4779	1634	1	2004-05-03
7	4779	4384	3	2004-05-03
8	4779	6764	3	2004-05-03
9	4779	5871	2	2004-05-03
1	4780	7396	2	2004-05-08
2	4780	1995	3	2004-05-08
3	4780	1314	1	2004-05-08
4	4780	2528	2	2004-05-08
5	4780	2012	2	2004-05-08
6	4780	4408	1	2004-05-08
7	4780	2220	2	2004-05-08
8	4780	5104	2	2004-05-08
9	4780	4465	2	2004-05-08
1	4781	4405	1	2004-05-26
2	4781	2160	1	2004-05-26
3	4781	6981	2	2004-05-26
1	4782	9150	2	2004-05-16
2	4782	255	1	2004-05-16
3	4782	8186	1	2004-05-16
1	4783	2092	3	2004-05-20
1	4784	1105	1	2004-05-22
2	4784	7411	2	2004-05-22
1	4785	2090	2	2004-05-15
2	4785	1286	3	2004-05-15
3	4785	7156	2	2004-05-15
4	4785	9199	2	2004-05-15
5	4785	376	3	2004-05-15
6	4785	6768	3	2004-05-15
7	4785	2236	1	2004-05-15
1	4786	6879	1	2004-05-28
1	4787	2262	3	2004-05-25
2	4787	4948	3	2004-05-25
3	4787	1263	1	2004-05-25
4	4787	3628	2	2004-05-25
5	4787	6430	2	2004-05-25
6	4787	298	2	2004-05-25
7	4787	9747	3	2004-05-25
8	4787	9890	1	2004-05-25
9	4787	8950	2	2004-05-25
1	4788	9633	2	2004-05-27
2	4788	8292	2	2004-05-27
3	4788	4379	2	2004-05-27
4	4788	6904	2	2004-05-27
5	4788	5489	3	2004-05-27
6	4788	5864	1	2004-05-27
7	4788	6031	3	2004-05-27
1	4789	4572	1	2004-05-09
2	4789	2648	2	2004-05-09
3	4789	272	1	2004-05-09
4	4789	4439	3	2004-05-09
5	4789	9194	1	2004-05-09
6	4789	407	3	2004-05-09
7	4789	562	1	2004-05-09
8	4789	2623	3	2004-05-09
9	4789	6549	3	2004-05-09
1	4790	2619	3	2004-05-17
1	4791	8307	3	2004-05-04
2	4791	2811	1	2004-05-04
3	4791	7657	2	2004-05-04
4	4791	7196	3	2004-05-04
1	4792	4756	3	2004-05-25
2	4792	6156	2	2004-05-25
3	4792	7595	3	2004-05-25
4	4792	4170	2	2004-05-25
5	4792	5779	3	2004-05-25
6	4792	7597	3	2004-05-25
7	4792	38	1	2004-05-25
1	4793	4899	3	2004-05-27
2	4793	1761	3	2004-05-27
3	4793	48	3	2004-05-27
4	4793	3167	3	2004-05-27
5	4793	7346	1	2004-05-27
1	4794	2052	2	2004-05-28
2	4794	8951	3	2004-05-28
3	4794	3281	1	2004-05-28
4	4794	3790	3	2004-05-28
1	4795	1601	3	2004-05-08
2	4795	3670	1	2004-05-08
3	4795	1607	3	2004-05-08
1	4796	2785	3	2004-05-24
2	4796	4924	1	2004-05-24
3	4796	604	2	2004-05-24
4	4796	4626	3	2004-05-24
5	4796	7436	3	2004-05-24
6	4796	3454	2	2004-05-24
7	4796	6324	3	2004-05-24
1	4797	1500	2	2004-05-30
2	4797	4507	1	2004-05-30
1	4798	6745	1	2004-05-03
2	4798	5750	1	2004-05-03
3	4798	8876	3	2004-05-03
1	4799	7602	1	2004-05-08
2	4799	2019	2	2004-05-08
3	4799	9967	2	2004-05-08
1	4800	6404	3	2004-05-05
1	4801	1003	1	2004-05-10
2	4801	5601	2	2004-05-10
3	4801	5208	1	2004-05-10
4	4801	5761	1	2004-05-10
5	4801	5366	2	2004-05-10
6	4801	9492	3	2004-05-10
7	4801	8436	3	2004-05-10
1	4802	1074	1	2004-05-03
2	4802	8389	1	2004-05-03
3	4802	7703	1	2004-05-03
1	4803	2009	1	2004-05-11
2	4803	3772	1	2004-05-11
3	4803	3471	3	2004-05-11
4	4803	7577	3	2004-05-11
5	4803	1717	2	2004-05-11
6	4803	9636	3	2004-05-11
1	4804	7283	2	2004-05-25
2	4804	2445	3	2004-05-25
3	4804	8726	2	2004-05-25
4	4804	142	3	2004-05-25
5	4804	6016	3	2004-05-25
6	4804	7710	3	2004-05-25
1	4805	6952	3	2004-05-07
2	4805	6972	1	2004-05-07
3	4805	8934	2	2004-05-07
4	4805	9099	1	2004-05-07
1	4806	7861	1	2004-05-25
2	4806	2267	2	2004-05-25
3	4806	8456	2	2004-05-25
4	4806	3873	3	2004-05-25
5	4806	8229	2	2004-05-25
6	4806	4296	2	2004-05-25
1	4807	8311	3	2004-05-06
2	4807	7770	2	2004-05-06
3	4807	9039	2	2004-05-06
4	4807	5684	3	2004-05-06
1	4808	3516	2	2004-05-29
2	4808	3032	1	2004-05-29
3	4808	9002	2	2004-05-29
4	4808	6520	3	2004-05-29
5	4808	9	1	2004-05-29
6	4808	4639	3	2004-05-29
7	4808	4407	3	2004-05-29
1	4809	76	3	2004-05-08
2	4809	5646	3	2004-05-08
3	4809	4512	2	2004-05-08
4	4809	2586	1	2004-05-08
5	4809	2655	1	2004-05-08
6	4809	4977	1	2004-05-08
1	4810	9869	2	2004-05-29
2	4810	7377	2	2004-05-29
1	4811	5624	1	2004-05-13
2	4811	7664	3	2004-05-13
3	4811	7454	3	2004-05-13
4	4811	4273	3	2004-05-13
5	4811	7853	3	2004-05-13
6	4811	5374	1	2004-05-13
7	4811	4601	3	2004-05-13
8	4811	2560	3	2004-05-13
1	4812	6029	2	2004-05-31
2	4812	959	2	2004-05-31
3	4812	2800	3	2004-05-31
4	4812	2286	3	2004-05-31
5	4812	5722	3	2004-05-31
6	4812	5621	1	2004-05-31
7	4812	255	1	2004-05-31
8	4812	9449	3	2004-05-31
1	4813	3639	1	2004-05-06
2	4813	2106	3	2004-05-06
3	4813	8568	2	2004-05-06
4	4813	5496	3	2004-05-06
5	4813	2202	2	2004-05-06
6	4813	7280	3	2004-05-06
7	4813	195	3	2004-05-06
8	4813	4128	1	2004-05-06
9	4813	6574	2	2004-05-06
1	4814	3639	2	2004-05-31
2	4814	8791	1	2004-05-31
3	4814	3442	1	2004-05-31
4	4814	6809	3	2004-05-31
5	4814	419	1	2004-05-31
1	4815	7189	2	2004-05-29
2	4815	6253	3	2004-05-29
3	4815	8211	2	2004-05-29
4	4815	7620	3	2004-05-29
5	4815	1770	1	2004-05-29
6	4815	1400	3	2004-05-29
7	4815	8160	1	2004-05-29
8	4815	639	2	2004-05-29
1	4816	7365	1	2004-05-22
2	4816	6260	2	2004-05-22
3	4816	1492	3	2004-05-22
4	4816	4620	1	2004-05-22
5	4816	9201	1	2004-05-22
6	4816	8630	2	2004-05-22
1	4817	8414	2	2004-05-24
2	4817	4105	1	2004-05-24
3	4817	5145	2	2004-05-24
4	4817	8528	1	2004-05-24
5	4817	6790	3	2004-05-24
6	4817	6945	2	2004-05-24
1	4818	9133	2	2004-05-11
1	4819	1402	1	2004-05-16
2	4819	2908	1	2004-05-16
3	4819	7690	1	2004-05-16
4	4819	4913	2	2004-05-16
5	4819	6096	1	2004-05-16
6	4819	6866	1	2004-05-16
7	4819	3511	1	2004-05-16
8	4819	5705	1	2004-05-16
9	4819	5315	1	2004-05-16
1	4820	8578	2	2004-05-04
2	4820	5455	3	2004-05-04
3	4820	660	1	2004-05-04
4	4820	8335	1	2004-05-04
5	4820	36	3	2004-05-04
1	4821	3339	2	2004-05-13
2	4821	5217	3	2004-05-13
1	4822	4093	2	2004-05-25
2	4822	3553	3	2004-05-25
1	4823	9404	1	2004-05-25
2	4823	9145	2	2004-05-25
3	4823	7955	3	2004-05-25
4	4823	5294	2	2004-05-25
1	4824	8272	2	2004-05-08
2	4824	8371	1	2004-05-08
3	4824	468	2	2004-05-08
4	4824	1044	3	2004-05-08
5	4824	5671	1	2004-05-08
6	4824	9989	3	2004-05-08
1	4825	8298	1	2004-05-19
2	4825	7755	3	2004-05-19
3	4825	1083	3	2004-05-19
4	4825	2560	3	2004-05-19
1	4826	3182	1	2004-05-21
2	4826	5887	1	2004-05-21
3	4826	7138	2	2004-05-21
4	4826	3063	3	2004-05-21
5	4826	7845	2	2004-05-21
6	4826	6079	2	2004-05-21
7	4826	4784	2	2004-05-21
8	4826	3279	1	2004-05-21
9	4826	9608	1	2004-05-21
1	4827	5607	2	2004-05-15
2	4827	9299	3	2004-05-15
3	4827	3407	2	2004-05-15
1	4828	80	1	2004-05-19
2	4828	652	3	2004-05-19
3	4828	5409	2	2004-05-19
4	4828	4823	1	2004-05-19
5	4828	7821	1	2004-05-19
6	4828	6770	1	2004-05-19
7	4828	6968	1	2004-05-19
8	4828	3404	2	2004-05-19
9	4828	2498	3	2004-05-19
1	4829	156	3	2004-05-14
1	4830	2294	1	2004-05-26
2	4830	3469	1	2004-05-26
3	4830	2166	2	2004-05-26
4	4830	9590	3	2004-05-26
1	4831	5313	3	2004-05-25
2	4831	8259	1	2004-05-25
3	4831	7645	1	2004-05-25
4	4831	8855	1	2004-05-25
5	4831	9711	2	2004-05-25
6	4831	5928	1	2004-05-25
1	4832	9646	2	2004-05-11
2	4832	5943	1	2004-05-11
1	4833	3531	2	2004-05-21
2	4833	6411	1	2004-05-21
3	4833	8312	3	2004-05-21
4	4833	7019	2	2004-05-21
5	4833	4835	2	2004-05-21
6	4833	5904	1	2004-05-21
7	4833	6938	2	2004-05-21
8	4833	2622	2	2004-05-21
1	4834	4633	3	2004-05-26
2	4834	3189	2	2004-05-26
1	4835	8542	1	2004-05-08
2	4835	7880	1	2004-05-08
3	4835	4428	2	2004-05-08
4	4835	3436	1	2004-05-08
5	4835	1528	1	2004-05-08
6	4835	6363	2	2004-05-08
7	4835	5731	1	2004-05-08
8	4835	8842	1	2004-05-08
9	4835	7026	1	2004-05-08
1	4836	6635	2	2004-05-29
2	4836	2840	3	2004-05-29
3	4836	8921	2	2004-05-29
4	4836	8955	2	2004-05-29
5	4836	4257	3	2004-05-29
6	4836	5665	1	2004-05-29
1	4837	2831	3	2004-05-30
2	4837	3458	3	2004-05-30
3	4837	4316	3	2004-05-30
1	4838	4619	1	2004-05-05
2	4838	3604	2	2004-05-05
3	4838	7295	1	2004-05-05
4	4838	9273	1	2004-05-05
5	4838	61	3	2004-05-05
6	4838	5348	3	2004-05-05
7	4838	3331	3	2004-05-05
8	4838	6511	3	2004-05-05
1	4839	9082	1	2004-05-06
2	4839	6120	1	2004-05-06
3	4839	1109	1	2004-05-06
4	4839	1727	1	2004-05-06
5	4839	3592	2	2004-05-06
6	4839	1053	3	2004-05-06
7	4839	4752	2	2004-05-06
8	4839	2841	1	2004-05-06
1	4840	307	3	2004-05-16
2	4840	3970	2	2004-05-16
3	4840	7131	1	2004-05-16
4	4840	2631	3	2004-05-16
5	4840	6559	1	2004-05-16
1	4841	8179	2	2004-05-22
2	4841	3590	3	2004-05-22
3	4841	7310	3	2004-05-22
1	4842	3019	3	2004-05-11
2	4842	285	3	2004-05-11
3	4842	346	1	2004-05-11
4	4842	2868	1	2004-05-11
5	4842	9992	3	2004-05-11
6	4842	4289	3	2004-05-11
7	4842	7317	3	2004-05-11
8	4842	5994	2	2004-05-11
1	4843	6185	3	2004-05-27
2	4843	7010	3	2004-05-27
3	4843	7599	2	2004-05-27
1	4844	9323	2	2004-05-22
2	4844	580	3	2004-05-22
3	4844	3613	1	2004-05-22
1	4845	3317	2	2004-05-07
2	4845	9186	1	2004-05-07
1	4846	8209	2	2004-05-09
2	4846	3688	2	2004-05-09
1	4847	5017	1	2004-05-06
2	4847	399	3	2004-05-06
3	4847	3470	3	2004-05-06
4	4847	3398	2	2004-05-06
5	4847	9327	3	2004-05-06
6	4847	4974	1	2004-05-06
7	4847	3491	2	2004-05-06
8	4847	3460	3	2004-05-06
9	4847	2415	1	2004-05-06
1	4848	6617	2	2004-05-24
2	4848	5972	1	2004-05-24
1	4849	7002	2	2004-05-02
2	4849	5715	3	2004-05-02
3	4849	3715	3	2004-05-02
4	4849	7121	3	2004-05-02
5	4849	3234	2	2004-05-02
1	4850	4757	1	2004-05-13
2	4850	4421	3	2004-05-13
3	4850	3949	1	2004-05-13
4	4850	2370	1	2004-05-13
5	4850	3810	3	2004-05-13
6	4850	7805	3	2004-05-13
7	4850	9291	3	2004-05-13
1	4851	6309	3	2004-05-24
2	4851	1871	1	2004-05-24
3	4851	7719	3	2004-05-24
4	4851	7136	1	2004-05-24
5	4851	5438	1	2004-05-24
1	4852	4585	1	2004-05-29
2	4852	1087	3	2004-05-29
3	4852	5152	2	2004-05-29
4	4852	305	3	2004-05-29
1	4853	6339	2	2004-05-08
2	4853	2024	3	2004-05-08
1	4854	8356	2	2004-05-03
2	4854	1544	2	2004-05-03
3	4854	6365	3	2004-05-03
1	4855	9439	2	2004-05-21
2	4855	8911	1	2004-05-21
3	4855	3378	2	2004-05-21
4	4855	3982	2	2004-05-21
5	4855	3023	2	2004-05-21
6	4855	1792	1	2004-05-21
1	4856	7289	3	2004-05-26
1	4857	395	1	2004-05-27
2	4857	2357	3	2004-05-27
3	4857	9735	3	2004-05-27
4	4857	2282	3	2004-05-27
5	4857	4725	1	2004-05-27
6	4857	4842	2	2004-05-27
7	4857	2246	3	2004-05-27
1	4858	2650	2	2004-05-24
1	4859	984	3	2004-05-08
1	4860	6361	2	2004-05-29
1	4861	7823	2	2004-05-10
2	4861	2813	1	2004-05-10
3	4861	5249	3	2004-05-10
1	4862	3721	3	2004-05-20
2	4862	4600	2	2004-05-20
3	4862	1469	3	2004-05-20
4	4862	7176	1	2004-05-20
1	4863	7653	2	2004-05-24
2	4863	6993	2	2004-05-24
3	4863	982	1	2004-05-24
4	4863	2731	1	2004-05-24
5	4863	2893	1	2004-05-24
6	4863	5756	2	2004-05-24
1	4864	8498	3	2004-05-10
2	4864	3162	1	2004-05-10
3	4864	7009	3	2004-05-10
4	4864	8590	3	2004-05-10
5	4864	4845	2	2004-05-10
6	4864	1768	1	2004-05-10
7	4864	3924	2	2004-05-10
8	4864	9054	1	2004-05-10
9	4864	664	2	2004-05-10
1	4865	3873	3	2004-05-18
2	4865	8873	3	2004-05-18
3	4865	4720	1	2004-05-18
4	4865	632	3	2004-05-18
5	4865	1255	3	2004-05-18
6	4865	7313	2	2004-05-18
7	4865	1348	2	2004-05-18
8	4865	2178	3	2004-05-18
1	4866	9412	3	2004-05-09
2	4866	8735	3	2004-05-09
3	4866	1203	3	2004-05-09
4	4866	4511	3	2004-05-09
5	4866	1043	1	2004-05-09
1	4867	4543	2	2004-05-16
2	4867	5957	2	2004-05-16
3	4867	2447	3	2004-05-16
4	4867	4303	3	2004-05-16
1	4868	5589	3	2004-05-06
2	4868	827	1	2004-05-06
3	4868	1443	1	2004-05-06
4	4868	917	1	2004-05-06
1	4869	8912	1	2004-05-27
2	4869	3846	2	2004-05-27
3	4869	5533	2	2004-05-27
1	4870	5249	1	2004-05-25
2	4870	1177	3	2004-05-25
3	4870	65	1	2004-05-25
4	4870	5202	2	2004-05-25
1	4871	2080	1	2004-05-21
2	4871	7673	1	2004-05-21
3	4871	2640	2	2004-05-21
4	4871	5115	1	2004-05-21
5	4871	9588	2	2004-05-21
6	4871	2832	2	2004-05-21
7	4871	8050	3	2004-05-21
1	4872	23	2	2004-05-22
2	4872	5091	1	2004-05-22
3	4872	3237	2	2004-05-22
4	4872	4003	3	2004-05-22
5	4872	9298	1	2004-05-22
1	4873	2781	2	2004-05-29
2	4873	4305	2	2004-05-29
1	4874	3446	1	2004-05-07
2	4874	5114	1	2004-05-07
1	4875	6824	3	2004-05-28
2	4875	953	1	2004-05-28
3	4875	8773	2	2004-05-28
4	4875	7069	1	2004-05-28
5	4875	2628	2	2004-05-28
6	4875	3386	1	2004-05-28
7	4875	6685	1	2004-05-28
1	4876	4885	3	2004-05-10
2	4876	6888	1	2004-05-10
3	4876	921	1	2004-05-10
4	4876	2984	2	2004-05-10
5	4876	1827	1	2004-05-10
6	4876	8073	3	2004-05-10
7	4876	9079	2	2004-05-10
1	4877	4221	2	2004-05-22
2	4877	8502	3	2004-05-22
3	4877	244	1	2004-05-22
4	4877	8705	3	2004-05-22
5	4877	3318	1	2004-05-22
6	4877	6393	1	2004-05-22
1	4878	3796	1	2004-05-29
2	4878	6556	3	2004-05-29
3	4878	6662	3	2004-05-29
4	4878	8591	2	2004-05-29
5	4878	7762	3	2004-05-29
6	4878	9630	2	2004-05-29
1	4879	317	3	2004-05-24
2	4879	8768	1	2004-05-24
1	4880	9340	2	2004-05-03
2	4880	4613	3	2004-05-03
3	4880	5159	2	2004-05-03
4	4880	4899	3	2004-05-03
1	4881	9838	2	2004-05-16
2	4881	6342	3	2004-05-16
1	4882	2409	1	2004-05-07
2	4882	1611	1	2004-05-07
3	4882	1698	1	2004-05-07
4	4882	3286	1	2004-05-07
5	4882	7849	1	2004-05-07
6	4882	6673	3	2004-05-07
7	4882	4656	1	2004-05-07
8	4882	5864	3	2004-05-07
9	4882	5605	1	2004-05-07
1	4883	2159	1	2004-05-28
2	4883	8826	3	2004-05-28
3	4883	9654	1	2004-05-28
4	4883	4470	1	2004-05-28
5	4883	509	3	2004-05-28
1	4884	2497	1	2004-05-15
2	4884	8946	1	2004-05-15
3	4884	3664	2	2004-05-15
4	4884	7534	3	2004-05-15
5	4884	6904	2	2004-05-15
6	4884	8135	1	2004-05-15
1	4885	1406	2	2004-05-13
2	4885	8432	1	2004-05-13
3	4885	3717	3	2004-05-13
4	4885	1049	3	2004-05-13
5	4885	52	1	2004-05-13
6	4885	5066	2	2004-05-13
1	4886	7559	1	2004-05-12
2	4886	6517	1	2004-05-12
3	4886	5757	2	2004-05-12
4	4886	9542	1	2004-05-12
5	4886	7447	3	2004-05-12
6	4886	5168	1	2004-05-12
1	4887	3443	2	2004-05-15
2	4887	6217	3	2004-05-15
3	4887	4500	3	2004-05-15
4	4887	5347	2	2004-05-15
5	4887	8822	1	2004-05-15
6	4887	9326	1	2004-05-15
1	4888	658	2	2004-05-16
2	4888	3861	2	2004-05-16
3	4888	9234	2	2004-05-16
1	4889	8287	2	2004-05-29
2	4889	2467	2	2004-05-29
3	4889	1646	2	2004-05-29
4	4889	2684	3	2004-05-29
1	4890	1734	2	2004-05-10
2	4890	8827	1	2004-05-10
3	4890	6447	2	2004-05-10
4	4890	1578	2	2004-05-10
5	4890	6545	1	2004-05-10
6	4890	298	1	2004-05-10
7	4890	8648	3	2004-05-10
8	4890	3809	3	2004-05-10
1	4891	547	2	2004-05-20
2	4891	767	1	2004-05-20
3	4891	339	2	2004-05-20
4	4891	54	2	2004-05-20
5	4891	633	2	2004-05-20
1	4892	3425	2	2004-05-06
1	4893	7236	1	2004-05-15
1	4894	3606	3	2004-05-05
2	4894	200	2	2004-05-05
3	4894	1227	1	2004-05-05
4	4894	9997	1	2004-05-05
5	4894	2938	1	2004-05-05
1	4895	8173	2	2004-05-17
2	4895	8442	3	2004-05-17
3	4895	6212	1	2004-05-17
4	4895	2879	1	2004-05-17
5	4895	6868	2	2004-05-17
6	4895	1864	2	2004-05-17
1	4896	8680	2	2004-05-15
2	4896	1806	3	2004-05-15
3	4896	9161	1	2004-05-15
4	4896	9625	3	2004-05-15
5	4896	5026	1	2004-05-15
1	4897	6544	2	2004-05-30
2	4897	8798	2	2004-05-30
3	4897	1028	2	2004-05-30
1	4898	7475	3	2004-05-22
2	4898	7822	1	2004-05-22
3	4898	1005	3	2004-05-22
4	4898	7107	3	2004-05-22
1	4899	1945	3	2004-05-05
1	4900	7438	2	2004-05-31
2	4900	2447	2	2004-05-31
3	4900	27	1	2004-05-31
4	4900	8965	1	2004-05-31
5	4900	6253	2	2004-05-31
6	4900	4960	1	2004-05-31
7	4900	9533	1	2004-05-31
8	4900	9664	3	2004-05-31
9	4900	4465	1	2004-05-31
1	4901	483	3	2004-05-17
2	4901	7127	1	2004-05-17
3	4901	7101	3	2004-05-17
4	4901	9397	3	2004-05-17
5	4901	6058	3	2004-05-17
6	4901	4150	3	2004-05-17
1	4902	5229	2	2004-05-03
2	4902	5594	1	2004-05-03
3	4902	8028	2	2004-05-03
4	4902	2622	3	2004-05-03
5	4902	2482	3	2004-05-03
6	4902	8360	3	2004-05-03
7	4902	8658	3	2004-05-03
8	4902	4209	3	2004-05-03
9	4902	7627	1	2004-05-03
1	4903	2575	2	2004-05-05
1	4904	899	1	2004-05-25
2	4904	8390	2	2004-05-25
3	4904	8492	2	2004-05-25
4	4904	6316	2	2004-05-25
5	4904	9111	3	2004-05-25
6	4904	4211	1	2004-05-25
7	4904	6024	1	2004-05-25
8	4904	9236	2	2004-05-25
1	4905	4781	2	2004-05-04
2	4905	3636	1	2004-05-04
3	4905	6351	2	2004-05-04
4	4905	7201	2	2004-05-04
5	4905	2934	3	2004-05-04
6	4905	2758	2	2004-05-04
7	4905	2435	1	2004-05-04
8	4905	9960	1	2004-05-04
9	4905	5131	2	2004-05-04
1	4906	5833	1	2004-05-24
2	4906	4228	2	2004-05-24
1	4907	4420	1	2004-05-19
2	4907	5123	3	2004-05-19
3	4907	6255	1	2004-05-19
4	4907	4264	2	2004-05-19
5	4907	5620	3	2004-05-19
6	4907	3399	3	2004-05-19
7	4907	1030	2	2004-05-19
8	4907	9524	1	2004-05-19
9	4907	6760	2	2004-05-19
1	4908	5863	2	2004-05-23
2	4908	3709	1	2004-05-23
3	4908	9795	3	2004-05-23
1	4909	1601	2	2004-05-18
1	4910	1311	1	2004-05-26
2	4910	9535	2	2004-05-26
3	4910	9951	1	2004-05-26
1	4911	4129	3	2004-05-02
2	4911	1508	1	2004-05-02
3	4911	1289	3	2004-05-02
4	4911	7751	2	2004-05-02
5	4911	7460	3	2004-05-02
6	4911	4621	1	2004-05-02
7	4911	5853	2	2004-05-02
1	4912	5309	2	2004-05-10
2	4912	3490	2	2004-05-10
1	4913	3588	1	2004-05-19
2	4913	5415	2	2004-05-19
3	4913	9172	3	2004-05-19
4	4913	3955	1	2004-05-19
5	4913	2568	2	2004-05-19
6	4913	8049	1	2004-05-19
1	4914	8567	2	2004-05-01
2	4914	8840	1	2004-05-01
3	4914	1169	3	2004-05-01
4	4914	2798	2	2004-05-01
5	4914	1716	2	2004-05-01
1	4915	3645	1	2004-05-10
2	4915	6294	3	2004-05-10
3	4915	8039	2	2004-05-10
4	4915	8603	1	2004-05-10
1	4916	1488	3	2004-05-20
2	4916	9699	3	2004-05-20
3	4916	2336	3	2004-05-20
4	4916	3065	1	2004-05-20
1	4917	711	1	2004-05-31
2	4917	8995	2	2004-05-31
3	4917	7895	3	2004-05-31
1	4918	599	3	2004-05-26
2	4918	9988	3	2004-05-26
3	4918	1235	2	2004-05-26
4	4918	372	3	2004-05-26
5	4918	323	1	2004-05-26
1	4919	8287	2	2004-05-19
2	4919	9455	3	2004-05-19
3	4919	8507	3	2004-05-19
4	4919	906	3	2004-05-19
5	4919	8121	3	2004-05-19
6	4919	3024	2	2004-05-19
7	4919	8205	1	2004-05-19
8	4919	7555	3	2004-05-19
1	4920	7354	3	2004-05-18
2	4920	1896	3	2004-05-18
3	4920	8354	1	2004-05-18
4	4920	9584	2	2004-05-18
5	4920	2240	1	2004-05-18
6	4920	2579	1	2004-05-18
1	4921	9964	3	2004-05-16
2	4921	2787	3	2004-05-16
3	4921	9528	2	2004-05-16
4	4921	4099	3	2004-05-16
1	4922	9806	2	2004-05-22
2	4922	8605	3	2004-05-22
3	4922	5674	1	2004-05-22
1	4923	8326	2	2004-05-16
2	4923	5259	1	2004-05-16
3	4923	5483	1	2004-05-16
4	4923	2937	2	2004-05-16
5	4923	3894	1	2004-05-16
1	4924	2491	2	2004-05-12
2	4924	1095	3	2004-05-12
3	4924	6734	3	2004-05-12
4	4924	2394	2	2004-05-12
1	4925	1498	3	2004-05-13
2	4925	3726	2	2004-05-13
3	4925	3049	1	2004-05-13
4	4925	9173	3	2004-05-13
5	4925	2954	2	2004-05-13
6	4925	8631	2	2004-05-13
7	4925	8861	1	2004-05-13
8	4925	8789	1	2004-05-13
9	4925	9206	3	2004-05-13
1	4926	1250	1	2004-05-19
2	4926	5385	2	2004-05-19
3	4926	8125	3	2004-05-19
4	4926	4642	1	2004-05-19
5	4926	9107	2	2004-05-19
6	4926	405	1	2004-05-19
7	4926	356	2	2004-05-19
1	4927	4183	1	2004-05-16
2	4927	3724	1	2004-05-16
3	4927	2917	1	2004-05-16
4	4927	5737	1	2004-05-16
5	4927	2283	1	2004-05-16
6	4927	3818	3	2004-05-16
7	4927	8943	2	2004-05-16
8	4927	8721	2	2004-05-16
1	4928	8669	1	2004-05-28
2	4928	9493	3	2004-05-28
3	4928	5674	3	2004-05-28
4	4928	2527	1	2004-05-28
1	4929	4680	1	2004-05-30
2	4929	6601	3	2004-05-30
3	4929	4626	1	2004-05-30
4	4929	9718	3	2004-05-30
1	4930	8603	1	2004-05-13
2	4930	7400	3	2004-05-13
3	4930	9610	1	2004-05-13
1	4931	7351	3	2004-05-03
1	4932	4166	3	2004-05-01
2	4932	2939	3	2004-05-01
3	4932	710	3	2004-05-01
4	4932	6442	2	2004-05-01
5	4932	1876	2	2004-05-01
6	4932	2245	2	2004-05-01
7	4932	9695	2	2004-05-01
8	4932	9077	3	2004-05-01
9	4932	9052	2	2004-05-01
1	4933	6940	1	2004-05-18
2	4933	6434	2	2004-05-18
3	4933	1238	2	2004-05-18
4	4933	4168	1	2004-05-18
5	4933	5821	3	2004-05-18
6	4933	39	3	2004-05-18
1	4934	6084	1	2004-05-23
2	4934	9778	3	2004-05-23
3	4934	6177	3	2004-05-23
4	4934	4616	2	2004-05-23
1	4935	2329	3	2004-05-25
2	4935	9654	3	2004-05-25
3	4935	926	2	2004-05-25
4	4935	3558	1	2004-05-25
1	4936	6057	2	2004-05-08
2	4936	7106	1	2004-05-08
3	4936	4392	2	2004-05-08
4	4936	6852	1	2004-05-08
5	4936	5574	2	2004-05-08
6	4936	8804	1	2004-05-08
7	4936	6101	2	2004-05-08
8	4936	7004	2	2004-05-08
1	4937	8070	3	2004-05-22
2	4937	8682	3	2004-05-22
3	4937	2989	1	2004-05-22
4	4937	1158	2	2004-05-22
5	4937	9964	2	2004-05-22
6	4937	3863	2	2004-05-22
7	4937	8407	1	2004-05-22
8	4937	9254	1	2004-05-22
9	4937	6370	2	2004-05-22
1	4938	3694	3	2004-05-11
2	4938	5496	1	2004-05-11
1	4939	1995	3	2004-05-09
2	4939	6853	1	2004-05-09
3	4939	6494	3	2004-05-09
4	4939	2915	3	2004-05-09
5	4939	5356	1	2004-05-09
6	4939	2414	3	2004-05-09
7	4939	8899	1	2004-05-09
8	4939	186	3	2004-05-09
9	4939	3619	2	2004-05-09
1	4940	8969	1	2004-05-14
2	4940	5829	2	2004-05-14
3	4940	2889	3	2004-05-14
4	4940	7045	1	2004-05-14
5	4940	8484	3	2004-05-14
6	4940	9815	2	2004-05-14
7	4940	9716	2	2004-05-14
1	4941	5509	2	2004-05-17
1	4942	2560	1	2004-05-31
2	4942	6490	3	2004-05-31
3	4942	7703	2	2004-05-31
4	4942	3811	3	2004-05-31
5	4942	7179	3	2004-05-31
6	4942	1135	1	2004-05-31
7	4942	8173	3	2004-05-31
8	4942	2384	2	2004-05-31
9	4942	7218	1	2004-05-31
1	4943	9563	1	2004-05-07
2	4943	7701	2	2004-05-07
3	4943	8838	3	2004-05-07
4	4943	9479	2	2004-05-07
5	4943	7386	1	2004-05-07
6	4943	6842	2	2004-05-07
7	4943	8855	2	2004-05-07
1	4944	2305	1	2004-05-28
2	4944	6108	1	2004-05-28
3	4944	528	3	2004-05-28
4	4944	7133	3	2004-05-28
5	4944	688	3	2004-05-28
6	4944	4679	3	2004-05-28
1	4945	9313	1	2004-05-20
2	4945	1444	3	2004-05-20
3	4945	6526	3	2004-05-20
4	4945	828	2	2004-05-20
1	4946	2348	3	2004-05-09
2	4946	7606	2	2004-05-09
1	4947	2204	1	2004-05-05
2	4947	9749	1	2004-05-05
1	4948	8668	2	2004-05-05
2	4948	1671	3	2004-05-05
3	4948	4239	1	2004-05-05
4	4948	6771	1	2004-05-05
5	4948	1942	3	2004-05-05
6	4948	4132	2	2004-05-05
7	4948	7281	1	2004-05-05
1	4949	4280	1	2004-05-20
2	4949	7528	3	2004-05-20
3	4949	4648	3	2004-05-20
4	4949	1669	2	2004-05-20
1	4950	731	3	2004-05-09
2	4950	8450	1	2004-05-09
3	4950	5471	1	2004-05-09
4	4950	5514	1	2004-05-09
5	4950	3453	3	2004-05-09
1	4951	9628	3	2004-05-31
2	4951	6748	1	2004-05-31
3	4951	2124	1	2004-05-31
4	4951	3441	3	2004-05-31
5	4951	435	3	2004-05-31
6	4951	9382	1	2004-05-31
7	4951	2484	1	2004-05-31
1	4952	8796	2	2004-05-16
2	4952	8289	2	2004-05-16
3	4952	7846	2	2004-05-16
4	4952	6508	1	2004-05-16
5	4952	1258	2	2004-05-16
6	4952	8883	2	2004-05-16
1	4953	9307	2	2004-05-11
1	4954	835	1	2004-05-04
2	4954	3780	1	2004-05-04
1	4955	4824	2	2004-05-15
2	4955	6692	1	2004-05-15
1	4956	5836	3	2004-05-24
2	4956	540	2	2004-05-24
3	4956	1530	2	2004-05-24
4	4956	3229	1	2004-05-24
1	4957	5283	1	2004-05-14
2	4957	7137	2	2004-05-14
3	4957	3248	1	2004-05-14
4	4957	9435	3	2004-05-14
5	4957	9852	2	2004-05-14
1	4958	7787	2	2004-05-30
2	4958	834	2	2004-05-30
3	4958	9356	3	2004-05-30
4	4958	2873	3	2004-05-30
5	4958	1388	2	2004-05-30
6	4958	3901	2	2004-05-30
1	4959	3582	1	2004-05-24
2	4959	5009	1	2004-05-24
3	4959	8550	3	2004-05-24
4	4959	1634	3	2004-05-24
5	4959	6329	1	2004-05-24
1	4960	2232	2	2004-05-07
2	4960	4682	1	2004-05-07
3	4960	8647	2	2004-05-07
4	4960	9735	1	2004-05-07
5	4960	3932	1	2004-05-07
6	4960	5922	3	2004-05-07
7	4960	5738	2	2004-05-07
8	4960	5953	1	2004-05-07
9	4960	8103	3	2004-05-07
1	4961	1368	1	2004-05-17
2	4961	1856	3	2004-05-17
3	4961	3371	2	2004-05-17
4	4961	3631	3	2004-05-17
1	4962	8928	1	2004-05-11
2	4962	2135	3	2004-05-11
3	4962	3643	2	2004-05-11
4	4962	9784	3	2004-05-11
5	4962	3899	2	2004-05-11
6	4962	3085	3	2004-05-11
7	4962	8410	1	2004-05-11
8	4962	9386	2	2004-05-11
1	4963	1523	3	2004-05-14
2	4963	3362	2	2004-05-14
3	4963	3354	3	2004-05-14
4	4963	4423	3	2004-05-14
5	4963	2855	3	2004-05-14
6	4963	4868	1	2004-05-14
1	4964	3068	1	2004-05-01
2	4964	3228	3	2004-05-01
3	4964	5750	2	2004-05-01
4	4964	6817	2	2004-05-01
1	4965	5839	2	2004-05-24
2	4965	7462	3	2004-05-24
1	4966	7817	3	2004-05-16
2	4966	5068	1	2004-05-16
3	4966	4575	3	2004-05-16
4	4966	2454	2	2004-05-16
5	4966	6937	1	2004-05-16
6	4966	8259	1	2004-05-16
7	4966	3127	1	2004-05-16
8	4966	6971	3	2004-05-16
1	4967	9989	1	2004-05-25
2	4967	7091	2	2004-05-25
3	4967	6412	2	2004-05-25
4	4967	3190	1	2004-05-25
5	4967	5376	2	2004-05-25
1	4968	3864	3	2004-05-30
2	4968	4659	2	2004-05-30
3	4968	1291	1	2004-05-30
4	4968	9215	3	2004-05-30
5	4968	1600	1	2004-05-30
1	4969	2357	2	2004-05-04
2	4969	4127	1	2004-05-04
3	4969	5173	1	2004-05-04
4	4969	8173	1	2004-05-04
5	4969	5769	1	2004-05-04
6	4969	2941	1	2004-05-04
7	4969	6806	1	2004-05-04
8	4969	4337	3	2004-05-04
1	4970	4516	3	2004-05-23
2	4970	3572	2	2004-05-23
1	4971	3742	3	2004-05-21
2	4971	6327	2	2004-05-21
3	4971	1539	1	2004-05-21
4	4971	8443	3	2004-05-21
5	4971	1670	2	2004-05-21
6	4971	8295	3	2004-05-21
7	4971	7978	1	2004-05-21
1	4972	3709	1	2004-05-27
2	4972	1118	3	2004-05-27
3	4972	3125	2	2004-05-27
1	4973	1868	2	2004-05-20
2	4973	196	2	2004-05-20
3	4973	2725	2	2004-05-20
1	4974	976	3	2004-05-06
1	4975	505	2	2004-05-21
2	4975	9524	2	2004-05-21
3	4975	7583	1	2004-05-21
4	4975	5484	3	2004-05-21
5	4975	2561	3	2004-05-21
1	4976	1502	3	2004-05-14
2	4976	9134	1	2004-05-14
3	4976	2780	1	2004-05-14
4	4976	8220	2	2004-05-14
1	4977	3838	1	2004-05-19
2	4977	6368	3	2004-05-19
3	4977	6140	3	2004-05-19
4	4977	4583	2	2004-05-19
5	4977	1208	1	2004-05-19
6	4977	8895	3	2004-05-19
7	4977	865	1	2004-05-19
1	4978	8895	1	2004-05-17
1	4979	9888	1	2004-05-25
1	4980	3108	1	2004-05-16
2	4980	1073	3	2004-05-16
3	4980	624	3	2004-05-16
4	4980	6348	2	2004-05-16
5	4980	2875	3	2004-05-16
6	4980	7370	1	2004-05-16
7	4980	4246	3	2004-05-16
8	4980	3224	3	2004-05-16
9	4980	3432	2	2004-05-16
1	4981	356	3	2004-05-01
2	4981	8478	1	2004-05-01
3	4981	367	2	2004-05-01
4	4981	6253	3	2004-05-01
5	4981	3192	3	2004-05-01
6	4981	7940	2	2004-05-01
7	4981	8836	3	2004-05-01
8	4981	1476	2	2004-05-01
1	4982	6119	3	2004-05-12
2	4982	9373	3	2004-05-12
1	4983	5131	3	2004-05-21
2	4983	4599	2	2004-05-21
3	4983	6751	1	2004-05-21
4	4983	5729	3	2004-05-21
5	4983	6594	1	2004-05-21
6	4983	4351	3	2004-05-21
7	4983	1342	1	2004-05-21
1	4984	5360	2	2004-05-13
2	4984	9875	3	2004-05-13
3	4984	5760	2	2004-05-13
4	4984	5079	2	2004-05-13
5	4984	5337	1	2004-05-13
1	4985	6217	1	2004-05-25
2	4985	8553	1	2004-05-25
3	4985	5956	2	2004-05-25
1	4986	2334	3	2004-05-01
2	4986	6724	2	2004-05-01
3	4986	7781	3	2004-05-01
4	4986	1908	1	2004-05-01
1	4987	7776	2	2004-05-07
2	4987	3090	1	2004-05-07
3	4987	7922	1	2004-05-07
4	4987	1270	2	2004-05-07
5	4987	4093	3	2004-05-07
6	4987	9083	1	2004-05-07
7	4987	453	2	2004-05-07
8	4987	6925	1	2004-05-07
1	4988	791	1	2004-05-24
2	4988	6304	3	2004-05-24
3	4988	9271	3	2004-05-24
4	4988	1712	1	2004-05-24
5	4988	9994	1	2004-05-24
6	4988	9426	3	2004-05-24
7	4988	9263	1	2004-05-24
8	4988	882	3	2004-05-24
9	4988	3542	1	2004-05-24
1	4989	278	1	2004-05-11
2	4989	7507	3	2004-05-11
3	4989	627	2	2004-05-11
1	4990	7291	1	2004-05-02
2	4990	9751	2	2004-05-02
1	4991	4410	3	2004-05-30
2	4991	7291	2	2004-05-30
3	4991	9971	3	2004-05-30
4	4991	856	2	2004-05-30
5	4991	323	2	2004-05-30
6	4991	1146	3	2004-05-30
7	4991	6710	1	2004-05-30
8	4991	50	2	2004-05-30
9	4991	8626	1	2004-05-30
1	4992	195	2	2004-05-29
2	4992	5642	3	2004-05-29
3	4992	125	2	2004-05-29
4	4992	1408	3	2004-05-29
1	4993	9489	2	2004-05-15
2	4993	155	1	2004-05-15
1	4994	437	1	2004-05-29
1	4995	1164	2	2004-05-06
1	4996	1000	2	2004-05-29
2	4996	9443	1	2004-05-29
3	4996	9959	1	2004-05-29
4	4996	9279	2	2004-05-29
5	4996	6668	2	2004-05-29
6	4996	6633	2	2004-05-29
7	4996	469	3	2004-05-29
8	4996	6499	3	2004-05-29
9	4996	7265	1	2004-05-29
1	4997	8189	3	2004-05-31
2	4997	1747	3	2004-05-31
1	4998	546	3	2004-05-09
2	4998	6645	3	2004-05-09
1	4999	1253	3	2004-05-28
2	4999	3077	3	2004-05-28
3	4999	3662	2	2004-05-28
4	4999	4673	1	2004-05-28
5	4999	3106	1	2004-05-28
6	4999	1244	1	2004-05-28
7	4999	9639	2	2004-05-28
8	4999	4364	3	2004-05-28
1	5000	7159	2	2004-05-05
2	5000	6078	3	2004-05-05
3	5000	1753	1	2004-05-05
4	5000	7692	1	2004-05-05
1	5001	5549	1	2004-06-08
2	5001	4398	2	2004-06-08
3	5001	7568	3	2004-06-08
4	5001	3244	3	2004-06-08
1	5002	2745	1	2004-06-14
2	5002	582	2	2004-06-14
1	5003	9056	3	2004-06-30
1	5004	2250	3	2004-06-21
2	5004	9382	1	2004-06-21
1	5005	8823	1	2004-06-10
2	5005	6815	1	2004-06-10
3	5005	9889	1	2004-06-10
4	5005	6267	1	2004-06-10
5	5005	3012	3	2004-06-10
6	5005	2330	2	2004-06-10
7	5005	4188	1	2004-06-10
1	5006	8686	1	2004-06-25
2	5006	2768	2	2004-06-25
3	5006	1816	2	2004-06-25
4	5006	5827	1	2004-06-25
5	5006	7477	3	2004-06-25
6	5006	6127	1	2004-06-25
7	5006	6541	2	2004-06-25
1	5007	4667	1	2004-06-19
2	5007	6754	3	2004-06-19
3	5007	2292	3	2004-06-19
4	5007	1272	2	2004-06-19
5	5007	1278	3	2004-06-19
6	5007	6122	2	2004-06-19
1	5008	869	2	2004-06-20
2	5008	4259	3	2004-06-20
3	5008	7702	1	2004-06-20
4	5008	5680	2	2004-06-20
5	5008	4856	1	2004-06-20
6	5008	8777	1	2004-06-20
7	5008	5577	2	2004-06-20
8	5008	7410	1	2004-06-20
9	5008	9074	2	2004-06-20
1	5009	7845	2	2004-06-24
2	5009	8538	2	2004-06-24
3	5009	9057	2	2004-06-24
4	5009	8774	2	2004-06-24
5	5009	4254	3	2004-06-24
6	5009	250	3	2004-06-24
7	5009	6337	3	2004-06-24
8	5009	247	1	2004-06-24
9	5009	1779	2	2004-06-24
1	5010	6347	2	2004-06-13
2	5010	56	2	2004-06-13
3	5010	7861	3	2004-06-13
4	5010	6785	1	2004-06-13
5	5010	7170	2	2004-06-13
6	5010	5628	2	2004-06-13
7	5010	8596	2	2004-06-13
8	5010	719	3	2004-06-13
9	5010	8430	2	2004-06-13
1	5011	6630	2	2004-06-22
2	5011	5362	3	2004-06-22
3	5011	8833	3	2004-06-22
4	5011	8964	2	2004-06-22
1	5012	730	3	2004-06-29
2	5012	7443	3	2004-06-29
3	5012	7787	2	2004-06-29
4	5012	2144	2	2004-06-29
5	5012	319	1	2004-06-29
6	5012	8098	1	2004-06-29
7	5012	8108	2	2004-06-29
8	5012	6010	2	2004-06-29
9	5012	5206	3	2004-06-29
1	5013	244	1	2004-06-26
2	5013	3423	3	2004-06-26
3	5013	7178	1	2004-06-26
4	5013	4517	2	2004-06-26
1	5014	2761	1	2004-06-07
2	5014	4355	2	2004-06-07
3	5014	3880	2	2004-06-07
4	5014	5643	1	2004-06-07
5	5014	5711	2	2004-06-07
6	5014	8505	1	2004-06-07
7	5014	8867	2	2004-06-07
8	5014	1215	3	2004-06-07
9	5014	5546	2	2004-06-07
1	5015	4997	2	2004-06-04
2	5015	7410	3	2004-06-04
3	5015	9670	3	2004-06-04
4	5015	4760	1	2004-06-04
5	5015	9453	3	2004-06-04
1	5016	8480	3	2004-06-09
2	5016	8670	2	2004-06-09
3	5016	1817	3	2004-06-09
4	5016	5912	1	2004-06-09
5	5016	884	3	2004-06-09
6	5016	8013	2	2004-06-09
7	5016	1564	3	2004-06-09
1	5017	1730	1	2004-06-07
2	5017	6728	1	2004-06-07
3	5017	862	1	2004-06-07
4	5017	3747	1	2004-06-07
5	5017	9007	2	2004-06-07
6	5017	4121	1	2004-06-07
7	5017	3253	1	2004-06-07
1	5018	9096	1	2004-06-29
2	5018	1997	3	2004-06-29
1	5019	9176	3	2004-06-30
2	5019	9449	1	2004-06-30
1	5020	2577	2	2004-06-18
2	5020	4056	2	2004-06-18
3	5020	5244	1	2004-06-18
1	5021	1964	2	2004-06-09
2	5021	8058	3	2004-06-09
3	5021	5303	3	2004-06-09
4	5021	1456	3	2004-06-09
5	5021	7132	1	2004-06-09
6	5021	7309	2	2004-06-09
1	5022	9402	3	2004-06-09
2	5022	3303	2	2004-06-09
1	5023	2203	2	2004-06-02
2	5023	7691	2	2004-06-02
3	5023	3006	1	2004-06-02
4	5023	1222	2	2004-06-02
5	5023	6173	3	2004-06-02
1	5024	8775	2	2004-06-12
2	5024	6463	2	2004-06-12
3	5024	7102	3	2004-06-12
4	5024	2569	3	2004-06-12
5	5024	1262	1	2004-06-12
1	5025	444	2	2004-06-22
2	5025	2474	1	2004-06-22
3	5025	7482	1	2004-06-22
4	5025	7732	1	2004-06-22
5	5025	2348	3	2004-06-22
6	5025	5456	3	2004-06-22
7	5025	8233	3	2004-06-22
8	5025	9995	2	2004-06-22
1	5026	4854	2	2004-06-14
1	5027	9392	1	2004-06-30
2	5027	5783	2	2004-06-30
1	5028	8872	2	2004-06-30
2	5028	2350	2	2004-06-30
1	5029	3217	2	2004-06-20
2	5029	1273	1	2004-06-20
1	5030	6449	3	2004-06-26
2	5030	2013	2	2004-06-26
3	5030	4257	2	2004-06-26
4	5030	7625	2	2004-06-26
5	5030	8475	2	2004-06-26
6	5030	8478	3	2004-06-26
7	5030	9632	3	2004-06-26
1	5031	5106	3	2004-06-02
2	5031	7417	1	2004-06-02
3	5031	2029	1	2004-06-02
1	5032	8930	2	2004-06-14
2	5032	9590	2	2004-06-14
3	5032	2660	1	2004-06-14
1	5033	564	3	2004-06-06
2	5033	2815	3	2004-06-06
3	5033	4872	1	2004-06-06
4	5033	6188	2	2004-06-06
5	5033	949	3	2004-06-06
6	5033	7963	2	2004-06-06
7	5033	9420	2	2004-06-06
8	5033	6718	1	2004-06-06
9	5033	6012	1	2004-06-06
1	5034	5681	2	2004-06-15
2	5034	9056	3	2004-06-15
3	5034	5270	1	2004-06-15
4	5034	5256	2	2004-06-15
1	5035	4860	2	2004-06-01
2	5035	5508	1	2004-06-01
3	5035	280	2	2004-06-01
1	5036	3622	3	2004-06-02
2	5036	1399	3	2004-06-02
3	5036	400	2	2004-06-02
4	5036	9489	2	2004-06-02
5	5036	9823	2	2004-06-02
6	5036	8145	3	2004-06-02
7	5036	3509	2	2004-06-02
8	5036	9717	3	2004-06-02
9	5036	6895	3	2004-06-02
1	5037	2096	3	2004-06-14
2	5037	491	1	2004-06-14
3	5037	4989	1	2004-06-14
4	5037	618	3	2004-06-14
5	5037	975	2	2004-06-14
6	5037	6728	1	2004-06-14
7	5037	3872	3	2004-06-14
8	5037	8519	2	2004-06-14
9	5037	1604	3	2004-06-14
1	5038	3163	3	2004-06-26
2	5038	803	1	2004-06-26
1	5039	4829	3	2004-06-21
2	5039	8458	2	2004-06-21
3	5039	1587	2	2004-06-21
4	5039	6342	1	2004-06-21
5	5039	945	3	2004-06-21
6	5039	6443	3	2004-06-21
7	5039	9689	1	2004-06-21
8	5039	4800	3	2004-06-21
9	5039	3675	2	2004-06-21
1	5040	4243	3	2004-06-20
2	5040	707	2	2004-06-20
3	5040	9371	3	2004-06-20
4	5040	430	2	2004-06-20
1	5041	577	3	2004-06-23
2	5041	9437	3	2004-06-23
3	5041	9488	1	2004-06-23
4	5041	4234	2	2004-06-23
5	5041	8054	2	2004-06-23
6	5041	6245	1	2004-06-23
1	5042	2123	2	2004-06-07
2	5042	2448	2	2004-06-07
3	5042	4724	1	2004-06-07
4	5042	1410	2	2004-06-07
5	5042	761	1	2004-06-07
6	5042	580	3	2004-06-07
7	5042	7098	2	2004-06-07
8	5042	4284	3	2004-06-07
1	5043	4101	3	2004-06-11
2	5043	8979	1	2004-06-11
3	5043	2747	2	2004-06-11
1	5044	3554	3	2004-06-16
2	5044	9675	2	2004-06-16
3	5044	3630	2	2004-06-16
4	5044	9155	2	2004-06-16
1	5045	8208	2	2004-06-26
2	5045	5347	1	2004-06-26
3	5045	1652	3	2004-06-26
4	5045	6211	2	2004-06-26
5	5045	1957	1	2004-06-26
6	5045	5068	1	2004-06-26
7	5045	2465	3	2004-06-26
8	5045	6158	3	2004-06-26
9	5045	2689	1	2004-06-26
1	5046	2244	1	2004-06-06
2	5046	5811	1	2004-06-06
1	5047	3373	3	2004-06-22
2	5047	8090	3	2004-06-22
3	5047	2011	3	2004-06-22
4	5047	7627	3	2004-06-22
1	5048	518	1	2004-06-18
1	5049	7975	1	2004-06-27
2	5049	7796	2	2004-06-27
1	5050	1436	2	2004-06-05
2	5050	1734	1	2004-06-05
3	5050	78	2	2004-06-05
4	5050	2268	3	2004-06-05
5	5050	3825	2	2004-06-05
6	5050	7908	1	2004-06-05
7	5050	2501	2	2004-06-05
1	5051	2029	2	2004-06-04
2	5051	8228	1	2004-06-04
1	5052	2741	1	2004-06-17
2	5052	3193	1	2004-06-17
3	5052	9759	2	2004-06-17
1	5053	6598	3	2004-06-23
2	5053	5682	1	2004-06-23
3	5053	3924	2	2004-06-23
4	5053	1874	2	2004-06-23
5	5053	7479	1	2004-06-23
6	5053	7456	1	2004-06-23
7	5053	4461	3	2004-06-23
1	5054	8891	1	2004-06-19
2	5054	4738	1	2004-06-19
1	5055	2560	1	2004-06-10
2	5055	4266	3	2004-06-10
3	5055	8056	1	2004-06-10
1	5056	7326	1	2004-06-29
2	5056	9929	2	2004-06-29
3	5056	6068	3	2004-06-29
4	5056	7224	1	2004-06-29
1	5057	5032	1	2004-06-21
2	5057	7538	3	2004-06-21
3	5057	3738	1	2004-06-21
4	5057	7700	3	2004-06-21
5	5057	3326	1	2004-06-21
6	5057	7382	3	2004-06-21
7	5057	195	2	2004-06-21
1	5058	3281	2	2004-06-26
2	5058	2897	1	2004-06-26
3	5058	1304	3	2004-06-26
4	5058	594	3	2004-06-26
5	5058	9492	3	2004-06-26
6	5058	1976	1	2004-06-26
7	5058	4312	3	2004-06-26
8	5058	4813	1	2004-06-26
9	5058	6777	3	2004-06-26
1	5059	4735	1	2004-06-08
2	5059	3318	2	2004-06-08
3	5059	8210	1	2004-06-08
4	5059	4705	3	2004-06-08
5	5059	1509	3	2004-06-08
6	5059	3885	2	2004-06-08
1	5060	3716	1	2004-06-04
2	5060	9250	2	2004-06-04
1	5061	5412	3	2004-06-17
1	5062	3540	3	2004-06-27
2	5062	7093	3	2004-06-27
3	5062	3613	2	2004-06-27
4	5062	8628	3	2004-06-27
1	5063	4542	3	2004-06-09
2	5063	1759	3	2004-06-09
3	5063	9287	2	2004-06-09
4	5063	772	3	2004-06-09
5	5063	1166	2	2004-06-09
6	5063	2098	2	2004-06-09
1	5064	5322	3	2004-06-21
2	5064	9971	3	2004-06-21
3	5064	5972	3	2004-06-21
4	5064	5719	3	2004-06-21
5	5064	2367	2	2004-06-21
6	5064	7903	2	2004-06-21
1	5065	1704	2	2004-06-14
2	5065	6934	1	2004-06-14
3	5065	8857	3	2004-06-14
4	5065	9526	1	2004-06-14
5	5065	4045	1	2004-06-14
6	5065	3886	1	2004-06-14
7	5065	9133	3	2004-06-14
8	5065	6416	2	2004-06-14
9	5065	4512	2	2004-06-14
1	5066	69	2	2004-06-10
2	5066	3379	3	2004-06-10
3	5066	870	3	2004-06-10
4	5066	2177	1	2004-06-10
5	5066	6884	2	2004-06-10
6	5066	5876	2	2004-06-10
7	5066	4870	2	2004-06-10
8	5066	1523	2	2004-06-10
9	5066	4755	2	2004-06-10
1	5067	5865	1	2004-06-19
2	5067	9604	1	2004-06-19
3	5067	9134	1	2004-06-19
4	5067	861	1	2004-06-19
5	5067	1952	1	2004-06-19
1	5068	3191	1	2004-06-26
2	5068	1762	1	2004-06-26
3	5068	4955	3	2004-06-26
4	5068	3891	3	2004-06-26
5	5068	2370	2	2004-06-26
6	5068	4219	3	2004-06-26
7	5068	981	1	2004-06-26
8	5068	5765	3	2004-06-26
9	5068	5387	1	2004-06-26
1	5069	7910	1	2004-06-01
2	5069	1778	3	2004-06-01
3	5069	3795	1	2004-06-01
4	5069	5191	1	2004-06-01
5	5069	9447	3	2004-06-01
6	5069	3770	1	2004-06-01
7	5069	8456	3	2004-06-01
8	5069	8846	1	2004-06-01
9	5069	8548	1	2004-06-01
1	5070	3004	2	2004-06-24
2	5070	6054	3	2004-06-24
3	5070	5733	2	2004-06-24
4	5070	3381	3	2004-06-24
5	5070	5309	1	2004-06-24
6	5070	604	3	2004-06-24
7	5070	1151	2	2004-06-24
8	5070	7264	2	2004-06-24
1	5071	7919	1	2004-06-22
1	5072	7980	1	2004-06-29
2	5072	900	2	2004-06-29
3	5072	2024	2	2004-06-29
4	5072	423	3	2004-06-29
5	5072	2293	2	2004-06-29
6	5072	4191	2	2004-06-29
7	5072	3894	3	2004-06-29
8	5072	6964	2	2004-06-29
1	5073	4456	2	2004-06-20
2	5073	561	3	2004-06-20
3	5073	6848	3	2004-06-20
4	5073	2356	2	2004-06-20
1	5074	1163	2	2004-06-16
2	5074	9543	1	2004-06-16
3	5074	9366	3	2004-06-16
1	5075	7332	1	2004-06-04
2	5075	4954	2	2004-06-04
3	5075	4513	1	2004-06-04
4	5075	2410	2	2004-06-04
5	5075	5390	3	2004-06-04
1	5076	4429	3	2004-06-29
2	5076	2674	3	2004-06-29
3	5076	6279	3	2004-06-29
4	5076	2896	3	2004-06-29
5	5076	2701	1	2004-06-29
6	5076	629	1	2004-06-29
1	5077	7345	1	2004-06-08
2	5077	8539	1	2004-06-08
3	5077	5353	1	2004-06-08
4	5077	3838	3	2004-06-08
5	5077	6459	3	2004-06-08
6	5077	4628	2	2004-06-08
7	5077	5177	1	2004-06-08
8	5077	2096	3	2004-06-08
1	5078	2007	1	2004-06-28
2	5078	2791	2	2004-06-28
3	5078	4612	2	2004-06-28
4	5078	6774	3	2004-06-28
5	5078	5310	1	2004-06-28
1	5079	4953	3	2004-06-17
2	5079	7130	3	2004-06-17
3	5079	4671	2	2004-06-17
4	5079	8018	3	2004-06-17
1	5080	2801	3	2004-06-29
2	5080	6306	1	2004-06-29
1	5081	3019	3	2004-06-14
2	5081	596	3	2004-06-14
3	5081	5879	2	2004-06-14
4	5081	292	1	2004-06-14
5	5081	8560	1	2004-06-14
6	5081	5496	2	2004-06-14
7	5081	8756	1	2004-06-14
1	5082	2725	2	2004-06-07
1	5083	1731	2	2004-06-11
2	5083	8393	2	2004-06-11
3	5083	1809	1	2004-06-11
4	5083	3295	2	2004-06-11
5	5083	1510	2	2004-06-11
6	5083	4620	3	2004-06-11
1	5084	6759	2	2004-06-30
2	5084	1867	2	2004-06-30
3	5084	6927	2	2004-06-30
4	5084	8942	1	2004-06-30
5	5084	4489	1	2004-06-30
6	5084	8794	3	2004-06-30
7	5084	4359	2	2004-06-30
8	5084	4318	2	2004-06-30
1	5085	5356	2	2004-06-29
2	5085	6116	3	2004-06-29
1	5086	5646	1	2004-06-29
2	5086	7541	1	2004-06-29
3	5086	7360	3	2004-06-29
4	5086	7919	2	2004-06-29
5	5086	3576	3	2004-06-29
6	5086	7425	3	2004-06-29
7	5086	8526	2	2004-06-29
8	5086	6067	1	2004-06-29
9	5086	2203	1	2004-06-29
1	5087	2973	3	2004-06-27
2	5087	6681	3	2004-06-27
1	5088	5259	2	2004-06-16
2	5088	2627	1	2004-06-16
3	5088	7873	3	2004-06-16
4	5088	2206	2	2004-06-16
5	5088	4272	2	2004-06-16
6	5088	2652	1	2004-06-16
7	5088	3845	1	2004-06-16
8	5088	7914	3	2004-06-16
9	5088	4061	1	2004-06-16
1	5089	4213	2	2004-06-01
2	5089	1842	1	2004-06-01
3	5089	3859	3	2004-06-01
4	5089	6967	2	2004-06-01
1	5090	5024	3	2004-06-21
2	5090	9338	3	2004-06-21
3	5090	2815	2	2004-06-21
4	5090	3011	2	2004-06-21
5	5090	5306	3	2004-06-21
6	5090	6643	1	2004-06-21
7	5090	6767	1	2004-06-21
8	5090	3336	3	2004-06-21
9	5090	3736	2	2004-06-21
1	5091	8843	2	2004-06-02
2	5091	9454	2	2004-06-02
3	5091	7446	2	2004-06-02
1	5092	3620	2	2004-06-25
2	5092	286	2	2004-06-25
3	5092	8478	1	2004-06-25
1	5093	7003	3	2004-06-06
2	5093	9246	1	2004-06-06
3	5093	3981	1	2004-06-06
4	5093	5473	2	2004-06-06
5	5093	930	2	2004-06-06
6	5093	6731	3	2004-06-06
7	5093	9143	2	2004-06-06
8	5093	5580	2	2004-06-06
1	5094	6669	3	2004-06-08
2	5094	2762	3	2004-06-08
3	5094	3237	1	2004-06-08
4	5094	250	2	2004-06-08
5	5094	5024	1	2004-06-08
6	5094	3680	1	2004-06-08
7	5094	7318	1	2004-06-08
8	5094	2364	1	2004-06-08
1	5095	3215	1	2004-06-18
2	5095	6606	1	2004-06-18
3	5095	8649	1	2004-06-18
4	5095	8945	1	2004-06-18
5	5095	5798	1	2004-06-18
6	5095	8905	1	2004-06-18
7	5095	8931	1	2004-06-18
1	5096	7304	3	2004-06-29
2	5096	69	1	2004-06-29
3	5096	9955	3	2004-06-29
4	5096	3908	1	2004-06-29
5	5096	8686	3	2004-06-29
6	5096	155	2	2004-06-29
7	5096	6647	2	2004-06-29
8	5096	6883	1	2004-06-29
9	5096	5726	2	2004-06-29
1	5097	6798	2	2004-06-17
2	5097	3702	2	2004-06-17
1	5098	2790	2	2004-06-22
1	5099	245	1	2004-06-24
2	5099	220	3	2004-06-24
3	5099	9902	1	2004-06-24
4	5099	3349	2	2004-06-24
5	5099	3744	1	2004-06-24
6	5099	9801	3	2004-06-24
7	5099	5763	2	2004-06-24
8	5099	4138	1	2004-06-24
1	5100	6663	2	2004-06-20
1	5101	9756	1	2004-06-10
2	5101	8944	2	2004-06-10
3	5101	731	3	2004-06-10
4	5101	6027	1	2004-06-10
5	5101	8119	2	2004-06-10
6	5101	1324	1	2004-06-10
1	5102	4536	3	2004-06-08
2	5102	7516	3	2004-06-08
3	5102	9766	2	2004-06-08
1	5103	2382	3	2004-06-29
2	5103	827	3	2004-06-29
3	5103	3547	1	2004-06-29
4	5103	94	1	2004-06-29
5	5103	6520	1	2004-06-29
6	5103	1680	1	2004-06-29
1	5104	1266	1	2004-06-06
2	5104	8165	1	2004-06-06
3	5104	3226	1	2004-06-06
1	5105	4731	1	2004-06-02
1	5106	6357	3	2004-06-24
1	5107	2395	2	2004-06-23
2	5107	8272	2	2004-06-23
3	5107	7724	1	2004-06-23
4	5107	3873	2	2004-06-23
5	5107	3142	2	2004-06-23
6	5107	7146	1	2004-06-23
7	5107	8102	1	2004-06-23
1	5108	8718	2	2004-06-13
2	5108	6358	2	2004-06-13
3	5108	4738	2	2004-06-13
4	5108	6516	1	2004-06-13
5	5108	1684	2	2004-06-13
1	5109	5520	3	2004-06-03
2	5109	7467	1	2004-06-03
3	5109	9634	1	2004-06-03
4	5109	9439	1	2004-06-03
1	5110	6956	3	2004-06-20
2	5110	3104	3	2004-06-20
3	5110	3464	1	2004-06-20
4	5110	3910	3	2004-06-20
5	5110	8247	3	2004-06-20
1	5111	8633	1	2004-06-11
2	5111	5454	3	2004-06-11
3	5111	4133	1	2004-06-11
4	5111	9541	1	2004-06-11
5	5111	4216	3	2004-06-11
1	5112	239	2	2004-06-09
2	5112	3991	3	2004-06-09
3	5112	4117	3	2004-06-09
4	5112	5262	3	2004-06-09
5	5112	8916	3	2004-06-09
6	5112	7402	3	2004-06-09
7	5112	7819	1	2004-06-09
8	5112	1925	3	2004-06-09
9	5112	5943	1	2004-06-09
1	5113	2369	1	2004-06-25
2	5113	4031	2	2004-06-25
3	5113	9223	3	2004-06-25
1	5114	7202	1	2004-06-01
1	5115	8898	2	2004-06-24
2	5115	2103	2	2004-06-24
3	5115	3543	3	2004-06-24
1	5116	6025	2	2004-06-22
2	5116	4468	2	2004-06-22
3	5116	8213	3	2004-06-22
1	5117	9211	2	2004-06-20
2	5117	6975	2	2004-06-20
3	5117	4135	2	2004-06-20
4	5117	5961	1	2004-06-20
5	5117	5494	2	2004-06-20
6	5117	4737	2	2004-06-20
1	5118	6759	3	2004-06-30
2	5118	8816	2	2004-06-30
3	5118	891	2	2004-06-30
4	5118	20	2	2004-06-30
1	5119	476	2	2004-06-05
2	5119	3757	3	2004-06-05
3	5119	9274	1	2004-06-05
4	5119	5277	2	2004-06-05
5	5119	4907	1	2004-06-05
6	5119	5214	1	2004-06-05
7	5119	4664	3	2004-06-05
8	5119	4791	2	2004-06-05
1	5120	3301	2	2004-06-21
2	5120	7788	2	2004-06-21
3	5120	1475	3	2004-06-21
4	5120	9550	1	2004-06-21
1	5121	7360	2	2004-06-19
2	5121	6202	2	2004-06-19
3	5121	5288	1	2004-06-19
4	5121	42	1	2004-06-19
5	5121	2716	2	2004-06-19
6	5121	595	3	2004-06-19
1	5122	867	3	2004-06-16
2	5122	5542	2	2004-06-16
1	5123	1136	3	2004-06-19
2	5123	623	3	2004-06-19
3	5123	9652	1	2004-06-19
4	5123	3691	3	2004-06-19
5	5123	5980	3	2004-06-19
6	5123	3646	1	2004-06-19
7	5123	1371	2	2004-06-19
1	5124	1467	2	2004-06-05
2	5124	7441	1	2004-06-05
1	5125	2473	3	2004-06-19
2	5125	5012	1	2004-06-19
1	5126	3323	3	2004-06-22
2	5126	9104	3	2004-06-22
3	5126	5402	2	2004-06-22
4	5126	6906	3	2004-06-22
5	5126	6350	3	2004-06-22
6	5126	2734	3	2004-06-22
7	5126	2364	1	2004-06-22
1	5127	7145	1	2004-06-30
2	5127	5614	1	2004-06-30
3	5127	3649	3	2004-06-30
4	5127	9410	3	2004-06-30
5	5127	8917	2	2004-06-30
6	5127	4809	3	2004-06-30
7	5127	4150	3	2004-06-30
1	5128	8337	1	2004-06-19
2	5128	492	2	2004-06-19
1	5129	4902	1	2004-06-01
2	5129	6518	1	2004-06-01
3	5129	9671	2	2004-06-01
1	5130	3370	1	2004-06-09
2	5130	5001	1	2004-06-09
3	5130	9666	3	2004-06-09
4	5130	9940	2	2004-06-09
5	5130	7940	2	2004-06-09
6	5130	7068	1	2004-06-09
1	5131	90	2	2004-06-23
2	5131	1144	1	2004-06-23
3	5131	8147	2	2004-06-23
4	5131	4950	2	2004-06-23
5	5131	6770	2	2004-06-23
6	5131	8326	3	2004-06-23
7	5131	9904	1	2004-06-23
8	5131	5802	1	2004-06-23
1	5132	612	2	2004-06-16
2	5132	8791	3	2004-06-16
3	5132	1481	2	2004-06-16
4	5132	1635	3	2004-06-16
5	5132	1262	3	2004-06-16
1	5133	3938	1	2004-06-21
2	5133	4013	3	2004-06-21
3	5133	5035	1	2004-06-21
4	5133	3508	2	2004-06-21
5	5133	244	2	2004-06-21
6	5133	5474	2	2004-06-21
7	5133	6684	1	2004-06-21
8	5133	6848	1	2004-06-21
1	5134	6011	3	2004-06-18
2	5134	407	3	2004-06-18
3	5134	8127	1	2004-06-18
4	5134	4412	2	2004-06-18
5	5134	3020	2	2004-06-18
1	5135	5844	1	2004-06-09
2	5135	7716	3	2004-06-09
3	5135	5403	3	2004-06-09
4	5135	2762	1	2004-06-09
5	5135	4005	3	2004-06-09
6	5135	1659	1	2004-06-09
7	5135	1686	3	2004-06-09
1	5136	8645	1	2004-06-25
2	5136	1969	3	2004-06-25
3	5136	4042	2	2004-06-25
4	5136	1723	3	2004-06-25
1	5137	1576	3	2004-06-10
1	5138	7251	1	2004-06-07
2	5138	8344	1	2004-06-07
3	5138	1417	1	2004-06-07
4	5138	2109	1	2004-06-07
5	5138	7420	1	2004-06-07
6	5138	2528	3	2004-06-07
7	5138	4744	1	2004-06-07
1	5139	3092	3	2004-06-06
2	5139	2862	2	2004-06-06
3	5139	4309	3	2004-06-06
4	5139	6132	2	2004-06-06
5	5139	6740	3	2004-06-06
6	5139	5176	2	2004-06-06
1	5140	3682	3	2004-06-17
2	5140	4011	2	2004-06-17
3	5140	2443	1	2004-06-17
4	5140	6210	2	2004-06-17
1	5141	7665	2	2004-06-03
2	5141	8375	1	2004-06-03
3	5141	3751	1	2004-06-03
1	5142	3944	2	2004-06-21
2	5142	1194	3	2004-06-21
3	5142	806	3	2004-06-21
1	5143	8069	2	2004-06-05
2	5143	1017	1	2004-06-05
3	5143	6307	3	2004-06-05
4	5143	5481	3	2004-06-05
5	5143	8180	1	2004-06-05
1	5144	6601	3	2004-06-30
2	5144	9307	2	2004-06-30
3	5144	7517	3	2004-06-30
4	5144	6461	1	2004-06-30
5	5144	2277	3	2004-06-30
6	5144	579	1	2004-06-30
7	5144	4513	1	2004-06-30
8	5144	1810	2	2004-06-30
1	5145	389	2	2004-06-23
2	5145	5593	2	2004-06-23
3	5145	3687	2	2004-06-23
4	5145	7493	2	2004-06-23
5	5145	9616	1	2004-06-23
6	5145	1453	2	2004-06-23
7	5145	2656	1	2004-06-23
8	5145	9682	1	2004-06-23
1	5146	3796	1	2004-06-25
1	5147	3689	1	2004-06-11
2	5147	5227	2	2004-06-11
3	5147	51	2	2004-06-11
4	5147	511	2	2004-06-11
5	5147	1486	2	2004-06-11
1	5148	2177	3	2004-06-29
2	5148	5248	2	2004-06-29
3	5148	9791	2	2004-06-29
4	5148	5005	3	2004-06-29
5	5148	1071	2	2004-06-29
6	5148	8429	2	2004-06-29
7	5148	8847	1	2004-06-29
8	5148	3175	1	2004-06-29
9	5148	7317	3	2004-06-29
1	5149	8159	1	2004-06-15
2	5149	559	3	2004-06-15
3	5149	5517	3	2004-06-15
4	5149	8622	1	2004-06-15
5	5149	9004	1	2004-06-15
1	5150	9179	1	2004-06-07
2	5150	9887	1	2004-06-07
1	5151	284	3	2004-06-22
2	5151	9297	3	2004-06-22
3	5151	5154	2	2004-06-22
4	5151	144	2	2004-06-22
5	5151	9077	3	2004-06-22
6	5151	7283	3	2004-06-22
1	5152	5893	3	2004-06-24
2	5152	7367	3	2004-06-24
3	5152	2862	1	2004-06-24
4	5152	9934	1	2004-06-24
5	5152	3632	3	2004-06-24
6	5152	2290	1	2004-06-24
1	5153	5696	2	2004-06-25
2	5153	6021	1	2004-06-25
3	5153	477	2	2004-06-25
4	5153	6812	3	2004-06-25
5	5153	4466	2	2004-06-25
6	5153	9188	1	2004-06-25
7	5153	6893	3	2004-06-25
8	5153	8982	1	2004-06-25
1	5154	9345	1	2004-06-23
1	5155	3879	3	2004-06-07
2	5155	2002	1	2004-06-07
3	5155	7113	3	2004-06-07
4	5155	7212	1	2004-06-07
5	5155	8547	3	2004-06-07
1	5156	9454	2	2004-06-28
2	5156	6176	2	2004-06-28
3	5156	5223	2	2004-06-28
4	5156	9131	1	2004-06-28
1	5157	671	2	2004-06-05
1	5158	9920	1	2004-06-12
2	5158	8601	3	2004-06-12
3	5158	9499	2	2004-06-12
4	5158	166	3	2004-06-12
5	5158	3499	3	2004-06-12
6	5158	3405	1	2004-06-12
7	5158	3225	1	2004-06-12
1	5159	4557	3	2004-06-22
2	5159	5018	2	2004-06-22
3	5159	8268	3	2004-06-22
1	5160	165	1	2004-06-21
1	5161	7117	2	2004-06-26
2	5161	2853	3	2004-06-26
3	5161	2261	2	2004-06-26
4	5161	6744	2	2004-06-26
5	5161	7091	3	2004-06-26
6	5161	8523	2	2004-06-26
7	5161	9368	3	2004-06-26
1	5162	9985	2	2004-06-20
2	5162	9579	3	2004-06-20
1	5163	5609	2	2004-06-10
2	5163	3515	1	2004-06-10
3	5163	3113	1	2004-06-10
4	5163	4540	2	2004-06-10
1	5164	2465	3	2004-06-24
2	5164	4626	1	2004-06-24
3	5164	3665	2	2004-06-24
4	5164	8713	1	2004-06-24
5	5164	7917	2	2004-06-24
1	5165	4796	1	2004-06-06
2	5165	4249	1	2004-06-06
1	5166	183	1	2004-06-18
2	5166	9941	2	2004-06-18
3	5166	7578	3	2004-06-18
4	5166	1522	3	2004-06-18
5	5166	2511	2	2004-06-18
6	5166	9301	3	2004-06-18
7	5166	4973	1	2004-06-18
8	5166	1129	2	2004-06-18
9	5166	3278	3	2004-06-18
1	5167	6809	1	2004-06-26
2	5167	9921	1	2004-06-26
3	5167	4167	2	2004-06-26
4	5167	916	1	2004-06-26
5	5167	5024	1	2004-06-26
6	5167	4278	2	2004-06-26
7	5167	5820	1	2004-06-26
1	5168	1327	1	2004-06-09
2	5168	2464	2	2004-06-09
3	5168	4015	2	2004-06-09
4	5168	9984	3	2004-06-09
5	5168	2637	3	2004-06-09
1	5169	1322	2	2004-06-08
2	5169	412	2	2004-06-08
3	5169	1632	1	2004-06-08
4	5169	8154	2	2004-06-08
5	5169	2424	1	2004-06-08
6	5169	1619	3	2004-06-08
7	5169	4287	2	2004-06-08
8	5169	5585	2	2004-06-08
9	5169	9765	3	2004-06-08
1	5170	5820	1	2004-06-22
1	5171	8038	3	2004-06-26
1	5172	4847	2	2004-06-01
1	5173	5432	2	2004-06-07
2	5173	2695	3	2004-06-07
3	5173	7886	3	2004-06-07
4	5173	5753	3	2004-06-07
5	5173	5190	1	2004-06-07
1	5174	1592	1	2004-06-30
2	5174	4154	1	2004-06-30
3	5174	3260	1	2004-06-30
4	5174	853	2	2004-06-30
5	5174	1549	2	2004-06-30
6	5174	4250	2	2004-06-30
1	5175	729	2	2004-06-29
2	5175	4853	2	2004-06-29
1	5176	389	3	2004-06-14
1	5177	5964	3	2004-06-10
2	5177	9391	1	2004-06-10
3	5177	105	1	2004-06-10
4	5177	2308	1	2004-06-10
5	5177	6199	2	2004-06-10
6	5177	5355	1	2004-06-10
7	5177	252	2	2004-06-10
1	5178	4476	1	2004-06-21
2	5178	877	3	2004-06-21
3	5178	3922	1	2004-06-21
4	5178	9318	2	2004-06-21
5	5178	9468	1	2004-06-21
6	5178	4577	2	2004-06-21
7	5178	9518	1	2004-06-21
1	5179	1559	1	2004-06-05
2	5179	2700	3	2004-06-05
1	5180	2981	2	2004-06-21
2	5180	6722	3	2004-06-21
3	5180	2386	1	2004-06-21
4	5180	495	1	2004-06-21
5	5180	217	2	2004-06-21
6	5180	5839	3	2004-06-21
7	5180	8727	2	2004-06-21
1	5181	3843	1	2004-06-06
2	5181	412	2	2004-06-06
1	5182	9728	2	2004-06-11
2	5182	4195	3	2004-06-11
3	5182	1360	3	2004-06-11
4	5182	2865	3	2004-06-11
5	5182	6487	2	2004-06-11
6	5182	9277	3	2004-06-11
1	5183	9029	1	2004-06-26
2	5183	9657	1	2004-06-26
3	5183	3427	3	2004-06-26
4	5183	2518	3	2004-06-26
1	5184	4900	3	2004-06-05
2	5184	1003	2	2004-06-05
3	5184	3518	2	2004-06-05
4	5184	2560	2	2004-06-05
5	5184	2373	2	2004-06-05
1	5185	5842	3	2004-06-09
2	5185	1728	3	2004-06-09
3	5185	3537	1	2004-06-09
1	5186	2914	2	2004-06-23
1	5187	9196	1	2004-06-25
2	5187	9059	1	2004-06-25
3	5187	6742	1	2004-06-25
4	5187	5396	3	2004-06-25
5	5187	7454	3	2004-06-25
6	5187	4727	1	2004-06-25
7	5187	6628	2	2004-06-25
8	5187	2646	1	2004-06-25
9	5187	4588	2	2004-06-25
1	5188	1318	3	2004-06-30
2	5188	7862	2	2004-06-30
3	5188	1185	2	2004-06-30
4	5188	8565	3	2004-06-30
5	5188	5747	3	2004-06-30
6	5188	516	2	2004-06-30
7	5188	7958	3	2004-06-30
1	5189	1122	1	2004-06-23
2	5189	5248	3	2004-06-23
3	5189	6686	3	2004-06-23
4	5189	218	1	2004-06-23
5	5189	2266	3	2004-06-23
1	5190	4293	2	2004-06-29
1	5191	3878	2	2004-06-15
2	5191	1271	2	2004-06-15
3	5191	1330	3	2004-06-15
4	5191	1650	3	2004-06-15
1	5192	9492	3	2004-06-08
2	5192	1452	2	2004-06-08
3	5192	6689	1	2004-06-08
4	5192	7450	3	2004-06-08
1	5193	7563	1	2004-06-05
2	5193	3447	1	2004-06-05
3	5193	6117	2	2004-06-05
4	5193	6021	3	2004-06-05
5	5193	748	3	2004-06-05
6	5193	4388	1	2004-06-05
7	5193	6521	2	2004-06-05
8	5193	790	3	2004-06-05
1	5194	3134	2	2004-06-13
2	5194	9915	3	2004-06-13
3	5194	5926	3	2004-06-13
4	5194	8776	3	2004-06-13
1	5195	5763	3	2004-06-13
2	5195	4284	1	2004-06-13
1	5196	7596	2	2004-06-12
2	5196	6604	2	2004-06-12
3	5196	2300	3	2004-06-12
4	5196	3218	2	2004-06-12
5	5196	1731	2	2004-06-12
1	5197	4686	2	2004-06-01
1	5198	8584	3	2004-06-23
2	5198	3548	2	2004-06-23
1	5199	8136	3	2004-06-29
2	5199	7694	2	2004-06-29
3	5199	4363	2	2004-06-29
1	5200	3208	2	2004-06-30
2	5200	9089	2	2004-06-30
3	5200	8284	3	2004-06-30
1	5201	6430	3	2004-06-12
2	5201	3023	2	2004-06-12
1	5202	4403	2	2004-06-28
2	5202	1683	1	2004-06-28
3	5202	3686	3	2004-06-28
4	5202	8270	3	2004-06-28
5	5202	3673	3	2004-06-28
6	5202	4711	2	2004-06-28
7	5202	1183	3	2004-06-28
8	5202	8782	1	2004-06-28
1	5203	35	2	2004-06-05
2	5203	6347	2	2004-06-05
3	5203	4505	3	2004-06-05
4	5203	1477	2	2004-06-05
5	5203	5941	1	2004-06-05
1	5204	2881	1	2004-06-07
2	5204	3208	1	2004-06-07
3	5204	8156	3	2004-06-07
4	5204	9267	1	2004-06-07
1	5205	720	1	2004-06-07
1	5206	5567	2	2004-06-25
2	5206	4588	1	2004-06-25
3	5206	3006	2	2004-06-25
4	5206	3704	3	2004-06-25
5	5206	6901	2	2004-06-25
6	5206	9289	1	2004-06-25
7	5206	9684	1	2004-06-25
8	5206	3429	1	2004-06-25
1	5207	4450	1	2004-06-10
2	5207	3034	2	2004-06-10
3	5207	3039	2	2004-06-10
1	5208	9253	3	2004-06-23
2	5208	8355	2	2004-06-23
3	5208	9749	1	2004-06-23
4	5208	9904	2	2004-06-23
5	5208	306	3	2004-06-23
1	5209	1763	2	2004-06-28
2	5209	1880	2	2004-06-28
3	5209	5139	1	2004-06-28
4	5209	7666	3	2004-06-28
5	5209	3666	1	2004-06-28
6	5209	4823	3	2004-06-28
7	5209	4453	1	2004-06-28
8	5209	7834	3	2004-06-28
9	5209	6968	3	2004-06-28
1	5210	6682	1	2004-06-25
2	5210	1441	3	2004-06-25
3	5210	7634	1	2004-06-25
4	5210	6582	3	2004-06-25
5	5210	9733	3	2004-06-25
6	5210	1314	1	2004-06-25
7	5210	3425	2	2004-06-25
8	5210	3264	1	2004-06-25
1	5211	3634	2	2004-06-19
1	5212	8553	1	2004-06-10
1	5213	308	1	2004-06-17
2	5213	9075	3	2004-06-17
1	5214	4001	3	2004-06-10
2	5214	4564	3	2004-06-10
3	5214	3466	3	2004-06-10
1	5215	372	3	2004-06-26
1	5216	3569	3	2004-06-20
2	5216	4399	3	2004-06-20
1	5217	7907	1	2004-06-24
2	5217	6136	1	2004-06-24
3	5217	5790	1	2004-06-24
4	5217	4077	3	2004-06-24
5	5217	8849	3	2004-06-24
6	5217	7215	1	2004-06-24
7	5217	6468	2	2004-06-24
8	5217	1822	1	2004-06-24
1	5218	5680	3	2004-06-19
2	5218	3935	3	2004-06-19
3	5218	7884	3	2004-06-19
1	5219	3967	1	2004-06-25
2	5219	9413	1	2004-06-25
3	5219	2797	2	2004-06-25
4	5219	1939	3	2004-06-25
5	5219	4992	1	2004-06-25
6	5219	5514	1	2004-06-25
7	5219	3103	1	2004-06-25
8	5219	7936	2	2004-06-25
9	5219	3206	2	2004-06-25
1	5220	2294	1	2004-06-22
2	5220	2044	1	2004-06-22
3	5220	8821	1	2004-06-22
1	5221	4259	3	2004-06-18
2	5221	19	3	2004-06-18
3	5221	4157	1	2004-06-18
4	5221	3929	3	2004-06-18
5	5221	2744	3	2004-06-18
6	5221	1354	2	2004-06-18
7	5221	1423	3	2004-06-18
8	5221	770	2	2004-06-18
9	5221	3260	3	2004-06-18
1	5222	300	1	2004-06-23
2	5222	9920	3	2004-06-23
3	5222	2991	2	2004-06-23
4	5222	1707	1	2004-06-23
5	5222	5784	2	2004-06-23
6	5222	1490	2	2004-06-23
7	5222	3021	2	2004-06-23
8	5222	7759	3	2004-06-23
9	5222	4794	1	2004-06-23
1	5223	5437	3	2004-06-20
2	5223	2443	3	2004-06-20
3	5223	5005	3	2004-06-20
4	5223	8509	2	2004-06-20
5	5223	9635	3	2004-06-20
6	5223	8414	3	2004-06-20
7	5223	7929	1	2004-06-20
8	5223	5423	3	2004-06-20
1	5224	7009	3	2004-06-12
2	5224	1074	2	2004-06-12
3	5224	5571	2	2004-06-12
4	5224	5270	1	2004-06-12
5	5224	2015	1	2004-06-12
1	5225	6149	2	2004-06-30
2	5225	2111	2	2004-06-30
1	5226	1299	1	2004-06-29
2	5226	9245	3	2004-06-29
3	5226	1028	1	2004-06-29
4	5226	7928	2	2004-06-29
5	5226	8610	2	2004-06-29
6	5226	5249	3	2004-06-29
7	5226	9703	1	2004-06-29
8	5226	5550	2	2004-06-29
1	5227	5017	2	2004-06-09
2	5227	4777	1	2004-06-09
3	5227	9063	3	2004-06-09
1	5228	6329	3	2004-06-18
2	5228	679	2	2004-06-18
3	5228	6650	1	2004-06-18
4	5228	8755	2	2004-06-18
5	5228	8335	3	2004-06-18
6	5228	9513	2	2004-06-18
7	5228	7047	3	2004-06-18
8	5228	4403	1	2004-06-18
9	5228	4187	3	2004-06-18
1	5229	6100	2	2004-06-01
2	5229	6342	2	2004-06-01
3	5229	1406	1	2004-06-01
4	5229	3650	1	2004-06-01
5	5229	1449	3	2004-06-01
1	5230	3834	2	2004-06-30
2	5230	1193	1	2004-06-30
3	5230	1669	1	2004-06-30
4	5230	5753	3	2004-06-30
5	5230	9920	1	2004-06-30
6	5230	1312	2	2004-06-30
1	5231	6651	1	2004-06-23
2	5231	1601	1	2004-06-23
3	5231	6143	1	2004-06-23
4	5231	5156	3	2004-06-23
5	5231	3043	2	2004-06-23
6	5231	9770	1	2004-06-23
7	5231	8732	2	2004-06-23
1	5232	4735	1	2004-06-29
1	5233	642	1	2004-06-05
2	5233	5547	3	2004-06-05
1	5234	1411	2	2004-06-09
2	5234	2436	3	2004-06-09
3	5234	9669	3	2004-06-09
4	5234	7345	1	2004-06-09
5	5234	4196	3	2004-06-09
6	5234	5718	1	2004-06-09
7	5234	2434	2	2004-06-09
8	5234	5494	1	2004-06-09
9	5234	6156	1	2004-06-09
1	5235	9116	1	2004-06-11
2	5235	4674	2	2004-06-11
3	5235	9335	3	2004-06-11
4	5235	5091	2	2004-06-11
1	5236	4054	1	2004-06-21
2	5236	6936	1	2004-06-21
3	5236	3439	1	2004-06-21
4	5236	8513	3	2004-06-21
5	5236	4060	1	2004-06-21
6	5236	4497	3	2004-06-21
7	5236	3003	1	2004-06-21
8	5236	9780	2	2004-06-21
9	5236	8329	1	2004-06-21
1	5237	2107	1	2004-06-30
2	5237	1846	3	2004-06-30
3	5237	5580	3	2004-06-30
4	5237	3699	2	2004-06-30
1	5238	9151	1	2004-06-25
2	5238	6165	3	2004-06-25
3	5238	9961	1	2004-06-25
4	5238	8608	2	2004-06-25
5	5238	9777	1	2004-06-25
1	5239	49	3	2004-06-16
2	5239	884	1	2004-06-16
3	5239	2046	1	2004-06-16
4	5239	3078	2	2004-06-16
1	5240	5296	1	2004-06-01
2	5240	1638	1	2004-06-01
3	5240	5776	1	2004-06-01
4	5240	3467	1	2004-06-01
1	5241	7885	1	2004-06-26
2	5241	8668	1	2004-06-26
3	5241	1497	2	2004-06-26
4	5241	6434	1	2004-06-26
5	5241	4295	3	2004-06-26
6	5241	3440	2	2004-06-26
7	5241	307	2	2004-06-26
1	5242	4379	1	2004-06-01
2	5242	3618	2	2004-06-01
3	5242	3132	3	2004-06-01
1	5243	25	2	2004-06-21
2	5243	2311	3	2004-06-21
3	5243	5439	1	2004-06-21
4	5243	903	3	2004-06-21
5	5243	7607	3	2004-06-21
1	5244	8242	2	2004-06-26
2	5244	8436	3	2004-06-26
1	5245	4080	2	2004-06-17
2	5245	5849	3	2004-06-17
3	5245	4359	1	2004-06-17
4	5245	3809	2	2004-06-17
5	5245	7905	2	2004-06-17
6	5245	9190	1	2004-06-17
7	5245	1742	2	2004-06-17
8	5245	1193	1	2004-06-17
9	5245	1563	3	2004-06-17
1	5246	1960	3	2004-06-30
2	5246	9594	1	2004-06-30
3	5246	7415	2	2004-06-30
4	5246	4007	3	2004-06-30
5	5246	4879	3	2004-06-30
1	5247	3378	3	2004-06-12
2	5247	3779	1	2004-06-12
3	5247	2940	1	2004-06-12
4	5247	1496	2	2004-06-12
5	5247	7597	1	2004-06-12
6	5247	7326	3	2004-06-12
7	5247	1488	3	2004-06-12
8	5247	9201	1	2004-06-12
1	5248	1557	3	2004-06-06
2	5248	6579	2	2004-06-06
1	5249	2184	3	2004-06-22
1	5250	6843	1	2004-06-28
2	5250	5869	3	2004-06-28
3	5250	5673	2	2004-06-28
1	5251	305	1	2004-06-04
2	5251	4702	1	2004-06-04
3	5251	2984	2	2004-06-04
1	5252	103	1	2004-06-12
1	5253	2697	1	2004-06-06
2	5253	9557	1	2004-06-06
3	5253	4737	2	2004-06-06
4	5253	1740	1	2004-06-06
1	5254	412	3	2004-06-15
2	5254	8279	1	2004-06-15
3	5254	8516	1	2004-06-15
4	5254	2960	1	2004-06-15
5	5254	8810	3	2004-06-15
6	5254	6039	1	2004-06-15
1	5255	9892	3	2004-06-22
2	5255	2902	1	2004-06-22
3	5255	9418	1	2004-06-22
4	5255	3337	2	2004-06-22
5	5255	8858	2	2004-06-22
6	5255	4759	2	2004-06-22
7	5255	2489	3	2004-06-22
8	5255	9360	1	2004-06-22
9	5255	5520	3	2004-06-22
1	5256	5534	3	2004-06-11
2	5256	3312	1	2004-06-11
3	5256	2612	1	2004-06-11
4	5256	7714	3	2004-06-11
5	5256	9310	3	2004-06-11
6	5256	5057	1	2004-06-11
1	5257	8627	2	2004-06-01
2	5257	8605	2	2004-06-01
3	5257	7121	1	2004-06-01
4	5257	2213	2	2004-06-01
1	5258	1767	2	2004-06-12
2	5258	4185	3	2004-06-12
3	5258	4162	3	2004-06-12
4	5258	8872	3	2004-06-12
5	5258	7901	2	2004-06-12
6	5258	4249	3	2004-06-12
7	5258	4190	3	2004-06-12
1	5259	7911	1	2004-06-29
2	5259	7614	2	2004-06-29
3	5259	5790	2	2004-06-29
4	5259	7609	3	2004-06-29
1	5260	9212	3	2004-06-04
2	5260	67	2	2004-06-04
3	5260	4800	2	2004-06-04
4	5260	893	2	2004-06-04
5	5260	1001	3	2004-06-04
1	5261	4555	2	2004-06-01
2	5261	8827	3	2004-06-01
3	5261	9512	3	2004-06-01
4	5261	738	3	2004-06-01
5	5261	3252	2	2004-06-01
1	5262	2463	1	2004-06-06
2	5262	8406	1	2004-06-06
3	5262	7763	3	2004-06-06
1	5263	6234	2	2004-06-16
2	5263	4756	2	2004-06-16
3	5263	8951	1	2004-06-16
4	5263	934	2	2004-06-16
5	5263	6183	3	2004-06-16
6	5263	1837	2	2004-06-16
1	5264	9101	2	2004-06-20
2	5264	609	2	2004-06-20
3	5264	7753	1	2004-06-20
4	5264	3894	2	2004-06-20
5	5264	4745	1	2004-06-20
6	5264	4630	3	2004-06-20
7	5264	4218	3	2004-06-20
8	5264	5775	1	2004-06-20
9	5264	1031	1	2004-06-20
1	5265	3486	3	2004-06-21
2	5265	7634	2	2004-06-21
3	5265	3165	2	2004-06-21
4	5265	7897	2	2004-06-21
5	5265	3880	3	2004-06-21
6	5265	662	2	2004-06-21
7	5265	628	3	2004-06-21
8	5265	7559	2	2004-06-21
1	5266	2117	1	2004-06-14
2	5266	6531	3	2004-06-14
3	5266	846	3	2004-06-14
4	5266	8422	3	2004-06-14
5	5266	7543	3	2004-06-14
6	5266	5659	1	2004-06-14
7	5266	7181	1	2004-06-14
8	5266	6351	1	2004-06-14
9	5266	7423	2	2004-06-14
1	5267	5791	1	2004-06-19
2	5267	5404	2	2004-06-19
3	5267	6394	3	2004-06-19
4	5267	5652	1	2004-06-19
5	5267	9176	3	2004-06-19
6	5267	2965	2	2004-06-19
7	5267	5660	2	2004-06-19
1	5268	3791	3	2004-06-10
1	5269	1317	3	2004-06-06
2	5269	2437	3	2004-06-06
3	5269	9272	2	2004-06-06
4	5269	4635	2	2004-06-06
5	5269	5555	1	2004-06-06
6	5269	8411	1	2004-06-06
7	5269	13	2	2004-06-06
8	5269	4519	3	2004-06-06
1	5270	1294	3	2004-06-06
2	5270	1571	1	2004-06-06
3	5270	8972	2	2004-06-06
4	5270	145	1	2004-06-06
5	5270	6332	1	2004-06-06
6	5270	8999	3	2004-06-06
7	5270	8661	1	2004-06-06
1	5271	2995	1	2004-06-16
2	5271	9965	1	2004-06-16
3	5271	2619	3	2004-06-16
4	5271	5468	3	2004-06-16
5	5271	9165	3	2004-06-16
6	5271	4620	2	2004-06-16
7	5271	4789	2	2004-06-16
8	5271	2221	2	2004-06-16
9	5271	8803	1	2004-06-16
1	5272	9638	1	2004-06-06
2	5272	5700	3	2004-06-06
3	5272	2436	1	2004-06-06
4	5272	6230	3	2004-06-06
5	5272	919	3	2004-06-06
6	5272	8222	1	2004-06-06
7	5272	629	1	2004-06-06
8	5272	860	2	2004-06-06
1	5273	4084	3	2004-06-24
2	5273	8508	2	2004-06-24
3	5273	4543	3	2004-06-24
1	5274	4315	2	2004-06-23
2	5274	501	1	2004-06-23
3	5274	4192	1	2004-06-23
4	5274	1007	1	2004-06-23
5	5274	488	1	2004-06-23
6	5274	9645	3	2004-06-23
7	5274	2808	1	2004-06-23
8	5274	9550	2	2004-06-23
9	5274	6371	3	2004-06-23
1	5275	7949	3	2004-06-12
2	5275	4080	1	2004-06-12
3	5275	5939	1	2004-06-12
4	5275	8753	1	2004-06-12
5	5275	1076	1	2004-06-12
6	5275	8089	1	2004-06-12
7	5275	3081	1	2004-06-12
1	5276	6012	1	2004-06-14
2	5276	3709	3	2004-06-14
3	5276	2620	1	2004-06-14
4	5276	2487	3	2004-06-14
5	5276	783	2	2004-06-14
1	5277	9532	3	2004-06-27
2	5277	9194	2	2004-06-27
3	5277	9609	3	2004-06-27
4	5277	7666	1	2004-06-27
5	5277	1014	2	2004-06-27
6	5277	2261	2	2004-06-27
7	5277	8034	3	2004-06-27
1	5278	3081	2	2004-06-25
2	5278	3013	2	2004-06-25
3	5278	8738	2	2004-06-25
4	5278	4690	3	2004-06-25
1	5279	147	3	2004-06-06
2	5279	3663	3	2004-06-06
3	5279	5427	1	2004-06-06
4	5279	7288	1	2004-06-06
5	5279	3956	3	2004-06-06
6	5279	8846	2	2004-06-06
1	5280	7614	2	2004-06-08
1	5281	6394	3	2004-06-15
2	5281	3280	1	2004-06-15
3	5281	8499	2	2004-06-15
4	5281	4528	3	2004-06-15
5	5281	587	2	2004-06-15
6	5281	8879	2	2004-06-15
7	5281	4016	2	2004-06-15
8	5281	7520	1	2004-06-15
1	5282	7691	1	2004-06-23
2	5282	3120	1	2004-06-23
3	5282	2573	1	2004-06-23
4	5282	5439	3	2004-06-23
5	5282	1428	2	2004-06-23
6	5282	5122	3	2004-06-23
1	5283	3357	2	2004-06-14
2	5283	2078	2	2004-06-14
3	5283	8107	1	2004-06-14
1	5284	3424	1	2004-06-25
2	5284	7186	1	2004-06-25
3	5284	8899	2	2004-06-25
4	5284	5023	1	2004-06-25
5	5284	5555	3	2004-06-25
6	5284	2752	1	2004-06-25
1	5285	2000	1	2004-06-15
1	5286	4336	2	2004-06-26
2	5286	5758	1	2004-06-26
1	5287	9661	3	2004-06-23
2	5287	5436	3	2004-06-23
3	5287	1013	2	2004-06-23
1	5288	3631	3	2004-06-06
2	5288	8270	3	2004-06-06
3	5288	3284	2	2004-06-06
4	5288	8626	2	2004-06-06
5	5288	6269	3	2004-06-06
6	5288	6188	1	2004-06-06
7	5288	8899	1	2004-06-06
1	5289	8607	3	2004-06-22
2	5289	7608	3	2004-06-22
3	5289	5515	1	2004-06-22
4	5289	5113	2	2004-06-22
5	5289	7378	3	2004-06-22
1	5290	2836	1	2004-06-08
2	5290	4761	2	2004-06-08
3	5290	7323	2	2004-06-08
4	5290	1403	2	2004-06-08
5	5290	471	3	2004-06-08
6	5290	4343	3	2004-06-08
1	5291	6484	1	2004-06-25
1	5292	7134	2	2004-06-26
2	5292	648	2	2004-06-26
3	5292	2847	1	2004-06-26
4	5292	8241	3	2004-06-26
1	5293	7196	2	2004-06-29
2	5293	7551	3	2004-06-29
3	5293	253	3	2004-06-29
4	5293	6189	2	2004-06-29
1	5294	5381	1	2004-06-23
2	5294	4048	2	2004-06-23
1	5295	958	3	2004-06-21
2	5295	8470	2	2004-06-21
3	5295	1966	3	2004-06-21
4	5295	762	1	2004-06-21
1	5296	6762	1	2004-06-24
2	5296	3581	3	2004-06-24
3	5296	1106	3	2004-06-24
4	5296	1611	3	2004-06-24
5	5296	4072	3	2004-06-24
1	5297	3439	3	2004-06-30
2	5297	8904	1	2004-06-30
3	5297	1380	3	2004-06-30
4	5297	303	3	2004-06-30
1	5298	3638	2	2004-06-11
2	5298	4527	3	2004-06-11
3	5298	9328	1	2004-06-11
4	5298	2256	1	2004-06-11
1	5299	1856	3	2004-06-25
2	5299	7776	1	2004-06-25
3	5299	6200	3	2004-06-25
4	5299	5724	3	2004-06-25
5	5299	5793	2	2004-06-25
6	5299	1185	3	2004-06-25
7	5299	4489	1	2004-06-25
8	5299	7021	3	2004-06-25
9	5299	3755	2	2004-06-25
1	5300	6564	3	2004-06-08
2	5300	8397	3	2004-06-08
3	5300	159	3	2004-06-08
4	5300	2180	1	2004-06-08
5	5300	6615	2	2004-06-08
6	5300	9583	2	2004-06-08
7	5300	5801	2	2004-06-08
1	5301	6151	2	2004-06-09
2	5301	5726	1	2004-06-09
3	5301	8092	1	2004-06-09
4	5301	8793	1	2004-06-09
5	5301	6325	1	2004-06-09
6	5301	9239	2	2004-06-09
7	5301	8481	2	2004-06-09
8	5301	1500	3	2004-06-09
1	5302	4493	1	2004-06-14
2	5302	835	2	2004-06-14
3	5302	4581	2	2004-06-14
4	5302	9857	3	2004-06-14
5	5302	8159	2	2004-06-14
6	5302	5897	2	2004-06-14
7	5302	1883	1	2004-06-14
1	5303	1822	1	2004-06-15
2	5303	5114	1	2004-06-15
3	5303	4942	2	2004-06-15
4	5303	6862	2	2004-06-15
1	5304	8283	1	2004-06-02
2	5304	4236	3	2004-06-02
3	5304	6666	3	2004-06-02
4	5304	5753	2	2004-06-02
1	5305	8220	2	2004-06-19
2	5305	3677	1	2004-06-19
1	5306	8739	1	2004-06-11
2	5306	6538	2	2004-06-11
3	5306	5615	2	2004-06-11
4	5306	121	2	2004-06-11
5	5306	4882	3	2004-06-11
1	5307	2282	3	2004-06-01
2	5307	3181	3	2004-06-01
3	5307	3997	3	2004-06-01
4	5307	1946	2	2004-06-01
1	5308	3333	1	2004-06-05
2	5308	3116	1	2004-06-05
3	5308	8612	1	2004-06-05
4	5308	2262	2	2004-06-05
5	5308	5534	3	2004-06-05
1	5309	3874	2	2004-06-26
2	5309	6594	2	2004-06-26
3	5309	8453	3	2004-06-26
4	5309	2157	1	2004-06-26
1	5310	1950	1	2004-06-21
2	5310	9021	1	2004-06-21
3	5310	7436	1	2004-06-21
4	5310	4563	1	2004-06-21
5	5310	2594	1	2004-06-21
6	5310	2406	2	2004-06-21
7	5310	8324	3	2004-06-21
8	5310	2730	3	2004-06-21
1	5311	776	3	2004-06-11
2	5311	2150	3	2004-06-11
3	5311	5771	2	2004-06-11
4	5311	862	1	2004-06-11
5	5311	460	1	2004-06-11
6	5311	1535	1	2004-06-11
7	5311	4199	1	2004-06-11
1	5312	2186	2	2004-06-12
2	5312	1573	2	2004-06-12
3	5312	356	3	2004-06-12
4	5312	2532	1	2004-06-12
5	5312	6768	2	2004-06-12
6	5312	9773	3	2004-06-12
7	5312	3592	1	2004-06-12
8	5312	3964	2	2004-06-12
1	5313	2414	1	2004-06-30
1	5314	4503	3	2004-06-08
2	5314	8304	3	2004-06-08
3	5314	5151	1	2004-06-08
4	5314	2912	3	2004-06-08
5	5314	5082	1	2004-06-08
6	5314	6619	3	2004-06-08
7	5314	6352	2	2004-06-08
1	5315	6672	2	2004-06-12
2	5315	3071	2	2004-06-12
3	5315	4151	1	2004-06-12
4	5315	7086	2	2004-06-12
5	5315	3625	3	2004-06-12
6	5315	512	2	2004-06-12
7	5315	6226	2	2004-06-12
1	5316	5019	2	2004-06-10
2	5316	5165	1	2004-06-10
3	5316	8604	1	2004-06-10
4	5316	7712	2	2004-06-10
5	5316	5168	1	2004-06-10
6	5316	1080	2	2004-06-10
7	5316	8778	3	2004-06-10
8	5316	39	1	2004-06-10
1	5317	752	3	2004-06-13
2	5317	842	1	2004-06-13
1	5318	1596	3	2004-06-16
2	5318	6864	2	2004-06-16
3	5318	4041	1	2004-06-16
4	5318	6713	1	2004-06-16
5	5318	3811	2	2004-06-16
6	5318	7600	3	2004-06-16
7	5318	5873	3	2004-06-16
8	5318	4600	2	2004-06-16
1	5319	8827	1	2004-06-20
1	5320	842	2	2004-06-06
2	5320	9821	3	2004-06-06
3	5320	3606	1	2004-06-06
1	5321	2498	2	2004-06-18
2	5321	2508	2	2004-06-18
3	5321	9166	1	2004-06-18
4	5321	5287	2	2004-06-18
5	5321	8786	3	2004-06-18
6	5321	9689	2	2004-06-18
7	5321	4525	2	2004-06-18
8	5321	5844	2	2004-06-18
9	5321	7651	3	2004-06-18
1	5322	2890	1	2004-06-09
2	5322	891	2	2004-06-09
3	5322	1749	3	2004-06-09
4	5322	6965	3	2004-06-09
1	5323	5770	2	2004-06-20
2	5323	9191	1	2004-06-20
3	5323	8725	3	2004-06-20
4	5323	943	3	2004-06-20
5	5323	3191	2	2004-06-20
6	5323	4601	3	2004-06-20
7	5323	8818	1	2004-06-20
8	5323	6792	1	2004-06-20
9	5323	9957	3	2004-06-20
1	5324	9341	3	2004-06-17
2	5324	3121	2	2004-06-17
3	5324	9164	3	2004-06-17
4	5324	5767	2	2004-06-17
5	5324	8781	1	2004-06-17
6	5324	7370	3	2004-06-17
1	5325	4507	3	2004-06-08
2	5325	9003	3	2004-06-08
3	5325	8172	3	2004-06-08
4	5325	1359	2	2004-06-08
1	5326	4160	3	2004-06-29
2	5326	1492	2	2004-06-29
3	5326	9288	2	2004-06-29
4	5326	9806	3	2004-06-29
5	5326	4310	2	2004-06-29
1	5327	1062	3	2004-06-07
2	5327	5598	3	2004-06-07
3	5327	3237	1	2004-06-07
4	5327	6146	1	2004-06-07
5	5327	9212	2	2004-06-07
6	5327	58	1	2004-06-07
7	5327	9280	3	2004-06-07
8	5327	1884	1	2004-06-07
9	5327	4708	2	2004-06-07
1	5328	812	3	2004-06-05
1	5329	8211	1	2004-06-28
2	5329	823	3	2004-06-28
1	5330	6524	1	2004-06-06
2	5330	7204	2	2004-06-06
3	5330	6743	3	2004-06-06
4	5330	6304	2	2004-06-06
5	5330	6885	3	2004-06-06
1	5331	7791	2	2004-06-23
2	5331	9748	3	2004-06-23
3	5331	3123	3	2004-06-23
4	5331	3723	3	2004-06-23
5	5331	252	1	2004-06-23
6	5331	71	1	2004-06-23
7	5331	1207	1	2004-06-23
8	5331	7493	3	2004-06-23
9	5331	6765	2	2004-06-23
1	5332	1229	2	2004-06-30
2	5332	2677	3	2004-06-30
3	5332	4243	1	2004-06-30
4	5332	9706	3	2004-06-30
5	5332	9257	3	2004-06-30
6	5332	2247	3	2004-06-30
1	5333	3412	3	2004-06-19
2	5333	1755	2	2004-06-19
3	5333	9263	1	2004-06-19
4	5333	5282	3	2004-06-19
5	5333	448	1	2004-06-19
6	5333	772	1	2004-06-19
7	5333	6015	1	2004-06-19
8	5333	7016	3	2004-06-19
9	5333	6578	3	2004-06-19
1	5334	9293	3	2004-06-17
2	5334	2559	1	2004-06-17
3	5334	8198	3	2004-06-17
4	5334	6909	2	2004-06-17
5	5334	8479	1	2004-06-17
1	5335	3195	3	2004-06-13
2	5335	342	2	2004-06-13
3	5335	1130	1	2004-06-13
4	5335	4003	3	2004-06-13
1	5336	711	3	2004-06-05
2	5336	9034	1	2004-06-05
3	5336	4805	3	2004-06-05
4	5336	9840	3	2004-06-05
5	5336	9866	3	2004-06-05
6	5336	6021	3	2004-06-05
7	5336	4172	2	2004-06-05
8	5336	7095	3	2004-06-05
1	5337	9979	1	2004-06-15
2	5337	1570	1	2004-06-15
3	5337	3537	2	2004-06-15
4	5337	8251	2	2004-06-15
5	5337	6591	1	2004-06-15
6	5337	3387	3	2004-06-15
7	5337	2380	1	2004-06-15
8	5337	7949	3	2004-06-15
1	5338	5826	1	2004-06-03
1	5339	8494	3	2004-06-23
2	5339	5376	1	2004-06-23
3	5339	7729	2	2004-06-23
4	5339	2999	3	2004-06-23
5	5339	6462	2	2004-06-23
1	5340	7350	2	2004-06-15
2	5340	8765	3	2004-06-15
1	5341	4502	1	2004-06-23
2	5341	8871	1	2004-06-23
3	5341	2029	2	2004-06-23
4	5341	325	3	2004-06-23
5	5341	737	3	2004-06-23
6	5341	6898	2	2004-06-23
7	5341	9393	2	2004-06-23
8	5341	1466	1	2004-06-23
1	5342	2640	1	2004-06-12
2	5342	260	3	2004-06-12
3	5342	5728	3	2004-06-12
4	5342	9719	1	2004-06-12
5	5342	5737	2	2004-06-12
6	5342	1500	1	2004-06-12
7	5342	8091	1	2004-06-12
8	5342	566	1	2004-06-12
1	5343	9708	2	2004-06-20
2	5343	3475	3	2004-06-20
3	5343	8739	2	2004-06-20
4	5343	1492	1	2004-06-20
5	5343	2868	1	2004-06-20
6	5343	1461	2	2004-06-20
7	5343	1052	1	2004-06-20
1	5344	19	2	2004-06-17
2	5344	1846	1	2004-06-17
3	5344	6719	3	2004-06-17
4	5344	1888	3	2004-06-17
5	5344	56	3	2004-06-17
1	5345	1384	3	2004-06-25
2	5345	6982	1	2004-06-25
3	5345	4290	3	2004-06-25
4	5345	2786	3	2004-06-25
5	5345	8892	2	2004-06-25
6	5345	2665	3	2004-06-25
7	5345	5967	3	2004-06-25
8	5345	6722	3	2004-06-25
1	5346	8258	3	2004-06-11
2	5346	5158	1	2004-06-11
3	5346	7192	2	2004-06-11
4	5346	8658	2	2004-06-11
5	5346	2484	2	2004-06-11
1	5347	3989	3	2004-06-10
1	5348	1021	3	2004-06-27
2	5348	7536	3	2004-06-27
3	5348	6156	2	2004-06-27
4	5348	3697	3	2004-06-27
5	5348	996	3	2004-06-27
6	5348	4752	3	2004-06-27
7	5348	6794	3	2004-06-27
1	5349	9350	3	2004-06-29
2	5349	2590	1	2004-06-29
3	5349	1471	2	2004-06-29
4	5349	2823	2	2004-06-29
5	5349	4647	1	2004-06-29
6	5349	2234	3	2004-06-29
7	5349	9117	1	2004-06-29
8	5349	7971	2	2004-06-29
1	5350	3657	1	2004-06-01
2	5350	823	3	2004-06-01
3	5350	1157	3	2004-06-01
4	5350	8317	1	2004-06-01
1	5351	1043	1	2004-06-05
1	5352	7973	1	2004-06-11
2	5352	7892	1	2004-06-11
3	5352	2295	3	2004-06-11
4	5352	3460	1	2004-06-11
5	5352	3660	2	2004-06-11
6	5352	4392	2	2004-06-11
1	5353	6456	3	2004-06-23
2	5353	6075	2	2004-06-23
3	5353	8182	3	2004-06-23
4	5353	8212	3	2004-06-23
5	5353	8625	3	2004-06-23
6	5353	7992	1	2004-06-23
7	5353	1768	2	2004-06-23
8	5353	8537	3	2004-06-23
1	5354	3436	2	2004-06-24
1	5355	1662	2	2004-06-02
2	5355	2982	3	2004-06-02
3	5355	3203	3	2004-06-02
4	5355	5760	3	2004-06-02
5	5355	4211	2	2004-06-02
1	5356	1676	3	2004-06-21
2	5356	7747	2	2004-06-21
3	5356	4390	2	2004-06-21
4	5356	3185	1	2004-06-21
5	5356	2711	1	2004-06-21
6	5356	2649	2	2004-06-21
1	5357	8126	2	2004-06-20
2	5357	8387	1	2004-06-20
3	5357	3035	1	2004-06-20
4	5357	545	3	2004-06-20
1	5358	7177	2	2004-06-03
2	5358	3396	3	2004-06-03
3	5358	2195	1	2004-06-03
4	5358	2296	2	2004-06-03
5	5358	7425	2	2004-06-03
6	5358	8956	1	2004-06-03
7	5358	8612	1	2004-06-03
8	5358	6281	2	2004-06-03
1	5359	4424	3	2004-06-15
2	5359	4029	3	2004-06-15
3	5359	8768	2	2004-06-15
1	5360	7453	2	2004-06-19
2	5360	2457	1	2004-06-19
3	5360	5355	2	2004-06-19
4	5360	1990	3	2004-06-19
5	5360	1236	3	2004-06-19
6	5360	3131	1	2004-06-19
7	5360	9549	1	2004-06-19
8	5360	1797	2	2004-06-19
9	5360	6891	2	2004-06-19
1	5361	2861	2	2004-06-17
2	5361	7233	1	2004-06-17
3	5361	8115	2	2004-06-17
4	5361	1262	3	2004-06-17
5	5361	2472	3	2004-06-17
6	5361	3945	2	2004-06-17
7	5361	9561	3	2004-06-17
8	5361	9581	1	2004-06-17
9	5361	6950	1	2004-06-17
1	5362	1823	1	2004-06-03
1	5363	4395	3	2004-06-20
2	5363	1470	3	2004-06-20
1	5364	2187	1	2004-06-08
1	5365	9587	3	2004-06-25
2	5365	1253	3	2004-06-25
1	5366	8283	1	2004-06-30
1	5367	8817	1	2004-06-05
2	5367	9483	1	2004-06-05
3	5367	2108	1	2004-06-05
4	5367	466	2	2004-06-05
5	5367	9654	3	2004-06-05
6	5367	5130	1	2004-06-05
7	5367	9492	1	2004-06-05
8	5367	6498	3	2004-06-05
1	5368	5252	3	2004-06-16
2	5368	4548	2	2004-06-16
3	5368	7666	1	2004-06-16
4	5368	6229	3	2004-06-16
5	5368	2934	1	2004-06-16
6	5368	6901	1	2004-06-16
1	5369	7335	2	2004-06-10
2	5369	9891	3	2004-06-10
3	5369	4776	2	2004-06-10
4	5369	8829	2	2004-06-10
5	5369	8160	2	2004-06-10
1	5370	9599	2	2004-06-08
2	5370	6115	2	2004-06-08
3	5370	1899	2	2004-06-08
4	5370	6976	3	2004-06-08
5	5370	2892	3	2004-06-08
6	5370	8154	3	2004-06-08
7	5370	1660	1	2004-06-08
8	5370	6175	2	2004-06-08
9	5370	6705	2	2004-06-08
1	5371	1615	3	2004-06-07
2	5371	1090	3	2004-06-07
3	5371	4653	2	2004-06-07
4	5371	3028	2	2004-06-07
5	5371	3086	1	2004-06-07
6	5371	2726	3	2004-06-07
7	5371	6772	2	2004-06-07
1	5372	3656	1	2004-06-09
2	5372	5664	2	2004-06-09
3	5372	2280	1	2004-06-09
4	5372	1937	3	2004-06-09
5	5372	5349	2	2004-06-09
6	5372	5578	2	2004-06-09
1	5373	6968	3	2004-06-03
2	5373	5604	3	2004-06-03
1	5374	7889	3	2004-06-18
2	5374	3238	1	2004-06-18
3	5374	3137	2	2004-06-18
4	5374	6740	3	2004-06-18
5	5374	6893	1	2004-06-18
6	5374	2108	3	2004-06-18
7	5374	4243	2	2004-06-18
8	5374	8156	3	2004-06-18
1	5375	927	1	2004-06-25
2	5375	737	3	2004-06-25
3	5375	437	2	2004-06-25
4	5375	7888	2	2004-06-25
5	5375	5029	1	2004-06-25
6	5375	4940	1	2004-06-25
7	5375	9898	3	2004-06-25
8	5375	3785	1	2004-06-25
1	5376	2929	1	2004-06-13
1	5377	6761	2	2004-06-01
2	5377	2120	1	2004-06-01
3	5377	2848	1	2004-06-01
4	5377	2809	2	2004-06-01
5	5377	939	1	2004-06-01
6	5377	9924	3	2004-06-01
7	5377	9570	2	2004-06-01
8	5377	9334	2	2004-06-01
1	5378	2265	3	2004-06-24
2	5378	2178	1	2004-06-24
1	5379	2276	1	2004-06-24
2	5379	6528	3	2004-06-24
3	5379	4016	3	2004-06-24
4	5379	1235	3	2004-06-24
5	5379	1694	2	2004-06-24
6	5379	447	1	2004-06-24
7	5379	7288	1	2004-06-24
8	5379	1459	3	2004-06-24
1	5380	23	2	2004-06-16
2	5380	4845	1	2004-06-16
3	5380	905	3	2004-06-16
1	5381	6957	2	2004-06-14
2	5381	8412	2	2004-06-14
3	5381	3439	1	2004-06-14
4	5381	2132	2	2004-06-14
5	5381	9290	2	2004-06-14
6	5381	8716	3	2004-06-14
7	5381	6458	2	2004-06-14
8	5381	107	3	2004-06-14
1	5382	8622	3	2004-06-09
2	5382	8279	2	2004-06-09
3	5382	1019	3	2004-06-09
4	5382	488	2	2004-06-09
1	5383	7017	1	2004-06-24
2	5383	8438	1	2004-06-24
3	5383	4644	1	2004-06-24
4	5383	5129	2	2004-06-24
5	5383	4395	2	2004-06-24
1	5384	8769	1	2004-06-12
2	5384	9206	3	2004-06-12
3	5384	6931	3	2004-06-12
4	5384	6209	2	2004-06-12
1	5385	2626	1	2004-06-04
2	5385	4396	2	2004-06-04
1	5386	1868	1	2004-06-23
2	5386	6349	3	2004-06-23
3	5386	7222	1	2004-06-23
4	5386	839	1	2004-06-23
5	5386	1596	1	2004-06-23
6	5386	4666	1	2004-06-23
1	5387	1699	2	2004-06-11
1	5388	4773	2	2004-06-17
2	5388	2308	3	2004-06-17
3	5388	332	3	2004-06-17
4	5388	580	3	2004-06-17
5	5388	5429	1	2004-06-17
6	5388	2266	1	2004-06-17
7	5388	9443	3	2004-06-17
8	5388	2521	1	2004-06-17
9	5388	377	2	2004-06-17
1	5389	8914	1	2004-06-03
2	5389	4675	1	2004-06-03
3	5389	6370	1	2004-06-03
4	5389	3605	3	2004-06-03
1	5390	7545	1	2004-06-01
2	5390	2077	3	2004-06-01
3	5390	858	3	2004-06-01
1	5391	2610	1	2004-06-02
1	5392	8029	1	2004-06-01
2	5392	5617	3	2004-06-01
1	5393	493	1	2004-06-09
2	5393	6734	1	2004-06-09
3	5393	9537	3	2004-06-09
4	5393	3041	3	2004-06-09
5	5393	163	2	2004-06-09
6	5393	5206	1	2004-06-09
7	5393	2622	2	2004-06-09
8	5393	4143	1	2004-06-09
9	5393	5790	3	2004-06-09
1	5394	7347	3	2004-06-12
2	5394	21	1	2004-06-12
3	5394	4709	1	2004-06-12
4	5394	3253	1	2004-06-12
5	5394	1825	2	2004-06-12
6	5394	3423	3	2004-06-12
7	5394	4358	1	2004-06-12
8	5394	6841	3	2004-06-12
9	5394	41	3	2004-06-12
1	5395	1022	1	2004-06-08
2	5395	7040	3	2004-06-08
3	5395	8917	1	2004-06-08
4	5395	2896	3	2004-06-08
5	5395	370	1	2004-06-08
1	5396	3129	2	2004-06-20
2	5396	3391	2	2004-06-20
1	5397	9773	1	2004-06-01
2	5397	1957	3	2004-06-01
3	5397	7355	2	2004-06-01
4	5397	5059	2	2004-06-01
5	5397	9606	2	2004-06-01
1	5398	7392	2	2004-06-23
2	5398	5112	3	2004-06-23
3	5398	6029	1	2004-06-23
4	5398	8152	3	2004-06-23
5	5398	2659	1	2004-06-23
6	5398	5690	2	2004-06-23
1	5399	450	1	2004-06-19
2	5399	99	1	2004-06-19
3	5399	2448	3	2004-06-19
4	5399	6877	3	2004-06-19
5	5399	2830	2	2004-06-19
6	5399	3586	1	2004-06-19
7	5399	3128	2	2004-06-19
8	5399	6828	1	2004-06-19
9	5399	2264	1	2004-06-19
1	5400	7525	2	2004-06-25
2	5400	7712	1	2004-06-25
3	5400	2178	2	2004-06-25
4	5400	9105	2	2004-06-25
5	5400	3693	3	2004-06-25
6	5400	7675	2	2004-06-25
1	5401	7629	2	2004-06-06
2	5401	5319	1	2004-06-06
3	5401	4444	3	2004-06-06
4	5401	7691	1	2004-06-06
5	5401	8965	3	2004-06-06
6	5401	3211	3	2004-06-06
7	5401	8246	3	2004-06-06
8	5401	3676	2	2004-06-06
1	5402	5333	3	2004-06-09
2	5402	25	3	2004-06-09
3	5402	7643	3	2004-06-09
4	5402	2816	3	2004-06-09
5	5402	7822	2	2004-06-09
1	5403	6664	1	2004-06-26
2	5403	2205	2	2004-06-26
3	5403	3848	1	2004-06-26
4	5403	4308	3	2004-06-26
1	5404	8322	2	2004-06-26
2	5404	3477	3	2004-06-26
1	5405	7835	1	2004-06-05
2	5405	9257	1	2004-06-05
1	5406	2527	1	2004-06-08
1	5407	3544	3	2004-06-15
2	5407	8214	3	2004-06-15
3	5407	6323	2	2004-06-15
4	5407	403	1	2004-06-15
5	5407	8717	3	2004-06-15
6	5407	6609	1	2004-06-15
7	5407	6030	3	2004-06-15
1	5408	4461	3	2004-06-04
2	5408	9486	3	2004-06-04
3	5408	6032	2	2004-06-04
4	5408	8181	3	2004-06-04
5	5408	7035	1	2004-06-04
6	5408	7748	1	2004-06-04
7	5408	63	1	2004-06-04
8	5408	1716	3	2004-06-04
1	5409	8100	2	2004-06-28
2	5409	8268	2	2004-06-28
3	5409	5813	2	2004-06-28
4	5409	2849	3	2004-06-28
5	5409	5722	1	2004-06-28
6	5409	5650	1	2004-06-28
7	5409	1500	2	2004-06-28
8	5409	7284	3	2004-06-28
9	5409	9329	2	2004-06-28
1	5410	8814	3	2004-06-19
2	5410	5128	1	2004-06-19
3	5410	6823	2	2004-06-19
4	5410	8567	1	2004-06-19
1	5411	1374	1	2004-06-12
2	5411	6378	2	2004-06-12
1	5412	2282	3	2004-06-24
2	5412	8756	3	2004-06-24
3	5412	5798	3	2004-06-24
4	5412	5029	1	2004-06-24
1	5413	2058	1	2004-06-14
2	5413	3788	3	2004-06-14
3	5413	5118	1	2004-06-14
1	5414	1010	1	2004-06-02
2	5414	7109	3	2004-06-02
3	5414	4614	2	2004-06-02
4	5414	9487	1	2004-06-02
5	5414	8701	1	2004-06-02
6	5414	9647	3	2004-06-02
1	5415	7331	3	2004-06-05
2	5415	9874	1	2004-06-05
3	5415	3245	1	2004-06-05
4	5415	3904	3	2004-06-05
5	5415	811	3	2004-06-05
6	5415	9386	1	2004-06-05
1	5416	8798	2	2004-06-24
2	5416	6348	2	2004-06-24
3	5416	9556	2	2004-06-24
4	5416	4791	3	2004-06-24
5	5416	7603	2	2004-06-24
6	5416	5713	3	2004-06-24
7	5416	9883	1	2004-06-24
8	5416	5298	3	2004-06-24
9	5416	1238	2	2004-06-24
1	5417	1514	3	2004-06-01
2	5417	3191	1	2004-06-01
3	5417	9329	1	2004-06-01
4	5417	9305	3	2004-06-01
1	5418	1512	1	2004-06-01
2	5418	2283	2	2004-06-01
3	5418	8982	3	2004-06-01
4	5418	741	2	2004-06-01
5	5418	8821	1	2004-06-01
6	5418	5946	2	2004-06-01
1	5419	1665	2	2004-06-24
2	5419	2271	1	2004-06-24
3	5419	4305	2	2004-06-24
4	5419	4078	2	2004-06-24
5	5419	6602	2	2004-06-24
6	5419	329	3	2004-06-24
7	5419	1483	1	2004-06-24
8	5419	3151	1	2004-06-24
1	5420	5318	1	2004-06-07
2	5420	5899	2	2004-06-07
1	5421	9027	3	2004-06-02
2	5421	6596	1	2004-06-02
3	5421	3939	3	2004-06-02
4	5421	3870	3	2004-06-02
5	5421	4327	3	2004-06-02
6	5421	1878	1	2004-06-02
7	5421	1329	1	2004-06-02
8	5421	7631	1	2004-06-02
1	5422	6215	2	2004-06-12
2	5422	7134	1	2004-06-12
3	5422	5140	1	2004-06-12
4	5422	5671	2	2004-06-12
5	5422	4876	2	2004-06-12
6	5422	4293	2	2004-06-12
1	5423	9756	3	2004-06-05
2	5423	3656	2	2004-06-05
3	5423	6409	2	2004-06-05
4	5423	5011	3	2004-06-05
5	5423	7739	1	2004-06-05
1	5424	7372	3	2004-06-02
2	5424	1457	2	2004-06-02
3	5424	1169	2	2004-06-02
4	5424	7537	3	2004-06-02
5	5424	2394	1	2004-06-02
6	5424	767	3	2004-06-02
1	5425	7652	3	2004-06-19
1	5426	6840	2	2004-06-29
2	5426	3516	2	2004-06-29
3	5426	9065	2	2004-06-29
4	5426	6021	1	2004-06-29
5	5426	418	2	2004-06-29
6	5426	2125	1	2004-06-29
1	5427	133	1	2004-06-24
2	5427	7847	1	2004-06-24
3	5427	7550	2	2004-06-24
4	5427	3138	2	2004-06-24
5	5427	5068	1	2004-06-24
1	5428	216	3	2004-06-08
2	5428	292	2	2004-06-08
3	5428	3514	3	2004-06-08
4	5428	7795	3	2004-06-08
1	5429	86	1	2004-06-06
2	5429	7262	3	2004-06-06
3	5429	6258	3	2004-06-06
4	5429	9417	2	2004-06-06
1	5430	2091	1	2004-06-25
2	5430	2220	2	2004-06-25
1	5431	3252	3	2004-06-24
2	5431	1715	3	2004-06-24
3	5431	8063	3	2004-06-24
4	5431	6300	3	2004-06-24
5	5431	7721	3	2004-06-24
6	5431	3875	3	2004-06-24
7	5431	49	1	2004-06-24
8	5431	6361	2	2004-06-24
1	5432	2744	3	2004-06-26
2	5432	8252	2	2004-06-26
3	5432	2005	1	2004-06-26
4	5432	9381	3	2004-06-26
5	5432	4786	3	2004-06-26
6	5432	7758	3	2004-06-26
7	5432	6501	3	2004-06-26
1	5433	4471	3	2004-06-15
1	5434	9481	1	2004-06-01
1	5435	4832	3	2004-06-21
2	5435	5762	1	2004-06-21
3	5435	4222	3	2004-06-21
4	5435	3554	2	2004-06-21
5	5435	7540	3	2004-06-21
6	5435	1397	2	2004-06-21
7	5435	6376	3	2004-06-21
1	5436	2279	3	2004-06-15
2	5436	449	1	2004-06-15
3	5436	5277	2	2004-06-15
4	5436	2980	2	2004-06-15
1	5437	6749	3	2004-06-18
2	5437	1853	1	2004-06-18
3	5437	681	2	2004-06-18
1	5438	2573	1	2004-06-01
2	5438	3113	3	2004-06-01
3	5438	8970	3	2004-06-01
4	5438	127	1	2004-06-01
5	5438	1629	1	2004-06-01
6	5438	8362	1	2004-06-01
7	5438	5009	2	2004-06-01
8	5438	7032	3	2004-06-01
1	5439	5319	2	2004-06-26
2	5439	8759	3	2004-06-26
1	5440	3673	1	2004-06-21
2	5440	5001	2	2004-06-21
3	5440	3993	3	2004-06-21
4	5440	5194	1	2004-06-21
5	5440	5994	2	2004-06-21
6	5440	4393	3	2004-06-21
7	5440	7725	1	2004-06-21
1	5441	722	2	2004-06-30
2	5441	9584	3	2004-06-30
3	5441	5948	2	2004-06-30
4	5441	2765	2	2004-06-30
5	5441	2072	3	2004-06-30
6	5441	4146	2	2004-06-30
7	5441	6856	3	2004-06-30
1	5442	9969	3	2004-06-25
2	5442	5193	2	2004-06-25
3	5442	4578	3	2004-06-25
1	5443	5036	3	2004-06-11
2	5443	15	2	2004-06-11
3	5443	3521	3	2004-06-11
1	5444	4175	2	2004-06-13
2	5444	6562	3	2004-06-13
3	5444	1888	2	2004-06-13
4	5444	6138	1	2004-06-13
5	5444	5273	1	2004-06-13
6	5444	2356	2	2004-06-13
7	5444	9459	3	2004-06-13
1	5445	6338	3	2004-06-04
2	5445	8074	1	2004-06-04
3	5445	8208	3	2004-06-04
4	5445	7130	1	2004-06-04
5	5445	7687	1	2004-06-04
1	5446	8756	2	2004-06-04
2	5446	3690	1	2004-06-04
3	5446	8124	3	2004-06-04
4	5446	767	2	2004-06-04
5	5446	28	1	2004-06-04
1	5447	3522	3	2004-06-26
2	5447	4634	3	2004-06-26
3	5447	7278	1	2004-06-26
4	5447	1234	2	2004-06-26
5	5447	796	3	2004-06-26
6	5447	7214	3	2004-06-26
7	5447	9619	3	2004-06-26
8	5447	667	3	2004-06-26
9	5447	3780	3	2004-06-26
1	5448	7296	1	2004-06-08
1	5449	6810	2	2004-06-12
2	5449	2473	1	2004-06-12
3	5449	2426	3	2004-06-12
1	5450	5189	1	2004-06-01
2	5450	9788	1	2004-06-01
1	5451	7170	2	2004-06-28
2	5451	9177	3	2004-06-28
3	5451	2059	3	2004-06-28
4	5451	234	3	2004-06-28
5	5451	71	2	2004-06-28
6	5451	6678	2	2004-06-28
7	5451	6855	2	2004-06-28
8	5451	8645	3	2004-06-28
9	5451	3820	1	2004-06-28
1	5452	5436	2	2004-06-20
2	5452	6854	2	2004-06-20
3	5452	8365	2	2004-06-20
4	5452	4630	3	2004-06-20
5	5452	5699	1	2004-06-20
6	5452	3766	2	2004-06-20
1	5453	5179	2	2004-06-05
2	5453	5896	1	2004-06-05
1	5454	2077	3	2004-06-25
2	5454	7925	3	2004-06-25
3	5454	3176	3	2004-06-25
4	5454	4755	3	2004-06-25
5	5454	4662	1	2004-06-25
6	5454	3835	1	2004-06-25
7	5454	7552	3	2004-06-25
1	5455	8126	1	2004-06-07
2	5455	1792	1	2004-06-07
3	5455	3371	3	2004-06-07
4	5455	6427	3	2004-06-07
5	5455	8828	2	2004-06-07
6	5455	2017	2	2004-06-07
1	5456	2603	2	2004-06-05
2	5456	8113	3	2004-06-05
3	5456	5122	1	2004-06-05
4	5456	8966	3	2004-06-05
5	5456	5800	2	2004-06-05
6	5456	7419	3	2004-06-05
7	5456	9767	3	2004-06-05
8	5456	3969	3	2004-06-05
9	5456	9380	2	2004-06-05
1	5457	2017	1	2004-06-01
2	5457	1196	2	2004-06-01
3	5457	5730	1	2004-06-01
4	5457	8126	3	2004-06-01
5	5457	2100	1	2004-06-01
6	5457	5577	1	2004-06-01
1	5458	9654	3	2004-06-25
2	5458	3568	3	2004-06-25
3	5458	6787	2	2004-06-25
4	5458	4753	1	2004-06-25
5	5458	1227	2	2004-06-25
6	5458	6515	1	2004-06-25
7	5458	6882	3	2004-06-25
1	5459	2931	2	2004-06-24
2	5459	1800	1	2004-06-24
3	5459	5598	2	2004-06-24
4	5459	1784	1	2004-06-24
5	5459	4112	3	2004-06-24
6	5459	1872	3	2004-06-24
7	5459	6921	1	2004-06-24
8	5459	5885	1	2004-06-24
9	5459	8598	1	2004-06-24
1	5460	7483	3	2004-06-12
2	5460	6409	2	2004-06-12
3	5460	9187	2	2004-06-12
4	5460	3262	3	2004-06-12
5	5460	3443	2	2004-06-12
1	5461	9142	3	2004-06-20
2	5461	3293	1	2004-06-20
1	5462	6690	2	2004-06-27
2	5462	6309	2	2004-06-27
3	5462	8907	1	2004-06-27
4	5462	8638	1	2004-06-27
5	5462	5181	2	2004-06-27
6	5462	2274	1	2004-06-27
1	5463	1449	3	2004-06-02
2	5463	9937	3	2004-06-02
3	5463	4602	3	2004-06-02
4	5463	89	2	2004-06-02
1	5464	8545	3	2004-06-19
2	5464	937	2	2004-06-19
3	5464	3583	3	2004-06-19
4	5464	522	1	2004-06-19
5	5464	7377	3	2004-06-19
1	5465	4147	2	2004-06-15
2	5465	8554	1	2004-06-15
3	5465	9508	1	2004-06-15
4	5465	9424	3	2004-06-15
5	5465	7971	2	2004-06-15
6	5465	6629	3	2004-06-15
7	5465	7768	1	2004-06-15
1	5466	2110	3	2004-06-05
2	5466	5219	2	2004-06-05
3	5466	6142	2	2004-06-05
4	5466	8181	2	2004-06-05
5	5466	4900	1	2004-06-05
6	5466	6075	1	2004-06-05
7	5466	96	1	2004-06-05
8	5466	5941	3	2004-06-05
9	5466	286	2	2004-06-05
1	5467	3735	1	2004-06-26
2	5467	4680	1	2004-06-26
3	5467	4364	2	2004-06-26
4	5467	6266	1	2004-06-26
5	5467	6103	3	2004-06-26
6	5467	1219	1	2004-06-26
1	5468	878	1	2004-06-13
2	5468	5250	3	2004-06-13
3	5468	2139	2	2004-06-13
1	5469	3527	1	2004-06-22
2	5469	7170	3	2004-06-22
3	5469	9264	1	2004-06-22
4	5469	9939	2	2004-06-22
5	5469	2407	2	2004-06-22
6	5469	62	3	2004-06-22
7	5469	6624	2	2004-06-22
1	5470	5203	2	2004-06-22
2	5470	3364	2	2004-06-22
1	5471	3958	1	2004-06-20
2	5471	6726	3	2004-06-20
3	5471	7667	1	2004-06-20
4	5471	595	2	2004-06-20
5	5471	8671	3	2004-06-20
6	5471	5741	3	2004-06-20
7	5471	3801	3	2004-06-20
8	5471	2910	2	2004-06-20
1	5472	7376	3	2004-06-21
2	5472	4984	1	2004-06-21
3	5472	2060	3	2004-06-21
4	5472	8659	3	2004-06-21
1	5473	1897	2	2004-06-21
1	5474	4399	1	2004-06-27
2	5474	9322	1	2004-06-27
3	5474	1470	1	2004-06-27
4	5474	8286	2	2004-06-27
5	5474	6985	2	2004-06-27
6	5474	3913	3	2004-06-27
7	5474	8973	1	2004-06-27
8	5474	4526	2	2004-06-27
9	5474	3867	2	2004-06-27
1	5475	4216	1	2004-06-07
2	5475	181	2	2004-06-07
3	5475	6304	3	2004-06-07
4	5475	5675	1	2004-06-07
5	5475	8514	1	2004-06-07
6	5475	3355	3	2004-06-07
7	5475	211	2	2004-06-07
8	5475	957	3	2004-06-07
9	5475	9204	3	2004-06-07
1	5476	4405	3	2004-06-11
2	5476	6528	3	2004-06-11
3	5476	6065	3	2004-06-11
1	5477	3583	3	2004-06-03
2	5477	1124	3	2004-06-03
3	5477	7325	3	2004-06-03
4	5477	381	2	2004-06-03
5	5477	6870	2	2004-06-03
1	5478	5577	3	2004-06-12
2	5478	2571	3	2004-06-12
3	5478	879	3	2004-06-12
4	5478	1750	2	2004-06-12
5	5478	7005	3	2004-06-12
1	5479	4286	2	2004-06-11
2	5479	9364	3	2004-06-11
3	5479	3475	1	2004-06-11
4	5479	7755	1	2004-06-11
1	5480	1870	1	2004-06-22
2	5480	1235	1	2004-06-22
3	5480	4939	3	2004-06-22
4	5480	8192	3	2004-06-22
1	5481	4354	1	2004-06-18
2	5481	6016	3	2004-06-18
3	5481	5108	1	2004-06-18
4	5481	2261	3	2004-06-18
5	5481	8324	1	2004-06-18
6	5481	7263	1	2004-06-18
7	5481	2110	2	2004-06-18
1	5482	3549	2	2004-06-08
2	5482	9543	2	2004-06-08
3	5482	5449	2	2004-06-08
4	5482	1595	2	2004-06-08
5	5482	1990	3	2004-06-08
6	5482	2711	3	2004-06-08
7	5482	5321	3	2004-06-08
8	5482	9063	1	2004-06-08
9	5482	4972	2	2004-06-08
1	5483	8856	1	2004-06-14
2	5483	4581	1	2004-06-14
3	5483	5843	3	2004-06-14
1	5484	4015	2	2004-06-02
2	5484	8691	3	2004-06-02
3	5484	434	1	2004-06-02
4	5484	3104	1	2004-06-02
1	5485	2877	3	2004-06-24
2	5485	4525	3	2004-06-24
3	5485	2682	3	2004-06-24
1	5486	7072	2	2004-06-16
2	5486	4902	1	2004-06-16
3	5486	3524	2	2004-06-16
4	5486	1909	3	2004-06-16
1	5487	5386	2	2004-06-28
2	5487	8145	3	2004-06-28
3	5487	8744	2	2004-06-28
4	5487	4303	3	2004-06-28
5	5487	9202	3	2004-06-28
6	5487	6702	2	2004-06-28
7	5487	5029	3	2004-06-28
8	5487	2710	1	2004-06-28
1	5488	821	3	2004-06-17
2	5488	5616	2	2004-06-17
3	5488	4209	3	2004-06-17
1	5489	1237	3	2004-06-13
1	5490	5395	1	2004-06-20
2	5490	3420	2	2004-06-20
3	5490	8803	1	2004-06-20
4	5490	8322	2	2004-06-20
5	5490	9505	1	2004-06-20
1	5491	7834	2	2004-06-12
2	5491	6932	2	2004-06-12
3	5491	670	1	2004-06-12
4	5491	973	2	2004-06-12
5	5491	4517	2	2004-06-12
6	5491	5113	2	2004-06-12
7	5491	3250	1	2004-06-12
8	5491	5135	1	2004-06-12
1	5492	5125	1	2004-06-21
1	5493	4477	3	2004-06-02
2	5493	5003	3	2004-06-02
3	5493	6749	1	2004-06-02
4	5493	6308	2	2004-06-02
5	5493	6286	3	2004-06-02
6	5493	4820	3	2004-06-02
7	5493	1925	3	2004-06-02
8	5493	1676	3	2004-06-02
9	5493	5090	2	2004-06-02
1	5494	754	3	2004-06-26
2	5494	5702	2	2004-06-26
3	5494	8681	2	2004-06-26
4	5494	9324	2	2004-06-26
5	5494	5937	2	2004-06-26
1	5495	3776	1	2004-06-07
2	5495	2697	1	2004-06-07
3	5495	7066	3	2004-06-07
4	5495	7320	3	2004-06-07
5	5495	6852	3	2004-06-07
6	5495	6028	1	2004-06-07
7	5495	3920	2	2004-06-07
8	5495	2165	3	2004-06-07
9	5495	120	1	2004-06-07
1	5496	1889	3	2004-06-22
2	5496	9286	3	2004-06-22
3	5496	1921	1	2004-06-22
4	5496	8764	2	2004-06-22
5	5496	572	1	2004-06-22
6	5496	5790	1	2004-06-22
1	5497	1846	3	2004-06-08
2	5497	8915	3	2004-06-08
3	5497	9577	1	2004-06-08
4	5497	2535	1	2004-06-08
5	5497	2247	1	2004-06-08
6	5497	4660	3	2004-06-08
7	5497	8475	2	2004-06-08
8	5497	5127	1	2004-06-08
9	5497	1576	2	2004-06-08
1	5498	9198	2	2004-06-25
2	5498	9491	2	2004-06-25
3	5498	9805	1	2004-06-25
4	5498	7843	1	2004-06-25
5	5498	2013	3	2004-06-25
6	5498	8224	1	2004-06-25
7	5498	7561	3	2004-06-25
1	5499	2749	2	2004-06-12
2	5499	5354	1	2004-06-12
3	5499	7656	1	2004-06-12
4	5499	1586	3	2004-06-12
5	5499	4891	3	2004-06-12
6	5499	2727	1	2004-06-12
1	5500	6911	3	2004-06-21
2	5500	8308	2	2004-06-21
3	5500	7785	1	2004-06-21
4	5500	4441	2	2004-06-21
5	5500	1247	1	2004-06-21
6	5500	3807	2	2004-06-21
1	5501	7547	2	2004-06-07
2	5501	6067	2	2004-06-07
3	5501	6848	3	2004-06-07
4	5501	4433	1	2004-06-07
5	5501	7426	3	2004-06-07
1	5502	365	2	2004-06-08
2	5502	7183	3	2004-06-08
3	5502	746	2	2004-06-08
4	5502	8992	2	2004-06-08
5	5502	975	1	2004-06-08
6	5502	7188	2	2004-06-08
7	5502	5245	3	2004-06-08
8	5502	8129	2	2004-06-08
9	5502	4128	2	2004-06-08
1	5503	7847	2	2004-06-08
2	5503	1212	2	2004-06-08
3	5503	2470	2	2004-06-08
4	5503	9422	1	2004-06-08
5	5503	3793	3	2004-06-08
6	5503	7546	1	2004-06-08
7	5503	8459	3	2004-06-08
8	5503	5943	3	2004-06-08
9	5503	3478	3	2004-06-08
1	5504	9949	3	2004-06-24
2	5504	9191	2	2004-06-24
3	5504	5503	1	2004-06-24
1	5505	1691	1	2004-06-13
2	5505	7389	2	2004-06-13
1	5506	6597	1	2004-06-19
1	5507	2505	2	2004-06-04
2	5507	3933	1	2004-06-04
3	5507	5691	2	2004-06-04
4	5507	3124	2	2004-06-04
5	5507	5458	1	2004-06-04
6	5507	9715	1	2004-06-04
7	5507	4130	2	2004-06-04
1	5508	7921	2	2004-06-23
2	5508	3190	2	2004-06-23
3	5508	300	3	2004-06-23
4	5508	4326	3	2004-06-23
5	5508	2160	2	2004-06-23
6	5508	1953	2	2004-06-23
7	5508	2415	2	2004-06-23
8	5508	8734	2	2004-06-23
9	5508	4649	2	2004-06-23
1	5509	86	3	2004-06-06
2	5509	8395	2	2004-06-06
3	5509	3761	2	2004-06-06
4	5509	9635	3	2004-06-06
5	5509	4764	3	2004-06-06
6	5509	3351	3	2004-06-06
7	5509	1782	2	2004-06-06
1	5510	1506	1	2004-06-21
2	5510	2722	2	2004-06-21
3	5510	6957	1	2004-06-21
4	5510	268	1	2004-06-21
5	5510	5879	1	2004-06-21
6	5510	9379	2	2004-06-21
7	5510	9681	3	2004-06-21
8	5510	5719	3	2004-06-21
9	5510	3680	3	2004-06-21
1	5511	870	1	2004-06-12
2	5511	6527	1	2004-06-12
3	5511	6343	2	2004-06-12
4	5511	8759	3	2004-06-12
5	5511	2394	1	2004-06-12
6	5511	9390	2	2004-06-12
7	5511	4185	2	2004-06-12
8	5511	6570	2	2004-06-12
1	5512	8391	2	2004-06-24
2	5512	6795	2	2004-06-24
3	5512	4454	1	2004-06-24
4	5512	3588	3	2004-06-24
5	5512	3789	1	2004-06-24
6	5512	6837	2	2004-06-24
7	5512	5620	2	2004-06-24
1	5513	8852	3	2004-06-22
2	5513	6334	3	2004-06-22
3	5513	4252	1	2004-06-22
4	5513	4589	1	2004-06-22
5	5513	4970	1	2004-06-22
6	5513	3270	1	2004-06-22
1	5514	5769	1	2004-06-30
2	5514	7141	3	2004-06-30
3	5514	762	1	2004-06-30
4	5514	2284	3	2004-06-30
5	5514	5588	3	2004-06-30
6	5514	961	1	2004-06-30
1	5515	6841	2	2004-06-30
2	5515	6958	1	2004-06-30
3	5515	5818	1	2004-06-30
4	5515	1914	1	2004-06-30
5	5515	4087	2	2004-06-30
6	5515	2455	2	2004-06-30
7	5515	6843	1	2004-06-30
8	5515	624	1	2004-06-30
1	5516	8693	2	2004-06-09
2	5516	1359	2	2004-06-09
3	5516	2153	1	2004-06-09
4	5516	7179	1	2004-06-09
1	5517	1446	3	2004-06-01
2	5517	7955	3	2004-06-01
3	5517	9238	3	2004-06-01
4	5517	8050	1	2004-06-01
5	5517	5051	1	2004-06-01
6	5517	7283	1	2004-06-01
7	5517	1003	3	2004-06-01
1	5518	7761	2	2004-06-14
2	5518	721	3	2004-06-14
3	5518	8643	1	2004-06-14
4	5518	1438	2	2004-06-14
5	5518	4891	1	2004-06-14
6	5518	1967	2	2004-06-14
1	5519	674	1	2004-06-25
2	5519	6147	3	2004-06-25
3	5519	5879	1	2004-06-25
4	5519	9227	1	2004-06-25
5	5519	3091	1	2004-06-25
6	5519	1067	3	2004-06-25
1	5520	1099	2	2004-06-13
2	5520	1110	3	2004-06-13
1	5521	4008	3	2004-06-23
2	5521	8175	1	2004-06-23
3	5521	940	1	2004-06-23
1	5522	337	3	2004-06-26
2	5522	5953	3	2004-06-26
3	5522	3085	3	2004-06-26
4	5522	9793	2	2004-06-26
5	5522	6638	2	2004-06-26
1	5523	5488	3	2004-06-03
2	5523	1728	1	2004-06-03
1	5524	4819	2	2004-06-30
2	5524	6007	2	2004-06-30
3	5524	5362	2	2004-06-30
4	5524	7372	3	2004-06-30
1	5525	7272	1	2004-06-29
2	5525	4366	3	2004-06-29
3	5525	6566	1	2004-06-29
4	5525	1088	3	2004-06-29
5	5525	1705	3	2004-06-29
1	5526	340	2	2004-06-29
2	5526	8458	2	2004-06-29
1	5527	9035	2	2004-06-23
2	5527	8189	2	2004-06-23
3	5527	4675	3	2004-06-23
4	5527	4116	2	2004-06-23
1	5528	8452	1	2004-06-09
2	5528	8250	3	2004-06-09
3	5528	437	3	2004-06-09
4	5528	6640	3	2004-06-09
5	5528	7148	1	2004-06-09
6	5528	1044	3	2004-06-09
7	5528	4753	3	2004-06-09
1	5529	5893	1	2004-06-11
2	5529	8697	2	2004-06-11
3	5529	8220	2	2004-06-11
4	5529	1641	1	2004-06-11
1	5530	1770	1	2004-06-23
2	5530	6776	1	2004-06-23
3	5530	1713	3	2004-06-23
4	5530	9974	3	2004-06-23
1	5531	4608	2	2004-06-22
2	5531	7635	3	2004-06-22
3	5531	6286	1	2004-06-22
4	5531	1559	1	2004-06-22
5	5531	2226	1	2004-06-22
6	5531	6260	1	2004-06-22
7	5531	3626	3	2004-06-22
8	5531	2779	1	2004-06-22
1	5532	8674	1	2004-06-08
2	5532	4211	1	2004-06-08
3	5532	8781	2	2004-06-08
4	5532	8739	2	2004-06-08
1	5533	1919	1	2004-06-04
2	5533	4044	3	2004-06-04
3	5533	2051	2	2004-06-04
4	5533	382	2	2004-06-04
5	5533	5858	2	2004-06-04
6	5533	4720	3	2004-06-04
1	5534	3999	2	2004-06-14
2	5534	1154	1	2004-06-14
3	5534	6843	2	2004-06-14
4	5534	3059	2	2004-06-14
5	5534	9548	1	2004-06-14
6	5534	1493	1	2004-06-14
7	5534	9749	2	2004-06-14
1	5535	9871	3	2004-06-21
1	5536	6894	3	2004-06-20
2	5536	1751	1	2004-06-20
3	5536	5678	1	2004-06-20
1	5537	2349	2	2004-06-26
2	5537	4915	2	2004-06-26
3	5537	9973	2	2004-06-26
4	5537	7204	1	2004-06-26
5	5537	5315	3	2004-06-26
6	5537	6961	1	2004-06-26
7	5537	8620	2	2004-06-26
8	5537	2889	3	2004-06-26
9	5537	3279	3	2004-06-26
1	5538	4919	1	2004-06-27
2	5538	7071	1	2004-06-27
3	5538	5551	2	2004-06-27
4	5538	273	1	2004-06-27
5	5538	5018	1	2004-06-27
6	5538	7408	3	2004-06-27
1	5539	8845	3	2004-06-25
2	5539	2185	2	2004-06-25
3	5539	1788	1	2004-06-25
4	5539	9900	2	2004-06-25
5	5539	9294	1	2004-06-25
1	5540	3672	2	2004-06-12
2	5540	8860	1	2004-06-12
3	5540	5431	2	2004-06-12
4	5540	6210	2	2004-06-12
5	5540	7469	1	2004-06-12
1	5541	2256	2	2004-06-25
2	5541	1584	1	2004-06-25
3	5541	5262	2	2004-06-25
4	5541	6906	3	2004-06-25
5	5541	4572	3	2004-06-25
6	5541	1726	2	2004-06-25
1	5542	1243	2	2004-06-30
2	5542	4736	1	2004-06-30
3	5542	6316	1	2004-06-30
4	5542	4513	1	2004-06-30
5	5542	5870	1	2004-06-30
6	5542	3752	2	2004-06-30
7	5542	6858	2	2004-06-30
8	5542	546	3	2004-06-30
9	5542	465	1	2004-06-30
1	5543	2775	1	2004-06-01
2	5543	3926	2	2004-06-01
3	5543	4335	2	2004-06-01
4	5543	200	2	2004-06-01
5	5543	3810	1	2004-06-01
6	5543	1809	3	2004-06-01
7	5543	1544	3	2004-06-01
1	5544	8039	2	2004-06-27
2	5544	8777	2	2004-06-27
3	5544	9312	3	2004-06-27
4	5544	4011	3	2004-06-27
5	5544	1452	2	2004-06-27
1	5545	7819	2	2004-06-17
2	5545	2774	1	2004-06-17
3	5545	9179	1	2004-06-17
4	5545	8388	1	2004-06-17
5	5545	4415	1	2004-06-17
6	5545	1534	2	2004-06-17
7	5545	8320	1	2004-06-17
8	5545	2016	3	2004-06-17
1	5546	4951	1	2004-06-15
2	5546	2927	3	2004-06-15
3	5546	2455	2	2004-06-15
4	5546	3185	3	2004-06-15
1	5547	9799	3	2004-06-06
2	5547	1698	3	2004-06-06
3	5547	1978	1	2004-06-06
4	5547	1966	2	2004-06-06
5	5547	280	2	2004-06-06
6	5547	2351	3	2004-06-06
7	5547	3746	2	2004-06-06
8	5547	7567	3	2004-06-06
9	5547	4420	1	2004-06-06
1	5548	8331	2	2004-06-07
2	5548	9482	1	2004-06-07
3	5548	4025	1	2004-06-07
4	5548	6044	1	2004-06-07
5	5548	754	2	2004-06-07
1	5549	2535	3	2004-06-28
2	5549	7629	1	2004-06-28
1	5550	4346	3	2004-06-01
2	5550	2601	3	2004-06-01
3	5550	9917	2	2004-06-01
4	5550	8136	2	2004-06-01
1	5551	7981	2	2004-06-30
2	5551	573	2	2004-06-30
3	5551	3880	1	2004-06-30
4	5551	9867	1	2004-06-30
5	5551	3777	2	2004-06-30
6	5551	4375	2	2004-06-30
7	5551	1469	1	2004-06-30
8	5551	9126	1	2004-06-30
9	5551	1983	1	2004-06-30
1	5552	5094	3	2004-06-18
2	5552	3159	1	2004-06-18
3	5552	2968	1	2004-06-18
4	5552	9694	1	2004-06-18
5	5552	2405	3	2004-06-18
6	5552	6192	1	2004-06-18
7	5552	1699	1	2004-06-18
8	5552	4303	1	2004-06-18
1	5553	4390	3	2004-06-10
2	5553	9588	2	2004-06-10
3	5553	9470	1	2004-06-10
4	5553	4056	2	2004-06-10
5	5553	7898	2	2004-06-10
6	5553	3630	1	2004-06-10
7	5553	3013	3	2004-06-10
1	5554	8547	1	2004-06-19
2	5554	3588	2	2004-06-19
3	5554	5211	2	2004-06-19
4	5554	4811	3	2004-06-19
5	5554	6851	3	2004-06-19
6	5554	7593	1	2004-06-19
1	5555	5498	1	2004-06-17
2	5555	6763	3	2004-06-17
3	5555	5537	2	2004-06-17
4	5555	3129	3	2004-06-17
5	5555	7652	2	2004-06-17
1	5556	9784	1	2004-06-18
2	5556	8016	2	2004-06-18
3	5556	5407	1	2004-06-18
4	5556	8657	1	2004-06-18
5	5556	2740	2	2004-06-18
6	5556	8238	1	2004-06-18
1	5557	9036	3	2004-06-26
2	5557	9713	2	2004-06-26
3	5557	7366	2	2004-06-26
4	5557	460	1	2004-06-26
5	5557	4415	3	2004-06-26
6	5557	6636	1	2004-06-26
7	5557	1982	3	2004-06-26
8	5557	6150	1	2004-06-26
9	5557	9424	2	2004-06-26
1	5558	5048	1	2004-06-16
2	5558	9301	1	2004-06-16
3	5558	465	3	2004-06-16
4	5558	7128	1	2004-06-16
1	5559	1962	3	2004-06-22
2	5559	2294	1	2004-06-22
3	5559	8450	3	2004-06-22
4	5559	532	2	2004-06-22
5	5559	7076	1	2004-06-22
6	5559	3842	1	2004-06-22
7	5559	4278	1	2004-06-22
1	5560	3207	1	2004-06-23
2	5560	4914	1	2004-06-23
3	5560	6429	2	2004-06-23
4	5560	415	2	2004-06-23
5	5560	8157	3	2004-06-23
1	5561	6704	3	2004-06-30
2	5561	4103	2	2004-06-30
1	5562	7146	2	2004-06-12
1	5563	837	2	2004-06-13
2	5563	6266	2	2004-06-13
1	5564	6558	3	2004-06-26
2	5564	8570	2	2004-06-26
3	5564	4712	3	2004-06-26
4	5564	3462	3	2004-06-26
5	5564	9971	1	2004-06-26
1	5565	8707	2	2004-06-20
1	5566	7275	3	2004-06-04
2	5566	6823	3	2004-06-04
3	5566	2421	1	2004-06-04
4	5566	2155	1	2004-06-04
5	5566	4267	3	2004-06-04
1	5567	5538	1	2004-06-19
2	5567	2876	3	2004-06-19
3	5567	9884	1	2004-06-19
4	5567	9164	2	2004-06-19
5	5567	6920	2	2004-06-19
1	5568	1478	3	2004-06-21
2	5568	3437	3	2004-06-21
3	5568	6655	1	2004-06-21
4	5568	6864	3	2004-06-21
5	5568	3346	3	2004-06-21
6	5568	79	3	2004-06-21
7	5568	7723	2	2004-06-21
8	5568	8436	2	2004-06-21
1	5569	2972	2	2004-06-03
2	5569	6404	1	2004-06-03
3	5569	129	1	2004-06-03
4	5569	6617	3	2004-06-03
1	5570	6329	3	2004-06-27
1	5571	2058	1	2004-06-28
2	5571	5061	1	2004-06-28
3	5571	9728	1	2004-06-28
4	5571	8232	3	2004-06-28
5	5571	6176	3	2004-06-28
6	5571	2137	3	2004-06-28
1	5572	7244	2	2004-06-08
2	5572	2198	2	2004-06-08
3	5572	715	1	2004-06-08
4	5572	516	2	2004-06-08
5	5572	1574	3	2004-06-08
6	5572	4303	1	2004-06-08
7	5572	9827	1	2004-06-08
8	5572	6796	1	2004-06-08
1	5573	4640	1	2004-06-16
2	5573	3080	1	2004-06-16
3	5573	1164	2	2004-06-16
4	5573	765	2	2004-06-16
5	5573	325	2	2004-06-16
1	5574	1430	3	2004-06-08
2	5574	5853	1	2004-06-08
3	5574	4614	3	2004-06-08
4	5574	8789	3	2004-06-08
5	5574	8179	3	2004-06-08
1	5575	6830	2	2004-06-06
2	5575	2095	1	2004-06-06
3	5575	6769	2	2004-06-06
4	5575	2285	3	2004-06-06
5	5575	391	1	2004-06-06
6	5575	1567	1	2004-06-06
7	5575	7421	2	2004-06-06
1	5576	4352	2	2004-06-25
2	5576	1658	3	2004-06-25
3	5576	2058	1	2004-06-25
4	5576	7881	1	2004-06-25
5	5576	9061	3	2004-06-25
6	5576	5210	3	2004-06-25
7	5576	7048	1	2004-06-25
8	5576	4077	3	2004-06-25
9	5576	3509	1	2004-06-25
1	5577	8842	1	2004-06-13
2	5577	5422	2	2004-06-13
3	5577	4419	2	2004-06-13
4	5577	1792	1	2004-06-13
5	5577	3420	2	2004-06-13
1	5578	5524	1	2004-06-24
2	5578	124	2	2004-06-24
3	5578	2858	2	2004-06-24
4	5578	4144	3	2004-06-24
5	5578	7373	3	2004-06-24
6	5578	9047	1	2004-06-24
7	5578	9066	2	2004-06-24
8	5578	6674	3	2004-06-24
9	5578	8069	2	2004-06-24
1	5579	7196	2	2004-06-25
2	5579	5803	1	2004-06-25
3	5579	9711	2	2004-06-25
1	5580	7806	2	2004-06-18
2	5580	5801	1	2004-06-18
1	5581	8164	3	2004-06-27
2	5581	7232	3	2004-06-27
3	5581	2978	2	2004-06-27
4	5581	5072	1	2004-06-27
5	5581	9419	1	2004-06-27
6	5581	4537	1	2004-06-27
1	5582	2348	2	2004-06-18
2	5582	5297	3	2004-06-18
1	5583	2463	2	2004-06-28
2	5583	7761	1	2004-06-28
3	5583	4999	3	2004-06-28
4	5583	7792	1	2004-06-28
5	5583	7944	2	2004-06-28
6	5583	391	1	2004-06-28
7	5583	8928	2	2004-06-28
1	5584	9542	2	2004-06-06
2	5584	8236	2	2004-06-06
3	5584	6246	1	2004-06-06
4	5584	8780	1	2004-06-06
5	5584	8623	3	2004-06-06
6	5584	361	3	2004-06-06
1	5585	4264	3	2004-06-16
2	5585	1257	1	2004-06-16
3	5585	1095	3	2004-06-16
1	5586	6948	1	2004-06-22
2	5586	4352	2	2004-06-22
3	5586	8592	2	2004-06-22
4	5586	248	3	2004-06-22
5	5586	8199	2	2004-06-22
6	5586	7410	3	2004-06-22
1	5587	3909	1	2004-06-25
2	5587	1219	3	2004-06-25
3	5587	3144	2	2004-06-25
4	5587	4774	2	2004-06-25
5	5587	7538	2	2004-06-25
6	5587	3600	2	2004-06-25
7	5587	7354	2	2004-06-25
8	5587	622	2	2004-06-25
1	5588	8868	1	2004-06-18
2	5588	1227	3	2004-06-18
3	5588	6709	3	2004-06-18
4	5588	4044	2	2004-06-18
1	5589	9308	2	2004-06-15
2	5589	5418	1	2004-06-15
3	5589	9842	1	2004-06-15
4	5589	6851	3	2004-06-15
5	5589	6060	1	2004-06-15
6	5589	1996	2	2004-06-15
7	5589	4170	1	2004-06-15
8	5589	7713	3	2004-06-15
1	5590	7895	2	2004-06-23
2	5590	3525	2	2004-06-23
3	5590	4240	3	2004-06-23
4	5590	9347	3	2004-06-23
5	5590	6661	1	2004-06-23
6	5590	7483	2	2004-06-23
1	5591	3092	2	2004-06-21
2	5591	4066	3	2004-06-21
3	5591	5720	2	2004-06-21
4	5591	2563	3	2004-06-21
5	5591	8679	1	2004-06-21
6	5591	9867	2	2004-06-21
7	5591	7956	2	2004-06-21
1	5592	453	2	2004-06-09
2	5592	3821	3	2004-06-09
3	5592	2995	1	2004-06-09
4	5592	2287	1	2004-06-09
5	5592	6449	3	2004-06-09
6	5592	3378	2	2004-06-09
1	5593	5620	2	2004-06-18
2	5593	5945	3	2004-06-18
3	5593	5747	2	2004-06-18
4	5593	8458	2	2004-06-18
5	5593	893	2	2004-06-18
6	5593	9858	2	2004-06-18
7	5593	2263	3	2004-06-18
8	5593	9873	1	2004-06-18
9	5593	3794	2	2004-06-18
1	5594	7266	1	2004-06-08
2	5594	3933	1	2004-06-08
3	5594	5491	3	2004-06-08
4	5594	7112	2	2004-06-08
5	5594	9635	1	2004-06-08
1	5595	203	3	2004-06-05
2	5595	2846	1	2004-06-05
3	5595	5784	1	2004-06-05
4	5595	4716	3	2004-06-05
5	5595	2409	2	2004-06-05
6	5595	762	2	2004-06-05
7	5595	8281	1	2004-06-05
1	5596	3076	1	2004-06-09
1	5597	4195	1	2004-06-03
2	5597	742	2	2004-06-03
3	5597	6977	1	2004-06-03
4	5597	2913	3	2004-06-03
5	5597	1026	2	2004-06-03
6	5597	8276	3	2004-06-03
7	5597	8462	1	2004-06-03
8	5597	4856	1	2004-06-03
1	5598	8895	1	2004-06-23
2	5598	8314	3	2004-06-23
3	5598	320	1	2004-06-23
4	5598	8984	1	2004-06-23
5	5598	9956	1	2004-06-23
6	5598	9231	2	2004-06-23
1	5599	1627	1	2004-06-07
2	5599	6300	1	2004-06-07
3	5599	8502	2	2004-06-07
4	5599	9461	3	2004-06-07
5	5599	7566	2	2004-06-07
6	5599	7833	2	2004-06-07
7	5599	9933	2	2004-06-07
8	5599	1004	3	2004-06-07
9	5599	4969	3	2004-06-07
1	5600	6508	1	2004-06-18
2	5600	5529	2	2004-06-18
3	5600	4811	3	2004-06-18
4	5600	5710	2	2004-06-18
5	5600	6791	3	2004-06-18
1	5601	7666	3	2004-06-23
2	5601	2849	2	2004-06-23
3	5601	3764	1	2004-06-23
4	5601	376	2	2004-06-23
5	5601	5587	1	2004-06-23
6	5601	2524	1	2004-06-23
1	5602	3106	1	2004-06-03
2	5602	2063	3	2004-06-03
1	5603	1514	1	2004-06-25
2	5603	1134	3	2004-06-25
3	5603	6186	1	2004-06-25
4	5603	4784	2	2004-06-25
1	5604	8313	3	2004-06-02
2	5604	8030	2	2004-06-02
3	5604	836	1	2004-06-02
4	5604	4454	1	2004-06-02
1	5605	2647	2	2004-06-27
2	5605	615	1	2004-06-27
1	5606	16	2	2004-06-06
2	5606	2280	2	2004-06-06
3	5606	6789	3	2004-06-06
4	5606	52	3	2004-06-06
1	5607	8590	3	2004-06-15
2	5607	6907	3	2004-06-15
3	5607	274	1	2004-06-15
1	5608	1131	2	2004-06-03
2	5608	8884	1	2004-06-03
3	5608	5039	1	2004-06-03
4	5608	8666	3	2004-06-03
1	5609	4882	1	2004-06-13
2	5609	3476	2	2004-06-13
3	5609	9384	3	2004-06-13
4	5609	4067	1	2004-06-13
5	5609	1178	1	2004-06-13
6	5609	796	3	2004-06-13
1	5610	218	1	2004-06-07
2	5610	6927	1	2004-06-07
3	5610	5405	2	2004-06-07
1	5611	14	1	2004-06-10
2	5611	440	2	2004-06-10
1	5612	255	2	2004-06-22
1	5613	6978	3	2004-06-27
2	5613	8015	3	2004-06-27
3	5613	9600	3	2004-06-27
4	5613	2097	3	2004-06-27
5	5613	8561	3	2004-06-27
6	5613	1166	2	2004-06-27
7	5613	4832	2	2004-06-27
8	5613	4408	1	2004-06-27
9	5613	6020	2	2004-06-27
1	5614	1781	3	2004-06-07
2	5614	9778	1	2004-06-07
3	5614	3612	3	2004-06-07
4	5614	6356	1	2004-06-07
5	5614	8461	1	2004-06-07
6	5614	9879	2	2004-06-07
7	5614	2393	3	2004-06-07
8	5614	3935	2	2004-06-07
9	5614	9296	1	2004-06-07
1	5615	4721	1	2004-06-11
2	5615	9736	1	2004-06-11
3	5615	5290	1	2004-06-11
4	5615	7199	2	2004-06-11
5	5615	1018	3	2004-06-11
6	5615	1913	1	2004-06-11
7	5615	1014	2	2004-06-11
8	5615	9325	3	2004-06-11
1	5616	4260	1	2004-06-21
2	5616	6227	3	2004-06-21
3	5616	7583	2	2004-06-21
4	5616	690	1	2004-06-21
5	5616	5984	3	2004-06-21
6	5616	9436	1	2004-06-21
7	5616	8019	3	2004-06-21
1	5617	8271	1	2004-06-05
2	5617	7622	1	2004-06-05
3	5617	2807	3	2004-06-05
4	5617	5707	1	2004-06-05
5	5617	6004	1	2004-06-05
6	5617	9917	3	2004-06-05
7	5617	9327	2	2004-06-05
8	5617	9801	2	2004-06-05
1	5618	8477	3	2004-06-08
2	5618	210	3	2004-06-08
3	5618	7763	3	2004-06-08
1	5619	7850	3	2004-06-22
2	5619	91	2	2004-06-22
3	5619	9989	1	2004-06-22
4	5619	4105	2	2004-06-22
5	5619	5030	1	2004-06-22
6	5619	8273	2	2004-06-22
7	5619	6816	3	2004-06-22
8	5619	9122	2	2004-06-22
1	5620	4553	1	2004-06-10
2	5620	1288	2	2004-06-10
3	5620	389	3	2004-06-10
4	5620	2990	3	2004-06-10
1	5621	4332	2	2004-06-25
2	5621	1577	2	2004-06-25
3	5621	8541	2	2004-06-25
4	5621	15	2	2004-06-25
5	5621	5791	3	2004-06-25
6	5621	8516	1	2004-06-25
1	5622	9130	1	2004-06-18
2	5622	3270	2	2004-06-18
3	5622	5698	2	2004-06-18
4	5622	8444	2	2004-06-18
5	5622	3609	1	2004-06-18
6	5622	3560	1	2004-06-18
7	5622	5959	3	2004-06-18
8	5622	7972	1	2004-06-18
9	5622	4754	3	2004-06-18
1	5623	6865	1	2004-06-14
2	5623	2912	2	2004-06-14
3	5623	3625	3	2004-06-14
4	5623	3017	1	2004-06-14
5	5623	7840	1	2004-06-14
1	5624	5667	2	2004-06-19
2	5624	7850	3	2004-06-19
1	5625	521	3	2004-06-18
2	5625	1952	2	2004-06-18
1	5626	1185	2	2004-06-26
2	5626	4907	2	2004-06-26
3	5626	813	3	2004-06-26
4	5626	2895	2	2004-06-26
1	5627	1844	1	2004-06-05
2	5627	9206	3	2004-06-05
3	5627	6073	3	2004-06-05
4	5627	6786	1	2004-06-05
5	5627	8465	3	2004-06-05
6	5627	3438	3	2004-06-05
7	5627	7037	2	2004-06-05
1	5628	9583	1	2004-06-13
2	5628	8259	2	2004-06-13
3	5628	7232	3	2004-06-13
1	5629	861	3	2004-06-10
2	5629	1838	1	2004-06-10
3	5629	678	1	2004-06-10
4	5629	214	3	2004-06-10
1	5630	4925	1	2004-06-25
2	5630	5548	1	2004-06-25
3	5630	7354	3	2004-06-25
4	5630	7658	3	2004-06-25
5	5630	2633	3	2004-06-25
6	5630	2439	1	2004-06-25
1	5631	9796	1	2004-06-06
2	5631	9144	1	2004-06-06
3	5631	1740	1	2004-06-06
4	5631	3360	1	2004-06-06
5	5631	2025	2	2004-06-06
1	5632	6687	2	2004-06-28
2	5632	9658	1	2004-06-28
3	5632	7459	3	2004-06-28
4	5632	2041	2	2004-06-28
5	5632	6316	2	2004-06-28
6	5632	2357	3	2004-06-28
7	5632	5566	2	2004-06-28
1	5633	8392	3	2004-06-26
2	5633	8875	1	2004-06-26
3	5633	8960	1	2004-06-26
4	5633	2548	1	2004-06-26
5	5633	5808	1	2004-06-26
6	5633	1107	2	2004-06-26
7	5633	9409	3	2004-06-26
8	5633	1877	3	2004-06-26
1	5634	4452	1	2004-06-01
2	5634	6742	3	2004-06-01
1	5635	7836	3	2004-06-04
2	5635	7790	2	2004-06-04
3	5635	7705	2	2004-06-04
4	5635	6358	2	2004-06-04
5	5635	8899	3	2004-06-04
6	5635	7648	2	2004-06-04
7	5635	621	3	2004-06-04
8	5635	1085	1	2004-06-04
9	5635	6547	1	2004-06-04
1	5636	8642	3	2004-06-28
2	5636	7568	2	2004-06-28
3	5636	3556	3	2004-06-28
4	5636	7691	2	2004-06-28
5	5636	8287	2	2004-06-28
1	5637	2740	3	2004-06-13
2	5637	8544	1	2004-06-13
1	5638	4945	3	2004-06-22
2	5638	7665	1	2004-06-22
3	5638	389	3	2004-06-22
4	5638	8065	1	2004-06-22
5	5638	1935	3	2004-06-22
6	5638	9433	3	2004-06-22
7	5638	2090	1	2004-06-22
1	5639	5306	1	2004-06-25
2	5639	2580	3	2004-06-25
3	5639	3491	2	2004-06-25
4	5639	5167	1	2004-06-25
5	5639	6958	1	2004-06-25
6	5639	8224	1	2004-06-25
1	5640	4659	1	2004-06-30
2	5640	4241	1	2004-06-30
3	5640	3803	2	2004-06-30
4	5640	9430	1	2004-06-30
5	5640	5679	1	2004-06-30
6	5640	6224	2	2004-06-30
7	5640	1300	2	2004-06-30
1	5641	3662	3	2004-06-02
2	5641	8300	3	2004-06-02
3	5641	794	2	2004-06-02
1	5642	2185	3	2004-06-04
1	5643	9566	2	2004-06-25
2	5643	8724	3	2004-06-25
3	5643	7442	2	2004-06-25
1	5644	7324	3	2004-06-02
2	5644	8420	1	2004-06-02
1	5645	910	1	2004-06-06
2	5645	5234	1	2004-06-06
3	5645	1165	2	2004-06-06
4	5645	2746	2	2004-06-06
5	5645	3078	1	2004-06-06
6	5645	192	2	2004-06-06
7	5645	3601	3	2004-06-06
8	5645	7687	1	2004-06-06
9	5645	8754	2	2004-06-06
1	5646	1083	2	2004-06-21
2	5646	3723	3	2004-06-21
3	5646	8711	2	2004-06-21
4	5646	1584	1	2004-06-21
5	5646	5378	1	2004-06-21
1	5647	4403	3	2004-06-07
2	5647	6727	3	2004-06-07
3	5647	8212	3	2004-06-07
4	5647	961	1	2004-06-07
1	5648	3775	1	2004-06-21
2	5648	4698	1	2004-06-21
3	5648	5889	2	2004-06-21
4	5648	8684	3	2004-06-21
5	5648	5282	3	2004-06-21
1	5649	9359	3	2004-06-16
1	5650	931	3	2004-06-03
2	5650	2882	3	2004-06-03
3	5650	6693	2	2004-06-03
4	5650	955	2	2004-06-03
5	5650	2489	2	2004-06-03
1	5651	8831	1	2004-06-27
2	5651	9276	3	2004-06-27
3	5651	1456	2	2004-06-27
4	5651	4909	2	2004-06-27
1	5652	2039	3	2004-06-05
1	5653	4862	2	2004-06-14
2	5653	4625	1	2004-06-14
3	5653	9980	2	2004-06-14
4	5653	4924	1	2004-06-14
5	5653	673	2	2004-06-14
1	5654	8474	2	2004-06-27
2	5654	5078	3	2004-06-27
3	5654	1050	3	2004-06-27
4	5654	6397	1	2004-06-27
5	5654	2354	1	2004-06-27
6	5654	3253	2	2004-06-27
7	5654	1109	3	2004-06-27
1	5655	504	3	2004-06-29
2	5655	5897	1	2004-06-29
3	5655	3492	1	2004-06-29
4	5655	2952	2	2004-06-29
1	5656	9247	3	2004-06-14
2	5656	8253	2	2004-06-14
1	5657	1774	2	2004-06-28
2	5657	8845	2	2004-06-28
3	5657	1057	3	2004-06-28
4	5657	2831	1	2004-06-28
5	5657	4318	2	2004-06-28
6	5657	4878	2	2004-06-28
1	5658	1595	3	2004-06-13
2	5658	1686	2	2004-06-13
3	5658	9941	1	2004-06-13
4	5658	7898	3	2004-06-13
5	5658	1743	2	2004-06-13
6	5658	3512	1	2004-06-13
7	5658	5451	3	2004-06-13
1	5659	2251	2	2004-06-20
2	5659	5326	2	2004-06-20
3	5659	6079	3	2004-06-20
4	5659	1200	1	2004-06-20
5	5659	4465	2	2004-06-20
1	5660	8025	2	2004-06-06
2	5660	9464	3	2004-06-06
3	5660	6914	3	2004-06-06
1	5661	9594	3	2004-06-22
1	5662	1496	3	2004-06-26
2	5662	8515	3	2004-06-26
3	5662	3517	2	2004-06-26
1	5663	9946	3	2004-06-20
1	5664	7133	1	2004-06-03
2	5664	6688	2	2004-06-03
3	5664	7432	2	2004-06-03
4	5664	2703	1	2004-06-03
5	5664	4504	1	2004-06-03
6	5664	9903	1	2004-06-03
7	5664	8418	2	2004-06-03
8	5664	5961	3	2004-06-03
1	5665	9069	1	2004-06-14
2	5665	2755	2	2004-06-14
3	5665	4128	1	2004-06-14
4	5665	1901	2	2004-06-14
5	5665	5397	1	2004-06-14
6	5665	3548	1	2004-06-14
7	5665	2579	1	2004-06-14
8	5665	6577	1	2004-06-14
1	5666	1574	1	2004-06-13
2	5666	1567	3	2004-06-13
3	5666	6941	3	2004-06-13
4	5666	9905	1	2004-06-13
5	5666	2003	2	2004-06-13
6	5666	9502	1	2004-06-13
7	5666	9838	1	2004-06-13
8	5666	5690	2	2004-06-13
1	5667	98	1	2004-06-15
1	5668	2687	2	2004-06-09
2	5668	8737	2	2004-06-09
3	5668	5225	1	2004-06-09
4	5668	4493	3	2004-06-09
5	5668	303	1	2004-06-09
6	5668	4319	1	2004-06-09
7	5668	2897	2	2004-06-09
8	5668	6847	1	2004-06-09
9	5668	7393	3	2004-06-09
1	5669	672	3	2004-06-14
2	5669	9963	1	2004-06-14
3	5669	1778	1	2004-06-14
4	5669	3445	2	2004-06-14
5	5669	2305	2	2004-06-14
6	5669	998	1	2004-06-14
7	5669	9770	2	2004-06-14
8	5669	1352	2	2004-06-14
9	5669	3014	1	2004-06-14
1	5670	3654	3	2004-06-18
2	5670	990	1	2004-06-18
3	5670	5392	2	2004-06-18
4	5670	4128	2	2004-06-18
5	5670	5254	2	2004-06-18
6	5670	5482	2	2004-06-18
7	5670	5568	3	2004-06-18
8	5670	8062	3	2004-06-18
1	5671	1407	2	2004-06-05
2	5671	8830	1	2004-06-05
3	5671	9176	1	2004-06-05
1	5672	3463	1	2004-06-14
2	5672	4981	2	2004-06-14
3	5672	3875	1	2004-06-14
4	5672	96	3	2004-06-14
5	5672	6415	2	2004-06-14
6	5672	2802	1	2004-06-14
1	5673	7382	1	2004-06-02
2	5673	8994	1	2004-06-02
3	5673	3374	1	2004-06-02
4	5673	7438	1	2004-06-02
5	5673	3159	2	2004-06-02
6	5673	4046	3	2004-06-02
7	5673	1485	1	2004-06-02
8	5673	3845	2	2004-06-02
1	5674	9198	3	2004-06-19
2	5674	7928	2	2004-06-19
3	5674	4844	1	2004-06-19
4	5674	7509	2	2004-06-19
5	5674	9098	2	2004-06-19
6	5674	4036	2	2004-06-19
7	5674	7432	1	2004-06-19
8	5674	9004	1	2004-06-19
9	5674	3429	2	2004-06-19
1	5675	4158	2	2004-06-10
2	5675	275	3	2004-06-10
3	5675	9486	2	2004-06-10
4	5675	6827	3	2004-06-10
5	5675	6250	2	2004-06-10
6	5675	8380	2	2004-06-10
7	5675	1638	1	2004-06-10
1	5676	5812	1	2004-06-15
2	5676	483	1	2004-06-15
3	5676	5697	3	2004-06-15
4	5676	4048	3	2004-06-15
1	5677	4110	3	2004-06-18
2	5677	3522	2	2004-06-18
3	5677	7872	1	2004-06-18
4	5677	710	2	2004-06-18
5	5677	1893	3	2004-06-18
6	5677	724	1	2004-06-18
7	5677	1137	1	2004-06-18
8	5677	3495	2	2004-06-18
9	5677	1507	1	2004-06-18
1	5678	561	1	2004-06-01
1	5679	1665	2	2004-06-01
2	5679	4926	2	2004-06-01
3	5679	5196	3	2004-06-01
4	5679	159	1	2004-06-01
5	5679	1455	1	2004-06-01
6	5679	7767	2	2004-06-01
1	5680	851	3	2004-06-24
2	5680	5007	1	2004-06-24
3	5680	9240	2	2004-06-24
4	5680	9676	2	2004-06-24
5	5680	5582	1	2004-06-24
6	5680	4522	2	2004-06-24
7	5680	4846	2	2004-06-24
8	5680	1540	2	2004-06-24
9	5680	9461	2	2004-06-24
1	5681	7725	2	2004-06-07
2	5681	3310	2	2004-06-07
3	5681	9715	1	2004-06-07
1	5682	448	2	2004-06-12
2	5682	7189	3	2004-06-12
3	5682	161	3	2004-06-12
4	5682	3719	2	2004-06-12
5	5682	7101	3	2004-06-12
1	5683	8456	1	2004-06-05
2	5683	9344	1	2004-06-05
3	5683	6493	2	2004-06-05
1	5684	9708	1	2004-06-10
2	5684	7628	2	2004-06-10
3	5684	3670	3	2004-06-10
4	5684	8519	2	2004-06-10
5	5684	2836	2	2004-06-10
6	5684	3803	1	2004-06-10
1	5685	5761	1	2004-06-08
2	5685	1616	3	2004-06-08
3	5685	2957	1	2004-06-08
4	5685	9971	1	2004-06-08
5	5685	810	2	2004-06-08
6	5685	6555	2	2004-06-08
7	5685	680	3	2004-06-08
8	5685	481	1	2004-06-08
9	5685	7512	3	2004-06-08
1	5686	5297	3	2004-06-13
2	5686	8299	3	2004-06-13
3	5686	1668	1	2004-06-13
1	5687	484	1	2004-06-20
2	5687	517	2	2004-06-20
3	5687	2224	1	2004-06-20
1	5688	7024	3	2004-06-18
2	5688	9471	3	2004-06-18
3	5688	8016	3	2004-06-18
1	5689	4682	2	2004-06-17
2	5689	118	1	2004-06-17
1	5690	2191	2	2004-06-08
2	5690	1560	1	2004-06-08
3	5690	6539	1	2004-06-08
4	5690	6115	3	2004-06-08
5	5690	2563	1	2004-06-08
6	5690	1797	3	2004-06-08
7	5690	4150	3	2004-06-08
8	5690	7142	2	2004-06-08
9	5690	6324	2	2004-06-08
1	5691	3382	1	2004-06-02
2	5691	2222	2	2004-06-02
3	5691	4910	2	2004-06-02
4	5691	5284	3	2004-06-02
5	5691	3959	3	2004-06-02
6	5691	3144	2	2004-06-02
7	5691	149	3	2004-06-02
8	5691	7594	2	2004-06-02
1	5692	9669	1	2004-06-26
1	5693	1969	2	2004-06-28
2	5693	7320	3	2004-06-28
3	5693	5251	1	2004-06-28
4	5693	1146	3	2004-06-28
5	5693	4200	2	2004-06-28
1	5694	6958	3	2004-06-07
2	5694	1729	3	2004-06-07
3	5694	7639	3	2004-06-07
4	5694	3369	2	2004-06-07
5	5694	9478	1	2004-06-07
6	5694	6324	3	2004-06-07
1	5695	769	3	2004-06-12
2	5695	6128	3	2004-06-12
3	5695	7142	1	2004-06-12
4	5695	8788	3	2004-06-12
5	5695	8851	1	2004-06-12
6	5695	4343	1	2004-06-12
7	5695	2471	3	2004-06-12
8	5695	7314	3	2004-06-12
9	5695	7113	3	2004-06-12
1	5696	834	3	2004-06-20
2	5696	1389	3	2004-06-20
3	5696	6987	2	2004-06-20
4	5696	2542	1	2004-06-20
5	5696	4783	1	2004-06-20
6	5696	868	1	2004-06-20
7	5696	1398	3	2004-06-20
8	5696	2290	1	2004-06-20
9	5696	6296	1	2004-06-20
1	5697	9794	3	2004-06-10
2	5697	5071	3	2004-06-10
3	5697	8599	1	2004-06-10
4	5697	1658	3	2004-06-10
5	5697	1507	1	2004-06-10
6	5697	4802	1	2004-06-10
1	5698	4731	1	2004-06-29
2	5698	5501	2	2004-06-29
1	5699	7085	3	2004-06-12
2	5699	7161	1	2004-06-12
3	5699	540	3	2004-06-12
4	5699	5901	1	2004-06-12
5	5699	8960	1	2004-06-12
6	5699	7240	3	2004-06-12
1	5700	1389	3	2004-06-08
2	5700	6977	1	2004-06-08
3	5700	1109	2	2004-06-08
4	5700	3228	2	2004-06-08
1	5701	5628	2	2004-06-24
2	5701	7587	1	2004-06-24
1	5702	4150	3	2004-06-15
2	5702	5816	1	2004-06-15
3	5702	9841	1	2004-06-15
4	5702	668	1	2004-06-15
5	5702	1953	2	2004-06-15
1	5703	4378	2	2004-06-20
2	5703	8489	3	2004-06-20
3	5703	1454	2	2004-06-20
4	5703	6335	1	2004-06-20
1	5704	4673	1	2004-06-24
2	5704	222	3	2004-06-24
3	5704	8357	2	2004-06-24
4	5704	6511	2	2004-06-24
5	5704	7481	2	2004-06-24
1	5705	3335	2	2004-06-22
2	5705	2522	3	2004-06-22
3	5705	8740	3	2004-06-22
4	5705	3457	3	2004-06-22
5	5705	4505	2	2004-06-22
6	5705	3552	1	2004-06-22
7	5705	7799	1	2004-06-22
8	5705	2801	2	2004-06-22
9	5705	6917	3	2004-06-22
1	5706	1510	1	2004-06-26
2	5706	1132	3	2004-06-26
3	5706	7976	3	2004-06-26
4	5706	7138	3	2004-06-26
5	5706	7540	1	2004-06-26
6	5706	2008	1	2004-06-26
7	5706	8314	1	2004-06-26
1	5707	6680	1	2004-06-21
2	5707	2304	2	2004-06-21
1	5708	2577	3	2004-06-09
2	5708	7023	3	2004-06-09
3	5708	5772	3	2004-06-09
4	5708	9317	3	2004-06-09
5	5708	7522	3	2004-06-09
6	5708	5264	2	2004-06-09
7	5708	4035	1	2004-06-09
8	5708	5131	2	2004-06-09
9	5708	2865	2	2004-06-09
1	5709	1289	1	2004-06-21
2	5709	6291	2	2004-06-21
3	5709	6373	3	2004-06-21
4	5709	8696	2	2004-06-21
5	5709	9143	1	2004-06-21
1	5710	4697	3	2004-06-17
2	5710	8069	1	2004-06-17
1	5711	6136	1	2004-06-17
2	5711	5648	3	2004-06-17
3	5711	5452	1	2004-06-17
4	5711	8824	1	2004-06-17
5	5711	7201	1	2004-06-17
6	5711	2559	2	2004-06-17
7	5711	3704	3	2004-06-17
8	5711	2750	1	2004-06-17
9	5711	5514	1	2004-06-17
1	5712	2073	1	2004-06-12
2	5712	914	1	2004-06-12
3	5712	4972	2	2004-06-12
1	5713	3855	1	2004-06-11
2	5713	8608	3	2004-06-11
3	5713	4175	3	2004-06-11
4	5713	9971	1	2004-06-11
5	5713	7543	1	2004-06-11
6	5713	4866	1	2004-06-11
7	5713	1462	3	2004-06-11
8	5713	3646	3	2004-06-11
9	5713	9507	3	2004-06-11
1	5714	317	1	2004-06-24
2	5714	95	2	2004-06-24
3	5714	7350	2	2004-06-24
4	5714	7136	2	2004-06-24
5	5714	3176	1	2004-06-24
6	5714	5178	1	2004-06-24
7	5714	297	3	2004-06-24
8	5714	9214	1	2004-06-24
9	5714	727	3	2004-06-24
1	5715	3207	1	2004-06-09
2	5715	1235	1	2004-06-09
3	5715	8964	3	2004-06-09
4	5715	276	3	2004-06-09
1	5716	5881	3	2004-06-28
2	5716	2733	1	2004-06-28
3	5716	567	2	2004-06-28
4	5716	4008	2	2004-06-28
5	5716	7692	2	2004-06-28
6	5716	5096	3	2004-06-28
7	5716	4572	2	2004-06-28
8	5716	3661	3	2004-06-28
9	5716	1414	1	2004-06-28
1	5717	7332	1	2004-06-05
2	5717	1978	3	2004-06-05
3	5717	1187	1	2004-06-05
1	5718	8092	1	2004-06-25
2	5718	7099	3	2004-06-25
3	5718	8854	1	2004-06-25
4	5718	4403	2	2004-06-25
1	5719	5320	3	2004-06-17
2	5719	7351	3	2004-06-17
3	5719	8774	3	2004-06-17
4	5719	1353	1	2004-06-17
5	5719	1840	3	2004-06-17
6	5719	4356	2	2004-06-17
7	5719	6292	2	2004-06-17
8	5719	4865	2	2004-06-17
9	5719	6507	2	2004-06-17
1	5720	3256	3	2004-06-26
2	5720	6779	3	2004-06-26
3	5720	3420	1	2004-06-26
4	5720	7156	3	2004-06-26
5	5720	2170	1	2004-06-26
6	5720	3980	3	2004-06-26
1	5721	4835	1	2004-06-28
1	5722	4732	3	2004-06-28
2	5722	29	1	2004-06-28
3	5722	4095	3	2004-06-28
4	5722	5836	1	2004-06-28
5	5722	4275	3	2004-06-28
1	5723	3242	2	2004-06-27
2	5723	9278	2	2004-06-27
3	5723	6381	1	2004-06-27
1	5724	6149	1	2004-06-15
2	5724	3765	2	2004-06-15
3	5724	35	3	2004-06-15
4	5724	929	2	2004-06-15
1	5725	9560	1	2004-06-21
1	5726	4888	3	2004-06-10
2	5726	4545	3	2004-06-10
1	5727	7081	3	2004-06-05
2	5727	3554	1	2004-06-05
3	5727	1899	3	2004-06-05
4	5727	3935	2	2004-06-05
5	5727	5096	2	2004-06-05
6	5727	3580	2	2004-06-05
7	5727	8735	1	2004-06-05
8	5727	6981	2	2004-06-05
1	5728	376	3	2004-06-05
2	5728	6827	2	2004-06-05
3	5728	5187	1	2004-06-05
4	5728	3393	3	2004-06-05
5	5728	5195	3	2004-06-05
1	5729	5365	3	2004-06-15
2	5729	7992	3	2004-06-15
3	5729	2964	1	2004-06-15
4	5729	3268	2	2004-06-15
5	5729	9111	1	2004-06-15
6	5729	7059	2	2004-06-15
7	5729	6741	3	2004-06-15
8	5729	2633	1	2004-06-15
1	5730	8271	2	2004-06-10
1	5731	8595	3	2004-06-05
2	5731	8963	2	2004-06-05
3	5731	5807	2	2004-06-05
4	5731	1299	2	2004-06-05
5	5731	3627	2	2004-06-05
6	5731	6886	3	2004-06-05
7	5731	805	2	2004-06-05
1	5732	6467	2	2004-06-27
2	5732	8956	3	2004-06-27
3	5732	7729	3	2004-06-27
4	5732	9883	2	2004-06-27
5	5732	5791	1	2004-06-27
6	5732	7662	3	2004-06-27
1	5733	254	1	2004-06-25
2	5733	1356	1	2004-06-25
3	5733	5695	2	2004-06-25
4	5733	5813	1	2004-06-25
5	5733	1877	2	2004-06-25
6	5733	8577	1	2004-06-25
7	5733	4480	1	2004-06-25
1	5734	708	1	2004-06-20
2	5734	5146	1	2004-06-20
3	5734	9115	1	2004-06-20
4	5734	1967	3	2004-06-20
5	5734	9509	1	2004-06-20
1	5735	7494	3	2004-06-10
2	5735	4838	1	2004-06-10
3	5735	3396	1	2004-06-10
1	5736	6045	1	2004-06-18
2	5736	5010	1	2004-06-18
3	5736	2694	1	2004-06-18
4	5736	7822	2	2004-06-18
1	5737	3905	2	2004-06-11
2	5737	9401	2	2004-06-11
3	5737	5990	1	2004-06-11
1	5738	1461	1	2004-06-28
2	5738	9692	2	2004-06-28
3	5738	1208	2	2004-06-28
4	5738	128	3	2004-06-28
5	5738	9804	2	2004-06-28
6	5738	223	2	2004-06-28
1	5739	6317	3	2004-06-26
2	5739	9417	1	2004-06-26
3	5739	1345	1	2004-06-26
4	5739	6266	1	2004-06-26
5	5739	6734	1	2004-06-26
6	5739	3178	2	2004-06-26
1	5740	9454	1	2004-06-16
2	5740	1620	1	2004-06-16
3	5740	7398	1	2004-06-16
4	5740	9136	3	2004-06-16
5	5740	7919	3	2004-06-16
6	5740	2014	2	2004-06-16
7	5740	2274	3	2004-06-16
1	5741	8898	3	2004-06-09
2	5741	5734	2	2004-06-09
3	5741	8033	1	2004-06-09
1	5742	107	1	2004-06-23
2	5742	9485	3	2004-06-23
3	5742	2396	1	2004-06-23
1	5743	6994	1	2004-06-01
2	5743	8714	3	2004-06-01
3	5743	7315	1	2004-06-01
4	5743	6230	1	2004-06-01
5	5743	9578	1	2004-06-01
6	5743	2722	3	2004-06-01
7	5743	9461	3	2004-06-01
8	5743	3639	3	2004-06-01
9	5743	921	1	2004-06-01
1	5744	9589	1	2004-06-27
2	5744	8370	1	2004-06-27
3	5744	4367	3	2004-06-27
4	5744	1777	3	2004-06-27
5	5744	7947	3	2004-06-27
6	5744	7986	2	2004-06-27
7	5744	7777	2	2004-06-27
8	5744	7648	2	2004-06-27
1	5745	5700	2	2004-06-17
2	5745	6784	3	2004-06-17
3	5745	3132	3	2004-06-17
4	5745	396	1	2004-06-17
5	5745	6836	2	2004-06-17
6	5745	644	2	2004-06-17
7	5745	7438	3	2004-06-17
8	5745	8409	1	2004-06-17
1	5746	8954	3	2004-06-23
2	5746	2211	3	2004-06-23
3	5746	2307	3	2004-06-23
4	5746	737	3	2004-06-23
5	5746	7083	3	2004-06-23
1	5747	2121	2	2004-06-19
2	5747	733	1	2004-06-19
3	5747	7521	3	2004-06-19
1	5748	7178	1	2004-06-21
2	5748	5932	2	2004-06-21
3	5748	2587	2	2004-06-21
4	5748	333	1	2004-06-21
1	5749	2402	3	2004-06-06
2	5749	2181	3	2004-06-06
3	5749	5922	3	2004-06-06
4	5749	2267	3	2004-06-06
1	5750	6903	1	2004-06-05
2	5750	9755	2	2004-06-05
1	5751	6150	2	2004-06-30
2	5751	1807	3	2004-06-30
3	5751	8606	1	2004-06-30
4	5751	276	1	2004-06-30
5	5751	4682	3	2004-06-30
6	5751	4832	3	2004-06-30
7	5751	7552	3	2004-06-30
1	5752	1950	3	2004-06-20
2	5752	3222	2	2004-06-20
3	5752	9077	1	2004-06-20
4	5752	7794	3	2004-06-20
5	5752	3717	3	2004-06-20
6	5752	2580	1	2004-06-20
7	5752	4665	3	2004-06-20
8	5752	5089	2	2004-06-20
1	5753	4259	1	2004-06-23
2	5753	6286	3	2004-06-23
3	5753	374	2	2004-06-23
4	5753	6102	3	2004-06-23
5	5753	7311	1	2004-06-23
6	5753	5776	3	2004-06-23
7	5753	8431	3	2004-06-23
1	5754	6339	1	2004-06-17
2	5754	805	3	2004-06-17
3	5754	4274	2	2004-06-17
1	5755	3057	1	2004-06-23
2	5755	2853	3	2004-06-23
3	5755	3841	3	2004-06-23
4	5755	6406	2	2004-06-23
5	5755	2975	1	2004-06-23
1	5756	9545	1	2004-06-04
2	5756	5927	2	2004-06-04
3	5756	9984	2	2004-06-04
4	5756	8080	2	2004-06-04
5	5756	7885	3	2004-06-04
6	5756	5241	1	2004-06-04
7	5756	4354	1	2004-06-04
1	5757	6845	1	2004-06-05
2	5757	1893	1	2004-06-05
3	5757	9990	3	2004-06-05
4	5757	4900	1	2004-06-05
5	5757	806	2	2004-06-05
1	5758	7329	3	2004-06-10
2	5758	7711	3	2004-06-10
3	5758	3960	2	2004-06-10
1	5759	4002	3	2004-06-11
2	5759	1763	2	2004-06-11
3	5759	5323	3	2004-06-11
4	5759	101	1	2004-06-11
5	5759	615	1	2004-06-11
6	5759	2852	1	2004-06-11
7	5759	292	3	2004-06-11
8	5759	3569	1	2004-06-11
1	5760	9613	1	2004-06-12
2	5760	5705	3	2004-06-12
3	5760	588	3	2004-06-12
4	5760	3114	2	2004-06-12
5	5760	1508	3	2004-06-12
6	5760	3096	2	2004-06-12
7	5760	6817	2	2004-06-12
1	5761	4307	2	2004-06-04
2	5761	3127	3	2004-06-04
1	5762	4514	3	2004-06-18
2	5762	6225	1	2004-06-18
3	5762	5508	2	2004-06-18
4	5762	3738	1	2004-06-18
5	5762	3161	2	2004-06-18
6	5762	877	2	2004-06-18
7	5762	8547	1	2004-06-18
8	5762	4062	1	2004-06-18
9	5762	7894	1	2004-06-18
1	5763	60	3	2004-06-20
2	5763	6353	1	2004-06-20
1	5764	1598	1	2004-06-14
2	5764	8106	3	2004-06-14
3	5764	1579	2	2004-06-14
4	5764	3659	2	2004-06-14
5	5764	4825	3	2004-06-14
6	5764	9641	2	2004-06-14
7	5764	3093	3	2004-06-14
8	5764	8085	3	2004-06-14
9	5764	9829	2	2004-06-14
1	5765	7447	2	2004-06-25
1	5766	5991	2	2004-06-26
2	5766	2241	3	2004-06-26
3	5766	5871	1	2004-06-26
1	5767	2765	3	2004-06-17
2	5767	5887	1	2004-06-17
3	5767	4485	3	2004-06-17
4	5767	592	1	2004-06-17
5	5767	6133	1	2004-06-17
6	5767	8548	2	2004-06-17
7	5767	6748	2	2004-06-17
8	5767	5211	2	2004-06-17
9	5767	8418	2	2004-06-17
1	5768	1322	3	2004-06-24
2	5768	1572	3	2004-06-24
3	5768	9017	3	2004-06-24
4	5768	4641	1	2004-06-24
1	5769	9810	2	2004-06-19
2	5769	914	1	2004-06-19
1	5770	1210	3	2004-06-27
2	5770	814	2	2004-06-27
3	5770	1764	3	2004-06-27
4	5770	1	3	2004-06-27
5	5770	5801	2	2004-06-27
6	5770	3741	3	2004-06-27
7	5770	5103	2	2004-06-27
1	5771	7095	3	2004-06-13
2	5771	6359	3	2004-06-13
3	5771	273	2	2004-06-13
4	5771	5098	1	2004-06-13
5	5771	6569	2	2004-06-13
6	5771	8232	3	2004-06-13
7	5771	1272	3	2004-06-13
8	5771	4958	1	2004-06-13
9	5771	5861	3	2004-06-13
1	5772	2293	1	2004-06-04
2	5772	4239	3	2004-06-04
3	5772	5530	3	2004-06-04
4	5772	1514	3	2004-06-04
5	5772	7507	3	2004-06-04
6	5772	6160	2	2004-06-04
7	5772	7462	2	2004-06-04
1	5773	6470	2	2004-06-01
2	5773	3990	3	2004-06-01
3	5773	5290	3	2004-06-01
4	5773	9826	1	2004-06-01
5	5773	5668	1	2004-06-01
6	5773	7011	1	2004-06-01
1	5774	6697	3	2004-06-25
2	5774	1049	3	2004-06-25
3	5774	5716	3	2004-06-25
1	5775	8308	1	2004-06-21
2	5775	6839	2	2004-06-21
3	5775	9054	1	2004-06-21
4	5775	1775	1	2004-06-21
1	5776	8214	3	2004-06-04
1	5777	4528	1	2004-06-07
1	5778	9435	2	2004-06-09
2	5778	2375	2	2004-06-09
3	5778	7652	2	2004-06-09
4	5778	532	2	2004-06-09
1	5779	679	2	2004-06-22
2	5779	9345	1	2004-06-22
3	5779	723	1	2004-06-22
4	5779	2600	3	2004-06-22
5	5779	8994	2	2004-06-22
6	5779	4161	3	2004-06-22
1	5780	9912	1	2004-06-15
2	5780	1475	3	2004-06-15
3	5780	6803	2	2004-06-15
4	5780	5598	2	2004-06-15
5	5780	8644	2	2004-06-15
6	5780	412	2	2004-06-15
7	5780	3501	1	2004-06-15
1	5781	5905	3	2004-06-07
2	5781	2870	3	2004-06-07
1	5782	661	3	2004-06-17
2	5782	8460	1	2004-06-17
3	5782	5660	3	2004-06-17
4	5782	2651	3	2004-06-17
5	5782	7716	3	2004-06-17
6	5782	984	1	2004-06-17
7	5782	3907	3	2004-06-17
8	5782	9443	2	2004-06-17
9	5782	5517	1	2004-06-17
1	5783	9243	1	2004-06-20
2	5783	9245	1	2004-06-20
3	5783	1529	2	2004-06-20
1	5784	2650	1	2004-06-12
2	5784	6261	3	2004-06-12
3	5784	1458	3	2004-06-12
4	5784	5444	3	2004-06-12
5	5784	8365	2	2004-06-12
1	5785	6589	1	2004-06-08
2	5785	4871	1	2004-06-08
1	5786	5017	2	2004-06-28
2	5786	634	2	2004-06-28
3	5786	9871	2	2004-06-28
4	5786	1191	2	2004-06-28
5	5786	9246	2	2004-06-28
6	5786	7587	2	2004-06-28
7	5786	2150	3	2004-06-28
8	5786	4418	3	2004-06-28
1	5787	5052	1	2004-06-25
1	5788	4842	1	2004-06-08
2	5788	9492	1	2004-06-08
3	5788	9444	2	2004-06-08
4	5788	5627	1	2004-06-08
5	5788	1053	2	2004-06-08
6	5788	4687	1	2004-06-08
7	5788	9996	2	2004-06-08
1	5789	6626	2	2004-06-19
2	5789	5826	2	2004-06-19
3	5789	6637	3	2004-06-19
4	5789	5544	1	2004-06-19
5	5789	9920	3	2004-06-19
6	5789	3328	1	2004-06-19
7	5789	5674	3	2004-06-19
8	5789	2486	2	2004-06-19
1	5790	2006	1	2004-06-27
2	5790	9905	3	2004-06-27
3	5790	2969	3	2004-06-27
4	5790	625	3	2004-06-27
1	5791	3918	1	2004-06-23
2	5791	8949	1	2004-06-23
3	5791	2956	2	2004-06-23
4	5791	2241	1	2004-06-23
1	5792	3737	3	2004-06-08
2	5792	3503	1	2004-06-08
3	5792	8853	1	2004-06-08
4	5792	6925	1	2004-06-08
5	5792	3900	3	2004-06-08
6	5792	7551	3	2004-06-08
7	5792	6729	3	2004-06-08
8	5792	5919	2	2004-06-08
1	5793	6314	3	2004-06-25
2	5793	2707	3	2004-06-25
1	5794	516	2	2004-06-06
2	5794	2763	2	2004-06-06
3	5794	3506	2	2004-06-06
4	5794	6771	1	2004-06-06
1	5795	524	1	2004-06-29
2	5795	206	3	2004-06-29
3	5795	8942	2	2004-06-29
4	5795	1464	3	2004-06-29
1	5796	7049	1	2004-06-28
2	5796	4910	3	2004-06-28
3	5796	6987	3	2004-06-28
4	5796	3232	3	2004-06-28
5	5796	3636	2	2004-06-28
6	5796	1755	3	2004-06-28
1	5797	2221	1	2004-06-07
2	5797	5037	1	2004-06-07
1	5798	1368	1	2004-06-11
2	5798	9603	1	2004-06-11
3	5798	1241	3	2004-06-11
1	5799	7097	3	2004-06-20
2	5799	8300	1	2004-06-20
1	5800	9078	3	2004-06-17
2	5800	5740	3	2004-06-17
3	5800	280	3	2004-06-17
4	5800	1294	2	2004-06-17
5	5800	704	2	2004-06-17
6	5800	558	1	2004-06-17
7	5800	7201	1	2004-06-17
1	5801	5737	3	2004-06-07
2	5801	1688	3	2004-06-07
3	5801	203	3	2004-06-07
4	5801	4667	3	2004-06-07
1	5802	7341	3	2004-06-28
2	5802	4016	1	2004-06-28
3	5802	8092	2	2004-06-28
4	5802	1041	3	2004-06-28
5	5802	9611	1	2004-06-28
1	5803	2094	2	2004-06-13
2	5803	8165	2	2004-06-13
1	5804	610	2	2004-06-25
2	5804	8473	2	2004-06-25
3	5804	2375	3	2004-06-25
4	5804	5403	1	2004-06-25
5	5804	3019	1	2004-06-25
6	5804	2328	3	2004-06-25
7	5804	5824	1	2004-06-25
8	5804	1329	3	2004-06-25
9	5804	9805	1	2004-06-25
1	5805	5329	1	2004-06-26
1	5806	7394	1	2004-06-17
2	5806	3344	3	2004-06-17
3	5806	5455	1	2004-06-17
4	5806	3280	3	2004-06-17
1	5807	1425	1	2004-06-29
2	5807	9453	3	2004-06-29
3	5807	3391	1	2004-06-29
1	5808	7162	1	2004-06-13
2	5808	3772	1	2004-06-13
3	5808	6027	3	2004-06-13
1	5809	5523	2	2004-06-18
2	5809	1380	1	2004-06-18
3	5809	8241	2	2004-06-18
4	5809	8808	3	2004-06-18
1	5810	2420	3	2004-06-11
2	5810	2013	2	2004-06-11
3	5810	292	2	2004-06-11
4	5810	9005	1	2004-06-11
5	5810	8844	2	2004-06-11
1	5811	2040	2	2004-06-15
1	5812	1545	3	2004-06-15
1	5813	7426	3	2004-06-04
1	5814	6996	2	2004-06-29
2	5814	7793	3	2004-06-29
1	5815	2964	2	2004-06-01
2	5815	1752	1	2004-06-01
3	5815	5002	2	2004-06-01
4	5815	6257	3	2004-06-01
5	5815	8912	2	2004-06-01
6	5815	135	1	2004-06-01
7	5815	3662	1	2004-06-01
8	5815	242	3	2004-06-01
9	5815	1555	3	2004-06-01
1	5816	3101	1	2004-06-16
2	5816	1433	1	2004-06-16
3	5816	9433	1	2004-06-16
4	5816	7691	3	2004-06-16
5	5816	863	1	2004-06-16
6	5816	2867	1	2004-06-16
7	5816	2274	3	2004-06-16
1	5817	2799	3	2004-06-20
2	5817	5772	2	2004-06-20
3	5817	9250	2	2004-06-20
4	5817	4173	1	2004-06-20
5	5817	3680	3	2004-06-20
1	5818	977	3	2004-06-06
2	5818	5914	1	2004-06-06
3	5818	9698	2	2004-06-06
4	5818	9140	1	2004-06-06
5	5818	4260	1	2004-06-06
1	5819	5064	3	2004-06-10
2	5819	4895	3	2004-06-10
3	5819	5357	1	2004-06-10
4	5819	4323	2	2004-06-10
5	5819	6679	3	2004-06-10
6	5819	5409	1	2004-06-10
7	5819	7773	3	2004-06-10
8	5819	9189	2	2004-06-10
9	5819	2351	1	2004-06-10
1	5820	1870	3	2004-06-07
2	5820	2544	2	2004-06-07
1	5821	5297	3	2004-06-06
2	5821	9139	1	2004-06-06
1	5822	9101	3	2004-06-17
2	5822	8405	2	2004-06-17
3	5822	7893	2	2004-06-17
4	5822	1839	3	2004-06-17
5	5822	491	2	2004-06-17
6	5822	7246	1	2004-06-17
7	5822	2454	3	2004-06-17
8	5822	4760	2	2004-06-17
9	5822	7532	3	2004-06-17
1	5823	841	3	2004-06-02
2	5823	839	3	2004-06-02
3	5823	8508	2	2004-06-02
1	5824	6900	2	2004-06-14
2	5824	8085	2	2004-06-14
3	5824	917	3	2004-06-14
4	5824	1874	1	2004-06-14
1	5825	6938	3	2004-06-13
2	5825	890	2	2004-06-13
3	5825	6245	1	2004-06-13
4	5825	3719	3	2004-06-13
5	5825	4454	2	2004-06-13
6	5825	7584	2	2004-06-13
1	5826	5456	3	2004-06-14
2	5826	2590	1	2004-06-14
3	5826	2792	1	2004-06-14
4	5826	7148	2	2004-06-14
5	5826	598	3	2004-06-14
6	5826	5115	2	2004-06-14
7	5826	8140	3	2004-06-14
8	5826	1278	2	2004-06-14
9	5826	8240	1	2004-06-14
1	5827	3750	3	2004-06-29
2	5827	7825	1	2004-06-29
3	5827	3253	1	2004-06-29
1	5828	3024	2	2004-06-23
2	5828	5235	2	2004-06-23
3	5828	4641	1	2004-06-23
1	5829	9950	3	2004-06-29
2	5829	3936	1	2004-06-29
3	5829	4620	1	2004-06-29
4	5829	3394	2	2004-06-29
5	5829	6659	3	2004-06-29
1	5830	1742	3	2004-06-23
2	5830	7620	3	2004-06-23
3	5830	3085	3	2004-06-23
4	5830	2046	2	2004-06-23
5	5830	2964	3	2004-06-23
1	5831	2843	1	2004-06-06
2	5831	6085	1	2004-06-06
1	5832	2195	3	2004-06-02
2	5832	9391	3	2004-06-02
3	5832	4313	3	2004-06-02
4	5832	9261	3	2004-06-02
5	5832	2078	1	2004-06-02
1	5833	8694	1	2004-06-22
1	5834	9260	3	2004-06-20
2	5834	9850	1	2004-06-20
3	5834	217	2	2004-06-20
4	5834	4894	1	2004-06-20
5	5834	5955	3	2004-06-20
6	5834	6046	3	2004-06-20
7	5834	6325	2	2004-06-20
8	5834	7002	1	2004-06-20
1	5835	7265	3	2004-06-07
2	5835	4032	3	2004-06-07
3	5835	7469	1	2004-06-07
4	5835	9645	2	2004-06-07
1	5836	8291	1	2004-06-14
2	5836	5743	3	2004-06-14
3	5836	8135	1	2004-06-14
4	5836	9329	2	2004-06-14
1	5837	811	3	2004-06-29
2	5837	6511	1	2004-06-29
3	5837	5503	2	2004-06-29
4	5837	7403	1	2004-06-29
5	5837	3418	1	2004-06-29
6	5837	199	1	2004-06-29
1	5838	8981	3	2004-06-13
2	5838	2180	3	2004-06-13
3	5838	9386	3	2004-06-13
4	5838	5778	3	2004-06-13
5	5838	8560	2	2004-06-13
6	5838	1610	3	2004-06-13
7	5838	481	2	2004-06-13
8	5838	3982	1	2004-06-13
1	5839	6812	1	2004-06-10
2	5839	1357	1	2004-06-10
3	5839	3196	1	2004-06-10
4	5839	1115	3	2004-06-10
5	5839	1399	2	2004-06-10
6	5839	5893	1	2004-06-10
7	5839	3135	3	2004-06-10
8	5839	7650	1	2004-06-10
1	5840	8535	1	2004-06-18
2	5840	2662	3	2004-06-18
3	5840	5497	2	2004-06-18
4	5840	307	3	2004-06-18
5	5840	7135	2	2004-06-18
1	5841	4176	3	2004-06-22
2	5841	85	2	2004-06-22
3	5841	6977	1	2004-06-22
4	5841	1239	1	2004-06-22
5	5841	1862	2	2004-06-22
6	5841	943	3	2004-06-22
7	5841	6893	3	2004-06-22
8	5841	2939	3	2004-06-22
1	5842	488	2	2004-06-05
2	5842	797	1	2004-06-05
3	5842	2661	3	2004-06-05
4	5842	5460	3	2004-06-05
1	5843	1510	3	2004-06-06
2	5843	1342	3	2004-06-06
3	5843	9930	1	2004-06-06
4	5843	1357	1	2004-06-06
5	5843	6954	1	2004-06-06
6	5843	1303	2	2004-06-06
1	5844	5715	3	2004-06-28
1	5845	6996	2	2004-06-15
2	5845	3607	1	2004-06-15
3	5845	5930	2	2004-06-15
4	5845	4343	2	2004-06-15
5	5845	1536	2	2004-06-15
6	5845	2741	1	2004-06-15
1	5846	4462	1	2004-06-14
2	5846	7994	2	2004-06-14
3	5846	6258	3	2004-06-14
4	5846	7	3	2004-06-14
5	5846	7956	2	2004-06-14
6	5846	6394	1	2004-06-14
1	5847	5925	1	2004-06-06
2	5847	1374	1	2004-06-06
3	5847	7601	2	2004-06-06
4	5847	6148	3	2004-06-06
5	5847	1569	3	2004-06-06
6	5847	2014	2	2004-06-06
7	5847	1559	3	2004-06-06
8	5847	1602	2	2004-06-06
9	5847	9884	3	2004-06-06
1	5848	3177	2	2004-06-06
2	5848	7512	3	2004-06-06
1	5849	8353	2	2004-06-23
2	5849	8243	3	2004-06-23
3	5849	7178	2	2004-06-23
4	5849	5443	1	2004-06-23
5	5849	4980	3	2004-06-23
6	5849	2214	3	2004-06-23
1	5850	9792	2	2004-06-09
2	5850	4115	1	2004-06-09
3	5850	491	1	2004-06-09
4	5850	3368	2	2004-06-09
5	5850	5720	1	2004-06-09
1	5851	9461	3	2004-06-10
2	5851	7957	3	2004-06-10
3	5851	8392	2	2004-06-10
1	5852	845	1	2004-06-11
2	5852	5519	2	2004-06-11
3	5852	4444	3	2004-06-11
4	5852	8281	2	2004-06-11
5	5852	4334	1	2004-06-11
6	5852	5812	2	2004-06-11
7	5852	3335	3	2004-06-11
8	5852	8491	3	2004-06-11
1	5853	4361	1	2004-06-01
1	5854	7452	1	2004-06-28
2	5854	1261	2	2004-06-28
3	5854	1627	1	2004-06-28
4	5854	6583	3	2004-06-28
5	5854	5867	1	2004-06-28
6	5854	7130	2	2004-06-28
7	5854	5261	1	2004-06-28
1	5855	252	2	2004-06-20
2	5855	8933	1	2004-06-20
3	5855	6504	1	2004-06-20
4	5855	680	1	2004-06-20
5	5855	3173	3	2004-06-20
6	5855	3182	1	2004-06-20
7	5855	7143	1	2004-06-20
8	5855	5828	3	2004-06-20
9	5855	6544	3	2004-06-20
1	5856	4153	1	2004-06-02
2	5856	523	3	2004-06-02
3	5856	3192	3	2004-06-02
4	5856	486	3	2004-06-02
5	5856	6944	1	2004-06-02
6	5856	4254	2	2004-06-02
1	5857	1622	1	2004-06-04
2	5857	1440	2	2004-06-04
1	5858	6986	1	2004-06-10
2	5858	6381	3	2004-06-10
3	5858	5107	1	2004-06-10
4	5858	3869	3	2004-06-10
5	5858	2709	2	2004-06-10
6	5858	8672	2	2004-06-10
7	5858	1457	3	2004-06-10
8	5858	5378	3	2004-06-10
9	5858	9894	3	2004-06-10
1	5859	2665	1	2004-06-13
2	5859	1844	2	2004-06-13
1	5860	3867	3	2004-06-21
2	5860	4228	1	2004-06-21
3	5860	7165	3	2004-06-21
1	5861	5425	3	2004-06-04
2	5861	9836	3	2004-06-04
3	5861	6422	2	2004-06-04
4	5861	5282	2	2004-06-04
1	5862	1031	3	2004-06-15
2	5862	7241	1	2004-06-15
3	5862	4023	2	2004-06-15
4	5862	7815	3	2004-06-15
5	5862	6301	1	2004-06-15
1	5863	9862	1	2004-06-20
2	5863	4579	3	2004-06-20
3	5863	7090	1	2004-06-20
4	5863	5718	3	2004-06-20
1	5864	8454	3	2004-06-21
2	5864	1724	2	2004-06-21
1	5865	5628	3	2004-06-07
2	5865	3506	2	2004-06-07
3	5865	6358	3	2004-06-07
4	5865	5124	1	2004-06-07
5	5865	334	3	2004-06-07
6	5865	6283	1	2004-06-07
7	5865	206	1	2004-06-07
8	5865	8650	3	2004-06-07
9	5865	864	2	2004-06-07
1	5866	9916	2	2004-06-13
2	5866	3339	1	2004-06-13
3	5866	668	2	2004-06-13
4	5866	4393	2	2004-06-13
5	5866	5005	1	2004-06-13
6	5866	5945	3	2004-06-13
1	5867	5040	3	2004-06-11
2	5867	5637	1	2004-06-11
3	5867	8846	2	2004-06-11
4	5867	2183	3	2004-06-11
5	5867	3139	1	2004-06-11
6	5867	1863	3	2004-06-11
7	5867	795	3	2004-06-11
8	5867	3717	1	2004-06-11
1	5868	2607	3	2004-06-10
2	5868	291	3	2004-06-10
3	5868	6761	2	2004-06-10
4	5868	6122	1	2004-06-10
1	5869	3089	2	2004-06-26
2	5869	4898	1	2004-06-26
3	5869	288	3	2004-06-26
4	5869	9430	2	2004-06-26
1	5870	9661	2	2004-06-01
1	5871	6985	2	2004-06-05
2	5871	718	3	2004-06-05
3	5871	1775	3	2004-06-05
4	5871	3511	3	2004-06-05
1	5872	5624	2	2004-06-24
2	5872	953	1	2004-06-24
3	5872	7358	1	2004-06-24
4	5872	7602	3	2004-06-24
5	5872	4665	3	2004-06-24
6	5872	8081	2	2004-06-24
1	5873	730	1	2004-06-26
1	5874	4991	3	2004-06-13
2	5874	2449	3	2004-06-13
3	5874	5339	1	2004-06-13
4	5874	549	3	2004-06-13
5	5874	6657	2	2004-06-13
1	5875	8849	2	2004-06-10
1	5876	8963	1	2004-06-22
2	5876	3063	3	2004-06-22
3	5876	947	2	2004-06-22
4	5876	417	2	2004-06-22
5	5876	1507	2	2004-06-22
1	5877	4998	3	2004-06-01
2	5877	2768	2	2004-06-01
3	5877	6537	3	2004-06-01
1	5878	87	2	2004-06-06
2	5878	2710	3	2004-06-06
3	5878	9395	2	2004-06-06
4	5878	2649	3	2004-06-06
5	5878	5403	2	2004-06-06
6	5878	7269	2	2004-06-06
7	5878	9503	3	2004-06-06
8	5878	1550	1	2004-06-06
1	5879	4340	1	2004-06-12
2	5879	6158	3	2004-06-12
3	5879	8051	1	2004-06-12
4	5879	6532	3	2004-06-12
5	5879	2327	2	2004-06-12
6	5879	8183	1	2004-06-12
7	5879	9447	1	2004-06-12
1	5880	7198	1	2004-06-30
2	5880	8100	2	2004-06-30
3	5880	7376	3	2004-06-30
1	5881	646	2	2004-06-07
2	5881	3213	2	2004-06-07
3	5881	8623	3	2004-06-07
4	5881	2091	3	2004-06-07
5	5881	2065	3	2004-06-07
6	5881	6442	2	2004-06-07
1	5882	5516	2	2004-06-07
2	5882	474	1	2004-06-07
1	5883	2138	3	2004-06-27
2	5883	4634	2	2004-06-27
3	5883	8467	1	2004-06-27
4	5883	208	3	2004-06-27
5	5883	9364	2	2004-06-27
6	5883	4096	3	2004-06-27
7	5883	2791	2	2004-06-27
1	5884	9246	3	2004-06-14
1	5885	2592	3	2004-06-18
2	5885	2378	1	2004-06-18
1	5886	4085	1	2004-06-21
2	5886	3200	1	2004-06-21
3	5886	6434	2	2004-06-21
4	5886	1663	2	2004-06-21
5	5886	6827	2	2004-06-21
6	5886	3783	3	2004-06-21
7	5886	1945	3	2004-06-21
8	5886	4472	3	2004-06-21
9	5886	9541	2	2004-06-21
1	5887	6504	1	2004-06-12
2	5887	1478	3	2004-06-12
3	5887	3881	3	2004-06-12
1	5888	5623	1	2004-06-11
2	5888	60	1	2004-06-11
3	5888	3767	1	2004-06-11
4	5888	7853	1	2004-06-11
5	5888	7480	1	2004-06-11
6	5888	211	3	2004-06-11
7	5888	76	2	2004-06-11
1	5889	4880	3	2004-06-19
2	5889	2300	1	2004-06-19
3	5889	522	2	2004-06-19
4	5889	264	2	2004-06-19
5	5889	2027	2	2004-06-19
6	5889	6838	3	2004-06-19
7	5889	1197	1	2004-06-19
8	5889	9549	1	2004-06-19
9	5889	4517	1	2004-06-19
1	5890	4004	2	2004-06-09
1	5891	3694	3	2004-06-30
2	5891	5981	3	2004-06-30
3	5891	5364	3	2004-06-30
4	5891	9956	2	2004-06-30
5	5891	2057	1	2004-06-30
6	5891	288	2	2004-06-30
1	5892	9585	1	2004-06-12
2	5892	6361	2	2004-06-12
3	5892	6136	3	2004-06-12
4	5892	6470	1	2004-06-12
5	5892	9797	1	2004-06-12
1	5893	5735	3	2004-06-13
2	5893	162	1	2004-06-13
3	5893	6817	2	2004-06-13
1	5894	6992	1	2004-06-30
2	5894	6137	1	2004-06-30
1	5895	2229	1	2004-06-27
2	5895	2506	3	2004-06-27
3	5895	1704	3	2004-06-27
4	5895	8408	1	2004-06-27
5	5895	9448	1	2004-06-27
6	5895	1178	2	2004-06-27
7	5895	5532	3	2004-06-27
8	5895	2242	2	2004-06-27
1	5896	5832	1	2004-06-26
2	5896	678	1	2004-06-26
3	5896	4322	3	2004-06-26
4	5896	3722	1	2004-06-26
5	5896	6223	3	2004-06-26
6	5896	1548	3	2004-06-26
7	5896	2090	2	2004-06-26
8	5896	6816	2	2004-06-26
1	5897	7793	2	2004-06-10
2	5897	6473	1	2004-06-10
3	5897	3382	3	2004-06-10
1	5898	635	2	2004-06-28
1	5899	8126	1	2004-06-09
2	5899	324	2	2004-06-09
3	5899	9875	1	2004-06-09
4	5899	2800	1	2004-06-09
5	5899	5925	3	2004-06-09
6	5899	5756	3	2004-06-09
7	5899	4837	1	2004-06-09
1	5900	5953	1	2004-06-05
2	5900	6616	2	2004-06-05
3	5900	2910	2	2004-06-05
4	5900	5204	2	2004-06-05
5	5900	7994	3	2004-06-05
6	5900	4855	2	2004-06-05
7	5900	5245	1	2004-06-05
8	5900	4570	2	2004-06-05
1	5901	6407	2	2004-06-22
1	5902	3211	2	2004-06-30
2	5902	7208	1	2004-06-30
3	5902	1647	1	2004-06-30
4	5902	1627	3	2004-06-30
5	5902	8130	2	2004-06-30
1	5903	1396	1	2004-06-08
1	5904	2209	1	2004-06-16
2	5904	4076	3	2004-06-16
3	5904	3371	1	2004-06-16
4	5904	3014	1	2004-06-16
5	5904	2646	2	2004-06-16
6	5904	7691	2	2004-06-16
7	5904	9077	2	2004-06-16
8	5904	6583	1	2004-06-16
9	5904	8058	3	2004-06-16
1	5905	9520	1	2004-06-27
2	5905	2278	1	2004-06-27
1	5906	6974	3	2004-06-12
2	5906	2916	1	2004-06-12
3	5906	9413	2	2004-06-12
4	5906	1533	1	2004-06-12
5	5906	9399	2	2004-06-12
6	5906	7757	3	2004-06-12
7	5906	33	3	2004-06-12
8	5906	1987	2	2004-06-12
9	5906	7556	1	2004-06-12
1	5907	8174	2	2004-06-15
2	5907	8395	1	2004-06-15
3	5907	6667	1	2004-06-15
4	5907	7793	2	2004-06-15
5	5907	1826	2	2004-06-15
6	5907	3986	2	2004-06-15
7	5907	5816	2	2004-06-15
1	5908	1525	2	2004-06-04
1	5909	8173	3	2004-06-23
2	5909	9547	1	2004-06-23
3	5909	4510	2	2004-06-23
4	5909	568	1	2004-06-23
5	5909	1530	3	2004-06-23
6	5909	3134	3	2004-06-23
7	5909	1115	1	2004-06-23
8	5909	2418	1	2004-06-23
9	5909	5692	2	2004-06-23
1	5910	8855	2	2004-06-24
2	5910	9137	1	2004-06-24
3	5910	9208	2	2004-06-24
4	5910	1938	3	2004-06-24
5	5910	6155	1	2004-06-24
6	5910	7593	2	2004-06-24
7	5910	3108	1	2004-06-24
8	5910	1480	2	2004-06-24
1	5911	1205	2	2004-06-15
2	5911	8843	2	2004-06-15
3	5911	6692	2	2004-06-15
4	5911	25	2	2004-06-15
5	5911	6042	3	2004-06-15
6	5911	3084	2	2004-06-15
7	5911	5453	1	2004-06-15
8	5911	5276	2	2004-06-15
1	5912	7324	1	2004-06-27
2	5912	730	1	2004-06-27
3	5912	3976	1	2004-06-27
4	5912	4106	3	2004-06-27
5	5912	5219	3	2004-06-27
1	5913	44	3	2004-06-21
2	5913	55	1	2004-06-21
3	5913	1558	2	2004-06-21
4	5913	9895	2	2004-06-21
5	5913	993	2	2004-06-21
1	5914	3482	2	2004-06-21
2	5914	764	1	2004-06-21
3	5914	6164	1	2004-06-21
4	5914	1236	1	2004-06-21
5	5914	3702	2	2004-06-21
6	5914	8900	3	2004-06-21
1	5915	1097	2	2004-06-07
2	5915	9759	1	2004-06-07
3	5915	5455	1	2004-06-07
1	5916	696	1	2004-06-22
2	5916	4508	1	2004-06-22
3	5916	8554	3	2004-06-22
4	5916	4991	3	2004-06-22
5	5916	8794	1	2004-06-22
6	5916	810	1	2004-06-22
7	5916	1295	2	2004-06-22
8	5916	5370	1	2004-06-22
1	5917	27	3	2004-06-11
2	5917	4160	3	2004-06-11
3	5917	8018	3	2004-06-11
4	5917	1102	2	2004-06-11
5	5917	4962	3	2004-06-11
6	5917	3504	2	2004-06-11
7	5917	9878	3	2004-06-11
8	5917	6359	3	2004-06-11
1	5918	2505	3	2004-06-18
2	5918	4822	2	2004-06-18
3	5918	3069	1	2004-06-18
4	5918	3993	2	2004-06-18
5	5918	7644	3	2004-06-18
1	5919	7456	2	2004-06-16
2	5919	9046	3	2004-06-16
3	5919	9910	2	2004-06-16
4	5919	5617	2	2004-06-16
5	5919	9665	2	2004-06-16
6	5919	1424	2	2004-06-16
7	5919	3926	3	2004-06-16
8	5919	7373	1	2004-06-16
9	5919	2216	3	2004-06-16
1	5920	7229	3	2004-06-01
2	5920	9801	2	2004-06-01
3	5920	7432	2	2004-06-01
1	5921	8706	2	2004-06-08
2	5921	8555	3	2004-06-08
3	5921	7559	2	2004-06-08
4	5921	2029	3	2004-06-08
5	5921	9666	2	2004-06-08
6	5921	3246	2	2004-06-08
7	5921	875	1	2004-06-08
8	5921	5266	1	2004-06-08
9	5921	497	2	2004-06-08
1	5922	1841	3	2004-06-01
2	5922	2229	3	2004-06-01
3	5922	3673	2	2004-06-01
4	5922	3332	3	2004-06-01
5	5922	4768	1	2004-06-01
6	5922	1730	1	2004-06-01
7	5922	654	3	2004-06-01
1	5923	6134	3	2004-06-23
2	5923	752	3	2004-06-23
3	5923	377	2	2004-06-23
4	5923	98	1	2004-06-23
5	5923	1515	1	2004-06-23
6	5923	5045	1	2004-06-23
7	5923	7583	3	2004-06-23
1	5924	4581	3	2004-06-27
2	5924	763	3	2004-06-27
3	5924	1527	1	2004-06-27
1	5925	4862	3	2004-06-09
1	5926	8003	3	2004-06-22
2	5926	4092	3	2004-06-22
3	5926	9298	2	2004-06-22
4	5926	8326	2	2004-06-22
5	5926	5919	2	2004-06-22
6	5926	1227	2	2004-06-22
7	5926	5718	3	2004-06-22
8	5926	7415	1	2004-06-22
1	5927	669	1	2004-06-21
2	5927	580	1	2004-06-21
3	5927	2480	2	2004-06-21
4	5927	742	3	2004-06-21
5	5927	6436	3	2004-06-21
6	5927	7878	2	2004-06-21
7	5927	7216	1	2004-06-21
8	5927	2538	2	2004-06-21
1	5928	6771	1	2004-06-23
2	5928	8324	1	2004-06-23
3	5928	9466	2	2004-06-23
4	5928	2787	2	2004-06-23
1	5929	4748	2	2004-06-12
2	5929	7033	3	2004-06-12
3	5929	759	3	2004-06-12
4	5929	7031	3	2004-06-12
5	5929	6565	2	2004-06-12
1	5930	294	2	2004-06-05
2	5930	5032	1	2004-06-05
3	5930	7945	1	2004-06-05
4	5930	3230	2	2004-06-05
1	5931	9034	2	2004-06-13
2	5931	9509	2	2004-06-13
3	5931	502	2	2004-06-13
4	5931	9090	3	2004-06-13
5	5931	1484	3	2004-06-13
6	5931	5309	3	2004-06-13
7	5931	7042	1	2004-06-13
1	5932	2841	2	2004-06-11
1	5933	9674	1	2004-06-15
2	5933	8962	2	2004-06-15
3	5933	3018	1	2004-06-15
1	5934	5823	3	2004-06-04
1	5935	4760	1	2004-06-15
2	5935	4801	1	2004-06-15
3	5935	2102	3	2004-06-15
4	5935	474	3	2004-06-15
5	5935	8521	1	2004-06-15
6	5935	3701	1	2004-06-15
1	5936	1118	2	2004-06-04
1	5937	6187	1	2004-06-15
2	5937	6408	1	2004-06-15
3	5937	163	1	2004-06-15
4	5937	6922	2	2004-06-15
5	5937	7498	1	2004-06-15
6	5937	5313	1	2004-06-15
1	5938	5169	3	2004-06-11
2	5938	7271	3	2004-06-11
3	5938	2312	3	2004-06-11
4	5938	9664	3	2004-06-11
1	5939	4917	3	2004-06-28
2	5939	9999	1	2004-06-28
3	5939	1871	2	2004-06-28
4	5939	3112	1	2004-06-28
1	5940	1715	1	2004-06-23
2	5940	7413	2	2004-06-23
3	5940	9843	3	2004-06-23
4	5940	9154	2	2004-06-23
5	5940	6975	2	2004-06-23
1	5941	7564	2	2004-06-12
2	5941	4324	1	2004-06-12
3	5941	8332	3	2004-06-12
4	5941	9860	3	2004-06-12
1	5942	3765	1	2004-06-02
2	5942	3488	1	2004-06-02
3	5942	7468	2	2004-06-02
4	5942	3311	2	2004-06-02
1	5943	8164	3	2004-06-02
2	5943	5977	1	2004-06-02
3	5943	9076	1	2004-06-02
4	5943	5587	2	2004-06-02
5	5943	5051	3	2004-06-02
6	5943	7405	2	2004-06-02
7	5943	9151	3	2004-06-02
8	5943	1713	3	2004-06-02
9	5943	8996	2	2004-06-02
1	5944	3641	2	2004-06-09
2	5944	1638	3	2004-06-09
3	5944	1150	1	2004-06-09
4	5944	104	2	2004-06-09
5	5944	1591	3	2004-06-09
6	5944	3753	3	2004-06-09
1	5945	9467	2	2004-06-01
2	5945	5809	3	2004-06-01
3	5945	6856	2	2004-06-01
4	5945	4136	3	2004-06-01
5	5945	4451	1	2004-06-01
6	5945	5018	3	2004-06-01
1	5946	89	2	2004-06-18
2	5946	6482	1	2004-06-18
3	5946	7507	2	2004-06-18
4	5946	5202	3	2004-06-18
5	5946	4853	3	2004-06-18
6	5946	6664	2	2004-06-18
7	5946	1783	2	2004-06-18
8	5946	1062	1	2004-06-18
9	5946	8560	3	2004-06-18
1	5947	3984	2	2004-06-25
2	5947	5388	3	2004-06-25
3	5947	3676	1	2004-06-25
1	5948	2978	3	2004-06-09
2	5948	4146	1	2004-06-09
3	5948	3875	3	2004-06-09
1	5949	3891	1	2004-06-29
2	5949	1330	2	2004-06-29
3	5949	1335	3	2004-06-29
4	5949	1822	3	2004-06-29
5	5949	5304	2	2004-06-29
6	5949	1712	3	2004-06-29
1	5950	8378	1	2004-06-30
2	5950	1113	3	2004-06-30
3	5950	4015	2	2004-06-30
4	5950	6475	3	2004-06-30
1	5951	9077	2	2004-06-14
2	5951	399	1	2004-06-14
3	5951	5894	1	2004-06-14
4	5951	7921	3	2004-06-14
1	5952	3392	3	2004-06-05
2	5952	6209	1	2004-06-05
3	5952	5494	2	2004-06-05
4	5952	6925	2	2004-06-05
5	5952	5604	3	2004-06-05
6	5952	3056	3	2004-06-05
7	5952	2127	3	2004-06-05
1	5953	856	3	2004-06-24
2	5953	1096	1	2004-06-24
3	5953	1926	3	2004-06-24
4	5953	2982	3	2004-06-24
5	5953	4217	2	2004-06-24
1	5954	9293	3	2004-06-29
2	5954	6299	2	2004-06-29
3	5954	2224	1	2004-06-29
1	5955	7446	2	2004-06-26
2	5955	1245	2	2004-06-26
1	5956	83	1	2004-06-01
1	5957	1853	1	2004-06-07
2	5957	9776	1	2004-06-07
3	5957	3709	1	2004-06-07
4	5957	4419	1	2004-06-07
5	5957	9023	1	2004-06-07
1	5958	9074	2	2004-06-24
2	5958	8159	2	2004-06-24
3	5958	8587	3	2004-06-24
4	5958	1744	3	2004-06-24
5	5958	528	1	2004-06-24
6	5958	9615	1	2004-06-24
1	5959	6987	2	2004-06-12
2	5959	5264	3	2004-06-12
3	5959	5908	3	2004-06-12
1	5960	1044	3	2004-06-25
2	5960	8327	2	2004-06-25
3	5960	6206	3	2004-06-25
4	5960	184	2	2004-06-25
5	5960	3920	3	2004-06-25
6	5960	3767	2	2004-06-25
7	5960	7442	2	2004-06-25
1	5961	8866	3	2004-06-24
2	5961	4230	2	2004-06-24
1	5962	8465	1	2004-06-06
2	5962	8222	1	2004-06-06
3	5962	7752	3	2004-06-06
4	5962	198	2	2004-06-06
5	5962	4249	2	2004-06-06
6	5962	3479	2	2004-06-06
7	5962	768	3	2004-06-06
8	5962	3201	2	2004-06-06
1	5963	7699	2	2004-06-10
1	5964	2417	1	2004-06-09
2	5964	6478	2	2004-06-09
3	5964	1135	2	2004-06-09
4	5964	5703	3	2004-06-09
5	5964	5379	2	2004-06-09
6	5964	8621	2	2004-06-09
7	5964	9532	1	2004-06-09
1	5965	409	1	2004-06-06
2	5965	7282	2	2004-06-06
3	5965	1143	2	2004-06-06
1	5966	5405	1	2004-06-14
2	5966	4189	3	2004-06-14
3	5966	4330	1	2004-06-14
4	5966	2852	2	2004-06-14
5	5966	5608	3	2004-06-14
6	5966	4820	1	2004-06-14
7	5966	2008	2	2004-06-14
1	5967	4551	2	2004-06-20
2	5967	1290	2	2004-06-20
3	5967	4109	3	2004-06-20
4	5967	8429	2	2004-06-20
5	5967	4682	1	2004-06-20
6	5967	4092	2	2004-06-20
7	5967	81	3	2004-06-20
8	5967	5614	2	2004-06-20
1	5968	5407	1	2004-06-22
1	5969	3666	3	2004-06-27
1	5970	3583	3	2004-06-07
2	5970	1780	3	2004-06-07
3	5970	6495	1	2004-06-07
4	5970	2942	1	2004-06-07
5	5970	3085	3	2004-06-07
6	5970	5698	1	2004-06-07
7	5970	6530	1	2004-06-07
1	5971	4017	2	2004-06-23
2	5971	2912	1	2004-06-23
3	5971	6885	2	2004-06-23
1	5972	525	3	2004-06-11
2	5972	2563	2	2004-06-11
3	5972	7085	2	2004-06-11
4	5972	1797	2	2004-06-11
5	5972	4550	2	2004-06-11
6	5972	4755	3	2004-06-11
1	5973	1762	3	2004-06-06
2	5973	2148	1	2004-06-06
3	5973	604	2	2004-06-06
4	5973	9675	2	2004-06-06
5	5973	8905	2	2004-06-06
6	5973	7954	1	2004-06-06
7	5973	7110	1	2004-06-06
8	5973	8118	3	2004-06-06
1	5974	5022	2	2004-06-29
2	5974	309	3	2004-06-29
3	5974	8275	2	2004-06-29
4	5974	7205	1	2004-06-29
5	5974	5515	3	2004-06-29
6	5974	8346	3	2004-06-29
7	5974	6239	1	2004-06-29
1	5975	358	2	2004-06-01
2	5975	6525	3	2004-06-01
3	5975	7939	2	2004-06-01
4	5975	8795	2	2004-06-01
5	5975	1268	3	2004-06-01
6	5975	6736	1	2004-06-01
7	5975	5170	1	2004-06-01
8	5975	6545	2	2004-06-01
9	5975	1328	2	2004-06-01
1	5976	6537	1	2004-06-02
2	5976	3332	1	2004-06-02
3	5976	3703	2	2004-06-02
4	5976	9618	1	2004-06-02
5	5976	3587	3	2004-06-02
6	5976	5923	1	2004-06-02
1	5977	9917	2	2004-06-25
2	5977	5522	2	2004-06-25
3	5977	8020	1	2004-06-25
4	5977	8409	2	2004-06-25
5	5977	6170	3	2004-06-25
6	5977	9382	3	2004-06-25
7	5977	8268	2	2004-06-25
1	5978	7579	1	2004-06-09
2	5978	9720	3	2004-06-09
3	5978	1519	1	2004-06-09
4	5978	7172	3	2004-06-09
5	5978	3418	2	2004-06-09
6	5978	1303	3	2004-06-09
1	5979	7872	1	2004-06-08
2	5979	8753	2	2004-06-08
3	5979	4756	2	2004-06-08
4	5979	6017	2	2004-06-08
5	5979	1634	2	2004-06-08
6	5979	8384	2	2004-06-08
7	5979	9088	2	2004-06-08
8	5979	498	2	2004-06-08
1	5980	3524	1	2004-06-21
2	5980	5958	3	2004-06-21
3	5980	6493	3	2004-06-21
4	5980	4103	3	2004-06-21
5	5980	8480	2	2004-06-21
6	5980	7093	2	2004-06-21
7	5980	6469	2	2004-06-21
8	5980	2632	1	2004-06-21
1	5981	2932	2	2004-06-03
2	5981	6801	1	2004-06-03
3	5981	9584	3	2004-06-03
1	5982	5096	1	2004-06-27
2	5982	3583	1	2004-06-27
3	5982	7981	1	2004-06-27
1	5983	8360	2	2004-06-25
2	5983	3144	2	2004-06-25
3	5983	2044	2	2004-06-25
4	5983	6053	1	2004-06-25
5	5983	4424	1	2004-06-25
6	5983	5211	3	2004-06-25
7	5983	5159	1	2004-06-25
1	5984	1322	3	2004-06-29
2	5984	609	2	2004-06-29
3	5984	7863	2	2004-06-29
4	5984	7470	2	2004-06-29
5	5984	4266	2	2004-06-29
6	5984	7927	2	2004-06-29
7	5984	2575	2	2004-06-29
8	5984	9571	2	2004-06-29
1	5985	4425	2	2004-06-04
2	5985	8581	3	2004-06-04
3	5985	3275	2	2004-06-04
4	5985	1646	1	2004-06-04
5	5985	8481	1	2004-06-04
6	5985	710	3	2004-06-04
7	5985	7778	1	2004-06-04
1	5986	1484	3	2004-06-19
2	5986	9470	3	2004-06-19
3	5986	3147	1	2004-06-19
4	5986	5697	1	2004-06-19
1	5987	3978	3	2004-06-24
2	5987	5177	1	2004-06-24
3	5987	8390	3	2004-06-24
4	5987	6297	1	2004-06-24
5	5987	1101	2	2004-06-24
6	5987	990	1	2004-06-24
7	5987	4578	3	2004-06-24
8	5987	3130	1	2004-06-24
9	5987	4408	3	2004-06-24
1	5988	5302	1	2004-06-14
2	5988	5999	1	2004-06-14
3	5988	4278	2	2004-06-14
4	5988	7809	3	2004-06-14
1	5989	4344	2	2004-06-10
2	5989	6648	1	2004-06-10
3	5989	5789	3	2004-06-10
4	5989	5418	3	2004-06-10
5	5989	9559	3	2004-06-10
6	5989	5545	1	2004-06-10
7	5989	792	3	2004-06-10
8	5989	1327	2	2004-06-10
1	5990	1301	2	2004-06-18
2	5990	2143	2	2004-06-18
1	5991	1737	1	2004-06-27
2	5991	204	2	2004-06-27
1	5992	4600	1	2004-06-22
2	5992	9870	2	2004-06-22
3	5992	2134	2	2004-06-22
1	5993	8199	1	2004-06-21
2	5993	7912	3	2004-06-21
3	5993	2355	3	2004-06-21
4	5993	2653	2	2004-06-21
5	5993	4791	1	2004-06-21
6	5993	4448	3	2004-06-21
7	5993	3648	2	2004-06-21
8	5993	526	2	2004-06-21
1	5994	919	2	2004-06-07
2	5994	1124	1	2004-06-07
3	5994	9461	1	2004-06-07
4	5994	6202	2	2004-06-07
5	5994	6182	1	2004-06-07
6	5994	4479	2	2004-06-07
7	5994	2778	1	2004-06-07
8	5994	1808	2	2004-06-07
9	5994	1603	2	2004-06-07
1	5995	5369	3	2004-06-29
2	5995	260	2	2004-06-29
3	5995	3599	1	2004-06-29
4	5995	3722	2	2004-06-29
1	5996	5428	3	2004-06-05
2	5996	5892	1	2004-06-05
3	5996	5371	1	2004-06-05
1	5997	2239	3	2004-06-10
2	5997	1107	2	2004-06-10
3	5997	2720	1	2004-06-10
4	5997	234	3	2004-06-10
5	5997	4810	2	2004-06-10
6	5997	8567	2	2004-06-10
1	5998	6466	3	2004-06-05
2	5998	9857	2	2004-06-05
3	5998	1739	2	2004-06-05
4	5998	5134	3	2004-06-05
5	5998	6914	1	2004-06-05
1	5999	6086	1	2004-06-30
2	5999	4416	3	2004-06-30
3	5999	6432	3	2004-06-30
4	5999	7927	2	2004-06-30
5	5999	5955	1	2004-06-30
6	5999	2267	2	2004-06-30
1	6000	8979	1	2004-06-24
2	6000	4504	3	2004-06-24
3	6000	9221	2	2004-06-24
4	6000	4120	2	2004-06-24
5	6000	3872	1	2004-06-24
1	6001	5853	1	2004-07-04
2	6001	4609	3	2004-07-04
3	6001	7550	2	2004-07-04
4	6001	2959	1	2004-07-04
5	6001	7669	1	2004-07-04
6	6001	6906	1	2004-07-04
7	6001	9046	3	2004-07-04
8	6001	3424	3	2004-07-04
9	6001	3864	1	2004-07-04
1	6002	100	1	2004-07-14
2	6002	3881	1	2004-07-14
3	6002	4715	2	2004-07-14
4	6002	9144	2	2004-07-14
5	6002	4544	2	2004-07-14
6	6002	7862	3	2004-07-14
7	6002	4151	2	2004-07-14
8	6002	5156	3	2004-07-14
1	6003	6040	3	2004-07-20
2	6003	2870	3	2004-07-20
3	6003	7214	3	2004-07-20
1	6004	9588	3	2004-07-08
2	6004	1518	2	2004-07-08
3	6004	217	2	2004-07-08
4	6004	8536	3	2004-07-08
5	6004	2646	1	2004-07-08
6	6004	4356	1	2004-07-08
7	6004	2231	3	2004-07-08
8	6004	5918	3	2004-07-08
9	6004	5616	1	2004-07-08
1	6005	2951	3	2004-07-01
2	6005	5714	1	2004-07-01
3	6005	4819	3	2004-07-01
4	6005	1676	2	2004-07-01
5	6005	7020	1	2004-07-01
6	6005	3849	3	2004-07-01
1	6006	3425	3	2004-07-15
2	6006	6345	3	2004-07-15
3	6006	7920	3	2004-07-15
1	6007	5951	2	2004-07-20
2	6007	6663	1	2004-07-20
1	6008	9777	2	2004-07-08
2	6008	6215	1	2004-07-08
3	6008	8353	1	2004-07-08
4	6008	2715	1	2004-07-08
5	6008	1771	3	2004-07-08
6	6008	6267	2	2004-07-08
7	6008	711	3	2004-07-08
8	6008	3952	3	2004-07-08
1	6009	5709	1	2004-07-24
2	6009	5660	1	2004-07-24
3	6009	7764	1	2004-07-24
4	6009	2825	1	2004-07-24
1	6010	6145	2	2004-07-06
2	6010	3163	2	2004-07-06
1	6011	3322	1	2004-07-25
2	6011	6079	2	2004-07-25
3	6011	2658	1	2004-07-25
4	6011	1088	1	2004-07-25
5	6011	1901	3	2004-07-25
6	6011	3887	3	2004-07-25
7	6011	8311	3	2004-07-25
8	6011	9268	2	2004-07-25
9	6011	1869	1	2004-07-25
1	6012	5514	1	2004-07-20
2	6012	9118	3	2004-07-20
3	6012	4811	3	2004-07-20
4	6012	4554	1	2004-07-20
5	6012	6428	3	2004-07-20
1	6013	2536	1	2004-07-14
2	6013	7261	2	2004-07-14
3	6013	9714	1	2004-07-14
4	6013	2046	3	2004-07-14
5	6013	694	1	2004-07-14
6	6013	4098	1	2004-07-14
7	6013	3407	1	2004-07-14
1	6014	7888	2	2004-07-20
2	6014	555	1	2004-07-20
1	6015	2984	3	2004-07-03
2	6015	9878	2	2004-07-03
3	6015	5813	1	2004-07-03
4	6015	7887	1	2004-07-03
5	6015	6850	3	2004-07-03
6	6015	4220	3	2004-07-03
7	6015	5625	2	2004-07-03
1	6016	80	2	2004-07-01
2	6016	1190	2	2004-07-01
3	6016	5716	3	2004-07-01
4	6016	9076	2	2004-07-01
1	6017	7392	2	2004-07-06
2	6017	4662	3	2004-07-06
3	6017	9254	1	2004-07-06
4	6017	9683	3	2004-07-06
5	6017	3547	2	2004-07-06
6	6017	4741	3	2004-07-06
1	6018	88	1	2004-07-17
2	6018	9250	1	2004-07-17
3	6018	3989	1	2004-07-17
4	6018	5187	3	2004-07-17
5	6018	9516	2	2004-07-17
6	6018	5974	1	2004-07-17
1	6019	1714	1	2004-07-14
2	6019	8942	1	2004-07-14
1	6020	5157	1	2004-07-08
2	6020	3717	1	2004-07-08
3	6020	3214	2	2004-07-08
4	6020	6219	1	2004-07-08
5	6020	6545	2	2004-07-08
6	6020	3468	1	2004-07-08
1	6021	2915	2	2004-07-19
2	6021	6713	3	2004-07-19
3	6021	3562	2	2004-07-19
4	6021	8870	2	2004-07-19
5	6021	5916	3	2004-07-19
1	6022	4273	1	2004-07-20
2	6022	7198	3	2004-07-20
3	6022	2176	1	2004-07-20
4	6022	4384	3	2004-07-20
1	6023	1461	3	2004-07-12
2	6023	5832	1	2004-07-12
3	6023	5195	3	2004-07-12
4	6023	7908	1	2004-07-12
5	6023	5943	1	2004-07-12
6	6023	5891	2	2004-07-12
7	6023	6745	1	2004-07-12
1	6024	7337	2	2004-07-09
2	6024	651	2	2004-07-09
3	6024	2388	1	2004-07-09
4	6024	4946	3	2004-07-09
5	6024	1221	3	2004-07-09
6	6024	7699	2	2004-07-09
7	6024	5835	3	2004-07-09
8	6024	4855	1	2004-07-09
9	6024	857	1	2004-07-09
1	6025	233	3	2004-07-02
2	6025	1166	3	2004-07-02
3	6025	9652	2	2004-07-02
4	6025	9964	3	2004-07-02
5	6025	2847	3	2004-07-02
6	6025	4177	2	2004-07-02
1	6026	3335	3	2004-07-06
2	6026	5437	1	2004-07-06
3	6026	2628	1	2004-07-06
4	6026	193	3	2004-07-06
5	6026	2936	1	2004-07-06
6	6026	7530	2	2004-07-06
7	6026	9813	3	2004-07-06
1	6027	7022	3	2004-07-31
1	6028	4286	1	2004-07-15
2	6028	999	2	2004-07-15
3	6028	7500	3	2004-07-15
4	6028	2901	1	2004-07-15
5	6028	4866	3	2004-07-15
6	6028	1868	3	2004-07-15
7	6028	9608	1	2004-07-15
1	6029	5891	1	2004-07-16
2	6029	1989	2	2004-07-16
3	6029	2967	3	2004-07-16
1	6030	6975	1	2004-07-21
1	6031	7381	1	2004-07-27
2	6031	6932	1	2004-07-27
3	6031	2332	1	2004-07-27
4	6031	8620	2	2004-07-27
5	6031	9289	3	2004-07-27
6	6031	6260	2	2004-07-27
7	6031	770	3	2004-07-27
8	6031	6766	2	2004-07-27
9	6031	2290	3	2004-07-27
1	6032	5246	2	2004-07-07
2	6032	9818	1	2004-07-07
3	6032	7435	3	2004-07-07
4	6032	3480	1	2004-07-07
5	6032	8040	1	2004-07-07
6	6032	2929	2	2004-07-07
7	6032	1143	2	2004-07-07
8	6032	6768	3	2004-07-07
1	6033	319	3	2004-07-30
2	6033	5087	3	2004-07-30
3	6033	5418	3	2004-07-30
4	6033	5837	3	2004-07-30
5	6033	2634	2	2004-07-30
6	6033	6376	3	2004-07-30
1	6034	4623	2	2004-07-26
2	6034	7150	1	2004-07-26
3	6034	4438	1	2004-07-26
4	6034	7634	2	2004-07-26
5	6034	5339	2	2004-07-26
6	6034	5342	2	2004-07-26
1	6035	2087	2	2004-07-02
1	6036	5172	2	2004-07-25
2	6036	7603	1	2004-07-25
3	6036	3492	2	2004-07-25
4	6036	7741	2	2004-07-25
1	6037	5026	1	2004-07-05
2	6037	8831	1	2004-07-05
3	6037	7184	2	2004-07-05
4	6037	7060	1	2004-07-05
5	6037	8967	3	2004-07-05
6	6037	5854	3	2004-07-05
7	6037	8292	3	2004-07-05
8	6037	5086	2	2004-07-05
1	6038	3679	3	2004-07-17
1	6039	759	2	2004-07-07
2	6039	2266	3	2004-07-07
3	6039	3687	3	2004-07-07
4	6039	9529	1	2004-07-07
5	6039	9950	3	2004-07-07
6	6039	6686	3	2004-07-07
7	6039	9237	2	2004-07-07
8	6039	4526	2	2004-07-07
9	6039	5135	1	2004-07-07
1	6040	8286	3	2004-07-10
2	6040	9089	1	2004-07-10
3	6040	6259	1	2004-07-10
4	6040	9135	3	2004-07-10
5	6040	1154	3	2004-07-10
6	6040	4525	2	2004-07-10
7	6040	7818	3	2004-07-10
8	6040	710	3	2004-07-10
1	6041	7669	1	2004-07-03
2	6041	3065	1	2004-07-03
3	6041	8384	3	2004-07-03
4	6041	5012	1	2004-07-03
5	6041	8420	2	2004-07-03
6	6041	9885	3	2004-07-03
7	6041	2790	3	2004-07-03
1	6042	8638	1	2004-07-27
2	6042	7697	1	2004-07-27
3	6042	4797	2	2004-07-27
4	6042	1374	2	2004-07-27
5	6042	2860	1	2004-07-27
6	6042	6165	3	2004-07-27
7	6042	9515	2	2004-07-27
8	6042	212	1	2004-07-27
1	6043	7	3	2004-07-19
1	6044	8865	2	2004-07-16
2	6044	6854	3	2004-07-16
3	6044	2378	2	2004-07-16
4	6044	466	1	2004-07-16
5	6044	8655	2	2004-07-16
6	6044	5589	1	2004-07-16
7	6044	768	3	2004-07-16
8	6044	2130	3	2004-07-16
1	6045	4223	3	2004-07-17
2	6045	4172	2	2004-07-17
3	6045	7832	2	2004-07-17
4	6045	4199	1	2004-07-17
5	6045	4071	1	2004-07-17
6	6045	655	1	2004-07-17
1	6046	3000	1	2004-07-15
2	6046	7128	1	2004-07-15
3	6046	7752	1	2004-07-15
4	6046	1682	3	2004-07-15
5	6046	1165	2	2004-07-15
6	6046	5451	2	2004-07-15
7	6046	5455	2	2004-07-15
1	6047	4678	1	2004-07-07
2	6047	459	3	2004-07-07
3	6047	3688	2	2004-07-07
4	6047	8978	2	2004-07-07
5	6047	7465	2	2004-07-07
6	6047	1850	3	2004-07-07
1	6048	6503	3	2004-07-03
2	6048	549	3	2004-07-03
3	6048	8249	1	2004-07-03
4	6048	1995	2	2004-07-03
5	6048	8243	3	2004-07-03
6	6048	9916	1	2004-07-03
7	6048	7125	1	2004-07-03
8	6048	6630	1	2004-07-03
1	6049	1618	3	2004-07-12
2	6049	1795	3	2004-07-12
3	6049	3309	2	2004-07-12
4	6049	8571	2	2004-07-12
5	6049	8494	1	2004-07-12
6	6049	1848	2	2004-07-12
7	6049	279	1	2004-07-12
1	6050	2226	1	2004-07-10
2	6050	2622	1	2004-07-10
3	6050	2702	3	2004-07-10
4	6050	5066	3	2004-07-10
5	6050	1549	3	2004-07-10
1	6051	1881	3	2004-07-20
2	6051	7119	2	2004-07-20
3	6051	1722	2	2004-07-20
4	6051	9204	1	2004-07-20
5	6051	6237	1	2004-07-20
6	6051	5210	2	2004-07-20
7	6051	3446	3	2004-07-20
8	6051	5042	3	2004-07-20
1	6052	9408	1	2004-07-12
2	6052	5930	2	2004-07-12
3	6052	1939	3	2004-07-12
4	6052	3303	3	2004-07-12
5	6052	9704	3	2004-07-12
6	6052	6395	1	2004-07-12
1	6053	9202	2	2004-07-24
2	6053	9598	2	2004-07-24
3	6053	7027	2	2004-07-24
4	6053	1954	1	2004-07-24
5	6053	3197	3	2004-07-24
6	6053	8027	3	2004-07-24
7	6053	4261	3	2004-07-24
8	6053	2942	2	2004-07-24
9	6053	540	3	2004-07-24
1	6054	836	2	2004-07-26
2	6054	1029	3	2004-07-26
1	6055	8076	3	2004-07-24
2	6055	385	3	2004-07-24
3	6055	5383	3	2004-07-24
4	6055	2481	3	2004-07-24
1	6056	2435	3	2004-07-25
2	6056	3843	2	2004-07-25
3	6056	2258	2	2004-07-25
4	6056	4248	1	2004-07-25
5	6056	6860	1	2004-07-25
6	6056	1842	3	2004-07-25
1	6057	1562	2	2004-07-21
2	6057	8691	3	2004-07-21
3	6057	5612	3	2004-07-21
4	6057	7310	1	2004-07-21
1	6058	5467	1	2004-07-21
2	6058	281	3	2004-07-21
3	6058	1248	2	2004-07-21
4	6058	3279	2	2004-07-21
1	6059	8121	2	2004-07-27
2	6059	3059	2	2004-07-27
3	6059	8616	3	2004-07-27
4	6059	9051	1	2004-07-27
5	6059	3651	3	2004-07-27
1	6060	255	1	2004-07-31
2	6060	6914	3	2004-07-31
3	6060	7674	1	2004-07-31
4	6060	1242	3	2004-07-31
5	6060	283	1	2004-07-31
6	6060	2078	2	2004-07-31
7	6060	5994	1	2004-07-31
1	6061	5642	3	2004-07-04
2	6061	3976	2	2004-07-04
3	6061	6987	1	2004-07-04
4	6061	4434	1	2004-07-04
5	6061	766	2	2004-07-04
6	6061	9899	3	2004-07-04
7	6061	1372	1	2004-07-04
8	6061	885	3	2004-07-04
9	6061	8737	3	2004-07-04
1	6062	2467	3	2004-07-03
1	6063	8358	2	2004-07-14
2	6063	4803	2	2004-07-14
3	6063	4122	3	2004-07-14
4	6063	8257	1	2004-07-14
5	6063	1803	1	2004-07-14
6	6063	1745	1	2004-07-14
1	6064	1797	1	2004-07-22
2	6064	6594	1	2004-07-22
3	6064	9594	3	2004-07-22
4	6064	512	2	2004-07-22
5	6064	8208	1	2004-07-22
6	6064	4697	1	2004-07-22
7	6064	1439	2	2004-07-22
8	6064	8313	3	2004-07-22
1	6065	1893	1	2004-07-28
2	6065	4214	2	2004-07-28
3	6065	4742	2	2004-07-28
1	6066	9989	3	2004-07-20
2	6066	7450	2	2004-07-20
3	6066	9933	3	2004-07-20
4	6066	3842	1	2004-07-20
5	6066	3151	1	2004-07-20
6	6066	3422	3	2004-07-20
1	6067	4656	1	2004-07-15
2	6067	6195	3	2004-07-15
3	6067	3806	3	2004-07-15
1	6068	3978	3	2004-07-02
2	6068	6923	1	2004-07-02
3	6068	4460	3	2004-07-02
4	6068	979	1	2004-07-02
5	6068	3494	1	2004-07-02
1	6069	9386	2	2004-07-28
2	6069	9951	2	2004-07-28
1	6070	2364	2	2004-07-30
2	6070	2743	2	2004-07-30
3	6070	1512	1	2004-07-30
4	6070	4189	1	2004-07-30
1	6071	9747	2	2004-07-27
2	6071	2322	1	2004-07-27
3	6071	7709	2	2004-07-27
4	6071	1637	2	2004-07-27
5	6071	3151	1	2004-07-27
1	6072	6688	3	2004-07-28
2	6072	381	2	2004-07-28
3	6072	1699	1	2004-07-28
4	6072	7344	2	2004-07-28
5	6072	8913	3	2004-07-28
6	6072	7686	1	2004-07-28
7	6072	2149	2	2004-07-28
8	6072	1268	2	2004-07-28
1	6073	1739	3	2004-07-05
2	6073	9720	2	2004-07-05
3	6073	3657	1	2004-07-05
4	6073	6367	1	2004-07-05
1	6074	1541	1	2004-07-17
2	6074	6011	1	2004-07-17
1	6075	2209	2	2004-07-14
2	6075	6277	2	2004-07-14
3	6075	1540	3	2004-07-14
1	6076	7029	1	2004-07-25
2	6076	4125	3	2004-07-25
3	6076	3670	3	2004-07-25
4	6076	9618	1	2004-07-25
5	6076	204	2	2004-07-25
6	6076	4172	1	2004-07-25
7	6076	7115	2	2004-07-25
1	6077	6478	2	2004-07-09
2	6077	300	3	2004-07-09
3	6077	1998	2	2004-07-09
4	6077	3043	2	2004-07-09
5	6077	4120	1	2004-07-09
6	6077	6661	1	2004-07-09
7	6077	8016	2	2004-07-09
1	6078	9921	1	2004-07-10
2	6078	6677	1	2004-07-10
3	6078	5076	1	2004-07-10
4	6078	1467	1	2004-07-10
5	6078	6561	2	2004-07-10
6	6078	5314	2	2004-07-10
1	6079	477	2	2004-07-05
2	6079	8328	2	2004-07-05
1	6080	5123	1	2004-07-24
2	6080	8028	3	2004-07-24
3	6080	4561	3	2004-07-24
4	6080	4735	2	2004-07-24
1	6081	2260	2	2004-07-27
2	6081	5783	3	2004-07-27
3	6081	401	1	2004-07-27
4	6081	4331	1	2004-07-27
1	6082	616	1	2004-07-09
2	6082	6884	3	2004-07-09
3	6082	4379	1	2004-07-09
4	6082	2633	3	2004-07-09
1	6083	9124	1	2004-07-12
2	6083	2751	3	2004-07-12
3	6083	3741	3	2004-07-12
4	6083	1234	2	2004-07-12
5	6083	3429	3	2004-07-12
6	6083	4819	2	2004-07-12
7	6083	8112	3	2004-07-12
8	6083	5682	1	2004-07-12
1	6084	1217	1	2004-07-18
2	6084	4533	2	2004-07-18
3	6084	2537	3	2004-07-18
4	6084	5096	2	2004-07-18
5	6084	7825	1	2004-07-18
6	6084	4515	3	2004-07-18
1	6085	4621	2	2004-07-16
2	6085	4761	3	2004-07-16
3	6085	2838	3	2004-07-16
4	6085	1879	1	2004-07-16
5	6085	8730	3	2004-07-16
6	6085	1949	2	2004-07-16
7	6085	6845	2	2004-07-16
8	6085	591	3	2004-07-16
1	6086	2288	3	2004-07-24
1	6087	7061	2	2004-07-20
1	6088	7471	3	2004-07-26
2	6088	793	1	2004-07-26
3	6088	9563	1	2004-07-26
1	6089	2645	3	2004-07-04
2	6089	9519	1	2004-07-04
3	6089	5137	3	2004-07-04
1	6090	7543	2	2004-07-26
1	6091	5446	1	2004-07-03
2	6091	9468	1	2004-07-03
3	6091	5242	3	2004-07-03
4	6091	651	2	2004-07-03
5	6091	7247	1	2004-07-03
6	6091	8706	3	2004-07-03
7	6091	8506	3	2004-07-03
8	6091	1710	1	2004-07-03
1	6092	8308	1	2004-07-19
2	6092	9940	2	2004-07-19
1	6093	6467	2	2004-07-11
2	6093	1967	1	2004-07-11
3	6093	5879	1	2004-07-11
4	6093	2581	1	2004-07-11
1	6094	3445	2	2004-07-26
2	6094	4124	1	2004-07-26
3	6094	4795	2	2004-07-26
4	6094	3101	1	2004-07-26
5	6094	7060	3	2004-07-26
6	6094	1953	2	2004-07-26
1	6095	9374	3	2004-07-01
2	6095	7769	2	2004-07-01
3	6095	3233	3	2004-07-01
4	6095	7753	3	2004-07-01
1	6096	3563	3	2004-07-04
2	6096	5163	3	2004-07-04
3	6096	3246	3	2004-07-04
4	6096	8958	3	2004-07-04
5	6096	5118	1	2004-07-04
6	6096	8846	1	2004-07-04
7	6096	9545	1	2004-07-04
8	6096	7545	3	2004-07-04
9	6096	2690	3	2004-07-04
1	6097	7904	1	2004-07-11
2	6097	897	2	2004-07-11
1	6098	1610	3	2004-07-02
1	6099	6058	2	2004-07-26
2	6099	9496	1	2004-07-26
1	6100	9140	1	2004-07-24
2	6100	6893	1	2004-07-24
3	6100	9293	1	2004-07-24
4	6100	3893	3	2004-07-24
5	6100	1448	1	2004-07-24
6	6100	9023	1	2004-07-24
7	6100	7452	3	2004-07-24
1	6101	2990	3	2004-07-14
2	6101	2793	3	2004-07-14
3	6101	105	3	2004-07-14
4	6101	5064	3	2004-07-14
5	6101	25	1	2004-07-14
6	6101	7941	2	2004-07-14
1	6102	8909	2	2004-07-31
2	6102	6934	1	2004-07-31
3	6102	1109	3	2004-07-31
4	6102	4598	1	2004-07-31
5	6102	726	1	2004-07-31
6	6102	9747	2	2004-07-31
1	6103	8835	2	2004-07-18
2	6103	8026	3	2004-07-18
3	6103	2799	1	2004-07-18
4	6103	8540	1	2004-07-18
5	6103	5727	2	2004-07-18
6	6103	6202	2	2004-07-18
7	6103	3560	1	2004-07-18
8	6103	2130	1	2004-07-18
1	6104	7445	3	2004-07-13
2	6104	5284	3	2004-07-13
3	6104	1917	2	2004-07-13
4	6104	3307	3	2004-07-13
5	6104	5215	2	2004-07-13
1	6105	2989	1	2004-07-19
2	6105	6997	1	2004-07-19
3	6105	4035	1	2004-07-19
4	6105	8008	1	2004-07-19
1	6106	4036	2	2004-07-26
1	6107	9173	2	2004-07-30
2	6107	5012	1	2004-07-30
3	6107	221	3	2004-07-30
4	6107	8494	2	2004-07-30
5	6107	2781	2	2004-07-30
6	6107	9485	1	2004-07-30
7	6107	8283	1	2004-07-30
1	6108	8002	1	2004-07-08
2	6108	6674	2	2004-07-08
3	6108	3577	3	2004-07-08
4	6108	6541	3	2004-07-08
5	6108	2141	2	2004-07-08
6	6108	6918	1	2004-07-08
1	6109	7179	3	2004-07-09
2	6109	6110	2	2004-07-09
3	6109	2894	3	2004-07-09
4	6109	47	1	2004-07-09
5	6109	83	3	2004-07-09
6	6109	4852	1	2004-07-09
7	6109	3609	3	2004-07-09
8	6109	8923	1	2004-07-09
1	6110	2981	2	2004-07-03
2	6110	2051	2	2004-07-03
3	6110	296	3	2004-07-03
4	6110	7169	1	2004-07-03
1	6111	1867	3	2004-07-16
2	6111	7907	2	2004-07-16
3	6111	5867	3	2004-07-16
1	6112	8434	3	2004-07-23
2	6112	845	3	2004-07-23
1	6113	6145	2	2004-07-05
2	6113	3673	3	2004-07-05
3	6113	1053	2	2004-07-05
4	6113	7163	3	2004-07-05
5	6113	7044	1	2004-07-05
6	6113	2630	3	2004-07-05
7	6113	4455	2	2004-07-05
8	6113	4888	1	2004-07-05
9	6113	9258	1	2004-07-05
1	6114	8388	2	2004-07-01
2	6114	6489	3	2004-07-01
3	6114	2492	3	2004-07-01
4	6114	939	2	2004-07-01
5	6114	7305	3	2004-07-01
6	6114	1376	1	2004-07-01
1	6115	651	1	2004-07-17
2	6115	4661	1	2004-07-17
3	6115	9899	3	2004-07-17
1	6116	5540	1	2004-07-25
2	6116	3431	1	2004-07-25
3	6116	8389	1	2004-07-25
4	6116	7378	2	2004-07-25
5	6116	1050	3	2004-07-25
6	6116	2866	1	2004-07-25
7	6116	5313	1	2004-07-25
1	6117	9117	2	2004-07-29
2	6117	6790	3	2004-07-29
3	6117	8080	1	2004-07-29
4	6117	3047	3	2004-07-29
1	6118	7857	3	2004-07-02
2	6118	3833	1	2004-07-02
1	6119	7099	2	2004-07-02
2	6119	7793	3	2004-07-02
3	6119	6141	1	2004-07-02
4	6119	133	2	2004-07-02
5	6119	9794	1	2004-07-02
6	6119	9561	3	2004-07-02
7	6119	7371	2	2004-07-02
8	6119	8677	2	2004-07-02
1	6120	2546	2	2004-07-25
2	6120	407	1	2004-07-25
3	6120	4497	2	2004-07-25
4	6120	1689	2	2004-07-25
5	6120	6461	2	2004-07-25
6	6120	2966	2	2004-07-25
7	6120	8945	1	2004-07-25
8	6120	3523	2	2004-07-25
1	6121	4936	3	2004-07-12
2	6121	2568	1	2004-07-12
3	6121	6207	1	2004-07-12
4	6121	7756	2	2004-07-12
1	6122	7376	1	2004-07-10
2	6122	5914	1	2004-07-10
3	6122	7018	3	2004-07-10
4	6122	6915	2	2004-07-10
5	6122	2394	3	2004-07-10
1	6123	6425	2	2004-07-22
1	6124	6578	1	2004-07-14
2	6124	1458	1	2004-07-14
3	6124	1972	3	2004-07-14
4	6124	6791	2	2004-07-14
5	6124	396	3	2004-07-14
6	6124	450	3	2004-07-14
7	6124	1941	2	2004-07-14
8	6124	9645	3	2004-07-14
9	6124	3966	2	2004-07-14
1	6125	7699	3	2004-07-08
2	6125	34	2	2004-07-08
3	6125	1583	2	2004-07-08
4	6125	845	3	2004-07-08
5	6125	3402	3	2004-07-08
6	6125	472	2	2004-07-08
7	6125	207	1	2004-07-08
8	6125	4071	3	2004-07-08
9	6125	7380	2	2004-07-08
1	6126	4194	1	2004-07-20
2	6126	7058	3	2004-07-20
3	6126	8442	3	2004-07-20
4	6126	4519	2	2004-07-20
5	6126	8966	1	2004-07-20
6	6126	1961	3	2004-07-20
7	6126	6340	2	2004-07-20
8	6126	3250	3	2004-07-20
1	6127	1509	2	2004-07-11
2	6127	6200	2	2004-07-11
3	6127	1810	2	2004-07-11
4	6127	47	3	2004-07-11
1	6128	4168	1	2004-07-05
2	6128	3762	1	2004-07-05
3	6128	2620	3	2004-07-05
4	6128	7490	1	2004-07-05
5	6128	497	3	2004-07-05
6	6128	585	3	2004-07-05
1	6129	484	3	2004-07-10
2	6129	37	1	2004-07-10
3	6129	3437	2	2004-07-10
4	6129	7572	2	2004-07-10
5	6129	9817	3	2004-07-10
6	6129	3215	1	2004-07-10
1	6130	2410	1	2004-07-31
2	6130	6679	2	2004-07-31
3	6130	8870	2	2004-07-31
4	6130	6615	3	2004-07-31
1	6131	1033	1	2004-07-12
2	6131	2891	1	2004-07-12
3	6131	8845	1	2004-07-12
4	6131	3509	1	2004-07-12
5	6131	9165	1	2004-07-12
6	6131	7527	3	2004-07-12
1	6132	25	3	2004-07-27
2	6132	2672	1	2004-07-27
3	6132	7626	3	2004-07-27
4	6132	7463	2	2004-07-27
5	6132	3519	2	2004-07-27
6	6132	5860	3	2004-07-27
7	6132	1276	1	2004-07-27
8	6132	3748	1	2004-07-27
1	6133	9567	3	2004-07-08
2	6133	3408	3	2004-07-08
1	6134	1676	3	2004-07-27
2	6134	5713	1	2004-07-27
3	6134	4956	3	2004-07-27
4	6134	4134	1	2004-07-27
5	6134	7734	1	2004-07-27
6	6134	9075	1	2004-07-27
7	6134	5674	2	2004-07-27
1	6135	9256	3	2004-07-27
2	6135	8775	1	2004-07-27
1	6136	7073	3	2004-07-02
2	6136	4746	2	2004-07-02
3	6136	5934	2	2004-07-02
4	6136	2706	1	2004-07-02
1	6137	241	3	2004-07-26
2	6137	3852	3	2004-07-26
3	6137	9016	3	2004-07-26
1	6138	9540	2	2004-07-14
2	6138	524	3	2004-07-14
1	6139	4738	2	2004-07-28
2	6139	8043	3	2004-07-28
3	6139	8515	2	2004-07-28
4	6139	5904	1	2004-07-28
5	6139	5623	2	2004-07-28
6	6139	8880	2	2004-07-28
7	6139	6280	3	2004-07-28
8	6139	3416	1	2004-07-28
9	6139	8437	1	2004-07-28
1	6140	3933	3	2004-07-30
2	6140	1858	2	2004-07-30
3	6140	7690	1	2004-07-30
4	6140	5383	2	2004-07-30
5	6140	9884	1	2004-07-30
6	6140	8075	3	2004-07-30
1	6141	7809	3	2004-07-30
2	6141	9532	3	2004-07-30
3	6141	3177	2	2004-07-30
4	6141	5810	2	2004-07-30
5	6141	5943	2	2004-07-30
1	6142	1727	1	2004-07-28
2	6142	8233	2	2004-07-28
3	6142	5322	2	2004-07-28
4	6142	4249	1	2004-07-28
5	6142	269	2	2004-07-28
6	6142	824	3	2004-07-28
7	6142	2058	1	2004-07-28
8	6142	4933	2	2004-07-28
1	6143	9431	2	2004-07-19
2	6143	1275	2	2004-07-19
3	6143	1252	3	2004-07-19
4	6143	9486	1	2004-07-19
5	6143	2815	2	2004-07-19
1	6144	8124	1	2004-07-29
2	6144	3288	1	2004-07-29
3	6144	3308	2	2004-07-29
4	6144	6504	2	2004-07-29
5	6144	1900	3	2004-07-29
6	6144	4558	3	2004-07-29
7	6144	2522	1	2004-07-29
1	6145	8666	3	2004-07-30
2	6145	4243	3	2004-07-30
3	6145	4445	2	2004-07-30
4	6145	193	3	2004-07-30
5	6145	146	3	2004-07-30
6	6145	1800	3	2004-07-30
7	6145	6691	3	2004-07-30
8	6145	31	3	2004-07-30
9	6145	2295	2	2004-07-30
1	6146	7360	1	2004-07-11
2	6146	2266	3	2004-07-11
3	6146	2516	1	2004-07-11
4	6146	3887	3	2004-07-11
5	6146	842	1	2004-07-11
1	6147	8813	1	2004-07-18
1	6148	6386	3	2004-07-23
2	6148	9123	2	2004-07-23
3	6148	8657	1	2004-07-23
4	6148	9754	1	2004-07-23
5	6148	216	3	2004-07-23
6	6148	7625	3	2004-07-23
7	6148	9249	3	2004-07-23
8	6148	7457	1	2004-07-23
9	6148	1728	1	2004-07-23
1	6149	7655	2	2004-07-01
2	6149	6073	2	2004-07-01
3	6149	9027	2	2004-07-01
4	6149	5425	1	2004-07-01
5	6149	2674	1	2004-07-01
6	6149	9691	1	2004-07-01
1	6150	538	2	2004-07-26
2	6150	5202	3	2004-07-26
3	6150	1006	2	2004-07-26
4	6150	8052	3	2004-07-26
5	6150	6216	3	2004-07-26
6	6150	9806	2	2004-07-26
7	6150	2349	2	2004-07-26
8	6150	2381	1	2004-07-26
1	6151	1927	1	2004-07-01
2	6151	107	2	2004-07-01
3	6151	3703	3	2004-07-01
4	6151	6397	1	2004-07-01
5	6151	8144	3	2004-07-01
6	6151	9907	3	2004-07-01
7	6151	3041	2	2004-07-01
8	6151	6843	2	2004-07-01
9	6151	9560	2	2004-07-01
1	6152	2225	3	2004-07-08
2	6152	6015	2	2004-07-08
3	6152	7026	2	2004-07-08
1	6153	5390	2	2004-07-10
2	6153	9585	3	2004-07-10
3	6153	5077	2	2004-07-10
4	6153	1020	1	2004-07-10
5	6153	5592	1	2004-07-10
1	6154	2677	2	2004-07-06
2	6154	3639	2	2004-07-06
3	6154	1371	3	2004-07-06
4	6154	7498	2	2004-07-06
5	6154	5336	2	2004-07-06
6	6154	8200	1	2004-07-06
7	6154	9593	1	2004-07-06
8	6154	5857	2	2004-07-06
1	6155	338	2	2004-07-20
2	6155	1808	1	2004-07-20
3	6155	8343	3	2004-07-20
4	6155	2285	1	2004-07-20
5	6155	6030	3	2004-07-20
6	6155	8989	3	2004-07-20
1	6156	940	1	2004-07-13
2	6156	8881	2	2004-07-13
3	6156	4899	3	2004-07-13
4	6156	8637	2	2004-07-13
5	6156	8339	2	2004-07-13
1	6157	407	2	2004-07-29
2	6157	4425	1	2004-07-29
3	6157	7436	1	2004-07-29
4	6157	9613	3	2004-07-29
5	6157	3012	2	2004-07-29
6	6157	8040	1	2004-07-29
7	6157	4348	1	2004-07-29
8	6157	4627	3	2004-07-29
9	6157	7241	2	2004-07-29
1	6158	3202	1	2004-07-30
2	6158	9015	1	2004-07-30
3	6158	4972	3	2004-07-30
4	6158	6121	1	2004-07-30
5	6158	7574	2	2004-07-30
1	6159	4766	3	2004-07-22
2	6159	3944	3	2004-07-22
3	6159	3996	1	2004-07-22
4	6159	9777	3	2004-07-22
1	6160	9971	2	2004-07-13
2	6160	7300	1	2004-07-13
1	6161	2041	3	2004-07-03
2	6161	8015	3	2004-07-03
3	6161	7975	2	2004-07-03
4	6161	4688	2	2004-07-03
5	6161	7587	2	2004-07-03
6	6161	8986	1	2004-07-03
7	6161	1782	1	2004-07-03
8	6161	130	2	2004-07-03
9	6161	4912	3	2004-07-03
1	6162	29	2	2004-07-13
1	6163	7829	3	2004-07-22
2	6163	7381	3	2004-07-22
3	6163	5648	2	2004-07-22
4	6163	8030	2	2004-07-22
5	6163	984	1	2004-07-22
6	6163	8385	3	2004-07-22
7	6163	6147	3	2004-07-22
1	6164	3706	2	2004-07-03
1	6165	8528	2	2004-07-03
2	6165	9548	2	2004-07-03
3	6165	1417	2	2004-07-03
4	6165	3072	3	2004-07-03
5	6165	4026	1	2004-07-03
1	6166	3296	3	2004-07-29
2	6166	9863	1	2004-07-29
3	6166	5400	2	2004-07-29
4	6166	9051	2	2004-07-29
5	6166	3936	3	2004-07-29
6	6166	7372	3	2004-07-29
7	6166	4562	3	2004-07-29
1	6167	2712	1	2004-07-17
2	6167	9429	2	2004-07-17
3	6167	8785	1	2004-07-17
4	6167	3374	1	2004-07-17
1	6168	9633	2	2004-07-10
2	6168	5629	3	2004-07-10
3	6168	7460	1	2004-07-10
4	6168	5504	2	2004-07-10
5	6168	7349	3	2004-07-10
6	6168	5861	2	2004-07-10
7	6168	7080	1	2004-07-10
8	6168	3050	1	2004-07-10
1	6169	9790	2	2004-07-29
2	6169	5884	3	2004-07-29
1	6170	1746	2	2004-07-27
2	6170	218	1	2004-07-27
1	6171	6874	2	2004-07-30
2	6171	3620	2	2004-07-30
3	6171	5815	3	2004-07-30
4	6171	8944	1	2004-07-30
5	6171	9901	1	2004-07-30
6	6171	5442	3	2004-07-30
7	6171	8639	1	2004-07-30
1	6172	7003	2	2004-07-03
2	6172	5840	3	2004-07-03
3	6172	7837	3	2004-07-03
4	6172	2258	3	2004-07-03
5	6172	8963	1	2004-07-03
6	6172	3900	3	2004-07-03
1	6173	4996	1	2004-07-28
2	6173	2116	2	2004-07-28
3	6173	4921	1	2004-07-28
1	6174	2344	1	2004-07-19
2	6174	2999	1	2004-07-19
3	6174	8243	1	2004-07-19
4	6174	6710	2	2004-07-19
5	6174	8389	2	2004-07-19
1	6175	2553	2	2004-07-06
1	6176	4205	1	2004-07-02
2	6176	8701	2	2004-07-02
3	6176	6206	2	2004-07-02
4	6176	8336	1	2004-07-02
5	6176	3983	3	2004-07-02
6	6176	6708	2	2004-07-02
7	6176	957	3	2004-07-02
1	6177	3282	3	2004-07-21
2	6177	7875	2	2004-07-21
3	6177	8741	1	2004-07-21
1	6178	2863	2	2004-07-18
2	6178	2716	3	2004-07-18
3	6178	6513	1	2004-07-18
4	6178	3387	1	2004-07-18
5	6178	5038	1	2004-07-18
6	6178	4855	3	2004-07-18
1	6179	1267	1	2004-07-04
2	6179	1175	1	2004-07-04
1	6180	9404	3	2004-07-17
2	6180	3643	2	2004-07-17
3	6180	9102	1	2004-07-17
1	6181	9031	1	2004-07-04
2	6181	5153	1	2004-07-04
3	6181	4090	1	2004-07-04
4	6181	4139	3	2004-07-04
1	6182	7132	1	2004-07-29
2	6182	6522	3	2004-07-29
3	6182	2746	1	2004-07-29
4	6182	2762	1	2004-07-29
5	6182	4984	1	2004-07-29
1	6183	9241	3	2004-07-30
2	6183	688	2	2004-07-30
3	6183	1904	3	2004-07-30
4	6183	5474	3	2004-07-30
5	6183	2135	3	2004-07-30
6	6183	7247	2	2004-07-30
7	6183	8509	2	2004-07-30
8	6183	1431	3	2004-07-30
1	6184	6869	2	2004-07-04
2	6184	9351	3	2004-07-04
3	6184	5347	2	2004-07-04
4	6184	1796	2	2004-07-04
5	6184	2961	3	2004-07-04
6	6184	3692	1	2004-07-04
7	6184	7108	2	2004-07-04
1	6185	6069	2	2004-07-20
2	6185	1340	1	2004-07-20
1	6186	8862	1	2004-07-08
2	6186	2497	3	2004-07-08
3	6186	8321	3	2004-07-08
4	6186	3183	3	2004-07-08
1	6187	3498	2	2004-07-28
1	6188	1568	2	2004-07-31
2	6188	5852	2	2004-07-31
3	6188	5245	1	2004-07-31
4	6188	1895	2	2004-07-31
5	6188	5235	2	2004-07-31
6	6188	6432	2	2004-07-31
7	6188	8333	2	2004-07-31
1	6189	195	3	2004-07-18
2	6189	1784	3	2004-07-18
3	6189	6654	2	2004-07-18
4	6189	9982	1	2004-07-18
1	6190	6554	3	2004-07-28
2	6190	9392	1	2004-07-28
3	6190	4573	2	2004-07-28
4	6190	4325	2	2004-07-28
5	6190	1220	3	2004-07-28
6	6190	866	3	2004-07-28
1	6191	28	3	2004-07-15
1	6192	9413	1	2004-07-14
2	6192	42	3	2004-07-14
3	6192	2816	3	2004-07-14
4	6192	9107	1	2004-07-14
5	6192	4720	2	2004-07-14
6	6192	9065	2	2004-07-14
1	6193	105	3	2004-07-25
2	6193	1948	1	2004-07-25
3	6193	7618	2	2004-07-25
1	6194	8448	1	2004-07-01
1	6195	7122	3	2004-07-02
2	6195	9225	3	2004-07-02
3	6195	6427	3	2004-07-02
4	6195	93	1	2004-07-02
5	6195	3992	3	2004-07-02
6	6195	5257	1	2004-07-02
7	6195	2795	2	2004-07-02
8	6195	4444	1	2004-07-02
9	6195	3971	2	2004-07-02
1	6196	2151	3	2004-07-12
2	6196	4234	1	2004-07-12
3	6196	1106	2	2004-07-12
4	6196	5055	3	2004-07-12
1	6197	2113	1	2004-07-14
2	6197	2040	1	2004-07-14
3	6197	3895	2	2004-07-14
4	6197	1362	3	2004-07-14
1	6198	7056	3	2004-07-26
2	6198	8921	1	2004-07-26
3	6198	8713	1	2004-07-26
1	6199	1461	1	2004-07-16
2	6199	3849	2	2004-07-16
3	6199	1393	3	2004-07-16
4	6199	8691	3	2004-07-16
5	6199	2040	1	2004-07-16
6	6199	465	2	2004-07-16
7	6199	3008	2	2004-07-16
8	6199	110	2	2004-07-16
9	6199	3510	3	2004-07-16
1	6200	3789	3	2004-07-27
2	6200	6506	1	2004-07-27
3	6200	1469	1	2004-07-27
4	6200	3365	1	2004-07-27
5	6200	665	2	2004-07-27
6	6200	5760	2	2004-07-27
1	6201	4868	2	2004-07-05
1	6202	9691	3	2004-07-03
2	6202	8210	1	2004-07-03
3	6202	7270	3	2004-07-03
4	6202	9865	3	2004-07-03
1	6203	6155	3	2004-07-08
2	6203	289	3	2004-07-08
3	6203	2169	1	2004-07-08
4	6203	4344	3	2004-07-08
5	6203	5466	2	2004-07-08
6	6203	5081	3	2004-07-08
7	6203	5714	3	2004-07-08
8	6203	3194	2	2004-07-08
1	6204	1232	3	2004-07-17
2	6204	8172	3	2004-07-17
3	6204	5332	3	2004-07-17
4	6204	6495	3	2004-07-17
5	6204	1689	2	2004-07-17
1	6205	7361	2	2004-07-21
2	6205	7709	1	2004-07-21
3	6205	3340	1	2004-07-21
4	6205	7388	3	2004-07-21
5	6205	1483	1	2004-07-21
6	6205	8370	2	2004-07-21
7	6205	9648	2	2004-07-21
1	6206	8632	3	2004-07-22
2	6206	6567	2	2004-07-22
3	6206	4828	1	2004-07-22
4	6206	1610	2	2004-07-22
5	6206	7197	3	2004-07-22
6	6206	4359	1	2004-07-22
7	6206	4833	1	2004-07-22
8	6206	5851	1	2004-07-22
1	6207	7611	3	2004-07-11
1	6208	9630	3	2004-07-13
2	6208	3594	3	2004-07-13
3	6208	6775	1	2004-07-13
4	6208	5043	2	2004-07-13
1	6209	6387	2	2004-07-20
2	6209	5875	1	2004-07-20
3	6209	4039	1	2004-07-20
4	6209	2465	3	2004-07-20
5	6209	3248	2	2004-07-20
6	6209	9079	3	2004-07-20
7	6209	6700	3	2004-07-20
8	6209	6159	1	2004-07-20
1	6210	6742	3	2004-07-09
2	6210	548	2	2004-07-09
3	6210	9990	2	2004-07-09
1	6211	3977	1	2004-07-22
2	6211	6860	3	2004-07-22
3	6211	2592	1	2004-07-22
1	6212	946	3	2004-07-02
2	6212	2768	3	2004-07-02
3	6212	6553	3	2004-07-02
4	6212	8257	3	2004-07-02
1	6213	192	1	2004-07-22
2	6213	7216	1	2004-07-22
3	6213	7657	2	2004-07-22
4	6213	6360	1	2004-07-22
1	6214	187	3	2004-07-23
2	6214	5090	1	2004-07-23
3	6214	2612	2	2004-07-23
4	6214	4551	2	2004-07-23
1	6215	6244	3	2004-07-18
2	6215	1513	1	2004-07-18
3	6215	1886	1	2004-07-18
1	6216	2259	1	2004-07-22
2	6216	8192	3	2004-07-22
3	6216	5872	2	2004-07-22
4	6216	8955	1	2004-07-22
1	6217	9887	1	2004-07-31
2	6217	680	2	2004-07-31
3	6217	4559	2	2004-07-31
4	6217	1755	2	2004-07-31
5	6217	8710	3	2004-07-31
1	6218	3254	3	2004-07-17
2	6218	9183	3	2004-07-17
3	6218	2223	1	2004-07-17
4	6218	1107	1	2004-07-17
5	6218	60	3	2004-07-17
6	6218	5938	3	2004-07-17
7	6218	7814	2	2004-07-17
1	6219	7206	1	2004-07-26
2	6219	2479	1	2004-07-26
3	6219	7558	2	2004-07-26
4	6219	7525	2	2004-07-26
5	6219	2231	1	2004-07-26
6	6219	6490	2	2004-07-26
7	6219	9850	3	2004-07-26
8	6219	1535	3	2004-07-26
1	6220	4172	1	2004-07-26
2	6220	6181	1	2004-07-26
3	6220	9547	2	2004-07-26
4	6220	5763	3	2004-07-26
5	6220	198	2	2004-07-26
6	6220	5745	3	2004-07-26
7	6220	7361	3	2004-07-26
8	6220	9167	2	2004-07-26
9	6220	2457	3	2004-07-26
1	6221	8119	3	2004-07-04
2	6221	7417	3	2004-07-04
3	6221	8316	2	2004-07-04
4	6221	3411	3	2004-07-04
5	6221	4715	3	2004-07-04
6	6221	9320	1	2004-07-04
7	6221	7691	3	2004-07-04
1	6222	9676	1	2004-07-16
2	6222	2489	3	2004-07-16
3	6222	537	1	2004-07-16
4	6222	1953	1	2004-07-16
5	6222	8346	1	2004-07-16
1	6223	7066	3	2004-07-24
2	6223	5452	2	2004-07-24
3	6223	3740	3	2004-07-24
4	6223	4170	3	2004-07-24
5	6223	6444	2	2004-07-24
6	6223	9349	2	2004-07-24
1	6224	9323	3	2004-07-08
2	6224	1238	1	2004-07-08
3	6224	4299	1	2004-07-08
4	6224	3466	2	2004-07-08
5	6224	4767	1	2004-07-08
6	6224	9389	1	2004-07-08
7	6224	9593	1	2004-07-08
8	6224	8246	2	2004-07-08
9	6224	8426	2	2004-07-08
1	6225	618	3	2004-07-07
2	6225	9698	3	2004-07-07
3	6225	3137	1	2004-07-07
4	6225	4203	1	2004-07-07
5	6225	977	2	2004-07-07
6	6225	7988	1	2004-07-07
1	6226	8538	3	2004-07-17
2	6226	612	3	2004-07-17
3	6226	1202	1	2004-07-17
4	6226	8124	3	2004-07-17
5	6226	6863	2	2004-07-17
6	6226	3143	3	2004-07-17
7	6226	8714	2	2004-07-17
8	6226	5111	3	2004-07-17
1	6227	6861	2	2004-07-15
2	6227	8563	3	2004-07-15
3	6227	7025	2	2004-07-15
4	6227	52	1	2004-07-15
5	6227	8837	2	2004-07-15
6	6227	1161	3	2004-07-15
7	6227	2794	1	2004-07-15
8	6227	5300	2	2004-07-15
1	6228	9973	2	2004-07-07
2	6228	7740	3	2004-07-07
3	6228	2285	1	2004-07-07
4	6228	8017	3	2004-07-07
5	6228	7658	3	2004-07-07
6	6228	4826	2	2004-07-07
7	6228	813	2	2004-07-07
8	6228	2357	3	2004-07-07
1	6229	6447	1	2004-07-31
2	6229	6149	3	2004-07-31
3	6229	3131	1	2004-07-31
4	6229	3234	2	2004-07-31
5	6229	4871	3	2004-07-31
6	6229	3946	2	2004-07-31
7	6229	3258	1	2004-07-31
8	6229	3529	2	2004-07-31
1	6230	8859	3	2004-07-15
2	6230	6712	3	2004-07-15
1	6231	1476	3	2004-07-03
1	6232	7162	1	2004-07-30
2	6232	7049	1	2004-07-30
3	6232	7300	1	2004-07-30
4	6232	7069	1	2004-07-30
5	6232	6763	1	2004-07-30
6	6232	2930	1	2004-07-30
1	6233	9658	1	2004-07-19
2	6233	5749	2	2004-07-19
3	6233	365	2	2004-07-19
4	6233	5438	3	2004-07-19
5	6233	7168	3	2004-07-19
6	6233	5578	2	2004-07-19
7	6233	4836	2	2004-07-19
8	6233	2221	1	2004-07-19
1	6234	1189	3	2004-07-22
2	6234	5379	3	2004-07-22
3	6234	9786	3	2004-07-22
4	6234	8242	2	2004-07-22
1	6235	771	3	2004-07-18
2	6235	1802	1	2004-07-18
3	6235	6286	3	2004-07-18
4	6235	9009	2	2004-07-18
5	6235	4152	2	2004-07-18
1	6236	984	2	2004-07-01
2	6236	1563	2	2004-07-01
3	6236	195	1	2004-07-01
1	6237	3883	3	2004-07-09
2	6237	8274	3	2004-07-09
3	6237	9021	1	2004-07-09
1	6238	928	3	2004-07-16
2	6238	4128	3	2004-07-16
3	6238	1856	3	2004-07-16
4	6238	4522	1	2004-07-16
5	6238	7267	2	2004-07-16
6	6238	4222	3	2004-07-16
7	6238	9809	2	2004-07-16
1	6239	5577	3	2004-07-06
2	6239	7079	3	2004-07-06
3	6239	8182	2	2004-07-06
4	6239	9115	3	2004-07-06
5	6239	7674	2	2004-07-06
1	6240	8195	2	2004-07-22
2	6240	7858	1	2004-07-22
3	6240	3497	1	2004-07-22
4	6240	1979	1	2004-07-22
5	6240	6127	2	2004-07-22
6	6240	9013	2	2004-07-22
7	6240	1985	1	2004-07-22
8	6240	5939	1	2004-07-22
1	6241	975	3	2004-07-16
2	6241	7526	1	2004-07-16
1	6242	4990	2	2004-07-16
2	6242	60	1	2004-07-16
1	6243	296	2	2004-07-02
2	6243	4860	2	2004-07-02
3	6243	1413	2	2004-07-02
4	6243	2358	2	2004-07-02
1	6244	9812	2	2004-07-14
2	6244	1778	1	2004-07-14
3	6244	1618	3	2004-07-14
4	6244	875	3	2004-07-14
5	6244	4502	2	2004-07-14
6	6244	8899	3	2004-07-14
7	6244	548	3	2004-07-14
8	6244	2676	1	2004-07-14
9	6244	6876	2	2004-07-14
1	6245	3595	1	2004-07-17
1	6246	4248	3	2004-07-13
2	6246	8090	2	2004-07-13
3	6246	3530	3	2004-07-13
4	6246	4844	2	2004-07-13
5	6246	9170	2	2004-07-13
6	6246	1910	2	2004-07-13
7	6246	884	1	2004-07-13
8	6246	3163	1	2004-07-13
1	6247	1749	3	2004-07-31
2	6247	3814	1	2004-07-31
3	6247	7928	3	2004-07-31
4	6247	5408	1	2004-07-31
5	6247	3360	1	2004-07-31
6	6247	390	3	2004-07-31
1	6248	8347	2	2004-07-04
2	6248	9872	3	2004-07-04
3	6248	2227	1	2004-07-04
4	6248	1188	1	2004-07-04
5	6248	2589	2	2004-07-04
1	6249	8997	1	2004-07-15
2	6249	4945	1	2004-07-15
3	6249	4810	1	2004-07-15
4	6249	218	1	2004-07-15
5	6249	4777	2	2004-07-15
6	6249	1559	2	2004-07-15
7	6249	1184	1	2004-07-15
1	6250	9358	3	2004-07-12
2	6250	9509	1	2004-07-12
1	6251	5048	3	2004-07-29
2	6251	4073	2	2004-07-29
1	6252	5880	1	2004-07-20
2	6252	4173	2	2004-07-20
1	6253	4115	1	2004-07-07
2	6253	6514	3	2004-07-07
3	6253	3707	2	2004-07-07
4	6253	9753	1	2004-07-07
1	6254	9959	3	2004-07-05
1	6255	243	2	2004-07-07
2	6255	9326	3	2004-07-07
3	6255	6235	2	2004-07-07
4	6255	9403	1	2004-07-07
5	6255	1302	1	2004-07-07
6	6255	9355	1	2004-07-07
1	6256	1230	2	2004-07-17
2	6256	5869	1	2004-07-17
1	6257	7673	1	2004-07-27
2	6257	2596	3	2004-07-27
3	6257	5208	1	2004-07-27
1	6258	2867	1	2004-07-19
2	6258	643	1	2004-07-19
3	6258	2749	1	2004-07-19
4	6258	3873	1	2004-07-19
5	6258	2921	3	2004-07-19
1	6259	296	3	2004-07-18
2	6259	7785	3	2004-07-18
3	6259	4192	3	2004-07-18
4	6259	2155	1	2004-07-18
5	6259	8230	2	2004-07-18
6	6259	1722	2	2004-07-18
7	6259	5924	3	2004-07-18
1	6260	4375	2	2004-07-28
2	6260	4022	3	2004-07-28
1	6261	7133	2	2004-07-19
2	6261	3533	3	2004-07-19
3	6261	1603	2	2004-07-19
4	6261	5234	3	2004-07-19
5	6261	2730	3	2004-07-19
6	6261	7415	2	2004-07-19
7	6261	1290	2	2004-07-19
8	6261	9634	1	2004-07-19
1	6262	7589	2	2004-07-29
2	6262	9719	1	2004-07-29
3	6262	8031	2	2004-07-29
4	6262	9086	2	2004-07-29
5	6262	1634	3	2004-07-29
6	6262	2668	3	2004-07-29
7	6262	3113	2	2004-07-29
8	6262	7014	2	2004-07-29
1	6263	1673	1	2004-07-01
2	6263	7641	1	2004-07-01
3	6263	7162	3	2004-07-01
1	6264	4207	1	2004-07-19
2	6264	932	2	2004-07-19
3	6264	2382	3	2004-07-19
4	6264	7665	1	2004-07-19
5	6264	2851	3	2004-07-19
6	6264	9780	2	2004-07-19
7	6264	8063	1	2004-07-19
1	6265	7325	1	2004-07-06
2	6265	4505	3	2004-07-06
1	6266	9419	3	2004-07-11
1	6267	2669	2	2004-07-21
1	6268	6517	3	2004-07-15
2	6268	1722	2	2004-07-15
3	6268	3008	3	2004-07-15
1	6269	6472	1	2004-07-29
2	6269	8503	1	2004-07-29
3	6269	1184	1	2004-07-29
4	6269	3122	1	2004-07-29
5	6269	2116	1	2004-07-29
6	6269	1072	3	2004-07-29
7	6269	4790	2	2004-07-29
1	6270	2508	2	2004-07-30
2	6270	6763	3	2004-07-30
3	6270	3623	3	2004-07-30
4	6270	5321	2	2004-07-30
1	6271	1302	3	2004-07-26
2	6271	5317	3	2004-07-26
3	6271	8803	2	2004-07-26
1	6272	4464	1	2004-07-05
2	6272	2392	3	2004-07-05
3	6272	6530	1	2004-07-05
4	6272	6712	3	2004-07-05
1	6273	8244	3	2004-07-20
2	6273	1556	2	2004-07-20
3	6273	4408	3	2004-07-20
1	6274	3588	3	2004-07-26
2	6274	9177	1	2004-07-26
3	6274	4772	1	2004-07-26
4	6274	4314	2	2004-07-26
5	6274	4358	3	2004-07-26
6	6274	5125	3	2004-07-26
7	6274	8031	1	2004-07-26
8	6274	8720	2	2004-07-26
9	6274	9677	2	2004-07-26
1	6275	1611	3	2004-07-13
2	6275	5768	2	2004-07-13
1	6276	3211	2	2004-07-30
2	6276	705	1	2004-07-30
3	6276	7758	2	2004-07-30
1	6277	849	2	2004-07-10
2	6277	4203	3	2004-07-10
3	6277	6667	1	2004-07-10
4	6277	3621	2	2004-07-10
5	6277	7950	3	2004-07-10
6	6277	176	2	2004-07-10
7	6277	9785	1	2004-07-10
1	6278	9390	3	2004-07-18
2	6278	7614	1	2004-07-18
3	6278	4949	3	2004-07-18
4	6278	4989	1	2004-07-18
5	6278	3795	3	2004-07-18
1	6279	8695	3	2004-07-15
2	6279	4504	2	2004-07-15
3	6279	2664	3	2004-07-15
4	6279	1704	1	2004-07-15
5	6279	5705	1	2004-07-15
6	6279	6662	2	2004-07-15
1	6280	7545	1	2004-07-12
2	6280	1049	2	2004-07-12
1	6281	8703	3	2004-07-10
2	6281	6103	2	2004-07-10
3	6281	953	1	2004-07-10
4	6281	9104	3	2004-07-10
5	6281	1384	2	2004-07-10
6	6281	5009	2	2004-07-10
7	6281	1732	3	2004-07-10
8	6281	4661	3	2004-07-10
1	6282	3686	2	2004-07-27
2	6282	3724	1	2004-07-27
3	6282	4394	2	2004-07-27
1	6283	5442	3	2004-07-20
2	6283	7134	1	2004-07-20
3	6283	2952	3	2004-07-20
4	6283	3187	1	2004-07-20
5	6283	7734	2	2004-07-20
6	6283	5663	1	2004-07-20
7	6283	8618	3	2004-07-20
8	6283	9456	1	2004-07-20
9	6283	4829	3	2004-07-20
1	6284	1717	2	2004-07-15
2	6284	9515	2	2004-07-15
3	6284	8801	2	2004-07-15
4	6284	3534	3	2004-07-15
5	6284	5765	3	2004-07-15
6	6284	9043	1	2004-07-15
7	6284	521	1	2004-07-15
8	6284	985	2	2004-07-15
1	6285	1462	3	2004-07-13
2	6285	7104	1	2004-07-13
3	6285	172	1	2004-07-13
4	6285	8965	2	2004-07-13
5	6285	9686	3	2004-07-13
6	6285	3057	1	2004-07-13
7	6285	3296	1	2004-07-13
8	6285	7513	1	2004-07-13
9	6285	8473	1	2004-07-13
1	6286	7136	1	2004-07-06
1	6287	6840	1	2004-07-09
2	6287	6460	3	2004-07-09
3	6287	9421	2	2004-07-09
4	6287	9218	3	2004-07-09
5	6287	5496	3	2004-07-09
6	6287	4365	2	2004-07-09
7	6287	7451	3	2004-07-09
1	6288	2842	3	2004-07-21
2	6288	5143	2	2004-07-21
3	6288	2702	2	2004-07-21
4	6288	5215	3	2004-07-21
1	6289	4665	2	2004-07-18
2	6289	2484	1	2004-07-18
3	6289	3099	1	2004-07-18
4	6289	4687	1	2004-07-18
5	6289	1497	1	2004-07-18
6	6289	498	2	2004-07-18
7	6289	5363	3	2004-07-18
8	6289	3282	1	2004-07-18
9	6289	8694	1	2004-07-18
1	6290	6043	2	2004-07-19
2	6290	6348	1	2004-07-19
1	6291	2012	2	2004-07-14
2	6291	7032	2	2004-07-14
3	6291	4962	1	2004-07-14
1	6292	9831	1	2004-07-20
2	6292	3757	2	2004-07-20
3	6292	892	3	2004-07-20
4	6292	7140	3	2004-07-20
5	6292	313	1	2004-07-20
6	6292	1121	1	2004-07-20
7	6292	4366	3	2004-07-20
8	6292	6490	1	2004-07-20
1	6293	3001	2	2004-07-27
2	6293	1433	1	2004-07-27
3	6293	9275	2	2004-07-27
4	6293	163	2	2004-07-27
5	6293	6043	1	2004-07-27
6	6293	3570	2	2004-07-27
7	6293	5552	3	2004-07-27
1	6294	6029	2	2004-07-04
2	6294	1389	3	2004-07-04
3	6294	6728	2	2004-07-04
4	6294	4313	1	2004-07-04
5	6294	6467	1	2004-07-04
6	6294	3983	3	2004-07-04
7	6294	329	3	2004-07-04
8	6294	4015	1	2004-07-04
1	6295	8962	2	2004-07-22
2	6295	9787	1	2004-07-22
3	6295	71	2	2004-07-22
4	6295	9858	1	2004-07-22
5	6295	1781	2	2004-07-22
6	6295	9346	3	2004-07-22
7	6295	8900	1	2004-07-22
1	6296	8844	1	2004-07-16
2	6296	2006	1	2004-07-16
3	6296	2189	1	2004-07-16
4	6296	9810	2	2004-07-16
5	6296	4095	3	2004-07-16
6	6296	9491	1	2004-07-16
7	6296	4004	3	2004-07-16
8	6296	6446	2	2004-07-16
9	6296	984	2	2004-07-16
1	6297	5063	3	2004-07-29
1	6298	9588	2	2004-07-28
2	6298	2949	3	2004-07-28
3	6298	7174	2	2004-07-28
4	6298	1257	3	2004-07-28
1	6299	7892	2	2004-07-23
2	6299	3631	1	2004-07-23
1	6300	6593	2	2004-07-11
2	6300	5331	2	2004-07-11
3	6300	5719	1	2004-07-11
4	6300	1247	2	2004-07-11
5	6300	4354	3	2004-07-11
1	6301	2373	1	2004-07-26
1	6302	4697	2	2004-07-19
2	6302	4684	1	2004-07-19
3	6302	352	3	2004-07-19
1	6303	8348	2	2004-07-14
1	6304	4070	1	2004-07-16
1	6305	2366	1	2004-07-16
2	6305	4306	2	2004-07-16
3	6305	3028	1	2004-07-16
1	6306	8059	3	2004-07-26
2	6306	5652	3	2004-07-26
3	6306	6620	1	2004-07-26
1	6307	9994	2	2004-07-08
1	6308	9701	1	2004-07-14
2	6308	6787	3	2004-07-14
3	6308	4351	3	2004-07-14
4	6308	1812	3	2004-07-14
5	6308	3891	2	2004-07-14
6	6308	8976	1	2004-07-14
7	6308	7601	1	2004-07-14
8	6308	5323	2	2004-07-14
1	6309	1109	2	2004-07-03
2	6309	2532	1	2004-07-03
3	6309	6954	1	2004-07-03
4	6309	6686	1	2004-07-03
5	6309	1750	1	2004-07-03
6	6309	9611	1	2004-07-03
7	6309	3766	2	2004-07-03
1	6310	6773	3	2004-07-02
2	6310	7257	2	2004-07-02
3	6310	1699	2	2004-07-02
1	6311	7996	2	2004-07-26
2	6311	6771	3	2004-07-26
3	6311	927	3	2004-07-26
4	6311	512	3	2004-07-26
5	6311	1828	3	2004-07-26
6	6311	9128	2	2004-07-26
7	6311	9858	3	2004-07-26
8	6311	5027	2	2004-07-26
9	6311	5135	2	2004-07-26
1	6312	124	2	2004-07-06
2	6312	4261	1	2004-07-06
3	6312	165	1	2004-07-06
4	6312	8845	1	2004-07-06
5	6312	1855	3	2004-07-06
6	6312	5271	3	2004-07-06
7	6312	5944	2	2004-07-06
8	6312	7928	2	2004-07-06
1	6313	3332	2	2004-07-13
2	6313	1941	3	2004-07-13
3	6313	7133	3	2004-07-13
1	6314	7384	3	2004-07-13
2	6314	7348	1	2004-07-13
1	6315	8195	2	2004-07-31
2	6315	5389	2	2004-07-31
3	6315	4730	1	2004-07-31
4	6315	9662	1	2004-07-31
5	6315	7788	2	2004-07-31
6	6315	2413	1	2004-07-31
7	6315	6942	2	2004-07-31
8	6315	4951	3	2004-07-31
1	6316	956	2	2004-07-13
2	6316	134	3	2004-07-13
3	6316	1600	3	2004-07-13
4	6316	9983	1	2004-07-13
5	6316	4994	2	2004-07-13
6	6316	9854	1	2004-07-13
7	6316	338	2	2004-07-13
8	6316	6654	2	2004-07-13
1	6317	53	1	2004-07-21
2	6317	5803	3	2004-07-21
3	6317	5882	1	2004-07-21
4	6317	5878	3	2004-07-21
1	6318	5552	3	2004-07-09
2	6318	2132	3	2004-07-09
3	6318	5691	1	2004-07-09
4	6318	8455	1	2004-07-09
1	6319	3550	1	2004-07-20
2	6319	1752	1	2004-07-20
3	6319	6841	3	2004-07-20
4	6319	4487	3	2004-07-20
5	6319	9614	1	2004-07-20
6	6319	3888	2	2004-07-20
7	6319	1043	3	2004-07-20
1	6320	7674	3	2004-07-17
2	6320	1767	3	2004-07-17
3	6320	4302	3	2004-07-17
4	6320	1919	1	2004-07-17
1	6321	4950	2	2004-07-26
2	6321	2539	3	2004-07-26
1	6322	6272	2	2004-07-15
2	6322	9513	1	2004-07-15
3	6322	1287	1	2004-07-15
4	6322	9924	3	2004-07-15
5	6322	4436	1	2004-07-15
6	6322	322	1	2004-07-15
7	6322	8675	1	2004-07-15
8	6322	1914	1	2004-07-15
9	6322	9545	2	2004-07-15
1	6323	9699	3	2004-07-18
2	6323	1411	1	2004-07-18
3	6323	3749	2	2004-07-18
4	6323	1616	3	2004-07-18
5	6323	5373	3	2004-07-18
6	6323	5717	2	2004-07-18
7	6323	8046	3	2004-07-18
1	6324	9493	2	2004-07-17
2	6324	1986	3	2004-07-17
3	6324	6178	2	2004-07-17
4	6324	1145	2	2004-07-17
5	6324	7732	3	2004-07-17
6	6324	3409	3	2004-07-17
7	6324	3675	1	2004-07-17
8	6324	6877	2	2004-07-17
9	6324	5344	1	2004-07-17
1	6325	4845	2	2004-07-04
2	6325	1492	1	2004-07-04
3	6325	3270	3	2004-07-04
4	6325	860	3	2004-07-04
5	6325	6810	1	2004-07-04
6	6325	1127	3	2004-07-04
1	6326	3027	1	2004-07-27
2	6326	6542	2	2004-07-27
3	6326	256	1	2004-07-27
4	6326	9541	3	2004-07-27
5	6326	5301	2	2004-07-27
6	6326	7758	2	2004-07-27
7	6326	1843	3	2004-07-27
8	6326	3141	3	2004-07-27
9	6326	4575	2	2004-07-27
1	6327	4881	3	2004-07-30
1	6328	3311	3	2004-07-03
2	6328	8975	2	2004-07-03
3	6328	292	2	2004-07-03
4	6328	2771	1	2004-07-03
5	6328	5732	1	2004-07-03
6	6328	7680	1	2004-07-03
7	6328	7197	2	2004-07-03
8	6328	7567	3	2004-07-03
9	6328	3745	1	2004-07-03
1	6329	6164	3	2004-07-18
2	6329	5742	1	2004-07-18
3	6329	5281	2	2004-07-18
4	6329	7052	1	2004-07-18
5	6329	5841	1	2004-07-18
1	6330	330	3	2004-07-08
2	6330	3156	2	2004-07-08
3	6330	1782	1	2004-07-08
1	6331	8017	1	2004-07-22
2	6331	5369	2	2004-07-22
3	6331	8336	1	2004-07-22
4	6331	9047	2	2004-07-22
5	6331	7615	2	2004-07-22
1	6332	5347	3	2004-07-18
2	6332	2957	3	2004-07-18
3	6332	1973	3	2004-07-18
1	6333	8364	1	2004-07-01
2	6333	4261	2	2004-07-01
3	6333	9884	1	2004-07-01
4	6333	120	3	2004-07-01
1	6334	6197	1	2004-07-02
2	6334	3383	2	2004-07-02
3	6334	5478	3	2004-07-02
4	6334	6706	3	2004-07-02
5	6334	1522	1	2004-07-02
6	6334	3954	2	2004-07-02
7	6334	9715	2	2004-07-02
8	6334	4134	3	2004-07-02
1	6335	4166	3	2004-07-26
2	6335	2051	2	2004-07-26
3	6335	8205	1	2004-07-26
4	6335	1950	3	2004-07-26
5	6335	7658	2	2004-07-26
6	6335	7636	2	2004-07-26
1	6336	9944	2	2004-07-14
2	6336	6555	1	2004-07-14
3	6336	6423	1	2004-07-14
4	6336	5943	2	2004-07-14
5	6336	6435	1	2004-07-14
6	6336	6124	2	2004-07-14
7	6336	3335	3	2004-07-14
8	6336	1257	3	2004-07-14
9	6336	7209	1	2004-07-14
1	6337	4166	1	2004-07-05
2	6337	7091	1	2004-07-05
3	6337	6989	1	2004-07-05
4	6337	2819	2	2004-07-05
1	6338	4226	2	2004-07-04
2	6338	8196	1	2004-07-04
3	6338	1584	2	2004-07-04
4	6338	245	3	2004-07-04
5	6338	9294	2	2004-07-04
6	6338	7242	1	2004-07-04
7	6338	1079	2	2004-07-04
1	6339	6126	2	2004-07-12
2	6339	2467	1	2004-07-12
3	6339	5830	3	2004-07-12
4	6339	4589	3	2004-07-12
5	6339	4109	2	2004-07-12
6	6339	1409	1	2004-07-12
7	6339	3408	2	2004-07-12
8	6339	8578	1	2004-07-12
9	6339	5803	1	2004-07-12
1	6340	9627	2	2004-07-20
2	6340	6077	1	2004-07-20
3	6340	9559	3	2004-07-20
4	6340	3333	3	2004-07-20
5	6340	9266	3	2004-07-20
1	6341	1188	3	2004-07-11
2	6341	7928	2	2004-07-11
3	6341	2985	3	2004-07-11
4	6341	8428	2	2004-07-11
5	6341	4971	3	2004-07-11
6	6341	7994	1	2004-07-11
7	6341	7166	2	2004-07-11
8	6341	6822	2	2004-07-11
9	6341	9753	2	2004-07-11
1	6342	5763	1	2004-07-01
2	6342	9121	2	2004-07-01
3	6342	9943	1	2004-07-01
4	6342	6762	1	2004-07-01
5	6342	1852	3	2004-07-01
6	6342	9881	3	2004-07-01
7	6342	3245	1	2004-07-01
8	6342	9115	1	2004-07-01
9	6342	9256	2	2004-07-01
1	6343	1476	1	2004-07-27
2	6343	877	1	2004-07-27
3	6343	8128	1	2004-07-27
4	6343	7058	2	2004-07-27
5	6343	717	1	2004-07-27
6	6343	5765	3	2004-07-27
1	6344	8324	2	2004-07-25
2	6344	2559	3	2004-07-25
3	6344	4039	2	2004-07-25
4	6344	1068	1	2004-07-25
5	6344	7477	1	2004-07-25
1	6345	1998	3	2004-07-23
2	6345	3780	1	2004-07-23
1	6346	7188	2	2004-07-01
2	6346	155	1	2004-07-01
3	6346	4444	3	2004-07-01
4	6346	8659	3	2004-07-01
5	6346	2613	3	2004-07-01
6	6346	1113	2	2004-07-01
7	6346	5185	2	2004-07-01
1	6347	6577	2	2004-07-04
2	6347	4606	2	2004-07-04
3	6347	7644	2	2004-07-04
4	6347	3197	1	2004-07-04
5	6347	9478	2	2004-07-04
6	6347	3331	2	2004-07-04
7	6347	808	1	2004-07-04
8	6347	7975	1	2004-07-04
1	6348	9271	1	2004-07-11
2	6348	9110	1	2004-07-11
1	6349	548	2	2004-07-21
2	6349	6178	3	2004-07-21
3	6349	9383	1	2004-07-21
4	6349	1273	3	2004-07-21
5	6349	7387	2	2004-07-21
6	6349	8449	3	2004-07-21
7	6349	7943	1	2004-07-21
1	6350	9713	2	2004-07-01
2	6350	624	3	2004-07-01
3	6350	7896	3	2004-07-01
4	6350	257	3	2004-07-01
5	6350	277	3	2004-07-01
6	6350	1301	2	2004-07-01
7	6350	4733	1	2004-07-01
8	6350	9649	1	2004-07-01
1	6351	6057	3	2004-07-28
1	6352	6285	2	2004-07-15
2	6352	1405	3	2004-07-15
3	6352	4382	1	2004-07-15
1	6353	4900	1	2004-07-14
2	6353	9251	2	2004-07-14
3	6353	7060	1	2004-07-14
1	6354	2702	1	2004-07-04
1	6355	3477	2	2004-07-30
2	6355	229	3	2004-07-30
3	6355	8980	2	2004-07-30
4	6355	5597	1	2004-07-30
5	6355	5095	3	2004-07-30
6	6355	1503	3	2004-07-30
1	6356	1351	1	2004-07-16
2	6356	5062	3	2004-07-16
3	6356	1491	2	2004-07-16
4	6356	202	2	2004-07-16
5	6356	6685	1	2004-07-16
6	6356	5259	2	2004-07-16
7	6356	7299	3	2004-07-16
8	6356	2076	1	2004-07-16
9	6356	3197	1	2004-07-16
1	6357	2562	2	2004-07-01
2	6357	5771	2	2004-07-01
3	6357	3354	1	2004-07-01
4	6357	5362	2	2004-07-01
5	6357	640	3	2004-07-01
6	6357	5983	2	2004-07-01
1	6358	1363	3	2004-07-16
2	6358	8226	2	2004-07-16
3	6358	4785	2	2004-07-16
4	6358	3492	3	2004-07-16
5	6358	6300	3	2004-07-16
1	6359	2287	1	2004-07-29
2	6359	1890	3	2004-07-29
3	6359	5490	2	2004-07-29
4	6359	8813	1	2004-07-29
5	6359	287	3	2004-07-29
6	6359	7563	2	2004-07-29
7	6359	5153	1	2004-07-29
8	6359	3742	3	2004-07-29
1	6360	1725	1	2004-07-25
2	6360	1757	2	2004-07-25
3	6360	6980	3	2004-07-25
4	6360	1905	2	2004-07-25
5	6360	4551	1	2004-07-25
6	6360	4124	3	2004-07-25
1	6361	1257	2	2004-07-07
2	6361	8535	1	2004-07-07
3	6361	3160	2	2004-07-07
4	6361	7813	3	2004-07-07
5	6361	8782	1	2004-07-07
6	6361	5214	3	2004-07-07
7	6361	6659	1	2004-07-07
1	6362	3600	3	2004-07-10
2	6362	2833	2	2004-07-10
3	6362	3792	3	2004-07-10
4	6362	6273	3	2004-07-10
5	6362	4222	3	2004-07-10
1	6363	2825	2	2004-07-13
2	6363	6728	2	2004-07-13
3	6363	781	2	2004-07-13
4	6363	4296	3	2004-07-13
5	6363	6094	3	2004-07-13
1	6364	1136	1	2004-07-20
2	6364	4147	2	2004-07-20
3	6364	8374	3	2004-07-20
4	6364	239	1	2004-07-20
5	6364	4364	2	2004-07-20
6	6364	80	3	2004-07-20
7	6364	4978	2	2004-07-20
8	6364	7702	1	2004-07-20
9	6364	9192	1	2004-07-20
1	6365	459	1	2004-07-19
2	6365	6154	2	2004-07-19
3	6365	314	1	2004-07-19
4	6365	9306	1	2004-07-19
5	6365	1874	1	2004-07-19
6	6365	1098	2	2004-07-19
1	6366	1637	3	2004-07-17
2	6366	1924	1	2004-07-17
3	6366	5949	3	2004-07-17
4	6366	5723	2	2004-07-17
5	6366	8028	2	2004-07-17
1	6367	431	1	2004-07-13
1	6368	9089	3	2004-07-05
2	6368	2175	1	2004-07-05
1	6369	2743	3	2004-07-24
2	6369	8179	2	2004-07-24
3	6369	7349	1	2004-07-24
1	6370	6947	2	2004-07-19
2	6370	6733	1	2004-07-19
1	6371	8859	1	2004-07-28
2	6371	5884	3	2004-07-28
3	6371	5097	2	2004-07-28
4	6371	3855	3	2004-07-28
5	6371	5934	1	2004-07-28
6	6371	543	1	2004-07-28
7	6371	4212	1	2004-07-28
8	6371	2901	1	2004-07-28
9	6371	7664	1	2004-07-28
1	6372	5576	1	2004-07-08
2	6372	4526	1	2004-07-08
3	6372	1615	2	2004-07-08
4	6372	9874	2	2004-07-08
5	6372	2693	3	2004-07-08
6	6372	6715	3	2004-07-08
7	6372	5436	1	2004-07-08
8	6372	3548	3	2004-07-08
9	6372	9082	3	2004-07-08
1	6373	2909	2	2004-07-03
2	6373	7340	1	2004-07-03
3	6373	5547	3	2004-07-03
4	6373	4330	3	2004-07-03
5	6373	9328	3	2004-07-03
1	6374	7247	1	2004-07-30
2	6374	4620	3	2004-07-30
1	6375	3145	1	2004-07-03
2	6375	5545	1	2004-07-03
3	6375	1545	2	2004-07-03
4	6375	1850	2	2004-07-03
5	6375	1230	2	2004-07-03
6	6375	9241	3	2004-07-03
1	6376	3880	3	2004-07-17
2	6376	9564	2	2004-07-17
3	6376	1582	1	2004-07-17
4	6376	4664	3	2004-07-17
5	6376	3862	3	2004-07-17
6	6376	8767	2	2004-07-17
7	6376	616	3	2004-07-17
8	6376	932	2	2004-07-17
9	6376	9346	2	2004-07-17
1	6377	4834	2	2004-07-19
2	6377	2594	2	2004-07-19
3	6377	2557	3	2004-07-19
4	6377	8862	1	2004-07-19
5	6377	7581	1	2004-07-19
6	6377	8687	3	2004-07-19
7	6377	6206	1	2004-07-19
8	6377	8921	1	2004-07-19
1	6378	7461	1	2004-07-29
2	6378	5144	3	2004-07-29
3	6378	4528	2	2004-07-29
4	6378	4869	1	2004-07-29
5	6378	5381	3	2004-07-29
6	6378	8350	1	2004-07-29
7	6378	1613	1	2004-07-29
8	6378	4288	2	2004-07-29
1	6379	5891	2	2004-07-28
2	6379	3591	1	2004-07-28
3	6379	4080	1	2004-07-28
4	6379	2966	1	2004-07-28
5	6379	5293	1	2004-07-28
6	6379	1036	1	2004-07-28
1	6380	669	2	2004-07-13
2	6380	8927	2	2004-07-13
3	6380	3640	3	2004-07-13
4	6380	6262	2	2004-07-13
5	6380	8220	1	2004-07-13
6	6380	9422	3	2004-07-13
7	6380	3699	2	2004-07-13
8	6380	3531	3	2004-07-13
1	6381	9631	2	2004-07-26
2	6381	5613	2	2004-07-26
3	6381	7769	2	2004-07-26
1	6382	66	2	2004-07-24
2	6382	4837	3	2004-07-24
3	6382	9544	3	2004-07-24
4	6382	6269	2	2004-07-24
5	6382	3729	2	2004-07-24
6	6382	6356	1	2004-07-24
7	6382	1573	1	2004-07-24
8	6382	7698	2	2004-07-24
1	6383	8497	1	2004-07-30
2	6383	5981	2	2004-07-30
1	6384	5402	2	2004-07-22
2	6384	3276	2	2004-07-22
3	6384	7080	3	2004-07-22
4	6384	4460	2	2004-07-22
5	6384	6588	1	2004-07-22
1	6385	3467	3	2004-07-08
2	6385	8839	1	2004-07-08
3	6385	1891	3	2004-07-08
4	6385	7222	2	2004-07-08
5	6385	9811	2	2004-07-08
6	6385	5967	2	2004-07-08
7	6385	9828	1	2004-07-08
8	6385	9540	1	2004-07-08
1	6386	409	1	2004-07-23
1	6387	5598	1	2004-07-27
2	6387	5489	1	2004-07-27
3	6387	9088	3	2004-07-27
4	6387	7604	3	2004-07-27
5	6387	121	3	2004-07-27
1	6388	3061	3	2004-07-20
2	6388	2011	1	2004-07-20
3	6388	2318	1	2004-07-20
4	6388	3474	3	2004-07-20
5	6388	6492	3	2004-07-20
6	6388	9987	3	2004-07-20
1	6389	3744	3	2004-07-28
2	6389	7067	3	2004-07-28
3	6389	8181	2	2004-07-28
4	6389	8188	2	2004-07-28
5	6389	4080	3	2004-07-28
6	6389	5278	1	2004-07-28
7	6389	5650	3	2004-07-28
1	6390	1599	1	2004-07-21
2	6390	267	2	2004-07-21
3	6390	291	3	2004-07-21
4	6390	2715	1	2004-07-21
5	6390	3658	1	2004-07-21
6	6390	8849	2	2004-07-21
7	6390	8371	1	2004-07-21
8	6390	2793	2	2004-07-21
1	6391	6757	2	2004-07-06
1	6392	919	1	2004-07-26
2	6392	2680	3	2004-07-26
3	6392	1581	2	2004-07-26
4	6392	154	1	2004-07-26
1	6393	723	1	2004-07-29
2	6393	3672	3	2004-07-29
1	6394	7479	2	2004-07-24
1	6395	4738	1	2004-07-05
2	6395	244	1	2004-07-05
3	6395	6289	1	2004-07-05
4	6395	3758	3	2004-07-05
5	6395	540	2	2004-07-05
6	6395	3247	1	2004-07-05
7	6395	7185	1	2004-07-05
8	6395	1137	2	2004-07-05
1	6396	1431	2	2004-07-15
2	6396	374	2	2004-07-15
3	6396	6221	3	2004-07-15
4	6396	7582	3	2004-07-15
5	6396	6920	1	2004-07-15
6	6396	5884	1	2004-07-15
7	6396	3900	2	2004-07-15
8	6396	2551	1	2004-07-15
1	6397	1646	1	2004-07-23
2	6397	8522	3	2004-07-23
3	6397	4999	3	2004-07-23
4	6397	4619	3	2004-07-23
5	6397	1518	1	2004-07-23
6	6397	7993	1	2004-07-23
7	6397	8410	3	2004-07-23
8	6397	6543	2	2004-07-23
1	6398	5705	3	2004-07-20
2	6398	4795	3	2004-07-20
3	6398	4315	3	2004-07-20
1	6399	9433	2	2004-07-31
2	6399	1350	3	2004-07-31
3	6399	4130	2	2004-07-31
4	6399	7612	3	2004-07-31
5	6399	6008	3	2004-07-31
6	6399	1418	2	2004-07-31
7	6399	2078	3	2004-07-31
8	6399	2367	3	2004-07-31
9	6399	4457	3	2004-07-31
1	6400	4947	2	2004-07-09
2	6400	8052	3	2004-07-09
3	6400	3863	3	2004-07-09
4	6400	865	3	2004-07-09
5	6400	6790	1	2004-07-09
6	6400	2816	3	2004-07-09
7	6400	8250	3	2004-07-09
8	6400	4487	2	2004-07-09
1	6401	4495	3	2004-07-18
2	6401	6939	3	2004-07-18
3	6401	5688	1	2004-07-18
4	6401	5446	3	2004-07-18
5	6401	8154	3	2004-07-18
6	6401	6878	1	2004-07-18
7	6401	3685	2	2004-07-18
1	6402	5064	3	2004-07-08
2	6402	3521	3	2004-07-08
3	6402	7701	1	2004-07-08
1	6403	2682	1	2004-07-15
1	6404	4039	2	2004-07-24
2	6404	5963	3	2004-07-24
3	6404	3810	2	2004-07-24
4	6404	6653	1	2004-07-24
5	6404	7217	1	2004-07-24
1	6405	2802	1	2004-07-18
2	6405	7949	2	2004-07-18
3	6405	829	2	2004-07-18
4	6405	8094	2	2004-07-18
5	6405	7837	2	2004-07-18
6	6405	6172	1	2004-07-18
7	6405	8350	2	2004-07-18
8	6405	7696	3	2004-07-18
1	6406	1219	3	2004-07-26
2	6406	8451	3	2004-07-26
3	6406	7916	2	2004-07-26
4	6406	8208	2	2004-07-26
1	6407	9041	3	2004-07-17
2	6407	4370	3	2004-07-17
3	6407	5518	1	2004-07-17
4	6407	5522	2	2004-07-17
5	6407	8189	1	2004-07-17
6	6407	3873	2	2004-07-17
7	6407	5496	1	2004-07-17
8	6407	4579	2	2004-07-17
1	6408	5228	2	2004-07-11
2	6408	2391	1	2004-07-11
3	6408	2317	1	2004-07-11
4	6408	6675	3	2004-07-11
5	6408	6690	3	2004-07-11
1	6409	5599	2	2004-07-18
2	6409	2440	1	2004-07-18
3	6409	7335	1	2004-07-18
4	6409	2814	1	2004-07-18
5	6409	7167	3	2004-07-18
6	6409	2776	1	2004-07-18
7	6409	2176	2	2004-07-18
8	6409	9744	1	2004-07-18
9	6409	598	2	2004-07-18
1	6410	3586	2	2004-07-22
2	6410	6904	1	2004-07-22
3	6410	3383	1	2004-07-22
4	6410	6006	1	2004-07-22
5	6410	2488	1	2004-07-22
6	6410	5826	2	2004-07-22
7	6410	2725	1	2004-07-22
8	6410	5556	2	2004-07-22
9	6410	4367	1	2004-07-22
1	6411	3219	2	2004-07-12
2	6411	6399	2	2004-07-12
3	6411	9181	2	2004-07-12
4	6411	6804	3	2004-07-12
5	6411	2766	1	2004-07-12
6	6411	2084	3	2004-07-12
1	6412	7312	2	2004-07-03
2	6412	8274	1	2004-07-03
3	6412	9595	1	2004-07-03
4	6412	6297	2	2004-07-03
5	6412	6536	1	2004-07-03
6	6412	7872	1	2004-07-03
7	6412	7805	1	2004-07-03
1	6413	4839	2	2004-07-20
2	6413	6227	1	2004-07-20
3	6413	3024	3	2004-07-20
1	6414	574	1	2004-07-07
2	6414	9364	3	2004-07-07
3	6414	5508	3	2004-07-07
1	6415	252	2	2004-07-04
2	6415	7981	3	2004-07-04
3	6415	5553	2	2004-07-04
4	6415	461	1	2004-07-04
5	6415	6808	3	2004-07-04
6	6415	4762	1	2004-07-04
7	6415	2738	1	2004-07-04
1	6416	869	3	2004-07-11
2	6416	8013	1	2004-07-11
3	6416	9480	3	2004-07-11
4	6416	9327	2	2004-07-11
5	6416	5013	1	2004-07-11
1	6417	8817	2	2004-07-01
1	6418	6326	3	2004-07-27
2	6418	5932	1	2004-07-27
3	6418	9886	3	2004-07-27
4	6418	2076	1	2004-07-27
5	6418	4431	1	2004-07-27
6	6418	8493	2	2004-07-27
7	6418	696	2	2004-07-27
8	6418	6741	1	2004-07-27
9	6418	3881	2	2004-07-27
1	6419	2541	2	2004-07-17
2	6419	5591	1	2004-07-17
3	6419	9727	2	2004-07-17
4	6419	5726	1	2004-07-17
5	6419	2976	1	2004-07-17
1	6420	7577	2	2004-07-30
2	6420	2457	1	2004-07-30
3	6420	7269	1	2004-07-30
4	6420	7305	3	2004-07-30
5	6420	7453	2	2004-07-30
6	6420	8139	1	2004-07-30
7	6420	112	1	2004-07-30
8	6420	227	2	2004-07-30
9	6420	8551	1	2004-07-30
1	6421	8194	3	2004-07-02
1	6422	77	2	2004-07-05
1	6423	9659	3	2004-07-01
2	6423	3575	3	2004-07-01
3	6423	5483	1	2004-07-01
1	6424	6921	1	2004-07-04
2	6424	7646	2	2004-07-04
1	6425	8586	3	2004-07-17
2	6425	9329	1	2004-07-17
3	6425	8974	1	2004-07-17
4	6425	965	3	2004-07-17
5	6425	6267	1	2004-07-17
6	6425	6702	2	2004-07-17
7	6425	3762	2	2004-07-17
8	6425	4038	3	2004-07-17
9	6425	3324	3	2004-07-17
1	6426	5452	1	2004-07-26
1	6427	1350	2	2004-07-11
2	6427	8150	3	2004-07-11
3	6427	2949	3	2004-07-11
4	6427	12	1	2004-07-11
5	6427	8708	1	2004-07-11
6	6427	973	2	2004-07-11
7	6427	2111	3	2004-07-11
8	6427	1493	2	2004-07-11
1	6428	5050	1	2004-07-13
2	6428	1690	3	2004-07-13
3	6428	2300	3	2004-07-13
4	6428	8252	2	2004-07-13
5	6428	239	2	2004-07-13
6	6428	4284	1	2004-07-13
7	6428	8928	1	2004-07-13
1	6429	3800	3	2004-07-05
2	6429	2511	2	2004-07-05
1	6430	494	2	2004-07-12
2	6430	618	2	2004-07-12
3	6430	3841	2	2004-07-12
4	6430	5277	2	2004-07-12
5	6430	3857	3	2004-07-12
1	6431	5892	3	2004-07-09
2	6431	4498	2	2004-07-09
3	6431	9907	2	2004-07-09
1	6432	8440	1	2004-07-21
1	6433	7122	2	2004-07-17
2	6433	4197	3	2004-07-17
3	6433	8884	3	2004-07-17
4	6433	3406	2	2004-07-17
5	6433	3568	3	2004-07-17
6	6433	1735	2	2004-07-17
7	6433	9371	2	2004-07-17
1	6434	83	1	2004-07-29
2	6434	9666	3	2004-07-29
3	6434	2124	3	2004-07-29
4	6434	7274	1	2004-07-29
1	6435	257	3	2004-07-23
2	6435	7153	2	2004-07-23
1	6436	196	2	2004-07-24
1	6437	6855	1	2004-07-26
2	6437	2761	3	2004-07-26
3	6437	5091	1	2004-07-26
4	6437	1556	2	2004-07-26
5	6437	9622	2	2004-07-26
6	6437	1978	3	2004-07-26
7	6437	4243	3	2004-07-26
1	6438	6561	3	2004-07-30
2	6438	4147	2	2004-07-30
3	6438	4425	2	2004-07-30
4	6438	4884	2	2004-07-30
5	6438	2695	1	2004-07-30
6	6438	6550	2	2004-07-30
7	6438	508	2	2004-07-30
8	6438	6437	1	2004-07-30
9	6438	2656	1	2004-07-30
1	6439	7892	3	2004-07-19
2	6439	2627	1	2004-07-19
3	6439	7525	1	2004-07-19
4	6439	8975	3	2004-07-19
5	6439	1757	2	2004-07-19
6	6439	7149	2	2004-07-19
1	6440	6192	2	2004-07-30
2	6440	7449	1	2004-07-30
3	6440	226	3	2004-07-30
4	6440	6145	2	2004-07-30
1	6441	3012	2	2004-07-04
2	6441	3067	1	2004-07-04
3	6441	2735	2	2004-07-04
4	6441	3038	1	2004-07-04
5	6441	7757	1	2004-07-04
6	6441	9020	3	2004-07-04
7	6441	7548	2	2004-07-04
1	6442	1541	2	2004-07-17
2	6442	3189	3	2004-07-17
3	6442	6672	2	2004-07-17
4	6442	6945	1	2004-07-17
5	6442	77	3	2004-07-17
6	6442	1618	3	2004-07-17
7	6442	5504	2	2004-07-17
8	6442	2739	3	2004-07-17
1	6443	5734	1	2004-07-18
2	6443	582	2	2004-07-18
3	6443	1533	3	2004-07-18
4	6443	921	3	2004-07-18
5	6443	5232	3	2004-07-18
6	6443	4903	3	2004-07-18
7	6443	2592	3	2004-07-18
8	6443	5761	3	2004-07-18
1	6444	874	2	2004-07-05
2	6444	9848	2	2004-07-05
1	6445	8061	3	2004-07-26
2	6445	2427	2	2004-07-26
3	6445	1229	1	2004-07-26
4	6445	8546	1	2004-07-26
1	6446	8127	2	2004-07-04
2	6446	3140	1	2004-07-04
3	6446	2703	3	2004-07-04
4	6446	9981	2	2004-07-04
5	6446	1605	1	2004-07-04
6	6446	5792	1	2004-07-04
1	6447	8226	2	2004-07-18
2	6447	7942	2	2004-07-18
3	6447	3011	1	2004-07-18
4	6447	79	2	2004-07-18
1	6448	8091	3	2004-07-11
2	6448	881	2	2004-07-11
3	6448	1318	2	2004-07-11
4	6448	6935	2	2004-07-11
5	6448	2920	3	2004-07-11
1	6449	7002	2	2004-07-26
2	6449	9661	2	2004-07-26
3	6449	8818	3	2004-07-26
4	6449	9659	3	2004-07-26
1	6450	6908	1	2004-07-13
2	6450	2874	2	2004-07-13
3	6450	5016	1	2004-07-13
4	6450	613	2	2004-07-13
1	6451	5952	1	2004-07-23
2	6451	1032	2	2004-07-23
3	6451	7360	1	2004-07-23
4	6451	8203	2	2004-07-23
1	6452	5749	3	2004-07-15
2	6452	317	3	2004-07-15
3	6452	2545	3	2004-07-15
4	6452	4169	3	2004-07-15
1	6453	8007	2	2004-07-25
2	6453	8858	2	2004-07-25
3	6453	5902	3	2004-07-25
1	6454	6036	3	2004-07-29
1	6455	2102	2	2004-07-02
2	6455	8644	3	2004-07-02
3	6455	3424	3	2004-07-02
4	6455	7770	2	2004-07-02
5	6455	6404	1	2004-07-02
1	6456	7312	3	2004-07-17
2	6456	2750	2	2004-07-17
3	6456	2176	3	2004-07-17
4	6456	4943	1	2004-07-17
5	6456	505	2	2004-07-17
6	6456	1817	2	2004-07-17
7	6456	5520	1	2004-07-17
8	6456	779	3	2004-07-17
1	6457	730	2	2004-07-23
2	6457	4850	3	2004-07-23
3	6457	1787	1	2004-07-23
4	6457	437	3	2004-07-23
5	6457	5603	3	2004-07-23
6	6457	5985	1	2004-07-23
1	6458	7386	2	2004-07-20
2	6458	59	3	2004-07-20
3	6458	578	1	2004-07-20
4	6458	4431	2	2004-07-20
5	6458	4035	2	2004-07-20
6	6458	4945	1	2004-07-20
7	6458	8089	3	2004-07-20
8	6458	7169	3	2004-07-20
1	6459	3271	3	2004-07-10
2	6459	2151	3	2004-07-10
3	6459	7170	3	2004-07-10
4	6459	1788	2	2004-07-10
5	6459	6870	1	2004-07-10
1	6460	2146	2	2004-07-07
2	6460	4085	2	2004-07-07
1	6461	9399	3	2004-07-05
2	6461	3856	2	2004-07-05
3	6461	8691	3	2004-07-05
4	6461	8585	2	2004-07-05
5	6461	1959	1	2004-07-05
6	6461	3761	2	2004-07-05
1	6462	4504	3	2004-07-03
2	6462	3387	2	2004-07-03
3	6462	3370	3	2004-07-03
1	6463	2091	2	2004-07-28
2	6463	1069	2	2004-07-28
3	6463	1844	1	2004-07-28
1	6464	2714	2	2004-07-12
2	6464	8445	2	2004-07-12
3	6464	7475	1	2004-07-12
1	6465	719	3	2004-07-28
1	6466	2388	1	2004-07-01
2	6466	9025	2	2004-07-01
3	6466	6109	1	2004-07-01
4	6466	1473	3	2004-07-01
1	6467	9016	2	2004-07-16
2	6467	1174	1	2004-07-16
3	6467	299	3	2004-07-16
4	6467	6402	3	2004-07-16
5	6467	1824	2	2004-07-16
6	6467	5975	2	2004-07-16
7	6467	6208	3	2004-07-16
8	6467	2599	2	2004-07-16
1	6468	52	3	2004-07-03
2	6468	9330	2	2004-07-03
3	6468	9996	1	2004-07-03
1	6469	3720	1	2004-07-11
1	6470	4512	1	2004-07-18
2	6470	3733	2	2004-07-18
3	6470	6448	3	2004-07-18
4	6470	1294	1	2004-07-18
5	6470	6400	2	2004-07-18
6	6470	9004	3	2004-07-18
1	6471	7743	3	2004-07-03
1	6472	2723	2	2004-07-22
1	6473	1336	1	2004-07-05
2	6473	2940	2	2004-07-05
3	6473	3898	3	2004-07-05
4	6473	2181	1	2004-07-05
5	6473	6379	2	2004-07-05
6	6473	3000	1	2004-07-05
7	6473	7367	1	2004-07-05
1	6474	8988	3	2004-07-31
1	6475	6320	3	2004-07-01
1	6476	4617	3	2004-07-17
2	6476	5616	3	2004-07-17
3	6476	2690	3	2004-07-17
1	6477	8345	1	2004-07-14
1	6478	3862	2	2004-07-11
2	6478	3714	1	2004-07-11
3	6478	4332	2	2004-07-11
4	6478	8834	1	2004-07-11
1	6479	2791	2	2004-07-14
2	6479	2564	3	2004-07-14
3	6479	2095	3	2004-07-14
4	6479	4963	2	2004-07-14
5	6479	7692	3	2004-07-14
6	6479	9655	3	2004-07-14
7	6479	9795	3	2004-07-14
8	6479	407	1	2004-07-14
9	6479	3710	2	2004-07-14
1	6480	420	2	2004-07-21
1	6481	4406	2	2004-07-13
2	6481	7975	3	2004-07-13
3	6481	992	1	2004-07-13
4	6481	4603	1	2004-07-13
5	6481	8717	3	2004-07-13
6	6481	7870	2	2004-07-13
7	6481	8755	3	2004-07-13
8	6481	3957	3	2004-07-13
1	6482	9631	3	2004-07-18
2	6482	6802	1	2004-07-18
3	6482	8507	3	2004-07-18
4	6482	5946	1	2004-07-18
5	6482	6475	1	2004-07-18
6	6482	932	1	2004-07-18
7	6482	7686	3	2004-07-18
8	6482	8077	3	2004-07-18
9	6482	9444	1	2004-07-18
1	6483	4568	1	2004-07-06
2	6483	7155	3	2004-07-06
3	6483	9548	1	2004-07-06
4	6483	2888	1	2004-07-06
5	6483	1908	1	2004-07-06
6	6483	9532	3	2004-07-06
7	6483	3142	3	2004-07-06
8	6483	5931	3	2004-07-06
9	6483	576	1	2004-07-06
1	6484	413	1	2004-07-04
2	6484	7394	3	2004-07-04
3	6484	4041	3	2004-07-04
4	6484	8016	2	2004-07-04
5	6484	8787	1	2004-07-04
6	6484	7285	2	2004-07-04
7	6484	1108	3	2004-07-04
8	6484	8617	2	2004-07-04
1	6485	9234	3	2004-07-26
2	6485	5675	2	2004-07-26
3	6485	8743	2	2004-07-26
4	6485	7568	3	2004-07-26
5	6485	7756	1	2004-07-26
6	6485	8491	3	2004-07-26
7	6485	2215	2	2004-07-26
1	6486	2541	2	2004-07-25
2	6486	8622	3	2004-07-25
3	6486	9766	3	2004-07-25
4	6486	6657	3	2004-07-25
5	6486	3725	2	2004-07-25
6	6486	8907	1	2004-07-25
1	6487	3304	3	2004-07-08
2	6487	4322	1	2004-07-08
3	6487	8410	1	2004-07-08
4	6487	1724	3	2004-07-08
5	6487	245	2	2004-07-08
6	6487	2785	3	2004-07-08
7	6487	194	3	2004-07-08
8	6487	4307	1	2004-07-08
1	6488	2657	3	2004-07-06
2	6488	9797	2	2004-07-06
1	6489	6843	2	2004-07-13
2	6489	4447	1	2004-07-13
3	6489	5150	3	2004-07-13
4	6489	1018	2	2004-07-13
5	6489	845	1	2004-07-13
6	6489	460	1	2004-07-13
1	6490	1067	2	2004-07-21
2	6490	9606	1	2004-07-21
3	6490	6593	1	2004-07-21
4	6490	4129	3	2004-07-21
5	6490	1380	2	2004-07-21
6	6490	5631	2	2004-07-21
7	6490	2629	1	2004-07-21
1	6491	9618	2	2004-07-06
2	6491	4946	1	2004-07-06
3	6491	7473	2	2004-07-06
4	6491	3376	3	2004-07-06
5	6491	6881	1	2004-07-06
6	6491	1175	2	2004-07-06
1	6492	4955	2	2004-07-22
2	6492	8697	3	2004-07-22
3	6492	5745	1	2004-07-22
4	6492	3008	1	2004-07-22
5	6492	5434	2	2004-07-22
6	6492	3626	3	2004-07-22
1	6493	6303	3	2004-07-16
2	6493	5359	2	2004-07-16
3	6493	4079	3	2004-07-16
4	6493	1707	1	2004-07-16
5	6493	8788	1	2004-07-16
1	6494	2248	1	2004-07-23
2	6494	3595	1	2004-07-23
3	6494	9159	3	2004-07-23
4	6494	1021	1	2004-07-23
5	6494	714	2	2004-07-23
6	6494	7803	2	2004-07-23
7	6494	3618	1	2004-07-23
1	6495	5247	1	2004-07-21
2	6495	6807	3	2004-07-21
3	6495	1726	3	2004-07-21
1	6496	6228	2	2004-07-01
2	6496	4580	3	2004-07-01
3	6496	6590	3	2004-07-01
4	6496	9419	2	2004-07-01
5	6496	7513	1	2004-07-01
6	6496	7915	3	2004-07-01
7	6496	6893	2	2004-07-01
1	6497	7470	2	2004-07-08
2	6497	2325	1	2004-07-08
3	6497	9252	3	2004-07-08
4	6497	2042	1	2004-07-08
5	6497	7645	1	2004-07-08
6	6497	1490	3	2004-07-08
7	6497	9805	3	2004-07-08
8	6497	5552	2	2004-07-08
9	6497	6192	1	2004-07-08
1	6498	6050	2	2004-07-08
1	6499	3452	1	2004-07-26
1	6500	3637	2	2004-07-01
2	6500	1613	2	2004-07-01
3	6500	6635	3	2004-07-01
1	6501	5842	2	2004-07-25
2	6501	2192	1	2004-07-25
3	6501	5988	2	2004-07-25
4	6501	7644	2	2004-07-25
5	6501	4820	2	2004-07-25
6	6501	9683	1	2004-07-25
7	6501	6634	1	2004-07-25
8	6501	3979	1	2004-07-25
1	6502	6616	2	2004-07-05
2	6502	3419	3	2004-07-05
3	6502	321	1	2004-07-05
4	6502	7485	3	2004-07-05
5	6502	8178	2	2004-07-05
6	6502	6130	2	2004-07-05
7	6502	9625	3	2004-07-05
1	6503	9490	3	2004-07-19
2	6503	7388	3	2004-07-19
3	6503	1007	2	2004-07-19
4	6503	377	2	2004-07-19
1	6504	9489	2	2004-07-13
2	6504	9755	1	2004-07-13
3	6504	3964	1	2004-07-13
4	6504	2960	1	2004-07-13
5	6504	8398	1	2004-07-13
1	6505	2848	1	2004-07-23
2	6505	2462	2	2004-07-23
3	6505	4904	1	2004-07-23
4	6505	3807	1	2004-07-23
5	6505	1124	2	2004-07-23
6	6505	6313	1	2004-07-23
7	6505	9798	1	2004-07-23
1	6506	4653	2	2004-07-11
2	6506	5624	3	2004-07-11
3	6506	5361	3	2004-07-11
1	6507	8284	2	2004-07-01
2	6507	4140	1	2004-07-01
3	6507	6085	2	2004-07-01
4	6507	7048	1	2004-07-01
5	6507	8553	1	2004-07-01
6	6507	3280	3	2004-07-01
7	6507	5666	3	2004-07-01
1	6508	4381	2	2004-07-04
2	6508	7124	3	2004-07-04
3	6508	828	1	2004-07-04
4	6508	7650	2	2004-07-04
1	6509	5004	3	2004-07-05
1	6510	5745	2	2004-07-19
2	6510	3002	2	2004-07-19
1	6511	5874	2	2004-07-23
2	6511	8389	2	2004-07-23
3	6511	9557	1	2004-07-23
1	6512	9428	3	2004-07-05
2	6512	8442	1	2004-07-05
3	6512	7166	3	2004-07-05
1	6513	1312	2	2004-07-06
2	6513	9750	3	2004-07-06
3	6513	2382	1	2004-07-06
4	6513	1354	3	2004-07-06
5	6513	9033	2	2004-07-06
6	6513	2567	2	2004-07-06
7	6513	479	1	2004-07-06
1	6514	6716	2	2004-07-03
2	6514	4471	2	2004-07-03
1	6515	1300	3	2004-07-16
2	6515	4313	3	2004-07-16
1	6516	2681	2	2004-07-20
2	6516	8948	2	2004-07-20
3	6516	5912	3	2004-07-20
4	6516	9363	3	2004-07-20
5	6516	2885	3	2004-07-20
6	6516	9434	2	2004-07-20
1	6517	8684	1	2004-07-31
2	6517	2735	2	2004-07-31
3	6517	3275	3	2004-07-31
4	6517	5807	2	2004-07-31
5	6517	8346	1	2004-07-31
6	6517	2490	2	2004-07-31
1	6518	2650	3	2004-07-18
2	6518	2459	3	2004-07-18
3	6518	7915	1	2004-07-18
4	6518	7039	1	2004-07-18
5	6518	1662	2	2004-07-18
6	6518	4475	1	2004-07-18
7	6518	9630	1	2004-07-18
8	6518	8130	3	2004-07-18
1	6519	501	3	2004-07-03
2	6519	8577	3	2004-07-03
3	6519	7901	1	2004-07-03
4	6519	3638	2	2004-07-03
1	6520	4561	2	2004-07-24
1	6521	3276	3	2004-07-27
2	6521	2166	3	2004-07-27
3	6521	9549	1	2004-07-27
4	6521	8115	3	2004-07-27
5	6521	109	3	2004-07-27
6	6521	8543	1	2004-07-27
1	6522	7889	3	2004-07-09
2	6522	2488	1	2004-07-09
1	6523	28	1	2004-07-05
2	6523	8007	3	2004-07-05
3	6523	3188	2	2004-07-05
4	6523	4377	2	2004-07-05
1	6524	8338	1	2004-07-08
2	6524	9592	3	2004-07-08
1	6525	7178	1	2004-07-04
2	6525	5436	2	2004-07-04
3	6525	8160	3	2004-07-04
4	6525	6593	3	2004-07-04
1	6526	3457	1	2004-07-25
2	6526	6565	2	2004-07-25
3	6526	5409	1	2004-07-25
4	6526	3108	3	2004-07-25
5	6526	7483	3	2004-07-25
6	6526	9686	2	2004-07-25
7	6526	9647	3	2004-07-25
8	6526	4266	1	2004-07-25
1	6527	5188	1	2004-07-23
2	6527	9655	2	2004-07-23
3	6527	8188	2	2004-07-23
4	6527	2917	2	2004-07-23
5	6527	8992	2	2004-07-23
1	6528	9093	1	2004-07-13
1	6529	9520	3	2004-07-05
2	6529	4734	3	2004-07-05
3	6529	9162	3	2004-07-05
4	6529	9983	2	2004-07-05
5	6529	3792	2	2004-07-05
6	6529	1161	3	2004-07-05
7	6529	5077	1	2004-07-05
8	6529	2327	1	2004-07-05
9	6529	7062	2	2004-07-05
1	6530	8502	3	2004-07-29
2	6530	3723	3	2004-07-29
3	6530	650	2	2004-07-29
1	6531	733	3	2004-07-31
2	6531	8482	3	2004-07-31
3	6531	7798	3	2004-07-31
4	6531	6466	1	2004-07-31
5	6531	3276	3	2004-07-31
6	6531	570	3	2004-07-31
7	6531	8441	1	2004-07-31
8	6531	1617	2	2004-07-31
9	6531	8138	1	2004-07-31
1	6532	7568	3	2004-07-05
1	6533	9066	3	2004-07-24
2	6533	6762	3	2004-07-24
3	6533	5899	2	2004-07-24
4	6533	9692	2	2004-07-24
5	6533	3708	2	2004-07-24
6	6533	5286	3	2004-07-24
7	6533	3782	2	2004-07-24
1	6534	7724	3	2004-07-17
2	6534	7876	3	2004-07-17
3	6534	6233	1	2004-07-17
4	6534	9337	2	2004-07-17
5	6534	9910	3	2004-07-17
6	6534	2018	1	2004-07-17
7	6534	4436	1	2004-07-17
1	6535	6441	1	2004-07-01
2	6535	9635	1	2004-07-01
3	6535	6728	2	2004-07-01
4	6535	7131	1	2004-07-01
5	6535	776	1	2004-07-01
6	6535	2732	3	2004-07-01
1	6536	9736	1	2004-07-30
2	6536	9325	3	2004-07-30
3	6536	6447	3	2004-07-30
4	6536	6060	3	2004-07-30
5	6536	2176	1	2004-07-30
6	6536	9548	1	2004-07-30
7	6536	1693	1	2004-07-30
1	6537	8281	3	2004-07-26
2	6537	2710	2	2004-07-26
3	6537	8238	2	2004-07-26
4	6537	7878	1	2004-07-26
5	6537	3011	3	2004-07-26
6	6537	1425	3	2004-07-26
7	6537	4589	1	2004-07-26
8	6537	2071	2	2004-07-26
1	6538	6983	2	2004-07-01
2	6538	6786	2	2004-07-01
3	6538	7539	3	2004-07-01
4	6538	6957	2	2004-07-01
5	6538	6612	3	2004-07-01
6	6538	3483	2	2004-07-01
1	6539	9678	3	2004-07-18
2	6539	4890	1	2004-07-18
3	6539	5478	2	2004-07-18
4	6539	2113	1	2004-07-18
1	6540	2701	3	2004-07-24
2	6540	3997	3	2004-07-24
3	6540	2449	1	2004-07-24
4	6540	6212	3	2004-07-24
5	6540	9261	1	2004-07-24
6	6540	5681	2	2004-07-24
7	6540	1126	3	2004-07-24
1	6541	730	2	2004-07-03
1	6542	1934	3	2004-07-29
2	6542	4793	3	2004-07-29
3	6542	4016	3	2004-07-29
4	6542	7113	3	2004-07-29
5	6542	5897	1	2004-07-29
1	6543	8333	1	2004-07-20
2	6543	5781	2	2004-07-20
3	6543	7024	3	2004-07-20
1	6544	8854	2	2004-07-10
2	6544	3565	3	2004-07-10
3	6544	62	1	2004-07-10
4	6544	2828	1	2004-07-10
5	6544	1118	3	2004-07-10
6	6544	1403	2	2004-07-10
7	6544	6392	3	2004-07-10
8	6544	1851	1	2004-07-10
1	6545	861	3	2004-07-30
2	6545	2668	2	2004-07-30
1	6546	7477	3	2004-07-10
2	6546	4686	2	2004-07-10
3	6546	1703	3	2004-07-10
4	6546	4432	1	2004-07-10
5	6546	9535	3	2004-07-10
6	6546	3760	1	2004-07-10
1	6547	3677	3	2004-07-16
2	6547	3559	1	2004-07-16
1	6548	3157	3	2004-07-19
2	6548	3386	2	2004-07-19
3	6548	7175	3	2004-07-19
4	6548	2288	2	2004-07-19
5	6548	4191	3	2004-07-19
6	6548	981	2	2004-07-19
7	6548	5223	2	2004-07-19
1	6549	5410	3	2004-07-24
2	6549	6579	1	2004-07-24
1	6550	3556	2	2004-07-28
2	6550	6573	3	2004-07-28
3	6550	1464	3	2004-07-28
1	6551	1781	3	2004-07-19
2	6551	7682	2	2004-07-19
3	6551	5125	3	2004-07-19
1	6552	5105	3	2004-07-06
2	6552	938	1	2004-07-06
3	6552	4300	3	2004-07-06
4	6552	1711	1	2004-07-06
5	6552	7771	1	2004-07-06
6	6552	5503	1	2004-07-06
7	6552	5261	1	2004-07-06
8	6552	9699	3	2004-07-06
9	6552	1805	2	2004-07-06
1	6553	5820	2	2004-07-05
2	6553	9324	1	2004-07-05
3	6553	4931	1	2004-07-05
4	6553	1291	3	2004-07-05
1	6554	6910	1	2004-07-03
2	6554	9162	3	2004-07-03
1	6555	8259	2	2004-07-10
2	6555	752	3	2004-07-10
3	6555	1147	1	2004-07-10
4	6555	3513	1	2004-07-10
5	6555	224	1	2004-07-10
6	6555	6071	2	2004-07-10
7	6555	8366	2	2004-07-10
8	6555	6987	1	2004-07-10
1	6556	4673	3	2004-07-21
2	6556	8937	1	2004-07-21
3	6556	8106	3	2004-07-21
4	6556	203	1	2004-07-21
5	6556	5031	3	2004-07-21
6	6556	9956	1	2004-07-21
7	6556	3789	1	2004-07-21
1	6557	7654	2	2004-07-04
2	6557	6857	2	2004-07-04
3	6557	9531	2	2004-07-04
4	6557	9119	2	2004-07-04
5	6557	8518	2	2004-07-04
1	6558	8873	1	2004-07-15
2	6558	1049	3	2004-07-15
3	6558	25	1	2004-07-15
4	6558	8257	2	2004-07-15
5	6558	617	3	2004-07-15
6	6558	8344	2	2004-07-15
7	6558	8920	3	2004-07-15
8	6558	9341	1	2004-07-15
9	6558	4349	3	2004-07-15
1	6559	6427	3	2004-07-18
2	6559	1717	2	2004-07-18
3	6559	5536	2	2004-07-18
4	6559	5764	3	2004-07-18
5	6559	5977	2	2004-07-18
1	6560	8277	3	2004-07-02
1	6561	3299	3	2004-07-18
2	6561	3463	1	2004-07-18
3	6561	9184	3	2004-07-18
4	6561	9632	2	2004-07-18
1	6562	185	1	2004-07-28
2	6562	388	2	2004-07-28
3	6562	8281	2	2004-07-28
4	6562	4246	2	2004-07-28
5	6562	786	2	2004-07-28
1	6563	2268	1	2004-07-04
2	6563	8452	1	2004-07-04
3	6563	4575	1	2004-07-04
4	6563	7349	3	2004-07-04
5	6563	4388	2	2004-07-04
6	6563	5849	2	2004-07-04
7	6563	1386	2	2004-07-04
8	6563	4369	1	2004-07-04
9	6563	308	2	2004-07-04
1	6564	6845	2	2004-07-10
2	6564	5748	3	2004-07-10
1	6565	6589	1	2004-07-29
2	6565	5088	2	2004-07-29
3	6565	2644	3	2004-07-29
4	6565	6790	3	2004-07-29
1	6566	5198	3	2004-07-24
2	6566	8413	3	2004-07-24
3	6566	9349	3	2004-07-24
4	6566	4120	1	2004-07-24
1	6567	8912	3	2004-07-30
2	6567	3890	3	2004-07-30
3	6567	6825	2	2004-07-30
4	6567	2513	2	2004-07-30
5	6567	6213	3	2004-07-30
6	6567	8454	3	2004-07-30
1	6568	6422	2	2004-07-23
2	6568	8512	1	2004-07-23
3	6568	3285	3	2004-07-23
4	6568	1185	1	2004-07-23
5	6568	5645	2	2004-07-23
1	6569	1318	3	2004-07-17
2	6569	9034	2	2004-07-17
3	6569	6735	2	2004-07-17
4	6569	9125	3	2004-07-17
5	6569	9271	2	2004-07-17
6	6569	6849	3	2004-07-17
7	6569	4194	2	2004-07-17
8	6569	2968	1	2004-07-17
9	6569	9075	3	2004-07-17
1	6570	4511	1	2004-07-27
2	6570	4335	1	2004-07-27
1	6571	8764	2	2004-07-24
2	6571	5801	3	2004-07-24
3	6571	1738	1	2004-07-24
4	6571	3655	1	2004-07-24
5	6571	1783	1	2004-07-24
6	6571	6200	3	2004-07-24
7	6571	649	1	2004-07-24
1	6572	3005	1	2004-07-09
2	6572	9403	2	2004-07-09
1	6573	4068	2	2004-07-12
2	6573	7416	3	2004-07-12
3	6573	892	2	2004-07-12
4	6573	5813	3	2004-07-12
5	6573	3977	3	2004-07-12
6	6573	9229	3	2004-07-12
7	6573	8412	1	2004-07-12
8	6573	556	2	2004-07-12
1	6574	4821	3	2004-07-30
2	6574	4200	3	2004-07-30
3	6574	295	2	2004-07-30
1	6575	1741	1	2004-07-06
2	6575	1739	3	2004-07-06
3	6575	864	1	2004-07-06
4	6575	5337	3	2004-07-06
5	6575	9324	3	2004-07-06
6	6575	4226	3	2004-07-06
7	6575	6944	1	2004-07-06
8	6575	9563	3	2004-07-06
1	6576	1587	2	2004-07-23
2	6576	694	2	2004-07-23
3	6576	1349	1	2004-07-23
1	6577	1225	2	2004-07-30
2	6577	8484	1	2004-07-30
3	6577	5737	3	2004-07-30
4	6577	5594	1	2004-07-30
5	6577	6023	2	2004-07-30
6	6577	385	1	2004-07-30
7	6577	3470	3	2004-07-30
1	6578	2236	2	2004-07-09
1	6579	9609	3	2004-07-08
2	6579	4069	3	2004-07-08
3	6579	1585	3	2004-07-08
1	6580	5772	1	2004-07-19
2	6580	3729	1	2004-07-19
3	6580	2295	3	2004-07-19
4	6580	6284	1	2004-07-19
1	6581	2786	2	2004-07-31
2	6581	3018	2	2004-07-31
3	6581	8363	2	2004-07-31
1	6582	3816	1	2004-07-28
2	6582	7449	2	2004-07-28
3	6582	1459	2	2004-07-28
4	6582	8209	3	2004-07-28
5	6582	7727	2	2004-07-28
6	6582	8168	1	2004-07-28
7	6582	5347	1	2004-07-28
8	6582	1206	1	2004-07-28
1	6583	4089	2	2004-07-10
2	6583	7982	3	2004-07-10
3	6583	9191	2	2004-07-10
1	6584	6487	2	2004-07-08
1	6585	7281	3	2004-07-11
2	6585	1948	2	2004-07-11
3	6585	3164	1	2004-07-11
4	6585	6462	3	2004-07-11
5	6585	578	3	2004-07-11
1	6586	6868	1	2004-07-01
2	6586	5693	2	2004-07-01
1	6587	2917	1	2004-07-01
2	6587	3567	3	2004-07-01
3	6587	8526	3	2004-07-01
1	6588	8683	2	2004-07-11
1	6589	357	2	2004-07-18
2	6589	9754	1	2004-07-18
1	6590	1585	3	2004-07-27
2	6590	192	1	2004-07-27
3	6590	2594	1	2004-07-27
4	6590	4224	2	2004-07-27
5	6590	4337	3	2004-07-27
1	6591	2363	3	2004-07-16
2	6591	8872	1	2004-07-16
3	6591	1078	2	2004-07-16
4	6591	2892	2	2004-07-16
5	6591	6585	1	2004-07-16
6	6591	10	2	2004-07-16
7	6591	3745	3	2004-07-16
8	6591	4964	2	2004-07-16
1	6592	8198	2	2004-07-12
2	6592	5402	1	2004-07-12
3	6592	1580	3	2004-07-12
4	6592	212	2	2004-07-12
1	6593	2129	2	2004-07-09
2	6593	6009	1	2004-07-09
3	6593	8117	3	2004-07-09
4	6593	8460	2	2004-07-09
5	6593	2149	3	2004-07-09
1	6594	1657	1	2004-07-04
2	6594	2550	2	2004-07-04
3	6594	4796	1	2004-07-04
4	6594	1201	1	2004-07-04
5	6594	3168	1	2004-07-04
6	6594	9936	2	2004-07-04
1	6595	7501	1	2004-07-29
2	6595	7640	2	2004-07-29
3	6595	3826	2	2004-07-29
4	6595	2410	1	2004-07-29
1	6596	452	3	2004-07-02
2	6596	7497	1	2004-07-02
1	6597	793	3	2004-07-27
2	6597	3479	2	2004-07-27
3	6597	1218	2	2004-07-27
1	6598	4513	2	2004-07-23
2	6598	6449	1	2004-07-23
3	6598	6962	1	2004-07-23
4	6598	7908	3	2004-07-23
5	6598	2559	3	2004-07-23
6	6598	3931	1	2004-07-23
1	6599	6489	3	2004-07-31
2	6599	7401	2	2004-07-31
3	6599	2787	3	2004-07-31
4	6599	2165	2	2004-07-31
5	6599	2153	2	2004-07-31
6	6599	9681	3	2004-07-31
7	6599	3875	2	2004-07-31
1	6600	539	2	2004-07-17
2	6600	2043	3	2004-07-17
1	6601	7915	3	2004-07-17
2	6601	3729	3	2004-07-17
3	6601	4025	1	2004-07-17
4	6601	8440	1	2004-07-17
5	6601	3944	1	2004-07-17
6	6601	9619	2	2004-07-17
7	6601	7493	1	2004-07-17
8	6601	9491	3	2004-07-17
9	6601	1262	2	2004-07-17
1	6602	8350	1	2004-07-09
2	6602	7935	1	2004-07-09
1	6603	2700	1	2004-07-03
2	6603	4216	2	2004-07-03
3	6603	1843	3	2004-07-03
4	6603	6645	1	2004-07-03
5	6603	9665	1	2004-07-03
6	6603	1509	3	2004-07-03
7	6603	6696	3	2004-07-03
1	6604	9550	3	2004-07-04
2	6604	8897	1	2004-07-04
3	6604	866	3	2004-07-04
1	6605	2152	1	2004-07-12
2	6605	1874	2	2004-07-12
3	6605	5540	2	2004-07-12
4	6605	1278	3	2004-07-12
1	6606	8510	3	2004-07-14
2	6606	3276	2	2004-07-14
3	6606	8173	2	2004-07-14
4	6606	1391	2	2004-07-14
1	6607	2242	2	2004-07-21
2	6607	2788	2	2004-07-21
3	6607	2987	1	2004-07-21
4	6607	159	2	2004-07-21
5	6607	3059	1	2004-07-21
1	6608	5981	1	2004-07-31
2	6608	9189	2	2004-07-31
1	6609	2903	1	2004-07-20
2	6609	4047	2	2004-07-20
3	6609	5333	1	2004-07-20
4	6609	5234	3	2004-07-20
5	6609	6234	3	2004-07-20
6	6609	2842	3	2004-07-20
7	6609	3306	2	2004-07-20
8	6609	9448	2	2004-07-20
9	6609	967	1	2004-07-20
1	6610	2220	3	2004-07-18
2	6610	6064	1	2004-07-18
3	6610	729	1	2004-07-18
4	6610	9106	2	2004-07-18
1	6611	6302	3	2004-07-07
2	6611	6960	1	2004-07-07
3	6611	8520	1	2004-07-07
4	6611	9009	1	2004-07-07
5	6611	2215	1	2004-07-07
6	6611	7190	1	2004-07-07
1	6612	9110	2	2004-07-18
2	6612	4890	1	2004-07-18
1	6613	3458	1	2004-07-08
2	6613	6630	2	2004-07-08
3	6613	3852	1	2004-07-08
1	6614	1688	3	2004-07-07
2	6614	2101	1	2004-07-07
3	6614	909	2	2004-07-07
4	6614	3011	3	2004-07-07
5	6614	5977	3	2004-07-07
6	6614	6254	1	2004-07-07
7	6614	64	2	2004-07-07
8	6614	5418	2	2004-07-07
9	6614	6694	3	2004-07-07
1	6615	1275	3	2004-07-19
2	6615	5044	2	2004-07-19
3	6615	8651	3	2004-07-19
4	6615	5280	3	2004-07-19
5	6615	5898	3	2004-07-19
6	6615	9224	3	2004-07-19
7	6615	7664	1	2004-07-19
8	6615	2313	1	2004-07-19
9	6615	8230	3	2004-07-19
1	6616	9847	2	2004-07-30
2	6616	4481	2	2004-07-30
3	6616	1626	1	2004-07-30
4	6616	5972	1	2004-07-30
5	6616	9753	3	2004-07-30
6	6616	9974	2	2004-07-30
7	6616	2373	3	2004-07-30
8	6616	1787	3	2004-07-30
9	6616	8302	3	2004-07-30
1	6617	7658	3	2004-07-15
2	6617	2958	2	2004-07-15
3	6617	6286	1	2004-07-15
1	6618	8572	2	2004-07-02
1	6619	2682	2	2004-07-21
2	6619	9975	1	2004-07-21
3	6619	1365	1	2004-07-21
1	6620	837	2	2004-07-04
2	6620	7105	2	2004-07-04
3	6620	6903	2	2004-07-04
4	6620	4516	3	2004-07-04
5	6620	650	1	2004-07-04
6	6620	2280	1	2004-07-04
7	6620	5521	2	2004-07-04
8	6620	1237	2	2004-07-04
9	6620	657	3	2004-07-04
1	6621	4042	1	2004-07-14
2	6621	9625	2	2004-07-14
3	6621	3045	1	2004-07-14
4	6621	8558	1	2004-07-14
5	6621	484	3	2004-07-14
6	6621	7663	3	2004-07-14
7	6621	5914	2	2004-07-14
1	6622	1231	3	2004-07-08
2	6622	4019	3	2004-07-08
3	6622	932	2	2004-07-08
1	6623	9060	2	2004-07-03
2	6623	2103	1	2004-07-03
3	6623	4670	1	2004-07-03
4	6623	8508	3	2004-07-03
5	6623	2631	3	2004-07-03
1	6624	702	1	2004-07-03
2	6624	2986	1	2004-07-03
3	6624	2802	3	2004-07-03
4	6624	6052	2	2004-07-03
5	6624	4114	1	2004-07-03
6	6624	783	2	2004-07-03
7	6624	5326	1	2004-07-03
8	6624	6633	3	2004-07-03
1	6625	8794	3	2004-07-21
2	6625	589	3	2004-07-21
3	6625	4931	1	2004-07-21
4	6625	4366	2	2004-07-21
5	6625	6333	1	2004-07-21
6	6625	4109	3	2004-07-21
7	6625	3198	3	2004-07-21
8	6625	87	2	2004-07-21
1	6626	6208	1	2004-07-14
2	6626	3661	1	2004-07-14
3	6626	2441	1	2004-07-14
4	6626	107	3	2004-07-14
5	6626	5986	1	2004-07-14
6	6626	8060	2	2004-07-14
7	6626	9871	3	2004-07-14
8	6626	2080	2	2004-07-14
1	6627	7271	2	2004-07-06
2	6627	5234	1	2004-07-06
3	6627	1691	2	2004-07-06
4	6627	6468	2	2004-07-06
5	6627	1458	2	2004-07-06
6	6627	4810	3	2004-07-06
7	6627	7313	3	2004-07-06
8	6627	9197	3	2004-07-06
1	6628	1958	3	2004-07-28
2	6628	9527	1	2004-07-28
3	6628	5659	1	2004-07-28
4	6628	6630	3	2004-07-28
5	6628	8052	3	2004-07-28
1	6629	5790	2	2004-07-18
1	6630	8756	2	2004-07-20
2	6630	5400	2	2004-07-20
3	6630	2880	2	2004-07-20
4	6630	5821	1	2004-07-20
5	6630	3900	2	2004-07-20
6	6630	6391	2	2004-07-20
7	6630	1784	2	2004-07-20
1	6631	4968	2	2004-07-24
2	6631	1433	1	2004-07-24
3	6631	896	1	2004-07-24
4	6631	1651	3	2004-07-24
1	6632	5664	3	2004-07-21
2	6632	564	1	2004-07-21
3	6632	3765	2	2004-07-21
4	6632	5661	3	2004-07-21
5	6632	5085	3	2004-07-21
6	6632	4358	1	2004-07-21
1	6633	3583	2	2004-07-17
2	6633	7417	3	2004-07-17
3	6633	489	3	2004-07-17
1	6634	8070	3	2004-07-29
1	6635	4708	2	2004-07-28
2	6635	5550	3	2004-07-28
3	6635	8714	1	2004-07-28
4	6635	8058	2	2004-07-28
5	6635	770	1	2004-07-28
1	6636	9288	1	2004-07-17
2	6636	7581	3	2004-07-17
3	6636	690	3	2004-07-17
1	6637	825	3	2004-07-18
2	6637	6104	3	2004-07-18
3	6637	4533	1	2004-07-18
4	6637	4132	3	2004-07-18
5	6637	6082	3	2004-07-18
6	6637	7713	2	2004-07-18
7	6637	891	2	2004-07-18
1	6638	7846	3	2004-07-27
2	6638	6534	3	2004-07-27
3	6638	8880	2	2004-07-27
4	6638	3838	3	2004-07-27
1	6639	6941	1	2004-07-07
2	6639	9158	1	2004-07-07
1	6640	2931	3	2004-07-31
2	6640	3786	1	2004-07-31
3	6640	4732	2	2004-07-31
4	6640	6414	1	2004-07-31
1	6641	1340	2	2004-07-20
2	6641	1315	1	2004-07-20
3	6641	7840	2	2004-07-20
4	6641	9789	1	2004-07-20
1	6642	9617	1	2004-07-15
2	6642	4527	3	2004-07-15
1	6643	8318	3	2004-07-14
2	6643	8078	1	2004-07-14
3	6643	2157	2	2004-07-14
4	6643	6376	3	2004-07-14
5	6643	9089	2	2004-07-14
6	6643	2675	1	2004-07-14
7	6643	7297	2	2004-07-14
1	6644	5158	2	2004-07-03
1	6645	7628	3	2004-07-31
2	6645	8932	1	2004-07-31
3	6645	8074	1	2004-07-31
4	6645	9567	2	2004-07-31
5	6645	106	3	2004-07-31
6	6645	9441	1	2004-07-31
7	6645	2135	2	2004-07-31
8	6645	756	1	2004-07-31
9	6645	9386	2	2004-07-31
1	6646	1818	2	2004-07-06
2	6646	2735	3	2004-07-06
3	6646	244	1	2004-07-06
1	6647	5101	1	2004-07-12
2	6647	3550	1	2004-07-12
1	6648	759	3	2004-07-11
2	6648	5730	1	2004-07-11
3	6648	4822	2	2004-07-11
4	6648	4117	2	2004-07-11
1	6649	8067	1	2004-07-31
2	6649	3895	1	2004-07-31
3	6649	9682	2	2004-07-31
4	6649	3262	2	2004-07-31
5	6649	9546	2	2004-07-31
6	6649	4888	2	2004-07-31
7	6649	5801	3	2004-07-31
1	6650	2629	1	2004-07-25
2	6650	6389	3	2004-07-25
3	6650	5205	1	2004-07-25
4	6650	4844	3	2004-07-25
5	6650	5417	2	2004-07-25
6	6650	5089	2	2004-07-25
7	6650	2093	1	2004-07-25
1	6651	124	3	2004-07-28
2	6651	2164	3	2004-07-28
3	6651	2282	3	2004-07-28
4	6651	4315	3	2004-07-28
5	6651	5488	1	2004-07-28
6	6651	7244	3	2004-07-28
7	6651	9518	3	2004-07-28
8	6651	9351	2	2004-07-28
1	6652	3876	1	2004-07-26
2	6652	7832	3	2004-07-26
3	6652	8837	3	2004-07-26
1	6653	6541	2	2004-07-07
2	6653	3290	3	2004-07-07
3	6653	5701	2	2004-07-07
4	6653	5755	1	2004-07-07
5	6653	3654	1	2004-07-07
6	6653	2149	1	2004-07-07
1	6654	7572	3	2004-07-26
2	6654	2188	2	2004-07-26
3	6654	2071	2	2004-07-26
4	6654	7219	3	2004-07-26
5	6654	5028	2	2004-07-26
6	6654	9825	3	2004-07-26
7	6654	3904	2	2004-07-26
1	6655	9148	3	2004-07-10
2	6655	2081	2	2004-07-10
3	6655	7482	2	2004-07-10
4	6655	6144	3	2004-07-10
5	6655	6630	2	2004-07-10
6	6655	1296	3	2004-07-10
1	6656	3555	3	2004-07-07
2	6656	309	1	2004-07-07
3	6656	8367	2	2004-07-07
4	6656	6829	3	2004-07-07
1	6657	1177	2	2004-07-08
2	6657	2210	1	2004-07-08
3	6657	3157	2	2004-07-08
4	6657	5226	1	2004-07-08
5	6657	24	1	2004-07-08
6	6657	268	2	2004-07-08
1	6658	431	1	2004-07-18
2	6658	2097	2	2004-07-18
3	6658	8912	1	2004-07-18
4	6658	4759	3	2004-07-18
5	6658	7741	1	2004-07-18
6	6658	5469	1	2004-07-18
7	6658	2320	3	2004-07-18
8	6658	5923	2	2004-07-18
1	6659	2423	3	2004-07-16
2	6659	8879	1	2004-07-16
3	6659	415	3	2004-07-16
4	6659	9101	2	2004-07-16
5	6659	711	1	2004-07-16
6	6659	4059	1	2004-07-16
7	6659	3599	2	2004-07-16
8	6659	5126	1	2004-07-16
1	6660	1471	2	2004-07-27
2	6660	6523	2	2004-07-27
3	6660	4650	1	2004-07-27
4	6660	7288	3	2004-07-27
5	6660	578	1	2004-07-27
6	6660	7975	1	2004-07-27
1	6661	6000	2	2004-07-01
1	6662	7851	1	2004-07-22
1	6663	2860	2	2004-07-22
2	6663	1848	2	2004-07-22
3	6663	8851	3	2004-07-22
4	6663	8122	2	2004-07-22
5	6663	815	2	2004-07-22
1	6664	4393	3	2004-07-11
2	6664	8062	3	2004-07-11
1	6665	771	1	2004-07-23
2	6665	4843	3	2004-07-23
3	6665	3387	1	2004-07-23
4	6665	1598	3	2004-07-23
1	6666	8789	3	2004-07-23
2	6666	7594	3	2004-07-23
3	6666	3140	3	2004-07-23
4	6666	2319	2	2004-07-23
5	6666	9801	3	2004-07-23
6	6666	7583	2	2004-07-23
7	6666	5504	2	2004-07-23
8	6666	4034	1	2004-07-23
9	6666	9705	3	2004-07-23
1	6667	9097	2	2004-07-21
2	6667	3420	1	2004-07-21
1	6668	22	2	2004-07-04
2	6668	1519	3	2004-07-04
1	6669	1033	2	2004-07-03
2	6669	2003	3	2004-07-03
3	6669	17	3	2004-07-03
1	6670	2473	3	2004-07-14
2	6670	4439	1	2004-07-14
3	6670	8582	2	2004-07-14
4	6670	6881	1	2004-07-14
1	6671	9851	1	2004-07-14
2	6671	3320	1	2004-07-14
3	6671	434	2	2004-07-14
4	6671	6029	2	2004-07-14
5	6671	7338	3	2004-07-14
6	6671	2280	3	2004-07-14
7	6671	5676	1	2004-07-14
8	6671	6847	3	2004-07-14
9	6671	6347	3	2004-07-14
1	6672	1803	1	2004-07-13
2	6672	1870	3	2004-07-13
3	6672	4666	2	2004-07-13
4	6672	6654	3	2004-07-13
5	6672	5479	2	2004-07-13
6	6672	283	3	2004-07-13
7	6672	7874	1	2004-07-13
8	6672	2969	2	2004-07-13
1	6673	9647	2	2004-07-23
2	6673	1750	2	2004-07-23
3	6673	6572	3	2004-07-23
4	6673	3584	1	2004-07-23
5	6673	6916	3	2004-07-23
6	6673	8803	3	2004-07-23
7	6673	330	1	2004-07-23
8	6673	7401	2	2004-07-23
9	6673	6771	2	2004-07-23
1	6674	1049	3	2004-07-08
2	6674	3458	2	2004-07-08
3	6674	2336	1	2004-07-08
1	6675	9936	1	2004-07-14
2	6675	463	2	2004-07-14
3	6675	9929	2	2004-07-14
4	6675	6975	3	2004-07-14
1	6676	6450	1	2004-07-06
2	6676	7037	1	2004-07-06
1	6677	2236	2	2004-07-22
2	6677	6011	2	2004-07-22
3	6677	535	3	2004-07-22
4	6677	6324	2	2004-07-22
5	6677	1643	2	2004-07-22
6	6677	8826	1	2004-07-22
7	6677	8240	3	2004-07-22
1	6678	5014	2	2004-07-26
2	6678	838	1	2004-07-26
3	6678	7089	3	2004-07-26
4	6678	3540	2	2004-07-26
5	6678	509	1	2004-07-26
1	6679	2497	2	2004-07-12
2	6679	1550	1	2004-07-12
3	6679	2490	3	2004-07-12
4	6679	7888	2	2004-07-12
5	6679	4280	3	2004-07-12
6	6679	5711	1	2004-07-12
1	6680	8856	2	2004-07-19
2	6680	4384	3	2004-07-19
3	6680	6277	1	2004-07-19
4	6680	6981	3	2004-07-19
5	6680	5598	3	2004-07-19
6	6680	373	3	2004-07-19
7	6680	3468	3	2004-07-19
8	6680	5075	2	2004-07-19
9	6680	2652	2	2004-07-19
1	6681	9274	3	2004-07-28
2	6681	3597	2	2004-07-28
3	6681	1294	3	2004-07-28
4	6681	8781	1	2004-07-28
5	6681	8936	3	2004-07-28
6	6681	7682	1	2004-07-28
7	6681	7330	2	2004-07-28
1	6682	1799	2	2004-07-15
1	6683	1231	2	2004-07-30
2	6683	1305	1	2004-07-30
3	6683	446	2	2004-07-30
4	6683	7109	3	2004-07-30
5	6683	4576	1	2004-07-30
1	6684	7851	3	2004-07-15
2	6684	1120	2	2004-07-15
3	6684	2558	3	2004-07-15
4	6684	9491	3	2004-07-15
1	6685	7410	3	2004-07-09
2	6685	9824	1	2004-07-09
3	6685	2025	1	2004-07-09
4	6685	5367	1	2004-07-09
5	6685	1280	2	2004-07-09
1	6686	9093	1	2004-07-29
2	6686	9574	3	2004-07-29
3	6686	3718	3	2004-07-29
4	6686	8635	2	2004-07-29
1	6687	8540	2	2004-07-10
2	6687	5710	2	2004-07-10
3	6687	601	1	2004-07-10
1	6688	1478	3	2004-07-12
2	6688	8974	1	2004-07-12
3	6688	4361	3	2004-07-12
4	6688	1145	3	2004-07-12
5	6688	1807	1	2004-07-12
6	6688	126	1	2004-07-12
1	6689	8681	1	2004-07-30
2	6689	9459	1	2004-07-30
3	6689	4205	3	2004-07-30
4	6689	8010	3	2004-07-30
5	6689	4275	3	2004-07-30
6	6689	3033	3	2004-07-30
7	6689	9034	2	2004-07-30
8	6689	3540	1	2004-07-30
1	6690	617	2	2004-07-15
2	6690	9014	1	2004-07-15
3	6690	4649	3	2004-07-15
4	6690	3804	2	2004-07-15
5	6690	2983	1	2004-07-15
6	6690	2548	1	2004-07-15
7	6690	4366	1	2004-07-15
8	6690	3628	3	2004-07-15
9	6690	4	1	2004-07-15
1	6691	2174	3	2004-07-27
2	6691	7730	2	2004-07-27
1	6692	1615	3	2004-07-31
2	6692	7473	1	2004-07-31
3	6692	1266	1	2004-07-31
1	6693	7676	3	2004-07-31
2	6693	4413	1	2004-07-31
3	6693	955	3	2004-07-31
1	6694	5237	3	2004-07-02
2	6694	609	3	2004-07-02
3	6694	9206	3	2004-07-02
4	6694	3124	3	2004-07-02
5	6694	830	1	2004-07-02
6	6694	2058	1	2004-07-02
7	6694	193	3	2004-07-02
8	6694	3073	1	2004-07-02
9	6694	1653	1	2004-07-02
1	6695	7004	1	2004-07-21
2	6695	6243	3	2004-07-21
3	6695	8044	3	2004-07-21
4	6695	8918	3	2004-07-21
1	6696	1565	3	2004-07-19
2	6696	4891	2	2004-07-19
3	6696	5848	2	2004-07-19
4	6696	6037	3	2004-07-19
5	6696	8165	2	2004-07-19
6	6696	7436	1	2004-07-19
1	6697	7143	3	2004-07-24
2	6697	8416	2	2004-07-24
3	6697	9672	2	2004-07-24
4	6697	2105	3	2004-07-24
1	6698	5176	1	2004-07-05
2	6698	4009	3	2004-07-05
3	6698	9931	3	2004-07-05
4	6698	1427	2	2004-07-05
5	6698	4620	3	2004-07-05
6	6698	3684	1	2004-07-05
7	6698	3693	1	2004-07-05
1	6699	5593	3	2004-07-13
2	6699	7769	2	2004-07-13
3	6699	1495	3	2004-07-13
4	6699	8668	2	2004-07-13
5	6699	5155	1	2004-07-13
6	6699	4621	1	2004-07-13
7	6699	7634	3	2004-07-13
8	6699	3672	1	2004-07-13
1	6700	9381	2	2004-07-21
2	6700	5426	1	2004-07-21
3	6700	7945	3	2004-07-21
4	6700	4183	1	2004-07-21
5	6700	497	2	2004-07-21
6	6700	66	2	2004-07-21
7	6700	1740	3	2004-07-21
8	6700	98	1	2004-07-21
1	6701	8943	1	2004-07-17
1	6702	8219	3	2004-07-04
2	6702	8294	3	2004-07-04
3	6702	5746	3	2004-07-04
4	6702	3921	1	2004-07-04
5	6702	737	1	2004-07-04
1	6703	9310	2	2004-07-01
1	6704	4283	3	2004-07-22
2	6704	5738	1	2004-07-22
3	6704	7435	2	2004-07-22
4	6704	2569	3	2004-07-22
5	6704	1257	2	2004-07-22
6	6704	3146	3	2004-07-22
7	6704	1600	1	2004-07-22
1	6705	8516	3	2004-07-26
2	6705	4021	3	2004-07-26
1	6706	1751	2	2004-07-15
2	6706	5126	2	2004-07-15
3	6706	3436	3	2004-07-15
4	6706	489	3	2004-07-15
1	6707	6378	2	2004-07-02
2	6707	6908	3	2004-07-02
3	6707	4584	3	2004-07-02
1	6708	4975	2	2004-07-03
1	6709	6848	1	2004-07-31
2	6709	8765	3	2004-07-31
3	6709	9224	2	2004-07-31
4	6709	2081	1	2004-07-31
5	6709	3298	1	2004-07-31
1	6710	6912	3	2004-07-06
2	6710	793	2	2004-07-06
3	6710	6392	2	2004-07-06
4	6710	2327	3	2004-07-06
5	6710	8195	3	2004-07-06
6	6710	7425	1	2004-07-06
1	6711	2032	3	2004-07-08
2	6711	8479	1	2004-07-08
3	6711	7610	3	2004-07-08
4	6711	4686	3	2004-07-08
5	6711	361	3	2004-07-08
6	6711	2260	1	2004-07-08
1	6712	9623	3	2004-07-06
2	6712	2534	2	2004-07-06
3	6712	4043	2	2004-07-06
4	6712	3367	1	2004-07-06
5	6712	3040	1	2004-07-06
6	6712	5406	2	2004-07-06
7	6712	8135	3	2004-07-06
8	6712	1306	1	2004-07-06
1	6713	7486	2	2004-07-21
2	6713	3881	3	2004-07-21
3	6713	3629	2	2004-07-21
4	6713	37	2	2004-07-21
1	6714	6578	3	2004-07-28
2	6714	4529	1	2004-07-28
3	6714	1541	3	2004-07-28
4	6714	2857	2	2004-07-28
5	6714	8686	3	2004-07-28
6	6714	167	3	2004-07-28
7	6714	5831	1	2004-07-28
8	6714	6986	1	2004-07-28
1	6715	3594	1	2004-07-04
2	6715	6587	3	2004-07-04
3	6715	6622	2	2004-07-04
4	6715	2654	2	2004-07-04
5	6715	4535	3	2004-07-04
6	6715	4029	1	2004-07-04
7	6715	3480	3	2004-07-04
8	6715	1731	2	2004-07-04
1	6716	2849	3	2004-07-21
2	6716	1959	3	2004-07-21
3	6716	1239	3	2004-07-21
4	6716	1091	1	2004-07-21
5	6716	6891	3	2004-07-21
1	6717	7706	2	2004-07-04
2	6717	4446	1	2004-07-04
3	6717	308	3	2004-07-04
4	6717	7159	2	2004-07-04
5	6717	91	1	2004-07-04
6	6717	2895	1	2004-07-04
7	6717	5658	3	2004-07-04
8	6717	6408	2	2004-07-04
1	6718	7936	2	2004-07-14
2	6718	5387	3	2004-07-14
3	6718	8759	1	2004-07-14
4	6718	6717	3	2004-07-14
5	6718	2761	2	2004-07-14
6	6718	7816	1	2004-07-14
1	6719	1240	3	2004-07-31
2	6719	4327	1	2004-07-31
3	6719	8620	3	2004-07-31
4	6719	3151	2	2004-07-31
5	6719	6568	3	2004-07-31
6	6719	9536	1	2004-07-31
7	6719	8815	2	2004-07-31
8	6719	7497	3	2004-07-31
9	6719	825	1	2004-07-31
1	6720	9577	3	2004-07-18
2	6720	7380	3	2004-07-18
3	6720	8386	3	2004-07-18
1	6721	7191	1	2004-07-30
1	6722	88	2	2004-07-07
2	6722	4933	3	2004-07-07
3	6722	6220	2	2004-07-07
4	6722	4184	2	2004-07-07
5	6722	497	2	2004-07-07
1	6723	8763	2	2004-07-21
2	6723	9678	2	2004-07-21
1	6724	7273	1	2004-07-05
2	6724	2107	2	2004-07-05
1	6725	9704	1	2004-07-06
1	6726	8383	2	2004-07-17
2	6726	5332	3	2004-07-17
1	6727	3688	2	2004-07-29
2	6727	7935	2	2004-07-29
3	6727	55	3	2004-07-29
4	6727	1428	1	2004-07-29
1	6728	3163	2	2004-07-03
2	6728	7146	2	2004-07-03
3	6728	5378	3	2004-07-03
1	6729	2392	3	2004-07-12
2	6729	7949	3	2004-07-12
3	6729	8747	3	2004-07-12
4	6729	9653	2	2004-07-12
1	6730	6704	3	2004-07-03
2	6730	8320	3	2004-07-03
3	6730	1122	3	2004-07-03
4	6730	6832	2	2004-07-03
5	6730	1844	3	2004-07-03
6	6730	9782	3	2004-07-03
7	6730	3431	2	2004-07-03
8	6730	5838	3	2004-07-03
1	6731	7191	3	2004-07-19
2	6731	6048	2	2004-07-19
3	6731	6083	2	2004-07-19
4	6731	9833	3	2004-07-19
5	6731	9039	3	2004-07-19
6	6731	5799	2	2004-07-19
7	6731	5505	2	2004-07-19
8	6731	3875	2	2004-07-19
1	6732	700	1	2004-07-10
2	6732	3980	2	2004-07-10
3	6732	6203	3	2004-07-10
4	6732	1358	1	2004-07-10
5	6732	7141	1	2004-07-10
1	6733	267	3	2004-07-02
2	6733	2209	1	2004-07-02
3	6733	4381	1	2004-07-02
4	6733	7740	1	2004-07-02
5	6733	6990	1	2004-07-02
6	6733	4297	1	2004-07-02
1	6734	2434	1	2004-07-31
2	6734	2176	2	2004-07-31
1	6735	514	2	2004-07-20
2	6735	124	1	2004-07-20
3	6735	7701	1	2004-07-20
4	6735	7483	3	2004-07-20
5	6735	8856	3	2004-07-20
6	6735	8066	1	2004-07-20
7	6735	939	2	2004-07-20
1	6736	8793	3	2004-07-11
2	6736	5155	1	2004-07-11
3	6736	52	3	2004-07-11
4	6736	2632	1	2004-07-11
5	6736	4002	3	2004-07-11
6	6736	605	1	2004-07-11
7	6736	6787	1	2004-07-11
1	6737	8359	3	2004-07-12
2	6737	9272	3	2004-07-12
1	6738	3143	2	2004-07-29
1	6739	1112	3	2004-07-26
2	6739	7289	1	2004-07-26
3	6739	4321	3	2004-07-26
4	6739	3391	3	2004-07-26
5	6739	8951	2	2004-07-26
6	6739	8556	2	2004-07-26
7	6739	5114	1	2004-07-26
1	6740	6782	1	2004-07-09
1	6741	6255	1	2004-07-26
2	6741	2538	2	2004-07-26
3	6741	5408	2	2004-07-26
4	6741	1315	2	2004-07-26
5	6741	848	3	2004-07-26
6	6741	7683	2	2004-07-26
7	6741	8523	1	2004-07-26
8	6741	3492	3	2004-07-26
1	6742	4206	2	2004-07-16
1	6743	405	2	2004-07-23
2	6743	218	1	2004-07-23
3	6743	3757	2	2004-07-23
4	6743	3693	2	2004-07-23
1	6744	5620	1	2004-07-03
2	6744	777	1	2004-07-03
1	6745	6773	3	2004-07-20
2	6745	1965	3	2004-07-20
3	6745	9624	2	2004-07-20
4	6745	5841	3	2004-07-20
5	6745	3840	1	2004-07-20
6	6745	1181	2	2004-07-20
7	6745	7789	1	2004-07-20
8	6745	4721	1	2004-07-20
9	6745	7870	3	2004-07-20
1	6746	903	1	2004-07-25
2	6746	9506	1	2004-07-25
3	6746	6435	2	2004-07-25
4	6746	979	1	2004-07-25
5	6746	5849	3	2004-07-25
6	6746	253	3	2004-07-25
7	6746	7734	3	2004-07-25
8	6746	3983	2	2004-07-25
1	6747	2066	2	2004-07-22
2	6747	9465	3	2004-07-22
3	6747	5612	3	2004-07-22
4	6747	5200	2	2004-07-22
5	6747	6064	1	2004-07-22
6	6747	1700	3	2004-07-22
7	6747	5846	1	2004-07-22
8	6747	8646	1	2004-07-22
1	6748	7376	2	2004-07-23
2	6748	797	2	2004-07-23
3	6748	3218	2	2004-07-23
1	6749	8172	2	2004-07-27
2	6749	9029	3	2004-07-27
3	6749	1454	2	2004-07-27
4	6749	4971	2	2004-07-27
5	6749	8092	1	2004-07-27
1	6750	997	2	2004-07-30
2	6750	7492	3	2004-07-30
3	6750	6270	1	2004-07-30
4	6750	1117	2	2004-07-30
5	6750	3922	1	2004-07-30
1	6751	7243	3	2004-07-28
2	6751	2399	2	2004-07-28
3	6751	3961	1	2004-07-28
4	6751	3051	2	2004-07-28
5	6751	6069	3	2004-07-28
6	6751	2067	2	2004-07-28
7	6751	9057	1	2004-07-28
1	6752	3703	2	2004-07-13
2	6752	3081	3	2004-07-13
3	6752	4716	2	2004-07-13
4	6752	3617	3	2004-07-13
5	6752	6112	1	2004-07-13
1	6753	2098	1	2004-07-18
2	6753	8432	2	2004-07-18
3	6753	3634	1	2004-07-18
1	6754	3863	3	2004-07-05
2	6754	4973	3	2004-07-05
3	6754	5618	1	2004-07-05
4	6754	2763	3	2004-07-05
1	6755	42	1	2004-07-18
1	6756	8957	2	2004-07-29
2	6756	7895	1	2004-07-29
3	6756	7290	2	2004-07-29
4	6756	7113	1	2004-07-29
5	6756	7809	3	2004-07-29
1	6757	5874	3	2004-07-02
2	6757	2304	1	2004-07-02
3	6757	8713	2	2004-07-02
4	6757	811	2	2004-07-02
5	6757	910	1	2004-07-02
1	6758	7104	3	2004-07-16
2	6758	8910	2	2004-07-16
3	6758	3370	3	2004-07-16
4	6758	7115	1	2004-07-16
1	6759	2813	1	2004-07-10
1	6760	2035	3	2004-07-26
2	6760	5616	1	2004-07-26
3	6760	4066	2	2004-07-26
4	6760	5212	2	2004-07-26
1	6761	4175	1	2004-07-21
2	6761	7821	1	2004-07-21
3	6761	9090	1	2004-07-21
4	6761	9889	2	2004-07-21
5	6761	1850	1	2004-07-21
6	6761	432	2	2004-07-21
7	6761	3957	1	2004-07-21
8	6761	5641	1	2004-07-21
9	6761	8182	1	2004-07-21
1	6762	963	2	2004-07-20
2	6762	8373	2	2004-07-20
1	6763	4435	1	2004-07-02
2	6763	9336	1	2004-07-02
3	6763	3575	3	2004-07-02
4	6763	3446	2	2004-07-02
5	6763	4630	2	2004-07-02
6	6763	6482	2	2004-07-02
1	6764	2647	2	2004-07-28
2	6764	6706	3	2004-07-28
3	6764	6702	3	2004-07-28
4	6764	926	3	2004-07-28
1	6765	4197	1	2004-07-11
2	6765	130	3	2004-07-11
3	6765	642	3	2004-07-11
4	6765	886	2	2004-07-11
1	6766	9626	2	2004-07-25
2	6766	7582	3	2004-07-25
3	6766	4601	2	2004-07-25
1	6767	6225	3	2004-07-09
2	6767	7471	3	2004-07-09
3	6767	6738	1	2004-07-09
4	6767	6448	1	2004-07-09
5	6767	4741	1	2004-07-09
6	6767	727	2	2004-07-09
7	6767	9274	1	2004-07-09
8	6767	4336	1	2004-07-09
9	6767	5585	1	2004-07-09
1	6768	7427	1	2004-07-14
2	6768	2470	1	2004-07-14
3	6768	8215	2	2004-07-14
4	6768	9273	1	2004-07-14
1	6769	2647	2	2004-07-15
2	6769	3005	3	2004-07-15
1	6770	2616	3	2004-07-22
2	6770	9067	3	2004-07-22
3	6770	9171	2	2004-07-22
4	6770	9178	2	2004-07-22
5	6770	7916	2	2004-07-22
6	6770	7777	2	2004-07-22
7	6770	6254	1	2004-07-22
1	6771	5056	1	2004-07-23
2	6771	2138	2	2004-07-23
3	6771	2145	2	2004-07-23
4	6771	1114	2	2004-07-23
5	6771	3879	3	2004-07-23
6	6771	2895	2	2004-07-23
1	6772	2461	1	2004-07-18
2	6772	9502	1	2004-07-18
3	6772	5458	3	2004-07-18
4	6772	5565	1	2004-07-18
5	6772	2759	1	2004-07-18
1	6773	6767	1	2004-07-11
2	6773	8971	3	2004-07-11
3	6773	6058	1	2004-07-11
4	6773	3688	3	2004-07-11
5	6773	6264	3	2004-07-11
6	6773	5257	3	2004-07-11
7	6773	1182	1	2004-07-11
8	6773	4668	2	2004-07-11
9	6773	5891	3	2004-07-11
1	6774	2809	2	2004-07-18
1	6775	5693	1	2004-07-14
2	6775	6690	1	2004-07-14
3	6775	3778	2	2004-07-14
4	6775	1362	3	2004-07-14
5	6775	6775	2	2004-07-14
6	6775	7006	1	2004-07-14
7	6775	2616	1	2004-07-14
1	6776	7605	3	2004-07-07
2	6776	3993	1	2004-07-07
3	6776	4587	1	2004-07-07
4	6776	4271	3	2004-07-07
5	6776	7092	3	2004-07-07
6	6776	2962	1	2004-07-07
7	6776	6339	3	2004-07-07
1	6777	8689	1	2004-07-18
2	6777	9289	2	2004-07-18
3	6777	7523	2	2004-07-18
4	6777	8502	1	2004-07-18
5	6777	8558	1	2004-07-18
6	6777	3936	1	2004-07-18
7	6777	7562	1	2004-07-18
8	6777	1055	1	2004-07-18
9	6777	4748	2	2004-07-18
1	6778	7583	2	2004-07-14
2	6778	4647	2	2004-07-14
1	6779	9777	2	2004-07-15
2	6779	8235	3	2004-07-15
3	6779	1101	2	2004-07-15
4	6779	5360	3	2004-07-15
5	6779	5897	2	2004-07-15
6	6779	300	3	2004-07-15
1	6780	9416	2	2004-07-18
2	6780	2473	2	2004-07-18
3	6780	5137	2	2004-07-18
4	6780	5136	1	2004-07-18
5	6780	1506	3	2004-07-18
6	6780	6642	2	2004-07-18
7	6780	107	2	2004-07-18
1	6781	8949	1	2004-07-06
1	6782	8224	1	2004-07-19
2	6782	1638	2	2004-07-19
1	6783	9127	1	2004-07-26
2	6783	1239	2	2004-07-26
3	6783	8814	2	2004-07-26
4	6783	6983	1	2004-07-26
5	6783	6158	2	2004-07-26
6	6783	6475	2	2004-07-26
7	6783	7215	3	2004-07-26
1	6784	6774	2	2004-07-20
2	6784	9403	3	2004-07-20
3	6784	6260	3	2004-07-20
4	6784	6938	3	2004-07-20
5	6784	1627	2	2004-07-20
1	6785	5763	2	2004-07-03
1	6786	4895	2	2004-07-14
2	6786	4903	1	2004-07-14
1	6787	8562	3	2004-07-08
2	6787	3814	2	2004-07-08
3	6787	2758	1	2004-07-08
4	6787	2041	3	2004-07-08
5	6787	842	3	2004-07-08
6	6787	6915	1	2004-07-08
7	6787	4009	3	2004-07-08
8	6787	4926	2	2004-07-08
1	6788	5265	1	2004-07-25
2	6788	3427	1	2004-07-25
1	6789	447	1	2004-07-22
2	6789	8078	3	2004-07-22
3	6789	9594	1	2004-07-22
4	6789	4343	1	2004-07-22
5	6789	5107	2	2004-07-22
6	6789	1369	2	2004-07-22
7	6789	5361	3	2004-07-22
8	6789	8416	3	2004-07-22
9	6789	6103	2	2004-07-22
1	6790	6104	3	2004-07-19
2	6790	6719	3	2004-07-19
3	6790	9455	2	2004-07-19
4	6790	7860	1	2004-07-19
5	6790	2863	3	2004-07-19
6	6790	2274	1	2004-07-19
1	6791	4219	3	2004-07-23
2	6791	8038	2	2004-07-23
1	6792	2768	3	2004-07-13
2	6792	5644	3	2004-07-13
3	6792	3927	3	2004-07-13
1	6793	9561	3	2004-07-16
2	6793	5148	3	2004-07-16
1	6794	8950	1	2004-07-30
2	6794	3547	1	2004-07-30
1	6795	3352	2	2004-07-15
2	6795	6129	3	2004-07-15
3	6795	5906	3	2004-07-15
1	6796	1222	1	2004-07-23
2	6796	1150	1	2004-07-23
1	6797	8129	3	2004-07-13
2	6797	7307	2	2004-07-13
3	6797	9700	2	2004-07-13
4	6797	6891	1	2004-07-13
5	6797	8038	1	2004-07-13
6	6797	1012	3	2004-07-13
7	6797	4314	2	2004-07-13
8	6797	1359	1	2004-07-13
9	6797	1584	3	2004-07-13
1	6798	9895	1	2004-07-29
2	6798	9426	1	2004-07-29
3	6798	226	2	2004-07-29
4	6798	1754	3	2004-07-29
5	6798	2872	3	2004-07-29
6	6798	6858	1	2004-07-29
7	6798	3736	2	2004-07-29
1	6799	2210	1	2004-07-20
2	6799	2227	2	2004-07-20
3	6799	5177	2	2004-07-20
4	6799	6967	3	2004-07-20
5	6799	850	2	2004-07-20
1	6800	9698	1	2004-07-18
2	6800	6475	3	2004-07-18
3	6800	6225	3	2004-07-18
4	6800	8761	3	2004-07-18
5	6800	8110	2	2004-07-18
1	6801	2471	1	2004-07-29
2	6801	180	2	2004-07-29
3	6801	2792	1	2004-07-29
4	6801	1205	3	2004-07-29
5	6801	5992	3	2004-07-29
6	6801	4729	3	2004-07-29
1	6802	5696	2	2004-07-14
2	6802	352	1	2004-07-14
3	6802	6125	2	2004-07-14
4	6802	398	2	2004-07-14
5	6802	5673	3	2004-07-14
6	6802	504	2	2004-07-14
7	6802	352	1	2004-07-14
1	6803	7503	3	2004-07-03
1	6804	6878	1	2004-07-11
2	6804	6071	1	2004-07-11
3	6804	410	1	2004-07-11
4	6804	9056	2	2004-07-11
5	6804	8777	3	2004-07-11
6	6804	8274	2	2004-07-11
7	6804	5984	3	2004-07-11
8	6804	9787	1	2004-07-11
9	6804	7178	1	2004-07-11
1	6805	351	3	2004-07-21
2	6805	8089	3	2004-07-21
3	6805	5074	1	2004-07-21
4	6805	6561	1	2004-07-21
5	6805	557	2	2004-07-21
6	6805	635	2	2004-07-21
7	6805	4792	1	2004-07-21
1	6806	3255	2	2004-07-29
2	6806	2880	3	2004-07-29
3	6806	4094	1	2004-07-29
4	6806	894	1	2004-07-29
5	6806	2957	3	2004-07-29
6	6806	8801	2	2004-07-29
7	6806	4751	3	2004-07-29
8	6806	3553	1	2004-07-29
1	6807	9116	2	2004-07-22
2	6807	7003	3	2004-07-22
3	6807	1352	1	2004-07-22
4	6807	795	1	2004-07-22
1	6808	3366	1	2004-07-18
2	6808	8134	3	2004-07-18
3	6808	4078	3	2004-07-18
4	6808	8731	3	2004-07-18
5	6808	6523	3	2004-07-18
6	6808	2961	1	2004-07-18
7	6808	6682	2	2004-07-18
8	6808	4113	2	2004-07-18
9	6808	5139	3	2004-07-18
1	6809	4005	2	2004-07-23
2	6809	6047	2	2004-07-23
3	6809	4908	1	2004-07-23
4	6809	2743	2	2004-07-23
1	6810	3568	3	2004-07-02
2	6810	7743	1	2004-07-02
3	6810	5964	2	2004-07-02
4	6810	9829	3	2004-07-02
5	6810	5538	2	2004-07-02
6	6810	5438	3	2004-07-02
7	6810	195	1	2004-07-02
8	6810	7930	3	2004-07-02
1	6811	5287	3	2004-07-15
2	6811	3635	1	2004-07-15
3	6811	9433	2	2004-07-15
4	6811	3634	1	2004-07-15
5	6811	2485	3	2004-07-15
6	6811	8732	2	2004-07-15
7	6811	7414	2	2004-07-15
8	6811	8349	2	2004-07-15
1	6812	4687	3	2004-07-03
2	6812	5928	2	2004-07-03
3	6812	8315	2	2004-07-03
4	6812	2327	1	2004-07-03
5	6812	4790	2	2004-07-03
6	6812	1979	1	2004-07-03
1	6813	1990	2	2004-07-06
2	6813	1216	2	2004-07-06
1	6814	6421	3	2004-07-08
2	6814	3180	3	2004-07-08
3	6814	7051	2	2004-07-08
4	6814	3437	1	2004-07-08
5	6814	3220	3	2004-07-08
6	6814	6619	1	2004-07-08
7	6814	3222	3	2004-07-08
8	6814	4678	3	2004-07-08
9	6814	2969	2	2004-07-08
1	6815	5937	2	2004-07-26
2	6815	2262	3	2004-07-26
3	6815	8732	2	2004-07-26
4	6815	7099	3	2004-07-26
5	6815	4454	2	2004-07-26
6	6815	8131	3	2004-07-26
7	6815	679	2	2004-07-26
8	6815	3115	2	2004-07-26
1	6816	7868	3	2004-07-22
2	6816	2482	1	2004-07-22
3	6816	4712	2	2004-07-22
4	6816	9202	1	2004-07-22
1	6817	5730	2	2004-07-01
2	6817	3276	2	2004-07-01
3	6817	8067	1	2004-07-01
4	6817	3719	1	2004-07-01
5	6817	3893	1	2004-07-01
6	6817	153	2	2004-07-01
1	6818	9601	1	2004-07-22
2	6818	7487	3	2004-07-22
3	6818	8867	3	2004-07-22
4	6818	14	2	2004-07-22
1	6819	688	3	2004-07-17
2	6819	1729	2	2004-07-17
3	6819	949	2	2004-07-17
4	6819	879	3	2004-07-17
5	6819	5378	2	2004-07-17
6	6819	1536	3	2004-07-17
1	6820	4956	1	2004-07-20
2	6820	7428	2	2004-07-20
3	6820	4693	2	2004-07-20
4	6820	2025	2	2004-07-20
1	6821	1255	2	2004-07-16
1	6822	8359	1	2004-07-19
2	6822	2640	3	2004-07-19
3	6822	1011	3	2004-07-19
4	6822	3834	1	2004-07-19
5	6822	7286	1	2004-07-19
6	6822	4235	1	2004-07-19
7	6822	3759	3	2004-07-19
1	6823	6100	2	2004-07-12
2	6823	1905	1	2004-07-12
3	6823	7810	3	2004-07-12
4	6823	1285	3	2004-07-12
5	6823	2558	3	2004-07-12
6	6823	1007	2	2004-07-12
7	6823	4827	3	2004-07-12
8	6823	5599	3	2004-07-12
1	6824	9155	1	2004-07-27
2	6824	2716	2	2004-07-27
3	6824	3894	2	2004-07-27
1	6825	5893	2	2004-07-08
2	6825	2097	3	2004-07-08
3	6825	4742	3	2004-07-08
4	6825	6840	2	2004-07-08
5	6825	8971	3	2004-07-08
6	6825	3217	3	2004-07-08
1	6826	5510	3	2004-07-10
2	6826	5208	1	2004-07-10
3	6826	378	2	2004-07-10
4	6826	3760	1	2004-07-10
5	6826	7752	3	2004-07-10
6	6826	9568	1	2004-07-10
7	6826	5200	3	2004-07-10
8	6826	6657	1	2004-07-10
1	6827	8660	2	2004-07-04
2	6827	1753	3	2004-07-04
3	6827	5126	2	2004-07-04
4	6827	7607	3	2004-07-04
5	6827	3013	3	2004-07-04
6	6827	6724	3	2004-07-04
1	6828	6294	1	2004-07-16
2	6828	8362	2	2004-07-16
3	6828	926	3	2004-07-16
4	6828	4376	2	2004-07-16
5	6828	5156	1	2004-07-16
1	6829	1867	3	2004-07-23
2	6829	1836	2	2004-07-23
3	6829	6074	3	2004-07-23
4	6829	8589	2	2004-07-23
5	6829	5087	1	2004-07-23
6	6829	629	1	2004-07-23
1	6830	788	1	2004-07-01
2	6830	2909	3	2004-07-01
3	6830	4080	2	2004-07-01
4	6830	7078	3	2004-07-01
5	6830	9960	1	2004-07-01
6	6830	9488	3	2004-07-01
7	6830	8373	3	2004-07-01
8	6830	3284	1	2004-07-01
9	6830	7716	2	2004-07-01
1	6831	7470	3	2004-07-12
2	6831	4048	3	2004-07-12
3	6831	8976	2	2004-07-12
1	6832	2752	3	2004-07-12
2	6832	3553	3	2004-07-12
3	6832	549	1	2004-07-12
4	6832	5288	1	2004-07-12
1	6833	4048	1	2004-07-09
2	6833	1476	1	2004-07-09
1	6834	7782	1	2004-07-19
2	6834	5333	1	2004-07-19
3	6834	1120	2	2004-07-19
4	6834	6001	2	2004-07-19
5	6834	7025	3	2004-07-19
6	6834	9140	3	2004-07-19
7	6834	6521	1	2004-07-19
8	6834	6609	3	2004-07-19
1	6835	6671	2	2004-07-11
2	6835	7422	1	2004-07-11
3	6835	6231	3	2004-07-11
4	6835	2481	1	2004-07-11
5	6835	4233	3	2004-07-11
6	6835	485	1	2004-07-11
1	6836	125	3	2004-07-04
2	6836	6912	3	2004-07-04
1	6837	8743	2	2004-07-30
2	6837	3241	1	2004-07-30
3	6837	5430	1	2004-07-30
4	6837	8251	1	2004-07-30
5	6837	6080	2	2004-07-30
6	6837	2818	1	2004-07-30
1	6838	3333	2	2004-07-15
2	6838	816	2	2004-07-15
3	6838	929	2	2004-07-15
4	6838	6564	1	2004-07-15
5	6838	4504	2	2004-07-15
6	6838	8204	2	2004-07-15
7	6838	9526	2	2004-07-15
8	6838	326	3	2004-07-15
1	6839	4384	3	2004-07-27
2	6839	6194	1	2004-07-27
3	6839	4258	3	2004-07-27
4	6839	2772	3	2004-07-27
1	6840	2511	3	2004-07-14
2	6840	2031	2	2004-07-14
3	6840	3105	3	2004-07-14
4	6840	4493	3	2004-07-14
5	6840	2068	1	2004-07-14
6	6840	1763	1	2004-07-14
7	6840	7826	1	2004-07-14
1	6841	583	1	2004-07-31
1	6842	5788	1	2004-07-28
2	6842	1864	1	2004-07-28
3	6842	669	3	2004-07-28
1	6843	6618	1	2004-07-24
2	6843	8365	1	2004-07-24
3	6843	8651	1	2004-07-24
4	6843	3807	1	2004-07-24
5	6843	2026	1	2004-07-24
6	6843	2500	1	2004-07-24
7	6843	8122	3	2004-07-24
8	6843	2082	3	2004-07-24
9	6843	8189	1	2004-07-24
1	6844	1957	2	2004-07-17
2	6844	1365	1	2004-07-17
1	6845	8877	1	2004-07-17
2	6845	4232	3	2004-07-17
3	6845	3531	1	2004-07-17
1	6846	8969	2	2004-07-24
2	6846	1586	3	2004-07-24
3	6846	3947	2	2004-07-24
4	6846	5793	1	2004-07-24
5	6846	4528	1	2004-07-24
6	6846	823	3	2004-07-24
7	6846	2540	1	2004-07-24
8	6846	4183	2	2004-07-24
9	6846	5404	3	2004-07-24
1	6847	3627	3	2004-07-10
2	6847	9128	3	2004-07-10
1	6848	6501	2	2004-07-31
2	6848	8826	3	2004-07-31
3	6848	552	1	2004-07-31
1	6849	7617	2	2004-07-06
2	6849	4705	1	2004-07-06
3	6849	8510	3	2004-07-06
4	6849	4062	2	2004-07-06
5	6849	8322	3	2004-07-06
6	6849	5120	1	2004-07-06
1	6850	5903	3	2004-07-28
2	6850	4887	1	2004-07-28
3	6850	567	1	2004-07-28
4	6850	3858	3	2004-07-28
5	6850	9474	2	2004-07-28
6	6850	2165	1	2004-07-28
7	6850	753	3	2004-07-28
8	6850	7508	3	2004-07-28
1	6851	1099	1	2004-07-09
2	6851	5226	3	2004-07-09
1	6852	9092	3	2004-07-30
2	6852	6702	2	2004-07-30
3	6852	5699	1	2004-07-30
4	6852	5390	2	2004-07-30
5	6852	2975	3	2004-07-30
6	6852	5658	1	2004-07-30
7	6852	3657	3	2004-07-30
8	6852	3675	2	2004-07-30
1	6853	3393	1	2004-07-16
2	6853	9011	2	2004-07-16
3	6853	3892	2	2004-07-16
4	6853	3910	2	2004-07-16
5	6853	4582	2	2004-07-16
6	6853	2167	2	2004-07-16
7	6853	2437	3	2004-07-16
1	6854	4401	2	2004-07-27
2	6854	3305	1	2004-07-27
3	6854	5880	3	2004-07-27
4	6854	7881	3	2004-07-27
1	6855	473	2	2004-07-05
2	6855	5453	3	2004-07-05
3	6855	8620	3	2004-07-05
4	6855	3719	1	2004-07-05
1	6856	1973	3	2004-07-09
2	6856	3931	1	2004-07-09
3	6856	7374	2	2004-07-09
4	6856	4696	1	2004-07-09
5	6856	7819	3	2004-07-09
1	6857	3251	2	2004-07-06
2	6857	2487	2	2004-07-06
3	6857	479	1	2004-07-06
4	6857	8115	2	2004-07-06
5	6857	2441	3	2004-07-06
6	6857	5276	2	2004-07-06
7	6857	9263	3	2004-07-06
8	6857	4459	2	2004-07-06
9	6857	3234	2	2004-07-06
1	6858	1551	1	2004-07-17
2	6858	4450	3	2004-07-17
3	6858	9764	2	2004-07-17
1	6859	1054	3	2004-07-10
2	6859	303	1	2004-07-10
3	6859	1437	3	2004-07-10
4	6859	7463	2	2004-07-10
5	6859	5150	1	2004-07-10
6	6859	37	2	2004-07-10
1	6860	926	2	2004-07-03
2	6860	1307	3	2004-07-03
3	6860	8455	1	2004-07-03
4	6860	9759	1	2004-07-03
1	6861	4247	2	2004-07-07
2	6861	1608	2	2004-07-07
3	6861	3655	1	2004-07-07
4	6861	6832	2	2004-07-07
5	6861	328	2	2004-07-07
1	6862	9890	3	2004-07-28
2	6862	3500	1	2004-07-28
3	6862	2086	2	2004-07-28
4	6862	6145	2	2004-07-28
5	6862	2419	2	2004-07-28
6	6862	6249	1	2004-07-28
7	6862	7504	3	2004-07-28
8	6862	1701	3	2004-07-28
9	6862	3766	2	2004-07-28
1	6863	7284	3	2004-07-06
2	6863	612	3	2004-07-06
3	6863	2374	3	2004-07-06
4	6863	3089	3	2004-07-06
5	6863	8585	1	2004-07-06
1	6864	6509	3	2004-07-23
2	6864	2826	3	2004-07-23
3	6864	4089	3	2004-07-23
4	6864	1106	1	2004-07-23
5	6864	7549	1	2004-07-23
6	6864	8281	1	2004-07-23
7	6864	8754	1	2004-07-23
8	6864	6687	1	2004-07-23
9	6864	5665	2	2004-07-23
1	6865	5856	2	2004-07-26
1	6866	6524	1	2004-07-31
2	6866	6645	1	2004-07-31
3	6866	481	3	2004-07-31
4	6866	1960	2	2004-07-31
5	6866	8545	1	2004-07-31
6	6866	6161	2	2004-07-31
7	6866	5871	2	2004-07-31
1	6867	4625	1	2004-07-23
2	6867	8064	1	2004-07-23
3	6867	6526	3	2004-07-23
4	6867	3160	1	2004-07-23
1	6868	231	2	2004-07-14
2	6868	2955	3	2004-07-14
1	6869	8003	2	2004-07-20
2	6869	1400	2	2004-07-20
3	6869	984	3	2004-07-20
4	6869	8604	3	2004-07-20
5	6869	1894	1	2004-07-20
6	6869	2485	2	2004-07-20
7	6869	3440	1	2004-07-20
8	6869	9224	3	2004-07-20
1	6870	5405	3	2004-07-01
2	6870	6471	2	2004-07-01
3	6870	2509	3	2004-07-01
4	6870	2511	3	2004-07-01
5	6870	2860	3	2004-07-01
1	6871	5026	2	2004-07-23
2	6871	5888	2	2004-07-23
3	6871	3122	3	2004-07-23
4	6871	6819	2	2004-07-23
5	6871	4300	1	2004-07-23
6	6871	6153	2	2004-07-23
7	6871	222	2	2004-07-23
8	6871	5907	1	2004-07-23
1	6872	6946	2	2004-07-03
2	6872	6749	3	2004-07-03
3	6872	3125	3	2004-07-03
4	6872	8313	1	2004-07-03
5	6872	470	1	2004-07-03
6	6872	8962	2	2004-07-03
7	6872	6790	2	2004-07-03
1	6873	5517	3	2004-07-29
2	6873	6201	1	2004-07-29
3	6873	453	2	2004-07-29
4	6873	8015	2	2004-07-29
5	6873	8989	3	2004-07-29
6	6873	7670	1	2004-07-29
1	6874	4072	3	2004-07-20
2	6874	2550	1	2004-07-20
3	6874	8430	1	2004-07-20
1	6875	2241	3	2004-07-14
2	6875	1144	2	2004-07-14
1	6876	8330	1	2004-07-12
2	6876	6204	2	2004-07-12
3	6876	8611	2	2004-07-12
4	6876	5213	2	2004-07-12
5	6876	5913	1	2004-07-12
6	6876	895	1	2004-07-12
7	6876	4347	2	2004-07-12
8	6876	8960	3	2004-07-12
9	6876	7350	3	2004-07-12
1	6877	3026	3	2004-07-31
2	6877	6069	2	2004-07-31
3	6877	1892	3	2004-07-31
4	6877	829	2	2004-07-31
5	6877	9431	3	2004-07-31
6	6877	5944	2	2004-07-31
7	6877	5502	2	2004-07-31
8	6877	826	1	2004-07-31
1	6878	7612	2	2004-07-03
2	6878	6694	2	2004-07-03
1	6879	5835	3	2004-07-11
2	6879	1707	3	2004-07-11
3	6879	5762	3	2004-07-11
1	6880	1345	3	2004-07-10
2	6880	3015	3	2004-07-10
3	6880	2488	3	2004-07-10
4	6880	1842	1	2004-07-10
1	6881	4403	3	2004-07-29
2	6881	7815	1	2004-07-29
1	6882	4453	1	2004-07-14
2	6882	6936	2	2004-07-14
3	6882	9834	1	2004-07-14
4	6882	3933	1	2004-07-14
5	6882	351	1	2004-07-14
6	6882	6720	1	2004-07-14
7	6882	8211	3	2004-07-14
8	6882	8984	1	2004-07-14
1	6883	3501	2	2004-07-26
2	6883	8831	3	2004-07-26
3	6883	1725	2	2004-07-26
4	6883	9000	2	2004-07-26
5	6883	7821	2	2004-07-26
6	6883	4155	1	2004-07-26
7	6883	5111	1	2004-07-26
1	6884	7807	2	2004-07-27
2	6884	3722	2	2004-07-27
3	6884	5834	1	2004-07-27
1	6885	5643	2	2004-07-14
2	6885	9992	3	2004-07-14
3	6885	703	3	2004-07-14
1	6886	8387	1	2004-07-22
2	6886	183	1	2004-07-22
3	6886	5560	2	2004-07-22
4	6886	3631	2	2004-07-22
5	6886	238	3	2004-07-22
6	6886	6356	3	2004-07-22
1	6887	2009	3	2004-07-05
2	6887	2207	2	2004-07-05
3	6887	9339	3	2004-07-05
4	6887	1280	3	2004-07-05
5	6887	6992	1	2004-07-05
6	6887	8152	2	2004-07-05
7	6887	4410	2	2004-07-05
1	6888	5338	1	2004-07-01
1	6889	6388	1	2004-07-18
2	6889	3838	3	2004-07-18
3	6889	2889	2	2004-07-18
4	6889	5334	2	2004-07-18
5	6889	3235	3	2004-07-18
6	6889	9535	1	2004-07-18
1	6890	2797	1	2004-07-17
2	6890	6417	3	2004-07-17
3	6890	3671	2	2004-07-17
1	6891	3040	1	2004-07-01
2	6891	4310	3	2004-07-01
3	6891	8112	1	2004-07-01
4	6891	2308	1	2004-07-01
5	6891	8640	2	2004-07-01
1	6892	1514	3	2004-07-26
2	6892	4161	3	2004-07-26
1	6893	6116	2	2004-07-02
2	6893	445	3	2004-07-02
3	6893	2197	1	2004-07-02
1	6894	1275	1	2004-07-02
2	6894	2898	3	2004-07-02
3	6894	794	2	2004-07-02
4	6894	1335	3	2004-07-02
1	6895	1278	2	2004-07-02
1	6896	1501	1	2004-07-01
1	6897	7403	3	2004-07-12
2	6897	4692	3	2004-07-12
3	6897	7955	1	2004-07-12
4	6897	1165	3	2004-07-12
1	6898	9267	3	2004-07-02
2	6898	802	3	2004-07-02
1	6899	9127	1	2004-07-30
1	6900	2051	2	2004-07-20
2	6900	5473	3	2004-07-20
3	6900	8888	1	2004-07-20
4	6900	7850	2	2004-07-20
5	6900	639	2	2004-07-20
6	6900	4058	1	2004-07-20
7	6900	5034	2	2004-07-20
8	6900	5866	2	2004-07-20
1	6901	4800	1	2004-07-19
2	6901	1012	2	2004-07-19
3	6901	4157	1	2004-07-19
4	6901	5242	1	2004-07-19
5	6901	1087	2	2004-07-19
6	6901	8368	1	2004-07-19
7	6901	728	2	2004-07-19
1	6902	3195	3	2004-07-07
2	6902	5645	3	2004-07-07
3	6902	9159	1	2004-07-07
4	6902	1886	2	2004-07-07
5	6902	4328	3	2004-07-07
6	6902	157	3	2004-07-07
7	6902	4692	2	2004-07-07
8	6902	1167	2	2004-07-07
9	6902	9917	2	2004-07-07
1	6903	1243	2	2004-07-19
2	6903	66	1	2004-07-19
3	6903	8043	1	2004-07-19
4	6903	1585	2	2004-07-19
5	6903	1896	2	2004-07-19
6	6903	2112	3	2004-07-19
7	6903	2032	1	2004-07-19
1	6904	1804	2	2004-07-26
2	6904	473	2	2004-07-26
3	6904	1407	1	2004-07-26
1	6905	6481	1	2004-07-07
2	6905	4969	3	2004-07-07
3	6905	6998	2	2004-07-07
4	6905	9693	2	2004-07-07
5	6905	7090	1	2004-07-07
6	6905	9797	3	2004-07-07
7	6905	6057	1	2004-07-07
8	6905	6525	3	2004-07-07
1	6906	7288	2	2004-07-10
2	6906	5922	3	2004-07-10
3	6906	304	3	2004-07-10
4	6906	9399	1	2004-07-10
5	6906	8651	2	2004-07-10
6	6906	542	2	2004-07-10
7	6906	9156	2	2004-07-10
8	6906	2854	2	2004-07-10
9	6906	545	1	2004-07-10
1	6907	6620	3	2004-07-04
1	6908	7888	3	2004-07-09
2	6908	5548	2	2004-07-09
3	6908	3779	1	2004-07-09
4	6908	2935	2	2004-07-09
5	6908	8797	1	2004-07-09
6	6908	6584	3	2004-07-09
1	6909	2636	2	2004-07-27
2	6909	4003	1	2004-07-27
3	6909	7978	2	2004-07-27
4	6909	815	1	2004-07-27
5	6909	6184	3	2004-07-27
6	6909	1681	3	2004-07-27
7	6909	580	3	2004-07-27
8	6909	5157	3	2004-07-27
1	6910	2172	2	2004-07-30
2	6910	7479	1	2004-07-30
3	6910	8909	2	2004-07-30
4	6910	8416	3	2004-07-30
1	6911	6426	3	2004-07-04
2	6911	7002	2	2004-07-04
3	6911	4649	3	2004-07-04
4	6911	6206	1	2004-07-04
1	6912	7534	2	2004-07-17
2	6912	4297	3	2004-07-17
3	6912	5773	3	2004-07-17
4	6912	550	3	2004-07-17
5	6912	4514	3	2004-07-17
6	6912	8914	2	2004-07-17
1	6913	8323	2	2004-07-07
2	6913	7098	2	2004-07-07
3	6913	5931	2	2004-07-07
1	6914	1412	3	2004-07-29
2	6914	3244	1	2004-07-29
3	6914	2997	1	2004-07-29
4	6914	6394	3	2004-07-29
5	6914	7930	1	2004-07-29
1	6915	6507	3	2004-07-17
2	6915	3168	3	2004-07-17
3	6915	6354	2	2004-07-17
4	6915	1871	2	2004-07-17
5	6915	669	3	2004-07-17
6	6915	9426	2	2004-07-17
7	6915	3067	3	2004-07-17
8	6915	7178	2	2004-07-17
9	6915	3936	3	2004-07-17
1	6916	7957	2	2004-07-07
2	6916	2439	2	2004-07-07
3	6916	8474	3	2004-07-07
4	6916	4366	3	2004-07-07
5	6916	7416	1	2004-07-07
1	6917	4775	1	2004-07-24
2	6917	8641	2	2004-07-24
3	6917	306	3	2004-07-24
4	6917	2042	2	2004-07-24
1	6918	7808	1	2004-07-21
1	6919	4029	3	2004-07-25
2	6919	1603	1	2004-07-25
3	6919	5757	2	2004-07-25
4	6919	1088	1	2004-07-25
5	6919	6840	3	2004-07-25
6	6919	3756	2	2004-07-25
1	6920	3974	3	2004-07-09
2	6920	9367	2	2004-07-09
1	6921	6589	1	2004-07-05
2	6921	179	2	2004-07-05
3	6921	763	2	2004-07-05
4	6921	64	2	2004-07-05
5	6921	3912	1	2004-07-05
6	6921	7293	3	2004-07-05
7	6921	7634	3	2004-07-05
8	6921	2841	2	2004-07-05
9	6921	7077	2	2004-07-05
1	6922	1038	3	2004-07-03
2	6922	6377	1	2004-07-03
3	6922	5114	3	2004-07-03
4	6922	6415	1	2004-07-03
5	6922	7376	1	2004-07-03
6	6922	3389	3	2004-07-03
7	6922	7351	2	2004-07-03
8	6922	3379	3	2004-07-03
1	6923	6959	3	2004-07-28
2	6923	4614	3	2004-07-28
3	6923	1187	1	2004-07-28
4	6923	6395	1	2004-07-28
5	6923	1427	1	2004-07-28
6	6923	393	1	2004-07-28
1	6924	4468	3	2004-07-02
2	6924	6081	1	2004-07-02
3	6924	2286	3	2004-07-02
4	6924	9397	3	2004-07-02
5	6924	3620	1	2004-07-02
6	6924	7051	1	2004-07-02
1	6925	2843	2	2004-07-01
2	6925	6823	2	2004-07-01
3	6925	5098	1	2004-07-01
4	6925	5997	2	2004-07-01
5	6925	4739	2	2004-07-01
6	6925	8989	2	2004-07-01
7	6925	3159	1	2004-07-01
1	6926	9470	2	2004-07-04
2	6926	6641	3	2004-07-04
3	6926	3062	1	2004-07-04
4	6926	1641	1	2004-07-04
5	6926	2821	1	2004-07-04
6	6926	6242	1	2004-07-04
7	6926	8729	3	2004-07-04
1	6927	8769	3	2004-07-16
1	6928	8865	3	2004-07-21
2	6928	7489	3	2004-07-21
3	6928	6284	3	2004-07-21
4	6928	7128	2	2004-07-21
5	6928	2054	2	2004-07-21
6	6928	4619	2	2004-07-21
1	6929	7965	1	2004-07-13
2	6929	8464	3	2004-07-13
3	6929	554	2	2004-07-13
4	6929	2245	2	2004-07-13
5	6929	3607	1	2004-07-13
6	6929	2779	1	2004-07-13
7	6929	4520	3	2004-07-13
1	6930	3340	1	2004-07-19
2	6930	2000	1	2004-07-19
3	6930	8973	2	2004-07-19
4	6930	4234	2	2004-07-19
1	6931	5110	3	2004-07-29
2	6931	5866	2	2004-07-29
3	6931	4507	2	2004-07-29
4	6931	7061	3	2004-07-29
1	6932	919	1	2004-07-01
2	6932	1144	3	2004-07-01
3	6932	5666	3	2004-07-01
1	6933	9471	1	2004-07-01
2	6933	6224	2	2004-07-01
1	6934	9789	3	2004-07-12
2	6934	1525	2	2004-07-12
3	6934	650	2	2004-07-12
4	6934	2074	3	2004-07-12
1	6935	5028	3	2004-07-09
1	6936	4250	2	2004-07-09
2	6936	7497	2	2004-07-09
3	6936	8438	3	2004-07-09
4	6936	5820	2	2004-07-09
5	6936	673	3	2004-07-09
6	6936	53	1	2004-07-09
7	6936	3393	3	2004-07-09
8	6936	9715	2	2004-07-09
1	6937	8075	2	2004-07-18
2	6937	9730	2	2004-07-18
3	6937	4274	2	2004-07-18
4	6937	5748	3	2004-07-18
5	6937	927	1	2004-07-18
6	6937	5593	2	2004-07-18
7	6937	8111	1	2004-07-18
1	6938	1210	1	2004-07-03
2	6938	6227	1	2004-07-03
3	6938	3367	3	2004-07-03
4	6938	1103	1	2004-07-03
5	6938	4537	2	2004-07-03
6	6938	3446	2	2004-07-03
1	6939	7972	2	2004-07-13
2	6939	8652	2	2004-07-13
3	6939	589	3	2004-07-13
4	6939	5562	2	2004-07-13
1	6940	221	3	2004-07-15
2	6940	2025	1	2004-07-15
3	6940	53	3	2004-07-15
4	6940	2692	2	2004-07-15
5	6940	7870	2	2004-07-15
1	6941	7891	2	2004-07-21
2	6941	1465	3	2004-07-21
3	6941	8451	3	2004-07-21
4	6941	593	3	2004-07-21
5	6941	3155	1	2004-07-21
6	6941	6681	3	2004-07-21
7	6941	7361	1	2004-07-21
8	6941	2389	2	2004-07-21
9	6941	6916	1	2004-07-21
1	6942	7191	3	2004-07-19
2	6942	9427	2	2004-07-19
3	6942	524	2	2004-07-19
4	6942	7467	1	2004-07-19
5	6942	5873	2	2004-07-19
6	6942	5471	3	2004-07-19
1	6943	1024	3	2004-07-08
2	6943	4235	3	2004-07-08
3	6943	8644	1	2004-07-08
1	6944	3642	2	2004-07-29
2	6944	4994	3	2004-07-29
3	6944	187	1	2004-07-29
4	6944	4411	3	2004-07-29
5	6944	7246	2	2004-07-29
6	6944	5541	2	2004-07-29
1	6945	8752	1	2004-07-19
2	6945	5242	2	2004-07-19
1	6946	3970	2	2004-07-18
2	6946	1413	1	2004-07-18
3	6946	5129	3	2004-07-18
4	6946	9163	3	2004-07-18
5	6946	3817	2	2004-07-18
6	6946	6451	2	2004-07-18
7	6946	6342	1	2004-07-18
8	6946	3618	2	2004-07-18
9	6946	5795	3	2004-07-18
1	6947	2964	3	2004-07-26
2	6947	896	3	2004-07-26
3	6947	4848	2	2004-07-26
4	6947	4471	1	2004-07-26
5	6947	6297	3	2004-07-26
6	6947	4397	3	2004-07-26
7	6947	1548	3	2004-07-26
8	6947	7346	1	2004-07-26
1	6948	5167	1	2004-07-26
2	6948	5605	3	2004-07-26
3	6948	4794	1	2004-07-26
4	6948	7942	1	2004-07-26
5	6948	3043	3	2004-07-26
1	6949	4211	1	2004-07-05
2	6949	8833	3	2004-07-05
3	6949	2986	2	2004-07-05
1	6950	6906	1	2004-07-23
2	6950	9379	2	2004-07-23
3	6950	1346	2	2004-07-23
4	6950	9945	2	2004-07-23
5	6950	5452	2	2004-07-23
6	6950	5296	1	2004-07-23
7	6950	6949	1	2004-07-23
8	6950	3338	3	2004-07-23
1	6951	7150	1	2004-07-06
2	6951	2275	2	2004-07-06
3	6951	8890	2	2004-07-06
4	6951	1112	2	2004-07-06
5	6951	2641	2	2004-07-06
6	6951	4678	3	2004-07-06
7	6951	4133	2	2004-07-06
8	6951	4747	2	2004-07-06
9	6951	8301	2	2004-07-06
1	6952	3998	3	2004-07-07
2	6952	525	3	2004-07-07
3	6952	7182	1	2004-07-07
4	6952	2131	1	2004-07-07
5	6952	1866	3	2004-07-07
6	6952	3388	2	2004-07-07
7	6952	5263	1	2004-07-07
1	6953	324	1	2004-07-30
2	6953	1586	2	2004-07-30
1	6954	1024	1	2004-07-22
2	6954	9073	1	2004-07-22
3	6954	9213	1	2004-07-22
4	6954	8454	3	2004-07-22
5	6954	406	2	2004-07-22
1	6955	1817	1	2004-07-07
2	6955	8018	3	2004-07-07
3	6955	4480	3	2004-07-07
4	6955	3455	1	2004-07-07
1	6956	8235	1	2004-07-30
1	6957	96	3	2004-07-23
2	6957	9660	3	2004-07-23
3	6957	215	3	2004-07-23
4	6957	9045	1	2004-07-23
5	6957	3748	1	2004-07-23
6	6957	3157	1	2004-07-23
7	6957	4937	2	2004-07-23
8	6957	4765	1	2004-07-23
1	6958	2010	3	2004-07-07
2	6958	9286	3	2004-07-07
3	6958	868	3	2004-07-07
4	6958	492	3	2004-07-07
5	6958	5689	3	2004-07-07
1	6959	5092	2	2004-07-21
2	6959	4409	2	2004-07-21
3	6959	6543	3	2004-07-21
4	6959	5194	3	2004-07-21
5	6959	718	1	2004-07-21
6	6959	4673	2	2004-07-21
1	6960	2234	3	2004-07-10
2	6960	3281	1	2004-07-10
3	6960	4476	2	2004-07-10
4	6960	9038	2	2004-07-10
1	6961	511	3	2004-07-08
2	6961	5319	2	2004-07-08
3	6961	5161	3	2004-07-08
4	6961	9737	1	2004-07-08
5	6961	7883	2	2004-07-08
6	6961	1402	3	2004-07-08
7	6961	5060	2	2004-07-08
8	6961	4083	3	2004-07-08
9	6961	2800	3	2004-07-08
1	6962	6552	1	2004-07-05
2	6962	9026	2	2004-07-05
3	6962	4986	1	2004-07-05
4	6962	316	3	2004-07-05
5	6962	437	1	2004-07-05
1	6963	5481	2	2004-07-25
2	6963	4617	2	2004-07-25
3	6963	1094	2	2004-07-25
1	6964	4296	2	2004-07-07
2	6964	4853	2	2004-07-07
3	6964	9925	1	2004-07-07
4	6964	772	2	2004-07-07
5	6964	414	3	2004-07-07
6	6964	2065	2	2004-07-07
1	6965	3207	1	2004-07-04
2	6965	7401	3	2004-07-04
1	6966	6245	3	2004-07-15
2	6966	5221	3	2004-07-15
3	6966	3044	3	2004-07-15
4	6966	4253	3	2004-07-15
5	6966	2204	3	2004-07-15
6	6966	3233	1	2004-07-15
7	6966	9501	2	2004-07-15
8	6966	8603	3	2004-07-15
9	6966	3802	1	2004-07-15
1	6967	6659	2	2004-07-17
2	6967	901	2	2004-07-17
3	6967	5888	2	2004-07-17
4	6967	6941	1	2004-07-17
5	6967	4689	1	2004-07-17
6	6967	8576	3	2004-07-17
7	6967	1393	1	2004-07-17
8	6967	7220	2	2004-07-17
9	6967	8958	3	2004-07-17
1	6968	6195	1	2004-07-15
2	6968	4164	3	2004-07-15
3	6968	821	3	2004-07-15
4	6968	5008	2	2004-07-15
1	6969	5726	2	2004-07-27
2	6969	5095	1	2004-07-27
3	6969	7697	3	2004-07-27
4	6969	5851	2	2004-07-27
5	6969	9691	3	2004-07-27
6	6969	7890	3	2004-07-27
7	6969	2888	3	2004-07-27
8	6969	6334	3	2004-07-27
9	6969	9038	3	2004-07-27
1	6970	5228	3	2004-07-06
2	6970	5528	1	2004-07-06
3	6970	2726	2	2004-07-06
4	6970	1902	1	2004-07-06
5	6970	3844	3	2004-07-06
6	6970	8861	3	2004-07-06
1	6971	2828	3	2004-07-01
2	6971	3387	1	2004-07-01
3	6971	5322	2	2004-07-01
4	6971	7565	1	2004-07-01
5	6971	3911	2	2004-07-01
6	6971	9538	2	2004-07-01
1	6972	6430	3	2004-07-06
2	6972	7297	3	2004-07-06
3	6972	1610	3	2004-07-06
4	6972	2004	2	2004-07-06
5	6972	6825	1	2004-07-06
6	6972	4393	3	2004-07-06
7	6972	7421	1	2004-07-06
1	6973	965	3	2004-07-11
2	6973	2922	3	2004-07-11
3	6973	8499	3	2004-07-11
4	6973	5131	3	2004-07-11
5	6973	2628	3	2004-07-11
6	6973	5610	2	2004-07-11
1	6974	1195	2	2004-07-13
2	6974	519	1	2004-07-13
1	6975	4461	1	2004-07-28
2	6975	6417	3	2004-07-28
3	6975	1730	3	2004-07-28
1	6976	1224	1	2004-07-14
2	6976	4122	2	2004-07-14
3	6976	1320	3	2004-07-14
4	6976	3317	3	2004-07-14
5	6976	1224	3	2004-07-14
6	6976	8968	1	2004-07-14
7	6976	8663	1	2004-07-14
1	6977	6524	3	2004-07-21
2	6977	8748	1	2004-07-21
3	6977	8906	2	2004-07-21
4	6977	8705	1	2004-07-21
5	6977	3106	1	2004-07-21
1	6978	1174	2	2004-07-11
2	6978	906	1	2004-07-11
3	6978	1235	2	2004-07-11
4	6978	9422	1	2004-07-11
5	6978	1564	3	2004-07-11
1	6979	9407	1	2004-07-18
2	6979	7506	2	2004-07-18
1	6980	1418	2	2004-07-29
2	6980	8875	2	2004-07-29
3	6980	8691	1	2004-07-29
4	6980	2413	3	2004-07-29
5	6980	6757	2	2004-07-29
6	6980	3540	3	2004-07-29
7	6980	6079	2	2004-07-29
8	6980	1884	2	2004-07-29
1	6981	3673	1	2004-07-23
2	6981	4827	1	2004-07-23
3	6981	4354	1	2004-07-23
1	6982	1929	1	2004-07-28
2	6982	1540	1	2004-07-28
3	6982	4527	1	2004-07-28
4	6982	3008	3	2004-07-28
5	6982	9285	3	2004-07-28
6	6982	526	1	2004-07-28
1	6983	2104	2	2004-07-24
2	6983	2756	2	2004-07-24
3	6983	7596	2	2004-07-24
4	6983	8435	1	2004-07-24
5	6983	9508	1	2004-07-24
6	6983	4755	3	2004-07-24
7	6983	6476	2	2004-07-24
8	6983	4438	3	2004-07-24
9	6983	3344	2	2004-07-24
1	6984	4809	2	2004-07-29
2	6984	1978	2	2004-07-29
1	6985	8711	2	2004-07-26
2	6985	746	1	2004-07-26
3	6985	35	3	2004-07-26
4	6985	7896	3	2004-07-26
5	6985	764	3	2004-07-26
6	6985	1256	2	2004-07-26
1	6986	6136	1	2004-07-19
1	6987	7557	2	2004-07-20
2	6987	8033	3	2004-07-20
3	6987	213	2	2004-07-20
1	6988	6191	1	2004-07-28
2	6988	9115	2	2004-07-28
3	6988	1348	3	2004-07-28
4	6988	4694	1	2004-07-28
5	6988	4413	2	2004-07-28
6	6988	7630	1	2004-07-28
7	6988	3681	2	2004-07-28
1	6989	5158	3	2004-07-03
2	6989	9565	1	2004-07-03
3	6989	3638	3	2004-07-03
4	6989	2249	2	2004-07-03
5	6989	3945	1	2004-07-03
6	6989	5999	2	2004-07-03
7	6989	8834	1	2004-07-03
1	6990	4958	1	2004-07-29
1	6991	9703	1	2004-07-09
1	6992	7417	3	2004-07-22
2	6992	4234	3	2004-07-22
3	6992	424	3	2004-07-22
4	6992	4578	1	2004-07-22
5	6992	1721	3	2004-07-22
1	6993	9909	2	2004-07-12
2	6993	640	3	2004-07-12
3	6993	4501	2	2004-07-12
1	6994	7472	2	2004-07-05
1	6995	9735	1	2004-07-10
2	6995	3488	2	2004-07-10
3	6995	9461	2	2004-07-10
4	6995	1839	2	2004-07-10
5	6995	6584	2	2004-07-10
6	6995	2561	1	2004-07-10
1	6996	1229	2	2004-07-04
2	6996	9510	2	2004-07-04
1	6997	1429	1	2004-07-30
2	6997	9010	2	2004-07-30
3	6997	4631	2	2004-07-30
4	6997	432	2	2004-07-30
1	6998	7830	1	2004-07-21
2	6998	50	2	2004-07-21
3	6998	3731	1	2004-07-21
4	6998	4855	2	2004-07-21
5	6998	9898	3	2004-07-21
6	6998	6195	1	2004-07-21
1	6999	6645	3	2004-07-06
2	6999	5470	3	2004-07-06
1	7000	8551	1	2004-07-01
2	7000	9123	2	2004-07-01
3	7000	7077	3	2004-07-01
4	7000	1114	2	2004-07-01
5	7000	7628	1	2004-07-01
1	7001	6079	2	2004-08-16
1	7002	7571	3	2004-08-15
2	7002	730	2	2004-08-15
3	7002	2982	3	2004-08-15
1	7003	2602	2	2004-08-01
2	7003	7955	2	2004-08-01
3	7003	8826	3	2004-08-01
4	7003	2944	2	2004-08-01
5	7003	129	2	2004-08-01
6	7003	6776	2	2004-08-01
7	7003	8422	3	2004-08-01
1	7004	3828	3	2004-08-18
1	7005	6151	3	2004-08-10
2	7005	3287	2	2004-08-10
3	7005	7113	2	2004-08-10
4	7005	4071	3	2004-08-10
1	7006	8917	3	2004-08-02
2	7006	3504	3	2004-08-02
3	7006	985	1	2004-08-02
4	7006	4111	3	2004-08-02
5	7006	153	3	2004-08-02
6	7006	3906	2	2004-08-02
7	7006	9986	3	2004-08-02
8	7006	1501	1	2004-08-02
9	7006	9131	3	2004-08-02
1	7007	1641	2	2004-08-21
2	7007	4317	2	2004-08-21
3	7007	4533	2	2004-08-21
4	7007	7736	3	2004-08-21
5	7007	4122	2	2004-08-21
6	7007	5104	3	2004-08-21
7	7007	5698	2	2004-08-21
8	7007	7903	3	2004-08-21
9	7007	5494	3	2004-08-21
1	7008	7133	2	2004-08-30
2	7008	2423	2	2004-08-30
3	7008	2295	3	2004-08-30
4	7008	1544	3	2004-08-30
5	7008	9013	1	2004-08-30
6	7008	4818	1	2004-08-30
7	7008	8895	3	2004-08-30
8	7008	8136	2	2004-08-30
9	7008	7696	1	2004-08-30
1	7009	8887	3	2004-08-11
2	7009	8788	2	2004-08-11
3	7009	5840	3	2004-08-11
4	7009	3780	3	2004-08-11
5	7009	7741	1	2004-08-11
6	7009	2704	1	2004-08-11
7	7009	7175	2	2004-08-11
8	7009	9238	3	2004-08-11
9	7009	4997	3	2004-08-11
1	7010	9164	3	2004-08-06
1	7011	9658	1	2004-08-24
1	7012	2924	2	2004-08-31
2	7012	6749	3	2004-08-31
3	7012	4001	2	2004-08-31
4	7012	7616	3	2004-08-31
5	7012	4652	2	2004-08-31
6	7012	1702	2	2004-08-31
7	7012	3509	3	2004-08-31
8	7012	2140	2	2004-08-31
1	7013	3436	2	2004-08-21
2	7013	2534	2	2004-08-21
3	7013	4344	1	2004-08-21
4	7013	7264	2	2004-08-21
5	7013	735	3	2004-08-21
6	7013	2510	2	2004-08-21
1	7014	3746	3	2004-08-08
2	7014	3086	3	2004-08-08
3	7014	2767	2	2004-08-08
4	7014	2286	2	2004-08-08
5	7014	1485	2	2004-08-08
6	7014	1686	3	2004-08-08
1	7015	1528	2	2004-08-26
2	7015	6989	2	2004-08-26
1	7016	1154	1	2004-08-27
2	7016	2789	2	2004-08-27
3	7016	1671	1	2004-08-27
4	7016	9917	2	2004-08-27
5	7016	1128	1	2004-08-27
6	7016	3813	2	2004-08-27
7	7016	7789	2	2004-08-27
8	7016	170	3	2004-08-27
9	7016	524	1	2004-08-27
1	7017	248	1	2004-08-23
1	7018	1488	3	2004-08-23
2	7018	4677	1	2004-08-23
3	7018	9464	3	2004-08-23
4	7018	6177	1	2004-08-23
5	7018	616	2	2004-08-23
1	7019	5637	3	2004-08-21
1	7020	7660	2	2004-08-21
2	7020	5653	3	2004-08-21
3	7020	4371	2	2004-08-21
4	7020	8684	1	2004-08-21
5	7020	3137	2	2004-08-21
6	7020	7066	2	2004-08-21
7	7020	2881	1	2004-08-21
1	7021	3478	3	2004-08-23
2	7021	9534	1	2004-08-23
3	7021	1564	3	2004-08-23
4	7021	390	3	2004-08-23
1	7022	3836	1	2004-08-18
2	7022	5096	3	2004-08-18
1	7023	987	3	2004-08-26
2	7023	2587	3	2004-08-26
3	7023	3149	2	2004-08-26
4	7023	9794	1	2004-08-26
5	7023	7811	3	2004-08-26
6	7023	3854	1	2004-08-26
7	7023	8822	2	2004-08-26
1	7024	7586	3	2004-08-05
2	7024	8555	1	2004-08-05
1	7025	1878	3	2004-08-29
2	7025	3757	3	2004-08-29
3	7025	6085	2	2004-08-29
4	7025	5790	3	2004-08-29
1	7026	9351	1	2004-08-09
2	7026	1589	1	2004-08-09
3	7026	3236	1	2004-08-09
1	7027	6254	3	2004-08-21
2	7027	6133	2	2004-08-21
3	7027	8972	2	2004-08-21
4	7027	7197	1	2004-08-21
5	7027	9618	3	2004-08-21
6	7027	9556	2	2004-08-21
7	7027	6340	2	2004-08-21
8	7027	8117	1	2004-08-21
1	7028	3500	1	2004-08-14
2	7028	396	2	2004-08-14
3	7028	3621	2	2004-08-14
4	7028	5498	1	2004-08-14
5	7028	8181	2	2004-08-14
6	7028	8818	2	2004-08-14
7	7028	4674	2	2004-08-14
8	7028	9242	2	2004-08-14
1	7029	5513	2	2004-08-01
2	7029	3269	1	2004-08-01
3	7029	9068	1	2004-08-01
4	7029	3980	2	2004-08-01
5	7029	2296	2	2004-08-01
6	7029	1826	2	2004-08-01
7	7029	5464	1	2004-08-01
8	7029	884	3	2004-08-01
9	7029	5851	2	2004-08-01
1	7030	8465	3	2004-08-29
2	7030	3063	3	2004-08-29
3	7030	994	2	2004-08-29
4	7030	4145	2	2004-08-29
5	7030	3235	3	2004-08-29
6	7030	8294	2	2004-08-29
7	7030	1508	3	2004-08-29
8	7030	7887	2	2004-08-29
1	7031	5979	2	2004-08-03
2	7031	4785	3	2004-08-03
3	7031	5081	1	2004-08-03
1	7032	2489	1	2004-08-11
2	7032	3265	2	2004-08-11
3	7032	837	2	2004-08-11
4	7032	8892	2	2004-08-11
5	7032	9124	1	2004-08-11
6	7032	4638	3	2004-08-11
1	7033	1634	2	2004-08-27
2	7033	6699	1	2004-08-27
3	7033	8082	1	2004-08-27
4	7033	8165	1	2004-08-27
5	7033	9539	1	2004-08-27
6	7033	3501	1	2004-08-27
1	7034	1298	1	2004-08-24
1	7035	7117	2	2004-08-18
2	7035	6680	1	2004-08-18
3	7035	2762	2	2004-08-18
4	7035	7900	3	2004-08-18
5	7035	1824	3	2004-08-18
1	7036	1199	3	2004-08-10
2	7036	4005	1	2004-08-10
1	7037	5673	1	2004-08-10
1	7038	9106	1	2004-08-03
2	7038	1058	2	2004-08-03
3	7038	5745	3	2004-08-03
4	7038	7976	3	2004-08-03
5	7038	3047	2	2004-08-03
6	7038	6046	2	2004-08-03
1	7039	243	2	2004-08-17
2	7039	6973	2	2004-08-17
3	7039	5329	1	2004-08-17
4	7039	1754	3	2004-08-17
5	7039	815	3	2004-08-17
6	7039	1064	1	2004-08-17
7	7039	4397	2	2004-08-17
1	7040	9724	1	2004-08-26
2	7040	6957	3	2004-08-26
3	7040	9893	1	2004-08-26
4	7040	3574	2	2004-08-26
5	7040	4874	3	2004-08-26
6	7040	5042	3	2004-08-26
7	7040	6089	2	2004-08-26
8	7040	2857	1	2004-08-26
9	7040	9532	3	2004-08-26
1	7041	8711	3	2004-08-10
2	7041	5616	1	2004-08-10
3	7041	3340	2	2004-08-10
4	7041	6609	3	2004-08-10
1	7042	4031	1	2004-08-10
2	7042	9956	3	2004-08-10
3	7042	6200	2	2004-08-10
4	7042	6585	1	2004-08-10
5	7042	3095	1	2004-08-10
6	7042	6527	2	2004-08-10
7	7042	5735	2	2004-08-10
8	7042	4138	3	2004-08-10
9	7042	7343	1	2004-08-10
1	7043	9161	1	2004-08-09
2	7043	2231	2	2004-08-09
3	7043	1590	2	2004-08-09
4	7043	2102	1	2004-08-09
5	7043	5179	2	2004-08-09
6	7043	2220	2	2004-08-09
7	7043	3737	3	2004-08-09
8	7043	9963	1	2004-08-09
1	7044	9010	3	2004-08-30
2	7044	2246	1	2004-08-30
3	7044	7607	3	2004-08-30
4	7044	4317	1	2004-08-30
5	7044	5643	2	2004-08-30
6	7044	8899	2	2004-08-30
1	7045	6355	1	2004-08-20
2	7045	9738	1	2004-08-20
3	7045	8807	1	2004-08-20
4	7045	6668	1	2004-08-20
5	7045	377	2	2004-08-20
6	7045	2864	1	2004-08-20
7	7045	9688	2	2004-08-20
8	7045	6226	3	2004-08-20
1	7046	8060	2	2004-08-15
2	7046	2637	2	2004-08-15
1	7047	2665	3	2004-08-31
2	7047	3715	3	2004-08-31
3	7047	1752	2	2004-08-31
4	7047	553	1	2004-08-31
5	7047	5410	3	2004-08-31
6	7047	3102	2	2004-08-31
1	7048	1822	1	2004-08-12
2	7048	2234	2	2004-08-12
3	7048	521	2	2004-08-12
4	7048	8599	3	2004-08-12
1	7049	2771	1	2004-08-01
2	7049	5919	2	2004-08-01
3	7049	9864	3	2004-08-01
4	7049	4454	1	2004-08-01
5	7049	3086	2	2004-08-01
6	7049	2174	3	2004-08-01
7	7049	2225	2	2004-08-01
8	7049	4281	2	2004-08-01
9	7049	1240	1	2004-08-01
1	7050	9469	1	2004-08-30
2	7050	5923	3	2004-08-30
1	7051	6145	1	2004-08-04
2	7051	4325	1	2004-08-04
3	7051	7509	2	2004-08-04
4	7051	1696	1	2004-08-04
1	7052	3275	3	2004-08-18
2	7052	3252	3	2004-08-18
3	7052	5267	2	2004-08-18
4	7052	7661	2	2004-08-18
5	7052	7554	3	2004-08-18
6	7052	6723	3	2004-08-18
7	7052	2492	1	2004-08-18
8	7052	5090	2	2004-08-18
1	7053	6467	1	2004-08-28
2	7053	7013	2	2004-08-28
3	7053	5798	3	2004-08-28
4	7053	5937	1	2004-08-28
5	7053	3489	1	2004-08-28
1	7054	4319	3	2004-08-30
2	7054	7321	1	2004-08-30
3	7054	2242	2	2004-08-30
1	7055	1609	3	2004-08-06
2	7055	8033	1	2004-08-06
3	7055	1379	2	2004-08-06
4	7055	5366	3	2004-08-06
1	7056	1087	3	2004-08-22
2	7056	4325	2	2004-08-22
3	7056	661	2	2004-08-22
1	7057	121	2	2004-08-05
2	7057	7635	1	2004-08-05
3	7057	8926	3	2004-08-05
4	7057	1326	1	2004-08-05
5	7057	3715	1	2004-08-05
6	7057	7809	1	2004-08-05
1	7058	7033	2	2004-08-11
2	7058	1095	3	2004-08-11
3	7058	6717	1	2004-08-11
4	7058	6609	1	2004-08-11
5	7058	6756	3	2004-08-11
6	7058	4943	3	2004-08-11
7	7058	26	1	2004-08-11
8	7058	3749	1	2004-08-11
1	7059	812	2	2004-08-18
2	7059	5473	2	2004-08-18
3	7059	6769	1	2004-08-18
4	7059	6274	1	2004-08-18
5	7059	2468	2	2004-08-18
1	7060	8353	2	2004-08-28
2	7060	2109	2	2004-08-28
3	7060	5090	3	2004-08-28
4	7060	2230	1	2004-08-28
5	7060	6957	1	2004-08-28
6	7060	1706	1	2004-08-28
7	7060	2402	3	2004-08-28
8	7060	2088	2	2004-08-28
9	7060	2080	1	2004-08-28
1	7061	833	2	2004-08-28
2	7061	5631	1	2004-08-28
3	7061	7040	2	2004-08-28
4	7061	2801	2	2004-08-28
5	7061	4392	1	2004-08-28
1	7062	5364	3	2004-08-27
2	7062	3540	1	2004-08-27
3	7062	599	2	2004-08-27
4	7062	3025	1	2004-08-27
1	7063	8011	2	2004-08-09
2	7063	2306	2	2004-08-09
3	7063	2166	1	2004-08-09
4	7063	9137	3	2004-08-09
5	7063	6439	2	2004-08-09
1	7064	393	3	2004-08-08
2	7064	3151	2	2004-08-08
3	7064	2473	3	2004-08-08
4	7064	4849	2	2004-08-08
5	7064	834	2	2004-08-08
6	7064	1257	2	2004-08-08
1	7065	8685	3	2004-08-27
2	7065	3011	1	2004-08-27
3	7065	2417	2	2004-08-27
4	7065	4129	1	2004-08-27
5	7065	2973	1	2004-08-27
6	7065	7730	2	2004-08-27
1	7066	7241	2	2004-08-31
1	7067	5725	2	2004-08-21
2	7067	6999	3	2004-08-21
1	7068	1802	3	2004-08-26
2	7068	4187	2	2004-08-26
3	7068	589	2	2004-08-26
4	7068	9988	2	2004-08-26
5	7068	8157	1	2004-08-26
6	7068	5284	2	2004-08-26
7	7068	8192	2	2004-08-26
1	7069	5107	1	2004-08-13
2	7069	1115	3	2004-08-13
1	7070	3821	1	2004-08-11
1	7071	4331	1	2004-08-19
2	7071	2602	2	2004-08-19
3	7071	9269	1	2004-08-19
4	7071	9636	3	2004-08-19
5	7071	5549	2	2004-08-19
6	7071	3312	2	2004-08-19
7	7071	9	3	2004-08-19
8	7071	3815	2	2004-08-19
1	7072	7575	1	2004-08-28
2	7072	6828	1	2004-08-28
3	7072	1375	1	2004-08-28
4	7072	1880	3	2004-08-28
5	7072	5381	1	2004-08-28
6	7072	5152	3	2004-08-28
7	7072	3024	3	2004-08-28
8	7072	4630	1	2004-08-28
9	7072	342	2	2004-08-28
1	7073	9631	3	2004-08-31
2	7073	502	2	2004-08-31
3	7073	4490	3	2004-08-31
1	7074	2609	2	2004-08-08
2	7074	548	2	2004-08-08
3	7074	6841	1	2004-08-08
4	7074	1346	1	2004-08-08
5	7074	2786	2	2004-08-08
6	7074	1933	2	2004-08-08
7	7074	4250	2	2004-08-08
8	7074	8101	2	2004-08-08
9	7074	828	3	2004-08-08
1	7075	9204	1	2004-08-02
1	7076	5470	1	2004-08-12
2	7076	5861	3	2004-08-12
3	7076	6282	2	2004-08-12
4	7076	2062	1	2004-08-12
5	7076	8837	2	2004-08-12
6	7076	5344	1	2004-08-12
1	7077	3839	2	2004-08-31
2	7077	8745	2	2004-08-31
3	7077	3349	3	2004-08-31
4	7077	4677	2	2004-08-31
1	7078	7572	2	2004-08-29
2	7078	8814	1	2004-08-29
3	7078	6357	2	2004-08-29
1	7079	5762	3	2004-08-04
2	7079	6589	1	2004-08-04
3	7079	1542	2	2004-08-04
1	7080	4504	3	2004-08-26
2	7080	6885	3	2004-08-26
1	7081	5441	3	2004-08-27
2	7081	845	1	2004-08-27
3	7081	3859	3	2004-08-27
4	7081	6054	1	2004-08-27
5	7081	4333	3	2004-08-27
6	7081	2854	2	2004-08-27
7	7081	354	3	2004-08-27
8	7081	5336	3	2004-08-27
1	7082	5850	2	2004-08-31
2	7082	320	1	2004-08-31
3	7082	3470	3	2004-08-31
4	7082	8205	1	2004-08-31
5	7082	8766	1	2004-08-31
6	7082	36	2	2004-08-31
7	7082	7843	1	2004-08-31
8	7082	7219	1	2004-08-31
1	7083	445	2	2004-08-02
2	7083	287	1	2004-08-02
3	7083	3384	2	2004-08-02
4	7083	7740	1	2004-08-02
5	7083	2499	1	2004-08-02
1	7084	8701	3	2004-08-04
2	7084	8728	3	2004-08-04
1	7085	1701	2	2004-08-03
1	7086	2191	3	2004-08-06
2	7086	7131	1	2004-08-06
3	7086	3386	3	2004-08-06
1	7087	9873	2	2004-08-11
2	7087	2347	1	2004-08-11
1	7088	6323	1	2004-08-13
2	7088	9493	3	2004-08-13
3	7088	8821	2	2004-08-13
1	7089	9440	3	2004-08-25
2	7089	1954	1	2004-08-25
3	7089	6969	3	2004-08-25
4	7089	4266	1	2004-08-25
5	7089	6501	3	2004-08-25
6	7089	7125	3	2004-08-25
7	7089	8872	3	2004-08-25
8	7089	5078	1	2004-08-25
9	7089	8073	3	2004-08-25
1	7090	1998	1	2004-08-28
2	7090	2270	1	2004-08-28
3	7090	7694	1	2004-08-28
4	7090	1340	3	2004-08-28
5	7090	9933	1	2004-08-28
1	7091	970	3	2004-08-24
2	7091	5020	3	2004-08-24
3	7091	4374	1	2004-08-24
4	7091	7011	1	2004-08-24
5	7091	9141	1	2004-08-24
1	7092	7883	1	2004-08-14
2	7092	8424	3	2004-08-14
3	7092	3646	1	2004-08-14
1	7093	683	1	2004-08-03
2	7093	2817	3	2004-08-03
1	7094	1902	3	2004-08-09
2	7094	1193	2	2004-08-09
3	7094	208	3	2004-08-09
4	7094	9522	3	2004-08-09
1	7095	7268	2	2004-08-01
2	7095	3946	2	2004-08-01
1	7096	8930	3	2004-08-14
2	7096	7060	3	2004-08-14
3	7096	8183	3	2004-08-14
4	7096	7992	1	2004-08-14
5	7096	5104	1	2004-08-14
1	7097	3281	3	2004-08-15
2	7097	4052	1	2004-08-15
3	7097	8653	2	2004-08-15
4	7097	6787	2	2004-08-15
5	7097	5687	2	2004-08-15
6	7097	9655	3	2004-08-15
1	7098	8999	2	2004-08-31
2	7098	3446	2	2004-08-31
3	7098	5766	1	2004-08-31
4	7098	5935	2	2004-08-31
5	7098	2563	1	2004-08-31
6	7098	4792	3	2004-08-31
1	7099	3196	3	2004-08-25
2	7099	4124	1	2004-08-25
1	7100	4964	3	2004-08-05
2	7100	6781	2	2004-08-05
3	7100	691	2	2004-08-05
4	7100	838	3	2004-08-05
5	7100	158	2	2004-08-05
6	7100	5748	2	2004-08-05
7	7100	5912	1	2004-08-05
1	7101	5694	1	2004-08-31
2	7101	8363	3	2004-08-31
3	7101	2085	1	2004-08-31
4	7101	5881	2	2004-08-31
5	7101	3407	3	2004-08-31
1	7102	7180	1	2004-08-23
2	7102	6791	3	2004-08-23
1	7103	1911	1	2004-08-17
2	7103	1356	3	2004-08-17
3	7103	4990	1	2004-08-17
4	7103	6298	3	2004-08-17
5	7103	5508	1	2004-08-17
1	7104	5428	2	2004-08-27
1	7105	9300	3	2004-08-21
2	7105	5961	2	2004-08-21
3	7105	9736	1	2004-08-21
4	7105	4351	2	2004-08-21
1	7106	5219	1	2004-08-02
2	7106	113	1	2004-08-02
3	7106	2834	2	2004-08-02
1	7107	2211	3	2004-08-25
2	7107	6943	3	2004-08-25
3	7107	5784	2	2004-08-25
4	7107	6473	3	2004-08-25
5	7107	7585	2	2004-08-25
6	7107	8223	2	2004-08-25
1	7108	2969	3	2004-08-07
2	7108	8514	2	2004-08-07
3	7108	8965	2	2004-08-07
4	7108	5209	3	2004-08-07
5	7108	3941	3	2004-08-07
6	7108	5486	1	2004-08-07
1	7109	3037	2	2004-08-20
2	7109	6233	3	2004-08-20
3	7109	8893	1	2004-08-20
4	7109	8578	2	2004-08-20
5	7109	8477	3	2004-08-20
6	7109	22	1	2004-08-20
7	7109	4758	2	2004-08-20
8	7109	7332	3	2004-08-20
1	7110	9578	2	2004-08-10
2	7110	1033	2	2004-08-10
1	7111	404	2	2004-08-14
1	7112	2261	3	2004-08-30
2	7112	8300	1	2004-08-30
3	7112	4180	3	2004-08-30
4	7112	7638	2	2004-08-30
5	7112	7506	1	2004-08-30
6	7112	520	2	2004-08-30
1	7113	5468	1	2004-08-01
2	7113	7603	2	2004-08-01
1	7114	2760	2	2004-08-12
2	7114	2778	1	2004-08-12
3	7114	6862	1	2004-08-12
4	7114	7719	3	2004-08-12
5	7114	9291	2	2004-08-12
6	7114	9960	2	2004-08-12
7	7114	2796	3	2004-08-12
8	7114	7672	1	2004-08-12
9	7114	9994	3	2004-08-12
1	7115	1373	3	2004-08-16
2	7115	6082	3	2004-08-16
3	7115	3671	3	2004-08-16
4	7115	966	3	2004-08-16
5	7115	9016	2	2004-08-16
6	7115	111	1	2004-08-16
1	7116	6094	1	2004-08-19
2	7116	9586	2	2004-08-19
3	7116	6141	1	2004-08-19
4	7116	3652	2	2004-08-19
1	7117	3761	2	2004-08-09
2	7117	3641	2	2004-08-09
3	7117	876	3	2004-08-09
4	7117	4109	2	2004-08-09
5	7117	9582	2	2004-08-09
6	7117	1235	3	2004-08-09
7	7117	8799	1	2004-08-09
8	7117	389	2	2004-08-09
1	7118	6440	3	2004-08-26
2	7118	465	1	2004-08-26
3	7118	179	2	2004-08-26
4	7118	6394	1	2004-08-26
1	7119	2103	2	2004-08-25
2	7119	6655	1	2004-08-25
1	7120	5837	3	2004-08-13
2	7120	2218	2	2004-08-13
3	7120	105	1	2004-08-13
4	7120	9283	3	2004-08-13
1	7121	5295	1	2004-08-20
2	7121	5397	2	2004-08-20
3	7121	7414	1	2004-08-20
1	7122	6697	1	2004-08-26
2	7122	3333	2	2004-08-26
3	7122	5269	3	2004-08-26
4	7122	4114	1	2004-08-26
5	7122	995	3	2004-08-26
6	7122	1552	1	2004-08-26
7	7122	4586	1	2004-08-26
8	7122	5820	2	2004-08-26
9	7122	78	1	2004-08-26
1	7123	6208	1	2004-08-05
2	7123	2132	2	2004-08-05
3	7123	2199	1	2004-08-05
4	7123	8796	1	2004-08-05
5	7123	9479	2	2004-08-05
6	7123	4676	1	2004-08-05
1	7124	2736	1	2004-08-28
2	7124	2908	2	2004-08-28
3	7124	4391	3	2004-08-28
1	7125	2405	1	2004-08-19
2	7125	8931	3	2004-08-19
3	7125	9383	2	2004-08-19
4	7125	7824	1	2004-08-19
5	7125	8759	1	2004-08-19
6	7125	1980	3	2004-08-19
1	7126	4270	1	2004-08-08
2	7126	7026	2	2004-08-08
3	7126	4847	3	2004-08-08
4	7126	5632	3	2004-08-08
5	7126	4049	1	2004-08-08
6	7126	5246	3	2004-08-08
7	7126	232	2	2004-08-08
1	7127	53	3	2004-08-19
2	7127	82	3	2004-08-19
3	7127	228	3	2004-08-19
4	7127	7898	1	2004-08-19
5	7127	6394	1	2004-08-19
1	7128	1329	2	2004-08-12
2	7128	2388	2	2004-08-12
3	7128	4174	3	2004-08-12
4	7128	3929	3	2004-08-12
5	7128	8041	3	2004-08-12
6	7128	8214	3	2004-08-12
7	7128	5781	2	2004-08-12
8	7128	909	2	2004-08-12
1	7129	8837	2	2004-08-29
2	7129	8090	3	2004-08-29
3	7129	6259	2	2004-08-29
4	7129	7039	3	2004-08-29
5	7129	3922	2	2004-08-29
6	7129	7859	2	2004-08-29
7	7129	8838	1	2004-08-29
8	7129	1425	1	2004-08-29
9	7129	8265	2	2004-08-29
1	7130	4579	1	2004-08-04
2	7130	3671	2	2004-08-04
3	7130	5419	1	2004-08-04
4	7130	6449	3	2004-08-04
5	7130	2090	2	2004-08-04
6	7130	3293	1	2004-08-04
7	7130	2019	3	2004-08-04
8	7130	4662	3	2004-08-04
9	7130	9475	3	2004-08-04
1	7131	7579	2	2004-08-11
2	7131	5331	2	2004-08-11
3	7131	612	2	2004-08-11
1	7132	5446	3	2004-08-07
2	7132	2215	1	2004-08-07
3	7132	2519	3	2004-08-07
4	7132	106	2	2004-08-07
5	7132	3948	2	2004-08-07
6	7132	4787	2	2004-08-07
7	7132	2950	3	2004-08-07
1	7133	9758	1	2004-08-16
2	7133	825	3	2004-08-16
3	7133	7123	2	2004-08-16
4	7133	3180	3	2004-08-16
5	7133	2718	2	2004-08-16
6	7133	2873	3	2004-08-16
7	7133	2056	3	2004-08-16
8	7133	8405	2	2004-08-16
1	7134	5532	3	2004-08-29
2	7134	2687	1	2004-08-29
3	7134	2848	2	2004-08-29
4	7134	9767	3	2004-08-29
5	7134	8061	3	2004-08-29
6	7134	6376	3	2004-08-29
7	7134	9663	3	2004-08-29
8	7134	5154	3	2004-08-29
9	7134	3356	3	2004-08-29
1	7135	4799	2	2004-08-15
2	7135	5711	1	2004-08-15
3	7135	9988	2	2004-08-15
4	7135	4126	1	2004-08-15
5	7135	4180	3	2004-08-15
6	7135	9803	3	2004-08-15
7	7135	9975	1	2004-08-15
1	7136	7540	3	2004-08-08
1	7137	3987	3	2004-08-26
2	7137	1869	3	2004-08-26
3	7137	3525	2	2004-08-26
4	7137	5899	3	2004-08-26
1	7138	6501	2	2004-08-04
2	7138	4156	1	2004-08-04
1	7139	6608	1	2004-08-17
2	7139	5024	3	2004-08-17
3	7139	615	1	2004-08-17
4	7139	4025	3	2004-08-17
5	7139	9765	3	2004-08-17
1	7140	2258	3	2004-08-08
2	7140	9932	3	2004-08-08
3	7140	7421	1	2004-08-08
4	7140	9765	3	2004-08-08
1	7141	6947	3	2004-08-08
2	7141	527	2	2004-08-08
3	7141	5188	3	2004-08-08
4	7141	4545	1	2004-08-08
5	7141	4262	2	2004-08-08
6	7141	2774	3	2004-08-08
1	7142	6289	1	2004-08-13
2	7142	1091	3	2004-08-13
3	7142	1077	1	2004-08-13
4	7142	6703	3	2004-08-13
5	7142	2200	2	2004-08-13
6	7142	7444	2	2004-08-13
7	7142	2733	1	2004-08-13
1	7143	4174	3	2004-08-04
2	7143	8841	3	2004-08-04
1	7144	1388	3	2004-08-23
1	7145	9773	2	2004-08-09
2	7145	7490	1	2004-08-09
3	7145	6835	2	2004-08-09
4	7145	9347	3	2004-08-09
5	7145	660	3	2004-08-09
6	7145	3647	2	2004-08-09
7	7145	8830	2	2004-08-09
8	7145	3072	1	2004-08-09
9	7145	6535	3	2004-08-09
1	7146	8477	3	2004-08-25
2	7146	5367	3	2004-08-25
3	7146	7873	3	2004-08-25
4	7146	7658	1	2004-08-25
5	7146	6964	3	2004-08-25
1	7147	8645	3	2004-08-27
2	7147	4278	3	2004-08-27
3	7147	4415	3	2004-08-27
4	7147	2697	1	2004-08-27
5	7147	2752	2	2004-08-27
1	7148	4661	3	2004-08-13
2	7148	7176	1	2004-08-13
1	7149	562	1	2004-08-28
2	7149	9283	3	2004-08-28
3	7149	8089	3	2004-08-28
4	7149	1978	2	2004-08-28
5	7149	2933	1	2004-08-28
6	7149	3994	3	2004-08-28
7	7149	9926	3	2004-08-28
1	7150	8390	2	2004-08-16
2	7150	7172	1	2004-08-16
3	7150	7598	1	2004-08-16
4	7150	377	2	2004-08-16
5	7150	4969	3	2004-08-16
6	7150	7314	3	2004-08-16
7	7150	5880	3	2004-08-16
8	7150	8628	2	2004-08-16
1	7151	3084	2	2004-08-17
2	7151	7999	3	2004-08-17
3	7151	2995	3	2004-08-17
4	7151	5486	3	2004-08-17
5	7151	546	3	2004-08-17
6	7151	6015	3	2004-08-17
7	7151	2811	1	2004-08-17
1	7152	5180	3	2004-08-02
1	7153	369	2	2004-08-31
2	7153	946	2	2004-08-31
3	7153	3298	2	2004-08-31
4	7153	3146	2	2004-08-31
5	7153	9582	1	2004-08-31
6	7153	3460	1	2004-08-31
1	7154	6084	3	2004-08-29
2	7154	8548	3	2004-08-29
3	7154	9906	3	2004-08-29
4	7154	9301	2	2004-08-29
5	7154	9597	2	2004-08-29
6	7154	4910	3	2004-08-29
7	7154	6974	1	2004-08-29
8	7154	5285	3	2004-08-29
9	7154	9446	2	2004-08-29
1	7155	9126	3	2004-08-10
2	7155	7401	1	2004-08-10
3	7155	2186	2	2004-08-10
4	7155	1530	1	2004-08-10
5	7155	6082	3	2004-08-10
6	7155	9611	2	2004-08-10
1	7156	4440	1	2004-08-21
2	7156	288	3	2004-08-21
3	7156	2609	3	2004-08-21
4	7156	2213	3	2004-08-21
5	7156	4605	1	2004-08-21
6	7156	4124	3	2004-08-21
1	7157	3759	1	2004-08-14
2	7157	6113	2	2004-08-14
3	7157	7842	3	2004-08-14
4	7157	8835	2	2004-08-14
1	7158	7961	1	2004-08-17
2	7158	7571	1	2004-08-17
1	7159	5120	2	2004-08-17
2	7159	5675	3	2004-08-17
3	7159	5620	3	2004-08-17
4	7159	7440	1	2004-08-17
5	7159	3948	1	2004-08-17
6	7159	3550	3	2004-08-17
7	7159	2784	3	2004-08-17
8	7159	3650	1	2004-08-17
1	7160	928	1	2004-08-23
2	7160	4323	3	2004-08-23
3	7160	5164	1	2004-08-23
1	7161	8116	2	2004-08-04
2	7161	7000	2	2004-08-04
3	7161	4595	1	2004-08-04
1	7162	3445	2	2004-08-12
2	7162	5240	2	2004-08-12
3	7162	5851	3	2004-08-12
4	7162	6854	1	2004-08-12
5	7162	1373	1	2004-08-12
6	7162	5715	1	2004-08-12
7	7162	4502	1	2004-08-12
1	7163	10000	1	2004-08-04
2	7163	5517	3	2004-08-04
3	7163	6551	1	2004-08-04
1	7164	3179	3	2004-08-06
2	7164	3024	2	2004-08-06
3	7164	3963	3	2004-08-06
4	7164	2852	3	2004-08-06
5	7164	7153	3	2004-08-06
1	7165	826	2	2004-08-10
2	7165	8721	1	2004-08-10
3	7165	5274	1	2004-08-10
4	7165	4493	2	2004-08-10
5	7165	2331	1	2004-08-10
6	7165	3387	3	2004-08-10
7	7165	2524	2	2004-08-10
8	7165	26	3	2004-08-10
1	7166	9827	3	2004-08-03
2	7166	2068	1	2004-08-03
3	7166	9208	3	2004-08-03
4	7166	2383	1	2004-08-03
1	7167	9099	3	2004-08-25
2	7167	585	2	2004-08-25
3	7167	229	2	2004-08-25
4	7167	9645	1	2004-08-25
5	7167	5086	1	2004-08-25
6	7167	1440	3	2004-08-25
7	7167	8322	1	2004-08-25
8	7167	5266	3	2004-08-25
1	7168	91	2	2004-08-15
2	7168	7172	3	2004-08-15
3	7168	4195	3	2004-08-15
4	7168	1473	1	2004-08-15
5	7168	3045	1	2004-08-15
1	7169	6516	1	2004-08-02
1	7170	9192	2	2004-08-20
2	7170	8866	3	2004-08-20
1	7171	4828	3	2004-08-24
2	7171	6766	2	2004-08-24
3	7171	4496	2	2004-08-24
1	7172	630	2	2004-08-14
2	7172	8021	1	2004-08-14
3	7172	8680	3	2004-08-14
4	7172	2235	2	2004-08-14
5	7172	2070	3	2004-08-14
6	7172	1356	3	2004-08-14
1	7173	8061	1	2004-08-30
2	7173	2661	2	2004-08-30
3	7173	2780	3	2004-08-30
4	7173	4197	3	2004-08-30
5	7173	2407	3	2004-08-30
6	7173	3482	2	2004-08-30
7	7173	7381	3	2004-08-30
8	7173	2311	3	2004-08-30
1	7174	262	1	2004-08-11
2	7174	7386	1	2004-08-11
1	7175	9289	1	2004-08-31
2	7175	7985	3	2004-08-31
3	7175	2515	1	2004-08-31
4	7175	2025	2	2004-08-31
5	7175	8133	2	2004-08-31
6	7175	4839	1	2004-08-31
7	7175	4912	3	2004-08-31
8	7175	7162	1	2004-08-31
9	7175	5294	3	2004-08-31
1	7176	994	1	2004-08-01
2	7176	839	3	2004-08-01
3	7176	2398	1	2004-08-01
4	7176	7121	1	2004-08-01
5	7176	86	2	2004-08-01
6	7176	3503	3	2004-08-01
7	7176	3759	2	2004-08-01
8	7176	8715	2	2004-08-01
9	7176	1311	3	2004-08-01
1	7177	4469	2	2004-08-07
2	7177	9208	3	2004-08-07
3	7177	4022	3	2004-08-07
4	7177	8567	2	2004-08-07
5	7177	8964	3	2004-08-07
6	7177	3892	3	2004-08-07
7	7177	7939	2	2004-08-07
1	7178	1468	1	2004-08-02
1	7179	1009	3	2004-08-27
2	7179	4149	1	2004-08-27
3	7179	4764	1	2004-08-27
4	7179	9926	3	2004-08-27
5	7179	6085	3	2004-08-27
6	7179	8995	1	2004-08-27
7	7179	8643	3	2004-08-27
1	7180	7408	2	2004-08-13
2	7180	4112	3	2004-08-13
3	7180	117	1	2004-08-13
4	7180	8356	1	2004-08-13
5	7180	3186	3	2004-08-13
6	7180	6811	1	2004-08-13
7	7180	4244	3	2004-08-13
8	7180	9105	3	2004-08-13
1	7181	3100	2	2004-08-03
1	7182	9654	1	2004-08-31
2	7182	6137	3	2004-08-31
3	7182	7874	2	2004-08-31
4	7182	1832	1	2004-08-31
5	7182	1383	1	2004-08-31
6	7182	3883	3	2004-08-31
7	7182	3533	3	2004-08-31
8	7182	6681	1	2004-08-31
1	7183	9317	3	2004-08-24
2	7183	530	3	2004-08-24
3	7183	9747	2	2004-08-24
4	7183	5258	3	2004-08-24
5	7183	5722	1	2004-08-24
6	7183	8166	2	2004-08-24
1	7184	7846	2	2004-08-05
2	7184	1286	3	2004-08-05
3	7184	5927	2	2004-08-05
4	7184	8966	3	2004-08-05
5	7184	2237	2	2004-08-05
6	7184	9802	3	2004-08-05
7	7184	6571	3	2004-08-05
8	7184	6456	2	2004-08-05
9	7184	6955	3	2004-08-05
1	7185	6336	2	2004-08-16
1	7186	8803	2	2004-08-06
2	7186	2492	2	2004-08-06
3	7186	7836	2	2004-08-06
1	7187	3221	1	2004-08-19
2	7187	489	1	2004-08-19
3	7187	977	3	2004-08-19
4	7187	987	3	2004-08-19
5	7187	2945	3	2004-08-19
1	7188	8464	1	2004-08-14
2	7188	1365	1	2004-08-14
3	7188	5478	1	2004-08-14
4	7188	3420	2	2004-08-14
5	7188	6930	2	2004-08-14
1	7189	8527	3	2004-08-03
2	7189	1647	1	2004-08-03
3	7189	9817	1	2004-08-03
4	7189	4771	1	2004-08-03
5	7189	9193	2	2004-08-03
6	7189	8225	1	2004-08-03
7	7189	3698	1	2004-08-03
1	7190	9317	3	2004-08-01
2	7190	8904	2	2004-08-01
3	7190	2108	1	2004-08-01
4	7190	9074	3	2004-08-01
5	7190	8234	1	2004-08-01
6	7190	3803	3	2004-08-01
7	7190	6806	1	2004-08-01
8	7190	6556	3	2004-08-01
1	7191	7165	3	2004-08-13
2	7191	4606	2	2004-08-13
3	7191	1916	3	2004-08-13
4	7191	8031	1	2004-08-13
5	7191	6643	2	2004-08-13
6	7191	804	2	2004-08-13
7	7191	4736	3	2004-08-13
8	7191	753	3	2004-08-13
1	7192	9829	3	2004-08-07
1	7193	5087	2	2004-08-26
2	7193	1114	2	2004-08-26
3	7193	4939	3	2004-08-26
4	7193	5452	3	2004-08-26
5	7193	3668	3	2004-08-26
1	7194	7399	1	2004-08-25
2	7194	449	1	2004-08-25
3	7194	6	1	2004-08-25
4	7194	8978	1	2004-08-25
5	7194	1028	2	2004-08-25
1	7195	7491	2	2004-08-08
1	7196	8251	3	2004-08-17
2	7196	4617	2	2004-08-17
3	7196	7126	3	2004-08-17
4	7196	1069	2	2004-08-17
5	7196	9982	1	2004-08-17
6	7196	9462	3	2004-08-17
1	7197	1112	3	2004-08-03
1	7198	2996	3	2004-08-09
2	7198	5685	1	2004-08-09
3	7198	4444	1	2004-08-09
4	7198	3064	3	2004-08-09
5	7198	7249	1	2004-08-09
1	7199	150	2	2004-08-15
2	7199	6768	1	2004-08-15
1	7200	6140	3	2004-08-21
2	7200	8373	3	2004-08-21
3	7200	5516	1	2004-08-21
4	7200	9391	3	2004-08-21
5	7200	6474	1	2004-08-21
6	7200	6754	1	2004-08-21
7	7200	2873	1	2004-08-21
1	7201	7251	1	2004-08-10
1	7202	8350	1	2004-08-07
2	7202	2462	2	2004-08-07
3	7202	7747	3	2004-08-07
1	7203	1137	1	2004-08-08
1	7204	2912	3	2004-08-07
2	7204	780	2	2004-08-07
3	7204	9328	2	2004-08-07
4	7204	1721	3	2004-08-07
5	7204	4164	3	2004-08-07
6	7204	568	2	2004-08-07
7	7204	1237	2	2004-08-07
8	7204	8676	3	2004-08-07
1	7205	1110	3	2004-08-22
2	7205	8466	3	2004-08-22
3	7205	7961	3	2004-08-22
4	7205	619	1	2004-08-22
5	7205	129	1	2004-08-22
1	7206	8825	3	2004-08-28
2	7206	3357	1	2004-08-28
3	7206	7066	3	2004-08-28
4	7206	9516	3	2004-08-28
5	7206	3866	1	2004-08-28
6	7206	2951	1	2004-08-28
7	7206	339	3	2004-08-28
8	7206	3679	2	2004-08-28
9	7206	4366	2	2004-08-28
1	7207	2433	2	2004-08-07
2	7207	77	1	2004-08-07
3	7207	5509	3	2004-08-07
4	7207	5602	2	2004-08-07
5	7207	8317	2	2004-08-07
6	7207	5086	1	2004-08-07
7	7207	4971	1	2004-08-07
8	7207	9194	2	2004-08-07
9	7207	9784	1	2004-08-07
1	7208	2519	3	2004-08-17
2	7208	499	3	2004-08-17
3	7208	4067	1	2004-08-17
4	7208	9715	3	2004-08-17
5	7208	2474	1	2004-08-17
6	7208	475	1	2004-08-17
1	7209	1616	3	2004-08-15
1	7210	8852	1	2004-08-15
2	7210	4192	3	2004-08-15
3	7210	3601	3	2004-08-15
4	7210	1370	3	2004-08-15
5	7210	5006	2	2004-08-15
6	7210	8479	2	2004-08-15
7	7210	773	1	2004-08-15
8	7210	8010	1	2004-08-15
9	7210	9506	1	2004-08-15
1	7211	5962	2	2004-08-09
2	7211	7656	3	2004-08-09
3	7211	4064	1	2004-08-09
4	7211	4278	2	2004-08-09
5	7211	2098	1	2004-08-09
6	7211	5954	2	2004-08-09
7	7211	1766	3	2004-08-09
1	7212	7024	3	2004-08-18
1	7213	8284	3	2004-08-20
2	7213	4721	1	2004-08-20
3	7213	9262	3	2004-08-20
4	7213	8265	2	2004-08-20
1	7214	8311	3	2004-08-07
2	7214	1618	1	2004-08-07
3	7214	208	3	2004-08-07
4	7214	6698	1	2004-08-07
5	7214	7125	1	2004-08-07
6	7214	5108	2	2004-08-07
1	7215	9928	1	2004-08-10
2	7215	3608	3	2004-08-10
3	7215	2170	3	2004-08-10
4	7215	9131	1	2004-08-10
5	7215	6081	3	2004-08-10
6	7215	6654	3	2004-08-10
7	7215	3315	3	2004-08-10
8	7215	4430	1	2004-08-10
9	7215	6532	2	2004-08-10
1	7216	8712	1	2004-08-07
2	7216	1148	2	2004-08-07
3	7216	6622	2	2004-08-07
4	7216	5951	3	2004-08-07
5	7216	3660	2	2004-08-07
6	7216	2621	3	2004-08-07
7	7216	4090	2	2004-08-07
8	7216	5595	1	2004-08-07
1	7217	9899	2	2004-08-20
2	7217	2327	2	2004-08-20
3	7217	5555	3	2004-08-20
1	7218	6319	2	2004-08-02
2	7218	4738	3	2004-08-02
3	7218	8129	1	2004-08-02
4	7218	1757	2	2004-08-02
1	7219	2683	2	2004-08-04
2	7219	8502	3	2004-08-04
3	7219	7266	2	2004-08-04
4	7219	9954	3	2004-08-04
1	7220	4181	3	2004-08-24
2	7220	8780	2	2004-08-24
3	7220	4952	2	2004-08-24
4	7220	8551	1	2004-08-24
5	7220	8686	1	2004-08-24
6	7220	8737	3	2004-08-24
7	7220	4647	1	2004-08-24
8	7220	893	2	2004-08-24
9	7220	5908	1	2004-08-24
1	7221	6868	1	2004-08-30
2	7221	2673	3	2004-08-30
3	7221	40	1	2004-08-30
4	7221	6673	1	2004-08-30
5	7221	188	1	2004-08-30
6	7221	9213	3	2004-08-30
7	7221	5410	2	2004-08-30
8	7221	3344	2	2004-08-30
1	7222	8843	1	2004-08-17
2	7222	4662	3	2004-08-17
3	7222	7631	1	2004-08-17
4	7222	585	3	2004-08-17
1	7223	7638	3	2004-08-29
2	7223	2848	3	2004-08-29
3	7223	7972	3	2004-08-29
4	7223	9526	3	2004-08-29
5	7223	373	3	2004-08-29
6	7223	7126	2	2004-08-29
1	7224	2498	3	2004-08-09
2	7224	2504	1	2004-08-09
3	7224	8880	3	2004-08-09
4	7224	1077	2	2004-08-09
5	7224	7735	1	2004-08-09
6	7224	3592	3	2004-08-09
7	7224	7140	3	2004-08-09
8	7224	2921	2	2004-08-09
1	7225	5288	1	2004-08-20
2	7225	2461	2	2004-08-20
3	7225	719	3	2004-08-20
4	7225	1442	2	2004-08-20
1	7226	8170	2	2004-08-01
2	7226	3894	3	2004-08-01
3	7226	1622	2	2004-08-01
1	7227	6250	2	2004-08-12
2	7227	5776	3	2004-08-12
3	7227	8548	1	2004-08-12
4	7227	4938	1	2004-08-12
5	7227	6406	1	2004-08-12
6	7227	2983	3	2004-08-12
7	7227	5886	2	2004-08-12
1	7228	8509	3	2004-08-27
2	7228	1060	3	2004-08-27
3	7228	3731	2	2004-08-27
4	7228	3727	2	2004-08-27
5	7228	9924	3	2004-08-27
6	7228	4708	2	2004-08-27
7	7228	4439	1	2004-08-27
8	7228	325	1	2004-08-27
1	7229	9876	3	2004-08-01
2	7229	5291	1	2004-08-01
3	7229	7590	1	2004-08-01
4	7229	6559	2	2004-08-01
5	7229	8502	2	2004-08-01
1	7230	3688	3	2004-08-15
2	7230	561	3	2004-08-15
3	7230	2235	1	2004-08-15
4	7230	4702	3	2004-08-15
5	7230	7038	3	2004-08-15
6	7230	7899	3	2004-08-15
1	7231	3092	2	2004-08-29
2	7231	397	3	2004-08-29
1	7232	4028	3	2004-08-28
2	7232	9406	3	2004-08-28
3	7232	5070	1	2004-08-28
4	7232	4183	3	2004-08-28
5	7232	9441	2	2004-08-28
1	7233	8617	1	2004-08-20
1	7234	4542	2	2004-08-01
2	7234	1039	3	2004-08-01
3	7234	1972	1	2004-08-01
4	7234	6014	1	2004-08-01
5	7234	9420	2	2004-08-01
6	7234	6467	2	2004-08-01
7	7234	3630	2	2004-08-01
8	7234	2023	3	2004-08-01
9	7234	8431	2	2004-08-01
1	7235	9546	2	2004-08-24
2	7235	4501	3	2004-08-24
3	7235	8438	2	2004-08-24
4	7235	4677	3	2004-08-24
1	7236	6851	2	2004-08-13
2	7236	6352	1	2004-08-13
3	7236	6838	2	2004-08-13
4	7236	8436	1	2004-08-13
5	7236	9219	1	2004-08-13
1	7237	7446	3	2004-08-29
2	7237	5477	3	2004-08-29
3	7237	1848	2	2004-08-29
4	7237	4567	2	2004-08-29
5	7237	3185	1	2004-08-29
6	7237	863	3	2004-08-29
7	7237	1069	2	2004-08-29
1	7238	893	2	2004-08-22
2	7238	6795	3	2004-08-22
3	7238	1784	2	2004-08-22
4	7238	1034	1	2004-08-22
1	7239	7816	3	2004-08-23
2	7239	6281	1	2004-08-23
3	7239	8081	3	2004-08-23
4	7239	8315	1	2004-08-23
5	7239	4478	1	2004-08-23
6	7239	5653	2	2004-08-23
7	7239	9360	3	2004-08-23
8	7239	82	2	2004-08-23
1	7240	5754	3	2004-08-06
2	7240	338	3	2004-08-06
3	7240	2395	1	2004-08-06
1	7241	7750	3	2004-08-27
1	7242	2159	1	2004-08-02
2	7242	1197	2	2004-08-02
3	7242	2502	3	2004-08-02
4	7242	1975	1	2004-08-02
5	7242	3570	1	2004-08-02
6	7242	8301	2	2004-08-02
7	7242	1798	3	2004-08-02
8	7242	7894	3	2004-08-02
1	7243	9602	2	2004-08-19
2	7243	7919	1	2004-08-19
3	7243	4406	2	2004-08-19
4	7243	577	2	2004-08-19
5	7243	9699	1	2004-08-19
6	7243	3423	1	2004-08-19
7	7243	4267	2	2004-08-19
8	7243	8492	3	2004-08-19
1	7244	2524	3	2004-08-05
2	7244	323	2	2004-08-05
3	7244	5600	3	2004-08-05
4	7244	1873	1	2004-08-05
5	7244	6446	3	2004-08-05
1	7245	7228	2	2004-08-30
2	7245	3248	3	2004-08-30
3	7245	9864	1	2004-08-30
4	7245	1068	1	2004-08-30
5	7245	4803	2	2004-08-30
6	7245	7906	1	2004-08-30
7	7245	2102	3	2004-08-30
1	7246	7661	2	2004-08-12
2	7246	606	1	2004-08-12
3	7246	2947	1	2004-08-12
4	7246	4693	3	2004-08-12
5	7246	9437	2	2004-08-12
6	7246	5440	1	2004-08-12
1	7247	471	2	2004-08-06
2	7247	8128	1	2004-08-06
3	7247	8163	1	2004-08-06
4	7247	6873	2	2004-08-06
5	7247	6224	3	2004-08-06
1	7248	6269	3	2004-08-17
2	7248	4582	3	2004-08-17
3	7248	624	3	2004-08-17
4	7248	9352	2	2004-08-17
5	7248	6921	3	2004-08-17
6	7248	9671	1	2004-08-17
7	7248	8810	1	2004-08-17
8	7248	5027	2	2004-08-17
9	7248	6786	2	2004-08-17
1	7249	7844	2	2004-08-27
2	7249	2927	2	2004-08-27
3	7249	2883	3	2004-08-27
4	7249	4052	1	2004-08-27
5	7249	8217	1	2004-08-27
6	7249	9951	1	2004-08-27
7	7249	7195	1	2004-08-27
1	7250	5334	2	2004-08-02
2	7250	9605	2	2004-08-02
3	7250	7167	2	2004-08-02
4	7250	7964	2	2004-08-02
5	7250	130	2	2004-08-02
6	7250	8866	3	2004-08-02
7	7250	3520	3	2004-08-02
1	7251	4813	2	2004-08-04
2	7251	6542	1	2004-08-04
3	7251	5149	2	2004-08-04
4	7251	5827	1	2004-08-04
1	7252	3397	2	2004-08-22
2	7252	8520	1	2004-08-22
3	7252	8364	2	2004-08-22
1	7253	2987	3	2004-08-24
2	7253	4928	2	2004-08-24
3	7253	5213	2	2004-08-24
4	7253	2952	2	2004-08-24
5	7253	9957	3	2004-08-24
6	7253	817	2	2004-08-24
7	7253	793	2	2004-08-24
1	7254	2771	3	2004-08-10
1	7255	9170	3	2004-08-10
2	7255	7222	3	2004-08-10
1	7256	5364	3	2004-08-19
2	7256	5598	1	2004-08-19
3	7256	5494	3	2004-08-19
4	7256	6565	2	2004-08-19
5	7256	6313	3	2004-08-19
6	7256	1949	3	2004-08-19
7	7256	3346	2	2004-08-19
8	7256	3724	1	2004-08-19
9	7256	4997	2	2004-08-19
1	7257	9548	1	2004-08-28
1	7258	3629	1	2004-08-01
2	7258	5239	3	2004-08-01
3	7258	2693	1	2004-08-01
4	7258	9569	3	2004-08-01
5	7258	9385	2	2004-08-01
6	7258	3637	2	2004-08-01
1	7259	524	2	2004-08-11
2	7259	8513	2	2004-08-11
3	7259	3021	3	2004-08-11
4	7259	3532	2	2004-08-11
5	7259	7622	1	2004-08-11
6	7259	7514	3	2004-08-11
7	7259	9848	2	2004-08-11
1	7260	2469	1	2004-08-12
2	7260	9884	1	2004-08-12
3	7260	226	3	2004-08-12
4	7260	8172	2	2004-08-12
5	7260	4965	1	2004-08-12
6	7260	9446	3	2004-08-12
7	7260	8547	3	2004-08-12
8	7260	4293	3	2004-08-12
9	7260	5489	3	2004-08-12
1	7261	2099	1	2004-08-14
2	7261	9704	1	2004-08-14
1	7262	2561	3	2004-08-21
2	7262	8042	1	2004-08-21
3	7262	9930	3	2004-08-21
4	7262	1712	3	2004-08-21
5	7262	2128	3	2004-08-21
6	7262	9789	1	2004-08-21
1	7263	5394	3	2004-08-14
2	7263	6049	3	2004-08-14
3	7263	6050	3	2004-08-14
4	7263	1853	3	2004-08-14
5	7263	9552	1	2004-08-14
6	7263	95	2	2004-08-14
7	7263	5069	2	2004-08-14
8	7263	2210	3	2004-08-14
1	7264	8518	1	2004-08-11
2	7264	1442	1	2004-08-11
3	7264	8461	1	2004-08-11
4	7264	2218	1	2004-08-11
1	7265	790	3	2004-08-30
2	7265	4771	3	2004-08-30
3	7265	6731	2	2004-08-30
4	7265	4987	2	2004-08-30
5	7265	8180	2	2004-08-30
1	7266	877	2	2004-08-08
2	7266	4949	1	2004-08-08
3	7266	7350	2	2004-08-08
4	7266	2733	3	2004-08-08
5	7266	4111	1	2004-08-08
1	7267	89	2	2004-08-01
2	7267	4545	1	2004-08-01
3	7267	3422	3	2004-08-01
4	7267	7717	1	2004-08-01
5	7267	5939	1	2004-08-01
6	7267	6434	2	2004-08-01
7	7267	7786	3	2004-08-01
8	7267	7366	3	2004-08-01
9	7267	3620	3	2004-08-01
1	7268	2035	1	2004-08-08
2	7268	8537	2	2004-08-08
3	7268	3116	3	2004-08-08
4	7268	2475	3	2004-08-08
5	7268	8144	1	2004-08-08
6	7268	2947	1	2004-08-08
7	7268	3441	2	2004-08-08
8	7268	2004	1	2004-08-08
9	7268	6521	3	2004-08-08
1	7269	1876	3	2004-08-12
2	7269	31	2	2004-08-12
1	7270	2170	2	2004-08-24
2	7270	8783	1	2004-08-24
3	7270	2245	1	2004-08-24
4	7270	9264	2	2004-08-24
5	7270	9110	3	2004-08-24
6	7270	7283	1	2004-08-24
7	7270	96	1	2004-08-24
1	7271	41	2	2004-08-27
2	7271	7899	1	2004-08-27
3	7271	7385	3	2004-08-27
4	7271	1529	3	2004-08-27
5	7271	5271	3	2004-08-27
1	7272	5434	2	2004-08-31
2	7272	2716	3	2004-08-31
1	7273	9386	3	2004-08-21
2	7273	7902	3	2004-08-21
3	7273	403	2	2004-08-21
4	7273	1580	1	2004-08-21
5	7273	1272	1	2004-08-21
6	7273	8021	3	2004-08-21
1	7274	2821	2	2004-08-12
2	7274	4448	1	2004-08-12
3	7274	3550	1	2004-08-12
4	7274	4670	3	2004-08-12
5	7274	5343	3	2004-08-12
1	7275	7925	3	2004-08-21
2	7275	8740	2	2004-08-21
3	7275	8231	3	2004-08-21
4	7275	2154	3	2004-08-21
5	7275	1424	2	2004-08-21
6	7275	1431	3	2004-08-21
7	7275	2595	2	2004-08-21
8	7275	4851	1	2004-08-21
9	7275	403	3	2004-08-21
1	7276	5354	2	2004-08-18
2	7276	8288	1	2004-08-18
3	7276	2386	2	2004-08-18
4	7276	2775	1	2004-08-18
5	7276	4010	1	2004-08-18
6	7276	498	1	2004-08-18
7	7276	6526	3	2004-08-18
8	7276	1892	3	2004-08-18
9	7276	8538	1	2004-08-18
1	7277	5120	3	2004-08-07
2	7277	6237	2	2004-08-07
3	7277	5282	1	2004-08-07
4	7277	372	2	2004-08-07
5	7277	1294	2	2004-08-07
1	7278	4532	3	2004-08-02
2	7278	4747	3	2004-08-02
3	7278	9895	2	2004-08-02
1	7279	5099	1	2004-08-05
2	7279	6499	3	2004-08-05
3	7279	2477	3	2004-08-05
1	7280	3118	1	2004-08-06
2	7280	126	2	2004-08-06
3	7280	7764	1	2004-08-06
4	7280	9215	3	2004-08-06
5	7280	1001	2	2004-08-06
6	7280	1374	2	2004-08-06
7	7280	4831	2	2004-08-06
8	7280	4074	2	2004-08-06
1	7281	8547	2	2004-08-05
2	7281	7846	2	2004-08-05
3	7281	3446	1	2004-08-05
4	7281	4304	2	2004-08-05
5	7281	7918	1	2004-08-05
1	7282	4526	1	2004-08-11
2	7282	5026	2	2004-08-11
3	7282	9463	2	2004-08-11
4	7282	9376	1	2004-08-11
1	7283	8931	3	2004-08-05
2	7283	996	1	2004-08-05
3	7283	3659	3	2004-08-05
4	7283	6320	1	2004-08-05
5	7283	4587	3	2004-08-05
6	7283	1826	3	2004-08-05
1	7284	779	2	2004-08-16
2	7284	2197	2	2004-08-16
3	7284	4473	3	2004-08-16
4	7284	9045	2	2004-08-16
5	7284	3249	3	2004-08-16
6	7284	4773	2	2004-08-16
7	7284	2626	1	2004-08-16
8	7284	439	1	2004-08-16
1	7285	976	3	2004-08-01
2	7285	5214	2	2004-08-01
3	7285	7717	3	2004-08-01
4	7285	4452	1	2004-08-01
1	7286	7900	2	2004-08-22
2	7286	2865	1	2004-08-22
3	7286	837	1	2004-08-22
4	7286	6309	2	2004-08-22
5	7286	329	1	2004-08-22
6	7286	8892	1	2004-08-22
7	7286	2811	3	2004-08-22
1	7287	6572	1	2004-08-14
2	7287	4096	1	2004-08-14
3	7287	7302	1	2004-08-14
4	7287	8824	1	2004-08-14
5	7287	4639	2	2004-08-14
6	7287	6267	2	2004-08-14
1	7288	6540	1	2004-08-10
2	7288	7941	1	2004-08-10
3	7288	4592	3	2004-08-10
4	7288	3930	2	2004-08-10
5	7288	1223	3	2004-08-10
6	7288	2815	2	2004-08-10
1	7289	5319	2	2004-08-30
2	7289	7958	1	2004-08-30
3	7289	7784	3	2004-08-30
4	7289	4374	1	2004-08-30
5	7289	2387	1	2004-08-30
6	7289	8480	2	2004-08-30
1	7290	8657	3	2004-08-15
2	7290	4196	1	2004-08-15
1	7291	4866	3	2004-08-25
2	7291	4750	2	2004-08-25
3	7291	3125	2	2004-08-25
4	7291	641	3	2004-08-25
5	7291	2599	3	2004-08-25
6	7291	1064	1	2004-08-25
7	7291	5381	2	2004-08-25
8	7291	2806	3	2004-08-25
9	7291	6077	1	2004-08-25
1	7292	2232	3	2004-08-11
2	7292	4429	2	2004-08-11
3	7292	1340	1	2004-08-11
4	7292	4553	3	2004-08-11
5	7292	1238	3	2004-08-11
1	7293	2614	2	2004-08-24
1	7294	5596	3	2004-08-29
1	7295	9686	3	2004-08-18
2	7295	2644	3	2004-08-18
1	7296	1302	3	2004-08-14
2	7296	1146	2	2004-08-14
3	7296	6622	1	2004-08-14
4	7296	5272	2	2004-08-14
5	7296	8371	3	2004-08-14
6	7296	4978	1	2004-08-14
7	7296	3683	2	2004-08-14
8	7296	6197	3	2004-08-14
9	7296	4406	1	2004-08-14
1	7297	1847	3	2004-08-17
2	7297	1174	2	2004-08-17
1	7298	4593	1	2004-08-28
2	7298	4759	2	2004-08-28
3	7298	6520	1	2004-08-28
4	7298	8121	1	2004-08-28
5	7298	5617	2	2004-08-28
6	7298	948	1	2004-08-28
1	7299	1437	3	2004-08-24
2	7299	5462	3	2004-08-24
3	7299	9248	2	2004-08-24
4	7299	8330	1	2004-08-24
1	7300	5172	2	2004-08-18
2	7300	737	3	2004-08-18
3	7300	5615	2	2004-08-18
4	7300	5502	1	2004-08-18
5	7300	6876	2	2004-08-18
1	7301	3087	3	2004-08-13
2	7301	9502	3	2004-08-13
3	7301	1259	1	2004-08-13
4	7301	7000	3	2004-08-13
5	7301	7685	2	2004-08-13
1	7302	5517	1	2004-08-08
2	7302	2433	1	2004-08-08
3	7302	7874	1	2004-08-08
4	7302	451	2	2004-08-08
5	7302	8665	2	2004-08-08
6	7302	5622	2	2004-08-08
7	7302	9575	3	2004-08-08
8	7302	8032	3	2004-08-08
1	7303	8958	3	2004-08-14
2	7303	4857	2	2004-08-14
3	7303	5254	1	2004-08-14
4	7303	2205	3	2004-08-14
1	7304	2471	3	2004-08-27
2	7304	4759	1	2004-08-27
3	7304	1134	2	2004-08-27
4	7304	3832	3	2004-08-27
1	7305	9000	2	2004-08-04
1	7306	7337	2	2004-08-02
2	7306	6231	1	2004-08-02
3	7306	9401	1	2004-08-02
4	7306	4734	1	2004-08-02
5	7306	9111	1	2004-08-02
6	7306	1151	2	2004-08-02
7	7306	7361	2	2004-08-02
1	7307	7329	3	2004-08-09
2	7307	3539	3	2004-08-09
3	7307	7251	3	2004-08-09
4	7307	9227	2	2004-08-09
1	7308	7348	3	2004-08-07
2	7308	174	2	2004-08-07
3	7308	9196	3	2004-08-07
4	7308	5063	2	2004-08-07
5	7308	1179	2	2004-08-07
6	7308	7219	1	2004-08-07
7	7308	8817	2	2004-08-07
1	7309	5164	2	2004-08-19
2	7309	7713	3	2004-08-19
3	7309	2517	2	2004-08-19
4	7309	7577	1	2004-08-19
5	7309	1213	3	2004-08-19
6	7309	1393	1	2004-08-19
7	7309	6550	3	2004-08-19
8	7309	7883	3	2004-08-19
9	7309	2320	3	2004-08-19
1	7310	1556	3	2004-08-20
2	7310	9805	1	2004-08-20
3	7310	2807	2	2004-08-20
4	7310	1795	3	2004-08-20
5	7310	5670	3	2004-08-20
6	7310	3530	2	2004-08-20
7	7310	5660	2	2004-08-20
1	7311	3057	3	2004-08-26
2	7311	436	3	2004-08-26
3	7311	7922	3	2004-08-26
4	7311	6329	1	2004-08-26
5	7311	5397	1	2004-08-26
6	7311	7623	2	2004-08-26
7	7311	101	3	2004-08-26
8	7311	4633	3	2004-08-26
9	7311	9551	3	2004-08-26
1	7312	8304	1	2004-08-18
2	7312	4711	2	2004-08-18
1	7313	2611	1	2004-08-21
2	7313	3488	1	2004-08-21
3	7313	9861	1	2004-08-21
4	7313	1365	2	2004-08-21
1	7314	3167	3	2004-08-06
2	7314	8451	3	2004-08-06
3	7314	8821	3	2004-08-06
4	7314	5237	2	2004-08-06
5	7314	9346	1	2004-08-06
6	7314	5810	3	2004-08-06
7	7314	2650	1	2004-08-06
8	7314	1611	3	2004-08-06
9	7314	3575	3	2004-08-06
1	7315	9232	3	2004-08-11
2	7315	8370	1	2004-08-11
3	7315	5114	1	2004-08-11
4	7315	7358	2	2004-08-11
5	7315	9290	1	2004-08-11
6	7315	2844	3	2004-08-11
7	7315	8323	1	2004-08-11
1	7316	5737	1	2004-08-18
2	7316	2734	3	2004-08-18
3	7316	2475	2	2004-08-18
4	7316	7555	2	2004-08-18
5	7316	3154	1	2004-08-18
1	7317	1143	2	2004-08-07
2	7317	2062	2	2004-08-07
1	7318	9944	1	2004-08-20
2	7318	3406	3	2004-08-20
3	7318	4692	3	2004-08-20
4	7318	1825	1	2004-08-20
5	7318	4232	3	2004-08-20
6	7318	2792	3	2004-08-20
1	7319	1315	2	2004-08-19
2	7319	4530	2	2004-08-19
3	7319	6682	1	2004-08-19
4	7319	5014	3	2004-08-19
1	7320	6495	2	2004-08-28
2	7320	919	2	2004-08-28
3	7320	7290	2	2004-08-28
4	7320	4704	1	2004-08-28
5	7320	3470	2	2004-08-28
1	7321	4667	1	2004-08-09
2	7321	877	2	2004-08-09
3	7321	3539	1	2004-08-09
4	7321	440	3	2004-08-09
5	7321	5740	3	2004-08-09
6	7321	588	1	2004-08-09
1	7322	4716	2	2004-08-16
2	7322	3288	2	2004-08-16
3	7322	763	1	2004-08-16
4	7322	9958	2	2004-08-16
5	7322	2559	2	2004-08-16
6	7322	1994	2	2004-08-16
7	7322	1130	2	2004-08-16
8	7322	988	2	2004-08-16
9	7322	6120	1	2004-08-16
1	7323	7727	3	2004-08-06
2	7323	9334	3	2004-08-06
1	7324	3304	1	2004-08-02
2	7324	2700	2	2004-08-02
3	7324	8128	2	2004-08-02
4	7324	7168	3	2004-08-02
5	7324	8928	3	2004-08-02
6	7324	1514	1	2004-08-02
7	7324	5104	1	2004-08-02
8	7324	7005	2	2004-08-02
1	7325	2783	1	2004-08-27
1	7326	8824	1	2004-08-08
2	7326	6035	2	2004-08-08
1	7327	5929	3	2004-08-03
2	7327	6885	1	2004-08-03
3	7327	5308	2	2004-08-03
4	7327	2823	3	2004-08-03
1	7328	4017	3	2004-08-21
2	7328	6863	1	2004-08-21
3	7328	8113	3	2004-08-21
4	7328	3979	1	2004-08-21
1	7329	8127	3	2004-08-01
2	7329	5579	3	2004-08-01
3	7329	7663	2	2004-08-01
4	7329	2274	2	2004-08-01
5	7329	1896	3	2004-08-01
6	7329	6688	3	2004-08-01
7	7329	4971	3	2004-08-01
8	7329	4025	1	2004-08-01
9	7329	7437	2	2004-08-01
1	7330	3424	3	2004-08-17
2	7330	1952	3	2004-08-17
3	7330	39	1	2004-08-17
1	7331	654	2	2004-08-10
2	7331	158	3	2004-08-10
1	7332	1589	3	2004-08-05
2	7332	436	2	2004-08-05
3	7332	8105	2	2004-08-05
1	7333	6994	3	2004-08-26
2	7333	6014	1	2004-08-26
3	7333	8843	3	2004-08-26
4	7333	7819	3	2004-08-26
1	7334	2308	1	2004-08-01
2	7334	7818	1	2004-08-01
1	7335	2386	2	2004-08-01
2	7335	682	1	2004-08-01
1	7336	4327	2	2004-08-10
2	7336	5015	1	2004-08-10
1	7337	8994	3	2004-08-15
2	7337	2294	3	2004-08-15
3	7337	556	2	2004-08-15
4	7337	221	1	2004-08-15
1	7338	7192	1	2004-08-17
2	7338	7635	3	2004-08-17
3	7338	6709	3	2004-08-17
4	7338	2399	3	2004-08-17
5	7338	7102	3	2004-08-17
1	7339	2749	3	2004-08-04
2	7339	7105	2	2004-08-04
3	7339	2891	2	2004-08-04
4	7339	4042	2	2004-08-04
5	7339	5164	2	2004-08-04
6	7339	8687	2	2004-08-04
1	7340	9601	1	2004-08-24
2	7340	3013	3	2004-08-24
3	7340	191	3	2004-08-24
1	7341	2270	1	2004-08-18
2	7341	4081	3	2004-08-18
3	7341	6612	3	2004-08-18
1	7342	9814	2	2004-08-21
2	7342	4731	2	2004-08-21
3	7342	9953	2	2004-08-21
4	7342	360	3	2004-08-21
5	7342	7472	2	2004-08-21
6	7342	202	3	2004-08-21
7	7342	4394	1	2004-08-21
8	7342	4308	2	2004-08-21
9	7342	2937	3	2004-08-21
1	7343	2947	2	2004-08-23
2	7343	6623	3	2004-08-23
3	7343	3418	1	2004-08-23
4	7343	3274	2	2004-08-23
5	7343	2827	1	2004-08-23
6	7343	87	3	2004-08-23
7	7343	8064	1	2004-08-23
8	7343	974	3	2004-08-23
9	7343	7452	3	2004-08-23
1	7344	867	3	2004-08-07
2	7344	1184	2	2004-08-07
3	7344	9682	3	2004-08-07
4	7344	6214	1	2004-08-07
5	7344	7801	3	2004-08-07
6	7344	8782	2	2004-08-07
1	7345	6931	1	2004-08-28
2	7345	5079	3	2004-08-28
1	7346	1567	2	2004-08-26
2	7346	7504	2	2004-08-26
3	7346	2158	1	2004-08-26
4	7346	370	1	2004-08-26
5	7346	2844	1	2004-08-26
6	7346	6828	1	2004-08-26
7	7346	9911	1	2004-08-26
8	7346	4717	3	2004-08-26
9	7346	2202	2	2004-08-26
1	7347	2912	1	2004-08-07
2	7347	365	3	2004-08-07
3	7347	9643	3	2004-08-07
4	7347	1134	3	2004-08-07
5	7347	7509	1	2004-08-07
6	7347	1203	2	2004-08-07
7	7347	6471	2	2004-08-07
8	7347	8032	3	2004-08-07
9	7347	6386	1	2004-08-07
1	7348	6254	3	2004-08-27
2	7348	6016	3	2004-08-27
3	7348	1616	3	2004-08-27
4	7348	9375	3	2004-08-27
5	7348	7987	1	2004-08-27
6	7348	9939	3	2004-08-27
7	7348	277	3	2004-08-27
8	7348	6802	1	2004-08-27
1	7349	9322	1	2004-08-20
2	7349	843	3	2004-08-20
3	7349	7421	3	2004-08-20
4	7349	8229	2	2004-08-20
5	7349	440	1	2004-08-20
6	7349	4118	3	2004-08-20
7	7349	9747	1	2004-08-20
1	7350	8675	2	2004-08-16
2	7350	6811	3	2004-08-16
3	7350	4621	3	2004-08-16
4	7350	8195	1	2004-08-16
5	7350	8497	2	2004-08-16
1	7351	3186	1	2004-08-18
2	7351	2406	1	2004-08-18
3	7351	24	1	2004-08-18
4	7351	6420	1	2004-08-18
5	7351	2263	1	2004-08-18
1	7352	3373	3	2004-08-23
2	7352	6831	1	2004-08-23
3	7352	5222	2	2004-08-23
1	7353	1265	3	2004-08-03
2	7353	3327	3	2004-08-03
3	7353	1831	2	2004-08-03
4	7353	2050	2	2004-08-03
5	7353	8078	2	2004-08-03
6	7353	5622	3	2004-08-03
7	7353	5089	1	2004-08-03
8	7353	8565	3	2004-08-03
1	7354	8029	1	2004-08-08
2	7354	2201	2	2004-08-08
3	7354	4780	3	2004-08-08
1	7355	4293	3	2004-08-27
2	7355	8454	3	2004-08-27
3	7355	5526	1	2004-08-27
4	7355	2900	3	2004-08-27
5	7355	5300	1	2004-08-27
6	7355	2031	1	2004-08-27
7	7355	9079	3	2004-08-27
8	7355	2963	3	2004-08-27
9	7355	4471	2	2004-08-27
1	7356	6566	1	2004-08-11
2	7356	6254	1	2004-08-11
1	7357	3983	1	2004-08-27
2	7357	4204	1	2004-08-27
3	7357	8695	3	2004-08-27
4	7357	2720	1	2004-08-27
5	7357	7305	3	2004-08-27
6	7357	2572	3	2004-08-27
1	7358	9293	1	2004-08-28
2	7358	7443	1	2004-08-28
1	7359	7219	1	2004-08-15
2	7359	2668	2	2004-08-15
1	7360	528	2	2004-08-16
2	7360	1477	3	2004-08-16
3	7360	5235	2	2004-08-16
4	7360	817	1	2004-08-16
5	7360	2215	2	2004-08-16
6	7360	1875	1	2004-08-16
7	7360	5038	3	2004-08-16
8	7360	3058	2	2004-08-16
9	7360	9253	1	2004-08-16
1	7361	5332	2	2004-08-22
1	7362	7451	1	2004-08-05
2	7362	5444	3	2004-08-05
3	7362	6386	3	2004-08-05
4	7362	7200	1	2004-08-05
5	7362	1117	3	2004-08-05
6	7362	4161	1	2004-08-05
1	7363	4363	3	2004-08-05
2	7363	772	2	2004-08-05
3	7363	8043	3	2004-08-05
4	7363	7626	2	2004-08-05
5	7363	8798	1	2004-08-05
6	7363	8723	1	2004-08-05
1	7364	9181	1	2004-08-03
2	7364	6385	2	2004-08-03
3	7364	8908	2	2004-08-03
4	7364	7188	1	2004-08-03
5	7364	1600	1	2004-08-03
6	7364	3355	1	2004-08-03
7	7364	7383	3	2004-08-03
8	7364	9445	1	2004-08-03
1	7365	7975	1	2004-08-17
2	7365	8201	3	2004-08-17
3	7365	5944	3	2004-08-17
4	7365	6914	3	2004-08-17
1	7366	5446	1	2004-08-17
2	7366	9970	2	2004-08-17
3	7366	5275	3	2004-08-17
4	7366	4377	3	2004-08-17
1	7367	5572	3	2004-08-27
2	7367	7632	1	2004-08-27
3	7367	9537	1	2004-08-27
4	7367	4382	3	2004-08-27
5	7367	5978	1	2004-08-27
6	7367	4283	1	2004-08-27
1	7368	4655	2	2004-08-30
2	7368	9132	1	2004-08-30
3	7368	5819	3	2004-08-30
4	7368	4453	1	2004-08-30
5	7368	6259	3	2004-08-30
1	7369	650	1	2004-08-25
2	7369	7164	3	2004-08-25
3	7369	3088	3	2004-08-25
4	7369	1274	3	2004-08-25
5	7369	4210	3	2004-08-25
6	7369	51	3	2004-08-25
7	7369	9173	3	2004-08-25
8	7369	9689	3	2004-08-25
1	7370	4443	3	2004-08-14
2	7370	2515	3	2004-08-14
3	7370	9033	3	2004-08-14
4	7370	7724	3	2004-08-14
1	7371	6417	1	2004-08-11
2	7371	2467	3	2004-08-11
3	7371	8705	2	2004-08-11
4	7371	6973	1	2004-08-11
1	7372	6580	1	2004-08-04
1	7373	4277	3	2004-08-26
1	7374	5565	2	2004-08-26
2	7374	4249	3	2004-08-26
3	7374	783	3	2004-08-26
4	7374	3286	3	2004-08-26
5	7374	1095	2	2004-08-26
6	7374	6703	3	2004-08-26
7	7374	9493	2	2004-08-26
1	7375	648	3	2004-08-09
2	7375	5212	3	2004-08-09
3	7375	8141	1	2004-08-09
4	7375	9083	1	2004-08-09
1	7376	4550	2	2004-08-02
2	7376	5800	3	2004-08-02
3	7376	3873	2	2004-08-02
4	7376	7888	3	2004-08-02
5	7376	3780	3	2004-08-02
6	7376	2912	1	2004-08-02
7	7376	8780	1	2004-08-02
8	7376	4158	1	2004-08-02
9	7376	2889	2	2004-08-02
1	7377	2341	1	2004-08-18
1	7378	8723	1	2004-08-05
2	7378	1299	1	2004-08-05
1	7379	3680	3	2004-08-21
1	7380	7942	3	2004-08-24
1	7381	6957	2	2004-08-10
2	7381	9445	3	2004-08-10
3	7381	5642	1	2004-08-10
4	7381	9369	3	2004-08-10
5	7381	3207	1	2004-08-10
6	7381	9109	1	2004-08-10
1	7382	7505	3	2004-08-13
1	7383	8643	2	2004-08-04
2	7383	9509	2	2004-08-04
3	7383	3893	1	2004-08-04
4	7383	8684	1	2004-08-04
5	7383	8438	2	2004-08-04
6	7383	7926	3	2004-08-04
7	7383	4733	2	2004-08-04
8	7383	9666	2	2004-08-04
9	7383	679	1	2004-08-04
1	7384	193	1	2004-08-20
1	7385	8881	2	2004-08-03
2	7385	846	3	2004-08-03
1	7386	2883	1	2004-08-03
2	7386	7682	1	2004-08-03
3	7386	8431	2	2004-08-03
4	7386	9201	1	2004-08-03
5	7386	9174	3	2004-08-03
1	7387	9639	2	2004-08-23
2	7387	3557	3	2004-08-23
3	7387	6547	2	2004-08-23
4	7387	7529	2	2004-08-23
1	7388	3934	3	2004-08-20
2	7388	7479	3	2004-08-20
3	7388	3598	1	2004-08-20
4	7388	832	1	2004-08-20
5	7388	1681	3	2004-08-20
6	7388	6886	1	2004-08-20
7	7388	2426	2	2004-08-20
1	7389	3117	2	2004-08-31
2	7389	8029	3	2004-08-31
1	7390	8400	3	2004-08-17
2	7390	9321	3	2004-08-17
3	7390	4401	1	2004-08-17
1	7391	2240	1	2004-08-18
2	7391	633	2	2004-08-18
3	7391	1389	3	2004-08-18
4	7391	4801	2	2004-08-18
5	7391	3578	2	2004-08-18
6	7391	3503	3	2004-08-18
7	7391	6036	2	2004-08-18
8	7391	5040	2	2004-08-18
9	7391	3293	1	2004-08-18
1	7392	1566	1	2004-08-27
2	7392	3775	2	2004-08-27
3	7392	5906	3	2004-08-27
4	7392	7845	3	2004-08-27
5	7392	8886	1	2004-08-27
6	7392	9326	3	2004-08-27
7	7392	4004	1	2004-08-27
1	7393	3353	3	2004-08-22
1	7394	3452	3	2004-08-01
2	7394	5562	1	2004-08-01
3	7394	2231	3	2004-08-01
4	7394	9129	2	2004-08-01
5	7394	1545	1	2004-08-01
1	7395	4649	1	2004-08-31
2	7395	7691	2	2004-08-31
3	7395	838	1	2004-08-31
4	7395	4688	3	2004-08-31
5	7395	499	3	2004-08-31
6	7395	8487	2	2004-08-31
7	7395	7245	3	2004-08-31
1	7396	9834	3	2004-08-11
2	7396	8782	1	2004-08-11
3	7396	8186	3	2004-08-11
4	7396	5862	3	2004-08-11
5	7396	813	2	2004-08-11
6	7396	7180	1	2004-08-11
7	7396	3231	1	2004-08-11
1	7397	2616	1	2004-08-15
2	7397	3277	1	2004-08-15
3	7397	9706	1	2004-08-15
4	7397	6967	3	2004-08-15
5	7397	353	1	2004-08-15
1	7398	3375	2	2004-08-28
2	7398	741	1	2004-08-28
3	7398	3591	2	2004-08-28
4	7398	1291	2	2004-08-28
5	7398	2225	3	2004-08-28
6	7398	7650	2	2004-08-28
7	7398	300	1	2004-08-28
8	7398	6378	2	2004-08-28
1	7399	2108	2	2004-08-24
1	7400	9280	1	2004-08-09
2	7400	7092	2	2004-08-09
3	7400	765	1	2004-08-09
1	7401	8107	1	2004-08-06
2	7401	9851	1	2004-08-06
3	7401	1787	3	2004-08-06
4	7401	5787	1	2004-08-06
5	7401	9715	1	2004-08-06
1	7402	8228	1	2004-08-26
2	7402	1079	1	2004-08-26
3	7402	2339	2	2004-08-26
4	7402	3894	1	2004-08-26
5	7402	6414	1	2004-08-26
1	7403	8683	2	2004-08-25
2	7403	5102	3	2004-08-25
3	7403	6796	2	2004-08-25
4	7403	7121	3	2004-08-25
5	7403	2452	1	2004-08-25
6	7403	668	1	2004-08-25
7	7403	5071	3	2004-08-25
8	7403	9499	2	2004-08-25
9	7403	3637	3	2004-08-25
1	7404	9040	1	2004-08-30
2	7404	3449	2	2004-08-30
1	7405	899	1	2004-08-11
2	7405	8420	2	2004-08-11
3	7405	8102	2	2004-08-11
4	7405	951	2	2004-08-11
5	7405	3797	2	2004-08-11
1	7406	3321	2	2004-08-26
2	7406	9428	3	2004-08-26
3	7406	2793	3	2004-08-26
1	7407	3907	2	2004-08-06
1	7408	2338	2	2004-08-20
2	7408	106	1	2004-08-20
3	7408	2342	3	2004-08-20
4	7408	5972	1	2004-08-20
5	7408	3430	3	2004-08-20
6	7408	6695	1	2004-08-20
7	7408	4234	1	2004-08-20
8	7408	4758	3	2004-08-20
1	7409	3105	2	2004-08-23
1	7410	8056	1	2004-08-05
2	7410	2827	2	2004-08-05
3	7410	1850	2	2004-08-05
4	7410	9843	1	2004-08-05
5	7410	5921	1	2004-08-05
1	7411	1662	1	2004-08-01
2	7411	5151	2	2004-08-01
3	7411	4435	3	2004-08-01
4	7411	3449	1	2004-08-01
1	7412	4143	2	2004-08-13
2	7412	1053	1	2004-08-13
3	7412	8842	3	2004-08-13
4	7412	4092	1	2004-08-13
5	7412	2609	2	2004-08-13
6	7412	6832	1	2004-08-13
7	7412	7897	1	2004-08-13
1	7413	1652	2	2004-08-15
1	7414	6709	2	2004-08-08
2	7414	8480	1	2004-08-08
3	7414	3610	1	2004-08-08
4	7414	7998	3	2004-08-08
5	7414	3776	3	2004-08-08
6	7414	8788	1	2004-08-08
7	7414	8159	1	2004-08-08
1	7415	3218	3	2004-08-14
2	7415	3870	3	2004-08-14
1	7416	4822	1	2004-08-15
2	7416	3228	3	2004-08-15
3	7416	6960	3	2004-08-15
4	7416	2673	2	2004-08-15
5	7416	737	2	2004-08-15
6	7416	5805	3	2004-08-15
1	7417	2199	2	2004-08-13
2	7417	5701	2	2004-08-13
3	7417	6711	2	2004-08-13
1	7418	7780	2	2004-08-24
2	7418	9987	2	2004-08-24
1	7419	1831	1	2004-08-08
2	7419	5599	2	2004-08-08
3	7419	8386	2	2004-08-08
4	7419	786	2	2004-08-08
5	7419	5070	2	2004-08-08
6	7419	3772	1	2004-08-08
1	7420	2454	2	2004-08-24
2	7420	7862	1	2004-08-24
3	7420	5438	3	2004-08-24
4	7420	1526	1	2004-08-24
1	7421	6320	2	2004-08-16
2	7421	3205	3	2004-08-16
3	7421	7892	3	2004-08-16
4	7421	2654	2	2004-08-16
5	7421	5138	2	2004-08-16
6	7421	468	1	2004-08-16
7	7421	8260	2	2004-08-16
1	7422	9244	1	2004-08-10
2	7422	7369	3	2004-08-10
1	7423	6024	1	2004-08-09
2	7423	5753	2	2004-08-09
3	7423	8851	1	2004-08-09
4	7423	9930	1	2004-08-09
1	7424	4099	2	2004-08-01
2	7424	6315	2	2004-08-01
3	7424	6203	2	2004-08-01
1	7425	1124	3	2004-08-28
2	7425	1675	3	2004-08-28
3	7425	6825	2	2004-08-28
4	7425	1299	1	2004-08-28
5	7425	8632	3	2004-08-28
6	7425	4336	2	2004-08-28
7	7425	2306	1	2004-08-28
8	7425	6456	1	2004-08-28
9	7425	5242	3	2004-08-28
1	7426	2095	2	2004-08-01
2	7426	8720	3	2004-08-01
3	7426	441	3	2004-08-01
4	7426	7561	1	2004-08-01
1	7427	7176	3	2004-08-21
2	7427	2602	3	2004-08-21
3	7427	488	1	2004-08-21
4	7427	5797	2	2004-08-21
5	7427	5617	3	2004-08-21
6	7427	8009	1	2004-08-21
7	7427	337	1	2004-08-21
8	7427	8749	1	2004-08-21
1	7428	4168	1	2004-08-29
2	7428	9743	2	2004-08-29
1	7429	5988	2	2004-08-03
2	7429	5539	1	2004-08-03
3	7429	3622	3	2004-08-03
4	7429	1638	2	2004-08-03
5	7429	9374	3	2004-08-03
6	7429	8932	2	2004-08-03
7	7429	5536	3	2004-08-03
1	7430	6264	3	2004-08-22
2	7430	4113	1	2004-08-22
3	7430	985	3	2004-08-22
4	7430	4076	1	2004-08-22
5	7430	2888	2	2004-08-22
6	7430	8031	3	2004-08-22
1	7431	7181	3	2004-08-07
2	7431	5873	3	2004-08-07
3	7431	2303	2	2004-08-07
4	7431	6251	1	2004-08-07
5	7431	238	1	2004-08-07
6	7431	8175	3	2004-08-07
7	7431	7658	3	2004-08-07
1	7432	4732	3	2004-08-10
2	7432	5505	3	2004-08-10
3	7432	9618	3	2004-08-10
4	7432	3674	3	2004-08-10
5	7432	6805	2	2004-08-10
6	7432	1665	1	2004-08-10
7	7432	3600	3	2004-08-10
1	7433	4719	2	2004-08-30
2	7433	3109	2	2004-08-30
1	7434	9649	2	2004-08-18
2	7434	7279	3	2004-08-18
3	7434	2594	1	2004-08-18
4	7434	6444	3	2004-08-18
1	7435	3709	1	2004-08-03
2	7435	360	2	2004-08-03
3	7435	4674	2	2004-08-03
4	7435	4218	2	2004-08-03
5	7435	3431	1	2004-08-03
1	7436	3106	1	2004-08-19
2	7436	511	2	2004-08-19
3	7436	4850	1	2004-08-19
4	7436	732	1	2004-08-19
5	7436	7713	1	2004-08-19
6	7436	4139	2	2004-08-19
7	7436	1424	2	2004-08-19
8	7436	218	3	2004-08-19
9	7436	9450	2	2004-08-19
1	7437	3768	2	2004-08-04
2	7437	128	3	2004-08-04
3	7437	5398	2	2004-08-04
4	7437	5347	1	2004-08-04
5	7437	5474	3	2004-08-04
6	7437	2684	2	2004-08-04
1	7438	9661	2	2004-08-12
2	7438	7870	2	2004-08-12
3	7438	8012	3	2004-08-12
4	7438	8756	3	2004-08-12
5	7438	7208	3	2004-08-12
1	7439	4301	1	2004-08-07
2	7439	4973	2	2004-08-07
1	7440	1562	2	2004-08-28
2	7440	2778	2	2004-08-28
3	7440	2133	2	2004-08-28
4	7440	1777	3	2004-08-28
1	7441	5236	1	2004-08-04
2	7441	8301	2	2004-08-04
3	7441	8373	2	2004-08-04
4	7441	2198	1	2004-08-04
5	7441	3926	1	2004-08-04
6	7441	1984	3	2004-08-04
7	7441	1993	3	2004-08-04
8	7441	2654	1	2004-08-04
9	7441	7327	1	2004-08-04
1	7442	3133	1	2004-08-17
2	7442	4667	2	2004-08-17
3	7442	9885	2	2004-08-17
4	7442	6347	1	2004-08-17
5	7442	4810	1	2004-08-17
6	7442	2160	1	2004-08-17
7	7442	5574	1	2004-08-17
8	7442	8618	3	2004-08-17
1	7443	770	3	2004-08-04
2	7443	10000	2	2004-08-04
3	7443	947	3	2004-08-04
1	7444	4319	3	2004-08-21
2	7444	7837	3	2004-08-21
3	7444	4256	3	2004-08-21
4	7444	4788	1	2004-08-21
5	7444	9738	3	2004-08-21
6	7444	2184	1	2004-08-21
1	7445	5529	2	2004-08-09
2	7445	3867	2	2004-08-09
1	7446	8059	2	2004-08-21
2	7446	3859	2	2004-08-21
3	7446	676	1	2004-08-21
4	7446	1038	2	2004-08-21
5	7446	9420	3	2004-08-21
6	7446	3978	2	2004-08-21
1	7447	8362	2	2004-08-21
2	7447	8231	1	2004-08-21
3	7447	4218	1	2004-08-21
4	7447	2393	3	2004-08-21
5	7447	4147	2	2004-08-21
6	7447	3257	1	2004-08-21
1	7448	1175	1	2004-08-03
2	7448	3765	1	2004-08-03
3	7448	1141	2	2004-08-03
4	7448	6843	1	2004-08-03
5	7448	3677	1	2004-08-03
6	7448	4235	1	2004-08-03
7	7448	9586	3	2004-08-03
8	7448	6607	3	2004-08-03
9	7448	4972	2	2004-08-03
1	7449	8935	3	2004-08-28
2	7449	7668	1	2004-08-28
1	7450	7517	1	2004-08-01
2	7450	8598	1	2004-08-01
3	7450	1958	3	2004-08-01
4	7450	6083	3	2004-08-01
5	7450	299	3	2004-08-01
6	7450	9621	2	2004-08-01
7	7450	33	3	2004-08-01
1	7451	1477	2	2004-08-10
2	7451	7205	3	2004-08-10
3	7451	7579	2	2004-08-10
4	7451	6614	2	2004-08-10
5	7451	8330	3	2004-08-10
6	7451	3808	3	2004-08-10
7	7451	4464	1	2004-08-10
8	7451	7372	1	2004-08-10
1	7452	8129	1	2004-08-09
2	7452	8447	3	2004-08-09
3	7452	7632	3	2004-08-09
4	7452	6956	1	2004-08-09
5	7452	5118	2	2004-08-09
6	7452	8691	2	2004-08-09
7	7452	280	2	2004-08-09
8	7452	3566	3	2004-08-09
1	7453	7114	3	2004-08-07
1	7454	4639	1	2004-08-24
2	7454	4327	3	2004-08-24
3	7454	9526	1	2004-08-24
4	7454	537	3	2004-08-24
5	7454	205	3	2004-08-24
1	7455	1269	3	2004-08-20
2	7455	8162	1	2004-08-20
1	7456	1907	1	2004-08-11
2	7456	5825	3	2004-08-11
3	7456	9419	2	2004-08-11
4	7456	597	3	2004-08-11
5	7456	8449	2	2004-08-11
1	7457	5231	1	2004-08-27
2	7457	5989	2	2004-08-27
3	7457	1377	1	2004-08-27
4	7457	2595	1	2004-08-27
5	7457	4007	2	2004-08-27
6	7457	7753	1	2004-08-27
7	7457	5412	1	2004-08-27
8	7457	3895	2	2004-08-27
1	7458	4820	3	2004-08-21
2	7458	5917	2	2004-08-21
3	7458	4395	2	2004-08-21
1	7459	904	1	2004-08-03
2	7459	6533	3	2004-08-03
3	7459	7806	3	2004-08-03
1	7460	4264	2	2004-08-29
2	7460	5505	3	2004-08-29
3	7460	7061	3	2004-08-29
4	7460	4491	2	2004-08-29
1	7461	8557	1	2004-08-17
1	7462	5838	2	2004-08-17
2	7462	9409	3	2004-08-17
3	7462	5962	2	2004-08-17
4	7462	3633	2	2004-08-17
5	7462	3850	1	2004-08-17
6	7462	4168	1	2004-08-17
1	7463	8106	2	2004-08-20
2	7463	1203	1	2004-08-20
1	7464	6420	1	2004-08-27
2	7464	6873	1	2004-08-27
3	7464	5919	1	2004-08-27
4	7464	7940	1	2004-08-27
5	7464	6912	3	2004-08-27
1	7465	6642	3	2004-08-27
2	7465	5092	1	2004-08-27
1	7466	3196	3	2004-08-29
2	7466	1894	2	2004-08-29
3	7466	9942	1	2004-08-29
4	7466	800	2	2004-08-29
5	7466	5302	3	2004-08-29
6	7466	7320	1	2004-08-29
7	7466	9074	1	2004-08-29
1	7467	4361	2	2004-08-18
2	7467	5281	3	2004-08-18
3	7467	5619	1	2004-08-18
1	7468	2102	1	2004-08-15
2	7468	880	2	2004-08-15
3	7468	9317	1	2004-08-15
4	7468	9696	3	2004-08-15
1	7469	7714	1	2004-08-11
2	7469	761	3	2004-08-11
3	7469	4168	2	2004-08-11
4	7469	3801	3	2004-08-11
5	7469	8663	3	2004-08-11
6	7469	2651	2	2004-08-11
7	7469	5812	3	2004-08-11
8	7469	5865	1	2004-08-11
1	7470	567	2	2004-08-28
1	7471	9142	1	2004-08-20
2	7471	6568	1	2004-08-20
3	7471	29	2	2004-08-20
4	7471	3682	1	2004-08-20
5	7471	1070	3	2004-08-20
6	7471	7045	2	2004-08-20
1	7472	9650	3	2004-08-22
2	7472	7929	2	2004-08-22
3	7472	9442	3	2004-08-22
4	7472	4110	2	2004-08-22
5	7472	7990	2	2004-08-22
6	7472	9330	2	2004-08-22
7	7472	4560	3	2004-08-22
8	7472	442	2	2004-08-22
9	7472	8926	3	2004-08-22
1	7473	9743	1	2004-08-21
1	7474	2494	1	2004-08-25
2	7474	4653	1	2004-08-25
3	7474	9104	1	2004-08-25
4	7474	7657	3	2004-08-25
5	7474	9490	1	2004-08-25
1	7475	1848	1	2004-08-08
2	7475	9306	1	2004-08-08
1	7476	7186	1	2004-08-15
2	7476	1291	3	2004-08-15
1	7477	4267	2	2004-08-10
1	7478	1501	2	2004-08-02
2	7478	8090	1	2004-08-02
3	7478	7774	1	2004-08-02
4	7478	8469	2	2004-08-02
5	7478	2402	1	2004-08-02
6	7478	5217	1	2004-08-02
7	7478	2605	3	2004-08-02
8	7478	9939	1	2004-08-02
9	7478	1075	3	2004-08-02
1	7479	1638	3	2004-08-08
2	7479	5623	2	2004-08-08
3	7479	3976	2	2004-08-08
4	7479	4823	1	2004-08-08
5	7479	5609	2	2004-08-08
1	7480	4279	2	2004-08-26
2	7480	324	3	2004-08-26
3	7480	6098	2	2004-08-26
4	7480	8389	3	2004-08-26
5	7480	5460	3	2004-08-26
6	7480	606	2	2004-08-26
1	7481	8541	1	2004-08-17
2	7481	7272	2	2004-08-17
3	7481	6441	1	2004-08-17
4	7481	228	1	2004-08-17
5	7481	3573	2	2004-08-17
6	7481	7587	1	2004-08-17
7	7481	9534	2	2004-08-17
8	7481	8015	2	2004-08-17
9	7481	681	3	2004-08-17
1	7482	5480	3	2004-08-02
2	7482	7210	2	2004-08-02
3	7482	5870	1	2004-08-02
4	7482	9183	2	2004-08-02
5	7482	2165	3	2004-08-02
6	7482	5304	3	2004-08-02
7	7482	1887	1	2004-08-02
8	7482	683	1	2004-08-02
1	7483	6162	3	2004-08-10
1	7484	2513	1	2004-08-18
2	7484	2950	2	2004-08-18
3	7484	673	3	2004-08-18
4	7484	5727	3	2004-08-18
5	7484	4514	1	2004-08-18
6	7484	543	2	2004-08-18
1	7485	2143	1	2004-08-20
2	7485	3413	1	2004-08-20
1	7486	7013	1	2004-08-17
2	7486	854	1	2004-08-17
3	7486	7418	1	2004-08-17
4	7486	8678	3	2004-08-17
1	7487	57	1	2004-08-13
2	7487	2495	2	2004-08-13
3	7487	3644	1	2004-08-13
4	7487	8265	1	2004-08-13
5	7487	5744	3	2004-08-13
1	7488	711	3	2004-08-06
2	7488	1507	3	2004-08-06
3	7488	1777	3	2004-08-06
4	7488	1033	1	2004-08-06
5	7488	1025	3	2004-08-06
1	7489	1330	2	2004-08-15
2	7489	3335	1	2004-08-15
3	7489	6747	2	2004-08-15
4	7489	5955	1	2004-08-15
5	7489	8867	2	2004-08-15
6	7489	398	2	2004-08-15
7	7489	3902	1	2004-08-15
8	7489	2497	3	2004-08-15
1	7490	998	3	2004-08-23
2	7490	7185	1	2004-08-23
3	7490	9703	3	2004-08-23
4	7490	480	2	2004-08-23
5	7490	7911	3	2004-08-23
6	7490	3205	3	2004-08-23
7	7490	3560	2	2004-08-23
8	7490	626	1	2004-08-23
1	7491	800	1	2004-08-08
2	7491	5844	2	2004-08-08
1	7492	1548	3	2004-08-10
1	7493	4576	2	2004-08-28
2	7493	4384	2	2004-08-28
3	7493	8144	1	2004-08-28
4	7493	3914	1	2004-08-28
5	7493	1535	3	2004-08-28
6	7493	7887	1	2004-08-28
1	7494	1489	3	2004-08-25
2	7494	9570	3	2004-08-25
3	7494	4241	1	2004-08-25
4	7494	5672	2	2004-08-25
5	7494	3060	3	2004-08-25
6	7494	2718	1	2004-08-25
7	7494	9764	3	2004-08-25
8	7494	8225	2	2004-08-25
1	7495	4903	1	2004-08-02
2	7495	9829	2	2004-08-02
3	7495	781	3	2004-08-02
4	7495	8598	3	2004-08-02
5	7495	7970	3	2004-08-02
6	7495	7037	3	2004-08-02
7	7495	6878	2	2004-08-02
8	7495	6790	1	2004-08-02
1	7496	9680	3	2004-08-29
2	7496	4449	3	2004-08-29
3	7496	6343	1	2004-08-29
1	7497	5160	1	2004-08-12
2	7497	6482	2	2004-08-12
3	7497	6621	3	2004-08-12
1	7498	2556	1	2004-08-09
1	7499	551	3	2004-08-01
2	7499	9381	3	2004-08-01
3	7499	1205	3	2004-08-01
4	7499	7167	2	2004-08-01
5	7499	8503	2	2004-08-01
6	7499	8326	1	2004-08-01
7	7499	188	2	2004-08-01
1	7500	336	1	2004-08-17
2	7500	9203	1	2004-08-17
1	7501	7884	2	2004-08-18
2	7501	7616	3	2004-08-18
3	7501	763	3	2004-08-18
4	7501	6154	1	2004-08-18
5	7501	5666	3	2004-08-18
6	7501	9203	1	2004-08-18
7	7501	3012	3	2004-08-18
8	7501	6340	1	2004-08-18
1	7502	1875	3	2004-08-31
2	7502	7388	1	2004-08-31
3	7502	9144	2	2004-08-31
4	7502	5251	2	2004-08-31
5	7502	1615	3	2004-08-31
1	7503	6847	2	2004-08-10
1	7504	358	1	2004-08-28
2	7504	7232	2	2004-08-28
3	7504	621	2	2004-08-28
4	7504	4706	1	2004-08-28
1	7505	8383	2	2004-08-01
2	7505	4184	3	2004-08-01
1	7506	8398	2	2004-08-01
2	7506	1145	1	2004-08-01
1	7507	991	3	2004-08-19
2	7507	8953	1	2004-08-19
3	7507	1401	2	2004-08-19
4	7507	4718	1	2004-08-19
5	7507	9755	3	2004-08-19
1	7508	1827	3	2004-08-09
2	7508	2130	2	2004-08-09
3	7508	4982	1	2004-08-09
4	7508	5445	3	2004-08-09
5	7508	3809	2	2004-08-09
6	7508	2529	2	2004-08-09
7	7508	5045	3	2004-08-09
8	7508	2944	3	2004-08-09
1	7509	5284	3	2004-08-09
2	7509	8037	1	2004-08-09
1	7510	7644	3	2004-08-06
2	7510	3039	3	2004-08-06
3	7510	5954	2	2004-08-06
4	7510	5480	1	2004-08-06
1	7511	4766	1	2004-08-23
2	7511	6091	3	2004-08-23
1	7512	2970	3	2004-08-29
2	7512	3843	3	2004-08-29
1	7513	9670	3	2004-08-24
2	7513	3710	3	2004-08-24
3	7513	6177	3	2004-08-24
4	7513	6783	1	2004-08-24
5	7513	1917	1	2004-08-24
6	7513	3064	3	2004-08-24
7	7513	3187	1	2004-08-24
8	7513	384	3	2004-08-24
9	7513	2019	2	2004-08-24
1	7514	3098	3	2004-08-25
2	7514	5321	3	2004-08-25
3	7514	6731	1	2004-08-25
4	7514	8820	2	2004-08-25
5	7514	2312	3	2004-08-25
6	7514	2664	2	2004-08-25
7	7514	5802	3	2004-08-25
1	7515	4847	2	2004-08-09
2	7515	3932	3	2004-08-09
3	7515	5309	2	2004-08-09
4	7515	5985	3	2004-08-09
5	7515	789	2	2004-08-09
1	7516	4775	2	2004-08-27
2	7516	8475	1	2004-08-27
1	7517	5782	3	2004-08-30
2	7517	7746	1	2004-08-30
1	7518	5201	3	2004-08-25
2	7518	2993	3	2004-08-25
3	7518	7047	3	2004-08-25
4	7518	3448	1	2004-08-25
5	7518	5629	2	2004-08-25
6	7518	6779	2	2004-08-25
7	7518	534	3	2004-08-25
8	7518	5599	2	2004-08-25
9	7518	4373	2	2004-08-25
1	7519	5510	3	2004-08-22
2	7519	2458	1	2004-08-22
3	7519	8731	1	2004-08-22
1	7520	1911	1	2004-08-12
2	7520	8102	3	2004-08-12
3	7520	703	1	2004-08-12
4	7520	1989	2	2004-08-12
5	7520	5785	3	2004-08-12
6	7520	396	2	2004-08-12
7	7520	6682	2	2004-08-12
8	7520	1627	1	2004-08-12
9	7520	67	3	2004-08-12
1	7521	8579	2	2004-08-16
1	7522	206	2	2004-08-12
2	7522	6342	1	2004-08-12
3	7522	6463	2	2004-08-12
4	7522	1075	3	2004-08-12
5	7522	5992	1	2004-08-12
6	7522	3498	1	2004-08-12
7	7522	1830	2	2004-08-12
1	7523	9566	3	2004-08-26
2	7523	8163	2	2004-08-26
3	7523	1385	3	2004-08-26
4	7523	4756	3	2004-08-26
5	7523	4110	3	2004-08-26
6	7523	7272	3	2004-08-26
7	7523	5731	3	2004-08-26
8	7523	2821	1	2004-08-26
9	7523	9595	3	2004-08-26
1	7524	3732	3	2004-08-21
2	7524	4284	2	2004-08-21
3	7524	3839	1	2004-08-21
1	7525	3679	1	2004-08-13
2	7525	8044	2	2004-08-13
3	7525	171	1	2004-08-13
4	7525	5026	2	2004-08-13
1	7526	9775	2	2004-08-04
2	7526	8960	3	2004-08-04
3	7526	5144	2	2004-08-04
4	7526	37	1	2004-08-04
5	7526	7983	2	2004-08-04
6	7526	1540	1	2004-08-04
7	7526	9329	2	2004-08-04
1	7527	7039	1	2004-08-15
2	7527	7009	2	2004-08-15
3	7527	7845	3	2004-08-15
4	7527	7881	1	2004-08-15
5	7527	1459	3	2004-08-15
6	7527	5168	2	2004-08-15
7	7527	5926	2	2004-08-15
1	7528	361	2	2004-08-02
2	7528	7097	3	2004-08-02
3	7528	8115	3	2004-08-02
4	7528	608	3	2004-08-02
5	7528	4014	2	2004-08-02
1	7529	5900	3	2004-08-03
2	7529	2965	2	2004-08-03
3	7529	6186	1	2004-08-03
4	7529	6615	3	2004-08-03
5	7529	9884	1	2004-08-03
6	7529	2144	2	2004-08-03
7	7529	6724	1	2004-08-03
8	7529	695	1	2004-08-03
1	7530	9397	2	2004-08-25
2	7530	3738	1	2004-08-25
3	7530	939	3	2004-08-25
4	7530	5257	1	2004-08-25
5	7530	868	3	2004-08-25
1	7531	511	1	2004-08-30
2	7531	3476	3	2004-08-30
3	7531	92	2	2004-08-30
1	7532	4737	3	2004-08-28
2	7532	6664	1	2004-08-28
3	7532	917	1	2004-08-28
4	7532	7845	1	2004-08-28
5	7532	5539	1	2004-08-28
6	7532	318	2	2004-08-28
1	7533	2829	3	2004-08-29
1	7534	1537	2	2004-08-22
2	7534	4601	1	2004-08-22
3	7534	7391	2	2004-08-22
4	7534	3862	2	2004-08-22
5	7534	9138	3	2004-08-22
6	7534	6421	2	2004-08-22
7	7534	1341	3	2004-08-22
1	7535	767	3	2004-08-25
2	7535	9860	1	2004-08-25
3	7535	3541	3	2004-08-25
4	7535	297	2	2004-08-25
1	7536	4738	3	2004-08-19
2	7536	632	3	2004-08-19
3	7536	8622	3	2004-08-19
4	7536	2846	1	2004-08-19
5	7536	4582	1	2004-08-19
6	7536	1082	1	2004-08-19
1	7537	1607	2	2004-08-25
2	7537	9009	1	2004-08-25
3	7537	3956	3	2004-08-25
4	7537	2471	3	2004-08-25
5	7537	6987	1	2004-08-25
6	7537	3865	1	2004-08-25
1	7538	6319	1	2004-08-01
2	7538	4106	2	2004-08-01
3	7538	8286	3	2004-08-01
4	7538	7424	1	2004-08-01
5	7538	8934	3	2004-08-01
1	7539	2344	1	2004-08-12
2	7539	8196	1	2004-08-12
1	7540	9647	3	2004-08-16
2	7540	142	2	2004-08-16
3	7540	239	1	2004-08-16
4	7540	2836	3	2004-08-16
5	7540	4938	3	2004-08-16
6	7540	134	3	2004-08-16
7	7540	4094	3	2004-08-16
1	7541	22	2	2004-08-19
2	7541	1645	1	2004-08-19
3	7541	7363	2	2004-08-19
4	7541	3479	2	2004-08-19
5	7541	5341	3	2004-08-19
1	7542	2768	2	2004-08-24
2	7542	868	1	2004-08-24
3	7542	6071	2	2004-08-24
4	7542	2877	1	2004-08-24
5	7542	2857	1	2004-08-24
6	7542	51	3	2004-08-24
7	7542	1431	2	2004-08-24
1	7543	7872	1	2004-08-27
2	7543	9435	2	2004-08-27
3	7543	6604	1	2004-08-27
4	7543	793	1	2004-08-27
5	7543	1298	3	2004-08-27
6	7543	7505	3	2004-08-27
7	7543	5858	1	2004-08-27
8	7543	2955	3	2004-08-27
1	7544	33	1	2004-08-11
2	7544	9167	1	2004-08-11
3	7544	236	1	2004-08-11
4	7544	6128	3	2004-08-11
5	7544	3314	3	2004-08-11
6	7544	7191	1	2004-08-11
1	7545	9540	3	2004-08-31
2	7545	8263	1	2004-08-31
3	7545	5715	2	2004-08-31
4	7545	7892	1	2004-08-31
5	7545	6040	1	2004-08-31
6	7545	8299	3	2004-08-31
1	7546	2013	2	2004-08-31
2	7546	9988	1	2004-08-31
3	7546	5238	2	2004-08-31
4	7546	951	3	2004-08-31
5	7546	3215	3	2004-08-31
6	7546	9738	1	2004-08-31
7	7546	4767	2	2004-08-31
8	7546	9249	2	2004-08-31
9	7546	3371	3	2004-08-31
1	7547	658	3	2004-08-16
2	7547	3879	3	2004-08-16
3	7547	8637	2	2004-08-16
1	7548	8751	2	2004-08-24
2	7548	1943	2	2004-08-24
3	7548	9756	1	2004-08-24
4	7548	2540	1	2004-08-24
5	7548	1034	1	2004-08-24
6	7548	5899	2	2004-08-24
7	7548	8434	2	2004-08-24
8	7548	105	1	2004-08-24
9	7548	2659	2	2004-08-24
1	7549	5256	1	2004-08-03
2	7549	502	2	2004-08-03
1	7550	7880	3	2004-08-19
2	7550	3201	3	2004-08-19
3	7550	741	1	2004-08-19
4	7550	2714	1	2004-08-19
5	7550	5926	2	2004-08-19
6	7550	5557	1	2004-08-19
7	7550	9547	2	2004-08-19
8	7550	6972	3	2004-08-19
9	7550	5795	3	2004-08-19
1	7551	8230	1	2004-08-16
2	7551	5331	3	2004-08-16
3	7551	4715	1	2004-08-16
1	7552	9469	2	2004-08-22
2	7552	4617	1	2004-08-22
3	7552	6952	3	2004-08-22
4	7552	3489	1	2004-08-22
5	7552	1078	3	2004-08-22
1	7553	275	3	2004-08-15
2	7553	1305	2	2004-08-15
1	7554	7695	2	2004-08-18
2	7554	2475	1	2004-08-18
3	7554	4911	3	2004-08-18
4	7554	5125	2	2004-08-18
1	7555	4802	2	2004-08-13
2	7555	6132	3	2004-08-13
3	7555	9531	3	2004-08-13
4	7555	7336	2	2004-08-13
5	7555	7834	1	2004-08-13
6	7555	5907	3	2004-08-13
7	7555	9203	3	2004-08-13
8	7555	3278	2	2004-08-13
1	7556	5297	1	2004-08-13
2	7556	4185	1	2004-08-13
1	7557	3902	2	2004-08-02
2	7557	3311	3	2004-08-02
3	7557	2268	3	2004-08-02
4	7557	6994	1	2004-08-02
5	7557	6652	2	2004-08-02
1	7558	2592	2	2004-08-19
2	7558	9148	2	2004-08-19
1	7559	5006	1	2004-08-27
2	7559	8011	3	2004-08-27
3	7559	2994	3	2004-08-27
4	7559	8500	3	2004-08-27
5	7559	2843	1	2004-08-27
6	7559	4520	2	2004-08-27
7	7559	1103	3	2004-08-27
1	7560	2425	2	2004-08-18
2	7560	6732	3	2004-08-18
3	7560	6552	3	2004-08-18
1	7561	8928	1	2004-08-04
2	7561	6724	2	2004-08-04
3	7561	5472	2	2004-08-04
4	7561	3124	3	2004-08-04
5	7561	3068	1	2004-08-04
6	7561	7372	2	2004-08-04
7	7561	4024	1	2004-08-04
8	7561	2064	2	2004-08-04
9	7561	8679	3	2004-08-04
1	7562	1878	2	2004-08-10
2	7562	2773	3	2004-08-10
3	7562	5961	2	2004-08-10
4	7562	4127	1	2004-08-10
5	7562	3447	1	2004-08-10
6	7562	3838	1	2004-08-10
1	7563	7775	3	2004-08-22
1	7564	7038	2	2004-08-06
2	7564	885	2	2004-08-06
3	7564	3603	2	2004-08-06
4	7564	2979	2	2004-08-06
5	7564	9754	2	2004-08-06
6	7564	146	1	2004-08-06
1	7565	7261	3	2004-08-11
2	7565	464	1	2004-08-11
3	7565	9943	3	2004-08-11
4	7565	408	2	2004-08-11
5	7565	7564	3	2004-08-11
6	7565	2816	3	2004-08-11
7	7565	3328	3	2004-08-11
1	7566	6081	2	2004-08-16
2	7566	48	3	2004-08-16
3	7566	9752	3	2004-08-16
4	7566	3914	3	2004-08-16
5	7566	2327	3	2004-08-16
6	7566	6004	3	2004-08-16
1	7567	4362	3	2004-08-15
2	7567	2523	2	2004-08-15
3	7567	3214	1	2004-08-15
4	7567	2951	2	2004-08-15
5	7567	9384	2	2004-08-15
1	7568	380	1	2004-08-09
2	7568	1610	1	2004-08-09
3	7568	1784	1	2004-08-09
4	7568	228	2	2004-08-09
5	7568	1259	1	2004-08-09
1	7569	526	3	2004-08-09
2	7569	2573	2	2004-08-09
3	7569	8001	2	2004-08-09
4	7569	9657	1	2004-08-09
5	7569	5180	1	2004-08-09
6	7569	7245	2	2004-08-09
7	7569	8886	3	2004-08-09
1	7570	8254	3	2004-08-28
2	7570	9809	1	2004-08-28
3	7570	8308	1	2004-08-28
4	7570	5735	3	2004-08-28
5	7570	2591	3	2004-08-28
6	7570	6829	2	2004-08-28
7	7570	6132	3	2004-08-28
8	7570	3431	3	2004-08-28
9	7570	2242	1	2004-08-28
1	7571	4505	3	2004-08-12
2	7571	3542	2	2004-08-12
3	7571	9861	1	2004-08-12
4	7571	8919	2	2004-08-12
5	7571	1926	3	2004-08-12
6	7571	2144	1	2004-08-12
7	7571	7210	1	2004-08-12
8	7571	1771	1	2004-08-12
9	7571	18	2	2004-08-12
1	7572	4200	1	2004-08-05
2	7572	6409	2	2004-08-05
3	7572	3020	1	2004-08-05
4	7572	8339	2	2004-08-05
5	7572	9186	1	2004-08-05
6	7572	5556	1	2004-08-05
7	7572	6232	2	2004-08-05
1	7573	2323	1	2004-08-17
2	7573	8931	3	2004-08-17
3	7573	3208	1	2004-08-17
4	7573	2477	1	2004-08-17
5	7573	5063	2	2004-08-17
6	7573	71	1	2004-08-17
7	7573	1757	2	2004-08-17
1	7574	8373	3	2004-08-15
2	7574	3496	3	2004-08-15
3	7574	1892	3	2004-08-15
4	7574	285	3	2004-08-15
5	7574	4467	2	2004-08-15
6	7574	3273	2	2004-08-15
7	7574	2750	2	2004-08-15
8	7574	7835	1	2004-08-15
1	7575	4267	3	2004-08-16
2	7575	1656	2	2004-08-16
3	7575	666	2	2004-08-16
4	7575	8607	2	2004-08-16
5	7575	1579	3	2004-08-16
6	7575	3307	3	2004-08-16
7	7575	8367	3	2004-08-16
1	7576	8381	1	2004-08-24
2	7576	3347	1	2004-08-24
3	7576	5399	2	2004-08-24
4	7576	7249	1	2004-08-24
5	7576	7777	1	2004-08-24
6	7576	4276	1	2004-08-24
7	7576	9982	3	2004-08-24
8	7576	7603	1	2004-08-24
1	7577	3744	2	2004-08-09
2	7577	805	3	2004-08-09
1	7578	9429	3	2004-08-21
2	7578	1879	3	2004-08-21
3	7578	25	2	2004-08-21
4	7578	9462	2	2004-08-21
1	7579	9088	1	2004-08-05
2	7579	9256	3	2004-08-05
3	7579	1477	3	2004-08-05
4	7579	706	2	2004-08-05
5	7579	5127	2	2004-08-05
6	7579	5843	3	2004-08-05
7	7579	2383	2	2004-08-05
8	7579	5921	3	2004-08-05
9	7579	5818	3	2004-08-05
1	7580	3054	3	2004-08-10
2	7580	151	1	2004-08-10
3	7580	4927	1	2004-08-10
4	7580	9227	2	2004-08-10
5	7580	569	3	2004-08-10
1	7581	6683	3	2004-08-21
2	7581	2350	1	2004-08-21
3	7581	3844	3	2004-08-21
4	7581	680	2	2004-08-21
5	7581	4839	2	2004-08-21
6	7581	5187	1	2004-08-21
7	7581	6373	3	2004-08-21
8	7581	5902	2	2004-08-21
1	7582	1471	1	2004-08-10
2	7582	4782	1	2004-08-10
3	7582	3864	2	2004-08-10
1	7583	8374	1	2004-08-28
2	7583	4482	1	2004-08-28
3	7583	3668	3	2004-08-28
4	7583	8915	2	2004-08-28
5	7583	4551	2	2004-08-28
6	7583	947	3	2004-08-28
1	7584	3170	1	2004-08-14
1	7585	8803	3	2004-08-29
1	7586	3047	3	2004-08-05
1	7587	2144	2	2004-08-22
2	7587	9646	1	2004-08-22
1	7588	3935	3	2004-08-30
1	7589	3037	3	2004-08-25
1	7590	6701	1	2004-08-30
2	7590	1049	1	2004-08-30
3	7590	1412	2	2004-08-30
4	7590	1023	3	2004-08-30
5	7590	5516	1	2004-08-30
6	7590	9572	3	2004-08-30
7	7590	7905	3	2004-08-30
8	7590	8717	3	2004-08-30
1	7591	2750	2	2004-08-11
2	7591	9255	1	2004-08-11
3	7591	7040	1	2004-08-11
4	7591	1077	2	2004-08-11
5	7591	9769	1	2004-08-11
6	7591	5004	2	2004-08-11
7	7591	1576	2	2004-08-11
1	7592	1238	2	2004-08-25
2	7592	1397	1	2004-08-25
3	7592	3321	3	2004-08-25
4	7592	28	1	2004-08-25
5	7592	6827	2	2004-08-25
6	7592	5566	2	2004-08-25
7	7592	791	3	2004-08-25
8	7592	904	1	2004-08-25
1	7593	4564	1	2004-08-02
2	7593	2281	3	2004-08-02
1	7594	6844	2	2004-08-27
2	7594	5085	3	2004-08-27
3	7594	1428	2	2004-08-27
4	7594	8891	2	2004-08-27
5	7594	5783	3	2004-08-27
6	7594	6787	1	2004-08-27
1	7595	668	3	2004-08-08
2	7595	3194	1	2004-08-08
3	7595	6378	2	2004-08-08
1	7596	508	2	2004-08-10
2	7596	9072	2	2004-08-10
3	7596	2527	2	2004-08-10
4	7596	1891	3	2004-08-10
5	7596	3996	1	2004-08-10
1	7597	1804	2	2004-08-13
2	7597	2485	2	2004-08-13
3	7597	7206	1	2004-08-13
4	7597	7312	3	2004-08-13
5	7597	8450	1	2004-08-13
6	7597	9136	2	2004-08-13
7	7597	6036	1	2004-08-13
8	7597	5768	2	2004-08-13
9	7597	7285	2	2004-08-13
1	7598	2272	2	2004-08-31
2	7598	18	2	2004-08-31
3	7598	7610	2	2004-08-31
1	7599	530	2	2004-08-29
1	7600	5609	2	2004-08-16
2	7600	2936	2	2004-08-16
3	7600	9762	3	2004-08-16
1	7601	1804	1	2004-08-22
2	7601	455	2	2004-08-22
3	7601	4926	1	2004-08-22
4	7601	8495	2	2004-08-22
1	7602	1780	1	2004-08-28
2	7602	9102	1	2004-08-28
3	7602	9508	2	2004-08-28
4	7602	45	2	2004-08-28
5	7602	6651	2	2004-08-28
6	7602	929	3	2004-08-28
7	7602	396	1	2004-08-28
8	7602	8558	3	2004-08-28
1	7603	3719	1	2004-08-20
2	7603	2228	3	2004-08-20
3	7603	4489	1	2004-08-20
4	7603	3587	2	2004-08-20
5	7603	6827	1	2004-08-20
6	7603	1627	3	2004-08-20
7	7603	5676	1	2004-08-20
8	7603	916	2	2004-08-20
1	7604	6613	1	2004-08-16
2	7604	1185	3	2004-08-16
1	7605	941	2	2004-08-09
2	7605	7039	2	2004-08-09
3	7605	7288	3	2004-08-09
4	7605	3304	1	2004-08-09
5	7605	9988	3	2004-08-09
6	7605	5257	3	2004-08-09
7	7605	9528	3	2004-08-09
8	7605	5420	2	2004-08-09
9	7605	7611	2	2004-08-09
1	7606	4157	2	2004-08-02
2	7606	3670	2	2004-08-02
1	7607	5480	2	2004-08-03
2	7607	659	1	2004-08-03
3	7607	684	3	2004-08-03
4	7607	1785	2	2004-08-03
5	7607	9722	1	2004-08-03
1	7608	1862	2	2004-08-03
1	7609	2030	3	2004-08-18
2	7609	7558	2	2004-08-18
3	7609	1544	1	2004-08-18
4	7609	1528	1	2004-08-18
5	7609	7693	2	2004-08-18
6	7609	7593	1	2004-08-18
1	7610	6197	3	2004-08-09
2	7610	7303	2	2004-08-09
3	7610	9247	3	2004-08-09
1	7611	1839	2	2004-08-03
2	7611	2230	1	2004-08-03
3	7611	181	2	2004-08-03
1	7612	8966	1	2004-08-31
2	7612	3819	2	2004-08-31
1	7613	9663	2	2004-08-27
2	7613	4533	2	2004-08-27
1	7614	14	1	2004-08-10
2	7614	75	3	2004-08-10
3	7614	5433	1	2004-08-10
1	7615	1922	2	2004-08-09
2	7615	701	1	2004-08-09
3	7615	5268	3	2004-08-09
1	7616	499	2	2004-08-14
2	7616	4139	1	2004-08-14
3	7616	1675	3	2004-08-14
1	7617	6913	1	2004-08-19
2	7617	473	3	2004-08-19
3	7617	9115	2	2004-08-19
4	7617	8900	1	2004-08-19
5	7617	3569	1	2004-08-19
6	7617	4858	2	2004-08-19
7	7617	6901	2	2004-08-19
8	7617	7858	1	2004-08-19
1	7618	5121	1	2004-08-17
2	7618	7704	3	2004-08-17
1	7619	4049	3	2004-08-06
2	7619	5732	1	2004-08-06
3	7619	8957	2	2004-08-06
4	7619	7948	3	2004-08-06
5	7619	2110	3	2004-08-06
6	7619	9967	2	2004-08-06
7	7619	9840	2	2004-08-06
8	7619	1169	3	2004-08-06
1	7620	1224	1	2004-08-02
2	7620	7157	2	2004-08-02
3	7620	1918	2	2004-08-02
4	7620	5603	2	2004-08-02
5	7620	4238	2	2004-08-02
6	7620	1766	3	2004-08-02
1	7621	3701	3	2004-08-07
1	7622	1489	2	2004-08-28
2	7622	3788	1	2004-08-28
3	7622	622	2	2004-08-28
4	7622	1684	3	2004-08-28
5	7622	9779	1	2004-08-28
6	7622	9695	3	2004-08-28
7	7622	9251	1	2004-08-28
8	7622	1795	2	2004-08-28
9	7622	5444	2	2004-08-28
1	7623	4706	2	2004-08-26
1	7624	4217	2	2004-08-04
1	7625	8364	3	2004-08-29
2	7625	7199	1	2004-08-29
3	7625	8834	3	2004-08-29
1	7626	140	2	2004-08-10
2	7626	7058	2	2004-08-10
1	7627	5800	3	2004-08-06
2	7627	9624	3	2004-08-06
3	7627	5903	1	2004-08-06
4	7627	7359	1	2004-08-06
5	7627	5185	2	2004-08-06
6	7627	5825	2	2004-08-06
1	7628	4235	1	2004-08-30
2	7628	3801	3	2004-08-30
3	7628	531	3	2004-08-30
4	7628	9393	1	2004-08-30
5	7628	3419	2	2004-08-30
6	7628	6254	2	2004-08-30
7	7628	1895	3	2004-08-30
1	7629	4775	1	2004-08-04
1	7630	8732	3	2004-08-04
2	7630	273	3	2004-08-04
3	7630	2576	2	2004-08-04
4	7630	5181	3	2004-08-04
5	7630	5445	3	2004-08-04
6	7630	3998	2	2004-08-04
1	7631	9841	1	2004-08-21
1	7632	9429	3	2004-08-17
2	7632	7326	2	2004-08-17
3	7632	928	3	2004-08-17
4	7632	6336	2	2004-08-17
5	7632	4955	2	2004-08-17
6	7632	1879	2	2004-08-17
1	7633	1265	2	2004-08-11
2	7633	7587	2	2004-08-11
3	7633	89	2	2004-08-11
4	7633	8653	3	2004-08-11
5	7633	4392	3	2004-08-11
6	7633	9631	3	2004-08-11
7	7633	227	1	2004-08-11
8	7633	6148	3	2004-08-11
1	7634	2021	1	2004-08-01
1	7635	2203	3	2004-08-14
2	7635	807	1	2004-08-14
3	7635	7289	1	2004-08-14
4	7635	4986	2	2004-08-14
5	7635	7334	2	2004-08-14
6	7635	9155	2	2004-08-14
1	7636	3208	2	2004-08-06
2	7636	3008	3	2004-08-06
1	7637	4047	2	2004-08-14
2	7637	8411	3	2004-08-14
3	7637	1822	2	2004-08-14
4	7637	4873	2	2004-08-14
5	7637	2355	2	2004-08-14
6	7637	4896	3	2004-08-14
7	7637	7751	3	2004-08-14
8	7637	4519	2	2004-08-14
1	7638	7219	2	2004-08-16
2	7638	8195	1	2004-08-16
3	7638	252	1	2004-08-16
4	7638	9780	2	2004-08-16
5	7638	4267	1	2004-08-16
6	7638	2828	3	2004-08-16
7	7638	7453	1	2004-08-16
1	7639	3297	3	2004-08-22
2	7639	7386	3	2004-08-22
1	7640	219	1	2004-08-22
2	7640	5099	1	2004-08-22
1	7641	2742	3	2004-08-31
2	7641	9183	1	2004-08-31
3	7641	1696	2	2004-08-31
4	7641	5127	2	2004-08-31
5	7641	1763	1	2004-08-31
6	7641	5763	3	2004-08-31
7	7641	1853	1	2004-08-31
8	7641	303	2	2004-08-31
1	7642	2824	1	2004-08-25
2	7642	6271	1	2004-08-25
3	7642	4440	1	2004-08-25
4	7642	4330	2	2004-08-25
5	7642	3686	1	2004-08-25
1	7643	8949	3	2004-08-07
2	7643	4837	2	2004-08-07
1	7644	5196	3	2004-08-14
1	7645	3186	3	2004-08-03
2	7645	3684	2	2004-08-03
3	7645	8409	3	2004-08-03
4	7645	9051	1	2004-08-03
5	7645	1324	2	2004-08-03
6	7645	7072	2	2004-08-03
7	7645	4545	3	2004-08-03
8	7645	1436	1	2004-08-03
1	7646	4459	3	2004-08-03
2	7646	2099	1	2004-08-03
3	7646	7438	3	2004-08-03
4	7646	9618	3	2004-08-03
5	7646	2791	1	2004-08-03
1	7647	1986	3	2004-08-23
1	7648	4417	3	2004-08-03
2	7648	7148	3	2004-08-03
1	7649	8968	2	2004-08-25
2	7649	4034	2	2004-08-25
3	7649	1700	2	2004-08-25
4	7649	4538	3	2004-08-25
5	7649	3426	2	2004-08-25
6	7649	7477	2	2004-08-25
7	7649	7427	2	2004-08-25
8	7649	2193	3	2004-08-25
1	7650	5215	3	2004-08-18
2	7650	8474	3	2004-08-18
3	7650	6489	2	2004-08-18
4	7650	8593	2	2004-08-18
5	7650	4205	1	2004-08-18
6	7650	2895	1	2004-08-18
1	7651	3061	1	2004-08-16
2	7651	5676	2	2004-08-16
3	7651	5291	1	2004-08-16
4	7651	2702	1	2004-08-16
5	7651	7808	2	2004-08-16
6	7651	411	1	2004-08-16
1	7652	4674	3	2004-08-29
2	7652	3917	1	2004-08-29
3	7652	3754	1	2004-08-29
4	7652	5523	3	2004-08-29
1	7653	5346	3	2004-08-09
2	7653	4233	3	2004-08-09
3	7653	8863	3	2004-08-09
4	7653	4892	2	2004-08-09
5	7653	3060	3	2004-08-09
6	7653	6871	1	2004-08-09
7	7653	2487	3	2004-08-09
1	7654	5844	3	2004-08-13
2	7654	1985	3	2004-08-13
3	7654	9898	2	2004-08-13
4	7654	2270	2	2004-08-13
1	7655	2819	3	2004-08-12
2	7655	2554	3	2004-08-12
3	7655	7588	1	2004-08-12
4	7655	6959	1	2004-08-12
5	7655	5570	1	2004-08-12
1	7656	9722	2	2004-08-01
2	7656	4117	2	2004-08-01
3	7656	8931	3	2004-08-01
1	7657	6654	1	2004-08-08
2	7657	7835	1	2004-08-08
3	7657	7116	1	2004-08-08
1	7658	6986	3	2004-08-17
2	7658	9146	2	2004-08-17
3	7658	920	2	2004-08-17
4	7658	3964	1	2004-08-17
5	7658	7156	2	2004-08-17
6	7658	3551	3	2004-08-17
7	7658	9928	3	2004-08-17
1	7659	9773	3	2004-08-03
2	7659	5593	2	2004-08-03
3	7659	9339	2	2004-08-03
1	7660	6389	2	2004-08-22
2	7660	9682	2	2004-08-22
1	7661	3543	1	2004-08-14
2	7661	6304	1	2004-08-14
3	7661	6131	3	2004-08-14
4	7661	7576	2	2004-08-14
5	7661	7521	3	2004-08-14
1	7662	2497	3	2004-08-16
2	7662	1115	1	2004-08-16
3	7662	434	3	2004-08-16
4	7662	8289	2	2004-08-16
5	7662	9843	2	2004-08-16
1	7663	8352	2	2004-08-05
2	7663	1187	1	2004-08-05
3	7663	6652	3	2004-08-05
4	7663	2594	1	2004-08-05
5	7663	7344	1	2004-08-05
6	7663	8839	2	2004-08-05
1	7664	8442	1	2004-08-27
2	7664	6823	3	2004-08-27
3	7664	4344	3	2004-08-27
4	7664	7447	1	2004-08-27
5	7664	2788	3	2004-08-27
6	7664	7309	2	2004-08-27
7	7664	6814	2	2004-08-27
8	7664	146	2	2004-08-27
9	7664	730	1	2004-08-27
1	7665	162	2	2004-08-22
2	7665	9822	3	2004-08-22
3	7665	1030	3	2004-08-22
4	7665	2755	1	2004-08-22
5	7665	8043	1	2004-08-22
6	7665	3551	2	2004-08-22
7	7665	753	3	2004-08-22
8	7665	2121	3	2004-08-22
9	7665	526	2	2004-08-22
1	7666	3195	3	2004-08-18
2	7666	7469	2	2004-08-18
3	7666	655	2	2004-08-18
1	7667	5641	2	2004-08-05
2	7667	467	3	2004-08-05
1	7668	4417	1	2004-08-07
1	7669	3368	3	2004-08-16
2	7669	2165	3	2004-08-16
3	7669	7516	1	2004-08-16
4	7669	1159	1	2004-08-16
5	7669	666	3	2004-08-16
6	7669	4634	1	2004-08-16
7	7669	3155	2	2004-08-16
1	7670	1340	3	2004-08-03
2	7670	3108	2	2004-08-03
3	7670	1091	1	2004-08-03
4	7670	3840	2	2004-08-03
5	7670	2084	3	2004-08-03
6	7670	676	1	2004-08-03
1	7671	2900	3	2004-08-20
2	7671	9739	2	2004-08-20
3	7671	9148	1	2004-08-20
4	7671	2685	2	2004-08-20
5	7671	1726	2	2004-08-20
6	7671	9719	1	2004-08-20
7	7671	3176	3	2004-08-20
8	7671	8960	2	2004-08-20
1	7672	2888	1	2004-08-16
2	7672	1590	2	2004-08-16
3	7672	898	1	2004-08-16
4	7672	6210	3	2004-08-16
5	7672	6310	3	2004-08-16
6	7672	5525	3	2004-08-16
1	7673	5669	2	2004-08-18
2	7673	8496	3	2004-08-18
3	7673	1790	3	2004-08-18
4	7673	9916	2	2004-08-18
5	7673	5336	3	2004-08-18
1	7674	6411	2	2004-08-30
2	7674	9484	3	2004-08-30
3	7674	8799	1	2004-08-30
4	7674	266	2	2004-08-30
5	7674	7510	2	2004-08-30
6	7674	2140	1	2004-08-30
7	7674	5784	3	2004-08-30
1	7675	5001	1	2004-08-26
2	7675	1361	3	2004-08-26
3	7675	9131	1	2004-08-26
4	7675	1756	2	2004-08-26
1	7676	8797	1	2004-08-01
1	7677	8661	3	2004-08-16
2	7677	8727	2	2004-08-16
3	7677	6045	1	2004-08-16
4	7677	9206	1	2004-08-16
1	7678	1471	2	2004-08-27
1	7679	4107	2	2004-08-06
1	7680	5347	2	2004-08-18
1	7681	3984	1	2004-08-05
1	7682	3575	3	2004-08-01
2	7682	8050	1	2004-08-01
3	7682	4275	3	2004-08-01
4	7682	3141	2	2004-08-01
5	7682	4807	2	2004-08-01
6	7682	8577	3	2004-08-01
1	7683	6938	3	2004-08-19
2	7683	1897	1	2004-08-19
1	7684	4107	2	2004-08-07
2	7684	6141	2	2004-08-07
3	7684	9242	2	2004-08-07
4	7684	505	1	2004-08-07
5	7684	477	3	2004-08-07
1	7685	498	1	2004-08-16
2	7685	3154	3	2004-08-16
3	7685	9764	3	2004-08-16
4	7685	1756	1	2004-08-16
5	7685	841	3	2004-08-16
6	7685	9221	1	2004-08-16
7	7685	978	1	2004-08-16
8	7685	6137	2	2004-08-16
1	7686	4527	3	2004-08-19
2	7686	5825	2	2004-08-19
1	7687	1053	1	2004-08-07
2	7687	5184	1	2004-08-07
3	7687	3357	3	2004-08-07
4	7687	624	1	2004-08-07
5	7687	7581	1	2004-08-07
6	7687	4784	3	2004-08-07
7	7687	1073	2	2004-08-07
1	7688	5578	1	2004-08-04
2	7688	7537	2	2004-08-04
3	7688	3334	1	2004-08-04
4	7688	4937	3	2004-08-04
5	7688	7096	3	2004-08-04
6	7688	5459	1	2004-08-04
7	7688	4134	2	2004-08-04
1	7689	7653	3	2004-08-06
2	7689	8228	2	2004-08-06
3	7689	1063	1	2004-08-06
4	7689	3655	1	2004-08-06
5	7689	7016	2	2004-08-06
1	7690	3467	3	2004-08-13
2	7690	5400	3	2004-08-13
3	7690	1706	1	2004-08-13
4	7690	5958	3	2004-08-13
5	7690	7390	1	2004-08-13
6	7690	9483	1	2004-08-13
7	7690	7928	1	2004-08-13
8	7690	840	2	2004-08-13
9	7690	6339	3	2004-08-13
1	7691	7578	3	2004-08-15
2	7691	7871	2	2004-08-15
3	7691	2192	1	2004-08-15
4	7691	6846	2	2004-08-15
5	7691	1820	1	2004-08-15
6	7691	3939	3	2004-08-15
1	7692	4446	2	2004-08-23
2	7692	4486	2	2004-08-23
3	7692	6468	1	2004-08-23
1	7693	5799	1	2004-08-16
2	7693	6065	3	2004-08-16
1	7694	8235	3	2004-08-28
2	7694	8734	2	2004-08-28
3	7694	3392	1	2004-08-28
4	7694	5392	3	2004-08-28
5	7694	7772	1	2004-08-28
6	7694	2976	2	2004-08-28
7	7694	5573	3	2004-08-28
1	7695	2471	2	2004-08-01
2	7695	4044	1	2004-08-01
3	7695	8007	3	2004-08-01
4	7695	3943	2	2004-08-01
5	7695	9366	1	2004-08-01
6	7695	7712	2	2004-08-01
7	7695	9427	2	2004-08-01
1	7696	8713	2	2004-08-17
2	7696	6085	2	2004-08-17
3	7696	8920	3	2004-08-17
4	7696	1811	2	2004-08-17
5	7696	6481	1	2004-08-17
6	7696	4552	3	2004-08-17
7	7696	8818	3	2004-08-17
8	7696	4338	1	2004-08-17
1	7697	6416	1	2004-08-25
2	7697	4586	2	2004-08-25
1	7698	2173	1	2004-08-26
2	7698	2456	1	2004-08-26
3	7698	7515	3	2004-08-26
4	7698	7369	2	2004-08-26
1	7699	1260	2	2004-08-24
2	7699	1910	1	2004-08-24
3	7699	2501	2	2004-08-24
4	7699	2939	1	2004-08-24
1	7700	7711	3	2004-08-27
2	7700	9134	2	2004-08-27
3	7700	827	3	2004-08-27
4	7700	9750	1	2004-08-27
5	7700	305	1	2004-08-27
1	7701	4255	3	2004-08-13
2	7701	432	2	2004-08-13
1	7702	1769	1	2004-08-08
2	7702	580	2	2004-08-08
3	7702	3554	3	2004-08-08
4	7702	350	2	2004-08-08
1	7703	4109	2	2004-08-13
2	7703	2517	2	2004-08-13
3	7703	6422	1	2004-08-13
1	7704	1558	2	2004-08-19
2	7704	5150	1	2004-08-19
3	7704	77	3	2004-08-19
4	7704	3681	1	2004-08-19
5	7704	1907	2	2004-08-19
6	7704	3898	1	2004-08-19
7	7704	157	3	2004-08-19
1	7705	8566	2	2004-08-06
2	7705	9146	1	2004-08-06
3	7705	9254	1	2004-08-06
4	7705	6532	2	2004-08-06
5	7705	4484	1	2004-08-06
6	7705	5981	2	2004-08-06
1	7706	9528	1	2004-08-30
2	7706	2123	1	2004-08-30
3	7706	834	2	2004-08-30
4	7706	8658	2	2004-08-30
5	7706	6516	3	2004-08-30
1	7707	4009	3	2004-08-07
2	7707	1249	1	2004-08-07
3	7707	558	1	2004-08-07
4	7707	4816	3	2004-08-07
5	7707	6178	3	2004-08-07
1	7708	9697	2	2004-08-31
2	7708	3630	3	2004-08-31
3	7708	4541	2	2004-08-31
4	7708	2434	2	2004-08-31
5	7708	9782	1	2004-08-31
6	7708	105	2	2004-08-31
7	7708	9904	1	2004-08-31
8	7708	4471	3	2004-08-31
9	7708	7705	3	2004-08-31
1	7709	9456	2	2004-08-23
2	7709	4753	2	2004-08-23
3	7709	5748	2	2004-08-23
4	7709	7792	1	2004-08-23
5	7709	3516	3	2004-08-23
6	7709	4616	3	2004-08-23
7	7709	6714	3	2004-08-23
1	7710	237	2	2004-08-09
2	7710	8975	1	2004-08-09
3	7710	6922	2	2004-08-09
1	7711	3580	2	2004-08-30
2	7711	4131	1	2004-08-30
3	7711	4	3	2004-08-30
4	7711	8669	2	2004-08-30
5	7711	3318	2	2004-08-30
6	7711	5924	3	2004-08-30
1	7712	9696	3	2004-08-13
1	7713	8859	3	2004-08-31
1	7714	407	2	2004-08-01
2	7714	6015	2	2004-08-01
3	7714	7451	1	2004-08-01
4	7714	7022	3	2004-08-01
5	7714	9028	2	2004-08-01
6	7714	3206	1	2004-08-01
7	7714	2151	3	2004-08-01
8	7714	9177	2	2004-08-01
9	7714	9670	1	2004-08-01
1	7715	3590	3	2004-08-21
2	7715	6618	1	2004-08-21
3	7715	8107	3	2004-08-21
4	7715	8229	1	2004-08-21
5	7715	6351	3	2004-08-21
6	7715	3973	1	2004-08-21
1	7716	8878	1	2004-08-09
2	7716	5335	1	2004-08-09
3	7716	3882	3	2004-08-09
4	7716	1214	1	2004-08-09
5	7716	3585	1	2004-08-09
6	7716	6213	1	2004-08-09
7	7716	248	2	2004-08-09
8	7716	6920	2	2004-08-09
9	7716	5821	2	2004-08-09
1	7717	4005	3	2004-08-20
2	7717	3151	3	2004-08-20
3	7717	9056	2	2004-08-20
4	7717	9400	1	2004-08-20
5	7717	5417	3	2004-08-20
1	7718	8236	1	2004-08-10
2	7718	43	1	2004-08-10
3	7718	2456	2	2004-08-10
4	7718	2169	1	2004-08-10
5	7718	2496	3	2004-08-10
6	7718	6541	3	2004-08-10
7	7718	2625	1	2004-08-10
1	7719	9657	1	2004-08-07
2	7719	4223	3	2004-08-07
3	7719	6265	2	2004-08-07
4	7719	278	1	2004-08-07
5	7719	1899	2	2004-08-07
6	7719	2433	1	2004-08-07
1	7720	2489	2	2004-08-02
1	7721	3745	2	2004-08-21
2	7721	7474	2	2004-08-21
3	7721	8357	3	2004-08-21
4	7721	9335	2	2004-08-21
5	7721	5963	3	2004-08-21
6	7721	6191	1	2004-08-21
7	7721	7703	1	2004-08-21
8	7721	3807	3	2004-08-21
9	7721	4137	2	2004-08-21
1	7722	7238	1	2004-08-05
2	7722	2133	3	2004-08-05
1	7723	7954	3	2004-08-26
2	7723	2604	2	2004-08-26
3	7723	4497	1	2004-08-26
4	7723	5144	2	2004-08-26
5	7723	6659	1	2004-08-26
6	7723	2822	1	2004-08-26
7	7723	1290	1	2004-08-26
1	7724	802	3	2004-08-17
2	7724	6011	3	2004-08-17
3	7724	1591	1	2004-08-17
4	7724	563	2	2004-08-17
5	7724	2974	3	2004-08-17
6	7724	2519	3	2004-08-17
7	7724	5719	1	2004-08-17
8	7724	5485	3	2004-08-17
9	7724	5899	3	2004-08-17
1	7725	2148	2	2004-08-29
2	7725	8792	2	2004-08-29
3	7725	7160	2	2004-08-29
4	7725	8534	2	2004-08-29
5	7725	3537	3	2004-08-29
6	7725	5530	3	2004-08-29
1	7726	843	2	2004-08-26
2	7726	7310	2	2004-08-26
3	7726	3126	1	2004-08-26
4	7726	3832	3	2004-08-26
5	7726	1351	3	2004-08-26
6	7726	8592	1	2004-08-26
7	7726	773	1	2004-08-26
8	7726	6576	1	2004-08-26
1	7727	9463	2	2004-08-29
2	7727	1863	1	2004-08-29
3	7727	4226	3	2004-08-29
4	7727	2546	1	2004-08-29
5	7727	4511	2	2004-08-29
6	7727	991	2	2004-08-29
1	7728	1328	1	2004-08-04
2	7728	2845	1	2004-08-04
3	7728	2276	1	2004-08-04
4	7728	3312	1	2004-08-04
1	7729	5255	1	2004-08-12
2	7729	9078	2	2004-08-12
3	7729	7215	1	2004-08-12
1	7730	3767	1	2004-08-24
1	7731	3057	3	2004-08-18
2	7731	946	2	2004-08-18
3	7731	9454	2	2004-08-18
4	7731	7062	1	2004-08-18
5	7731	5226	1	2004-08-18
6	7731	4777	3	2004-08-18
7	7731	261	1	2004-08-18
1	7732	232	1	2004-08-07
1	7733	8209	2	2004-08-07
1	7734	522	1	2004-08-10
2	7734	8240	1	2004-08-10
1	7735	9422	1	2004-08-24
2	7735	5125	2	2004-08-24
3	7735	9548	2	2004-08-24
4	7735	4944	1	2004-08-24
5	7735	900	3	2004-08-24
1	7736	9078	1	2004-08-08
2	7736	4773	3	2004-08-08
3	7736	5511	3	2004-08-08
4	7736	1096	2	2004-08-08
5	7736	9240	1	2004-08-08
1	7737	5172	3	2004-08-29
2	7737	1503	2	2004-08-29
3	7737	8822	2	2004-08-29
4	7737	8793	3	2004-08-29
5	7737	2012	2	2004-08-29
6	7737	9862	1	2004-08-29
7	7737	1749	1	2004-08-29
1	7738	65	1	2004-08-13
2	7738	406	2	2004-08-13
3	7738	9535	1	2004-08-13
1	7739	6254	2	2004-08-05
1	7740	6020	2	2004-08-23
2	7740	5279	2	2004-08-23
3	7740	1733	3	2004-08-23
4	7740	8547	1	2004-08-23
5	7740	201	1	2004-08-23
6	7740	3972	2	2004-08-23
7	7740	340	1	2004-08-23
8	7740	7362	1	2004-08-23
1	7741	9269	3	2004-08-08
2	7741	762	1	2004-08-08
1	7742	8441	1	2004-08-24
2	7742	3512	2	2004-08-24
3	7742	6494	3	2004-08-24
4	7742	9271	3	2004-08-24
5	7742	6080	3	2004-08-24
1	7743	522	3	2004-08-31
2	7743	4618	3	2004-08-31
3	7743	8858	3	2004-08-31
4	7743	5650	2	2004-08-31
1	7744	7304	3	2004-08-29
2	7744	6833	2	2004-08-29
3	7744	4723	2	2004-08-29
4	7744	9022	3	2004-08-29
5	7744	9733	2	2004-08-29
6	7744	7024	3	2004-08-29
7	7744	3742	1	2004-08-29
8	7744	6821	2	2004-08-29
9	7744	9383	2	2004-08-29
1	7745	7787	1	2004-08-23
2	7745	9041	2	2004-08-23
1	7746	7915	2	2004-08-22
2	7746	9093	2	2004-08-22
3	7746	1551	2	2004-08-22
4	7746	20	1	2004-08-22
5	7746	2050	3	2004-08-22
6	7746	6087	3	2004-08-22
7	7746	8755	3	2004-08-22
8	7746	2177	2	2004-08-22
9	7746	3390	1	2004-08-22
1	7747	2714	3	2004-08-02
2	7747	6136	1	2004-08-02
3	7747	2686	1	2004-08-02
4	7747	9851	1	2004-08-02
1	7748	2512	3	2004-08-08
2	7748	5355	1	2004-08-08
1	7749	6478	1	2004-08-28
2	7749	4735	3	2004-08-28
3	7749	6613	3	2004-08-28
4	7749	214	3	2004-08-28
5	7749	8867	1	2004-08-28
1	7750	3335	2	2004-08-04
2	7750	366	1	2004-08-04
3	7750	4652	1	2004-08-04
4	7750	950	1	2004-08-04
5	7750	4351	2	2004-08-04
6	7750	9600	3	2004-08-04
7	7750	5992	3	2004-08-04
1	7751	9313	3	2004-08-23
2	7751	2242	2	2004-08-23
3	7751	6186	1	2004-08-23
4	7751	3047	2	2004-08-23
1	7752	1210	3	2004-08-13
2	7752	8668	1	2004-08-13
3	7752	3151	1	2004-08-13
4	7752	4387	2	2004-08-13
5	7752	4670	3	2004-08-13
1	7753	2689	2	2004-08-24
2	7753	1828	2	2004-08-24
3	7753	9141	1	2004-08-24
4	7753	4077	1	2004-08-24
1	7754	5314	3	2004-08-22
1	7755	1913	1	2004-08-13
2	7755	6958	2	2004-08-13
3	7755	5010	1	2004-08-13
4	7755	9164	3	2004-08-13
5	7755	83	3	2004-08-13
1	7756	4079	1	2004-08-13
2	7756	2652	1	2004-08-13
3	7756	3246	3	2004-08-13
4	7756	4600	1	2004-08-13
5	7756	6990	3	2004-08-13
6	7756	425	1	2004-08-13
1	7757	9979	2	2004-08-20
2	7757	1116	3	2004-08-20
3	7757	1226	2	2004-08-20
4	7757	8280	1	2004-08-20
5	7757	5805	3	2004-08-20
6	7757	7115	3	2004-08-20
7	7757	6888	3	2004-08-20
8	7757	6389	1	2004-08-20
9	7757	9497	3	2004-08-20
1	7758	3055	1	2004-08-13
2	7758	7221	2	2004-08-13
3	7758	5062	2	2004-08-13
4	7758	8075	3	2004-08-13
5	7758	3048	3	2004-08-13
6	7758	5474	2	2004-08-13
7	7758	4989	3	2004-08-13
8	7758	288	1	2004-08-13
1	7759	5844	3	2004-08-22
2	7759	1595	1	2004-08-22
3	7759	9485	1	2004-08-22
4	7759	1274	2	2004-08-22
1	7760	9800	3	2004-08-12
2	7760	367	2	2004-08-12
3	7760	3296	3	2004-08-12
4	7760	4173	2	2004-08-12
5	7760	6495	3	2004-08-12
6	7760	506	1	2004-08-12
7	7760	6347	1	2004-08-12
1	7761	7640	1	2004-08-15
2	7761	4901	3	2004-08-15
3	7761	4962	2	2004-08-15
4	7761	326	2	2004-08-15
5	7761	8055	2	2004-08-15
6	7761	3277	1	2004-08-15
1	7762	7937	2	2004-08-04
2	7762	9857	1	2004-08-04
1	7763	7835	3	2004-08-31
1	7764	8969	3	2004-08-04
2	7764	733	2	2004-08-04
3	7764	8412	2	2004-08-04
4	7764	8255	3	2004-08-04
5	7764	1929	2	2004-08-04
6	7764	2897	2	2004-08-04
7	7764	6818	2	2004-08-04
8	7764	8281	3	2004-08-04
1	7765	8326	1	2004-08-17
2	7765	1568	1	2004-08-17
3	7765	622	3	2004-08-17
4	7765	8183	1	2004-08-17
5	7765	1988	3	2004-08-17
1	7766	4826	3	2004-08-31
1	7767	9390	3	2004-08-20
2	7767	3306	2	2004-08-20
3	7767	2886	1	2004-08-20
4	7767	3206	3	2004-08-20
5	7767	7803	2	2004-08-20
6	7767	3462	2	2004-08-20
7	7767	3977	2	2004-08-20
8	7767	6210	2	2004-08-20
1	7768	4112	2	2004-08-14
2	7768	7374	1	2004-08-14
3	7768	6562	1	2004-08-14
4	7768	317	1	2004-08-14
5	7768	5279	2	2004-08-14
6	7768	834	2	2004-08-14
1	7769	5726	2	2004-08-17
2	7769	6433	2	2004-08-17
3	7769	7763	3	2004-08-17
4	7769	9657	1	2004-08-17
5	7769	4923	2	2004-08-17
6	7769	6338	3	2004-08-17
7	7769	259	1	2004-08-17
8	7769	5770	2	2004-08-17
1	7770	5341	3	2004-08-28
2	7770	8056	1	2004-08-28
3	7770	4057	3	2004-08-28
4	7770	5288	3	2004-08-28
5	7770	3030	2	2004-08-28
1	7771	2284	3	2004-08-24
2	7771	3874	1	2004-08-24
3	7771	9746	3	2004-08-24
4	7771	7807	2	2004-08-24
1	7772	2436	3	2004-08-26
2	7772	7060	3	2004-08-26
3	7772	2845	1	2004-08-26
4	7772	7510	1	2004-08-26
1	7773	926	1	2004-08-10
2	7773	4471	3	2004-08-10
3	7773	1576	2	2004-08-10
4	7773	2453	2	2004-08-10
5	7773	2722	2	2004-08-10
6	7773	5800	1	2004-08-10
7	7773	5122	2	2004-08-10
8	7773	8552	1	2004-08-10
1	7774	4834	2	2004-08-06
2	7774	3921	3	2004-08-06
3	7774	6646	1	2004-08-06
4	7774	8580	3	2004-08-06
1	7775	1191	1	2004-08-10
2	7775	2396	1	2004-08-10
3	7775	7157	2	2004-08-10
4	7775	6625	3	2004-08-10
1	7776	6031	1	2004-08-04
2	7776	9566	3	2004-08-04
3	7776	8209	3	2004-08-04
4	7776	1809	1	2004-08-04
5	7776	998	2	2004-08-04
6	7776	722	3	2004-08-04
1	7777	7672	2	2004-08-23
1	7778	1628	2	2004-08-13
2	7778	1324	3	2004-08-13
3	7778	4756	1	2004-08-13
4	7778	677	3	2004-08-13
5	7778	8795	3	2004-08-13
6	7778	7999	3	2004-08-13
1	7779	9251	2	2004-08-14
2	7779	1947	3	2004-08-14
3	7779	3753	3	2004-08-14
4	7779	9273	1	2004-08-14
5	7779	9263	3	2004-08-14
6	7779	6338	2	2004-08-14
1	7780	8936	1	2004-08-18
2	7780	5684	2	2004-08-18
3	7780	3639	2	2004-08-18
4	7780	794	1	2004-08-18
5	7780	3067	3	2004-08-18
6	7780	793	3	2004-08-18
7	7780	5000	2	2004-08-18
1	7781	4222	2	2004-08-12
2	7781	4745	2	2004-08-12
3	7781	6826	2	2004-08-12
4	7781	437	1	2004-08-12
5	7781	7350	2	2004-08-12
6	7781	7222	3	2004-08-12
1	7782	9850	1	2004-08-12
2	7782	5718	1	2004-08-12
3	7782	4377	3	2004-08-12
4	7782	9436	2	2004-08-12
5	7782	6260	2	2004-08-12
6	7782	1074	3	2004-08-12
7	7782	8685	1	2004-08-12
8	7782	5592	1	2004-08-12
9	7782	8855	1	2004-08-12
1	7783	8844	1	2004-08-20
2	7783	3079	2	2004-08-20
3	7783	8859	3	2004-08-20
4	7783	2223	3	2004-08-20
5	7783	6110	1	2004-08-20
6	7783	9110	1	2004-08-20
7	7783	2716	2	2004-08-20
1	7784	6586	3	2004-08-02
2	7784	6823	2	2004-08-02
3	7784	2816	1	2004-08-02
4	7784	8177	1	2004-08-02
5	7784	2750	2	2004-08-02
6	7784	7350	3	2004-08-02
7	7784	1414	2	2004-08-02
1	7785	1245	2	2004-08-28
2	7785	4810	3	2004-08-28
3	7785	6553	2	2004-08-28
4	7785	9181	3	2004-08-28
5	7785	7405	3	2004-08-28
6	7785	1419	2	2004-08-28
7	7785	6662	3	2004-08-28
1	7786	5898	1	2004-08-18
2	7786	275	3	2004-08-18
3	7786	6029	3	2004-08-18
4	7786	5741	3	2004-08-18
5	7786	3817	2	2004-08-18
6	7786	1934	2	2004-08-18
7	7786	2171	1	2004-08-18
8	7786	556	3	2004-08-18
1	7787	6376	3	2004-08-02
2	7787	9503	3	2004-08-02
3	7787	4363	2	2004-08-02
4	7787	5798	1	2004-08-02
5	7787	9647	3	2004-08-02
6	7787	8756	2	2004-08-02
7	7787	525	3	2004-08-02
8	7787	4192	2	2004-08-02
9	7787	6654	3	2004-08-02
1	7788	6545	2	2004-08-13
2	7788	9108	3	2004-08-13
3	7788	3608	3	2004-08-13
4	7788	4208	2	2004-08-13
5	7788	9351	1	2004-08-13
6	7788	2809	3	2004-08-13
1	7789	7323	2	2004-08-26
2	7789	3248	2	2004-08-26
3	7789	207	2	2004-08-26
4	7789	5108	2	2004-08-26
1	7790	2231	3	2004-08-02
2	7790	250	3	2004-08-02
3	7790	5415	3	2004-08-02
4	7790	5876	3	2004-08-02
1	7791	667	2	2004-08-28
2	7791	7199	3	2004-08-28
3	7791	3506	1	2004-08-28
4	7791	3218	1	2004-08-28
5	7791	6878	2	2004-08-28
6	7791	6907	3	2004-08-28
7	7791	237	1	2004-08-28
8	7791	1483	1	2004-08-28
1	7792	4599	2	2004-08-12
2	7792	4781	1	2004-08-12
3	7792	4490	1	2004-08-12
4	7792	9034	2	2004-08-12
5	7792	740	1	2004-08-12
6	7792	1831	1	2004-08-12
1	7793	1244	2	2004-08-28
2	7793	3230	3	2004-08-28
3	7793	130	1	2004-08-28
1	7794	929	2	2004-08-17
2	7794	2499	2	2004-08-17
3	7794	1928	3	2004-08-17
4	7794	944	3	2004-08-17
5	7794	7110	2	2004-08-17
6	7794	7366	2	2004-08-17
7	7794	8918	3	2004-08-17
1	7795	9778	3	2004-08-27
2	7795	10000	1	2004-08-27
3	7795	3626	1	2004-08-27
4	7795	9143	2	2004-08-27
5	7795	3364	2	2004-08-27
6	7795	4122	2	2004-08-27
7	7795	1035	2	2004-08-27
1	7796	631	1	2004-08-05
2	7796	73	3	2004-08-05
3	7796	7237	3	2004-08-05
4	7796	3884	2	2004-08-05
1	7797	186	3	2004-08-18
2	7797	5014	1	2004-08-18
3	7797	7702	3	2004-08-18
4	7797	3414	3	2004-08-18
5	7797	2394	3	2004-08-18
1	7798	1566	2	2004-08-04
2	7798	5760	1	2004-08-04
3	7798	7089	2	2004-08-04
1	7799	4599	3	2004-08-14
2	7799	7621	1	2004-08-14
1	7800	1204	1	2004-08-02
1	7801	5749	1	2004-08-04
2	7801	1164	3	2004-08-04
3	7801	7757	2	2004-08-04
4	7801	9166	3	2004-08-04
1	7802	1315	2	2004-08-23
2	7802	1430	2	2004-08-23
3	7802	7444	2	2004-08-23
4	7802	3461	2	2004-08-23
1	7803	4851	1	2004-08-20
2	7803	1573	2	2004-08-20
1	7804	1661	1	2004-08-31
2	7804	2383	3	2004-08-31
3	7804	4827	1	2004-08-31
4	7804	8738	1	2004-08-31
5	7804	6473	1	2004-08-31
1	7805	3234	2	2004-08-20
2	7805	3734	3	2004-08-20
3	7805	8971	3	2004-08-20
4	7805	756	3	2004-08-20
5	7805	1267	2	2004-08-20
6	7805	9349	1	2004-08-20
7	7805	1429	3	2004-08-20
1	7806	3011	3	2004-08-11
2	7806	4335	3	2004-08-11
3	7806	8418	1	2004-08-11
4	7806	9845	2	2004-08-11
5	7806	3558	2	2004-08-11
1	7807	3927	3	2004-08-09
2	7807	2604	1	2004-08-09
3	7807	7461	2	2004-08-09
4	7807	1455	3	2004-08-09
5	7807	8966	1	2004-08-09
6	7807	1566	1	2004-08-09
1	7808	9743	2	2004-08-31
2	7808	1204	2	2004-08-31
3	7808	2880	3	2004-08-31
4	7808	7150	1	2004-08-31
1	7809	729	1	2004-08-14
2	7809	3098	2	2004-08-14
3	7809	226	2	2004-08-14
4	7809	7552	3	2004-08-14
5	7809	9061	3	2004-08-14
6	7809	6413	3	2004-08-14
7	7809	9811	3	2004-08-14
1	7810	3992	1	2004-08-27
1	7811	4816	2	2004-08-18
2	7811	1099	3	2004-08-18
3	7811	4479	3	2004-08-18
4	7811	6515	2	2004-08-18
5	7811	2611	3	2004-08-18
6	7811	9862	1	2004-08-18
7	7811	5313	3	2004-08-18
8	7811	523	2	2004-08-18
1	7812	4914	1	2004-08-20
2	7812	5888	3	2004-08-20
3	7812	1273	3	2004-08-20
4	7812	260	3	2004-08-20
5	7812	5074	3	2004-08-20
6	7812	5143	3	2004-08-20
1	7813	6184	2	2004-08-03
2	7813	339	3	2004-08-03
3	7813	5343	1	2004-08-03
4	7813	1631	1	2004-08-03
5	7813	7614	1	2004-08-03
1	7814	265	2	2004-08-16
2	7814	8250	2	2004-08-16
3	7814	1717	3	2004-08-16
4	7814	6032	1	2004-08-16
5	7814	6291	1	2004-08-16
6	7814	8859	1	2004-08-16
7	7814	995	3	2004-08-16
1	7815	5942	2	2004-08-24
2	7815	2652	1	2004-08-24
3	7815	5180	2	2004-08-24
4	7815	1939	1	2004-08-24
1	7816	4397	3	2004-08-20
2	7816	9524	1	2004-08-20
3	7816	3243	1	2004-08-20
4	7816	2168	3	2004-08-20
5	7816	3218	3	2004-08-20
1	7817	1587	3	2004-08-02
2	7817	1584	2	2004-08-02
1	7818	8809	2	2004-08-05
2	7818	8356	1	2004-08-05
3	7818	9182	2	2004-08-05
4	7818	7715	2	2004-08-05
1	7819	4757	2	2004-08-01
2	7819	1078	3	2004-08-01
3	7819	5614	2	2004-08-01
4	7819	5382	2	2004-08-01
5	7819	6371	2	2004-08-01
6	7819	7365	3	2004-08-01
7	7819	2837	3	2004-08-01
8	7819	4187	2	2004-08-01
9	7819	6474	2	2004-08-01
1	7820	6030	1	2004-08-26
2	7820	1478	2	2004-08-26
3	7820	6974	1	2004-08-26
4	7820	5855	1	2004-08-26
5	7820	1627	1	2004-08-26
6	7820	6413	1	2004-08-26
7	7820	7535	1	2004-08-26
1	7821	8188	2	2004-08-22
2	7821	1328	1	2004-08-22
3	7821	4332	2	2004-08-22
4	7821	5283	1	2004-08-22
1	7822	302	1	2004-08-03
2	7822	3659	1	2004-08-03
3	7822	5862	1	2004-08-03
1	7823	2327	3	2004-08-12
2	7823	7900	3	2004-08-12
3	7823	9142	2	2004-08-12
4	7823	2777	3	2004-08-12
5	7823	8269	1	2004-08-12
1	7824	5110	3	2004-08-08
2	7824	7680	2	2004-08-08
3	7824	886	2	2004-08-08
4	7824	8712	1	2004-08-08
5	7824	5886	1	2004-08-08
6	7824	2966	1	2004-08-08
7	7824	3002	2	2004-08-08
1	7825	821	3	2004-08-11
2	7825	5650	3	2004-08-11
3	7825	4528	3	2004-08-11
4	7825	7121	1	2004-08-11
5	7825	9392	3	2004-08-11
6	7825	2391	1	2004-08-11
1	7826	3519	3	2004-08-21
2	7826	7985	1	2004-08-21
3	7826	725	2	2004-08-21
4	7826	4600	2	2004-08-21
1	7827	1306	1	2004-08-18
2	7827	4868	1	2004-08-18
3	7827	1583	1	2004-08-18
4	7827	2088	2	2004-08-18
5	7827	8944	3	2004-08-18
6	7827	8906	3	2004-08-18
7	7827	8872	1	2004-08-18
8	7827	9716	2	2004-08-18
9	7827	8797	3	2004-08-18
1	7828	4545	3	2004-08-30
2	7828	1480	3	2004-08-30
3	7828	2321	3	2004-08-30
4	7828	6745	1	2004-08-30
5	7828	6174	3	2004-08-30
6	7828	4499	1	2004-08-30
7	7828	176	2	2004-08-30
1	7829	1471	1	2004-08-05
1	7830	5751	1	2004-08-28
2	7830	6920	2	2004-08-28
3	7830	3505	2	2004-08-28
4	7830	2987	3	2004-08-28
5	7830	3456	2	2004-08-28
6	7830	7193	2	2004-08-28
7	7830	1562	2	2004-08-28
8	7830	8320	3	2004-08-28
1	7831	8901	1	2004-08-07
2	7831	4425	1	2004-08-07
1	7832	6237	2	2004-08-03
2	7832	8227	1	2004-08-03
3	7832	5773	2	2004-08-03
4	7832	7364	3	2004-08-03
5	7832	9972	1	2004-08-03
6	7832	7327	2	2004-08-03
7	7832	4816	2	2004-08-03
8	7832	9202	2	2004-08-03
9	7832	8457	3	2004-08-03
1	7833	2605	3	2004-08-13
2	7833	3225	3	2004-08-13
3	7833	333	2	2004-08-13
1	7834	7104	1	2004-08-10
2	7834	1147	1	2004-08-10
3	7834	7107	3	2004-08-10
4	7834	2154	3	2004-08-10
5	7834	8860	3	2004-08-10
6	7834	505	2	2004-08-10
7	7834	4001	3	2004-08-10
8	7834	52	1	2004-08-10
9	7834	7229	2	2004-08-10
1	7835	6810	1	2004-08-09
2	7835	2534	3	2004-08-09
3	7835	4339	2	2004-08-09
4	7835	9663	3	2004-08-09
5	7835	4618	3	2004-08-09
1	7836	4274	1	2004-08-01
2	7836	4219	1	2004-08-01
3	7836	1277	2	2004-08-01
4	7836	6808	2	2004-08-01
5	7836	4431	3	2004-08-01
6	7836	7734	1	2004-08-01
7	7836	1024	1	2004-08-01
1	7837	8355	3	2004-08-29
2	7837	3180	1	2004-08-29
3	7837	4130	1	2004-08-29
4	7837	766	3	2004-08-29
5	7837	9609	1	2004-08-29
6	7837	4511	3	2004-08-29
1	7838	1917	1	2004-08-25
2	7838	6882	3	2004-08-25
1	7839	2971	2	2004-08-24
2	7839	5966	1	2004-08-24
3	7839	4686	1	2004-08-24
4	7839	8236	1	2004-08-24
5	7839	777	1	2004-08-24
1	7840	3653	2	2004-08-18
2	7840	7298	3	2004-08-18
3	7840	3116	2	2004-08-18
4	7840	6947	2	2004-08-18
5	7840	7395	3	2004-08-18
6	7840	6485	2	2004-08-18
1	7841	9418	3	2004-08-24
2	7841	9782	2	2004-08-24
3	7841	756	2	2004-08-24
1	7842	406	1	2004-08-24
2	7842	3170	2	2004-08-24
3	7842	9740	3	2004-08-24
4	7842	8527	3	2004-08-24
5	7842	4985	1	2004-08-24
6	7842	2274	1	2004-08-24
7	7842	5804	3	2004-08-24
8	7842	795	1	2004-08-24
1	7843	1556	2	2004-08-13
2	7843	8091	1	2004-08-13
3	7843	1174	3	2004-08-13
4	7843	5804	3	2004-08-13
5	7843	7837	1	2004-08-13
6	7843	6924	3	2004-08-13
7	7843	6552	1	2004-08-13
8	7843	2904	2	2004-08-13
9	7843	6915	1	2004-08-13
1	7844	3830	3	2004-08-11
2	7844	5270	2	2004-08-11
3	7844	1166	3	2004-08-11
4	7844	3007	3	2004-08-11
5	7844	8748	2	2004-08-11
6	7844	3329	3	2004-08-11
1	7845	3163	2	2004-08-19
2	7845	5013	1	2004-08-19
1	7846	7854	3	2004-08-06
2	7846	6096	1	2004-08-06
3	7846	8993	3	2004-08-06
4	7846	6782	1	2004-08-06
5	7846	8045	1	2004-08-06
1	7847	6748	1	2004-08-24
1	7848	4579	1	2004-08-16
1	7849	7828	3	2004-08-09
2	7849	9190	3	2004-08-09
3	7849	2480	3	2004-08-09
4	7849	5101	3	2004-08-09
5	7849	8224	2	2004-08-09
6	7849	7743	2	2004-08-09
7	7849	6915	2	2004-08-09
1	7850	4813	1	2004-08-22
2	7850	8333	3	2004-08-22
3	7850	1821	2	2004-08-22
4	7850	738	2	2004-08-22
5	7850	7716	2	2004-08-22
6	7850	4141	2	2004-08-22
7	7850	976	1	2004-08-22
8	7850	1582	1	2004-08-22
1	7851	2636	2	2004-08-31
2	7851	9169	1	2004-08-31
3	7851	436	2	2004-08-31
4	7851	6166	3	2004-08-31
5	7851	444	1	2004-08-31
1	7852	5082	2	2004-08-19
2	7852	9328	2	2004-08-19
3	7852	1125	3	2004-08-19
4	7852	9169	2	2004-08-19
1	7853	309	3	2004-08-03
2	7853	6452	3	2004-08-03
3	7853	2285	3	2004-08-03
1	7854	7537	2	2004-08-10
2	7854	874	3	2004-08-10
3	7854	6792	3	2004-08-10
4	7854	3237	3	2004-08-10
1	7855	4137	2	2004-08-03
1	7856	3450	3	2004-08-23
2	7856	402	2	2004-08-23
3	7856	5255	3	2004-08-23
4	7856	1275	3	2004-08-23
5	7856	5941	2	2004-08-23
6	7856	8993	2	2004-08-23
7	7856	7604	2	2004-08-23
8	7856	1036	3	2004-08-23
1	7857	7524	2	2004-08-14
2	7857	6064	1	2004-08-14
3	7857	6153	1	2004-08-14
4	7857	7493	2	2004-08-14
5	7857	3505	3	2004-08-14
6	7857	1364	3	2004-08-14
7	7857	6352	1	2004-08-14
1	7858	9145	2	2004-08-03
2	7858	6207	3	2004-08-03
1	7859	2288	3	2004-08-31
1	7860	3446	1	2004-08-28
2	7860	8296	3	2004-08-28
3	7860	3183	2	2004-08-28
4	7860	2951	3	2004-08-28
5	7860	4094	2	2004-08-28
6	7860	3641	1	2004-08-28
1	7861	6338	1	2004-08-19
2	7861	9258	1	2004-08-19
3	7861	9332	3	2004-08-19
4	7861	6356	2	2004-08-19
5	7861	223	3	2004-08-19
1	7862	5399	3	2004-08-10
1	7863	9484	1	2004-08-10
2	7863	2943	2	2004-08-10
3	7863	6402	2	2004-08-10
4	7863	4021	1	2004-08-10
5	7863	936	2	2004-08-10
6	7863	7180	3	2004-08-10
1	7864	5660	2	2004-08-23
2	7864	596	2	2004-08-23
3	7864	4817	2	2004-08-23
4	7864	4931	1	2004-08-23
5	7864	3859	1	2004-08-23
6	7864	450	3	2004-08-23
1	7865	1674	2	2004-08-13
2	7865	7084	3	2004-08-13
3	7865	2715	1	2004-08-13
4	7865	556	2	2004-08-13
1	7866	4173	1	2004-08-23
2	7866	1040	3	2004-08-23
3	7866	6916	1	2004-08-23
4	7866	5714	1	2004-08-23
1	7867	973	1	2004-08-17
2	7867	6193	2	2004-08-17
3	7867	2679	3	2004-08-17
4	7867	8504	2	2004-08-17
5	7867	5513	2	2004-08-17
6	7867	2427	3	2004-08-17
7	7867	6692	1	2004-08-17
8	7867	1878	2	2004-08-17
9	7867	718	1	2004-08-17
1	7868	4722	1	2004-08-26
2	7868	985	1	2004-08-26
3	7868	2190	2	2004-08-26
4	7868	1079	2	2004-08-26
5	7868	5648	1	2004-08-26
6	7868	7925	1	2004-08-26
7	7868	7049	1	2004-08-26
8	7868	1222	2	2004-08-26
9	7868	4955	3	2004-08-26
1	7869	364	3	2004-08-04
2	7869	1699	1	2004-08-04
3	7869	9639	1	2004-08-04
4	7869	5972	1	2004-08-04
5	7869	9357	1	2004-08-04
6	7869	3640	1	2004-08-04
7	7869	1129	2	2004-08-04
8	7869	6728	1	2004-08-04
1	7870	4215	1	2004-08-03
2	7870	9188	2	2004-08-03
3	7870	6860	2	2004-08-03
4	7870	2170	3	2004-08-03
5	7870	1524	3	2004-08-03
6	7870	5830	1	2004-08-03
7	7870	3969	3	2004-08-03
8	7870	2970	2	2004-08-03
1	7871	9635	1	2004-08-24
2	7871	7234	1	2004-08-24
3	7871	6256	2	2004-08-24
4	7871	2971	3	2004-08-24
5	7871	6337	3	2004-08-24
6	7871	5501	1	2004-08-24
7	7871	8537	2	2004-08-24
1	7872	3395	1	2004-08-19
2	7872	5287	3	2004-08-19
3	7872	2241	3	2004-08-19
4	7872	6753	2	2004-08-19
5	7872	2862	2	2004-08-19
6	7872	4151	3	2004-08-19
7	7872	1182	2	2004-08-19
8	7872	77	3	2004-08-19
1	7873	3249	3	2004-08-15
2	7873	4749	3	2004-08-15
3	7873	9265	1	2004-08-15
4	7873	3437	2	2004-08-15
5	7873	8682	1	2004-08-15
6	7873	3408	1	2004-08-15
7	7873	2620	3	2004-08-15
1	7874	71	1	2004-08-05
2	7874	2343	2	2004-08-05
3	7874	460	2	2004-08-05
4	7874	8007	1	2004-08-05
5	7874	1940	1	2004-08-05
6	7874	6869	2	2004-08-05
7	7874	73	1	2004-08-05
8	7874	3031	2	2004-08-05
1	7875	7548	3	2004-08-28
2	7875	4570	1	2004-08-28
3	7875	8864	3	2004-08-28
1	7876	8218	1	2004-08-30
2	7876	8408	1	2004-08-30
3	7876	6342	3	2004-08-30
4	7876	4085	2	2004-08-30
5	7876	9404	2	2004-08-30
6	7876	6902	2	2004-08-30
7	7876	342	3	2004-08-30
1	7877	5669	3	2004-08-20
2	7877	7559	1	2004-08-20
3	7877	6688	1	2004-08-20
4	7877	4172	2	2004-08-20
5	7877	9318	2	2004-08-20
1	7878	3488	3	2004-08-18
2	7878	4493	3	2004-08-18
3	7878	8695	3	2004-08-18
4	7878	4176	3	2004-08-18
1	7879	8052	1	2004-08-15
2	7879	8318	3	2004-08-15
3	7879	6015	2	2004-08-15
4	7879	9748	2	2004-08-15
5	7879	7202	2	2004-08-15
1	7880	5195	3	2004-08-18
2	7880	6387	2	2004-08-18
3	7880	1633	3	2004-08-18
4	7880	6441	2	2004-08-18
5	7880	9702	2	2004-08-18
1	7881	4956	3	2004-08-15
2	7881	4249	1	2004-08-15
3	7881	8362	1	2004-08-15
4	7881	2855	2	2004-08-15
5	7881	6552	1	2004-08-15
6	7881	7950	2	2004-08-15
7	7881	9038	2	2004-08-15
8	7881	5127	1	2004-08-15
9	7881	8671	1	2004-08-15
1	7882	4931	2	2004-08-28
1	7883	8510	1	2004-08-21
2	7883	487	2	2004-08-21
1	7884	7301	3	2004-08-29
2	7884	2084	2	2004-08-29
3	7884	1929	1	2004-08-29
4	7884	7606	1	2004-08-29
5	7884	3685	1	2004-08-29
6	7884	1989	1	2004-08-29
7	7884	3052	1	2004-08-29
1	7885	3361	3	2004-08-23
2	7885	6974	1	2004-08-23
3	7885	8728	2	2004-08-23
1	7886	3949	2	2004-08-12
2	7886	667	1	2004-08-12
3	7886	4749	1	2004-08-12
1	7887	7644	2	2004-08-16
2	7887	5439	3	2004-08-16
3	7887	8823	3	2004-08-16
1	7888	8575	1	2004-08-02
2	7888	8955	2	2004-08-02
1	7889	6897	3	2004-08-12
2	7889	280	1	2004-08-12
3	7889	5403	1	2004-08-12
4	7889	2096	1	2004-08-12
5	7889	3698	3	2004-08-12
6	7889	6829	2	2004-08-12
7	7889	9906	2	2004-08-12
1	7890	3835	2	2004-08-10
2	7890	8005	1	2004-08-10
1	7891	2128	3	2004-08-19
2	7891	2495	1	2004-08-19
3	7891	5174	3	2004-08-19
4	7891	3140	2	2004-08-19
5	7891	236	3	2004-08-19
1	7892	9529	2	2004-08-20
1	7893	4778	2	2004-08-21
2	7893	1296	3	2004-08-21
3	7893	8545	3	2004-08-21
4	7893	923	2	2004-08-21
5	7893	5880	2	2004-08-21
6	7893	9213	3	2004-08-21
7	7893	2923	1	2004-08-21
8	7893	1166	3	2004-08-21
9	7893	1098	2	2004-08-21
1	7894	3664	1	2004-08-11
2	7894	43	1	2004-08-11
3	7894	7062	2	2004-08-11
4	7894	2626	3	2004-08-11
5	7894	6145	3	2004-08-11
6	7894	1151	3	2004-08-11
7	7894	6015	3	2004-08-11
8	7894	6741	3	2004-08-11
9	7894	4096	1	2004-08-11
1	7895	5015	1	2004-08-07
2	7895	3024	2	2004-08-07
3	7895	6099	2	2004-08-07
4	7895	7445	3	2004-08-07
5	7895	6518	1	2004-08-07
1	7896	3180	3	2004-08-02
2	7896	4602	3	2004-08-02
3	7896	4329	2	2004-08-02
4	7896	6765	1	2004-08-02
5	7896	5447	2	2004-08-02
6	7896	7280	3	2004-08-02
7	7896	6125	3	2004-08-02
1	7897	8545	3	2004-08-09
2	7897	3978	2	2004-08-09
3	7897	3808	1	2004-08-09
4	7897	3589	1	2004-08-09
5	7897	2531	2	2004-08-09
6	7897	6886	3	2004-08-09
7	7897	1623	1	2004-08-09
8	7897	3757	2	2004-08-09
1	7898	8428	3	2004-08-30
2	7898	9659	2	2004-08-30
3	7898	6966	2	2004-08-30
4	7898	4993	3	2004-08-30
5	7898	2536	3	2004-08-30
6	7898	7681	1	2004-08-30
1	7899	3080	3	2004-08-20
1	7900	2442	2	2004-08-02
2	7900	7526	2	2004-08-02
3	7900	1234	3	2004-08-02
4	7900	4283	1	2004-08-02
5	7900	3069	1	2004-08-02
6	7900	634	1	2004-08-02
7	7900	8418	3	2004-08-02
1	7901	2617	2	2004-08-27
1	7902	9310	3	2004-08-07
2	7902	7159	3	2004-08-07
3	7902	5441	1	2004-08-07
4	7902	7346	3	2004-08-07
5	7902	5555	2	2004-08-07
6	7902	4081	3	2004-08-07
7	7902	1787	3	2004-08-07
8	7902	9999	2	2004-08-07
1	7903	8230	2	2004-08-04
2	7903	2902	2	2004-08-04
3	7903	7137	2	2004-08-04
4	7903	737	3	2004-08-04
5	7903	4577	3	2004-08-04
6	7903	7109	2	2004-08-04
7	7903	7318	2	2004-08-04
8	7903	3770	1	2004-08-04
9	7903	4813	1	2004-08-04
1	7904	7155	3	2004-08-02
2	7904	3086	3	2004-08-02
3	7904	2628	2	2004-08-02
4	7904	7785	1	2004-08-02
5	7904	3651	2	2004-08-02
1	7905	2070	1	2004-08-20
2	7905	2698	2	2004-08-20
3	7905	9882	3	2004-08-20
4	7905	532	3	2004-08-20
1	7906	5417	1	2004-08-13
2	7906	9253	1	2004-08-13
3	7906	5321	2	2004-08-13
4	7906	9177	3	2004-08-13
5	7906	3561	1	2004-08-13
6	7906	2565	1	2004-08-13
7	7906	2012	2	2004-08-13
8	7906	7360	3	2004-08-13
1	7907	1411	2	2004-08-09
2	7907	1483	1	2004-08-09
3	7907	4253	1	2004-08-09
4	7907	8491	3	2004-08-09
5	7907	6316	3	2004-08-09
1	7908	3136	2	2004-08-23
2	7908	2872	1	2004-08-23
3	7908	2774	2	2004-08-23
4	7908	4115	2	2004-08-23
5	7908	7778	2	2004-08-23
6	7908	1553	2	2004-08-23
1	7909	9157	2	2004-08-14
2	7909	631	1	2004-08-14
3	7909	6855	2	2004-08-14
4	7909	2653	2	2004-08-14
5	7909	3209	3	2004-08-14
6	7909	3794	1	2004-08-14
1	7910	7209	3	2004-08-03
2	7910	6146	3	2004-08-03
3	7910	6190	1	2004-08-03
4	7910	5320	2	2004-08-03
1	7911	1193	1	2004-08-20
1	7912	988	2	2004-08-22
2	7912	2521	2	2004-08-22
3	7912	1019	2	2004-08-22
4	7912	2607	2	2004-08-22
5	7912	6150	1	2004-08-22
6	7912	7654	1	2004-08-22
7	7912	7140	2	2004-08-22
1	7913	3545	1	2004-08-09
2	7913	2948	3	2004-08-09
3	7913	7037	1	2004-08-09
4	7913	753	3	2004-08-09
5	7913	5306	3	2004-08-09
6	7913	8578	2	2004-08-09
7	7913	5399	3	2004-08-09
8	7913	9798	3	2004-08-09
9	7913	3205	1	2004-08-09
1	7914	9116	1	2004-08-12
2	7914	2833	2	2004-08-12
3	7914	8144	2	2004-08-12
4	7914	9540	1	2004-08-12
5	7914	4607	1	2004-08-12
6	7914	3152	3	2004-08-12
7	7914	3014	1	2004-08-12
8	7914	9603	2	2004-08-12
9	7914	8417	2	2004-08-12
1	7915	6560	3	2004-08-05
2	7915	4844	3	2004-08-05
3	7915	9647	3	2004-08-05
4	7915	5574	2	2004-08-05
5	7915	8289	2	2004-08-05
6	7915	8558	1	2004-08-05
7	7915	945	3	2004-08-05
1	7916	3568	1	2004-08-21
2	7916	8907	2	2004-08-21
1	7917	3418	1	2004-08-10
2	7917	8440	1	2004-08-10
1	7918	4763	1	2004-08-28
2	7918	2132	1	2004-08-28
3	7918	6203	1	2004-08-28
4	7918	5026	2	2004-08-28
1	7919	6455	1	2004-08-05
2	7919	9642	1	2004-08-05
3	7919	3992	3	2004-08-05
4	7919	6603	3	2004-08-05
5	7919	7057	3	2004-08-05
6	7919	8466	1	2004-08-05
7	7919	8822	3	2004-08-05
8	7919	2924	3	2004-08-05
1	7920	5130	2	2004-08-06
2	7920	7004	1	2004-08-06
3	7920	3811	1	2004-08-06
4	7920	6092	2	2004-08-06
5	7920	8000	3	2004-08-06
6	7920	3641	2	2004-08-06
7	7920	8705	1	2004-08-06
1	7921	9716	3	2004-08-14
1	7922	5087	1	2004-08-25
2	7922	4466	3	2004-08-25
3	7922	6486	2	2004-08-25
4	7922	3658	1	2004-08-25
5	7922	9116	1	2004-08-25
6	7922	2947	1	2004-08-25
7	7922	2690	3	2004-08-25
1	7923	5142	2	2004-08-26
2	7923	5202	3	2004-08-26
1	7924	5918	3	2004-08-25
2	7924	5888	2	2004-08-25
3	7924	5566	1	2004-08-25
4	7924	7560	1	2004-08-25
5	7924	7965	2	2004-08-25
6	7924	5756	1	2004-08-25
7	7924	5660	2	2004-08-25
1	7925	7644	2	2004-08-08
2	7925	5661	2	2004-08-08
3	7925	7996	1	2004-08-08
4	7925	9529	1	2004-08-08
5	7925	419	3	2004-08-08
1	7926	9831	1	2004-08-01
2	7926	1424	2	2004-08-01
3	7926	2088	3	2004-08-01
4	7926	5427	1	2004-08-01
5	7926	3028	1	2004-08-01
6	7926	1674	3	2004-08-01
1	7927	8929	2	2004-08-19
2	7927	9927	2	2004-08-19
3	7927	9172	3	2004-08-19
4	7927	5393	3	2004-08-19
1	7928	6924	1	2004-08-04
2	7928	7495	3	2004-08-04
1	7929	7901	3	2004-08-08
2	7929	4698	1	2004-08-08
3	7929	8760	2	2004-08-08
4	7929	9616	2	2004-08-08
5	7929	328	3	2004-08-08
1	7930	3847	1	2004-08-27
2	7930	6514	3	2004-08-27
3	7930	9720	3	2004-08-27
4	7930	5050	2	2004-08-27
5	7930	8982	1	2004-08-27
6	7930	7385	2	2004-08-27
7	7930	8727	3	2004-08-27
8	7930	5393	1	2004-08-27
1	7931	4221	3	2004-08-15
2	7931	5657	2	2004-08-15
3	7931	2026	2	2004-08-15
4	7931	747	1	2004-08-15
5	7931	5241	1	2004-08-15
6	7931	9282	3	2004-08-15
7	7931	3613	2	2004-08-15
8	7931	8326	1	2004-08-15
9	7931	3428	2	2004-08-15
1	7932	8885	2	2004-08-29
2	7932	6600	2	2004-08-29
3	7932	4951	1	2004-08-29
4	7932	7571	2	2004-08-29
5	7932	474	1	2004-08-29
6	7932	617	2	2004-08-29
1	7933	3332	3	2004-08-18
2	7933	8969	1	2004-08-18
3	7933	6443	1	2004-08-18
4	7933	8408	2	2004-08-18
5	7933	5914	1	2004-08-18
6	7933	8143	2	2004-08-18
1	7934	7565	3	2004-08-14
2	7934	7406	1	2004-08-14
3	7934	9631	2	2004-08-14
1	7935	6234	1	2004-08-19
2	7935	9178	3	2004-08-19
3	7935	8771	1	2004-08-19
4	7935	5703	3	2004-08-19
5	7935	5122	1	2004-08-19
6	7935	320	2	2004-08-19
1	7936	1420	3	2004-08-22
2	7936	8545	1	2004-08-22
3	7936	2737	2	2004-08-22
4	7936	1705	1	2004-08-22
5	7936	8625	1	2004-08-22
1	7937	1080	3	2004-08-16
2	7937	4283	1	2004-08-16
1	7938	792	3	2004-08-19
2	7938	3868	1	2004-08-19
1	7939	5834	3	2004-08-05
2	7939	6390	2	2004-08-05
3	7939	2027	3	2004-08-05
4	7939	489	2	2004-08-05
5	7939	9268	3	2004-08-05
6	7939	5067	2	2004-08-05
7	7939	3658	2	2004-08-05
1	7940	4995	1	2004-08-20
1	7941	5649	2	2004-08-12
2	7941	5510	3	2004-08-12
3	7941	6568	1	2004-08-12
4	7941	3847	1	2004-08-12
1	7942	9362	3	2004-08-06
2	7942	7377	3	2004-08-06
3	7942	6382	1	2004-08-06
4	7942	3015	1	2004-08-06
1	7943	9842	3	2004-08-28
2	7943	3325	2	2004-08-28
3	7943	7531	2	2004-08-28
1	7944	246	3	2004-08-25
2	7944	6210	2	2004-08-25
3	7944	2	3	2004-08-25
4	7944	4328	3	2004-08-25
1	7945	2318	1	2004-08-05
2	7945	1293	2	2004-08-05
3	7945	470	1	2004-08-05
4	7945	4620	2	2004-08-05
5	7945	3367	2	2004-08-05
6	7945	5016	3	2004-08-05
7	7945	7911	1	2004-08-05
8	7945	1937	2	2004-08-05
1	7946	570	2	2004-08-18
2	7946	64	1	2004-08-18
3	7946	3152	2	2004-08-18
4	7946	7353	2	2004-08-18
5	7946	8081	1	2004-08-18
6	7946	3475	1	2004-08-18
1	7947	5008	1	2004-08-06
2	7947	7549	3	2004-08-06
3	7947	4812	1	2004-08-06
1	7948	8480	1	2004-08-16
2	7948	9971	3	2004-08-16
3	7948	6810	1	2004-08-16
4	7948	2916	3	2004-08-16
5	7948	1112	2	2004-08-16
6	7948	1264	3	2004-08-16
7	7948	692	3	2004-08-16
1	7949	8933	2	2004-08-31
2	7949	4003	2	2004-08-31
1	7950	4117	3	2004-08-19
1	7951	66	2	2004-08-11
2	7951	9427	3	2004-08-11
1	7952	8410	2	2004-08-16
2	7952	4468	3	2004-08-16
3	7952	4355	2	2004-08-16
4	7952	3268	2	2004-08-16
5	7952	6034	1	2004-08-16
6	7952	9568	1	2004-08-16
1	7953	6023	2	2004-08-20
2	7953	5835	3	2004-08-20
3	7953	4931	1	2004-08-20
4	7953	1212	2	2004-08-20
5	7953	4568	1	2004-08-20
6	7953	1871	3	2004-08-20
7	7953	2981	2	2004-08-20
8	7953	5465	1	2004-08-20
1	7954	4267	2	2004-08-02
2	7954	9080	1	2004-08-02
3	7954	5960	3	2004-08-02
4	7954	335	1	2004-08-02
5	7954	4036	1	2004-08-02
1	7955	9435	1	2004-08-02
2	7955	6604	1	2004-08-02
3	7955	7552	1	2004-08-02
4	7955	1285	3	2004-08-02
5	7955	633	2	2004-08-02
6	7955	5041	2	2004-08-02
1	7956	654	1	2004-08-18
2	7956	9909	3	2004-08-18
3	7956	595	2	2004-08-18
4	7956	8380	1	2004-08-18
5	7956	7968	1	2004-08-18
6	7956	2852	3	2004-08-18
1	7957	3032	1	2004-08-08
2	7957	2554	1	2004-08-08
1	7958	8104	2	2004-08-09
2	7958	9416	2	2004-08-09
3	7958	718	2	2004-08-09
1	7959	1104	2	2004-08-31
2	7959	5685	3	2004-08-31
3	7959	7263	2	2004-08-31
4	7959	1898	1	2004-08-31
5	7959	2175	2	2004-08-31
6	7959	591	3	2004-08-31
7	7959	6277	2	2004-08-31
8	7959	8600	3	2004-08-31
9	7959	4206	1	2004-08-31
1	7960	9260	2	2004-08-09
1	7961	1349	2	2004-08-15
2	7961	4257	1	2004-08-15
3	7961	1536	3	2004-08-15
4	7961	1936	3	2004-08-15
1	7962	8203	3	2004-08-12
2	7962	2854	2	2004-08-12
3	7962	3125	1	2004-08-12
4	7962	3310	3	2004-08-12
5	7962	2739	2	2004-08-12
6	7962	1544	3	2004-08-12
1	7963	781	1	2004-08-21
2	7963	5720	1	2004-08-21
1	7964	9918	2	2004-08-19
2	7964	6359	2	2004-08-19
3	7964	349	2	2004-08-19
4	7964	9282	3	2004-08-19
5	7964	4774	1	2004-08-19
6	7964	3032	3	2004-08-19
7	7964	3589	2	2004-08-19
1	7965	3668	3	2004-08-17
2	7965	7576	2	2004-08-17
3	7965	346	3	2004-08-17
4	7965	5850	2	2004-08-17
5	7965	485	1	2004-08-17
6	7965	6042	2	2004-08-17
7	7965	9435	2	2004-08-17
1	7966	1064	3	2004-08-05
2	7966	481	2	2004-08-05
1	7967	9852	3	2004-08-03
2	7967	803	1	2004-08-03
3	7967	5738	2	2004-08-03
4	7967	1236	1	2004-08-03
5	7967	9498	1	2004-08-03
1	7968	7223	2	2004-08-06
2	7968	7218	2	2004-08-06
1	7969	727	2	2004-08-30
2	7969	7873	1	2004-08-30
3	7969	9349	3	2004-08-30
4	7969	4719	1	2004-08-30
5	7969	3237	2	2004-08-30
6	7969	2049	2	2004-08-30
7	7969	6740	3	2004-08-30
8	7969	8510	3	2004-08-30
9	7969	1100	3	2004-08-30
1	7970	4921	1	2004-08-30
2	7970	891	1	2004-08-30
3	7970	7234	1	2004-08-30
4	7970	935	3	2004-08-30
5	7970	9658	1	2004-08-30
6	7970	3195	3	2004-08-30
7	7970	2868	1	2004-08-30
1	7971	2156	3	2004-08-20
2	7971	3567	3	2004-08-20
3	7971	5462	1	2004-08-20
4	7971	6871	2	2004-08-20
5	7971	84	2	2004-08-20
6	7971	9329	2	2004-08-20
7	7971	3629	2	2004-08-20
8	7971	4017	2	2004-08-20
9	7971	6388	1	2004-08-20
1	7972	8984	2	2004-08-16
2	7972	2246	1	2004-08-16
3	7972	6670	3	2004-08-16
4	7972	9437	1	2004-08-16
5	7972	8064	1	2004-08-16
1	7973	3707	3	2004-08-31
2	7973	1995	2	2004-08-31
3	7973	3784	1	2004-08-31
4	7973	7230	3	2004-08-31
5	7973	5573	1	2004-08-31
1	7974	9282	2	2004-08-06
2	7974	1707	3	2004-08-06
3	7974	7556	2	2004-08-06
4	7974	116	2	2004-08-06
5	7974	2490	3	2004-08-06
6	7974	6521	1	2004-08-06
7	7974	1146	2	2004-08-06
1	7975	8991	2	2004-08-07
2	7975	9679	1	2004-08-07
3	7975	5243	3	2004-08-07
4	7975	188	1	2004-08-07
5	7975	8154	1	2004-08-07
6	7975	2776	1	2004-08-07
1	7976	322	1	2004-08-29
1	7977	9991	1	2004-08-15
2	7977	7812	1	2004-08-15
3	7977	8873	3	2004-08-15
4	7977	2769	1	2004-08-15
5	7977	5883	1	2004-08-15
6	7977	4717	2	2004-08-15
7	7977	4533	3	2004-08-15
1	7978	6840	2	2004-08-08
1	7979	6768	2	2004-08-04
2	7979	6985	1	2004-08-04
3	7979	6368	1	2004-08-04
4	7979	8797	2	2004-08-04
5	7979	5225	2	2004-08-04
1	7980	4894	1	2004-08-24
1	7981	9571	1	2004-08-07
2	7981	1274	1	2004-08-07
3	7981	1136	3	2004-08-07
4	7981	3897	1	2004-08-07
5	7981	4064	3	2004-08-07
6	7981	7758	1	2004-08-07
1	7982	7586	1	2004-08-17
2	7982	8160	1	2004-08-17
1	7983	5915	1	2004-08-25
2	7983	6860	3	2004-08-25
3	7983	1411	2	2004-08-25
4	7983	4488	1	2004-08-25
1	7984	3874	2	2004-08-17
2	7984	8960	3	2004-08-17
3	7984	4728	3	2004-08-17
4	7984	8768	1	2004-08-17
5	7984	1459	1	2004-08-17
6	7984	1963	3	2004-08-17
1	7985	5775	3	2004-08-08
1	7986	9623	1	2004-08-14
2	7986	6213	2	2004-08-14
1	7987	8183	2	2004-08-10
2	7987	9501	3	2004-08-10
3	7987	1681	2	2004-08-10
4	7987	3859	1	2004-08-10
1	7988	4362	2	2004-08-14
2	7988	6475	2	2004-08-14
3	7988	3960	1	2004-08-14
4	7988	4977	3	2004-08-14
5	7988	3938	2	2004-08-14
6	7988	9717	2	2004-08-14
1	7989	7560	3	2004-08-24
1	7990	2885	1	2004-08-15
2	7990	8464	3	2004-08-15
3	7990	3413	1	2004-08-15
4	7990	2060	2	2004-08-15
1	7991	2636	1	2004-08-29
2	7991	7928	3	2004-08-29
3	7991	1250	1	2004-08-29
4	7991	3149	1	2004-08-29
5	7991	5426	1	2004-08-29
6	7991	6897	1	2004-08-29
1	7992	198	1	2004-08-04
2	7992	84	1	2004-08-04
3	7992	4887	3	2004-08-04
4	7992	9825	3	2004-08-04
5	7992	1399	1	2004-08-04
6	7992	3296	1	2004-08-04
1	7993	5019	2	2004-08-26
1	7994	7235	1	2004-08-27
2	7994	2355	2	2004-08-27
1	7995	9315	3	2004-08-15
2	7995	7152	3	2004-08-15
3	7995	1867	1	2004-08-15
4	7995	7945	1	2004-08-15
5	7995	337	3	2004-08-15
1	7996	5811	2	2004-08-12
2	7996	2817	1	2004-08-12
1	7997	3067	2	2004-08-02
2	7997	8006	2	2004-08-02
3	7997	8464	1	2004-08-02
4	7997	8889	3	2004-08-02
5	7997	7830	3	2004-08-02
6	7997	5835	2	2004-08-02
1	7998	9391	3	2004-08-24
2	7998	4890	1	2004-08-24
3	7998	990	2	2004-08-24
4	7998	4841	3	2004-08-24
5	7998	1062	3	2004-08-24
1	7999	8004	1	2004-08-24
2	7999	9058	2	2004-08-24
3	7999	7513	3	2004-08-24
4	7999	8609	2	2004-08-24
5	7999	4571	2	2004-08-24
1	8000	8105	3	2004-08-15
2	8000	7752	3	2004-08-15
1	8001	1376	1	2004-09-12
2	8001	9981	3	2004-09-12
3	8001	7410	3	2004-09-12
4	8001	2277	2	2004-09-12
5	8001	8945	1	2004-09-12
6	8001	4272	2	2004-09-12
1	8002	1626	2	2004-09-05
2	8002	6797	1	2004-09-05
3	8002	6441	2	2004-09-05
4	8002	1167	1	2004-09-05
5	8002	6650	3	2004-09-05
6	8002	4377	1	2004-09-05
1	8003	6876	3	2004-09-10
2	8003	4152	2	2004-09-10
3	8003	6419	2	2004-09-10
4	8003	8159	2	2004-09-10
5	8003	9010	1	2004-09-10
1	8004	7065	2	2004-09-05
2	8004	134	2	2004-09-05
3	8004	5371	2	2004-09-05
4	8004	9794	2	2004-09-05
5	8004	7818	2	2004-09-05
1	8005	6185	2	2004-09-15
2	8005	2537	1	2004-09-15
3	8005	822	3	2004-09-15
4	8005	7345	3	2004-09-15
5	8005	3118	2	2004-09-15
6	8005	2603	1	2004-09-15
7	8005	7933	2	2004-09-15
8	8005	2640	1	2004-09-15
1	8006	3566	1	2004-09-29
2	8006	6346	2	2004-09-29
3	8006	7362	2	2004-09-29
4	8006	9801	1	2004-09-29
5	8006	6358	2	2004-09-29
6	8006	99	1	2004-09-29
7	8006	484	1	2004-09-29
8	8006	5601	1	2004-09-29
9	8006	9324	1	2004-09-29
1	8007	4568	2	2004-09-26
2	8007	5267	3	2004-09-26
1	8008	4678	1	2004-09-22
2	8008	3542	1	2004-09-22
3	8008	3835	1	2004-09-22
1	8009	278	1	2004-09-16
2	8009	4086	1	2004-09-16
1	8010	2632	1	2004-09-18
2	8010	7534	1	2004-09-18
3	8010	1756	1	2004-09-18
4	8010	7460	3	2004-09-18
5	8010	9309	2	2004-09-18
1	8011	6695	1	2004-09-06
2	8011	7628	1	2004-09-06
3	8011	1881	1	2004-09-06
4	8011	4165	2	2004-09-06
5	8011	4359	2	2004-09-06
6	8011	8050	3	2004-09-06
1	8012	8910	1	2004-09-16
2	8012	7877	2	2004-09-16
3	8012	1842	3	2004-09-16
4	8012	8545	3	2004-09-16
5	8012	6654	3	2004-09-16
6	8012	4021	3	2004-09-16
7	8012	4072	1	2004-09-16
1	8013	1296	2	2004-09-16
2	8013	5627	2	2004-09-16
3	8013	9230	3	2004-09-16
1	8014	1097	2	2004-09-30
2	8014	2373	1	2004-09-30
3	8014	7322	1	2004-09-30
4	8014	6450	3	2004-09-30
5	8014	9881	2	2004-09-30
1	8015	5115	3	2004-09-26
2	8015	3941	1	2004-09-26
3	8015	7684	2	2004-09-26
1	8016	4439	3	2004-09-10
2	8016	8723	2	2004-09-10
3	8016	7198	3	2004-09-10
4	8016	9447	3	2004-09-10
5	8016	3710	1	2004-09-10
6	8016	8302	1	2004-09-10
7	8016	2069	2	2004-09-10
8	8016	193	1	2004-09-10
1	8017	1141	2	2004-09-30
2	8017	9509	2	2004-09-30
3	8017	3896	3	2004-09-30
1	8018	5744	1	2004-09-05
2	8018	2062	2	2004-09-05
1	8019	7554	2	2004-09-15
2	8019	6215	2	2004-09-15
3	8019	6357	3	2004-09-15
4	8019	607	2	2004-09-15
1	8020	2943	2	2004-09-01
2	8020	2310	1	2004-09-01
3	8020	1427	2	2004-09-01
4	8020	9643	1	2004-09-01
5	8020	3212	2	2004-09-01
6	8020	5026	3	2004-09-01
7	8020	6422	3	2004-09-01
8	8020	3422	1	2004-09-01
1	8021	364	1	2004-09-20
2	8021	9757	3	2004-09-20
3	8021	264	1	2004-09-20
4	8021	3269	1	2004-09-20
1	8022	4820	1	2004-09-03
2	8022	6107	2	2004-09-03
3	8022	7724	2	2004-09-03
4	8022	9129	1	2004-09-03
1	8023	1242	1	2004-09-05
2	8023	9354	3	2004-09-05
3	8023	8349	2	2004-09-05
4	8023	1490	3	2004-09-05
5	8023	7101	1	2004-09-05
6	8023	5431	3	2004-09-05
7	8023	1609	3	2004-09-05
8	8023	7860	1	2004-09-05
1	8024	8588	1	2004-09-22
2	8024	8238	2	2004-09-22
1	8025	1520	3	2004-09-24
2	8025	7379	1	2004-09-24
3	8025	445	3	2004-09-24
4	8025	350	3	2004-09-24
5	8025	1852	1	2004-09-24
6	8025	7505	3	2004-09-24
7	8025	3086	1	2004-09-24
8	8025	6317	2	2004-09-24
9	8025	1634	2	2004-09-24
1	8026	798	3	2004-09-22
2	8026	5081	3	2004-09-22
3	8026	6143	1	2004-09-22
1	8027	522	3	2004-09-20
2	8027	681	1	2004-09-20
3	8027	6422	1	2004-09-20
4	8027	9760	3	2004-09-20
5	8027	2871	3	2004-09-20
6	8027	7226	2	2004-09-20
7	8027	200	2	2004-09-20
8	8027	652	1	2004-09-20
1	8028	664	1	2004-09-24
2	8028	8796	2	2004-09-24
3	8028	472	2	2004-09-24
4	8028	8660	3	2004-09-24
5	8028	8326	1	2004-09-24
6	8028	4792	3	2004-09-24
7	8028	661	2	2004-09-24
8	8028	9815	3	2004-09-24
9	8028	6504	3	2004-09-24
1	8029	5331	3	2004-09-17
2	8029	6124	2	2004-09-17
3	8029	8871	2	2004-09-17
1	8030	946	1	2004-09-11
2	8030	58	1	2004-09-11
3	8030	6540	3	2004-09-11
4	8030	8289	2	2004-09-11
1	8031	8554	2	2004-09-30
1	8032	4431	3	2004-09-23
2	8032	5369	3	2004-09-23
3	8032	6980	1	2004-09-23
1	8033	5360	3	2004-09-18
2	8033	3705	2	2004-09-18
3	8033	9741	2	2004-09-18
4	8033	7722	2	2004-09-18
5	8033	2480	2	2004-09-18
6	8033	1146	1	2004-09-18
7	8033	9092	2	2004-09-18
8	8033	2519	3	2004-09-18
9	8033	8387	3	2004-09-18
1	8034	1431	3	2004-09-09
2	8034	6894	3	2004-09-09
3	8034	9600	1	2004-09-09
4	8034	4260	2	2004-09-09
5	8034	2028	3	2004-09-09
6	8034	3073	2	2004-09-09
7	8034	5924	1	2004-09-09
1	8035	9657	1	2004-09-29
2	8035	4144	3	2004-09-29
1	8036	6612	3	2004-09-16
2	8036	4974	3	2004-09-16
3	8036	6228	2	2004-09-16
4	8036	7458	1	2004-09-16
1	8037	1990	3	2004-09-15
2	8037	8692	2	2004-09-15
3	8037	3518	2	2004-09-15
4	8037	7875	1	2004-09-15
5	8037	8260	3	2004-09-15
6	8037	4988	3	2004-09-15
7	8037	7207	3	2004-09-15
8	8037	6665	1	2004-09-15
9	8037	5793	1	2004-09-15
1	8038	1755	3	2004-09-18
1	8039	6269	3	2004-09-22
2	8039	1052	3	2004-09-22
1	8040	4357	1	2004-09-16
2	8040	1574	1	2004-09-16
3	8040	8162	2	2004-09-16
4	8040	534	2	2004-09-16
5	8040	5692	3	2004-09-16
6	8040	7673	1	2004-09-16
7	8040	255	2	2004-09-16
8	8040	3889	1	2004-09-16
1	8041	4855	1	2004-09-13
2	8041	3367	1	2004-09-13
1	8042	4161	1	2004-09-29
2	8042	3150	3	2004-09-29
3	8042	3894	2	2004-09-29
4	8042	1135	1	2004-09-29
5	8042	1285	1	2004-09-29
1	8043	8461	3	2004-09-23
2	8043	8557	1	2004-09-23
3	8043	1527	1	2004-09-23
4	8043	7993	1	2004-09-23
5	8043	4168	1	2004-09-23
1	8044	1953	2	2004-09-14
2	8044	8737	2	2004-09-14
3	8044	6051	1	2004-09-14
4	8044	4631	3	2004-09-14
1	8045	7434	3	2004-09-20
2	8045	4870	2	2004-09-20
3	8045	4520	1	2004-09-20
4	8045	5418	1	2004-09-20
5	8045	5679	3	2004-09-20
6	8045	5856	2	2004-09-20
7	8045	9257	1	2004-09-20
8	8045	6518	2	2004-09-20
1	8046	3839	3	2004-09-23
2	8046	5622	3	2004-09-23
3	8046	8627	1	2004-09-23
4	8046	9833	2	2004-09-23
5	8046	6019	1	2004-09-23
6	8046	3130	2	2004-09-23
7	8046	1256	3	2004-09-23
8	8046	9750	2	2004-09-23
9	8046	1328	2	2004-09-23
1	8047	677	1	2004-09-27
2	8047	4731	3	2004-09-27
3	8047	5226	1	2004-09-27
4	8047	7683	1	2004-09-27
5	8047	1796	1	2004-09-27
1	8048	7671	1	2004-09-30
2	8048	3833	2	2004-09-30
3	8048	3074	3	2004-09-30
4	8048	7141	2	2004-09-30
5	8048	4960	3	2004-09-30
6	8048	106	2	2004-09-30
7	8048	2058	3	2004-09-30
8	8048	3294	2	2004-09-30
1	8049	1166	1	2004-09-11
2	8049	683	3	2004-09-11
3	8049	3993	1	2004-09-11
4	8049	369	2	2004-09-11
5	8049	9896	1	2004-09-11
6	8049	2561	3	2004-09-11
7	8049	3020	2	2004-09-11
8	8049	1256	2	2004-09-11
1	8050	5286	1	2004-09-11
2	8050	4602	3	2004-09-11
3	8050	9486	3	2004-09-11
4	8050	1513	1	2004-09-11
5	8050	1867	3	2004-09-11
6	8050	1546	1	2004-09-11
7	8050	7813	1	2004-09-11
8	8050	1880	1	2004-09-11
1	8051	4026	3	2004-09-15
2	8051	2168	3	2004-09-15
3	8051	4722	2	2004-09-15
4	8051	3139	3	2004-09-15
5	8051	1819	2	2004-09-15
1	8052	4448	2	2004-09-20
1	8053	3010	3	2004-09-27
1	8054	2628	2	2004-09-12
2	8054	7913	3	2004-09-12
3	8054	9807	1	2004-09-12
4	8054	6725	1	2004-09-12
5	8054	8983	1	2004-09-12
6	8054	5397	1	2004-09-12
1	8055	4320	3	2004-09-29
2	8055	6905	3	2004-09-29
3	8055	3347	2	2004-09-29
4	8055	4728	1	2004-09-29
5	8055	6546	3	2004-09-29
6	8055	8344	1	2004-09-29
1	8056	4048	2	2004-09-26
2	8056	9583	2	2004-09-26
1	8057	7753	1	2004-09-18
2	8057	6950	3	2004-09-18
3	8057	8440	1	2004-09-18
4	8057	3187	1	2004-09-18
5	8057	2404	1	2004-09-18
1	8058	5823	1	2004-09-05
2	8058	3991	2	2004-09-05
3	8058	2759	1	2004-09-05
4	8058	3009	3	2004-09-05
5	8058	3736	3	2004-09-05
6	8058	2663	1	2004-09-05
1	8059	3338	3	2004-09-03
2	8059	7960	1	2004-09-03
3	8059	4652	2	2004-09-03
4	8059	2920	3	2004-09-03
5	8059	9158	2	2004-09-03
6	8059	7928	1	2004-09-03
7	8059	1075	2	2004-09-03
1	8060	1063	3	2004-09-21
1	8061	1127	1	2004-09-11
2	8061	530	1	2004-09-11
3	8061	8921	1	2004-09-11
4	8061	8771	1	2004-09-11
5	8061	7531	3	2004-09-11
6	8061	2546	1	2004-09-11
7	8061	3129	2	2004-09-11
1	8062	2969	1	2004-09-01
2	8062	1756	3	2004-09-01
3	8062	8761	3	2004-09-01
4	8062	830	3	2004-09-01
5	8062	6988	2	2004-09-01
6	8062	3895	2	2004-09-01
7	8062	1517	2	2004-09-01
8	8062	5150	1	2004-09-01
1	8063	6329	3	2004-09-22
2	8063	2556	3	2004-09-22
3	8063	1913	2	2004-09-22
4	8063	4341	1	2004-09-22
5	8063	7970	2	2004-09-22
6	8063	9878	1	2004-09-22
1	8064	9626	1	2004-09-21
2	8064	5579	2	2004-09-21
3	8064	5978	3	2004-09-21
4	8064	1351	3	2004-09-21
5	8064	4494	2	2004-09-21
6	8064	9540	1	2004-09-21
1	8065	1470	3	2004-09-02
2	8065	5774	2	2004-09-02
3	8065	5615	1	2004-09-02
4	8065	5313	2	2004-09-02
5	8065	5245	2	2004-09-02
6	8065	4523	1	2004-09-02
7	8065	6824	2	2004-09-02
1	8066	3062	1	2004-09-24
2	8066	3045	2	2004-09-24
3	8066	509	3	2004-09-24
4	8066	912	1	2004-09-24
1	8067	8381	1	2004-09-28
2	8067	6392	2	2004-09-28
3	8067	6640	1	2004-09-28
4	8067	4270	1	2004-09-28
5	8067	5591	3	2004-09-28
6	8067	7143	1	2004-09-28
1	8068	415	1	2004-09-06
2	8068	3317	2	2004-09-06
3	8068	5529	2	2004-09-06
4	8068	7888	2	2004-09-06
5	8068	3899	3	2004-09-06
6	8068	6086	1	2004-09-06
7	8068	281	3	2004-09-06
8	8068	9447	3	2004-09-06
9	8068	1131	2	2004-09-06
1	8069	9723	2	2004-09-09
2	8069	6600	3	2004-09-09
3	8069	3550	3	2004-09-09
4	8069	831	3	2004-09-09
5	8069	8097	1	2004-09-09
6	8069	1542	1	2004-09-09
7	8069	4721	3	2004-09-09
1	8070	1408	3	2004-09-24
2	8070	4657	1	2004-09-24
1	8071	9942	1	2004-09-22
2	8071	5968	3	2004-09-22
3	8071	252	2	2004-09-22
4	8071	1223	3	2004-09-22
5	8071	2556	2	2004-09-22
6	8071	5203	2	2004-09-22
7	8071	3799	1	2004-09-22
8	8071	4631	2	2004-09-22
1	8072	1959	2	2004-09-15
2	8072	4154	2	2004-09-15
3	8072	4713	3	2004-09-15
1	8073	9978	1	2004-09-16
2	8073	8570	2	2004-09-16
3	8073	640	3	2004-09-16
4	8073	1636	1	2004-09-16
5	8073	5673	2	2004-09-16
1	8074	4173	1	2004-09-20
1	8075	1366	2	2004-09-18
2	8075	3703	2	2004-09-18
3	8075	6883	3	2004-09-18
4	8075	4330	1	2004-09-18
5	8075	195	3	2004-09-18
6	8075	7340	1	2004-09-18
7	8075	96	2	2004-09-18
8	8075	6117	1	2004-09-18
1	8076	1944	3	2004-09-15
1	8077	1726	2	2004-09-04
2	8077	4333	1	2004-09-04
3	8077	3619	2	2004-09-04
4	8077	6800	3	2004-09-04
5	8077	1218	2	2004-09-04
1	8078	2789	1	2004-09-18
2	8078	6101	1	2004-09-18
3	8078	8868	1	2004-09-18
4	8078	3620	2	2004-09-18
5	8078	9971	2	2004-09-18
6	8078	4002	1	2004-09-18
1	8079	730	1	2004-09-17
2	8079	546	2	2004-09-17
3	8079	6442	2	2004-09-17
4	8079	761	1	2004-09-17
5	8079	1484	1	2004-09-17
1	8080	3149	1	2004-09-21
2	8080	5498	3	2004-09-21
3	8080	3198	2	2004-09-21
1	8081	3035	1	2004-09-05
2	8081	3350	3	2004-09-05
1	8082	7941	2	2004-09-22
2	8082	3034	2	2004-09-22
3	8082	8303	2	2004-09-22
4	8082	7622	3	2004-09-22
5	8082	5772	2	2004-09-22
6	8082	7006	1	2004-09-22
7	8082	7084	1	2004-09-22
8	8082	3611	1	2004-09-22
1	8083	3626	2	2004-09-29
1	8084	5144	2	2004-09-07
2	8084	437	3	2004-09-07
3	8084	2087	3	2004-09-07
4	8084	2876	2	2004-09-07
5	8084	2758	1	2004-09-07
6	8084	8914	1	2004-09-07
1	8085	7982	1	2004-09-03
2	8085	8124	1	2004-09-03
3	8085	4588	3	2004-09-03
4	8085	8401	1	2004-09-03
5	8085	8395	1	2004-09-03
6	8085	6441	1	2004-09-03
7	8085	8688	1	2004-09-03
8	8085	6354	2	2004-09-03
1	8086	5167	2	2004-09-23
2	8086	4632	3	2004-09-23
3	8086	6623	2	2004-09-23
4	8086	8304	3	2004-09-23
5	8086	8231	1	2004-09-23
6	8086	5558	2	2004-09-23
7	8086	5234	2	2004-09-23
8	8086	7805	3	2004-09-23
9	8086	1208	2	2004-09-23
1	8087	301	3	2004-09-05
2	8087	1105	2	2004-09-05
3	8087	751	3	2004-09-05
4	8087	3444	1	2004-09-05
5	8087	8043	3	2004-09-05
6	8087	8762	1	2004-09-05
7	8087	6534	2	2004-09-05
8	8087	6220	2	2004-09-05
1	8088	663	1	2004-09-09
2	8088	2211	3	2004-09-09
3	8088	3117	2	2004-09-09
4	8088	4673	2	2004-09-09
5	8088	3021	1	2004-09-09
6	8088	2264	1	2004-09-09
7	8088	9825	2	2004-09-09
8	8088	9976	1	2004-09-09
1	8089	2029	1	2004-09-06
2	8089	2615	3	2004-09-06
3	8089	8038	3	2004-09-06
4	8089	3400	1	2004-09-06
5	8089	3284	1	2004-09-06
6	8089	9538	2	2004-09-06
7	8089	4759	1	2004-09-06
8	8089	2414	3	2004-09-06
9	8089	5168	3	2004-09-06
1	8090	1509	3	2004-09-08
2	8090	7977	1	2004-09-08
3	8090	390	3	2004-09-08
4	8090	4904	2	2004-09-08
5	8090	9816	3	2004-09-08
1	8091	1264	3	2004-09-21
2	8091	5981	2	2004-09-21
3	8091	356	2	2004-09-21
4	8091	8493	2	2004-09-21
5	8091	7268	1	2004-09-21
1	8092	623	3	2004-09-09
2	8092	9943	1	2004-09-09
3	8092	7798	3	2004-09-09
4	8092	3616	3	2004-09-09
5	8092	7793	3	2004-09-09
1	8093	39	1	2004-09-08
2	8093	4376	1	2004-09-08
3	8093	9840	1	2004-09-08
4	8093	5849	1	2004-09-08
5	8093	5875	2	2004-09-08
6	8093	5311	1	2004-09-08
7	8093	5247	3	2004-09-08
8	8093	5577	1	2004-09-08
9	8093	3634	2	2004-09-08
1	8094	1494	1	2004-09-04
2	8094	7205	3	2004-09-04
3	8094	465	3	2004-09-04
4	8094	6895	2	2004-09-04
5	8094	9076	3	2004-09-04
6	8094	6862	2	2004-09-04
7	8094	8235	3	2004-09-04
8	8094	3806	2	2004-09-04
9	8094	6898	3	2004-09-04
1	8095	507	3	2004-09-26
2	8095	6910	2	2004-09-26
3	8095	4597	3	2004-09-26
4	8095	7717	1	2004-09-26
1	8096	8497	2	2004-09-22
2	8096	4025	2	2004-09-22
3	8096	1252	1	2004-09-22
4	8096	2325	3	2004-09-22
1	8097	4643	1	2004-09-20
1	8098	6738	2	2004-09-01
2	8098	1257	2	2004-09-01
3	8098	8568	2	2004-09-01
1	8099	5494	2	2004-09-06
2	8099	3277	2	2004-09-06
3	8099	8988	3	2004-09-06
4	8099	9382	1	2004-09-06
5	8099	401	1	2004-09-06
6	8099	8353	3	2004-09-06
7	8099	2266	1	2004-09-06
8	8099	7306	3	2004-09-06
9	8099	4881	3	2004-09-06
1	8100	3228	1	2004-09-30
2	8100	358	1	2004-09-30
3	8100	7309	1	2004-09-30
4	8100	8079	2	2004-09-30
5	8100	1059	2	2004-09-30
6	8100	9741	2	2004-09-30
7	8100	7563	3	2004-09-30
1	8101	8651	3	2004-09-05
2	8101	8987	1	2004-09-05
1	8102	3634	3	2004-09-02
2	8102	4170	2	2004-09-02
3	8102	4510	3	2004-09-02
4	8102	5289	2	2004-09-02
5	8102	9193	1	2004-09-02
1	8103	843	3	2004-09-22
2	8103	2395	3	2004-09-22
3	8103	7155	2	2004-09-22
4	8103	5350	2	2004-09-22
5	8103	6067	2	2004-09-22
6	8103	3443	2	2004-09-22
7	8103	4918	2	2004-09-22
8	8103	1346	1	2004-09-22
1	8104	8813	2	2004-09-28
2	8104	867	2	2004-09-28
3	8104	9916	1	2004-09-28
4	8104	6699	3	2004-09-28
1	8105	3812	3	2004-09-22
2	8105	6578	1	2004-09-22
3	8105	1402	1	2004-09-22
4	8105	7088	3	2004-09-22
5	8105	5928	1	2004-09-22
6	8105	2522	1	2004-09-22
7	8105	4462	2	2004-09-22
8	8105	3587	2	2004-09-22
1	8106	9175	3	2004-09-27
2	8106	1760	3	2004-09-27
3	8106	8156	3	2004-09-27
4	8106	6008	2	2004-09-27
5	8106	3843	1	2004-09-27
6	8106	3657	3	2004-09-27
7	8106	8355	1	2004-09-27
1	8107	7224	3	2004-09-26
2	8107	6238	3	2004-09-26
3	8107	8935	1	2004-09-26
4	8107	3613	1	2004-09-26
5	8107	4461	1	2004-09-26
6	8107	6648	1	2004-09-26
1	8108	4913	3	2004-09-01
2	8108	334	1	2004-09-01
1	8109	1832	1	2004-09-11
2	8109	7321	1	2004-09-11
3	8109	13	3	2004-09-11
4	8109	6159	3	2004-09-11
5	8109	7571	1	2004-09-11
6	8109	6982	2	2004-09-11
7	8109	3096	1	2004-09-11
1	8110	9248	1	2004-09-28
2	8110	1496	3	2004-09-28
3	8110	5045	2	2004-09-28
4	8110	6981	2	2004-09-28
5	8110	7328	1	2004-09-28
6	8110	9555	3	2004-09-28
1	8111	1837	3	2004-09-23
2	8111	4297	3	2004-09-23
3	8111	6736	1	2004-09-23
4	8111	392	2	2004-09-23
5	8111	8373	2	2004-09-23
1	8112	3072	1	2004-09-13
2	8112	532	2	2004-09-13
3	8112	9328	2	2004-09-13
4	8112	976	2	2004-09-13
5	8112	954	3	2004-09-13
6	8112	6718	1	2004-09-13
7	8112	7533	2	2004-09-13
1	8113	6520	1	2004-09-06
2	8113	1726	1	2004-09-06
3	8113	5193	1	2004-09-06
4	8113	6973	2	2004-09-06
1	8114	8646	2	2004-09-17
2	8114	6941	3	2004-09-17
3	8114	8603	2	2004-09-17
4	8114	4753	3	2004-09-17
5	8114	2577	2	2004-09-17
6	8114	7881	3	2004-09-17
1	8115	2433	1	2004-09-19
2	8115	1838	3	2004-09-19
3	8115	5861	2	2004-09-19
4	8115	2207	1	2004-09-19
5	8115	5681	3	2004-09-19
6	8115	4618	1	2004-09-19
7	8115	462	2	2004-09-19
8	8115	7936	3	2004-09-19
1	8116	1144	1	2004-09-29
2	8116	7798	2	2004-09-29
3	8116	8744	2	2004-09-29
4	8116	3014	2	2004-09-29
5	8116	1091	2	2004-09-29
6	8116	3065	2	2004-09-29
7	8116	9056	2	2004-09-29
8	8116	2476	2	2004-09-29
1	8117	3862	1	2004-09-26
2	8117	5433	2	2004-09-26
3	8117	6168	2	2004-09-26
4	8117	3431	2	2004-09-26
1	8118	4754	1	2004-09-25
2	8118	3108	2	2004-09-25
3	8118	7481	2	2004-09-25
4	8118	8455	3	2004-09-25
5	8118	2642	1	2004-09-25
6	8118	2095	1	2004-09-25
7	8118	6423	2	2004-09-25
8	8118	6613	2	2004-09-25
9	8118	9253	1	2004-09-25
1	8119	7437	3	2004-09-28
2	8119	7835	1	2004-09-28
3	8119	5120	2	2004-09-28
4	8119	2584	3	2004-09-28
5	8119	5466	3	2004-09-28
1	8120	4694	3	2004-09-03
2	8120	6981	3	2004-09-03
3	8120	809	3	2004-09-03
4	8120	9033	3	2004-09-03
5	8120	3646	2	2004-09-03
6	8120	2119	1	2004-09-03
7	8120	8225	1	2004-09-03
8	8120	6011	1	2004-09-03
1	8121	4315	2	2004-09-17
2	8121	9534	3	2004-09-17
3	8121	4971	2	2004-09-17
4	8121	4235	2	2004-09-17
1	8122	4359	1	2004-09-11
2	8122	5600	2	2004-09-11
3	8122	362	2	2004-09-11
4	8122	2398	2	2004-09-11
5	8122	277	2	2004-09-11
6	8122	6904	3	2004-09-11
7	8122	5671	1	2004-09-11
8	8122	9893	1	2004-09-11
1	8123	6464	2	2004-09-20
1	8124	7331	1	2004-09-23
2	8124	6879	1	2004-09-23
1	8125	6404	1	2004-09-04
2	8125	1347	3	2004-09-04
3	8125	7292	1	2004-09-04
4	8125	3319	2	2004-09-04
5	8125	125	3	2004-09-04
6	8125	7111	1	2004-09-04
7	8125	280	2	2004-09-04
1	8126	9306	1	2004-09-02
2	8126	8531	3	2004-09-02
3	8126	3532	2	2004-09-02
4	8126	1435	1	2004-09-02
5	8126	7499	1	2004-09-02
6	8126	1647	1	2004-09-02
7	8126	9265	3	2004-09-02
1	8127	2235	1	2004-09-12
1	8128	2376	3	2004-09-16
2	8128	5777	1	2004-09-16
3	8128	4463	3	2004-09-16
1	8129	2354	2	2004-09-01
2	8129	4499	2	2004-09-01
3	8129	5589	1	2004-09-01
4	8129	6338	3	2004-09-01
5	8129	2419	2	2004-09-01
6	8129	5286	2	2004-09-01
7	8129	6215	1	2004-09-01
8	8129	7124	3	2004-09-01
1	8130	4623	1	2004-09-07
2	8130	904	1	2004-09-07
1	8131	9136	1	2004-09-19
2	8131	4937	1	2004-09-19
3	8131	7150	3	2004-09-19
4	8131	5277	1	2004-09-19
5	8131	1432	1	2004-09-19
6	8131	9975	2	2004-09-19
1	8132	7398	3	2004-09-22
2	8132	1881	3	2004-09-22
3	8132	9417	1	2004-09-22
4	8132	1172	2	2004-09-22
1	8133	7443	2	2004-09-18
2	8133	8366	2	2004-09-18
1	8134	2738	2	2004-09-21
2	8134	6620	2	2004-09-21
3	8134	4956	2	2004-09-21
4	8134	8019	1	2004-09-21
1	8135	5092	3	2004-09-06
2	8135	8956	2	2004-09-06
3	8135	172	1	2004-09-06
4	8135	8547	2	2004-09-06
5	8135	2204	1	2004-09-06
6	8135	8109	3	2004-09-06
7	8135	7744	2	2004-09-06
8	8135	6223	2	2004-09-06
9	8135	9777	2	2004-09-06
1	8136	6684	1	2004-09-26
2	8136	1567	2	2004-09-26
3	8136	4759	2	2004-09-26
4	8136	2696	1	2004-09-26
5	8136	2671	3	2004-09-26
1	8137	1754	1	2004-09-24
2	8137	4059	2	2004-09-24
3	8137	3825	1	2004-09-24
4	8137	3603	1	2004-09-24
5	8137	8642	3	2004-09-24
6	8137	6043	3	2004-09-24
7	8137	4114	2	2004-09-24
8	8137	933	1	2004-09-24
1	8138	2319	3	2004-09-29
1	8139	2801	3	2004-09-14
2	8139	8654	2	2004-09-14
3	8139	5310	1	2004-09-14
4	8139	5938	3	2004-09-14
5	8139	4364	3	2004-09-14
6	8139	1536	3	2004-09-14
7	8139	1330	1	2004-09-14
1	8140	1769	3	2004-09-24
2	8140	3650	1	2004-09-24
1	8141	7071	2	2004-09-22
2	8141	4477	2	2004-09-22
3	8141	3461	3	2004-09-22
4	8141	3817	1	2004-09-22
5	8141	2374	3	2004-09-22
6	8141	2521	3	2004-09-22
7	8141	8495	3	2004-09-22
8	8141	8073	1	2004-09-22
9	8141	4851	3	2004-09-22
1	8142	4548	3	2004-09-01
2	8142	8331	3	2004-09-01
3	8142	9683	2	2004-09-01
4	8142	6178	1	2004-09-01
5	8142	4938	1	2004-09-01
6	8142	8193	3	2004-09-01
7	8142	9770	1	2004-09-01
8	8142	6693	2	2004-09-01
1	8143	7376	1	2004-09-12
2	8143	3174	2	2004-09-12
3	8143	1235	3	2004-09-12
4	8143	4851	1	2004-09-12
5	8143	667	1	2004-09-12
6	8143	243	2	2004-09-12
1	8144	4048	3	2004-09-01
2	8144	1611	3	2004-09-01
3	8144	2837	3	2004-09-01
4	8144	8401	1	2004-09-01
5	8144	1457	2	2004-09-01
6	8144	6192	2	2004-09-01
7	8144	4158	3	2004-09-01
8	8144	1513	1	2004-09-01
9	8144	108	2	2004-09-01
1	8145	2784	2	2004-09-21
2	8145	3457	1	2004-09-21
1	8146	3476	2	2004-09-26
2	8146	1588	2	2004-09-26
1	8147	7029	2	2004-09-14
2	8147	8127	1	2004-09-14
3	8147	1570	1	2004-09-14
1	8148	7768	1	2004-09-07
2	8148	3574	1	2004-09-07
3	8148	2632	2	2004-09-07
1	8149	9712	1	2004-09-12
2	8149	4442	1	2004-09-12
3	8149	6632	2	2004-09-12
1	8150	4299	3	2004-09-25
2	8150	9506	1	2004-09-25
3	8150	702	1	2004-09-25
1	8151	5055	1	2004-09-15
2	8151	9327	3	2004-09-15
3	8151	2401	1	2004-09-15
4	8151	4986	2	2004-09-15
5	8151	8045	2	2004-09-15
6	8151	8697	3	2004-09-15
7	8151	5354	1	2004-09-15
8	8151	943	1	2004-09-15
1	8152	2375	3	2004-09-28
2	8152	7101	1	2004-09-28
3	8152	9974	3	2004-09-28
4	8152	2955	2	2004-09-28
5	8152	626	3	2004-09-28
6	8152	3210	2	2004-09-28
7	8152	9034	1	2004-09-28
8	8152	4308	1	2004-09-28
9	8152	4494	3	2004-09-28
1	8153	294	3	2004-09-24
2	8153	9523	1	2004-09-24
3	8153	1001	3	2004-09-24
4	8153	452	2	2004-09-24
5	8153	8309	1	2004-09-24
6	8153	1800	2	2004-09-24
1	8154	6457	2	2004-09-15
2	8154	4771	3	2004-09-15
3	8154	9516	2	2004-09-15
4	8154	2203	2	2004-09-15
5	8154	5238	3	2004-09-15
6	8154	3116	1	2004-09-15
7	8154	9234	3	2004-09-15
1	8155	764	3	2004-09-28
2	8155	7523	1	2004-09-28
3	8155	1045	2	2004-09-28
4	8155	4042	1	2004-09-28
5	8155	1240	3	2004-09-28
6	8155	4617	2	2004-09-28
7	8155	6409	1	2004-09-28
8	8155	8286	1	2004-09-28
1	8156	1623	1	2004-09-03
2	8156	9638	2	2004-09-03
3	8156	3146	3	2004-09-03
1	8157	1289	3	2004-09-05
2	8157	4104	3	2004-09-05
3	8157	377	2	2004-09-05
4	8157	4642	2	2004-09-05
5	8157	7992	2	2004-09-05
6	8157	3167	1	2004-09-05
7	8157	332	3	2004-09-05
1	8158	6417	2	2004-09-12
2	8158	7364	3	2004-09-12
3	8158	5958	3	2004-09-12
4	8158	2778	3	2004-09-12
1	8159	1604	1	2004-09-18
2	8159	3431	2	2004-09-18
3	8159	1659	2	2004-09-18
4	8159	855	2	2004-09-18
1	8160	1456	1	2004-09-25
2	8160	967	2	2004-09-25
1	8161	7458	3	2004-09-04
2	8161	5585	2	2004-09-04
3	8161	3924	3	2004-09-04
4	8161	2518	3	2004-09-04
5	8161	2656	2	2004-09-04
6	8161	4064	2	2004-09-04
7	8161	6925	3	2004-09-04
1	8162	4884	3	2004-09-30
1	8163	9578	1	2004-09-30
2	8163	6261	1	2004-09-30
1	8164	2742	2	2004-09-11
1	8165	6460	2	2004-09-14
2	8165	1073	1	2004-09-14
3	8165	9113	3	2004-09-14
4	8165	8018	3	2004-09-14
5	8165	6581	3	2004-09-14
6	8165	9900	1	2004-09-14
7	8165	8845	3	2004-09-14
1	8166	1646	3	2004-09-26
2	8166	8814	2	2004-09-26
3	8166	2770	3	2004-09-26
4	8166	6313	2	2004-09-26
5	8166	901	1	2004-09-26
6	8166	2176	1	2004-09-26
7	8166	7787	3	2004-09-26
8	8166	7952	3	2004-09-26
1	8167	6143	2	2004-09-28
2	8167	6495	2	2004-09-28
3	8167	4901	2	2004-09-28
4	8167	5609	2	2004-09-28
5	8167	5101	2	2004-09-28
6	8167	1537	3	2004-09-28
7	8167	3249	1	2004-09-28
1	8168	1530	3	2004-09-06
2	8168	9100	2	2004-09-06
3	8168	1414	3	2004-09-06
4	8168	2341	3	2004-09-06
5	8168	5745	1	2004-09-06
6	8168	6429	1	2004-09-06
7	8168	8676	1	2004-09-06
8	8168	6037	2	2004-09-06
1	8169	4366	2	2004-09-26
2	8169	519	2	2004-09-26
3	8169	2355	2	2004-09-26
4	8169	6252	2	2004-09-26
1	8170	1981	1	2004-09-30
2	8170	5020	2	2004-09-30
1	8171	8859	3	2004-09-26
2	8171	6988	3	2004-09-26
3	8171	1759	1	2004-09-26
4	8171	2705	1	2004-09-26
1	8172	8822	2	2004-09-12
2	8172	4229	1	2004-09-12
3	8172	8877	1	2004-09-12
4	8172	5527	3	2004-09-12
5	8172	4146	3	2004-09-12
6	8172	9978	2	2004-09-12
7	8172	9945	2	2004-09-12
8	8172	9521	3	2004-09-12
1	8173	1468	3	2004-09-08
2	8173	8751	1	2004-09-08
1	8174	4668	3	2004-09-09
2	8174	5275	2	2004-09-09
3	8174	3296	3	2004-09-09
4	8174	4666	1	2004-09-09
5	8174	9983	1	2004-09-09
6	8174	836	2	2004-09-09
7	8174	8379	1	2004-09-09
1	8175	6912	3	2004-09-01
2	8175	2056	3	2004-09-01
3	8175	9385	2	2004-09-01
4	8175	9852	3	2004-09-01
5	8175	6749	1	2004-09-01
6	8175	9591	1	2004-09-01
7	8175	9788	2	2004-09-01
8	8175	8531	2	2004-09-01
9	8175	7748	1	2004-09-01
1	8176	2606	2	2004-09-14
2	8176	8678	1	2004-09-14
3	8176	5647	3	2004-09-14
4	8176	9307	1	2004-09-14
5	8176	8709	2	2004-09-14
1	8177	4288	2	2004-09-29
2	8177	7147	1	2004-09-29
3	8177	8796	3	2004-09-29
4	8177	1381	3	2004-09-29
5	8177	995	3	2004-09-29
6	8177	3647	3	2004-09-29
7	8177	1737	3	2004-09-29
8	8177	1155	2	2004-09-29
9	8177	2761	2	2004-09-29
1	8178	371	2	2004-09-02
2	8178	7674	3	2004-09-02
3	8178	268	3	2004-09-02
4	8178	9844	2	2004-09-02
5	8178	6310	2	2004-09-02
6	8178	2330	2	2004-09-02
1	8179	9710	1	2004-09-16
2	8179	6458	2	2004-09-16
3	8179	9928	3	2004-09-16
4	8179	1568	1	2004-09-16
5	8179	3930	2	2004-09-16
6	8179	4842	2	2004-09-16
1	8180	3635	3	2004-09-18
2	8180	5214	2	2004-09-18
3	8180	5686	2	2004-09-18
4	8180	276	1	2004-09-18
5	8180	9188	1	2004-09-18
6	8180	5450	2	2004-09-18
1	8181	6828	3	2004-09-12
2	8181	6795	3	2004-09-12
3	8181	5553	3	2004-09-12
4	8181	7836	3	2004-09-12
1	8182	2262	2	2004-09-09
2	8182	4589	2	2004-09-09
3	8182	3081	3	2004-09-09
4	8182	9798	3	2004-09-09
5	8182	4860	1	2004-09-09
6	8182	761	2	2004-09-09
7	8182	2678	2	2004-09-09
8	8182	8402	2	2004-09-09
1	8183	6661	2	2004-09-06
2	8183	5434	1	2004-09-06
3	8183	5004	1	2004-09-06
4	8183	1694	3	2004-09-06
5	8183	5946	2	2004-09-06
6	8183	6148	3	2004-09-06
7	8183	367	1	2004-09-06
8	8183	4103	2	2004-09-06
1	8184	3974	1	2004-09-02
2	8184	9446	2	2004-09-02
3	8184	9184	3	2004-09-02
4	8184	3059	1	2004-09-02
5	8184	7149	1	2004-09-02
1	8185	6021	2	2004-09-30
2	8185	8417	3	2004-09-30
3	8185	2245	2	2004-09-30
4	8185	3387	3	2004-09-30
5	8185	2570	2	2004-09-30
1	8186	573	3	2004-09-28
2	8186	5065	2	2004-09-28
3	8186	2385	2	2004-09-28
4	8186	1197	1	2004-09-28
5	8186	2356	2	2004-09-28
6	8186	2604	3	2004-09-28
7	8186	7161	1	2004-09-28
8	8186	3313	3	2004-09-28
9	8186	7466	3	2004-09-28
1	8187	246	1	2004-09-04
2	8187	1896	1	2004-09-04
3	8187	4186	1	2004-09-04
4	8187	9488	1	2004-09-04
1	8188	4607	1	2004-09-03
2	8188	264	2	2004-09-03
3	8188	4748	1	2004-09-03
4	8188	59	3	2004-09-03
5	8188	2124	3	2004-09-03
6	8188	9669	2	2004-09-03
1	8189	3017	1	2004-09-12
2	8189	8691	1	2004-09-12
3	8189	2250	1	2004-09-12
4	8189	6077	2	2004-09-12
5	8189	1611	2	2004-09-12
1	8190	8054	1	2004-09-24
2	8190	1797	3	2004-09-24
3	8190	6036	2	2004-09-24
4	8190	938	2	2004-09-24
5	8190	3895	1	2004-09-24
6	8190	3314	2	2004-09-24
7	8190	8498	3	2004-09-24
8	8190	697	1	2004-09-24
1	8191	6975	3	2004-09-08
2	8191	1706	1	2004-09-08
1	8192	5615	2	2004-09-12
2	8192	207	2	2004-09-12
1	8193	8547	1	2004-09-14
1	8194	6005	2	2004-09-20
2	8194	7155	3	2004-09-20
3	8194	7751	3	2004-09-20
4	8194	414	1	2004-09-20
5	8194	700	3	2004-09-20
6	8194	169	1	2004-09-20
7	8194	440	2	2004-09-20
8	8194	5721	3	2004-09-20
9	8194	5529	1	2004-09-20
1	8195	7739	3	2004-09-10
2	8195	8275	2	2004-09-10
3	8195	9914	2	2004-09-10
4	8195	8727	2	2004-09-10
5	8195	4789	2	2004-09-10
6	8195	382	1	2004-09-10
7	8195	1432	3	2004-09-10
1	8196	9234	1	2004-09-05
2	8196	4630	3	2004-09-05
3	8196	5074	1	2004-09-05
1	8197	6338	3	2004-09-27
2	8197	9791	2	2004-09-27
1	8198	2940	3	2004-09-12
2	8198	9491	3	2004-09-12
3	8198	3818	3	2004-09-12
4	8198	9672	2	2004-09-12
1	8199	3421	2	2004-09-25
2	8199	104	3	2004-09-25
3	8199	6002	2	2004-09-25
4	8199	8400	2	2004-09-25
5	8199	5779	1	2004-09-25
6	8199	6753	1	2004-09-25
7	8199	6773	2	2004-09-25
8	8199	6193	1	2004-09-25
9	8199	4609	2	2004-09-25
1	8200	5277	3	2004-09-13
2	8200	3405	2	2004-09-13
3	8200	4706	1	2004-09-13
4	8200	6144	1	2004-09-13
1	8201	7613	2	2004-09-02
1	8202	6096	2	2004-09-17
2	8202	3550	1	2004-09-17
1	8203	6295	3	2004-09-07
2	8203	4311	1	2004-09-07
3	8203	894	3	2004-09-07
4	8203	1392	2	2004-09-07
5	8203	4535	2	2004-09-07
6	8203	5704	1	2004-09-07
7	8203	7898	2	2004-09-07
1	8204	154	1	2004-09-01
2	8204	3865	3	2004-09-01
3	8204	3646	3	2004-09-01
4	8204	4623	3	2004-09-01
5	8204	2829	3	2004-09-01
6	8204	6937	2	2004-09-01
7	8204	3541	1	2004-09-01
8	8204	3507	3	2004-09-01
1	8205	8697	1	2004-09-16
2	8205	2655	2	2004-09-16
3	8205	2649	1	2004-09-16
4	8205	480	1	2004-09-16
5	8205	6577	3	2004-09-16
6	8205	743	3	2004-09-16
1	8206	4568	1	2004-09-28
2	8206	92	3	2004-09-28
3	8206	7142	3	2004-09-28
1	8207	8533	2	2004-09-11
2	8207	1449	2	2004-09-11
3	8207	1983	1	2004-09-11
4	8207	7942	2	2004-09-11
5	8207	4546	1	2004-09-11
6	8207	5189	2	2004-09-11
7	8207	3481	1	2004-09-11
1	8208	8830	2	2004-09-07
2	8208	4210	2	2004-09-07
1	8209	1329	2	2004-09-14
2	8209	2425	1	2004-09-14
1	8210	6928	3	2004-09-05
2	8210	2978	2	2004-09-05
3	8210	3634	3	2004-09-05
1	8211	588	2	2004-09-17
2	8211	3163	3	2004-09-17
3	8211	5925	1	2004-09-17
4	8211	3319	1	2004-09-17
5	8211	5390	3	2004-09-17
6	8211	4434	2	2004-09-17
7	8211	9664	2	2004-09-17
8	8211	519	1	2004-09-17
9	8211	7351	1	2004-09-17
1	8212	3361	3	2004-09-10
2	8212	4842	3	2004-09-10
3	8212	5235	1	2004-09-10
4	8212	5817	3	2004-09-10
5	8212	9242	2	2004-09-10
6	8212	2395	1	2004-09-10
7	8212	5486	3	2004-09-10
8	8212	4397	3	2004-09-10
9	8212	8453	3	2004-09-10
1	8213	8649	2	2004-09-21
2	8213	8476	2	2004-09-21
3	8213	8392	1	2004-09-21
4	8213	364	1	2004-09-21
5	8213	1494	2	2004-09-21
6	8213	838	2	2004-09-21
1	8214	3856	2	2004-09-03
2	8214	2939	2	2004-09-03
3	8214	8281	3	2004-09-03
4	8214	4569	1	2004-09-03
5	8214	7228	1	2004-09-03
6	8214	2464	2	2004-09-03
1	8215	4921	3	2004-09-18
2	8215	555	1	2004-09-18
3	8215	337	1	2004-09-18
4	8215	6438	1	2004-09-18
5	8215	4644	3	2004-09-18
1	8216	1898	3	2004-09-25
2	8216	678	2	2004-09-25
3	8216	3455	3	2004-09-25
4	8216	3259	3	2004-09-25
5	8216	1636	1	2004-09-25
1	8217	2531	2	2004-09-04
2	8217	1506	3	2004-09-04
3	8217	3596	1	2004-09-04
4	8217	764	2	2004-09-04
5	8217	2979	3	2004-09-04
6	8217	5762	3	2004-09-04
7	8217	4478	2	2004-09-04
1	8218	5030	3	2004-09-09
2	8218	9717	3	2004-09-09
3	8218	8363	1	2004-09-09
4	8218	6507	3	2004-09-09
5	8218	3462	3	2004-09-09
1	8219	2681	2	2004-09-13
2	8219	4079	2	2004-09-13
3	8219	8068	2	2004-09-13
4	8219	209	1	2004-09-13
5	8219	2044	2	2004-09-13
6	8219	8668	2	2004-09-13
1	8220	6533	3	2004-09-30
2	8220	8027	2	2004-09-30
3	8220	7862	2	2004-09-30
4	8220	9224	2	2004-09-30
5	8220	6387	1	2004-09-30
6	8220	1919	1	2004-09-30
7	8220	587	2	2004-09-30
8	8220	7110	1	2004-09-30
1	8221	6031	3	2004-09-08
1	8222	4596	2	2004-09-05
1	8223	8320	1	2004-09-06
2	8223	4641	2	2004-09-06
3	8223	8656	2	2004-09-06
4	8223	549	2	2004-09-06
5	8223	6550	1	2004-09-06
6	8223	5526	3	2004-09-06
7	8223	8887	1	2004-09-06
8	8223	404	1	2004-09-06
1	8224	9700	2	2004-09-12
2	8224	7928	2	2004-09-12
3	8224	3553	1	2004-09-12
4	8224	1039	2	2004-09-12
5	8224	1466	2	2004-09-12
6	8224	3804	3	2004-09-12
7	8224	7546	3	2004-09-12
8	8224	5966	2	2004-09-12
9	8224	2308	2	2004-09-12
1	8225	5993	3	2004-09-04
2	8225	9404	2	2004-09-04
3	8225	9180	1	2004-09-04
4	8225	6344	1	2004-09-04
5	8225	3081	2	2004-09-04
6	8225	4331	1	2004-09-04
7	8225	1464	3	2004-09-04
1	8226	7781	3	2004-09-11
2	8226	4782	2	2004-09-11
3	8226	5544	1	2004-09-11
4	8226	1527	3	2004-09-11
5	8226	7262	1	2004-09-11
1	8227	4110	3	2004-09-21
2	8227	9097	1	2004-09-21
3	8227	2169	2	2004-09-21
1	8228	6257	1	2004-09-13
2	8228	6490	3	2004-09-13
3	8228	5450	3	2004-09-13
4	8228	4785	1	2004-09-13
5	8228	6885	3	2004-09-13
6	8228	8556	1	2004-09-13
7	8228	314	1	2004-09-13
8	8228	279	3	2004-09-13
1	8229	9688	3	2004-09-09
2	8229	1333	3	2004-09-09
3	8229	1217	2	2004-09-09
1	8230	4097	2	2004-09-13
2	8230	8656	1	2004-09-13
3	8230	4793	2	2004-09-13
4	8230	371	3	2004-09-13
5	8230	7336	3	2004-09-13
6	8230	9143	2	2004-09-13
1	8231	7032	3	2004-09-30
2	8231	6949	1	2004-09-30
3	8231	1215	2	2004-09-30
4	8231	8777	1	2004-09-30
5	8231	5420	3	2004-09-30
6	8231	6048	3	2004-09-30
7	8231	5485	2	2004-09-30
8	8231	5353	3	2004-09-30
9	8231	9801	2	2004-09-30
1	8232	4170	2	2004-09-01
1	8233	2769	3	2004-09-24
2	8233	7437	3	2004-09-24
3	8233	6137	2	2004-09-24
4	8233	649	3	2004-09-24
5	8233	1021	3	2004-09-24
6	8233	9898	2	2004-09-24
7	8233	9418	2	2004-09-24
1	8234	4483	1	2004-09-19
2	8234	5447	2	2004-09-19
1	8235	9009	1	2004-09-16
2	8235	2617	1	2004-09-16
3	8235	451	2	2004-09-16
4	8235	7661	3	2004-09-16
5	8235	5185	2	2004-09-16
6	8235	2273	2	2004-09-16
7	8235	1148	1	2004-09-16
8	8235	5258	1	2004-09-16
9	8235	9734	2	2004-09-16
1	8236	7256	2	2004-09-21
2	8236	8273	1	2004-09-21
3	8236	8708	2	2004-09-21
4	8236	6262	2	2004-09-21
5	8236	2712	2	2004-09-21
6	8236	6869	2	2004-09-21
7	8236	5620	3	2004-09-21
1	8237	7077	3	2004-09-03
2	8237	1730	3	2004-09-03
3	8237	772	3	2004-09-03
4	8237	9270	1	2004-09-03
5	8237	1663	2	2004-09-03
6	8237	6324	1	2004-09-03
1	8238	6281	2	2004-09-12
2	8238	5669	1	2004-09-12
3	8238	7899	3	2004-09-12
1	8239	2086	2	2004-09-24
2	8239	6712	3	2004-09-24
3	8239	320	2	2004-09-24
4	8239	4771	1	2004-09-24
1	8240	6048	1	2004-09-07
2	8240	7541	1	2004-09-07
1	8241	3792	1	2004-09-06
2	8241	1243	3	2004-09-06
3	8241	4773	3	2004-09-06
4	8241	7841	1	2004-09-06
5	8241	3909	1	2004-09-06
6	8241	6018	2	2004-09-06
7	8241	5972	1	2004-09-06
1	8242	8340	3	2004-09-10
2	8242	3599	3	2004-09-10
3	8242	9811	3	2004-09-10
4	8242	8075	3	2004-09-10
5	8242	2018	1	2004-09-10
6	8242	8881	3	2004-09-10
7	8242	7250	1	2004-09-10
8	8242	198	3	2004-09-10
1	8243	7556	1	2004-09-07
2	8243	1523	2	2004-09-07
3	8243	7537	3	2004-09-07
4	8243	6304	1	2004-09-07
5	8243	3785	1	2004-09-07
6	8243	8879	1	2004-09-07
7	8243	1351	1	2004-09-07
8	8243	9501	1	2004-09-07
9	8243	2125	3	2004-09-07
1	8244	2109	2	2004-09-26
2	8244	65	1	2004-09-26
3	8244	3330	1	2004-09-26
4	8244	7276	1	2004-09-26
5	8244	2171	2	2004-09-26
6	8244	2505	2	2004-09-26
7	8244	8406	1	2004-09-26
1	8245	7531	3	2004-09-04
2	8245	7096	3	2004-09-04
3	8245	2220	2	2004-09-04
4	8245	43	2	2004-09-04
5	8245	4172	3	2004-09-04
1	8246	6598	2	2004-09-26
1	8247	891	1	2004-09-09
1	8248	3436	2	2004-09-16
2	8248	8121	2	2004-09-16
3	8248	228	2	2004-09-16
4	8248	4041	3	2004-09-16
1	8249	604	3	2004-09-14
2	8249	3128	3	2004-09-14
3	8249	9851	3	2004-09-14
4	8249	9683	2	2004-09-14
5	8249	5086	1	2004-09-14
1	8250	3672	3	2004-09-20
2	8250	661	3	2004-09-20
3	8250	1176	2	2004-09-20
4	8250	2999	3	2004-09-20
5	8250	8396	1	2004-09-20
6	8250	4948	1	2004-09-20
7	8250	549	3	2004-09-20
1	8251	2558	3	2004-09-27
2	8251	8390	1	2004-09-27
3	8251	6255	3	2004-09-27
4	8251	8857	1	2004-09-27
5	8251	654	2	2004-09-27
6	8251	4634	2	2004-09-27
7	8251	2498	3	2004-09-27
8	8251	1174	1	2004-09-27
9	8251	6047	1	2004-09-27
1	8252	2271	2	2004-09-22
2	8252	8087	1	2004-09-22
3	8252	6071	3	2004-09-22
4	8252	7287	1	2004-09-22
5	8252	6084	3	2004-09-22
6	8252	7304	2	2004-09-22
1	8253	4899	1	2004-09-07
1	8254	7837	3	2004-09-20
2	8254	1999	2	2004-09-20
3	8254	129	3	2004-09-20
4	8254	2928	1	2004-09-20
5	8254	4905	2	2004-09-20
6	8254	8365	1	2004-09-20
7	8254	8017	2	2004-09-20
8	8254	9774	2	2004-09-20
1	8255	330	3	2004-09-14
2	8255	5420	1	2004-09-14
1	8256	9849	1	2004-09-26
2	8256	3692	3	2004-09-26
3	8256	460	2	2004-09-26
4	8256	1568	1	2004-09-26
5	8256	4944	2	2004-09-26
1	8257	2839	3	2004-09-08
1	8258	8469	3	2004-09-16
2	8258	1579	3	2004-09-16
3	8258	5561	3	2004-09-16
4	8258	1672	2	2004-09-16
5	8258	7316	3	2004-09-16
6	8258	8923	3	2004-09-16
7	8258	423	1	2004-09-16
8	8258	4849	1	2004-09-16
9	8258	8305	2	2004-09-16
1	8259	3095	1	2004-09-05
2	8259	4559	2	2004-09-05
3	8259	8311	3	2004-09-05
4	8259	8545	1	2004-09-05
1	8260	5812	2	2004-09-29
1	8261	5227	3	2004-09-25
2	8261	2494	2	2004-09-25
3	8261	652	3	2004-09-25
4	8261	6532	3	2004-09-25
5	8261	3759	3	2004-09-25
1	8262	5271	2	2004-09-07
2	8262	1232	2	2004-09-07
3	8262	6111	3	2004-09-07
4	8262	4904	2	2004-09-07
5	8262	6790	2	2004-09-07
1	8263	86	3	2004-09-20
2	8263	9906	2	2004-09-20
3	8263	6584	1	2004-09-20
4	8263	962	3	2004-09-20
5	8263	9742	3	2004-09-20
1	8264	8168	3	2004-09-19
2	8264	3694	2	2004-09-19
3	8264	3719	2	2004-09-19
4	8264	7019	3	2004-09-19
5	8264	4702	1	2004-09-19
6	8264	5377	1	2004-09-19
7	8264	6310	1	2004-09-19
8	8264	4093	2	2004-09-19
1	8265	9491	1	2004-09-20
2	8265	8821	1	2004-09-20
3	8265	8106	3	2004-09-20
4	8265	7944	2	2004-09-20
5	8265	2061	2	2004-09-20
6	8265	2692	1	2004-09-20
1	8266	1310	1	2004-09-03
2	8266	4314	2	2004-09-03
3	8266	2606	3	2004-09-03
4	8266	7503	3	2004-09-03
5	8266	1630	1	2004-09-03
1	8267	4567	2	2004-09-14
2	8267	9812	2	2004-09-14
3	8267	5715	3	2004-09-14
4	8267	1950	2	2004-09-14
5	8267	2213	2	2004-09-14
6	8267	7097	2	2004-09-14
7	8267	4239	3	2004-09-14
8	8267	1290	3	2004-09-14
9	8267	2346	1	2004-09-14
1	8268	6350	2	2004-09-26
2	8268	108	3	2004-09-26
1	8269	3705	1	2004-09-24
2	8269	8743	2	2004-09-24
3	8269	4078	2	2004-09-24
4	8269	1432	2	2004-09-24
1	8270	8549	2	2004-09-25
2	8270	3075	3	2004-09-25
3	8270	2179	2	2004-09-25
4	8270	2438	1	2004-09-25
5	8270	2080	1	2004-09-25
1	8271	6407	2	2004-09-06
2	8271	6829	1	2004-09-06
1	8272	4048	3	2004-09-26
2	8272	1547	2	2004-09-26
3	8272	3326	3	2004-09-26
4	8272	9124	2	2004-09-26
5	8272	4876	3	2004-09-26
6	8272	7638	3	2004-09-26
7	8272	7511	3	2004-09-26
1	8273	996	1	2004-09-11
2	8273	3878	3	2004-09-11
3	8273	4606	1	2004-09-11
4	8273	3023	1	2004-09-11
5	8273	2815	1	2004-09-11
1	8274	3334	1	2004-09-06
2	8274	1493	2	2004-09-06
3	8274	9668	1	2004-09-06
4	8274	23	2	2004-09-06
5	8274	8288	3	2004-09-06
6	8274	2492	2	2004-09-06
1	8275	1311	3	2004-09-23
2	8275	599	2	2004-09-23
3	8275	4897	2	2004-09-23
4	8275	5472	3	2004-09-23
5	8275	6637	3	2004-09-23
6	8275	9288	3	2004-09-23
7	8275	4321	3	2004-09-23
8	8275	4615	3	2004-09-23
1	8276	6723	2	2004-09-24
2	8276	1960	2	2004-09-24
3	8276	1997	2	2004-09-24
4	8276	809	3	2004-09-24
5	8276	313	2	2004-09-24
6	8276	7532	1	2004-09-24
7	8276	3296	3	2004-09-24
1	8277	6112	3	2004-09-21
2	8277	567	2	2004-09-21
3	8277	8571	2	2004-09-21
1	8278	9293	3	2004-09-10
1	8279	1026	1	2004-09-25
1	8280	8389	1	2004-09-15
2	8280	6655	1	2004-09-15
3	8280	8321	2	2004-09-15
4	8280	9878	1	2004-09-15
5	8280	5746	2	2004-09-15
1	8281	1199	2	2004-09-05
1	8282	596	2	2004-09-11
2	8282	8686	1	2004-09-11
3	8282	4003	3	2004-09-11
1	8283	3755	3	2004-09-15
2	8283	7825	1	2004-09-15
3	8283	1620	2	2004-09-15
4	8283	3875	1	2004-09-15
5	8283	7798	3	2004-09-15
6	8283	7486	3	2004-09-15
7	8283	5932	3	2004-09-15
1	8284	871	3	2004-09-29
2	8284	5660	1	2004-09-29
3	8284	2562	2	2004-09-29
1	8285	5287	2	2004-09-10
2	8285	5858	3	2004-09-10
3	8285	5536	2	2004-09-10
4	8285	9451	3	2004-09-10
5	8285	9828	1	2004-09-10
6	8285	8653	3	2004-09-10
7	8285	2945	2	2004-09-10
8	8285	7044	3	2004-09-10
1	8286	9644	3	2004-09-16
2	8286	7243	2	2004-09-16
3	8286	8342	3	2004-09-16
4	8286	9648	1	2004-09-16
5	8286	6368	2	2004-09-16
6	8286	9817	1	2004-09-16
7	8286	9306	2	2004-09-16
8	8286	695	2	2004-09-16
1	8287	3470	1	2004-09-29
2	8287	6809	2	2004-09-29
3	8287	6787	2	2004-09-29
4	8287	5290	1	2004-09-29
5	8287	508	1	2004-09-29
6	8287	212	1	2004-09-29
7	8287	8171	3	2004-09-29
8	8287	5455	2	2004-09-29
9	8287	7259	2	2004-09-29
1	8288	5280	3	2004-09-25
2	8288	3597	2	2004-09-25
3	8288	2953	1	2004-09-25
4	8288	6120	2	2004-09-25
5	8288	2138	3	2004-09-25
6	8288	5597	3	2004-09-25
7	8288	6003	1	2004-09-25
8	8288	2800	1	2004-09-25
1	8289	3459	1	2004-09-13
2	8289	1847	3	2004-09-13
3	8289	7271	3	2004-09-13
4	8289	4017	2	2004-09-13
1	8290	934	3	2004-09-09
2	8290	3984	2	2004-09-09
3	8290	9846	1	2004-09-09
4	8290	8835	1	2004-09-09
5	8290	9692	2	2004-09-09
6	8290	929	2	2004-09-09
7	8290	6815	2	2004-09-09
8	8290	6987	1	2004-09-09
1	8291	333	3	2004-09-22
1	8292	2979	3	2004-09-29
2	8292	6246	2	2004-09-29
3	8292	7078	3	2004-09-29
4	8292	3167	1	2004-09-29
1	8293	4995	1	2004-09-04
2	8293	4332	2	2004-09-04
3	8293	6550	1	2004-09-04
4	8293	9651	2	2004-09-04
5	8293	2142	3	2004-09-04
6	8293	3111	3	2004-09-04
7	8293	7179	2	2004-09-04
8	8293	4763	2	2004-09-04
9	8293	1048	1	2004-09-04
1	8294	300	3	2004-09-01
2	8294	3432	2	2004-09-01
3	8294	8308	2	2004-09-01
4	8294	6478	3	2004-09-01
5	8294	4396	1	2004-09-01
6	8294	326	3	2004-09-01
1	8295	412	1	2004-09-23
2	8295	3731	2	2004-09-23
3	8295	9542	1	2004-09-23
4	8295	6966	2	2004-09-23
5	8295	7495	3	2004-09-23
6	8295	5405	3	2004-09-23
7	8295	2039	2	2004-09-23
1	8296	5805	1	2004-09-12
2	8296	1682	1	2004-09-12
3	8296	597	2	2004-09-12
4	8296	3755	1	2004-09-12
5	8296	4804	1	2004-09-12
6	8296	7798	2	2004-09-12
7	8296	8196	3	2004-09-12
1	8297	2836	3	2004-09-21
2	8297	536	1	2004-09-21
3	8297	6710	2	2004-09-21
4	8297	7831	3	2004-09-21
5	8297	1514	1	2004-09-21
6	8297	1086	2	2004-09-21
1	8298	9172	2	2004-09-27
1	8299	4076	2	2004-09-20
2	8299	6010	1	2004-09-20
1	8300	8932	3	2004-09-09
2	8300	3411	3	2004-09-09
3	8300	7361	1	2004-09-09
4	8300	5408	2	2004-09-09
5	8300	8868	3	2004-09-09
1	8301	6842	3	2004-09-21
2	8301	6001	2	2004-09-21
3	8301	2767	1	2004-09-21
4	8301	8940	3	2004-09-21
5	8301	3864	1	2004-09-21
1	8302	2573	3	2004-09-14
2	8302	2216	1	2004-09-14
3	8302	6515	2	2004-09-14
4	8302	972	2	2004-09-14
5	8302	5746	2	2004-09-14
6	8302	9067	2	2004-09-14
7	8302	3300	2	2004-09-14
1	8303	1264	3	2004-09-14
2	8303	7420	2	2004-09-14
1	8304	9375	3	2004-09-30
2	8304	3660	2	2004-09-30
3	8304	5792	2	2004-09-30
4	8304	4144	3	2004-09-30
1	8305	4533	3	2004-09-24
2	8305	5087	2	2004-09-24
3	8305	3992	3	2004-09-24
4	8305	9443	3	2004-09-24
5	8305	2939	1	2004-09-24
6	8305	9963	2	2004-09-24
7	8305	8228	3	2004-09-24
8	8305	8232	3	2004-09-24
1	8306	296	2	2004-09-12
2	8306	7778	2	2004-09-12
3	8306	1828	1	2004-09-12
1	8307	8272	3	2004-09-13
2	8307	7107	2	2004-09-13
3	8307	709	1	2004-09-13
4	8307	1744	1	2004-09-13
5	8307	9654	2	2004-09-13
6	8307	987	3	2004-09-13
7	8307	8884	3	2004-09-13
1	8308	9120	3	2004-09-21
1	8309	5502	3	2004-09-12
2	8309	3555	3	2004-09-12
1	8310	3242	2	2004-09-19
2	8310	7914	2	2004-09-19
3	8310	5528	3	2004-09-19
4	8310	4103	2	2004-09-19
5	8310	4338	2	2004-09-19
1	8311	336	1	2004-09-15
2	8311	2535	3	2004-09-15
1	8312	8025	2	2004-09-03
2	8312	2580	1	2004-09-03
3	8312	3968	3	2004-09-03
4	8312	7712	1	2004-09-03
5	8312	3421	1	2004-09-03
6	8312	5723	1	2004-09-03
1	8313	6431	2	2004-09-15
2	8313	4096	1	2004-09-15
3	8313	8548	3	2004-09-15
4	8313	3022	3	2004-09-15
5	8313	64	2	2004-09-15
6	8313	8338	1	2004-09-15
7	8313	1947	3	2004-09-15
8	8313	6888	3	2004-09-15
9	8313	1578	3	2004-09-15
1	8314	6837	1	2004-09-05
2	8314	216	1	2004-09-05
3	8314	3087	2	2004-09-05
4	8314	3809	2	2004-09-05
5	8314	4126	1	2004-09-05
6	8314	9404	3	2004-09-05
7	8314	1467	3	2004-09-05
8	8314	6619	2	2004-09-05
9	8314	6835	3	2004-09-05
1	8315	2378	2	2004-09-01
2	8315	1964	2	2004-09-01
1	8316	2777	2	2004-09-13
2	8316	4150	1	2004-09-13
3	8316	8895	3	2004-09-13
1	8317	2943	1	2004-09-25
2	8317	460	2	2004-09-25
3	8317	8667	3	2004-09-25
1	8318	672	1	2004-09-27
2	8318	935	1	2004-09-27
3	8318	6071	1	2004-09-27
4	8318	7005	1	2004-09-27
5	8318	6412	2	2004-09-27
6	8318	2533	3	2004-09-27
7	8318	2840	3	2004-09-27
8	8318	2182	1	2004-09-27
9	8318	3919	1	2004-09-27
1	8319	5945	1	2004-09-14
2	8319	1791	2	2004-09-14
3	8319	71	1	2004-09-14
4	8319	112	2	2004-09-14
5	8319	9633	1	2004-09-14
6	8319	5304	1	2004-09-14
7	8319	3833	1	2004-09-14
1	8320	7342	2	2004-09-11
2	8320	9064	1	2004-09-11
3	8320	725	1	2004-09-11
4	8320	1916	2	2004-09-11
5	8320	1539	2	2004-09-11
6	8320	9873	2	2004-09-11
7	8320	3736	2	2004-09-11
8	8320	7064	2	2004-09-11
9	8320	429	3	2004-09-11
1	8321	1324	2	2004-09-19
2	8321	6414	2	2004-09-19
3	8321	7643	3	2004-09-19
4	8321	5993	3	2004-09-19
5	8321	9752	2	2004-09-19
6	8321	3195	3	2004-09-19
1	8322	8562	1	2004-09-11
2	8322	1786	3	2004-09-11
3	8322	5670	2	2004-09-11
4	8322	4252	1	2004-09-11
5	8322	1047	2	2004-09-11
1	8323	3109	2	2004-09-30
1	8324	9400	3	2004-09-22
2	8324	3895	3	2004-09-22
3	8324	1026	3	2004-09-22
4	8324	7967	2	2004-09-22
5	8324	1008	3	2004-09-22
1	8325	8003	2	2004-09-30
2	8325	7278	1	2004-09-30
1	8326	5586	1	2004-09-25
2	8326	8726	3	2004-09-25
3	8326	8696	2	2004-09-25
4	8326	8217	1	2004-09-25
5	8326	569	3	2004-09-25
6	8326	8085	2	2004-09-25
7	8326	6767	3	2004-09-25
8	8326	1553	2	2004-09-25
1	8327	2129	1	2004-09-11
2	8327	5380	1	2004-09-11
3	8327	7679	1	2004-09-11
4	8327	2386	2	2004-09-11
1	8328	1473	1	2004-09-03
2	8328	5260	1	2004-09-03
3	8328	8151	2	2004-09-03
4	8328	561	3	2004-09-03
5	8328	1091	3	2004-09-03
6	8328	3183	3	2004-09-03
1	8329	7296	2	2004-09-24
2	8329	5029	3	2004-09-24
1	8330	3065	1	2004-09-24
2	8330	1117	2	2004-09-24
3	8330	1261	2	2004-09-24
4	8330	610	1	2004-09-24
5	8330	7041	2	2004-09-24
1	8331	3911	1	2004-09-09
2	8331	2107	3	2004-09-09
3	8331	8291	3	2004-09-09
4	8331	1829	1	2004-09-09
1	8332	8549	2	2004-09-04
2	8332	6705	3	2004-09-04
3	8332	9370	3	2004-09-04
4	8332	46	1	2004-09-04
5	8332	3813	1	2004-09-04
6	8332	5202	2	2004-09-04
1	8333	7434	3	2004-09-13
2	8333	399	1	2004-09-13
3	8333	70	1	2004-09-13
4	8333	8437	3	2004-09-13
5	8333	2367	1	2004-09-13
6	8333	9239	2	2004-09-13
7	8333	9390	2	2004-09-13
1	8334	6042	3	2004-09-30
2	8334	6404	2	2004-09-30
3	8334	9280	1	2004-09-30
4	8334	7393	2	2004-09-30
5	8334	4639	1	2004-09-30
6	8334	6724	2	2004-09-30
1	8335	5500	2	2004-09-26
2	8335	1273	2	2004-09-26
3	8335	2994	2	2004-09-26
4	8335	4203	1	2004-09-26
5	8335	7275	2	2004-09-26
6	8335	7699	3	2004-09-26
7	8335	1530	3	2004-09-26
8	8335	3841	3	2004-09-26
1	8336	461	1	2004-09-18
2	8336	9679	2	2004-09-18
3	8336	2482	2	2004-09-18
4	8336	30	1	2004-09-18
5	8336	559	2	2004-09-18
1	8337	9996	1	2004-09-29
1	8338	7790	1	2004-09-14
2	8338	9011	3	2004-09-14
1	8339	3097	1	2004-09-28
2	8339	393	2	2004-09-28
3	8339	1600	1	2004-09-28
4	8339	8657	2	2004-09-28
5	8339	6473	3	2004-09-28
1	8340	3089	1	2004-09-15
2	8340	5442	1	2004-09-15
3	8340	4734	3	2004-09-15
4	8340	7282	3	2004-09-15
5	8340	1778	2	2004-09-15
1	8341	3641	1	2004-09-05
1	8342	293	2	2004-09-18
2	8342	6278	3	2004-09-18
3	8342	7513	1	2004-09-18
4	8342	7637	1	2004-09-18
5	8342	9781	1	2004-09-18
6	8342	6994	1	2004-09-18
1	8343	2408	1	2004-09-11
2	8343	7351	2	2004-09-11
3	8343	8307	3	2004-09-11
4	8343	4973	1	2004-09-11
5	8343	9313	3	2004-09-11
6	8343	3979	2	2004-09-11
7	8343	5349	2	2004-09-11
8	8343	1333	2	2004-09-11
1	8344	360	1	2004-09-28
2	8344	9198	1	2004-09-28
3	8344	3146	2	2004-09-28
4	8344	3009	2	2004-09-28
5	8344	8627	3	2004-09-28
6	8344	4736	1	2004-09-28
7	8344	2197	1	2004-09-28
1	8345	3201	1	2004-09-16
1	8346	2990	2	2004-09-27
2	8346	9794	1	2004-09-27
3	8346	4161	2	2004-09-27
4	8346	8984	2	2004-09-27
1	8347	4372	3	2004-09-20
2	8347	6332	1	2004-09-20
3	8347	6631	1	2004-09-20
4	8347	4031	3	2004-09-20
5	8347	3154	3	2004-09-20
6	8347	9331	2	2004-09-20
7	8347	9439	1	2004-09-20
8	8347	4024	3	2004-09-20
9	8347	9710	3	2004-09-20
1	8348	4930	3	2004-09-08
2	8348	6573	2	2004-09-08
1	8349	2944	2	2004-09-14
2	8349	6801	3	2004-09-14
3	8349	9461	2	2004-09-14
4	8349	342	2	2004-09-14
5	8349	2259	2	2004-09-14
6	8349	2740	1	2004-09-14
7	8349	7428	1	2004-09-14
8	8349	4121	1	2004-09-14
9	8349	419	2	2004-09-14
1	8350	4999	1	2004-09-03
2	8350	6438	1	2004-09-03
3	8350	5371	1	2004-09-03
4	8350	4756	3	2004-09-03
5	8350	43	3	2004-09-03
6	8350	3927	3	2004-09-03
1	8351	6879	1	2004-09-21
2	8351	811	3	2004-09-21
3	8351	4122	3	2004-09-21
4	8351	1796	3	2004-09-21
5	8351	9690	1	2004-09-21
6	8351	2072	1	2004-09-21
7	8351	5027	3	2004-09-21
1	8352	1596	2	2004-09-21
2	8352	4215	2	2004-09-21
3	8352	2892	2	2004-09-21
1	8353	207	1	2004-09-13
1	8354	6704	3	2004-09-26
2	8354	7389	3	2004-09-26
3	8354	6267	3	2004-09-26
4	8354	714	3	2004-09-26
5	8354	7461	2	2004-09-26
6	8354	6938	2	2004-09-26
7	8354	5765	3	2004-09-26
8	8354	7633	3	2004-09-26
9	8354	2425	1	2004-09-26
1	8355	2136	3	2004-09-12
2	8355	8788	1	2004-09-12
3	8355	8577	3	2004-09-12
4	8355	9427	1	2004-09-12
5	8355	6278	2	2004-09-12
6	8355	507	2	2004-09-12
7	8355	4629	3	2004-09-12
1	8356	1082	1	2004-09-03
2	8356	2532	3	2004-09-03
3	8356	9045	1	2004-09-03
4	8356	4207	1	2004-09-03
5	8356	2012	3	2004-09-03
6	8356	6787	3	2004-09-03
7	8356	5682	3	2004-09-03
8	8356	5319	2	2004-09-03
1	8357	6376	3	2004-09-04
1	8358	3656	1	2004-09-21
2	8358	6789	3	2004-09-21
1	8359	4716	3	2004-09-02
2	8359	3184	3	2004-09-02
3	8359	1329	2	2004-09-02
1	8360	7037	3	2004-09-21
2	8360	6991	3	2004-09-21
3	8360	2524	3	2004-09-21
1	8361	5782	3	2004-09-27
2	8361	7254	3	2004-09-27
3	8361	283	2	2004-09-27
4	8361	8203	1	2004-09-27
5	8361	1912	3	2004-09-27
6	8361	3791	2	2004-09-27
1	8362	2169	1	2004-09-27
1	8363	4108	1	2004-09-25
2	8363	3656	2	2004-09-25
3	8363	487	1	2004-09-25
4	8363	5531	3	2004-09-25
5	8363	8450	1	2004-09-25
1	8364	9744	3	2004-09-15
2	8364	5998	1	2004-09-15
3	8364	7970	3	2004-09-15
4	8364	8281	3	2004-09-15
5	8364	6762	2	2004-09-15
1	8365	4408	1	2004-09-22
2	8365	728	3	2004-09-22
3	8365	3026	2	2004-09-22
4	8365	5146	2	2004-09-22
5	8365	7026	1	2004-09-22
1	8366	1177	1	2004-09-02
2	8366	630	1	2004-09-02
3	8366	1688	2	2004-09-02
4	8366	2575	3	2004-09-02
5	8366	6415	1	2004-09-02
1	8367	2105	1	2004-09-20
2	8367	8925	2	2004-09-20
3	8367	2026	3	2004-09-20
4	8367	5028	2	2004-09-20
1	8368	849	3	2004-09-13
1	8369	5572	2	2004-09-20
2	8369	8631	3	2004-09-20
3	8369	1678	1	2004-09-20
4	8369	6917	3	2004-09-20
5	8369	2061	2	2004-09-20
6	8369	1268	3	2004-09-20
7	8369	6972	2	2004-09-20
1	8370	5548	2	2004-09-23
2	8370	4723	3	2004-09-23
3	8370	5085	1	2004-09-23
4	8370	641	2	2004-09-23
5	8370	2305	3	2004-09-23
6	8370	8770	3	2004-09-23
7	8370	4885	2	2004-09-23
8	8370	1778	2	2004-09-23
9	8370	1601	2	2004-09-23
1	8371	1935	1	2004-09-15
2	8371	3526	3	2004-09-15
3	8371	6187	1	2004-09-15
4	8371	4803	2	2004-09-15
5	8371	843	1	2004-09-15
6	8371	983	2	2004-09-15
7	8371	9932	2	2004-09-15
1	8372	7746	1	2004-09-27
2	8372	7880	1	2004-09-27
1	8373	3114	1	2004-09-16
2	8373	5230	2	2004-09-16
3	8373	7646	3	2004-09-16
4	8373	7476	1	2004-09-16
5	8373	6071	2	2004-09-16
6	8373	2343	1	2004-09-16
7	8373	9733	1	2004-09-16
1	8374	6784	3	2004-09-04
2	8374	1726	3	2004-09-04
1	8375	2102	2	2004-09-27
2	8375	6289	3	2004-09-27
3	8375	1380	3	2004-09-27
4	8375	9111	2	2004-09-27
5	8375	4063	3	2004-09-27
6	8375	3773	1	2004-09-27
1	8376	716	2	2004-09-24
1	8377	3092	1	2004-09-11
2	8377	9801	2	2004-09-11
1	8378	5183	2	2004-09-04
1	8379	873	2	2004-09-17
2	8379	3424	2	2004-09-17
3	8379	503	3	2004-09-17
4	8379	6472	3	2004-09-17
5	8379	7040	1	2004-09-17
6	8379	8701	3	2004-09-17
7	8379	6602	1	2004-09-17
1	8380	4678	2	2004-09-30
2	8380	7602	2	2004-09-30
3	8380	2710	1	2004-09-30
1	8381	9362	1	2004-09-20
2	8381	8912	1	2004-09-20
1	8382	9532	1	2004-09-20
2	8382	5592	2	2004-09-20
3	8382	3310	2	2004-09-20
4	8382	4326	3	2004-09-20
5	8382	6447	2	2004-09-20
6	8382	2159	1	2004-09-20
7	8382	6803	3	2004-09-20
1	8383	6293	3	2004-09-15
2	8383	5563	2	2004-09-15
3	8383	1485	2	2004-09-15
4	8383	7483	1	2004-09-15
5	8383	5159	2	2004-09-15
6	8383	2732	1	2004-09-15
7	8383	1303	1	2004-09-15
1	8384	1187	1	2004-09-06
2	8384	5188	3	2004-09-06
3	8384	7177	3	2004-09-06
4	8384	8437	2	2004-09-06
5	8384	4183	2	2004-09-06
1	8385	6298	2	2004-09-26
2	8385	9245	3	2004-09-26
3	8385	1559	3	2004-09-26
4	8385	8179	3	2004-09-26
5	8385	869	1	2004-09-26
1	8386	9067	1	2004-09-22
2	8386	4288	1	2004-09-22
3	8386	5164	3	2004-09-22
4	8386	7886	1	2004-09-22
5	8386	6821	2	2004-09-22
6	8386	6319	1	2004-09-22
7	8386	9722	2	2004-09-22
8	8386	7913	1	2004-09-22
9	8386	9376	2	2004-09-22
1	8387	5348	1	2004-09-23
2	8387	5701	2	2004-09-23
3	8387	1081	1	2004-09-23
4	8387	8388	2	2004-09-23
5	8387	1755	3	2004-09-23
6	8387	6259	2	2004-09-23
7	8387	7707	1	2004-09-23
8	8387	5516	2	2004-09-23
9	8387	3763	1	2004-09-23
1	8388	4782	1	2004-09-06
2	8388	2428	2	2004-09-06
1	8389	8836	3	2004-09-17
2	8389	7624	2	2004-09-17
3	8389	4340	3	2004-09-17
4	8389	7280	1	2004-09-17
5	8389	2956	3	2004-09-17
6	8389	182	3	2004-09-17
7	8389	5076	3	2004-09-17
1	8390	2929	2	2004-09-02
2	8390	4479	2	2004-09-02
3	8390	7030	3	2004-09-02
4	8390	7519	3	2004-09-02
1	8391	433	3	2004-09-11
2	8391	4317	3	2004-09-11
3	8391	2681	3	2004-09-11
4	8391	6759	3	2004-09-11
5	8391	1383	3	2004-09-11
6	8391	8995	1	2004-09-11
1	8392	4663	1	2004-09-27
2	8392	3963	3	2004-09-27
3	8392	8325	3	2004-09-27
4	8392	3858	2	2004-09-27
5	8392	7702	1	2004-09-27
6	8392	4812	1	2004-09-27
7	8392	4356	2	2004-09-27
8	8392	7312	2	2004-09-27
9	8392	2266	1	2004-09-27
1	8393	4907	1	2004-09-09
2	8393	9317	2	2004-09-09
3	8393	3228	3	2004-09-09
4	8393	7972	1	2004-09-09
5	8393	7810	1	2004-09-09
6	8393	5610	1	2004-09-09
7	8393	224	2	2004-09-09
8	8393	215	2	2004-09-09
9	8393	9289	3	2004-09-09
1	8394	8220	2	2004-09-17
2	8394	4602	1	2004-09-17
3	8394	7973	3	2004-09-17
4	8394	5431	3	2004-09-17
5	8394	7049	1	2004-09-17
6	8394	9920	2	2004-09-17
7	8394	4239	1	2004-09-17
8	8394	4611	1	2004-09-17
9	8394	5827	1	2004-09-17
1	8395	5371	2	2004-09-15
2	8395	9149	2	2004-09-15
3	8395	2324	2	2004-09-15
4	8395	8759	1	2004-09-15
5	8395	4420	3	2004-09-15
1	8396	6467	1	2004-09-24
2	8396	3931	2	2004-09-24
3	8396	3232	2	2004-09-24
4	8396	9880	3	2004-09-24
5	8396	6999	2	2004-09-24
6	8396	9680	1	2004-09-24
1	8397	9591	3	2004-09-21
1	8398	3345	1	2004-09-17
2	8398	9192	3	2004-09-17
3	8398	28	3	2004-09-17
4	8398	6785	3	2004-09-17
5	8398	2571	1	2004-09-17
6	8398	386	2	2004-09-17
7	8398	6766	2	2004-09-17
8	8398	352	2	2004-09-17
1	8399	175	3	2004-09-04
1	8400	4066	2	2004-09-16
2	8400	3620	3	2004-09-16
3	8400	2493	3	2004-09-16
4	8400	1404	1	2004-09-16
5	8400	4729	1	2004-09-16
1	8401	4764	3	2004-09-26
2	8401	7650	1	2004-09-26
1	8402	5351	3	2004-09-09
2	8402	4779	2	2004-09-09
3	8402	7353	1	2004-09-09
4	8402	9961	2	2004-09-09
1	8403	2381	2	2004-09-15
2	8403	5534	2	2004-09-15
3	8403	5335	1	2004-09-15
4	8403	5216	2	2004-09-15
5	8403	1775	2	2004-09-15
6	8403	5061	2	2004-09-15
7	8403	3445	1	2004-09-15
8	8403	8068	2	2004-09-15
1	8404	5550	2	2004-09-03
2	8404	1587	1	2004-09-03
3	8404	5228	1	2004-09-03
4	8404	9403	1	2004-09-03
5	8404	5573	1	2004-09-03
6	8404	8746	3	2004-09-03
1	8405	4541	3	2004-09-13
2	8405	3458	2	2004-09-13
3	8405	1090	3	2004-09-13
4	8405	2855	2	2004-09-13
5	8405	1228	1	2004-09-13
6	8405	904	1	2004-09-13
7	8405	7164	1	2004-09-13
8	8405	8000	1	2004-09-13
9	8405	6443	3	2004-09-13
1	8406	1848	3	2004-09-17
2	8406	5578	1	2004-09-17
3	8406	4658	3	2004-09-17
4	8406	4873	2	2004-09-17
5	8406	9335	3	2004-09-17
1	8407	1311	3	2004-09-11
2	8407	8972	1	2004-09-11
3	8407	9506	3	2004-09-11
4	8407	4477	3	2004-09-11
1	8408	2062	2	2004-09-04
2	8408	9272	1	2004-09-04
3	8408	13	1	2004-09-04
4	8408	9900	2	2004-09-04
5	8408	1713	2	2004-09-04
6	8408	5379	2	2004-09-04
7	8408	953	2	2004-09-04
1	8409	8737	3	2004-09-18
2	8409	312	3	2004-09-18
1	8410	6487	3	2004-09-05
2	8410	8307	2	2004-09-05
3	8410	6341	1	2004-09-05
4	8410	865	2	2004-09-05
5	8410	3563	1	2004-09-05
6	8410	6733	2	2004-09-05
1	8411	5031	3	2004-09-20
2	8411	6559	1	2004-09-20
1	8412	2880	1	2004-09-10
2	8412	9714	2	2004-09-10
1	8413	6036	3	2004-09-09
2	8413	5242	1	2004-09-09
3	8413	8739	2	2004-09-09
4	8413	7990	1	2004-09-09
5	8413	6983	2	2004-09-09
6	8413	5764	2	2004-09-09
7	8413	3167	2	2004-09-09
8	8413	5295	3	2004-09-09
9	8413	2755	1	2004-09-09
1	8414	8032	3	2004-09-28
2	8414	5053	3	2004-09-28
1	8415	7311	1	2004-09-10
2	8415	1466	1	2004-09-10
3	8415	3453	1	2004-09-10
1	8416	6163	3	2004-09-26
2	8416	9090	3	2004-09-26
3	8416	2053	2	2004-09-26
4	8416	7527	2	2004-09-26
5	8416	6238	3	2004-09-26
6	8416	831	1	2004-09-26
1	8417	6608	2	2004-09-27
2	8417	1727	1	2004-09-27
3	8417	7077	3	2004-09-27
4	8417	2724	3	2004-09-27
1	8418	7618	1	2004-09-05
1	8419	3109	1	2004-09-18
2	8419	9363	1	2004-09-18
3	8419	6381	2	2004-09-18
4	8419	7387	3	2004-09-18
5	8419	7754	2	2004-09-18
1	8420	2686	1	2004-09-19
2	8420	4329	3	2004-09-19
3	8420	675	3	2004-09-19
1	8421	2511	1	2004-09-25
2	8421	8303	3	2004-09-25
3	8421	4626	3	2004-09-25
4	8421	3376	3	2004-09-25
5	8421	9399	1	2004-09-25
6	8421	8369	2	2004-09-25
7	8421	8338	2	2004-09-25
1	8422	4796	1	2004-09-09
2	8422	1745	3	2004-09-09
3	8422	3426	2	2004-09-09
4	8422	7242	2	2004-09-09
5	8422	3126	2	2004-09-09
6	8422	6364	2	2004-09-09
7	8422	2595	3	2004-09-09
8	8422	7201	1	2004-09-09
9	8422	7273	1	2004-09-09
1	8423	3387	3	2004-09-27
2	8423	3901	1	2004-09-27
3	8423	3683	3	2004-09-27
4	8423	7816	2	2004-09-27
5	8423	5955	1	2004-09-27
6	8423	7349	3	2004-09-27
7	8423	92	1	2004-09-27
8	8423	3773	3	2004-09-27
1	8424	3253	2	2004-09-15
2	8424	112	1	2004-09-15
1	8425	8033	1	2004-09-20
2	8425	3215	1	2004-09-20
3	8425	9764	3	2004-09-20
4	8425	3144	2	2004-09-20
5	8425	4006	1	2004-09-20
1	8426	7660	2	2004-09-28
2	8426	7129	1	2004-09-28
3	8426	995	1	2004-09-28
4	8426	8330	2	2004-09-28
5	8426	3240	1	2004-09-28
6	8426	9347	2	2004-09-28
1	8427	811	3	2004-09-07
2	8427	6149	2	2004-09-07
3	8427	187	2	2004-09-07
4	8427	1141	1	2004-09-07
1	8428	5107	3	2004-09-29
2	8428	4720	1	2004-09-29
3	8428	1521	1	2004-09-29
4	8428	4198	1	2004-09-29
5	8428	3850	1	2004-09-29
6	8428	6389	3	2004-09-29
7	8428	4109	2	2004-09-29
8	8428	440	2	2004-09-29
1	8429	9942	2	2004-09-05
2	8429	6289	1	2004-09-05
3	8429	2517	3	2004-09-05
1	8430	240	3	2004-09-11
2	8430	5605	2	2004-09-11
3	8430	446	3	2004-09-11
4	8430	6807	2	2004-09-11
5	8430	9641	1	2004-09-11
6	8430	7170	2	2004-09-11
7	8430	7746	1	2004-09-11
1	8431	9361	3	2004-09-06
2	8431	5481	3	2004-09-06
3	8431	4480	1	2004-09-06
1	8432	8872	1	2004-09-29
2	8432	633	3	2004-09-29
3	8432	9452	2	2004-09-29
1	8433	4541	1	2004-09-13
1	8434	2989	1	2004-09-05
2	8434	7464	1	2004-09-05
3	8434	4013	3	2004-09-05
4	8434	8286	3	2004-09-05
5	8434	6126	1	2004-09-05
6	8434	1262	2	2004-09-05
7	8434	9762	1	2004-09-05
8	8434	8442	3	2004-09-05
9	8434	2230	3	2004-09-05
1	8435	1580	3	2004-09-24
2	8435	2689	2	2004-09-24
1	8436	3499	1	2004-09-06
1	8437	7786	3	2004-09-05
2	8437	5013	2	2004-09-05
3	8437	2280	2	2004-09-05
4	8437	9465	1	2004-09-05
5	8437	6733	3	2004-09-05
1	8438	645	1	2004-09-03
2	8438	230	1	2004-09-03
3	8438	969	1	2004-09-03
4	8438	8345	1	2004-09-03
5	8438	7140	2	2004-09-03
6	8438	3358	1	2004-09-03
7	8438	6995	2	2004-09-03
8	8438	1600	3	2004-09-03
1	8439	3295	1	2004-09-02
2	8439	1672	1	2004-09-02
3	8439	2058	3	2004-09-02
4	8439	667	1	2004-09-02
5	8439	7367	3	2004-09-02
1	8440	236	1	2004-09-04
2	8440	4296	3	2004-09-04
1	8441	2073	1	2004-09-11
2	8441	1780	2	2004-09-11
3	8441	9973	1	2004-09-11
4	8441	3057	3	2004-09-11
5	8441	7561	2	2004-09-11
6	8441	7728	3	2004-09-11
7	8441	9111	3	2004-09-11
1	8442	7426	2	2004-09-23
2	8442	3015	3	2004-09-23
3	8442	5041	1	2004-09-23
4	8442	8278	3	2004-09-23
5	8442	1830	1	2004-09-23
1	8443	8334	1	2004-09-03
2	8443	6516	3	2004-09-03
3	8443	2695	3	2004-09-03
1	8444	9488	2	2004-09-19
2	8444	3529	3	2004-09-19
3	8444	4812	2	2004-09-19
4	8444	2127	1	2004-09-19
1	8445	8391	3	2004-09-30
2	8445	4085	1	2004-09-30
3	8445	9716	2	2004-09-30
4	8445	6804	3	2004-09-30
5	8445	7700	2	2004-09-30
1	8446	3787	3	2004-09-27
2	8446	1949	3	2004-09-27
1	8447	8561	3	2004-09-10
2	8447	2779	1	2004-09-10
3	8447	1791	1	2004-09-10
4	8447	5829	1	2004-09-10
5	8447	7235	2	2004-09-10
6	8447	9275	1	2004-09-10
7	8447	4439	3	2004-09-10
1	8448	6380	2	2004-09-19
2	8448	8089	3	2004-09-19
3	8448	8146	1	2004-09-19
4	8448	9285	1	2004-09-19
1	8449	9224	1	2004-09-05
2	8449	5883	1	2004-09-05
3	8449	778	3	2004-09-05
4	8449	4488	2	2004-09-05
5	8449	9068	1	2004-09-05
6	8449	824	3	2004-09-05
1	8450	6504	2	2004-09-10
2	8450	3090	1	2004-09-10
3	8450	1242	1	2004-09-10
4	8450	2708	3	2004-09-10
5	8450	3055	1	2004-09-10
6	8450	9482	2	2004-09-10
7	8450	4482	1	2004-09-10
8	8450	968	2	2004-09-10
9	8450	1102	3	2004-09-10
1	8451	8484	2	2004-09-18
1	8452	4570	3	2004-09-06
2	8452	4171	1	2004-09-06
3	8452	4053	3	2004-09-06
4	8452	3957	2	2004-09-06
5	8452	8439	2	2004-09-06
1	8453	6133	1	2004-09-15
2	8453	5175	3	2004-09-15
3	8453	6842	2	2004-09-15
4	8453	3951	1	2004-09-15
1	8454	2067	2	2004-09-25
2	8454	5947	2	2004-09-25
3	8454	9608	1	2004-09-25
4	8454	3264	2	2004-09-25
5	8454	1590	3	2004-09-25
6	8454	1038	2	2004-09-25
1	8455	970	1	2004-09-08
2	8455	1455	3	2004-09-08
3	8455	4004	2	2004-09-08
4	8455	4203	1	2004-09-08
5	8455	2906	3	2004-09-08
6	8455	3391	1	2004-09-08
7	8455	6628	2	2004-09-08
1	8456	2693	1	2004-09-24
2	8456	4162	2	2004-09-24
3	8456	4168	2	2004-09-24
4	8456	3273	2	2004-09-24
1	8457	3174	2	2004-09-04
2	8457	4374	2	2004-09-04
3	8457	2755	3	2004-09-04
4	8457	1258	3	2004-09-04
1	8458	5224	1	2004-09-28
2	8458	8742	1	2004-09-28
3	8458	430	3	2004-09-28
1	8459	9079	2	2004-09-20
1	8460	8233	2	2004-09-20
2	8460	1285	1	2004-09-20
3	8460	9621	2	2004-09-20
4	8460	6035	1	2004-09-20
5	8460	4034	3	2004-09-20
6	8460	9332	1	2004-09-20
7	8460	1455	2	2004-09-20
1	8461	9603	2	2004-09-18
2	8461	4132	2	2004-09-18
3	8461	9730	2	2004-09-18
4	8461	6902	3	2004-09-18
5	8461	8127	2	2004-09-18
1	8462	1383	1	2004-09-04
2	8462	797	1	2004-09-04
3	8462	8102	3	2004-09-04
4	8462	3378	1	2004-09-04
5	8462	4123	1	2004-09-04
6	8462	5391	2	2004-09-04
7	8462	7149	1	2004-09-04
8	8462	2256	1	2004-09-04
9	8462	5864	1	2004-09-04
1	8463	4041	2	2004-09-30
2	8463	8470	1	2004-09-30
3	8463	8313	3	2004-09-30
4	8463	9582	3	2004-09-30
5	8463	9019	1	2004-09-30
6	8463	1917	3	2004-09-30
7	8463	1967	1	2004-09-30
8	8463	6645	2	2004-09-30
9	8463	2155	1	2004-09-30
1	8464	8801	3	2004-09-25
2	8464	8528	2	2004-09-25
3	8464	458	3	2004-09-25
4	8464	4660	3	2004-09-25
5	8464	8123	3	2004-09-25
1	8465	6220	1	2004-09-11
2	8465	1202	2	2004-09-11
1	8466	3138	1	2004-09-05
2	8466	8724	2	2004-09-05
3	8466	2465	3	2004-09-05
4	8466	2837	3	2004-09-05
1	8467	6302	3	2004-09-06
1	8468	9662	3	2004-09-27
2	8468	3680	1	2004-09-27
3	8468	1500	3	2004-09-27
4	8468	978	1	2004-09-27
5	8468	5138	1	2004-09-27
6	8468	5821	1	2004-09-27
7	8468	5770	3	2004-09-27
1	8469	1269	3	2004-09-06
2	8469	3160	1	2004-09-06
3	8469	8723	1	2004-09-06
4	8469	3751	2	2004-09-06
1	8470	9804	2	2004-09-26
2	8470	4558	2	2004-09-26
3	8470	6175	2	2004-09-26
4	8470	3384	3	2004-09-26
5	8470	8759	3	2004-09-26
1	8471	3537	1	2004-09-29
2	8471	9804	3	2004-09-29
3	8471	4951	1	2004-09-29
4	8471	4872	3	2004-09-29
5	8471	4318	2	2004-09-29
1	8472	784	2	2004-09-27
2	8472	1901	1	2004-09-27
3	8472	250	2	2004-09-27
4	8472	4072	2	2004-09-27
5	8472	2516	3	2004-09-27
6	8472	3577	1	2004-09-27
7	8472	5977	1	2004-09-27
1	8473	5288	3	2004-09-18
2	8473	7176	1	2004-09-18
3	8473	9307	1	2004-09-18
4	8473	8350	2	2004-09-18
5	8473	5642	3	2004-09-18
6	8473	1692	2	2004-09-18
7	8473	4142	1	2004-09-18
8	8473	8864	2	2004-09-18
9	8473	3064	3	2004-09-18
1	8474	4590	3	2004-09-08
2	8474	6291	1	2004-09-08
3	8474	2235	1	2004-09-08
4	8474	5254	1	2004-09-08
5	8474	1534	1	2004-09-08
1	8475	757	3	2004-09-27
2	8475	1829	2	2004-09-27
3	8475	6156	2	2004-09-27
4	8475	658	1	2004-09-27
5	8475	5997	3	2004-09-27
6	8475	6341	3	2004-09-27
7	8475	8636	3	2004-09-27
8	8475	6195	2	2004-09-27
1	8476	1349	2	2004-09-12
1	8477	7142	2	2004-09-07
2	8477	2536	3	2004-09-07
3	8477	3292	1	2004-09-07
4	8477	7049	2	2004-09-07
1	8478	3502	2	2004-09-30
1	8479	8684	3	2004-09-30
2	8479	2678	1	2004-09-30
3	8479	675	2	2004-09-30
4	8479	2690	1	2004-09-30
5	8479	1489	2	2004-09-30
6	8479	8625	3	2004-09-30
7	8479	8809	2	2004-09-30
8	8479	2762	1	2004-09-30
1	8480	1173	2	2004-09-12
1	8481	4451	2	2004-09-12
2	8481	7283	3	2004-09-12
3	8481	3048	2	2004-09-12
4	8481	8039	2	2004-09-12
5	8481	8507	3	2004-09-12
6	8481	1692	1	2004-09-12
7	8481	737	1	2004-09-12
1	8482	5129	2	2004-09-19
2	8482	6331	3	2004-09-19
3	8482	9668	1	2004-09-19
4	8482	9552	1	2004-09-19
5	8482	5292	2	2004-09-19
1	8483	4508	3	2004-09-02
2	8483	3252	3	2004-09-02
3	8483	4181	1	2004-09-02
4	8483	3280	1	2004-09-02
5	8483	4	2	2004-09-02
1	8484	103	3	2004-09-12
1	8485	4048	1	2004-09-16
2	8485	2345	2	2004-09-16
1	8486	7601	3	2004-09-10
2	8486	8885	1	2004-09-10
3	8486	6236	1	2004-09-10
4	8486	9662	1	2004-09-10
1	8487	7912	3	2004-09-11
2	8487	4171	2	2004-09-11
3	8487	7048	2	2004-09-11
4	8487	5066	1	2004-09-11
1	8488	9973	2	2004-09-29
2	8488	7152	1	2004-09-29
3	8488	3455	2	2004-09-29
4	8488	6882	1	2004-09-29
1	8489	7903	1	2004-09-07
2	8489	8915	1	2004-09-07
3	8489	5766	1	2004-09-07
4	8489	4759	2	2004-09-07
5	8489	9003	3	2004-09-07
6	8489	9739	2	2004-09-07
7	8489	3204	2	2004-09-07
8	8489	8146	1	2004-09-07
1	8490	7439	2	2004-09-08
2	8490	5563	1	2004-09-08
3	8490	7655	1	2004-09-08
1	8491	8416	2	2004-09-06
2	8491	7935	3	2004-09-06
3	8491	7442	2	2004-09-06
4	8491	9348	1	2004-09-06
5	8491	7378	3	2004-09-06
1	8492	1920	1	2004-09-04
2	8492	7042	2	2004-09-04
3	8492	4165	1	2004-09-04
4	8492	6871	1	2004-09-04
1	8493	4877	2	2004-09-21
2	8493	4286	1	2004-09-21
3	8493	9556	1	2004-09-21
4	8493	9200	3	2004-09-21
1	8494	8842	3	2004-09-01
2	8494	7729	3	2004-09-01
3	8494	5684	1	2004-09-01
4	8494	4304	3	2004-09-01
5	8494	4674	1	2004-09-01
6	8494	2012	3	2004-09-01
7	8494	4647	3	2004-09-01
8	8494	442	1	2004-09-01
9	8494	1314	1	2004-09-01
1	8495	9278	3	2004-09-18
1	8496	5119	2	2004-09-09
2	8496	2126	2	2004-09-09
3	8496	4188	3	2004-09-09
1	8497	7475	2	2004-09-12
2	8497	9580	3	2004-09-12
3	8497	5494	2	2004-09-12
4	8497	8368	2	2004-09-12
5	8497	5589	3	2004-09-12
6	8497	8873	1	2004-09-12
7	8497	5872	2	2004-09-12
8	8497	1333	2	2004-09-12
1	8498	6797	3	2004-09-10
2	8498	3244	3	2004-09-10
3	8498	2706	3	2004-09-10
4	8498	8777	2	2004-09-10
5	8498	7303	1	2004-09-10
6	8498	4872	2	2004-09-10
7	8498	7415	2	2004-09-10
1	8499	8843	2	2004-09-13
2	8499	2314	3	2004-09-13
3	8499	5584	3	2004-09-13
1	8500	966	3	2004-09-12
2	8500	4790	3	2004-09-12
3	8500	5707	3	2004-09-12
4	8500	6685	3	2004-09-12
5	8500	5464	2	2004-09-12
6	8500	5048	1	2004-09-12
7	8500	6221	3	2004-09-12
1	8501	6543	1	2004-09-23
2	8501	4439	2	2004-09-23
1	8502	4938	3	2004-09-22
2	8502	9815	3	2004-09-22
3	8502	4239	1	2004-09-22
1	8503	7060	2	2004-09-16
1	8504	5289	3	2004-09-29
2	8504	4317	1	2004-09-29
3	8504	542	3	2004-09-29
4	8504	4640	3	2004-09-29
1	8505	5831	2	2004-09-06
2	8505	1947	1	2004-09-06
3	8505	2643	1	2004-09-06
4	8505	9039	3	2004-09-06
5	8505	2541	2	2004-09-06
6	8505	5909	1	2004-09-06
7	8505	5211	1	2004-09-06
8	8505	6309	2	2004-09-06
9	8505	5491	3	2004-09-06
1	8506	3611	2	2004-09-27
2	8506	1963	3	2004-09-27
3	8506	1528	2	2004-09-27
1	8507	9568	2	2004-09-22
2	8507	3926	1	2004-09-22
3	8507	6452	1	2004-09-22
1	8508	75	1	2004-09-28
2	8508	7967	2	2004-09-28
3	8508	7008	2	2004-09-28
4	8508	3378	2	2004-09-28
5	8508	4236	3	2004-09-28
1	8509	6096	1	2004-09-28
2	8509	4902	2	2004-09-28
1	8510	2338	1	2004-09-22
2	8510	9025	3	2004-09-22
3	8510	3472	3	2004-09-22
4	8510	7782	1	2004-09-22
5	8510	3114	3	2004-09-22
6	8510	3154	1	2004-09-22
7	8510	4238	1	2004-09-22
1	8511	4895	2	2004-09-14
2	8511	6618	2	2004-09-14
3	8511	6574	1	2004-09-14
4	8511	9868	1	2004-09-14
5	8511	6137	3	2004-09-14
6	8511	9122	1	2004-09-14
7	8511	3930	1	2004-09-14
8	8511	3227	1	2004-09-14
1	8512	7405	2	2004-09-01
2	8512	5885	1	2004-09-01
3	8512	5264	1	2004-09-01
4	8512	720	3	2004-09-01
5	8512	7738	3	2004-09-01
6	8512	8572	1	2004-09-01
7	8512	2218	2	2004-09-01
8	8512	9250	3	2004-09-01
1	8513	6232	3	2004-09-24
2	8513	6759	1	2004-09-24
3	8513	846	3	2004-09-24
4	8513	3116	1	2004-09-24
1	8514	8368	2	2004-09-21
2	8514	4646	2	2004-09-21
3	8514	5131	2	2004-09-21
4	8514	3432	1	2004-09-21
1	8515	7193	2	2004-09-07
2	8515	3222	2	2004-09-07
3	8515	3867	2	2004-09-07
4	8515	9135	1	2004-09-07
1	8516	5878	2	2004-09-09
2	8516	4813	1	2004-09-09
3	8516	7561	2	2004-09-09
4	8516	6648	2	2004-09-09
1	8517	6659	1	2004-09-27
2	8517	6942	3	2004-09-27
3	8517	4995	1	2004-09-27
4	8517	3302	1	2004-09-27
1	8518	10	2	2004-09-22
1	8519	6603	3	2004-09-04
2	8519	4792	1	2004-09-04
1	8520	8280	2	2004-09-03
2	8520	8689	3	2004-09-03
3	8520	8368	2	2004-09-03
4	8520	831	2	2004-09-03
5	8520	4219	2	2004-09-03
6	8520	7751	3	2004-09-03
7	8520	8012	2	2004-09-03
1	8521	1710	3	2004-09-13
2	8521	6937	2	2004-09-13
3	8521	8572	2	2004-09-13
4	8521	2209	2	2004-09-13
1	8522	352	2	2004-09-15
1	8523	4388	1	2004-09-14
2	8523	8277	3	2004-09-14
3	8523	8488	2	2004-09-14
1	8524	1792	3	2004-09-19
1	8525	7522	1	2004-09-13
2	8525	4700	3	2004-09-13
1	8526	9962	1	2004-09-19
2	8526	5765	2	2004-09-19
1	8527	261	2	2004-09-07
2	8527	5072	3	2004-09-07
3	8527	1835	1	2004-09-07
4	8527	5247	1	2004-09-07
5	8527	1368	3	2004-09-07
6	8527	9772	2	2004-09-07
1	8528	6590	1	2004-09-02
2	8528	7791	1	2004-09-02
3	8528	1106	1	2004-09-02
4	8528	4419	1	2004-09-02
5	8528	3514	1	2004-09-02
6	8528	5630	2	2004-09-02
7	8528	7782	1	2004-09-02
8	8528	2058	3	2004-09-02
1	8529	8327	1	2004-09-27
1	8530	5285	3	2004-09-11
2	8530	7271	1	2004-09-11
3	8530	7676	2	2004-09-11
4	8530	3486	2	2004-09-11
1	8531	5658	3	2004-09-20
1	8532	4447	3	2004-09-04
2	8532	6933	2	2004-09-04
3	8532	4234	2	2004-09-04
4	8532	4215	1	2004-09-04
5	8532	5760	3	2004-09-04
6	8532	2254	2	2004-09-04
7	8532	1196	3	2004-09-04
8	8532	4448	3	2004-09-04
9	8532	9573	1	2004-09-04
1	8533	7648	2	2004-09-07
2	8533	9761	1	2004-09-07
3	8533	2986	1	2004-09-07
4	8533	4592	3	2004-09-07
5	8533	9761	3	2004-09-07
6	8533	5138	3	2004-09-07
7	8533	2452	3	2004-09-07
8	8533	415	2	2004-09-07
1	8534	1008	2	2004-09-06
2	8534	1721	2	2004-09-06
3	8534	4147	1	2004-09-06
4	8534	7579	2	2004-09-06
1	8535	8697	2	2004-09-14
2	8535	5304	1	2004-09-14
1	8536	8934	2	2004-09-18
2	8536	2390	1	2004-09-18
3	8536	4223	1	2004-09-18
4	8536	8052	2	2004-09-18
5	8536	8979	1	2004-09-18
6	8536	335	3	2004-09-18
1	8537	3349	1	2004-09-25
2	8537	8839	3	2004-09-25
3	8537	8188	2	2004-09-25
1	8538	8566	2	2004-09-30
2	8538	4898	3	2004-09-30
3	8538	846	2	2004-09-30
4	8538	3133	1	2004-09-30
5	8538	5218	3	2004-09-30
1	8539	5807	2	2004-09-19
2	8539	5004	2	2004-09-19
3	8539	5897	1	2004-09-19
4	8539	6391	3	2004-09-19
5	8539	3466	2	2004-09-19
1	8540	8537	3	2004-09-21
2	8540	1645	3	2004-09-21
3	8540	3736	2	2004-09-21
4	8540	5383	2	2004-09-21
5	8540	374	3	2004-09-21
6	8540	7817	2	2004-09-21
1	8541	8874	2	2004-09-18
2	8541	3216	2	2004-09-18
3	8541	8693	3	2004-09-18
4	8541	4322	2	2004-09-18
5	8541	8357	3	2004-09-18
6	8541	312	2	2004-09-18
7	8541	9440	3	2004-09-18
8	8541	1943	3	2004-09-18
9	8541	8272	2	2004-09-18
1	8542	6589	1	2004-09-16
1	8543	8261	2	2004-09-27
2	8543	4219	3	2004-09-27
3	8543	9619	3	2004-09-27
4	8543	1011	3	2004-09-27
5	8543	6546	2	2004-09-27
1	8544	202	1	2004-09-11
2	8544	3391	1	2004-09-11
3	8544	536	1	2004-09-11
4	8544	5730	2	2004-09-11
1	8545	6360	2	2004-09-12
1	8546	7404	2	2004-09-14
2	8546	57	3	2004-09-14
3	8546	1544	1	2004-09-14
1	8547	2991	3	2004-09-16
2	8547	2432	1	2004-09-16
3	8547	2079	2	2004-09-16
4	8547	5336	1	2004-09-16
5	8547	7486	1	2004-09-16
6	8547	8228	1	2004-09-16
7	8547	6924	2	2004-09-16
8	8547	1415	1	2004-09-16
1	8548	9001	1	2004-09-29
2	8548	3351	3	2004-09-29
3	8548	160	2	2004-09-29
4	8548	125	2	2004-09-29
5	8548	2983	2	2004-09-29
6	8548	4220	2	2004-09-29
7	8548	6044	2	2004-09-29
8	8548	9166	3	2004-09-29
9	8548	2474	2	2004-09-29
1	8549	1116	1	2004-09-03
2	8549	3265	1	2004-09-03
3	8549	5774	1	2004-09-03
4	8549	8607	1	2004-09-03
5	8549	1855	3	2004-09-03
6	8549	4646	2	2004-09-03
7	8549	6665	2	2004-09-03
8	8549	100	3	2004-09-03
9	8549	298	1	2004-09-03
1	8550	1168	3	2004-09-10
2	8550	7480	2	2004-09-10
3	8550	2721	3	2004-09-10
4	8550	3601	3	2004-09-10
5	8550	7179	2	2004-09-10
6	8550	778	1	2004-09-10
7	8550	7246	2	2004-09-10
8	8550	3058	2	2004-09-10
9	8550	8059	2	2004-09-10
1	8551	7509	1	2004-09-11
1	8552	2323	1	2004-09-21
1	8553	7131	1	2004-09-29
2	8553	5279	1	2004-09-29
3	8553	1581	1	2004-09-29
4	8553	5447	1	2004-09-29
5	8553	2901	1	2004-09-29
6	8553	8911	2	2004-09-29
7	8553	8544	3	2004-09-29
1	8554	2128	3	2004-09-03
1	8555	9268	3	2004-09-04
2	8555	6852	3	2004-09-04
3	8555	799	3	2004-09-04
4	8555	5915	3	2004-09-04
5	8555	718	1	2004-09-04
1	8556	4657	2	2004-09-26
2	8556	6798	2	2004-09-26
3	8556	2509	2	2004-09-26
4	8556	536	2	2004-09-26
1	8557	7390	2	2004-09-23
2	8557	8513	1	2004-09-23
3	8557	66	3	2004-09-23
4	8557	9686	3	2004-09-23
5	8557	6633	1	2004-09-23
6	8557	4341	1	2004-09-23
7	8557	8413	2	2004-09-23
8	8557	3741	3	2004-09-23
9	8557	7356	3	2004-09-23
1	8558	5580	2	2004-09-04
2	8558	3315	2	2004-09-04
3	8558	9830	1	2004-09-04
4	8558	6323	2	2004-09-04
5	8558	131	2	2004-09-04
6	8558	9760	3	2004-09-04
7	8558	6089	3	2004-09-04
8	8558	6425	2	2004-09-04
1	8559	5604	2	2004-09-21
1	8560	6735	1	2004-09-19
2	8560	5508	1	2004-09-19
3	8560	891	1	2004-09-19
4	8560	7128	2	2004-09-19
1	8561	1150	2	2004-09-22
2	8561	7236	1	2004-09-22
3	8561	3639	1	2004-09-22
4	8561	734	1	2004-09-22
1	8562	8557	3	2004-09-28
2	8562	26	2	2004-09-28
3	8562	8066	1	2004-09-28
4	8562	8193	2	2004-09-28
5	8562	4684	2	2004-09-28
1	8563	9780	1	2004-09-17
2	8563	9560	2	2004-09-17
3	8563	5513	1	2004-09-17
1	8564	6074	1	2004-09-29
2	8564	3340	2	2004-09-29
3	8564	9826	2	2004-09-29
1	8565	3079	1	2004-09-02
1	8566	4971	2	2004-09-07
2	8566	2575	3	2004-09-07
3	8566	6125	1	2004-09-07
4	8566	1747	2	2004-09-07
5	8566	6997	3	2004-09-07
6	8566	6393	2	2004-09-07
7	8566	9	3	2004-09-07
1	8567	1253	1	2004-09-30
2	8567	9710	1	2004-09-30
3	8567	8568	2	2004-09-30
1	8568	2917	2	2004-09-07
2	8568	1649	3	2004-09-07
3	8568	9706	2	2004-09-07
4	8568	7646	2	2004-09-07
5	8568	6576	3	2004-09-07
1	8569	208	2	2004-09-05
2	8569	5917	1	2004-09-05
3	8569	2742	2	2004-09-05
4	8569	3370	2	2004-09-05
5	8569	6462	1	2004-09-05
6	8569	5774	2	2004-09-05
7	8569	7970	3	2004-09-05
8	8569	6675	2	2004-09-05
1	8570	7479	1	2004-09-09
2	8570	8624	2	2004-09-09
3	8570	7825	2	2004-09-09
4	8570	4516	3	2004-09-09
1	8571	7828	1	2004-09-27
2	8571	9097	1	2004-09-27
3	8571	9437	1	2004-09-27
4	8571	4564	2	2004-09-27
5	8571	5546	1	2004-09-27
6	8571	928	2	2004-09-27
7	8571	8442	3	2004-09-27
8	8571	9622	1	2004-09-27
9	8571	7195	1	2004-09-27
1	8572	9797	1	2004-09-17
2	8572	9417	2	2004-09-17
3	8572	1068	3	2004-09-17
4	8572	5480	3	2004-09-17
1	8573	3878	1	2004-09-22
2	8573	8729	3	2004-09-22
3	8573	6809	2	2004-09-22
4	8573	8779	3	2004-09-22
5	8573	7790	3	2004-09-22
6	8573	5340	3	2004-09-22
1	8574	7206	1	2004-09-26
2	8574	8227	3	2004-09-26
3	8574	4956	3	2004-09-26
4	8574	1315	2	2004-09-26
1	8575	103	2	2004-09-18
2	8575	9260	2	2004-09-18
3	8575	6717	3	2004-09-18
1	8576	1262	1	2004-09-08
2	8576	8420	2	2004-09-08
1	8577	843	2	2004-09-23
2	8577	9	3	2004-09-23
3	8577	3343	2	2004-09-23
4	8577	6714	2	2004-09-23
5	8577	987	1	2004-09-23
6	8577	1452	2	2004-09-23
7	8577	5542	1	2004-09-23
1	8578	2790	3	2004-09-04
2	8578	1371	2	2004-09-04
3	8578	9152	1	2004-09-04
4	8578	5104	3	2004-09-04
5	8578	9233	1	2004-09-04
6	8578	4406	3	2004-09-04
7	8578	9350	2	2004-09-04
8	8578	4707	3	2004-09-04
1	8579	2705	2	2004-09-13
1	8580	5710	1	2004-09-11
2	8580	3920	1	2004-09-11
3	8580	9603	3	2004-09-11
4	8580	9196	1	2004-09-11
5	8580	1762	3	2004-09-11
6	8580	3605	3	2004-09-11
7	8580	5919	1	2004-09-11
8	8580	9432	1	2004-09-11
9	8580	1204	3	2004-09-11
1	8581	3959	1	2004-09-17
2	8581	922	2	2004-09-17
3	8581	7769	2	2004-09-17
4	8581	820	3	2004-09-17
5	8581	3616	2	2004-09-17
6	8581	155	3	2004-09-17
7	8581	7771	3	2004-09-17
8	8581	4245	3	2004-09-17
9	8581	731	2	2004-09-17
1	8582	7174	1	2004-09-16
2	8582	1556	3	2004-09-16
1	8583	7017	3	2004-09-04
2	8583	1682	3	2004-09-04
3	8583	4908	3	2004-09-04
4	8583	2436	2	2004-09-04
5	8583	7848	2	2004-09-04
6	8583	2256	3	2004-09-04
7	8583	3588	1	2004-09-04
8	8583	7760	3	2004-09-04
9	8583	6993	3	2004-09-04
1	8584	3538	3	2004-09-12
2	8584	9011	2	2004-09-12
3	8584	8376	1	2004-09-12
4	8584	2220	1	2004-09-12
5	8584	9316	3	2004-09-12
6	8584	908	1	2004-09-12
7	8584	7175	2	2004-09-12
1	8585	5662	2	2004-09-02
2	8585	6296	3	2004-09-02
3	8585	3825	2	2004-09-02
4	8585	7081	1	2004-09-02
5	8585	2545	1	2004-09-02
6	8585	3123	2	2004-09-02
7	8585	7626	2	2004-09-02
8	8585	5369	2	2004-09-02
1	8586	6407	2	2004-09-06
2	8586	3208	3	2004-09-06
3	8586	7043	1	2004-09-06
4	8586	3130	3	2004-09-06
1	8587	8470	1	2004-09-30
2	8587	4903	1	2004-09-30
3	8587	6133	1	2004-09-30
4	8587	3113	3	2004-09-30
5	8587	2901	2	2004-09-30
6	8587	4048	1	2004-09-30
1	8588	3161	2	2004-09-09
2	8588	8619	3	2004-09-09
3	8588	9940	1	2004-09-09
4	8588	6882	3	2004-09-09
5	8588	2207	1	2004-09-09
1	8589	7852	1	2004-09-14
1	8590	4737	3	2004-09-07
2	8590	7142	3	2004-09-07
3	8590	4795	1	2004-09-07
4	8590	8163	3	2004-09-07
5	8590	606	2	2004-09-07
6	8590	2336	2	2004-09-07
7	8590	9220	1	2004-09-07
8	8590	3335	3	2004-09-07
1	8591	227	1	2004-09-09
2	8591	7185	2	2004-09-09
3	8591	867	2	2004-09-09
4	8591	8063	1	2004-09-09
5	8591	7792	2	2004-09-09
1	8592	165	3	2004-09-05
2	8592	9993	3	2004-09-05
3	8592	4552	1	2004-09-05
4	8592	3654	3	2004-09-05
5	8592	4366	1	2004-09-05
6	8592	7842	3	2004-09-05
7	8592	2032	1	2004-09-05
8	8592	7916	3	2004-09-05
1	8593	3052	3	2004-09-17
2	8593	7830	1	2004-09-17
3	8593	2849	2	2004-09-17
1	8594	3315	3	2004-09-14
2	8594	3556	1	2004-09-14
3	8594	6642	3	2004-09-14
4	8594	3907	1	2004-09-14
5	8594	4996	3	2004-09-14
6	8594	3168	1	2004-09-14
7	8594	5971	2	2004-09-14
1	8595	2029	1	2004-09-11
2	8595	1859	2	2004-09-11
3	8595	1805	3	2004-09-11
4	8595	6195	2	2004-09-11
5	8595	5310	1	2004-09-11
6	8595	9164	2	2004-09-11
7	8595	7511	1	2004-09-11
8	8595	1771	1	2004-09-11
9	8595	5787	3	2004-09-11
1	8596	7964	1	2004-09-28
2	8596	7006	2	2004-09-28
3	8596	7072	1	2004-09-28
4	8596	7821	1	2004-09-28
1	8597	4930	2	2004-09-29
2	8597	1078	1	2004-09-29
1	8598	9845	3	2004-09-28
2	8598	697	1	2004-09-28
3	8598	518	2	2004-09-28
4	8598	28	3	2004-09-28
5	8598	6175	3	2004-09-28
6	8598	3860	2	2004-09-28
7	8598	608	1	2004-09-28
8	8598	8073	3	2004-09-28
1	8599	5743	1	2004-09-04
1	8600	1795	2	2004-09-07
2	8600	9713	2	2004-09-07
3	8600	2390	3	2004-09-07
1	8601	9568	1	2004-09-10
2	8601	3396	2	2004-09-10
3	8601	9932	3	2004-09-10
4	8601	9881	1	2004-09-10
1	8602	3848	2	2004-09-25
2	8602	307	3	2004-09-25
3	8602	7055	1	2004-09-25
4	8602	261	1	2004-09-25
5	8602	5880	1	2004-09-25
6	8602	6344	2	2004-09-25
7	8602	5792	3	2004-09-25
8	8602	5149	3	2004-09-25
9	8602	1818	2	2004-09-25
1	8603	7129	3	2004-09-09
2	8603	3337	3	2004-09-09
3	8603	7989	1	2004-09-09
4	8603	4963	2	2004-09-09
5	8603	904	3	2004-09-09
6	8603	2545	1	2004-09-09
1	8604	1772	3	2004-09-26
2	8604	716	3	2004-09-26
3	8604	5236	2	2004-09-26
4	8604	6848	1	2004-09-26
5	8604	5488	3	2004-09-26
6	8604	6704	3	2004-09-26
7	8604	51	2	2004-09-26
8	8604	4254	3	2004-09-26
1	8605	9046	3	2004-09-06
2	8605	5866	3	2004-09-06
3	8605	7961	3	2004-09-06
4	8605	1160	2	2004-09-06
5	8605	8010	2	2004-09-06
6	8605	5021	3	2004-09-06
7	8605	4568	2	2004-09-06
8	8605	7896	3	2004-09-06
9	8605	2244	2	2004-09-06
1	8606	5904	2	2004-09-01
2	8606	1112	1	2004-09-01
3	8606	638	1	2004-09-01
4	8606	7748	2	2004-09-01
5	8606	2442	3	2004-09-01
6	8606	3977	3	2004-09-01
7	8606	6743	1	2004-09-01
1	8607	2825	1	2004-09-21
2	8607	4509	3	2004-09-21
3	8607	9054	1	2004-09-21
4	8607	7196	1	2004-09-21
5	8607	7148	3	2004-09-21
1	8608	4014	2	2004-09-28
2	8608	5091	2	2004-09-28
3	8608	8167	1	2004-09-28
4	8608	9478	1	2004-09-28
5	8608	9632	2	2004-09-28
1	8609	4276	2	2004-09-27
2	8609	363	3	2004-09-27
3	8609	7006	2	2004-09-27
4	8609	4493	2	2004-09-27
5	8609	7276	1	2004-09-27
6	8609	7357	2	2004-09-27
1	8610	1318	3	2004-09-28
2	8610	8729	2	2004-09-28
3	8610	3643	3	2004-09-28
4	8610	9247	1	2004-09-28
1	8611	5253	1	2004-09-23
2	8611	2056	3	2004-09-23
3	8611	5652	1	2004-09-23
4	8611	6629	1	2004-09-23
5	8611	7290	1	2004-09-23
6	8611	8716	2	2004-09-23
1	8612	2457	2	2004-09-09
2	8612	5225	2	2004-09-09
1	8613	850	3	2004-09-09
2	8613	9720	3	2004-09-09
3	8613	8308	2	2004-09-09
4	8613	4776	2	2004-09-09
5	8613	8257	3	2004-09-09
6	8613	3088	2	2004-09-09
1	8614	837	2	2004-09-28
2	8614	1104	2	2004-09-28
3	8614	1351	1	2004-09-28
4	8614	5527	2	2004-09-28
5	8614	4057	1	2004-09-28
6	8614	7582	3	2004-09-28
1	8615	7194	1	2004-09-15
2	8615	3910	2	2004-09-15
3	8615	9623	3	2004-09-15
4	8615	9061	3	2004-09-15
5	8615	5517	1	2004-09-15
1	8616	1306	1	2004-09-06
2	8616	3630	1	2004-09-06
3	8616	6347	2	2004-09-06
4	8616	2501	1	2004-09-06
5	8616	8788	2	2004-09-06
6	8616	2626	2	2004-09-06
7	8616	3569	3	2004-09-06
8	8616	4133	3	2004-09-06
1	8617	6827	1	2004-09-09
2	8617	5481	2	2004-09-09
3	8617	8012	1	2004-09-09
4	8617	8035	3	2004-09-09
5	8617	5763	3	2004-09-09
6	8617	8149	3	2004-09-09
7	8617	2600	1	2004-09-09
1	8618	820	2	2004-09-29
2	8618	8533	2	2004-09-29
1	8619	9282	2	2004-09-06
2	8619	7373	3	2004-09-06
3	8619	457	2	2004-09-06
4	8619	9925	2	2004-09-06
5	8619	86	3	2004-09-06
6	8619	6935	3	2004-09-06
1	8620	9764	1	2004-09-24
2	8620	7661	3	2004-09-24
3	8620	9564	2	2004-09-24
4	8620	1218	1	2004-09-24
5	8620	9965	3	2004-09-24
6	8620	3828	1	2004-09-24
1	8621	8264	2	2004-09-06
2	8621	924	3	2004-09-06
1	8622	8785	1	2004-09-29
2	8622	7702	2	2004-09-29
3	8622	4289	2	2004-09-29
4	8622	2402	2	2004-09-29
5	8622	6339	1	2004-09-29
6	8622	3294	2	2004-09-29
7	8622	4481	2	2004-09-29
8	8622	6285	2	2004-09-29
9	8622	4261	1	2004-09-29
1	8623	7244	1	2004-09-19
2	8623	9547	3	2004-09-19
3	8623	1699	3	2004-09-19
4	8623	9017	2	2004-09-19
1	8624	4320	1	2004-09-26
2	8624	2045	3	2004-09-26
3	8624	6291	3	2004-09-26
4	8624	6783	3	2004-09-26
5	8624	4285	1	2004-09-26
6	8624	4094	1	2004-09-26
1	8625	4466	2	2004-09-18
2	8625	6282	1	2004-09-18
1	8626	4871	3	2004-09-26
1	8627	9818	1	2004-09-20
2	8627	6617	1	2004-09-20
3	8627	7733	1	2004-09-20
4	8627	245	2	2004-09-20
1	8628	5098	1	2004-09-08
2	8628	4940	2	2004-09-08
3	8628	3520	3	2004-09-08
4	8628	1174	3	2004-09-08
5	8628	1114	3	2004-09-08
6	8628	5630	1	2004-09-08
1	8629	3994	2	2004-09-29
2	8629	427	2	2004-09-29
3	8629	7591	3	2004-09-29
4	8629	5674	2	2004-09-29
5	8629	9952	2	2004-09-29
6	8629	9839	1	2004-09-29
1	8630	7104	2	2004-09-02
2	8630	1324	1	2004-09-02
3	8630	3372	1	2004-09-02
4	8630	424	2	2004-09-02
5	8630	2044	2	2004-09-02
1	8631	7711	1	2004-09-17
2	8631	1938	3	2004-09-17
3	8631	4357	3	2004-09-17
4	8631	5181	1	2004-09-17
5	8631	4851	2	2004-09-17
1	8632	306	2	2004-09-18
2	8632	1941	3	2004-09-18
3	8632	569	1	2004-09-18
4	8632	8031	2	2004-09-18
5	8632	5762	3	2004-09-18
6	8632	8425	3	2004-09-18
1	8633	9262	3	2004-09-14
1	8634	727	1	2004-09-05
2	8634	5990	2	2004-09-05
3	8634	5628	1	2004-09-05
4	8634	267	1	2004-09-05
5	8634	8334	1	2004-09-05
6	8634	9804	1	2004-09-05
1	8635	4313	3	2004-09-24
2	8635	4465	1	2004-09-24
3	8635	7104	3	2004-09-24
4	8635	6639	2	2004-09-24
5	8635	31	2	2004-09-24
6	8635	3748	1	2004-09-24
1	8636	9558	2	2004-09-22
2	8636	3402	2	2004-09-22
3	8636	5523	2	2004-09-22
4	8636	8388	2	2004-09-22
5	8636	4240	3	2004-09-22
6	8636	4130	1	2004-09-22
7	8636	8564	3	2004-09-22
8	8636	8230	1	2004-09-22
1	8637	1667	1	2004-09-21
2	8637	640	1	2004-09-21
3	8637	8152	2	2004-09-21
4	8637	3332	2	2004-09-21
1	8638	4512	2	2004-09-11
2	8638	8194	1	2004-09-11
3	8638	145	2	2004-09-11
1	8639	6603	2	2004-09-12
2	8639	5687	2	2004-09-12
3	8639	6213	1	2004-09-12
4	8639	7527	1	2004-09-12
5	8639	6722	3	2004-09-12
6	8639	4079	3	2004-09-12
7	8639	891	1	2004-09-12
8	8639	1750	2	2004-09-12
1	8640	8208	3	2004-09-23
1	8641	2982	2	2004-09-22
2	8641	1559	3	2004-09-22
3	8641	1604	3	2004-09-22
4	8641	1091	3	2004-09-22
5	8641	2994	3	2004-09-22
6	8641	9942	1	2004-09-22
7	8641	9130	2	2004-09-22
1	8642	5439	2	2004-09-30
1	8643	3474	3	2004-09-15
2	8643	9637	1	2004-09-15
3	8643	5582	3	2004-09-15
4	8643	7680	3	2004-09-15
5	8643	2917	3	2004-09-15
6	8643	6317	2	2004-09-15
7	8643	7399	3	2004-09-15
8	8643	1810	1	2004-09-15
9	8643	4711	1	2004-09-15
1	8644	7049	1	2004-09-03
1	8645	5406	3	2004-09-04
2	8645	6033	3	2004-09-04
3	8645	8367	2	2004-09-04
4	8645	9383	2	2004-09-04
5	8645	5001	3	2004-09-04
6	8645	2511	3	2004-09-04
1	8646	6235	2	2004-09-19
2	8646	4091	1	2004-09-19
3	8646	5997	2	2004-09-19
4	8646	4785	2	2004-09-19
1	8647	4319	2	2004-09-17
2	8647	2916	3	2004-09-17
3	8647	4250	3	2004-09-17
4	8647	8603	1	2004-09-17
5	8647	4617	3	2004-09-17
6	8647	6564	3	2004-09-17
7	8647	5046	3	2004-09-17
1	8648	5043	2	2004-09-23
2	8648	4215	3	2004-09-23
3	8648	5080	1	2004-09-23
4	8648	4136	3	2004-09-23
5	8648	4623	3	2004-09-23
6	8648	1697	1	2004-09-23
7	8648	6624	2	2004-09-23
8	8648	6536	3	2004-09-23
9	8648	5740	1	2004-09-23
1	8649	2326	3	2004-09-26
2	8649	2723	3	2004-09-26
3	8649	9040	1	2004-09-26
1	8650	1076	2	2004-09-27
2	8650	2890	2	2004-09-27
3	8650	4652	3	2004-09-27
4	8650	6020	3	2004-09-27
1	8651	3732	3	2004-09-21
2	8651	2954	3	2004-09-21
3	8651	8067	1	2004-09-21
4	8651	3812	1	2004-09-21
1	8652	3508	1	2004-09-14
2	8652	7525	1	2004-09-14
3	8652	7412	3	2004-09-14
4	8652	5981	3	2004-09-14
5	8652	2190	3	2004-09-14
6	8652	4644	3	2004-09-14
7	8652	5895	1	2004-09-14
1	8653	6098	1	2004-09-19
2	8653	4143	3	2004-09-19
3	8653	1582	1	2004-09-19
4	8653	493	2	2004-09-19
5	8653	3677	2	2004-09-19
6	8653	1531	2	2004-09-19
7	8653	2307	2	2004-09-19
1	8654	7581	1	2004-09-17
2	8654	1481	3	2004-09-17
3	8654	2112	2	2004-09-17
1	8655	691	2	2004-09-20
2	8655	9587	3	2004-09-20
3	8655	7279	2	2004-09-20
1	8656	4254	3	2004-09-18
2	8656	1371	2	2004-09-18
3	8656	4725	2	2004-09-18
4	8656	823	1	2004-09-18
5	8656	3508	3	2004-09-18
6	8656	3299	1	2004-09-18
1	8657	904	3	2004-09-04
2	8657	1443	3	2004-09-04
3	8657	194	1	2004-09-04
4	8657	2859	3	2004-09-04
1	8658	8998	3	2004-09-27
2	8658	1094	1	2004-09-27
3	8658	9063	1	2004-09-27
4	8658	9036	2	2004-09-27
5	8658	6141	3	2004-09-27
1	8659	737	3	2004-09-13
2	8659	2171	1	2004-09-13
3	8659	2704	1	2004-09-13
4	8659	9062	2	2004-09-13
5	8659	765	3	2004-09-13
6	8659	6280	2	2004-09-13
7	8659	9036	2	2004-09-13
1	8660	1992	1	2004-09-12
2	8660	6008	1	2004-09-12
3	8660	3520	2	2004-09-12
1	8661	9309	1	2004-09-15
2	8661	6326	1	2004-09-15
3	8661	2112	3	2004-09-15
4	8661	1639	2	2004-09-15
5	8661	1571	1	2004-09-15
6	8661	8962	1	2004-09-15
7	8661	9955	2	2004-09-15
8	8661	5959	3	2004-09-15
9	8661	443	3	2004-09-15
1	8662	1461	3	2004-09-05
2	8662	4580	2	2004-09-05
3	8662	3526	3	2004-09-05
4	8662	4640	3	2004-09-05
1	8663	3993	2	2004-09-26
2	8663	3176	2	2004-09-26
3	8663	8199	2	2004-09-26
4	8663	6331	3	2004-09-26
5	8663	7081	2	2004-09-26
1	8664	2757	3	2004-09-08
2	8664	3250	2	2004-09-08
3	8664	336	2	2004-09-08
1	8665	4336	2	2004-09-12
2	8665	5667	1	2004-09-12
3	8665	8279	3	2004-09-12
4	8665	7370	1	2004-09-12
5	8665	322	1	2004-09-12
6	8665	7902	3	2004-09-12
7	8665	5291	2	2004-09-12
1	8666	5411	2	2004-09-18
2	8666	927	3	2004-09-18
3	8666	2603	2	2004-09-18
4	8666	3399	1	2004-09-18
5	8666	8886	3	2004-09-18
6	8666	7853	3	2004-09-18
7	8666	4352	1	2004-09-18
8	8666	2906	1	2004-09-18
1	8667	3456	3	2004-09-15
2	8667	2793	1	2004-09-15
3	8667	5798	3	2004-09-15
1	8668	9561	2	2004-09-17
2	8668	1900	1	2004-09-17
3	8668	4033	2	2004-09-17
4	8668	4663	3	2004-09-17
5	8668	7440	2	2004-09-17
6	8668	4543	2	2004-09-17
1	8669	8912	1	2004-09-07
2	8669	6215	2	2004-09-07
3	8669	4604	3	2004-09-07
4	8669	3146	3	2004-09-07
5	8669	1027	3	2004-09-07
1	8670	2722	3	2004-09-17
2	8670	1798	2	2004-09-17
3	8670	469	2	2004-09-17
4	8670	9123	2	2004-09-17
5	8670	3261	2	2004-09-17
6	8670	8680	3	2004-09-17
1	8671	5835	2	2004-09-06
2	8671	1688	1	2004-09-06
3	8671	1476	2	2004-09-06
4	8671	1719	2	2004-09-06
5	8671	3687	1	2004-09-06
6	8671	3565	3	2004-09-06
7	8671	9361	2	2004-09-06
8	8671	5098	1	2004-09-06
9	8671	3968	3	2004-09-06
1	8672	9567	2	2004-09-21
2	8672	2387	3	2004-09-21
3	8672	3789	2	2004-09-21
4	8672	9050	1	2004-09-21
5	8672	3572	2	2004-09-21
6	8672	6093	2	2004-09-21
1	8673	2190	2	2004-09-21
2	8673	1398	2	2004-09-21
3	8673	4402	1	2004-09-21
4	8673	9741	3	2004-09-21
5	8673	2842	2	2004-09-21
6	8673	6394	3	2004-09-21
7	8673	8144	3	2004-09-21
8	8673	5371	3	2004-09-21
1	8674	1998	2	2004-09-16
2	8674	9377	2	2004-09-16
3	8674	9890	2	2004-09-16
4	8674	828	3	2004-09-16
5	8674	3038	1	2004-09-16
6	8674	5476	2	2004-09-16
7	8674	7615	3	2004-09-16
8	8674	982	1	2004-09-16
9	8674	7633	1	2004-09-16
1	8675	19	1	2004-09-05
2	8675	7027	2	2004-09-05
3	8675	284	1	2004-09-05
4	8675	3147	2	2004-09-05
5	8675	1023	2	2004-09-05
6	8675	1245	1	2004-09-05
7	8675	712	1	2004-09-05
8	8675	5869	1	2004-09-05
1	8676	4134	1	2004-09-24
2	8676	306	2	2004-09-24
3	8676	3546	3	2004-09-24
4	8676	5838	2	2004-09-24
1	8677	2842	3	2004-09-26
2	8677	3819	1	2004-09-26
3	8677	2125	3	2004-09-26
4	8677	9364	1	2004-09-26
5	8677	2108	1	2004-09-26
6	8677	3547	1	2004-09-26
7	8677	1742	3	2004-09-26
8	8677	4358	3	2004-09-26
1	8678	9804	2	2004-09-25
2	8678	7569	2	2004-09-25
3	8678	1375	2	2004-09-25
1	8679	8216	2	2004-09-26
2	8679	1371	1	2004-09-26
1	8680	6642	1	2004-09-29
2	8680	9612	1	2004-09-29
3	8680	3926	1	2004-09-29
4	8680	9603	3	2004-09-29
5	8680	1053	3	2004-09-29
6	8680	6557	2	2004-09-29
7	8680	377	2	2004-09-29
8	8680	7620	3	2004-09-29
9	8680	9710	3	2004-09-29
1	8681	9496	3	2004-09-05
2	8681	1540	1	2004-09-05
3	8681	9031	1	2004-09-05
4	8681	4361	3	2004-09-05
5	8681	184	1	2004-09-05
1	8682	1150	1	2004-09-28
2	8682	1344	1	2004-09-28
3	8682	8717	3	2004-09-28
1	8683	7038	2	2004-09-20
2	8683	2998	3	2004-09-20
3	8683	2089	1	2004-09-20
4	8683	3412	1	2004-09-20
1	8684	6131	3	2004-09-27
2	8684	5835	2	2004-09-27
3	8684	7813	2	2004-09-27
4	8684	6110	3	2004-09-27
5	8684	8032	3	2004-09-27
6	8684	9797	3	2004-09-27
7	8684	9460	3	2004-09-27
8	8684	7276	2	2004-09-27
1	8685	5506	1	2004-09-23
2	8685	3030	3	2004-09-23
3	8685	4624	2	2004-09-23
4	8685	9177	2	2004-09-23
5	8685	1392	1	2004-09-23
1	8686	3836	2	2004-09-04
2	8686	2007	3	2004-09-04
3	8686	5251	1	2004-09-04
4	8686	7204	2	2004-09-04
5	8686	9414	2	2004-09-04
6	8686	3560	3	2004-09-04
7	8686	2508	1	2004-09-04
1	8687	5201	3	2004-09-25
2	8687	1324	3	2004-09-25
3	8687	5278	1	2004-09-25
4	8687	3222	3	2004-09-25
1	8688	1461	3	2004-09-07
1	8689	3506	2	2004-09-21
2	8689	7108	1	2004-09-21
1	8690	1832	3	2004-09-06
2	8690	6700	3	2004-09-06
3	8690	1564	1	2004-09-06
4	8690	6475	1	2004-09-06
1	8691	8422	2	2004-09-06
2	8691	9369	1	2004-09-06
3	8691	6078	1	2004-09-06
4	8691	638	1	2004-09-06
5	8691	4297	3	2004-09-06
1	8692	723	2	2004-09-15
2	8692	2723	1	2004-09-15
1	8693	2193	3	2004-09-30
2	8693	8567	3	2004-09-30
3	8693	2617	1	2004-09-30
4	8693	420	2	2004-09-30
5	8693	5234	3	2004-09-30
6	8693	1520	2	2004-09-30
1	8694	485	3	2004-09-05
2	8694	699	2	2004-09-05
1	8695	104	1	2004-09-23
2	8695	8584	1	2004-09-23
3	8695	4764	3	2004-09-23
4	8695	6736	3	2004-09-23
5	8695	6476	2	2004-09-23
6	8695	5623	3	2004-09-23
7	8695	5592	2	2004-09-23
8	8695	5097	1	2004-09-23
1	8696	4214	1	2004-09-15
2	8696	8426	2	2004-09-15
3	8696	587	3	2004-09-15
4	8696	131	3	2004-09-15
5	8696	3607	3	2004-09-15
6	8696	6370	2	2004-09-15
1	8697	1700	1	2004-09-24
2	8697	9547	3	2004-09-24
3	8697	5817	2	2004-09-24
1	8698	2233	2	2004-09-22
2	8698	8981	3	2004-09-22
3	8698	2431	1	2004-09-22
1	8699	9981	3	2004-09-26
2	8699	7222	2	2004-09-26
3	8699	5640	2	2004-09-26
4	8699	7297	2	2004-09-26
5	8699	8544	1	2004-09-26
6	8699	6058	1	2004-09-26
7	8699	1591	2	2004-09-26
8	8699	8420	3	2004-09-26
9	8699	775	2	2004-09-26
1	8700	8082	3	2004-09-27
1	8701	1369	3	2004-09-27
2	8701	6332	1	2004-09-27
3	8701	6139	2	2004-09-27
4	8701	4936	1	2004-09-27
5	8701	7145	1	2004-09-27
6	8701	5245	2	2004-09-27
7	8701	3308	1	2004-09-27
1	8702	2305	3	2004-09-18
2	8702	38	1	2004-09-18
3	8702	9668	3	2004-09-18
4	8702	2166	3	2004-09-18
1	8703	8100	3	2004-09-16
2	8703	3463	2	2004-09-16
3	8703	978	3	2004-09-16
4	8703	7984	2	2004-09-16
5	8703	1379	2	2004-09-16
1	8704	7925	3	2004-09-25
2	8704	6351	2	2004-09-25
1	8705	9774	1	2004-09-04
2	8705	9225	1	2004-09-04
1	8706	9691	1	2004-09-30
2	8706	7817	1	2004-09-30
3	8706	5342	3	2004-09-30
4	8706	2754	1	2004-09-30
5	8706	4708	2	2004-09-30
6	8706	8454	1	2004-09-30
7	8706	755	3	2004-09-30
8	8706	4305	3	2004-09-30
1	8707	9311	2	2004-09-19
2	8707	8253	3	2004-09-19
3	8707	8202	3	2004-09-19
4	8707	1023	3	2004-09-19
5	8707	1823	2	2004-09-19
6	8707	6318	1	2004-09-19
7	8707	4746	2	2004-09-19
1	8708	3413	3	2004-09-14
2	8708	1553	1	2004-09-14
3	8708	487	1	2004-09-14
4	8708	1137	2	2004-09-14
5	8708	987	3	2004-09-14
6	8708	5448	2	2004-09-14
7	8708	4272	2	2004-09-14
1	8709	3	2	2004-09-02
2	8709	6850	1	2004-09-02
3	8709	8700	1	2004-09-02
4	8709	3338	2	2004-09-02
5	8709	7301	3	2004-09-02
6	8709	3532	1	2004-09-02
7	8709	5425	3	2004-09-02
8	8709	7864	3	2004-09-02
1	8710	3142	1	2004-09-27
2	8710	7102	3	2004-09-27
3	8710	4766	1	2004-09-27
4	8710	3348	2	2004-09-27
5	8710	3898	3	2004-09-27
6	8710	4007	2	2004-09-27
7	8710	2054	1	2004-09-27
8	8710	5725	1	2004-09-27
9	8710	4024	3	2004-09-27
1	8711	1553	1	2004-09-13
2	8711	4673	3	2004-09-13
3	8711	9468	2	2004-09-13
4	8711	7767	3	2004-09-13
5	8711	3430	1	2004-09-13
6	8711	9020	1	2004-09-13
7	8711	9498	2	2004-09-13
1	8712	33	1	2004-09-06
2	8712	9703	1	2004-09-06
3	8712	3934	2	2004-09-06
4	8712	2839	3	2004-09-06
5	8712	4491	3	2004-09-06
6	8712	9281	1	2004-09-06
1	8713	250	2	2004-09-15
2	8713	2920	3	2004-09-15
3	8713	2266	2	2004-09-15
4	8713	8924	1	2004-09-15
5	8713	6880	3	2004-09-15
6	8713	5071	3	2004-09-15
7	8713	1265	2	2004-09-15
8	8713	4587	1	2004-09-15
9	8713	7219	2	2004-09-15
1	8714	9109	2	2004-09-11
2	8714	3258	3	2004-09-11
3	8714	5763	3	2004-09-11
4	8714	9223	3	2004-09-11
5	8714	7459	3	2004-09-11
6	8714	3327	1	2004-09-11
1	8715	6878	2	2004-09-23
2	8715	4831	1	2004-09-23
3	8715	2391	2	2004-09-23
4	8715	6090	3	2004-09-23
5	8715	7394	1	2004-09-23
6	8715	1266	1	2004-09-23
1	8716	5187	1	2004-09-14
2	8716	1958	1	2004-09-14
3	8716	8277	1	2004-09-14
4	8716	760	2	2004-09-14
1	8717	9678	1	2004-09-02
2	8717	4550	2	2004-09-02
3	8717	6447	3	2004-09-02
4	8717	8504	3	2004-09-02
5	8717	5477	2	2004-09-02
6	8717	5815	1	2004-09-02
7	8717	7901	3	2004-09-02
8	8717	3646	1	2004-09-02
1	8718	900	3	2004-09-25
2	8718	4197	3	2004-09-25
3	8718	9067	2	2004-09-25
1	8719	7858	3	2004-09-15
1	8720	1789	2	2004-09-12
1	8721	134	2	2004-09-28
2	8721	2044	2	2004-09-28
3	8721	8634	1	2004-09-28
4	8721	4424	2	2004-09-28
5	8721	3352	2	2004-09-28
1	8722	2504	3	2004-09-08
2	8722	1234	1	2004-09-08
1	8723	1499	2	2004-09-02
2	8723	4612	1	2004-09-02
3	8723	9318	2	2004-09-02
4	8723	552	3	2004-09-02
1	8724	4465	1	2004-09-27
1	8725	4212	3	2004-09-03
2	8725	1769	3	2004-09-03
3	8725	1120	2	2004-09-03
4	8725	8125	1	2004-09-03
1	8726	2862	1	2004-09-18
2	8726	1621	3	2004-09-18
3	8726	6230	1	2004-09-18
4	8726	1233	3	2004-09-18
5	8726	8627	3	2004-09-18
6	8726	7466	1	2004-09-18
1	8727	819	1	2004-09-03
2	8727	5812	2	2004-09-03
1	8728	1853	1	2004-09-06
2	8728	5415	3	2004-09-06
3	8728	427	3	2004-09-06
1	8729	761	2	2004-09-12
2	8729	6308	1	2004-09-12
3	8729	2812	2	2004-09-12
4	8729	1948	1	2004-09-12
5	8729	7522	1	2004-09-12
1	8730	5041	1	2004-09-07
2	8730	8056	3	2004-09-07
3	8730	7652	1	2004-09-07
1	8731	7174	2	2004-09-01
2	8731	2317	1	2004-09-01
3	8731	7379	1	2004-09-01
4	8731	6294	3	2004-09-01
5	8731	8149	1	2004-09-01
1	8732	1236	2	2004-09-01
2	8732	4748	2	2004-09-01
1	8733	9077	2	2004-09-24
2	8733	9781	3	2004-09-24
3	8733	6320	3	2004-09-24
1	8734	4074	3	2004-09-19
2	8734	4329	1	2004-09-19
3	8734	9717	1	2004-09-19
4	8734	9592	3	2004-09-19
1	8735	1803	1	2004-09-10
1	8736	5556	3	2004-09-18
2	8736	6370	2	2004-09-18
3	8736	4490	2	2004-09-18
4	8736	1361	1	2004-09-18
1	8737	999	2	2004-09-18
2	8737	8858	2	2004-09-18
1	8738	6439	3	2004-09-19
2	8738	5634	2	2004-09-19
3	8738	9927	3	2004-09-19
4	8738	5322	2	2004-09-19
5	8738	3986	3	2004-09-19
6	8738	9310	3	2004-09-19
1	8739	1830	2	2004-09-27
2	8739	4090	3	2004-09-27
3	8739	3128	2	2004-09-27
1	8740	9453	2	2004-09-28
2	8740	6495	2	2004-09-28
3	8740	1977	1	2004-09-28
4	8740	4570	3	2004-09-28
5	8740	8195	2	2004-09-28
6	8740	5045	2	2004-09-28
7	8740	235	3	2004-09-28
8	8740	2339	3	2004-09-28
1	8741	4410	3	2004-09-26
2	8741	8280	3	2004-09-26
3	8741	4859	1	2004-09-26
1	8742	1843	2	2004-09-11
2	8742	9194	3	2004-09-11
3	8742	386	1	2004-09-11
1	8743	9452	2	2004-09-04
2	8743	2979	3	2004-09-04
3	8743	2855	2	2004-09-04
4	8743	9230	1	2004-09-04
5	8743	6446	2	2004-09-04
6	8743	4170	1	2004-09-04
7	8743	1507	1	2004-09-04
8	8743	9354	2	2004-09-04
9	8743	3857	1	2004-09-04
1	8744	4375	2	2004-09-01
2	8744	467	2	2004-09-01
1	8745	1199	3	2004-09-19
2	8745	8828	2	2004-09-19
3	8745	8853	1	2004-09-19
4	8745	9494	3	2004-09-19
5	8745	3108	2	2004-09-19
1	8746	9727	2	2004-09-08
2	8746	407	2	2004-09-08
3	8746	8880	1	2004-09-08
4	8746	2972	2	2004-09-08
1	8747	2106	2	2004-09-09
2	8747	5025	1	2004-09-09
3	8747	1022	2	2004-09-09
1	8748	1531	3	2004-09-03
2	8748	7921	2	2004-09-03
3	8748	5832	1	2004-09-03
4	8748	1915	1	2004-09-03
5	8748	4499	1	2004-09-03
6	8748	8773	2	2004-09-03
7	8748	5224	3	2004-09-03
8	8748	5600	3	2004-09-03
9	8748	2393	3	2004-09-03
1	8749	8205	3	2004-09-17
2	8749	9466	3	2004-09-17
3	8749	2960	1	2004-09-17
4	8749	9075	2	2004-09-17
5	8749	292	1	2004-09-17
6	8749	3252	3	2004-09-17
7	8749	5243	3	2004-09-17
1	8750	8798	1	2004-09-27
2	8750	8072	2	2004-09-27
3	8750	8134	2	2004-09-27
1	8751	2713	2	2004-09-07
2	8751	5401	1	2004-09-07
3	8751	543	2	2004-09-07
4	8751	143	2	2004-09-07
5	8751	5320	3	2004-09-07
6	8751	6862	2	2004-09-07
7	8751	9823	1	2004-09-07
1	8752	2223	1	2004-09-12
2	8752	5659	1	2004-09-12
3	8752	1387	2	2004-09-12
1	8753	46	3	2004-09-16
2	8753	5012	1	2004-09-16
3	8753	3302	1	2004-09-16
4	8753	3675	2	2004-09-16
5	8753	5280	2	2004-09-16
6	8753	7347	1	2004-09-16
7	8753	3036	2	2004-09-16
1	8754	7923	2	2004-09-19
1	8755	1166	2	2004-09-08
2	8755	1914	2	2004-09-08
3	8755	5329	3	2004-09-08
4	8755	3463	2	2004-09-08
5	8755	8811	3	2004-09-08
6	8755	8132	1	2004-09-08
7	8755	8888	1	2004-09-08
8	8755	5956	2	2004-09-08
1	8756	7510	1	2004-09-17
2	8756	1518	1	2004-09-17
3	8756	1009	3	2004-09-17
4	8756	5346	2	2004-09-17
5	8756	9586	3	2004-09-17
6	8756	1716	1	2004-09-17
7	8756	5576	2	2004-09-17
8	8756	6957	1	2004-09-17
1	8757	8894	2	2004-09-09
2	8757	3866	3	2004-09-09
1	8758	3123	3	2004-09-19
2	8758	500	1	2004-09-19
1	8759	1458	3	2004-09-24
2	8759	2230	1	2004-09-24
3	8759	7575	2	2004-09-24
4	8759	1793	1	2004-09-24
5	8759	7575	3	2004-09-24
6	8759	4054	1	2004-09-24
7	8759	9169	1	2004-09-24
8	8759	2274	3	2004-09-24
1	8760	5960	3	2004-09-15
1	8761	9714	1	2004-09-09
2	8761	5312	1	2004-09-09
3	8761	892	3	2004-09-09
1	8762	7067	3	2004-09-30
2	8762	706	2	2004-09-30
3	8762	8353	2	2004-09-30
4	8762	5160	3	2004-09-30
5	8762	5090	3	2004-09-30
6	8762	5583	3	2004-09-30
7	8762	3572	1	2004-09-30
1	8763	8614	2	2004-09-03
2	8763	6873	3	2004-09-03
3	8763	5916	1	2004-09-03
4	8763	503	3	2004-09-03
1	8764	8041	3	2004-09-27
2	8764	6366	3	2004-09-27
3	8764	1635	2	2004-09-27
4	8764	3505	3	2004-09-27
5	8764	2239	3	2004-09-27
6	8764	4227	3	2004-09-27
7	8764	8423	3	2004-09-27
1	8765	2785	2	2004-09-28
2	8765	2185	3	2004-09-28
3	8765	4271	3	2004-09-28
4	8765	1841	2	2004-09-28
5	8765	4907	1	2004-09-28
6	8765	5258	2	2004-09-28
7	8765	7554	1	2004-09-28
8	8765	1827	2	2004-09-28
1	8766	255	1	2004-09-07
2	8766	4143	2	2004-09-07
3	8766	8698	1	2004-09-07
4	8766	2280	3	2004-09-07
5	8766	1772	3	2004-09-07
1	8767	4212	3	2004-09-20
2	8767	6694	2	2004-09-20
3	8767	4595	1	2004-09-20
4	8767	6844	3	2004-09-20
5	8767	6434	2	2004-09-20
6	8767	3150	3	2004-09-20
7	8767	8317	2	2004-09-20
8	8767	1722	3	2004-09-20
1	8768	6458	2	2004-09-03
2	8768	7451	3	2004-09-03
3	8768	4474	3	2004-09-03
4	8768	8345	1	2004-09-03
5	8768	3777	2	2004-09-03
1	8769	4041	3	2004-09-29
2	8769	7769	1	2004-09-29
3	8769	8164	2	2004-09-29
4	8769	5282	1	2004-09-29
5	8769	2463	2	2004-09-29
6	8769	6508	2	2004-09-29
1	8770	2135	1	2004-09-02
2	8770	4912	3	2004-09-02
3	8770	1354	3	2004-09-02
4	8770	8807	3	2004-09-02
5	8770	267	1	2004-09-02
6	8770	3595	3	2004-09-02
7	8770	571	3	2004-09-02
8	8770	5912	2	2004-09-02
1	8771	7883	1	2004-09-17
2	8771	5101	1	2004-09-17
3	8771	4376	1	2004-09-17
4	8771	4528	2	2004-09-17
1	8772	3305	3	2004-09-27
1	8773	4356	3	2004-09-02
2	8773	1967	3	2004-09-02
3	8773	7617	1	2004-09-02
4	8773	5262	2	2004-09-02
5	8773	7149	1	2004-09-02
6	8773	7209	1	2004-09-02
7	8773	4672	2	2004-09-02
8	8773	3421	3	2004-09-02
9	8773	5436	3	2004-09-02
1	8774	651	2	2004-09-05
1	8775	8613	1	2004-09-04
2	8775	1193	1	2004-09-04
1	8776	5696	2	2004-09-30
2	8776	884	1	2004-09-30
3	8776	7064	3	2004-09-30
4	8776	5487	1	2004-09-30
5	8776	3183	3	2004-09-30
6	8776	1509	3	2004-09-30
7	8776	6704	1	2004-09-30
1	8777	5465	2	2004-09-26
2	8777	3187	3	2004-09-26
3	8777	6168	1	2004-09-26
4	8777	1590	3	2004-09-26
5	8777	4767	1	2004-09-26
6	8777	518	2	2004-09-26
7	8777	8686	2	2004-09-26
8	8777	1862	3	2004-09-26
9	8777	9056	3	2004-09-26
1	8778	3450	1	2004-09-23
1	8779	9581	3	2004-09-29
2	8779	7273	2	2004-09-29
3	8779	2544	1	2004-09-29
4	8779	4769	3	2004-09-29
5	8779	2257	2	2004-09-29
6	8779	6071	3	2004-09-29
7	8779	7687	2	2004-09-29
8	8779	2707	2	2004-09-29
1	8780	3494	2	2004-09-09
2	8780	6400	2	2004-09-09
1	8781	2	1	2004-09-14
2	8781	1945	3	2004-09-14
3	8781	9564	3	2004-09-14
4	8781	4628	1	2004-09-14
1	8782	5753	3	2004-09-30
2	8782	8955	2	2004-09-30
1	8783	6229	2	2004-09-11
2	8783	8133	3	2004-09-11
3	8783	9355	2	2004-09-11
4	8783	3876	2	2004-09-11
5	8783	4381	1	2004-09-11
6	8783	7702	2	2004-09-11
1	8784	8864	3	2004-09-05
2	8784	3248	3	2004-09-05
1	8785	954	3	2004-09-24
2	8785	7180	2	2004-09-24
3	8785	1086	3	2004-09-24
4	8785	706	3	2004-09-24
1	8786	3370	1	2004-09-09
2	8786	5897	3	2004-09-09
1	8787	3246	2	2004-09-04
2	8787	3824	1	2004-09-04
3	8787	4689	3	2004-09-04
1	8788	6416	1	2004-09-02
2	8788	543	2	2004-09-02
1	8789	8943	1	2004-09-20
2	8789	6062	2	2004-09-20
3	8789	5430	3	2004-09-20
4	8789	6889	1	2004-09-20
5	8789	7182	3	2004-09-20
6	8789	4925	3	2004-09-20
7	8789	680	3	2004-09-20
1	8790	1575	1	2004-09-17
1	8791	4801	1	2004-09-09
2	8791	2786	1	2004-09-09
3	8791	4215	2	2004-09-09
4	8791	8542	1	2004-09-09
5	8791	6703	2	2004-09-09
6	8791	9135	1	2004-09-09
7	8791	4034	2	2004-09-09
8	8791	3459	1	2004-09-09
9	8791	4019	3	2004-09-09
1	8792	9203	3	2004-09-02
2	8792	6041	1	2004-09-02
3	8792	7760	3	2004-09-02
4	8792	3488	3	2004-09-02
5	8792	8007	3	2004-09-02
6	8792	2391	1	2004-09-02
1	8793	9762	1	2004-09-29
2	8793	2750	3	2004-09-29
3	8793	3000	3	2004-09-29
4	8793	4920	2	2004-09-29
5	8793	7999	3	2004-09-29
6	8793	4842	3	2004-09-29
7	8793	3637	1	2004-09-29
8	8793	4469	1	2004-09-29
1	8794	9326	3	2004-09-25
2	8794	5791	3	2004-09-25
3	8794	5393	3	2004-09-25
4	8794	8125	2	2004-09-25
5	8794	4787	1	2004-09-25
6	8794	3146	2	2004-09-25
1	8795	2679	3	2004-09-10
2	8795	2615	1	2004-09-10
3	8795	7302	3	2004-09-10
4	8795	9205	1	2004-09-10
5	8795	8852	2	2004-09-10
6	8795	3778	3	2004-09-10
1	8796	4498	3	2004-09-13
2	8796	840	3	2004-09-13
3	8796	7040	3	2004-09-13
4	8796	4888	1	2004-09-13
1	8797	3930	3	2004-09-04
2	8797	567	2	2004-09-04
3	8797	8182	1	2004-09-04
4	8797	7285	2	2004-09-04
1	8798	163	1	2004-09-02
2	8798	6569	2	2004-09-02
3	8798	7592	3	2004-09-02
4	8798	7852	1	2004-09-02
5	8798	8495	3	2004-09-02
6	8798	1979	2	2004-09-02
7	8798	7656	3	2004-09-02
8	8798	7360	3	2004-09-02
9	8798	4899	2	2004-09-02
1	8799	5436	1	2004-09-10
2	8799	7068	1	2004-09-10
3	8799	7216	3	2004-09-10
4	8799	9210	2	2004-09-10
1	8800	3716	1	2004-09-22
2	8800	3399	1	2004-09-22
3	8800	3517	1	2004-09-22
4	8800	258	2	2004-09-22
1	8801	6823	3	2004-09-23
2	8801	8520	1	2004-09-23
3	8801	6087	1	2004-09-23
4	8801	4028	1	2004-09-23
5	8801	3803	1	2004-09-23
1	8802	4655	2	2004-09-13
2	8802	2826	3	2004-09-13
3	8802	9756	2	2004-09-13
4	8802	9918	1	2004-09-13
1	8803	8929	1	2004-09-25
2	8803	6279	1	2004-09-25
3	8803	7260	1	2004-09-25
4	8803	8548	2	2004-09-25
5	8803	3243	2	2004-09-25
6	8803	7849	3	2004-09-25
7	8803	6158	1	2004-09-25
8	8803	8366	1	2004-09-25
1	8804	3159	3	2004-09-09
2	8804	5815	1	2004-09-09
3	8804	3221	2	2004-09-09
4	8804	6068	1	2004-09-09
5	8804	9167	1	2004-09-09
6	8804	9694	3	2004-09-09
7	8804	3588	2	2004-09-09
1	8805	6626	1	2004-09-29
2	8805	2567	2	2004-09-29
3	8805	9587	3	2004-09-29
4	8805	6127	3	2004-09-29
5	8805	9126	3	2004-09-29
6	8805	5117	1	2004-09-29
7	8805	6120	3	2004-09-29
8	8805	9659	1	2004-09-29
1	8806	4207	3	2004-09-04
2	8806	8372	2	2004-09-04
3	8806	4928	1	2004-09-04
4	8806	9873	2	2004-09-04
5	8806	2806	3	2004-09-04
6	8806	2244	3	2004-09-04
7	8806	1263	2	2004-09-04
1	8807	8801	1	2004-09-12
1	8808	2193	2	2004-09-27
2	8808	6881	2	2004-09-27
3	8808	8176	2	2004-09-27
4	8808	639	1	2004-09-27
5	8808	1380	3	2004-09-27
1	8809	620	2	2004-09-19
2	8809	5101	1	2004-09-19
3	8809	3205	2	2004-09-19
4	8809	7674	3	2004-09-19
5	8809	7212	1	2004-09-19
6	8809	7142	2	2004-09-19
1	8810	915	1	2004-09-12
2	8810	4806	3	2004-09-12
3	8810	5502	1	2004-09-12
4	8810	2343	2	2004-09-12
5	8810	5364	2	2004-09-12
6	8810	5150	1	2004-09-12
7	8810	30	2	2004-09-12
8	8810	7800	1	2004-09-12
9	8810	9892	1	2004-09-12
1	8811	206	2	2004-09-11
2	8811	2394	3	2004-09-11
1	8812	5771	2	2004-09-08
2	8812	4534	1	2004-09-08
3	8812	2025	1	2004-09-08
1	8813	8088	1	2004-09-11
2	8813	567	3	2004-09-11
3	8813	7445	3	2004-09-11
4	8813	8766	3	2004-09-11
5	8813	1268	1	2004-09-11
6	8813	432	1	2004-09-11
7	8813	3462	1	2004-09-11
8	8813	7005	2	2004-09-11
9	8813	7983	3	2004-09-11
1	8814	5526	2	2004-09-07
2	8814	8465	3	2004-09-07
3	8814	6474	1	2004-09-07
4	8814	1917	1	2004-09-07
5	8814	944	1	2004-09-07
6	8814	3977	1	2004-09-07
7	8814	8122	1	2004-09-07
8	8814	9877	3	2004-09-07
1	8815	1675	1	2004-09-27
2	8815	9823	3	2004-09-27
3	8815	8481	3	2004-09-27
4	8815	8170	1	2004-09-27
5	8815	9103	1	2004-09-27
6	8815	8487	2	2004-09-27
7	8815	6512	3	2004-09-27
8	8815	2179	1	2004-09-27
9	8815	8975	2	2004-09-27
1	8816	1429	1	2004-09-17
2	8816	1032	1	2004-09-17
3	8816	9107	3	2004-09-17
4	8816	2449	3	2004-09-17
5	8816	8975	2	2004-09-17
6	8816	895	3	2004-09-17
7	8816	2802	3	2004-09-17
8	8816	6603	1	2004-09-17
9	8816	9974	2	2004-09-17
1	8817	5412	1	2004-09-04
2	8817	542	2	2004-09-04
3	8817	6609	2	2004-09-04
4	8817	4305	1	2004-09-04
5	8817	5790	2	2004-09-04
6	8817	2928	3	2004-09-04
7	8817	7038	1	2004-09-04
1	8818	3610	1	2004-09-20
2	8818	4380	2	2004-09-20
3	8818	574	1	2004-09-20
4	8818	7383	1	2004-09-20
5	8818	6688	3	2004-09-20
6	8818	9008	3	2004-09-20
1	8819	8806	2	2004-09-18
2	8819	2704	1	2004-09-18
3	8819	6851	3	2004-09-18
4	8819	8843	3	2004-09-18
5	8819	5314	2	2004-09-18
6	8819	1813	1	2004-09-18
1	8820	3317	1	2004-09-17
2	8820	5389	2	2004-09-17
3	8820	2867	1	2004-09-17
4	8820	4438	3	2004-09-17
5	8820	1200	2	2004-09-17
6	8820	6577	3	2004-09-17
7	8820	7864	2	2004-09-17
8	8820	3710	3	2004-09-17
9	8820	2254	2	2004-09-17
1	8821	8882	1	2004-09-30
2	8821	4502	1	2004-09-30
3	8821	2142	3	2004-09-30
4	8821	2812	3	2004-09-30
5	8821	8846	2	2004-09-30
6	8821	1532	2	2004-09-30
7	8821	18	2	2004-09-30
8	8821	7006	2	2004-09-30
1	8822	5388	2	2004-09-12
1	8823	5510	1	2004-09-20
2	8823	7997	1	2004-09-20
3	8823	829	3	2004-09-20
4	8823	635	2	2004-09-20
5	8823	7574	1	2004-09-20
6	8823	5199	1	2004-09-20
7	8823	2423	2	2004-09-20
8	8823	6513	2	2004-09-20
9	8823	8278	2	2004-09-20
1	8824	3488	3	2004-09-26
2	8824	2833	3	2004-09-26
3	8824	4646	3	2004-09-26
1	8825	9285	2	2004-09-24
2	8825	3896	1	2004-09-24
3	8825	3240	2	2004-09-24
4	8825	5444	1	2004-09-24
1	8826	4686	3	2004-09-22
2	8826	3683	1	2004-09-22
3	8826	4241	1	2004-09-22
4	8826	8247	2	2004-09-22
5	8826	4339	1	2004-09-22
6	8826	4109	3	2004-09-22
7	8826	609	3	2004-09-22
8	8826	6642	3	2004-09-22
9	8826	5830	2	2004-09-22
1	8827	5227	2	2004-09-07
2	8827	486	1	2004-09-07
3	8827	5420	3	2004-09-07
4	8827	1312	2	2004-09-07
5	8827	7520	2	2004-09-07
6	8827	4328	1	2004-09-07
1	8828	3793	3	2004-09-27
2	8828	8942	3	2004-09-27
3	8828	4746	3	2004-09-27
4	8828	6656	1	2004-09-27
5	8828	8131	1	2004-09-27
6	8828	6394	1	2004-09-27
7	8828	7600	3	2004-09-27
1	8829	3497	3	2004-09-19
2	8829	4423	2	2004-09-19
3	8829	4405	1	2004-09-19
4	8829	806	3	2004-09-19
5	8829	3145	3	2004-09-19
6	8829	7300	2	2004-09-19
1	8830	8994	3	2004-09-21
2	8830	5468	2	2004-09-21
3	8830	89	2	2004-09-21
4	8830	8134	2	2004-09-21
5	8830	3790	2	2004-09-21
6	8830	4243	3	2004-09-21
1	8831	4397	1	2004-09-26
2	8831	6864	3	2004-09-26
1	8832	7437	2	2004-09-09
2	8832	2457	2	2004-09-09
3	8832	5924	2	2004-09-09
4	8832	328	2	2004-09-09
5	8832	5114	2	2004-09-09
6	8832	566	2	2004-09-09
1	8833	4433	2	2004-09-29
2	8833	3118	1	2004-09-29
3	8833	2538	3	2004-09-29
1	8834	5736	2	2004-09-16
2	8834	9581	1	2004-09-16
1	8835	1428	2	2004-09-30
2	8835	8552	1	2004-09-30
1	8836	8868	3	2004-09-27
2	8836	8207	1	2004-09-27
3	8836	125	1	2004-09-27
4	8836	6481	1	2004-09-27
5	8836	5632	3	2004-09-27
6	8836	2928	1	2004-09-27
7	8836	5953	2	2004-09-27
8	8836	2591	1	2004-09-27
9	8836	7209	1	2004-09-27
1	8837	9031	1	2004-09-15
2	8837	7079	3	2004-09-15
3	8837	2370	2	2004-09-15
1	8838	6862	2	2004-09-04
1	8839	229	1	2004-09-03
2	8839	6165	1	2004-09-03
3	8839	2682	1	2004-09-03
4	8839	6758	2	2004-09-03
5	8839	3805	2	2004-09-03
6	8839	7443	3	2004-09-03
7	8839	858	2	2004-09-03
1	8840	7471	3	2004-09-06
2	8840	4913	3	2004-09-06
3	8840	9534	1	2004-09-06
4	8840	8834	2	2004-09-06
5	8840	4170	3	2004-09-06
6	8840	3382	1	2004-09-06
7	8840	6648	2	2004-09-06
8	8840	2543	1	2004-09-06
9	8840	6765	2	2004-09-06
1	8841	7488	3	2004-09-15
2	8841	7495	3	2004-09-15
3	8841	4568	3	2004-09-15
4	8841	8234	1	2004-09-15
5	8841	8204	2	2004-09-15
6	8841	1426	1	2004-09-15
7	8841	4423	1	2004-09-15
8	8841	3555	1	2004-09-15
1	8842	8264	3	2004-09-23
1	8843	6030	3	2004-09-14
1	8844	4463	2	2004-09-14
2	8844	463	3	2004-09-14
1	8845	4400	1	2004-09-09
1	8846	2078	1	2004-09-13
2	8846	5282	2	2004-09-13
3	8846	1317	2	2004-09-13
4	8846	4236	2	2004-09-13
5	8846	4353	2	2004-09-13
6	8846	6771	1	2004-09-13
7	8846	3596	1	2004-09-13
1	8847	2849	2	2004-09-21
2	8847	400	2	2004-09-21
1	8848	3509	1	2004-09-09
2	8848	5900	3	2004-09-09
3	8848	7983	3	2004-09-09
4	8848	7316	1	2004-09-09
5	8848	2809	3	2004-09-09
6	8848	6811	3	2004-09-09
7	8848	4294	1	2004-09-09
1	8849	2465	3	2004-09-11
2	8849	6565	2	2004-09-11
3	8849	9822	3	2004-09-11
4	8849	9966	1	2004-09-11
5	8849	4946	1	2004-09-11
6	8849	1463	1	2004-09-11
7	8849	9720	2	2004-09-11
1	8850	3596	3	2004-09-06
2	8850	3036	2	2004-09-06
3	8850	7654	3	2004-09-06
4	8850	3449	1	2004-09-06
5	8850	1009	3	2004-09-06
6	8850	3011	1	2004-09-06
7	8850	4033	2	2004-09-06
8	8850	1005	1	2004-09-06
9	8850	1459	1	2004-09-06
1	8851	4067	1	2004-09-01
2	8851	6319	2	2004-09-01
3	8851	7483	3	2004-09-01
4	8851	9406	3	2004-09-01
5	8851	7880	1	2004-09-01
1	8852	762	1	2004-09-25
2	8852	7811	1	2004-09-25
3	8852	9796	1	2004-09-25
4	8852	4322	2	2004-09-25
5	8852	6297	2	2004-09-25
6	8852	4424	3	2004-09-25
1	8853	9387	1	2004-09-19
2	8853	9714	2	2004-09-19
3	8853	7032	3	2004-09-19
4	8853	3814	2	2004-09-19
5	8853	6384	1	2004-09-19
6	8853	9438	2	2004-09-19
7	8853	2608	3	2004-09-19
1	8854	5139	1	2004-09-02
2	8854	9088	3	2004-09-02
3	8854	5318	2	2004-09-02
4	8854	4787	3	2004-09-02
5	8854	3139	1	2004-09-02
6	8854	4174	1	2004-09-02
7	8854	8142	2	2004-09-02
8	8854	5564	3	2004-09-02
1	8855	9032	1	2004-09-28
2	8855	4771	3	2004-09-28
3	8855	6027	3	2004-09-28
1	8856	4750	2	2004-09-22
2	8856	497	2	2004-09-22
3	8856	5346	2	2004-09-22
4	8856	9221	1	2004-09-22
5	8856	5556	1	2004-09-22
6	8856	1072	3	2004-09-22
7	8856	4677	3	2004-09-22
8	8856	3289	1	2004-09-22
9	8856	7069	1	2004-09-22
1	8857	3553	1	2004-09-09
2	8857	336	3	2004-09-09
1	8858	6654	1	2004-09-24
2	8858	4412	3	2004-09-24
3	8858	4649	3	2004-09-24
4	8858	2965	2	2004-09-24
5	8858	9889	3	2004-09-24
6	8858	6228	1	2004-09-24
7	8858	8250	1	2004-09-24
8	8858	174	1	2004-09-24
1	8859	9361	3	2004-09-04
2	8859	5845	1	2004-09-04
3	8859	121	2	2004-09-04
4	8859	2491	3	2004-09-04
1	8860	9365	1	2004-09-12
1	8861	7883	1	2004-09-23
1	8862	5014	1	2004-09-28
2	8862	8905	2	2004-09-28
3	8862	8856	1	2004-09-28
4	8862	136	3	2004-09-28
5	8862	2716	2	2004-09-28
6	8862	1128	1	2004-09-28
7	8862	2161	2	2004-09-28
1	8863	6472	1	2004-09-03
2	8863	7998	2	2004-09-03
3	8863	5549	3	2004-09-03
4	8863	4702	2	2004-09-03
5	8863	9071	2	2004-09-03
6	8863	7542	1	2004-09-03
7	8863	1187	1	2004-09-03
1	8864	3087	3	2004-09-07
1	8865	8639	3	2004-09-28
1	8866	6536	3	2004-09-12
2	8866	7647	2	2004-09-12
3	8866	3553	1	2004-09-12
4	8866	3123	3	2004-09-12
5	8866	6627	1	2004-09-12
6	8866	2074	2	2004-09-12
1	8867	3352	2	2004-09-09
2	8867	5806	2	2004-09-09
3	8867	4284	2	2004-09-09
4	8867	2240	3	2004-09-09
5	8867	5323	1	2004-09-09
1	8868	5374	3	2004-09-19
2	8868	8527	1	2004-09-19
3	8868	1321	1	2004-09-19
4	8868	6217	2	2004-09-19
5	8868	333	1	2004-09-19
6	8868	6635	1	2004-09-19
7	8868	7012	3	2004-09-19
8	8868	5667	2	2004-09-19
9	8868	4164	3	2004-09-19
1	8869	4971	3	2004-09-28
2	8869	2565	1	2004-09-28
3	8869	8575	3	2004-09-28
4	8869	9556	3	2004-09-28
1	8870	7950	3	2004-09-24
2	8870	8347	2	2004-09-24
3	8870	1378	3	2004-09-24
4	8870	7009	3	2004-09-24
5	8870	1086	2	2004-09-24
6	8870	7350	3	2004-09-24
1	8871	1483	1	2004-09-24
2	8871	377	2	2004-09-24
3	8871	8923	1	2004-09-24
4	8871	6747	3	2004-09-24
5	8871	1605	2	2004-09-24
6	8871	6325	3	2004-09-24
7	8871	1231	1	2004-09-24
1	8872	3345	1	2004-09-17
2	8872	2639	1	2004-09-17
3	8872	8263	2	2004-09-17
4	8872	4374	2	2004-09-17
1	8873	9052	3	2004-09-02
2	8873	7474	3	2004-09-02
3	8873	5061	2	2004-09-02
4	8873	2369	1	2004-09-02
5	8873	3894	2	2004-09-02
6	8873	8109	1	2004-09-02
1	8874	8519	1	2004-09-10
2	8874	2893	1	2004-09-10
3	8874	1281	2	2004-09-10
4	8874	2217	3	2004-09-10
5	8874	9256	2	2004-09-10
6	8874	5155	3	2004-09-10
7	8874	8718	1	2004-09-10
8	8874	5979	3	2004-09-10
9	8874	887	2	2004-09-10
1	8875	7755	2	2004-09-22
2	8875	3539	2	2004-09-22
3	8875	3958	3	2004-09-22
4	8875	5202	2	2004-09-22
5	8875	5791	2	2004-09-22
6	8875	7144	3	2004-09-22
7	8875	5584	3	2004-09-22
8	8875	4214	3	2004-09-22
9	8875	7967	2	2004-09-22
1	8876	5400	3	2004-09-14
2	8876	876	2	2004-09-14
3	8876	2632	3	2004-09-14
1	8877	6220	1	2004-09-07
2	8877	5853	1	2004-09-07
3	8877	8033	1	2004-09-07
4	8877	6292	2	2004-09-07
5	8877	4775	2	2004-09-07
6	8877	2505	1	2004-09-07
7	8877	1859	3	2004-09-07
8	8877	8158	3	2004-09-07
9	8877	188	1	2004-09-07
1	8878	2568	2	2004-09-09
2	8878	4631	2	2004-09-09
3	8878	4604	3	2004-09-09
4	8878	7678	1	2004-09-09
5	8878	6854	2	2004-09-09
6	8878	3416	1	2004-09-09
7	8878	4076	1	2004-09-09
8	8878	3761	1	2004-09-09
1	8879	8892	2	2004-09-16
2	8879	4495	3	2004-09-16
3	8879	5485	2	2004-09-16
4	8879	9598	3	2004-09-16
5	8879	8070	2	2004-09-16
6	8879	6774	1	2004-09-16
7	8879	1784	1	2004-09-16
1	8880	8627	2	2004-09-18
2	8880	7412	1	2004-09-18
3	8880	7830	1	2004-09-18
4	8880	3491	1	2004-09-18
1	8881	6537	3	2004-09-06
2	8881	1318	1	2004-09-06
3	8881	6066	3	2004-09-06
4	8881	5713	2	2004-09-06
5	8881	5232	2	2004-09-06
6	8881	916	1	2004-09-06
1	8882	9086	1	2004-09-14
1	8883	9755	2	2004-09-12
2	8883	2670	1	2004-09-12
1	8884	182	3	2004-09-19
2	8884	5365	1	2004-09-19
3	8884	9573	1	2004-09-19
4	8884	8301	2	2004-09-19
5	8884	7094	2	2004-09-19
6	8884	9067	3	2004-09-19
1	8885	3743	3	2004-09-17
2	8885	629	3	2004-09-17
3	8885	7508	3	2004-09-17
4	8885	8695	3	2004-09-17
5	8885	2067	1	2004-09-17
6	8885	507	3	2004-09-17
7	8885	5889	1	2004-09-17
8	8885	4640	2	2004-09-17
9	8885	1054	1	2004-09-17
1	8886	5911	3	2004-09-23
2	8886	9404	2	2004-09-23
3	8886	6538	2	2004-09-23
4	8886	8464	3	2004-09-23
5	8886	3889	1	2004-09-23
6	8886	7041	2	2004-09-23
1	8887	1811	2	2004-09-30
2	8887	9777	1	2004-09-30
3	8887	2308	2	2004-09-30
4	8887	4830	3	2004-09-30
5	8887	1737	2	2004-09-30
6	8887	6951	3	2004-09-30
7	8887	6510	3	2004-09-30
8	8887	5177	1	2004-09-30
1	8888	9521	2	2004-09-21
2	8888	696	2	2004-09-21
3	8888	8067	3	2004-09-21
4	8888	7927	3	2004-09-21
1	8889	3894	2	2004-09-07
2	8889	6412	2	2004-09-07
3	8889	1641	1	2004-09-07
4	8889	3149	2	2004-09-07
1	8890	8483	3	2004-09-22
2	8890	6053	2	2004-09-22
3	8890	2440	2	2004-09-22
4	8890	8844	1	2004-09-22
1	8891	7275	1	2004-09-28
2	8891	5164	3	2004-09-28
3	8891	3174	1	2004-09-28
4	8891	3654	3	2004-09-28
5	8891	7335	1	2004-09-28
6	8891	3269	3	2004-09-28
7	8891	1306	2	2004-09-28
1	8892	2062	2	2004-09-08
2	8892	2894	3	2004-09-08
3	8892	392	2	2004-09-08
4	8892	1565	3	2004-09-08
5	8892	7292	1	2004-09-08
1	8893	5958	2	2004-09-27
2	8893	5607	3	2004-09-27
3	8893	4779	3	2004-09-27
4	8893	6198	1	2004-09-27
5	8893	9326	3	2004-09-27
6	8893	1089	1	2004-09-27
1	8894	8475	1	2004-09-18
2	8894	7395	1	2004-09-18
3	8894	9235	3	2004-09-18
1	8895	1676	2	2004-09-21
2	8895	6653	3	2004-09-21
3	8895	1844	1	2004-09-21
4	8895	3349	3	2004-09-21
1	8896	242	2	2004-09-06
2	8896	7404	1	2004-09-06
3	8896	6667	1	2004-09-06
4	8896	4771	2	2004-09-06
5	8896	5682	1	2004-09-06
6	8896	6846	1	2004-09-06
7	8896	4613	2	2004-09-06
8	8896	863	1	2004-09-06
1	8897	3679	1	2004-09-21
2	8897	8487	2	2004-09-21
3	8897	4567	1	2004-09-21
4	8897	2973	2	2004-09-21
5	8897	9964	3	2004-09-21
6	8897	4245	1	2004-09-21
7	8897	5719	1	2004-09-21
8	8897	1535	1	2004-09-21
1	8898	9551	2	2004-09-15
1	8899	5476	3	2004-09-12
2	8899	2438	1	2004-09-12
3	8899	6474	2	2004-09-12
4	8899	2737	2	2004-09-12
5	8899	1638	3	2004-09-12
1	8900	4293	3	2004-09-21
2	8900	6964	1	2004-09-21
3	8900	9503	3	2004-09-21
4	8900	2396	2	2004-09-21
5	8900	4804	1	2004-09-21
6	8900	5050	2	2004-09-21
7	8900	5462	3	2004-09-21
1	8901	4415	2	2004-09-26
2	8901	4773	1	2004-09-26
3	8901	1847	3	2004-09-26
4	8901	5848	2	2004-09-26
1	8902	9402	1	2004-09-15
2	8902	6277	2	2004-09-15
3	8902	2400	2	2004-09-15
4	8902	4864	2	2004-09-15
5	8902	213	3	2004-09-15
6	8902	5301	2	2004-09-15
7	8902	4022	1	2004-09-15
8	8902	4003	1	2004-09-15
1	8903	3027	1	2004-09-22
2	8903	2561	2	2004-09-22
1	8904	1052	2	2004-09-27
2	8904	2047	1	2004-09-27
3	8904	8842	3	2004-09-27
4	8904	6819	1	2004-09-27
1	8905	1349	1	2004-09-13
2	8905	9577	2	2004-09-13
3	8905	2098	2	2004-09-13
4	8905	7910	3	2004-09-13
1	8906	5747	2	2004-09-03
2	8906	8776	2	2004-09-03
3	8906	2000	3	2004-09-03
4	8906	8186	1	2004-09-03
1	8907	8556	1	2004-09-11
2	8907	3670	1	2004-09-11
3	8907	2004	3	2004-09-11
1	8908	8723	1	2004-09-21
2	8908	126	2	2004-09-21
3	8908	2495	1	2004-09-21
4	8908	1075	2	2004-09-21
5	8908	4903	3	2004-09-21
6	8908	7116	2	2004-09-21
1	8909	2166	2	2004-09-05
2	8909	9801	2	2004-09-05
3	8909	6829	3	2004-09-05
4	8909	5992	1	2004-09-05
5	8909	1014	3	2004-09-05
6	8909	202	3	2004-09-05
7	8909	1347	1	2004-09-05
8	8909	4532	1	2004-09-05
9	8909	4380	2	2004-09-05
1	8910	398	1	2004-09-21
2	8910	4597	3	2004-09-21
3	8910	4239	2	2004-09-21
4	8910	6629	2	2004-09-21
5	8910	5546	3	2004-09-21
6	8910	9452	2	2004-09-21
7	8910	4464	2	2004-09-21
1	8911	8449	3	2004-09-12
2	8911	2701	3	2004-09-12
3	8911	8221	3	2004-09-12
4	8911	9864	1	2004-09-12
5	8911	1889	2	2004-09-12
1	8912	8108	3	2004-09-29
2	8912	7385	1	2004-09-29
3	8912	4915	2	2004-09-29
4	8912	7398	1	2004-09-29
5	8912	2807	3	2004-09-29
6	8912	5807	3	2004-09-29
7	8912	3129	3	2004-09-29
8	8912	7725	3	2004-09-29
9	8912	4225	2	2004-09-29
1	8913	4157	2	2004-09-21
2	8913	7703	2	2004-09-21
3	8913	2397	3	2004-09-21
4	8913	3592	3	2004-09-21
5	8913	7047	1	2004-09-21
1	8914	8443	1	2004-09-18
1	8915	8519	1	2004-09-04
2	8915	6363	2	2004-09-04
3	8915	1326	1	2004-09-04
4	8915	2416	3	2004-09-04
5	8915	7512	3	2004-09-04
6	8915	3311	1	2004-09-04
7	8915	4216	1	2004-09-04
1	8916	3349	2	2004-09-24
2	8916	3005	3	2004-09-24
1	8917	8495	1	2004-09-29
2	8917	9357	3	2004-09-29
3	8917	7508	3	2004-09-29
4	8917	8208	2	2004-09-29
5	8917	4119	3	2004-09-29
6	8917	4457	2	2004-09-29
7	8917	7741	1	2004-09-29
8	8917	4919	1	2004-09-29
1	8918	5747	1	2004-09-11
2	8918	2656	3	2004-09-11
1	8919	2711	3	2004-09-17
2	8919	3260	1	2004-09-17
3	8919	8377	1	2004-09-17
4	8919	7992	2	2004-09-17
5	8919	491	2	2004-09-17
1	8920	1143	2	2004-09-30
2	8920	6178	2	2004-09-30
3	8920	4523	3	2004-09-30
4	8920	5195	2	2004-09-30
1	8921	36	1	2004-09-04
2	8921	9480	3	2004-09-04
3	8921	7480	1	2004-09-04
4	8921	5872	1	2004-09-04
1	8922	132	2	2004-09-11
2	8922	7586	3	2004-09-11
1	8923	6789	1	2004-09-26
2	8923	5658	1	2004-09-26
3	8923	85	1	2004-09-26
4	8923	7900	1	2004-09-26
5	8923	1793	2	2004-09-26
6	8923	5069	1	2004-09-26
7	8923	7067	2	2004-09-26
8	8923	9978	2	2004-09-26
9	8923	6739	2	2004-09-26
1	8924	1521	1	2004-09-16
2	8924	2484	3	2004-09-16
3	8924	113	1	2004-09-16
4	8924	2424	2	2004-09-16
5	8924	534	3	2004-09-16
6	8924	4477	2	2004-09-16
7	8924	525	2	2004-09-16
8	8924	7044	3	2004-09-16
1	8925	664	1	2004-09-18
1	8926	6492	1	2004-09-17
2	8926	2299	2	2004-09-17
1	8927	2926	3	2004-09-27
2	8927	2120	2	2004-09-27
1	8928	8845	2	2004-09-04
2	8928	176	2	2004-09-04
3	8928	3511	2	2004-09-04
4	8928	4724	3	2004-09-04
5	8928	6866	2	2004-09-04
6	8928	6903	1	2004-09-04
1	8929	1739	3	2004-09-19
2	8929	9110	1	2004-09-19
3	8929	576	2	2004-09-19
1	8930	8851	2	2004-09-05
2	8930	6395	2	2004-09-05
3	8930	9608	2	2004-09-05
4	8930	8499	3	2004-09-05
1	8931	8683	1	2004-09-04
2	8931	1239	2	2004-09-04
3	8931	4927	3	2004-09-04
4	8931	7264	3	2004-09-04
5	8931	9790	3	2004-09-04
6	8931	6141	3	2004-09-04
1	8932	218	3	2004-09-29
1	8933	2481	1	2004-09-15
2	8933	6436	1	2004-09-15
1	8934	3414	1	2004-09-04
2	8934	9474	2	2004-09-04
3	8934	7256	2	2004-09-04
4	8934	1921	2	2004-09-04
5	8934	3784	1	2004-09-04
6	8934	3523	3	2004-09-04
7	8934	610	1	2004-09-04
1	8935	3121	3	2004-09-20
2	8935	5927	2	2004-09-20
3	8935	23	3	2004-09-20
4	8935	6088	2	2004-09-20
5	8935	9388	3	2004-09-20
6	8935	4020	1	2004-09-20
7	8935	3998	3	2004-09-20
1	8936	7871	2	2004-09-13
2	8936	5823	1	2004-09-13
1	8937	2309	3	2004-09-18
2	8937	1760	2	2004-09-18
3	8937	5079	2	2004-09-18
4	8937	5160	1	2004-09-18
5	8937	9681	2	2004-09-18
6	8937	9413	2	2004-09-18
1	8938	1176	3	2004-09-05
2	8938	3092	2	2004-09-05
3	8938	394	2	2004-09-05
4	8938	6525	3	2004-09-05
5	8938	9182	1	2004-09-05
6	8938	9918	2	2004-09-05
1	8939	9717	1	2004-09-06
2	8939	333	2	2004-09-06
3	8939	7862	2	2004-09-06
4	8939	5800	3	2004-09-06
1	8940	4013	2	2004-09-03
2	8940	7973	2	2004-09-03
3	8940	3160	1	2004-09-03
1	8941	1817	2	2004-09-02
2	8941	9281	1	2004-09-02
3	8941	319	1	2004-09-02
4	8941	3231	1	2004-09-02
5	8941	4973	1	2004-09-02
6	8941	4521	2	2004-09-02
7	8941	7742	1	2004-09-02
1	8942	8754	1	2004-09-03
2	8942	3784	1	2004-09-03
1	8943	2820	3	2004-09-29
2	8943	6183	3	2004-09-29
3	8943	5297	3	2004-09-29
1	8944	5550	1	2004-09-14
2	8944	6341	1	2004-09-14
3	8944	5910	1	2004-09-14
4	8944	5826	2	2004-09-14
5	8944	3244	2	2004-09-14
1	8945	6404	1	2004-09-22
2	8945	8711	2	2004-09-22
3	8945	3631	2	2004-09-22
4	8945	8505	2	2004-09-22
5	8945	5026	2	2004-09-22
6	8945	5510	1	2004-09-22
1	8946	4792	1	2004-09-09
2	8946	5381	1	2004-09-09
3	8946	970	1	2004-09-09
1	8947	3418	1	2004-09-06
2	8947	8406	1	2004-09-06
3	8947	8080	2	2004-09-06
4	8947	3386	3	2004-09-06
5	8947	683	3	2004-09-06
1	8948	3875	3	2004-09-11
2	8948	8801	2	2004-09-11
3	8948	8967	2	2004-09-11
4	8948	8978	2	2004-09-11
5	8948	4148	2	2004-09-11
6	8948	4890	2	2004-09-11
7	8948	5650	3	2004-09-11
8	8948	1912	1	2004-09-11
1	8949	6838	1	2004-09-07
1	8950	7240	1	2004-09-17
2	8950	5204	1	2004-09-17
3	8950	9527	3	2004-09-17
4	8950	9681	3	2004-09-17
5	8950	5638	3	2004-09-17
6	8950	2027	2	2004-09-17
1	8951	1291	2	2004-09-08
2	8951	4178	1	2004-09-08
3	8951	5215	2	2004-09-08
4	8951	8531	3	2004-09-08
5	8951	6823	2	2004-09-08
6	8951	8744	1	2004-09-08
7	8951	5592	2	2004-09-08
1	8952	3536	3	2004-09-25
2	8952	2453	1	2004-09-25
3	8952	5238	3	2004-09-25
4	8952	1864	3	2004-09-25
1	8953	1562	2	2004-09-09
2	8953	6302	2	2004-09-09
1	8954	9456	3	2004-09-24
2	8954	1828	3	2004-09-24
3	8954	1014	3	2004-09-24
4	8954	4536	3	2004-09-24
5	8954	250	1	2004-09-24
6	8954	2560	2	2004-09-24
1	8955	3102	3	2004-09-27
2	8955	1333	2	2004-09-27
3	8955	3133	2	2004-09-27
4	8955	7485	2	2004-09-27
1	8956	5303	1	2004-09-29
2	8956	3888	2	2004-09-29
3	8956	1327	2	2004-09-29
4	8956	2956	1	2004-09-29
5	8956	3135	3	2004-09-29
6	8956	1525	2	2004-09-29
7	8956	9413	2	2004-09-29
1	8957	2313	1	2004-09-22
2	8957	3036	2	2004-09-22
3	8957	8004	2	2004-09-22
4	8957	8415	2	2004-09-22
1	8958	5341	2	2004-09-03
2	8958	3763	3	2004-09-03
1	8959	7430	3	2004-09-29
2	8959	9782	3	2004-09-29
3	8959	1461	3	2004-09-29
1	8960	2801	3	2004-09-10
2	8960	4333	2	2004-09-10
1	8961	7824	1	2004-09-11
2	8961	9722	3	2004-09-11
1	8962	4290	1	2004-09-13
2	8962	3011	3	2004-09-13
3	8962	3299	1	2004-09-13
4	8962	7310	1	2004-09-13
5	8962	9394	3	2004-09-13
6	8962	2275	1	2004-09-13
7	8962	7400	3	2004-09-13
8	8962	4567	1	2004-09-13
1	8963	1235	3	2004-09-29
2	8963	4666	3	2004-09-29
3	8963	902	2	2004-09-29
1	8964	2981	2	2004-09-19
2	8964	8840	2	2004-09-19
3	8964	2971	1	2004-09-19
4	8964	6432	1	2004-09-19
5	8964	5218	2	2004-09-19
6	8964	9051	3	2004-09-19
7	8964	8258	2	2004-09-19
8	8964	7204	1	2004-09-19
1	8965	9522	1	2004-09-20
2	8965	723	2	2004-09-20
3	8965	2015	1	2004-09-20
1	8966	6003	3	2004-09-26
2	8966	1760	2	2004-09-26
3	8966	5657	2	2004-09-26
4	8966	6979	1	2004-09-26
5	8966	5010	1	2004-09-26
6	8966	7913	2	2004-09-26
7	8966	9689	2	2004-09-26
8	8966	510	3	2004-09-26
1	8967	9845	1	2004-09-27
1	8968	2191	2	2004-09-12
2	8968	3860	3	2004-09-12
3	8968	3860	3	2004-09-12
4	8968	8540	2	2004-09-12
5	8968	4703	2	2004-09-12
6	8968	350	1	2004-09-12
1	8969	9419	2	2004-09-19
2	8969	366	3	2004-09-19
3	8969	458	3	2004-09-19
4	8969	7088	2	2004-09-19
1	8970	7499	2	2004-09-01
2	8970	9438	3	2004-09-01
3	8970	197	1	2004-09-01
4	8970	8564	2	2004-09-01
1	8971	1299	1	2004-09-10
2	8971	9543	3	2004-09-10
3	8971	5385	2	2004-09-10
4	8971	1777	2	2004-09-10
5	8971	6986	1	2004-09-10
6	8971	4731	3	2004-09-10
7	8971	1502	1	2004-09-10
8	8971	1458	1	2004-09-10
1	8972	2910	2	2004-09-27
2	8972	5939	1	2004-09-27
3	8972	8061	2	2004-09-27
4	8972	7163	1	2004-09-27
5	8972	1606	3	2004-09-27
6	8972	9079	1	2004-09-27
1	8973	2041	1	2004-09-21
2	8973	7051	3	2004-09-21
3	8973	4403	1	2004-09-21
1	8974	7481	1	2004-09-20
2	8974	6478	1	2004-09-20
3	8974	8600	3	2004-09-20
4	8974	7571	2	2004-09-20
5	8974	2493	2	2004-09-20
6	8974	9041	3	2004-09-20
7	8974	6849	1	2004-09-20
8	8974	6494	2	2004-09-20
1	8975	5605	2	2004-09-11
2	8975	6294	1	2004-09-11
3	8975	5614	1	2004-09-11
4	8975	4437	1	2004-09-11
1	8976	387	2	2004-09-20
2	8976	6887	3	2004-09-20
3	8976	5874	2	2004-09-20
4	8976	3525	3	2004-09-20
1	8977	3212	2	2004-09-01
2	8977	2863	3	2004-09-01
3	8977	7872	3	2004-09-01
4	8977	795	2	2004-09-01
5	8977	3998	3	2004-09-01
6	8977	6133	3	2004-09-01
7	8977	7784	1	2004-09-01
1	8978	8462	3	2004-09-06
2	8978	8191	2	2004-09-06
1	8979	2431	3	2004-09-24
2	8979	4070	1	2004-09-24
1	8980	4042	1	2004-09-21
2	8980	7099	2	2004-09-21
3	8980	6316	1	2004-09-21
4	8980	1924	1	2004-09-21
5	8980	707	3	2004-09-21
6	8980	3016	1	2004-09-21
7	8980	4090	1	2004-09-21
8	8980	4104	1	2004-09-21
9	8980	613	1	2004-09-21
1	8981	95	3	2004-09-24
2	8981	7596	2	2004-09-24
3	8981	9241	2	2004-09-24
4	8981	1445	2	2004-09-24
5	8981	4112	2	2004-09-24
6	8981	7046	1	2004-09-24
7	8981	322	2	2004-09-24
1	8982	1953	3	2004-09-07
2	8982	5414	2	2004-09-07
3	8982	445	3	2004-09-07
1	8983	9649	3	2004-09-26
2	8983	4198	3	2004-09-26
3	8983	6958	1	2004-09-26
4	8983	3908	2	2004-09-26
5	8983	6216	2	2004-09-26
6	8983	405	1	2004-09-26
1	8984	811	2	2004-09-03
2	8984	3406	2	2004-09-03
1	8985	1401	2	2004-09-21
2	8985	1788	3	2004-09-21
3	8985	6945	2	2004-09-21
1	8986	6337	3	2004-09-20
1	8987	5597	2	2004-09-08
2	8987	9019	2	2004-09-08
3	8987	2776	1	2004-09-08
4	8987	7595	2	2004-09-08
5	8987	4401	1	2004-09-08
6	8987	206	1	2004-09-08
7	8987	6359	2	2004-09-08
8	8987	3530	3	2004-09-08
1	8988	8916	2	2004-09-05
2	8988	5072	1	2004-09-05
3	8988	4922	1	2004-09-05
4	8988	9406	3	2004-09-05
5	8988	1652	2	2004-09-05
6	8988	6090	3	2004-09-05
7	8988	9653	2	2004-09-05
8	8988	3683	1	2004-09-05
1	8989	2278	2	2004-09-17
1	8990	6394	2	2004-09-04
2	8990	169	2	2004-09-04
3	8990	1880	3	2004-09-04
4	8990	8384	3	2004-09-04
5	8990	9765	1	2004-09-04
1	8991	3498	3	2004-09-26
1	8992	5578	3	2004-09-22
1	8993	7813	3	2004-09-07
2	8993	3131	3	2004-09-07
3	8993	3802	3	2004-09-07
4	8993	3081	2	2004-09-07
5	8993	3670	2	2004-09-07
1	8994	5359	1	2004-09-10
2	8994	1989	2	2004-09-10
3	8994	277	2	2004-09-10
1	8995	8475	2	2004-09-09
2	8995	2318	1	2004-09-09
3	8995	5806	3	2004-09-09
4	8995	5186	2	2004-09-09
5	8995	8897	3	2004-09-09
1	8996	6669	1	2004-09-10
2	8996	1337	3	2004-09-10
3	8996	3562	1	2004-09-10
4	8996	2540	3	2004-09-10
5	8996	3514	2	2004-09-10
6	8996	4981	2	2004-09-10
1	8997	2589	3	2004-09-01
2	8997	2863	2	2004-09-01
3	8997	490	3	2004-09-01
4	8997	4853	2	2004-09-01
5	8997	2286	2	2004-09-01
6	8997	3992	2	2004-09-01
7	8997	6448	1	2004-09-01
8	8997	1961	1	2004-09-01
1	8998	6544	2	2004-09-11
2	8998	5820	1	2004-09-11
3	8998	9906	1	2004-09-11
4	8998	3847	3	2004-09-11
5	8998	8636	2	2004-09-11
6	8998	8569	1	2004-09-11
7	8998	4970	1	2004-09-11
1	8999	1135	1	2004-09-19
1	9000	6956	3	2004-09-15
2	9000	4298	1	2004-09-15
1	9001	1697	2	2004-10-24
2	9001	5227	2	2004-10-24
3	9001	2409	2	2004-10-24
4	9001	7020	3	2004-10-24
5	9001	2166	1	2004-10-24
6	9001	5555	3	2004-10-24
7	9001	2850	2	2004-10-24
1	9002	5711	3	2004-10-22
2	9002	9041	1	2004-10-22
3	9002	4408	3	2004-10-22
1	9003	3020	3	2004-10-26
2	9003	3550	2	2004-10-26
3	9003	4226	3	2004-10-26
4	9003	9580	2	2004-10-26
5	9003	5002	2	2004-10-26
6	9003	4635	3	2004-10-26
1	9004	3704	1	2004-10-22
2	9004	5354	3	2004-10-22
3	9004	4909	1	2004-10-22
4	9004	6855	2	2004-10-22
5	9004	1119	1	2004-10-22
6	9004	2226	3	2004-10-22
7	9004	3537	2	2004-10-22
8	9004	5220	2	2004-10-22
9	9004	2237	3	2004-10-22
1	9005	3097	1	2004-10-04
1	9006	7920	2	2004-10-24
2	9006	4397	1	2004-10-24
3	9006	6402	3	2004-10-24
4	9006	977	1	2004-10-24
5	9006	816	3	2004-10-24
1	9007	1317	1	2004-10-17
2	9007	1658	2	2004-10-17
3	9007	9186	2	2004-10-17
4	9007	5306	1	2004-10-17
5	9007	357	1	2004-10-17
6	9007	1308	2	2004-10-17
7	9007	5400	3	2004-10-17
1	9008	9719	3	2004-10-04
2	9008	728	2	2004-10-04
3	9008	7402	1	2004-10-04
4	9008	7431	3	2004-10-04
5	9008	9535	1	2004-10-04
6	9008	151	3	2004-10-04
7	9008	175	1	2004-10-04
8	9008	1258	1	2004-10-04
9	9008	8003	1	2004-10-04
1	9009	6160	1	2004-10-18
2	9009	9535	1	2004-10-18
3	9009	964	1	2004-10-18
4	9009	6673	2	2004-10-18
5	9009	9824	2	2004-10-18
6	9009	1869	1	2004-10-18
1	9010	7488	1	2004-10-08
2	9010	2633	3	2004-10-08
3	9010	417	1	2004-10-08
4	9010	9105	1	2004-10-08
5	9010	4638	3	2004-10-08
6	9010	2117	1	2004-10-08
7	9010	416	1	2004-10-08
8	9010	6444	2	2004-10-08
9	9010	5223	2	2004-10-08
1	9011	404	2	2004-10-26
2	9011	1199	1	2004-10-26
3	9011	7072	2	2004-10-26
4	9011	1543	3	2004-10-26
5	9011	3653	3	2004-10-26
1	9012	9091	2	2004-10-04
2	9012	3206	2	2004-10-04
1	9013	8338	1	2004-10-09
2	9013	9872	2	2004-10-09
3	9013	6513	3	2004-10-09
1	9014	9731	2	2004-10-31
1	9015	6128	1	2004-10-08
2	9015	2993	3	2004-10-08
3	9015	7658	3	2004-10-08
4	9015	8773	3	2004-10-08
1	9016	7301	2	2004-10-17
2	9016	1609	2	2004-10-17
3	9016	5103	1	2004-10-17
4	9016	9199	1	2004-10-17
5	9016	9485	3	2004-10-17
6	9016	4826	1	2004-10-17
7	9016	9095	2	2004-10-17
8	9016	6307	1	2004-10-17
1	9017	5401	3	2004-10-05
2	9017	4728	1	2004-10-05
3	9017	8133	2	2004-10-05
4	9017	9808	2	2004-10-05
5	9017	5479	1	2004-10-05
6	9017	1879	1	2004-10-05
7	9017	4853	2	2004-10-05
1	9018	1570	2	2004-10-27
2	9018	6561	2	2004-10-27
3	9018	6749	2	2004-10-27
4	9018	951	1	2004-10-27
5	9018	7172	1	2004-10-27
6	9018	7084	1	2004-10-27
7	9018	9794	1	2004-10-27
1	9019	8022	2	2004-10-04
2	9019	2822	2	2004-10-04
3	9019	5635	2	2004-10-04
4	9019	6279	1	2004-10-04
5	9019	8188	2	2004-10-04
6	9019	442	1	2004-10-04
7	9019	2311	1	2004-10-04
8	9019	7607	3	2004-10-04
9	9019	8405	2	2004-10-04
1	9020	1664	2	2004-10-15
2	9020	4349	1	2004-10-15
1	9021	4728	2	2004-10-22
2	9021	7870	3	2004-10-22
3	9021	7500	2	2004-10-22
1	9022	8474	2	2004-10-07
1	9023	9656	2	2004-10-12
2	9023	5552	2	2004-10-12
1	9024	7457	1	2004-10-14
2	9024	7323	2	2004-10-14
3	9024	5701	1	2004-10-14
4	9024	6955	1	2004-10-14
5	9024	7303	2	2004-10-14
6	9024	7977	2	2004-10-14
1	9025	662	3	2004-10-26
2	9025	6749	2	2004-10-26
3	9025	7838	1	2004-10-26
1	9026	1674	1	2004-10-17
1	9027	7783	2	2004-10-13
2	9027	5855	2	2004-10-13
1	9028	7632	1	2004-10-28
2	9028	832	2	2004-10-28
3	9028	2112	3	2004-10-28
4	9028	8277	1	2004-10-28
5	9028	6466	2	2004-10-28
6	9028	7025	2	2004-10-28
1	9029	3473	2	2004-10-26
2	9029	8488	3	2004-10-26
3	9029	1023	2	2004-10-26
4	9029	8856	3	2004-10-26
5	9029	2016	2	2004-10-26
6	9029	2287	1	2004-10-26
1	9030	8083	3	2004-10-24
2	9030	1109	1	2004-10-24
3	9030	7016	3	2004-10-24
4	9030	2967	2	2004-10-24
5	9030	4410	3	2004-10-24
1	9031	8873	2	2004-10-25
2	9031	3046	3	2004-10-25
3	9031	3372	2	2004-10-25
4	9031	3950	1	2004-10-25
5	9031	2873	2	2004-10-25
6	9031	6937	2	2004-10-25
7	9031	6708	2	2004-10-25
8	9031	1356	2	2004-10-25
9	9031	9605	3	2004-10-25
1	9032	99	1	2004-10-04
2	9032	1580	2	2004-10-04
3	9032	2591	3	2004-10-04
4	9032	7131	2	2004-10-04
5	9032	8941	2	2004-10-04
6	9032	990	1	2004-10-04
7	9032	3364	2	2004-10-04
8	9032	6055	3	2004-10-04
1	9033	4086	3	2004-10-21
2	9033	7978	2	2004-10-21
3	9033	3465	3	2004-10-21
4	9033	4880	2	2004-10-21
1	9034	7112	2	2004-10-26
2	9034	2902	3	2004-10-26
3	9034	3590	1	2004-10-26
4	9034	4756	1	2004-10-26
5	9034	6036	2	2004-10-26
6	9034	4517	3	2004-10-26
7	9034	106	1	2004-10-26
8	9034	6713	3	2004-10-26
1	9035	9975	3	2004-10-30
2	9035	9026	2	2004-10-30
3	9035	5777	2	2004-10-30
4	9035	7988	2	2004-10-30
1	9036	4862	2	2004-10-27
2	9036	5233	3	2004-10-27
3	9036	5400	3	2004-10-27
4	9036	983	1	2004-10-27
5	9036	5733	2	2004-10-27
1	9037	2530	2	2004-10-03
2	9037	7537	1	2004-10-03
3	9037	9153	3	2004-10-03
4	9037	940	3	2004-10-03
5	9037	951	3	2004-10-03
6	9037	2085	3	2004-10-03
7	9037	788	1	2004-10-03
1	9038	8621	1	2004-10-30
2	9038	2887	2	2004-10-30
3	9038	1252	2	2004-10-30
4	9038	5457	3	2004-10-30
1	9039	3840	2	2004-10-30
2	9039	1007	1	2004-10-30
3	9039	8098	1	2004-10-30
4	9039	8888	3	2004-10-30
5	9039	8338	3	2004-10-30
1	9040	925	3	2004-10-18
2	9040	9794	3	2004-10-18
3	9040	2785	3	2004-10-18
4	9040	8221	2	2004-10-18
5	9040	2435	3	2004-10-18
6	9040	9540	3	2004-10-18
1	9041	4346	3	2004-10-21
2	9041	4629	2	2004-10-21
3	9041	9398	1	2004-10-21
4	9041	5512	3	2004-10-21
5	9041	1764	2	2004-10-21
6	9041	8124	3	2004-10-21
7	9041	4272	3	2004-10-21
8	9041	4057	2	2004-10-21
9	9041	5251	2	2004-10-21
1	9042	3706	2	2004-10-07
1	9043	2154	3	2004-10-31
2	9043	5578	2	2004-10-31
3	9043	4796	1	2004-10-31
4	9043	1851	2	2004-10-31
5	9043	2933	3	2004-10-31
6	9043	2479	2	2004-10-31
1	9044	7503	2	2004-10-04
2	9044	680	1	2004-10-04
3	9044	118	1	2004-10-04
4	9044	788	1	2004-10-04
5	9044	3204	2	2004-10-04
1	9045	9348	3	2004-10-22
2	9045	6443	2	2004-10-22
3	9045	6391	1	2004-10-22
4	9045	5132	3	2004-10-22
5	9045	5431	3	2004-10-22
6	9045	5605	3	2004-10-22
7	9045	2760	3	2004-10-22
8	9045	8512	2	2004-10-22
9	9045	2301	2	2004-10-22
1	9046	5812	3	2004-10-04
2	9046	3738	3	2004-10-04
1	9047	487	1	2004-10-13
2	9047	1679	3	2004-10-13
1	9048	6311	2	2004-10-20
2	9048	9530	1	2004-10-20
1	9049	7260	1	2004-10-05
1	9050	9854	3	2004-10-19
2	9050	4358	2	2004-10-19
3	9050	8840	3	2004-10-19
4	9050	4408	1	2004-10-19
5	9050	194	2	2004-10-19
1	9051	9942	3	2004-10-08
2	9051	113	2	2004-10-08
3	9051	3590	3	2004-10-08
4	9051	8167	2	2004-10-08
5	9051	1932	3	2004-10-08
6	9051	5117	3	2004-10-08
7	9051	7930	1	2004-10-08
8	9051	7689	1	2004-10-08
1	9052	1134	1	2004-10-19
1	9053	437	2	2004-10-28
2	9053	782	1	2004-10-28
3	9053	2466	1	2004-10-28
4	9053	2253	1	2004-10-28
5	9053	6975	2	2004-10-28
6	9053	2221	2	2004-10-28
7	9053	940	2	2004-10-28
8	9053	2039	2	2004-10-28
9	9053	3343	3	2004-10-28
1	9054	8575	2	2004-10-23
2	9054	3470	3	2004-10-23
3	9054	4279	1	2004-10-23
1	9055	9604	1	2004-10-17
2	9055	7948	1	2004-10-17
3	9055	2599	1	2004-10-17
4	9055	4647	3	2004-10-17
5	9055	6042	3	2004-10-17
6	9055	4713	3	2004-10-17
1	9056	6719	1	2004-10-04
2	9056	5395	3	2004-10-04
3	9056	3404	2	2004-10-04
4	9056	2301	3	2004-10-04
1	9057	2364	1	2004-10-12
2	9057	4613	1	2004-10-12
3	9057	2030	1	2004-10-12
4	9057	4036	2	2004-10-12
5	9057	2760	3	2004-10-12
6	9057	4201	3	2004-10-12
7	9057	5550	3	2004-10-12
8	9057	5781	2	2004-10-12
9	9057	5664	3	2004-10-12
1	9058	1009	1	2004-10-03
2	9058	295	1	2004-10-03
3	9058	9337	2	2004-10-03
4	9058	9889	3	2004-10-03
5	9058	2898	1	2004-10-03
6	9058	8549	3	2004-10-03
1	9059	5207	1	2004-10-14
2	9059	6937	3	2004-10-14
3	9059	1630	1	2004-10-14
4	9059	8320	3	2004-10-14
5	9059	9056	2	2004-10-14
6	9059	6228	3	2004-10-14
7	9059	6366	2	2004-10-14
8	9059	6315	3	2004-10-14
1	9060	581	1	2004-10-25
2	9060	5483	2	2004-10-25
3	9060	2826	2	2004-10-25
4	9060	989	3	2004-10-25
5	9060	4610	1	2004-10-25
6	9060	5299	3	2004-10-25
7	9060	3889	1	2004-10-25
1	9061	2928	2	2004-10-29
2	9061	1528	3	2004-10-29
3	9061	3765	3	2004-10-29
4	9061	4443	1	2004-10-29
5	9061	5268	1	2004-10-29
6	9061	6689	2	2004-10-29
7	9061	9281	3	2004-10-29
1	9062	8794	1	2004-10-21
2	9062	6396	2	2004-10-21
3	9062	2796	1	2004-10-21
4	9062	3221	3	2004-10-21
5	9062	3930	1	2004-10-21
6	9062	2202	3	2004-10-21
7	9062	9988	2	2004-10-21
8	9062	2427	1	2004-10-21
9	9062	4284	2	2004-10-21
1	9063	920	1	2004-10-30
2	9063	628	1	2004-10-30
3	9063	229	3	2004-10-30
4	9063	4963	1	2004-10-30
5	9063	6505	2	2004-10-30
1	9064	4595	1	2004-10-09
2	9064	2193	3	2004-10-09
3	9064	2825	2	2004-10-09
4	9064	7174	1	2004-10-09
5	9064	9523	3	2004-10-09
1	9065	2534	1	2004-10-14
2	9065	8409	2	2004-10-14
3	9065	5023	3	2004-10-14
4	9065	3653	2	2004-10-14
1	9066	2372	3	2004-10-20
2	9066	5593	3	2004-10-20
3	9066	4450	1	2004-10-20
1	9067	1036	2	2004-10-31
2	9067	5550	1	2004-10-31
3	9067	5485	3	2004-10-31
1	9068	3339	1	2004-10-14
2	9068	351	3	2004-10-14
3	9068	1055	2	2004-10-14
4	9068	3612	3	2004-10-14
5	9068	2618	3	2004-10-14
6	9068	9938	2	2004-10-14
7	9068	8780	2	2004-10-14
1	9069	9871	2	2004-10-15
2	9069	7172	1	2004-10-15
3	9069	313	1	2004-10-15
4	9069	1464	2	2004-10-15
1	9070	2726	1	2004-10-09
2	9070	8226	1	2004-10-09
3	9070	8773	3	2004-10-09
4	9070	7079	1	2004-10-09
5	9070	6525	3	2004-10-09
6	9070	2224	2	2004-10-09
1	9071	4233	3	2004-10-15
2	9071	3641	2	2004-10-15
3	9071	2139	1	2004-10-15
4	9071	5009	1	2004-10-15
5	9071	3534	2	2004-10-15
6	9071	8248	2	2004-10-15
7	9071	2300	2	2004-10-15
8	9071	2339	2	2004-10-15
9	9071	5732	1	2004-10-15
1	9072	6890	2	2004-10-26
2	9072	4875	3	2004-10-26
3	9072	2833	3	2004-10-26
4	9072	117	2	2004-10-26
5	9072	8766	2	2004-10-26
1	9073	3219	2	2004-10-08
2	9073	7125	3	2004-10-08
3	9073	9932	2	2004-10-08
4	9073	2884	1	2004-10-08
5	9073	692	2	2004-10-08
1	9074	928	2	2004-10-23
2	9074	536	3	2004-10-23
3	9074	2001	2	2004-10-23
4	9074	6930	2	2004-10-23
5	9074	4970	3	2004-10-23
1	9075	6142	3	2004-10-30
2	9075	6869	3	2004-10-30
1	9076	9365	3	2004-10-11
2	9076	5470	1	2004-10-11
3	9076	4217	1	2004-10-11
1	9077	5634	3	2004-10-21
2	9077	5225	3	2004-10-21
3	9077	4029	1	2004-10-21
4	9077	2469	3	2004-10-21
5	9077	9200	1	2004-10-21
6	9077	2733	1	2004-10-21
7	9077	4322	3	2004-10-21
1	9078	5183	2	2004-10-02
2	9078	6985	2	2004-10-02
3	9078	3340	1	2004-10-02
4	9078	4604	3	2004-10-02
1	9079	8491	1	2004-10-17
2	9079	1881	2	2004-10-17
3	9079	829	2	2004-10-17
1	9080	5424	3	2004-10-19
2	9080	5663	3	2004-10-19
3	9080	6513	2	2004-10-19
4	9080	935	2	2004-10-19
5	9080	9851	2	2004-10-19
1	9081	9290	2	2004-10-29
2	9081	9988	2	2004-10-29
3	9081	6351	3	2004-10-29
1	9082	8557	1	2004-10-24
2	9082	5520	2	2004-10-24
3	9082	4867	1	2004-10-24
4	9082	9494	1	2004-10-24
5	9082	8064	2	2004-10-24
6	9082	36	2	2004-10-24
7	9082	1261	1	2004-10-24
8	9082	9322	1	2004-10-24
9	9082	7087	3	2004-10-24
1	9083	3019	1	2004-10-25
2	9083	1705	3	2004-10-25
3	9083	8376	3	2004-10-25
4	9083	4212	3	2004-10-25
5	9083	9046	1	2004-10-25
6	9083	686	2	2004-10-25
7	9083	7193	2	2004-10-25
1	9084	1843	2	2004-10-16
2	9084	7629	1	2004-10-16
3	9084	6846	3	2004-10-16
1	9085	1684	2	2004-10-14
2	9085	9396	2	2004-10-14
1	9086	535	3	2004-10-22
2	9086	4524	3	2004-10-22
3	9086	1051	2	2004-10-22
4	9086	4145	3	2004-10-22
5	9086	761	3	2004-10-22
1	9087	2479	3	2004-10-16
2	9087	9876	3	2004-10-16
3	9087	6766	2	2004-10-16
4	9087	3257	1	2004-10-16
5	9087	6250	2	2004-10-16
6	9087	8331	2	2004-10-16
7	9087	9643	2	2004-10-16
1	9088	1997	2	2004-10-21
2	9088	6859	1	2004-10-21
3	9088	504	1	2004-10-21
4	9088	1290	1	2004-10-21
5	9088	138	2	2004-10-21
6	9088	7866	1	2004-10-21
7	9088	2991	1	2004-10-21
1	9089	6955	1	2004-10-07
2	9089	1035	1	2004-10-07
3	9089	7866	3	2004-10-07
4	9089	8850	3	2004-10-07
5	9089	4728	2	2004-10-07
6	9089	1222	2	2004-10-07
7	9089	2873	1	2004-10-07
8	9089	793	3	2004-10-07
9	9089	6266	1	2004-10-07
1	9090	3774	1	2004-10-03
1	9091	9631	1	2004-10-10
2	9091	4247	2	2004-10-10
3	9091	3364	2	2004-10-10
4	9091	9790	1	2004-10-10
5	9091	4646	3	2004-10-10
1	9092	4872	3	2004-10-28
2	9092	3178	2	2004-10-28
3	9092	6837	3	2004-10-28
4	9092	6961	3	2004-10-28
5	9092	6999	3	2004-10-28
6	9092	8446	1	2004-10-28
7	9092	9947	1	2004-10-28
8	9092	7537	1	2004-10-28
9	9092	6984	3	2004-10-28
1	9093	6511	2	2004-10-04
2	9093	5748	1	2004-10-04
3	9093	2180	2	2004-10-04
4	9093	531	2	2004-10-04
5	9093	4443	2	2004-10-04
1	9094	7063	3	2004-10-11
1	9095	4833	3	2004-10-25
2	9095	8015	1	2004-10-25
3	9095	8212	2	2004-10-25
4	9095	9536	3	2004-10-25
5	9095	6229	1	2004-10-25
6	9095	3886	1	2004-10-25
1	9096	4117	2	2004-10-22
2	9096	5420	3	2004-10-22
3	9096	9828	3	2004-10-22
4	9096	6179	1	2004-10-22
5	9096	9291	1	2004-10-22
6	9096	8921	3	2004-10-22
7	9096	7302	2	2004-10-22
8	9096	3587	1	2004-10-22
9	9096	3964	1	2004-10-22
1	9097	1543	1	2004-10-14
2	9097	7327	2	2004-10-14
3	9097	5569	2	2004-10-14
4	9097	5061	3	2004-10-14
1	9098	7737	2	2004-10-10
2	9098	7520	2	2004-10-10
3	9098	4612	3	2004-10-10
4	9098	7156	2	2004-10-10
5	9098	4027	2	2004-10-10
6	9098	2	3	2004-10-10
7	9098	6592	2	2004-10-10
8	9098	9216	1	2004-10-10
1	9099	8645	1	2004-10-20
2	9099	3111	2	2004-10-20
3	9099	6617	3	2004-10-20
4	9099	3677	3	2004-10-20
5	9099	7348	3	2004-10-20
6	9099	8363	2	2004-10-20
7	9099	1285	2	2004-10-20
1	9100	9430	3	2004-10-28
2	9100	613	3	2004-10-28
3	9100	4332	3	2004-10-28
4	9100	3397	2	2004-10-28
5	9100	8300	3	2004-10-28
6	9100	9363	2	2004-10-28
1	9101	2220	1	2004-10-23
1	9102	3463	1	2004-10-27
2	9102	932	2	2004-10-27
3	9102	6536	3	2004-10-27
4	9102	644	3	2004-10-27
5	9102	6086	1	2004-10-27
6	9102	5947	3	2004-10-27
1	9103	3826	1	2004-10-30
2	9103	2437	1	2004-10-30
3	9103	5635	3	2004-10-30
1	9104	4040	3	2004-10-04
2	9104	9310	2	2004-10-04
3	9104	4334	1	2004-10-04
4	9104	6983	2	2004-10-04
1	9105	2747	1	2004-10-24
2	9105	8235	3	2004-10-24
3	9105	7980	3	2004-10-24
4	9105	8973	1	2004-10-24
5	9105	638	1	2004-10-24
6	9105	4083	1	2004-10-24
7	9105	5987	3	2004-10-24
8	9105	2730	3	2004-10-24
1	9106	1201	3	2004-10-04
2	9106	1616	2	2004-10-04
3	9106	2677	3	2004-10-04
4	9106	800	1	2004-10-04
5	9106	2118	2	2004-10-04
1	9107	3558	2	2004-10-26
2	9107	4328	1	2004-10-26
3	9107	7138	2	2004-10-26
4	9107	5328	1	2004-10-26
5	9107	8040	1	2004-10-26
6	9107	937	1	2004-10-26
1	9108	7469	2	2004-10-27
2	9108	8995	3	2004-10-27
3	9108	219	1	2004-10-27
4	9108	7683	1	2004-10-27
5	9108	1866	3	2004-10-27
6	9108	7013	1	2004-10-27
7	9108	4664	2	2004-10-27
8	9108	6813	3	2004-10-27
9	9108	9547	1	2004-10-27
1	9109	7904	2	2004-10-03
2	9109	7393	3	2004-10-03
3	9109	4914	2	2004-10-03
4	9109	1024	3	2004-10-03
5	9109	4979	3	2004-10-03
6	9109	3082	2	2004-10-03
1	9110	4318	3	2004-10-24
2	9110	5059	1	2004-10-24
3	9110	7732	3	2004-10-24
4	9110	5620	2	2004-10-24
5	9110	7943	2	2004-10-24
1	9111	4771	3	2004-10-18
2	9111	5934	1	2004-10-18
1	9112	9243	1	2004-10-27
2	9112	8111	1	2004-10-27
3	9112	7004	2	2004-10-27
4	9112	5624	1	2004-10-27
5	9112	945	3	2004-10-27
6	9112	159	2	2004-10-27
7	9112	1271	3	2004-10-27
8	9112	5726	3	2004-10-27
9	9112	2434	2	2004-10-27
1	9113	9907	3	2004-10-07
2	9113	3661	2	2004-10-07
3	9113	9296	1	2004-10-07
4	9113	6686	3	2004-10-07
1	9114	8253	3	2004-10-06
2	9114	5670	2	2004-10-06
3	9114	29	2	2004-10-06
4	9114	3818	1	2004-10-06
5	9114	2618	2	2004-10-06
6	9114	8077	3	2004-10-06
7	9114	1979	1	2004-10-06
8	9114	2012	2	2004-10-06
9	9114	8628	2	2004-10-06
1	9115	4373	1	2004-10-25
2	9115	3858	1	2004-10-25
1	9116	5714	2	2004-10-26
2	9116	5902	1	2004-10-26
3	9116	9115	2	2004-10-26
4	9116	7997	1	2004-10-26
5	9116	6116	1	2004-10-26
6	9116	8021	2	2004-10-26
7	9116	8958	3	2004-10-26
8	9116	4702	1	2004-10-26
1	9117	1863	3	2004-10-13
2	9117	3579	2	2004-10-13
1	9118	3166	2	2004-10-24
2	9118	4309	3	2004-10-24
3	9118	9519	1	2004-10-24
4	9118	262	3	2004-10-24
5	9118	6140	3	2004-10-24
6	9118	1566	1	2004-10-24
1	9119	9585	1	2004-10-28
2	9119	8798	2	2004-10-28
3	9119	4478	2	2004-10-28
4	9119	5596	2	2004-10-28
5	9119	982	3	2004-10-28
6	9119	2575	3	2004-10-28
7	9119	6610	3	2004-10-28
8	9119	4411	3	2004-10-28
1	9120	8930	3	2004-10-13
2	9120	2300	2	2004-10-13
3	9120	7175	2	2004-10-13
4	9120	7324	2	2004-10-13
1	9121	4920	1	2004-10-11
2	9121	6655	3	2004-10-11
3	9121	6813	1	2004-10-11
1	9122	6418	3	2004-10-18
2	9122	8180	1	2004-10-18
3	9122	7810	1	2004-10-18
4	9122	9547	2	2004-10-18
5	9122	5994	3	2004-10-18
6	9122	5380	3	2004-10-18
7	9122	3545	1	2004-10-18
8	9122	2159	1	2004-10-18
1	9123	8645	3	2004-10-27
2	9123	5151	2	2004-10-27
3	9123	8956	1	2004-10-27
1	9124	3004	2	2004-10-24
2	9124	7006	1	2004-10-24
3	9124	7001	2	2004-10-24
4	9124	3511	2	2004-10-24
5	9124	1278	3	2004-10-24
6	9124	5024	2	2004-10-24
7	9124	7798	3	2004-10-24
8	9124	9212	3	2004-10-24
9	9124	9436	3	2004-10-24
1	9125	3634	2	2004-10-18
2	9125	9510	1	2004-10-18
3	9125	7401	3	2004-10-18
4	9125	7282	3	2004-10-18
1	9126	1468	1	2004-10-19
2	9126	7850	2	2004-10-19
3	9126	6877	3	2004-10-19
1	9127	468	2	2004-10-14
2	9127	2238	3	2004-10-14
3	9127	2809	3	2004-10-14
1	9128	8535	1	2004-10-13
2	9128	202	2	2004-10-13
3	9128	8583	3	2004-10-13
4	9128	3091	2	2004-10-13
5	9128	7769	2	2004-10-13
6	9128	7648	3	2004-10-13
7	9128	6750	2	2004-10-13
1	9129	5526	1	2004-10-14
2	9129	978	2	2004-10-14
3	9129	5406	1	2004-10-14
4	9129	5897	3	2004-10-14
5	9129	1019	3	2004-10-14
6	9129	1311	1	2004-10-14
7	9129	7487	3	2004-10-14
8	9129	4557	3	2004-10-14
1	9130	7751	1	2004-10-18
2	9130	5290	2	2004-10-18
3	9130	2178	1	2004-10-18
4	9130	895	2	2004-10-18
5	9130	5665	2	2004-10-18
6	9130	5090	1	2004-10-18
7	9130	5928	2	2004-10-18
8	9130	7183	1	2004-10-18
1	9131	2954	1	2004-10-29
1	9132	8129	2	2004-10-11
2	9132	1029	1	2004-10-11
3	9132	5351	3	2004-10-11
4	9132	6241	1	2004-10-11
5	9132	4178	3	2004-10-11
6	9132	2678	2	2004-10-11
7	9132	4810	3	2004-10-11
8	9132	592	3	2004-10-11
1	9133	7852	2	2004-10-30
2	9133	9794	3	2004-10-30
3	9133	5550	1	2004-10-30
4	9133	8256	3	2004-10-30
5	9133	3187	3	2004-10-30
6	9133	6773	1	2004-10-30
7	9133	5438	3	2004-10-30
1	9134	1427	1	2004-10-15
1	9135	2447	2	2004-10-29
2	9135	3983	1	2004-10-29
3	9135	2941	3	2004-10-29
4	9135	8694	1	2004-10-29
1	9136	1236	2	2004-10-17
1	9137	5737	1	2004-10-30
2	9137	4202	1	2004-10-30
3	9137	1627	1	2004-10-30
4	9137	1208	1	2004-10-30
5	9137	1540	1	2004-10-30
6	9137	7159	3	2004-10-30
1	9138	1585	3	2004-10-15
2	9138	8495	1	2004-10-15
3	9138	7524	2	2004-10-15
4	9138	8767	2	2004-10-15
5	9138	4439	1	2004-10-15
6	9138	2160	2	2004-10-15
7	9138	4424	3	2004-10-15
8	9138	469	1	2004-10-15
1	9139	5453	1	2004-10-27
1	9140	4363	3	2004-10-10
1	9141	4887	2	2004-10-31
2	9141	1707	1	2004-10-31
1	9142	475	1	2004-10-24
2	9142	6005	2	2004-10-24
1	9143	1144	2	2004-10-25
2	9143	6273	2	2004-10-25
3	9143	7290	3	2004-10-25
4	9143	3588	3	2004-10-25
5	9143	9592	3	2004-10-25
6	9143	6255	3	2004-10-25
1	9144	5371	1	2004-10-19
1	9145	4805	2	2004-10-11
2	9145	1811	1	2004-10-11
1	9146	5901	3	2004-10-27
2	9146	9042	1	2004-10-27
3	9146	5022	2	2004-10-27
4	9146	1526	3	2004-10-27
1	9147	554	1	2004-10-19
2	9147	3641	1	2004-10-19
1	9148	1880	3	2004-10-12
2	9148	8585	3	2004-10-12
3	9148	552	1	2004-10-12
4	9148	7494	3	2004-10-12
5	9148	50	2	2004-10-12
6	9148	2440	2	2004-10-12
7	9148	3202	1	2004-10-12
1	9149	6831	2	2004-10-26
2	9149	767	2	2004-10-26
3	9149	5709	1	2004-10-26
4	9149	6054	3	2004-10-26
5	9149	2738	3	2004-10-26
6	9149	8361	3	2004-10-26
7	9149	6767	1	2004-10-26
8	9149	3760	2	2004-10-26
9	9149	6924	2	2004-10-26
1	9150	9193	2	2004-10-18
2	9150	1746	1	2004-10-18
3	9150	7197	3	2004-10-18
4	9150	617	2	2004-10-18
5	9150	9517	3	2004-10-18
6	9150	8643	1	2004-10-18
1	9151	3700	2	2004-10-03
2	9151	6600	1	2004-10-03
3	9151	1066	2	2004-10-03
4	9151	2299	2	2004-10-03
5	9151	8718	3	2004-10-03
6	9151	9136	2	2004-10-03
7	9151	3640	1	2004-10-03
1	9152	5227	2	2004-10-01
2	9152	1872	2	2004-10-01
1	9153	1672	2	2004-10-02
2	9153	3327	1	2004-10-02
3	9153	1018	3	2004-10-02
4	9153	7614	3	2004-10-02
5	9153	9086	3	2004-10-02
6	9153	984	1	2004-10-02
7	9153	3505	3	2004-10-02
8	9153	608	1	2004-10-02
9	9153	4165	2	2004-10-02
1	9154	6427	1	2004-10-16
2	9154	8506	3	2004-10-16
3	9154	8150	3	2004-10-16
1	9155	5567	1	2004-10-31
2	9155	4632	2	2004-10-31
1	9156	925	2	2004-10-26
2	9156	8641	2	2004-10-26
3	9156	4886	3	2004-10-26
4	9156	7068	3	2004-10-26
5	9156	3496	1	2004-10-26
6	9156	3474	1	2004-10-26
7	9156	5300	3	2004-10-26
1	9157	2646	3	2004-10-09
1	9158	1606	2	2004-10-08
2	9158	4623	3	2004-10-08
3	9158	6120	3	2004-10-08
4	9158	7031	3	2004-10-08
5	9158	4009	2	2004-10-08
6	9158	1472	3	2004-10-08
7	9158	4919	3	2004-10-08
8	9158	7945	3	2004-10-08
1	9159	1317	1	2004-10-03
2	9159	9764	3	2004-10-03
3	9159	2905	1	2004-10-03
4	9159	7400	2	2004-10-03
5	9159	2871	2	2004-10-03
6	9159	3416	2	2004-10-03
1	9160	6863	1	2004-10-02
2	9160	3680	1	2004-10-02
3	9160	6952	2	2004-10-02
4	9160	9765	1	2004-10-02
5	9160	3691	3	2004-10-02
6	9160	284	2	2004-10-02
1	9161	1145	1	2004-10-29
1	9162	9425	2	2004-10-31
2	9162	3999	1	2004-10-31
3	9162	9828	2	2004-10-31
4	9162	879	2	2004-10-31
5	9162	1151	3	2004-10-31
6	9162	5359	2	2004-10-31
7	9162	8612	1	2004-10-31
1	9163	6086	2	2004-10-31
2	9163	8021	2	2004-10-31
3	9163	3736	3	2004-10-31
4	9163	5655	2	2004-10-31
1	9164	2970	3	2004-10-27
1	9165	1483	1	2004-10-20
2	9165	136	1	2004-10-20
3	9165	9812	2	2004-10-20
4	9165	7465	3	2004-10-20
5	9165	7805	3	2004-10-20
6	9165	6800	1	2004-10-20
1	9166	8096	1	2004-10-04
2	9166	7467	2	2004-10-04
3	9166	5062	2	2004-10-04
4	9166	9363	2	2004-10-04
5	9166	6746	1	2004-10-04
6	9166	2341	1	2004-10-04
7	9166	9300	2	2004-10-04
8	9166	9035	1	2004-10-04
9	9166	5604	3	2004-10-04
1	9167	3839	1	2004-10-11
1	9168	3523	1	2004-10-26
2	9168	8581	1	2004-10-26
3	9168	1082	2	2004-10-26
4	9168	5368	2	2004-10-26
5	9168	1913	2	2004-10-26
6	9168	132	3	2004-10-26
7	9168	7062	1	2004-10-26
8	9168	1635	2	2004-10-26
9	9168	6006	1	2004-10-26
1	9169	7026	2	2004-10-23
1	9170	1502	1	2004-10-05
2	9170	9207	2	2004-10-05
3	9170	2327	3	2004-10-05
4	9170	6642	2	2004-10-05
5	9170	3835	1	2004-10-05
6	9170	9552	2	2004-10-05
7	9170	6740	3	2004-10-05
8	9170	4406	2	2004-10-05
9	9170	2156	2	2004-10-05
1	9171	9772	2	2004-10-01
2	9171	7864	3	2004-10-01
3	9171	1054	3	2004-10-01
4	9171	7661	3	2004-10-01
5	9171	9066	3	2004-10-01
6	9171	9454	3	2004-10-01
7	9171	4187	1	2004-10-01
1	9172	2838	2	2004-10-19
2	9172	5642	3	2004-10-19
3	9172	4423	1	2004-10-19
4	9172	3378	2	2004-10-19
5	9172	6087	2	2004-10-19
6	9172	4741	1	2004-10-19
7	9172	844	2	2004-10-19
8	9172	9344	3	2004-10-19
9	9172	1309	1	2004-10-19
1	9173	8132	3	2004-10-25
2	9173	5347	1	2004-10-25
3	9173	9658	1	2004-10-25
4	9173	3146	2	2004-10-25
5	9173	1302	2	2004-10-25
6	9173	9585	3	2004-10-25
7	9173	5560	2	2004-10-25
1	9174	2477	2	2004-10-22
2	9174	5871	1	2004-10-22
3	9174	9838	2	2004-10-22
1	9175	115	2	2004-10-07
1	9176	564	1	2004-10-23
2	9176	3863	2	2004-10-23
3	9176	6417	2	2004-10-23
1	9177	9	3	2004-10-31
2	9177	4187	1	2004-10-31
3	9177	2172	2	2004-10-31
4	9177	5920	3	2004-10-31
5	9177	9984	2	2004-10-31
1	9178	2045	3	2004-10-11
2	9178	2904	3	2004-10-11
3	9178	5265	2	2004-10-11
4	9178	1610	2	2004-10-11
5	9178	6387	2	2004-10-11
6	9178	9537	1	2004-10-11
7	9178	636	3	2004-10-11
8	9178	8804	1	2004-10-11
1	9179	9407	2	2004-10-14
2	9179	5328	2	2004-10-14
3	9179	2051	2	2004-10-14
4	9179	1084	2	2004-10-14
5	9179	7321	3	2004-10-14
6	9179	4176	3	2004-10-14
7	9179	5006	3	2004-10-14
8	9179	8520	1	2004-10-14
1	9180	5602	2	2004-10-06
2	9180	1085	2	2004-10-06
3	9180	4863	3	2004-10-06
4	9180	8980	3	2004-10-06
5	9180	8701	1	2004-10-06
6	9180	8005	3	2004-10-06
7	9180	4827	1	2004-10-06
8	9180	3433	3	2004-10-06
1	9181	2504	2	2004-10-27
2	9181	5330	3	2004-10-27
3	9181	3438	2	2004-10-27
4	9181	7780	2	2004-10-27
5	9181	3979	2	2004-10-27
6	9181	3614	3	2004-10-27
1	9182	4586	2	2004-10-30
2	9182	3716	1	2004-10-30
3	9182	5616	1	2004-10-30
4	9182	1393	1	2004-10-30
1	9183	9342	3	2004-10-16
2	9183	9660	1	2004-10-16
3	9183	5862	2	2004-10-16
4	9183	9355	3	2004-10-16
1	9184	1013	3	2004-10-28
2	9184	2397	1	2004-10-28
3	9184	2943	3	2004-10-28
1	9185	816	3	2004-10-16
2	9185	337	1	2004-10-16
3	9185	9069	2	2004-10-16
4	9185	7034	2	2004-10-16
5	9185	9085	2	2004-10-16
6	9185	5890	3	2004-10-16
7	9185	8221	1	2004-10-16
8	9185	3734	3	2004-10-16
1	9186	5387	2	2004-10-04
2	9186	3927	3	2004-10-04
3	9186	6247	3	2004-10-04
4	9186	5998	1	2004-10-04
5	9186	4399	3	2004-10-04
6	9186	9764	2	2004-10-04
1	9187	5490	2	2004-10-24
2	9187	3093	2	2004-10-24
3	9187	829	3	2004-10-24
4	9187	3319	3	2004-10-24
5	9187	733	3	2004-10-24
6	9187	6624	1	2004-10-24
7	9187	9623	1	2004-10-24
1	9188	2793	1	2004-10-24
2	9188	8259	3	2004-10-24
1	9189	7870	2	2004-10-14
2	9189	4312	2	2004-10-14
3	9189	2143	3	2004-10-14
4	9189	9745	2	2004-10-14
1	9190	9623	2	2004-10-14
2	9190	4746	2	2004-10-14
3	9190	6733	2	2004-10-14
4	9190	7578	2	2004-10-14
5	9190	9378	2	2004-10-14
6	9190	5585	1	2004-10-14
7	9190	7932	2	2004-10-14
1	9191	6591	2	2004-10-03
2	9191	4197	1	2004-10-03
3	9191	9661	2	2004-10-03
4	9191	704	3	2004-10-03
5	9191	1574	2	2004-10-03
6	9191	9979	2	2004-10-03
7	9191	2773	3	2004-10-03
8	9191	741	3	2004-10-03
1	9192	1669	1	2004-10-19
2	9192	8057	3	2004-10-19
3	9192	3435	2	2004-10-19
4	9192	1097	2	2004-10-19
1	9193	1968	3	2004-10-26
2	9193	5861	1	2004-10-26
3	9193	3689	2	2004-10-26
4	9193	1034	2	2004-10-26
5	9193	1643	1	2004-10-26
1	9194	1934	2	2004-10-04
2	9194	9267	2	2004-10-04
1	9195	8189	3	2004-10-31
2	9195	3928	3	2004-10-31
3	9195	2916	1	2004-10-31
4	9195	6883	2	2004-10-31
5	9195	7253	3	2004-10-31
6	9195	3421	1	2004-10-31
7	9195	478	3	2004-10-31
8	9195	9678	1	2004-10-31
1	9196	5737	1	2004-10-08
2	9196	5219	3	2004-10-08
3	9196	9595	2	2004-10-08
4	9196	1491	3	2004-10-08
1	9197	5097	1	2004-10-17
2	9197	2893	3	2004-10-17
3	9197	3640	3	2004-10-17
4	9197	4082	1	2004-10-17
1	9198	4612	2	2004-10-27
2	9198	612	3	2004-10-27
3	9198	5005	1	2004-10-27
4	9198	409	1	2004-10-27
5	9198	6269	2	2004-10-27
6	9198	8411	2	2004-10-27
7	9198	112	3	2004-10-27
8	9198	5340	2	2004-10-27
9	9198	6478	1	2004-10-27
1	9199	9585	3	2004-10-29
2	9199	1808	2	2004-10-29
1	9200	9534	2	2004-10-27
2	9200	6324	1	2004-10-27
3	9200	2763	1	2004-10-27
1	9201	8798	1	2004-10-11
2	9201	5409	3	2004-10-11
3	9201	380	1	2004-10-11
4	9201	4442	3	2004-10-11
5	9201	3506	2	2004-10-11
6	9201	8430	3	2004-10-11
7	9201	5614	3	2004-10-11
8	9201	5349	3	2004-10-11
9	9201	1681	2	2004-10-11
1	9202	8628	1	2004-10-25
2	9202	7532	1	2004-10-25
3	9202	4273	1	2004-10-25
4	9202	4561	2	2004-10-25
5	9202	356	2	2004-10-25
6	9202	6820	2	2004-10-25
7	9202	2267	3	2004-10-25
1	9203	290	1	2004-10-21
1	9204	3325	1	2004-10-24
2	9204	6957	1	2004-10-24
3	9204	5029	2	2004-10-24
1	9205	5046	1	2004-10-27
2	9205	6905	3	2004-10-27
3	9205	7138	3	2004-10-27
4	9205	2964	2	2004-10-27
5	9205	3025	2	2004-10-27
6	9205	1156	3	2004-10-27
1	9206	7697	3	2004-10-07
2	9206	8131	3	2004-10-07
3	9206	157	1	2004-10-07
1	9207	693	1	2004-10-02
2	9207	9063	3	2004-10-02
3	9207	7294	2	2004-10-02
4	9207	8013	2	2004-10-02
5	9207	3715	2	2004-10-02
1	9208	1908	1	2004-10-05
2	9208	4021	2	2004-10-05
3	9208	5474	2	2004-10-05
4	9208	6074	1	2004-10-05
5	9208	759	2	2004-10-05
1	9209	8029	3	2004-10-05
2	9209	7152	3	2004-10-05
1	9210	322	2	2004-10-30
2	9210	982	2	2004-10-30
3	9210	9099	1	2004-10-30
4	9210	714	3	2004-10-30
5	9210	6924	1	2004-10-30
6	9210	8467	1	2004-10-30
7	9210	6468	2	2004-10-30
1	9211	6746	3	2004-10-15
2	9211	6194	1	2004-10-15
3	9211	222	2	2004-10-15
4	9211	697	3	2004-10-15
5	9211	2944	1	2004-10-15
1	9212	2829	3	2004-10-12
2	9212	7945	1	2004-10-12
3	9212	391	3	2004-10-12
4	9212	133	3	2004-10-12
1	9213	2539	1	2004-10-04
2	9213	289	3	2004-10-04
3	9213	8057	3	2004-10-04
4	9213	8126	2	2004-10-04
5	9213	9440	3	2004-10-04
6	9213	8473	1	2004-10-04
7	9213	5720	1	2004-10-04
1	9214	3216	1	2004-10-01
2	9214	5243	1	2004-10-01
3	9214	5052	2	2004-10-01
4	9214	9819	2	2004-10-01
5	9214	2948	1	2004-10-01
6	9214	3783	1	2004-10-01
7	9214	8847	2	2004-10-01
1	9215	6170	2	2004-10-13
2	9215	6288	2	2004-10-13
1	9216	6175	2	2004-10-08
2	9216	7469	2	2004-10-08
3	9216	3360	1	2004-10-08
4	9216	9595	3	2004-10-08
5	9216	1845	2	2004-10-08
6	9216	4236	1	2004-10-08
7	9216	9830	3	2004-10-08
8	9216	2762	2	2004-10-08
1	9217	743	2	2004-10-26
2	9217	4407	3	2004-10-26
3	9217	9999	1	2004-10-26
1	9218	602	1	2004-10-08
2	9218	4333	3	2004-10-08
3	9218	8099	3	2004-10-08
4	9218	8754	3	2004-10-08
5	9218	6295	1	2004-10-08
6	9218	2339	1	2004-10-08
7	9218	2261	1	2004-10-08
8	9218	7713	2	2004-10-08
1	9219	8469	3	2004-10-18
2	9219	1619	1	2004-10-18
3	9219	4283	1	2004-10-18
4	9219	3569	3	2004-10-18
5	9219	4057	3	2004-10-18
6	9219	5069	2	2004-10-18
1	9220	7093	1	2004-10-03
2	9220	6443	2	2004-10-03
3	9220	2080	3	2004-10-03
4	9220	3917	2	2004-10-03
5	9220	950	1	2004-10-03
6	9220	9362	3	2004-10-03
7	9220	7729	2	2004-10-03
8	9220	2446	2	2004-10-03
1	9221	5682	1	2004-10-11
2	9221	4447	3	2004-10-11
3	9221	1663	3	2004-10-11
4	9221	4396	1	2004-10-11
5	9221	8916	3	2004-10-11
6	9221	1063	2	2004-10-11
7	9221	8606	3	2004-10-11
1	9222	5025	3	2004-10-30
2	9222	4941	2	2004-10-30
3	9222	3966	1	2004-10-30
1	9223	477	3	2004-10-02
2	9223	1381	2	2004-10-02
3	9223	576	2	2004-10-02
4	9223	5895	1	2004-10-02
1	9224	7414	2	2004-10-17
2	9224	267	2	2004-10-17
3	9224	3118	3	2004-10-17
4	9224	6704	3	2004-10-17
1	9225	6114	1	2004-10-10
2	9225	581	2	2004-10-10
3	9225	7016	3	2004-10-10
4	9225	227	3	2004-10-10
5	9225	7382	1	2004-10-10
6	9225	3650	3	2004-10-10
7	9225	7436	3	2004-10-10
8	9225	196	1	2004-10-10
1	9226	360	3	2004-10-31
2	9226	3268	2	2004-10-31
3	9226	6963	3	2004-10-31
4	9226	2880	3	2004-10-31
5	9226	1699	3	2004-10-31
6	9226	7848	3	2004-10-31
7	9226	122	3	2004-10-31
1	9227	4630	2	2004-10-14
2	9227	6137	3	2004-10-14
3	9227	3214	2	2004-10-14
4	9227	7823	2	2004-10-14
5	9227	6350	3	2004-10-14
1	9228	688	3	2004-10-26
2	9228	1993	3	2004-10-26
3	9228	8145	2	2004-10-26
4	9228	7586	3	2004-10-26
5	9228	4391	2	2004-10-26
6	9228	7656	2	2004-10-26
7	9228	3861	1	2004-10-26
8	9228	1650	1	2004-10-26
1	9229	4557	1	2004-10-21
2	9229	6193	1	2004-10-21
3	9229	3612	1	2004-10-21
1	9230	283	2	2004-10-01
2	9230	3116	1	2004-10-01
3	9230	4266	1	2004-10-01
4	9230	7148	1	2004-10-01
5	9230	1104	1	2004-10-01
1	9231	715	3	2004-10-23
2	9231	2878	3	2004-10-23
1	9232	70	2	2004-10-13
2	9232	914	2	2004-10-13
3	9232	8556	1	2004-10-13
4	9232	5448	2	2004-10-13
5	9232	5893	2	2004-10-13
6	9232	1098	3	2004-10-13
7	9232	8005	2	2004-10-13
8	9232	269	2	2004-10-13
1	9233	130	1	2004-10-23
2	9233	5641	1	2004-10-23
3	9233	437	3	2004-10-23
4	9233	8045	2	2004-10-23
5	9233	8386	3	2004-10-23
1	9234	2136	1	2004-10-10
2	9234	4810	3	2004-10-10
3	9234	6917	1	2004-10-10
4	9234	3314	3	2004-10-10
1	9235	6470	1	2004-10-31
2	9235	1349	1	2004-10-31
3	9235	5086	1	2004-10-31
4	9235	5897	1	2004-10-31
5	9235	2323	2	2004-10-31
6	9235	9246	1	2004-10-31
7	9235	747	3	2004-10-31
8	9235	8233	2	2004-10-31
9	9235	6086	1	2004-10-31
1	9236	5806	1	2004-10-24
2	9236	3064	3	2004-10-24
3	9236	9474	1	2004-10-24
1	9237	3439	2	2004-10-02
2	9237	66	3	2004-10-02
3	9237	5578	2	2004-10-02
4	9237	9251	3	2004-10-02
5	9237	2296	3	2004-10-02
6	9237	8268	1	2004-10-02
7	9237	6127	2	2004-10-02
1	9238	435	1	2004-10-21
2	9238	6649	2	2004-10-21
3	9238	4615	3	2004-10-21
4	9238	5359	2	2004-10-21
1	9239	2703	1	2004-10-08
2	9239	9335	1	2004-10-08
3	9239	8899	2	2004-10-08
4	9239	8731	3	2004-10-08
5	9239	2812	1	2004-10-08
1	9240	7579	1	2004-10-21
2	9240	4985	2	2004-10-21
3	9240	5090	2	2004-10-21
1	9241	1450	3	2004-10-29
2	9241	8044	2	2004-10-29
3	9241	2812	2	2004-10-29
4	9241	9170	2	2004-10-29
1	9242	3417	3	2004-10-17
2	9242	2404	2	2004-10-17
3	9242	8038	3	2004-10-17
4	9242	7308	1	2004-10-17
1	9243	1074	3	2004-10-06
2	9243	2223	1	2004-10-06
3	9243	9736	2	2004-10-06
4	9243	4371	1	2004-10-06
5	9243	897	1	2004-10-06
6	9243	5120	2	2004-10-06
7	9243	7394	2	2004-10-06
1	9244	7003	2	2004-10-29
2	9244	4515	3	2004-10-29
3	9244	2439	1	2004-10-29
4	9244	8454	3	2004-10-29
5	9244	4658	1	2004-10-29
6	9244	4631	3	2004-10-29
7	9244	7079	2	2004-10-29
1	9245	3183	1	2004-10-18
2	9245	6483	2	2004-10-18
3	9245	2903	1	2004-10-18
4	9245	7788	1	2004-10-18
5	9245	5892	3	2004-10-18
1	9246	4896	3	2004-10-10
1	9247	7080	2	2004-10-30
2	9247	8180	1	2004-10-30
3	9247	3802	2	2004-10-30
4	9247	7414	3	2004-10-30
5	9247	4560	2	2004-10-30
6	9247	4662	3	2004-10-30
7	9247	4021	1	2004-10-30
8	9247	1822	3	2004-10-30
1	9248	6618	1	2004-10-09
2	9248	7324	1	2004-10-09
3	9248	309	1	2004-10-09
4	9248	155	3	2004-10-09
5	9248	9554	1	2004-10-09
6	9248	7667	2	2004-10-09
7	9248	7969	2	2004-10-09
8	9248	8344	1	2004-10-09
1	9249	9289	2	2004-10-04
2	9249	3408	1	2004-10-04
3	9249	6939	2	2004-10-04
4	9249	233	3	2004-10-04
5	9249	4837	3	2004-10-04
6	9249	8322	1	2004-10-04
1	9250	7866	1	2004-10-24
2	9250	7783	3	2004-10-24
3	9250	4470	2	2004-10-24
4	9250	4052	1	2004-10-24
5	9250	1296	1	2004-10-24
6	9250	4209	1	2004-10-24
7	9250	8152	2	2004-10-24
8	9250	8066	3	2004-10-24
1	9251	6701	1	2004-10-04
2	9251	7760	1	2004-10-04
3	9251	8433	2	2004-10-04
4	9251	2991	2	2004-10-04
5	9251	1727	2	2004-10-04
6	9251	4167	3	2004-10-04
7	9251	8310	1	2004-10-04
8	9251	7011	1	2004-10-04
1	9252	3458	3	2004-10-23
2	9252	1094	1	2004-10-23
3	9252	4769	3	2004-10-23
4	9252	9051	2	2004-10-23
5	9252	632	3	2004-10-23
6	9252	3981	3	2004-10-23
7	9252	783	1	2004-10-23
8	9252	8869	3	2004-10-23
1	9253	7432	3	2004-10-25
2	9253	9139	2	2004-10-25
3	9253	1477	2	2004-10-25
4	9253	8520	3	2004-10-25
5	9253	7211	2	2004-10-25
6	9253	7568	1	2004-10-25
7	9253	3164	3	2004-10-25
8	9253	2278	3	2004-10-25
9	9253	7820	1	2004-10-25
1	9254	5783	1	2004-10-12
2	9254	9557	2	2004-10-12
3	9254	1126	3	2004-10-12
4	9254	6510	2	2004-10-12
5	9254	6924	2	2004-10-12
6	9254	6013	2	2004-10-12
7	9254	9681	3	2004-10-12
8	9254	2210	3	2004-10-12
1	9255	89	2	2004-10-20
2	9255	2592	1	2004-10-20
3	9255	3033	1	2004-10-20
4	9255	3693	3	2004-10-20
1	9256	6731	2	2004-10-28
2	9256	9294	3	2004-10-28
3	9256	1620	2	2004-10-28
4	9256	4342	3	2004-10-28
5	9256	9744	1	2004-10-28
1	9257	7624	2	2004-10-15
2	9257	6235	3	2004-10-15
3	9257	8138	2	2004-10-15
4	9257	4663	1	2004-10-15
5	9257	8689	3	2004-10-15
6	9257	1140	1	2004-10-15
7	9257	4566	1	2004-10-15
1	9258	3496	2	2004-10-23
2	9258	1788	2	2004-10-23
3	9258	9740	2	2004-10-23
4	9258	3658	3	2004-10-23
1	9259	5076	2	2004-10-21
2	9259	8534	1	2004-10-21
3	9259	6092	3	2004-10-21
4	9259	7633	1	2004-10-21
1	9260	8703	1	2004-10-23
2	9260	8539	2	2004-10-23
3	9260	2267	1	2004-10-23
4	9260	9837	2	2004-10-23
5	9260	7119	1	2004-10-23
6	9260	877	3	2004-10-23
7	9260	7754	2	2004-10-23
8	9260	6341	2	2004-10-23
1	9261	1778	3	2004-10-09
2	9261	9182	3	2004-10-09
3	9261	3767	3	2004-10-09
4	9261	8624	1	2004-10-09
5	9261	3136	3	2004-10-09
6	9261	9704	1	2004-10-09
7	9261	87	3	2004-10-09
8	9261	7743	1	2004-10-09
1	9262	9204	3	2004-10-05
2	9262	5401	3	2004-10-05
3	9262	3527	1	2004-10-05
4	9262	1194	2	2004-10-05
5	9262	6989	3	2004-10-05
6	9262	4194	3	2004-10-05
7	9262	6853	2	2004-10-05
8	9262	6636	1	2004-10-05
1	9263	2332	1	2004-10-01
2	9263	5162	1	2004-10-01
3	9263	9730	1	2004-10-01
1	9264	9696	3	2004-10-15
2	9264	1880	2	2004-10-15
3	9264	6646	2	2004-10-15
1	9265	7596	2	2004-10-22
2	9265	2594	2	2004-10-22
3	9265	9298	3	2004-10-22
4	9265	5068	3	2004-10-22
1	9266	8340	3	2004-10-14
2	9266	9237	3	2004-10-14
3	9266	876	2	2004-10-14
4	9266	9223	1	2004-10-14
5	9266	6896	3	2004-10-14
6	9266	1048	3	2004-10-14
7	9266	4015	3	2004-10-14
1	9267	4680	1	2004-10-13
2	9267	1832	3	2004-10-13
3	9267	7577	1	2004-10-13
4	9267	6501	1	2004-10-13
5	9267	615	1	2004-10-13
6	9267	9495	2	2004-10-13
1	9268	5903	1	2004-10-25
2	9268	1051	2	2004-10-25
3	9268	3630	3	2004-10-25
4	9268	4043	2	2004-10-25
5	9268	6722	3	2004-10-25
6	9268	2371	1	2004-10-25
7	9268	8910	3	2004-10-25
1	9269	861	3	2004-10-22
2	9269	9772	3	2004-10-22
3	9269	1252	1	2004-10-22
4	9269	8350	1	2004-10-22
5	9269	3810	2	2004-10-22
6	9269	8581	2	2004-10-22
7	9269	3199	2	2004-10-22
8	9269	7475	2	2004-10-22
1	9270	5782	3	2004-10-30
2	9270	1708	3	2004-10-30
3	9270	9819	1	2004-10-30
4	9270	6056	2	2004-10-30
1	9271	5694	2	2004-10-14
2	9271	2428	3	2004-10-14
3	9271	5430	1	2004-10-14
4	9271	7692	3	2004-10-14
5	9271	6934	2	2004-10-14
1	9272	4381	1	2004-10-14
2	9272	3022	2	2004-10-14
1	9273	6955	2	2004-10-13
2	9273	6337	1	2004-10-13
3	9273	1943	1	2004-10-13
4	9273	96	3	2004-10-13
5	9273	5609	2	2004-10-13
6	9273	2260	3	2004-10-13
1	9274	6929	2	2004-10-09
1	9275	3289	1	2004-10-21
2	9275	7815	2	2004-10-21
3	9275	6836	1	2004-10-21
4	9275	5113	1	2004-10-21
5	9275	7548	1	2004-10-21
6	9275	7642	2	2004-10-21
7	9275	5077	3	2004-10-21
1	9276	963	3	2004-10-14
1	9277	4124	2	2004-10-26
2	9277	2632	1	2004-10-26
3	9277	5046	3	2004-10-26
4	9277	8275	3	2004-10-26
5	9277	8769	2	2004-10-26
6	9277	4644	2	2004-10-26
7	9277	7917	3	2004-10-26
1	9278	9348	3	2004-10-25
2	9278	5159	2	2004-10-25
3	9278	2072	1	2004-10-25
4	9278	3809	1	2004-10-25
5	9278	1014	1	2004-10-25
6	9278	6731	3	2004-10-25
1	9279	1676	2	2004-10-28
2	9279	9906	3	2004-10-28
1	9280	4280	2	2004-10-15
2	9280	9216	1	2004-10-15
3	9280	9420	1	2004-10-15
4	9280	7789	3	2004-10-15
5	9280	7938	1	2004-10-15
6	9280	2541	1	2004-10-15
7	9280	4904	2	2004-10-15
8	9280	3043	2	2004-10-15
9	9280	8229	3	2004-10-15
1	9281	8389	1	2004-10-12
2	9281	1594	3	2004-10-12
3	9281	2255	2	2004-10-12
4	9281	6970	3	2004-10-12
5	9281	5868	1	2004-10-12
1	9282	6121	1	2004-10-07
2	9282	437	2	2004-10-07
1	9283	9327	3	2004-10-14
2	9283	5019	3	2004-10-14
3	9283	6883	3	2004-10-14
4	9283	4548	3	2004-10-14
5	9283	3810	1	2004-10-14
6	9283	9814	2	2004-10-14
7	9283	1231	1	2004-10-14
8	9283	1811	3	2004-10-14
9	9283	362	3	2004-10-14
1	9284	4280	3	2004-10-30
2	9284	4161	2	2004-10-30
3	9284	2938	3	2004-10-30
1	9285	4113	1	2004-10-24
2	9285	4574	1	2004-10-24
3	9285	1176	3	2004-10-24
4	9285	8506	2	2004-10-24
5	9285	2059	3	2004-10-24
6	9285	387	1	2004-10-24
7	9285	387	1	2004-10-24
1	9286	3359	1	2004-10-05
1	9287	2354	2	2004-10-12
2	9287	6368	1	2004-10-12
3	9287	1457	2	2004-10-12
4	9287	7065	2	2004-10-12
5	9287	6306	1	2004-10-12
6	9287	6565	3	2004-10-12
7	9287	761	2	2004-10-12
8	9287	2466	1	2004-10-12
1	9288	5049	3	2004-10-11
2	9288	4524	2	2004-10-11
3	9288	8536	3	2004-10-11
4	9288	7559	1	2004-10-11
1	9289	3527	3	2004-10-18
2	9289	7921	2	2004-10-18
3	9289	589	2	2004-10-18
4	9289	553	3	2004-10-18
5	9289	6624	3	2004-10-18
6	9289	4375	3	2004-10-18
7	9289	2188	3	2004-10-18
8	9289	204	2	2004-10-18
1	9290	3909	2	2004-10-31
2	9290	9665	1	2004-10-31
3	9290	1759	3	2004-10-31
4	9290	4829	3	2004-10-31
5	9290	6297	2	2004-10-31
1	9291	4806	1	2004-10-16
2	9291	8059	2	2004-10-16
3	9291	9466	2	2004-10-16
1	9292	681	1	2004-10-08
2	9292	241	1	2004-10-08
3	9292	8583	3	2004-10-08
4	9292	5113	1	2004-10-08
5	9292	3470	2	2004-10-08
1	9293	2508	3	2004-10-16
2	9293	4986	3	2004-10-16
3	9293	8119	3	2004-10-16
4	9293	736	1	2004-10-16
5	9293	9540	3	2004-10-16
6	9293	8283	3	2004-10-16
7	9293	3477	1	2004-10-16
8	9293	2846	2	2004-10-16
9	9293	5422	2	2004-10-16
1	9294	5255	3	2004-10-25
2	9294	8889	3	2004-10-25
3	9294	3789	2	2004-10-25
4	9294	3953	2	2004-10-25
5	9294	3589	2	2004-10-25
6	9294	4085	3	2004-10-25
1	9295	5128	2	2004-10-13
2	9295	3651	2	2004-10-13
3	9295	4088	3	2004-10-13
4	9295	4168	3	2004-10-13
5	9295	2672	3	2004-10-13
1	9296	6884	1	2004-10-02
2	9296	3369	2	2004-10-02
3	9296	9231	3	2004-10-02
4	9296	9597	1	2004-10-02
1	9297	1759	2	2004-10-10
2	9297	9234	3	2004-10-10
3	9297	8624	2	2004-10-10
4	9297	2384	1	2004-10-10
5	9297	7770	2	2004-10-10
6	9297	9402	1	2004-10-10
7	9297	3405	1	2004-10-10
1	9298	8222	3	2004-10-05
2	9298	7284	1	2004-10-05
3	9298	5216	2	2004-10-05
4	9298	8747	2	2004-10-05
5	9298	9697	1	2004-10-05
6	9298	7997	3	2004-10-05
7	9298	8722	3	2004-10-05
1	9299	2316	3	2004-10-10
2	9299	4004	1	2004-10-10
1	9300	5479	2	2004-10-19
2	9300	3181	3	2004-10-19
3	9300	325	1	2004-10-19
4	9300	7483	3	2004-10-19
5	9300	2992	1	2004-10-19
6	9300	4122	1	2004-10-19
7	9300	7510	2	2004-10-19
8	9300	3431	2	2004-10-19
9	9300	3160	1	2004-10-19
1	9301	7996	1	2004-10-17
2	9301	1757	1	2004-10-17
3	9301	2508	3	2004-10-17
1	9302	8078	1	2004-10-17
1	9303	6011	2	2004-10-28
2	9303	9103	1	2004-10-28
3	9303	6297	2	2004-10-28
4	9303	3951	3	2004-10-28
5	9303	2118	3	2004-10-28
6	9303	1880	3	2004-10-28
1	9304	4410	1	2004-10-11
2	9304	3370	3	2004-10-11
1	9305	9659	3	2004-10-29
2	9305	6269	3	2004-10-29
3	9305	7927	3	2004-10-29
4	9305	4986	2	2004-10-29
5	9305	2394	2	2004-10-29
6	9305	4070	3	2004-10-29
1	9306	5130	1	2004-10-03
2	9306	197	3	2004-10-03
3	9306	2284	3	2004-10-03
1	9307	3610	1	2004-10-31
2	9307	2021	2	2004-10-31
3	9307	6566	1	2004-10-31
1	9308	670	2	2004-10-15
2	9308	6446	1	2004-10-15
3	9308	9332	1	2004-10-15
1	9309	2849	2	2004-10-06
1	9310	2936	1	2004-10-02
2	9310	9444	2	2004-10-02
3	9310	5290	1	2004-10-02
1	9311	8988	1	2004-10-15
2	9311	4140	3	2004-10-15
1	9312	7872	2	2004-10-17
2	9312	2159	3	2004-10-17
1	9313	4357	1	2004-10-12
2	9313	9746	2	2004-10-12
3	9313	3015	1	2004-10-12
4	9313	8570	1	2004-10-12
5	9313	6960	2	2004-10-12
6	9313	5512	1	2004-10-12
7	9313	1169	2	2004-10-12
1	9314	9403	1	2004-10-10
2	9314	1955	2	2004-10-10
3	9314	3156	3	2004-10-10
4	9314	7716	2	2004-10-10
5	9314	9452	1	2004-10-10
6	9314	6008	3	2004-10-10
7	9314	8270	1	2004-10-10
1	9315	698	2	2004-10-30
2	9315	4985	3	2004-10-30
3	9315	9318	1	2004-10-30
1	9316	642	1	2004-10-30
2	9316	9510	1	2004-10-30
3	9316	1943	1	2004-10-30
1	9317	413	1	2004-10-13
2	9317	3222	2	2004-10-13
1	9318	9508	2	2004-10-31
2	9318	2028	1	2004-10-31
3	9318	9133	3	2004-10-31
4	9318	7862	3	2004-10-31
5	9318	7508	3	2004-10-31
6	9318	8936	1	2004-10-31
7	9318	9583	3	2004-10-31
8	9318	2056	3	2004-10-31
9	9318	9622	2	2004-10-31
1	9319	5213	3	2004-10-02
2	9319	2589	3	2004-10-02
1	9320	2080	3	2004-10-19
2	9320	6387	2	2004-10-19
3	9320	9640	2	2004-10-19
1	9321	4721	1	2004-10-04
2	9321	252	2	2004-10-04
3	9321	2481	1	2004-10-04
4	9321	3394	1	2004-10-04
5	9321	6305	2	2004-10-04
6	9321	5662	2	2004-10-04
7	9321	5795	1	2004-10-04
8	9321	4908	3	2004-10-04
1	9322	3549	1	2004-10-29
2	9322	8670	3	2004-10-29
3	9322	7148	3	2004-10-29
4	9322	5455	3	2004-10-29
5	9322	5810	3	2004-10-29
6	9322	6894	1	2004-10-29
7	9322	2327	3	2004-10-29
8	9322	4832	2	2004-10-29
9	9322	9453	3	2004-10-29
1	9323	1157	3	2004-10-22
2	9323	3446	2	2004-10-22
3	9323	6352	1	2004-10-22
1	9324	353	1	2004-10-22
1	9325	5767	2	2004-10-02
2	9325	5261	1	2004-10-02
3	9325	5308	3	2004-10-02
4	9325	9806	1	2004-10-02
5	9325	2396	3	2004-10-02
6	9325	8366	3	2004-10-02
1	9326	8509	2	2004-10-16
2	9326	2235	2	2004-10-16
3	9326	8079	3	2004-10-16
4	9326	2171	1	2004-10-16
5	9326	9584	1	2004-10-16
6	9326	728	3	2004-10-16
1	9327	4475	1	2004-10-01
2	9327	8451	3	2004-10-01
3	9327	8655	3	2004-10-01
4	9327	9922	1	2004-10-01
5	9327	7514	3	2004-10-01
6	9327	357	1	2004-10-01
1	9328	7558	1	2004-10-28
2	9328	2194	2	2004-10-28
3	9328	69	2	2004-10-28
4	9328	5705	3	2004-10-28
5	9328	6888	2	2004-10-28
6	9328	9621	3	2004-10-28
7	9328	6129	2	2004-10-28
1	9329	385	2	2004-10-09
2	9329	9406	1	2004-10-09
1	9330	9448	3	2004-10-20
2	9330	8789	3	2004-10-20
3	9330	4755	2	2004-10-20
4	9330	9080	3	2004-10-20
5	9330	1982	3	2004-10-20
6	9330	1314	3	2004-10-20
1	9331	5112	1	2004-10-28
2	9331	3847	3	2004-10-28
3	9331	849	1	2004-10-28
4	9331	8962	1	2004-10-28
5	9331	5487	3	2004-10-28
6	9331	1541	1	2004-10-28
7	9331	5287	1	2004-10-28
8	9331	8240	2	2004-10-28
1	9332	3374	1	2004-10-24
2	9332	9257	2	2004-10-24
3	9332	1110	1	2004-10-24
1	9333	8332	2	2004-10-10
2	9333	7406	1	2004-10-10
3	9333	1694	3	2004-10-10
4	9333	2518	1	2004-10-10
5	9333	9488	3	2004-10-10
6	9333	9022	1	2004-10-10
7	9333	9689	2	2004-10-10
1	9334	4956	1	2004-10-04
2	9334	1023	3	2004-10-04
3	9334	3887	1	2004-10-04
4	9334	3685	2	2004-10-04
5	9334	850	3	2004-10-04
6	9334	4906	3	2004-10-04
7	9334	3885	1	2004-10-04
8	9334	3504	1	2004-10-04
1	9335	5852	3	2004-10-17
2	9335	5936	2	2004-10-17
3	9335	59	2	2004-10-17
4	9335	9183	1	2004-10-17
5	9335	3553	3	2004-10-17
6	9335	9935	3	2004-10-17
7	9335	151	1	2004-10-17
8	9335	6837	2	2004-10-17
1	9336	7247	2	2004-10-04
2	9336	1709	1	2004-10-04
1	9337	408	1	2004-10-23
2	9337	522	2	2004-10-23
3	9337	996	2	2004-10-23
1	9338	2274	2	2004-10-04
1	9339	3165	1	2004-10-27
2	9339	2728	2	2004-10-27
3	9339	1501	1	2004-10-27
4	9339	6490	3	2004-10-27
5	9339	5698	3	2004-10-27
6	9339	9879	1	2004-10-27
7	9339	3409	1	2004-10-27
8	9339	5462	2	2004-10-27
1	9340	2440	1	2004-10-14
2	9340	6313	2	2004-10-14
3	9340	1522	3	2004-10-14
4	9340	155	1	2004-10-14
5	9340	793	2	2004-10-14
1	9341	8361	3	2004-10-28
2	9341	3239	2	2004-10-28
1	9342	1809	2	2004-10-18
2	9342	7700	3	2004-10-18
3	9342	273	1	2004-10-18
4	9342	3253	1	2004-10-18
5	9342	7222	2	2004-10-18
1	9343	2120	1	2004-10-05
2	9343	3138	1	2004-10-05
3	9343	4664	1	2004-10-05
1	9344	6715	2	2004-10-22
2	9344	80	1	2004-10-22
3	9344	5543	1	2004-10-22
4	9344	7637	3	2004-10-22
5	9344	9582	2	2004-10-22
1	9345	202	2	2004-10-15
2	9345	3566	1	2004-10-15
3	9345	8055	2	2004-10-15
4	9345	4833	1	2004-10-15
5	9345	4146	3	2004-10-15
6	9345	3087	3	2004-10-15
7	9345	9860	3	2004-10-15
8	9345	8749	1	2004-10-15
1	9346	7699	2	2004-10-17
2	9346	8393	2	2004-10-17
3	9346	2730	3	2004-10-17
4	9346	673	3	2004-10-17
5	9346	7829	3	2004-10-17
1	9347	9786	1	2004-10-17
2	9347	2566	2	2004-10-17
3	9347	722	3	2004-10-17
4	9347	2589	2	2004-10-17
5	9347	5521	1	2004-10-17
6	9347	3765	2	2004-10-17
7	9347	5677	3	2004-10-17
8	9347	9732	2	2004-10-17
1	9348	2767	2	2004-10-14
2	9348	584	2	2004-10-14
3	9348	970	3	2004-10-14
1	9349	4981	2	2004-10-05
2	9349	4451	3	2004-10-05
3	9349	846	2	2004-10-05
4	9349	4258	2	2004-10-05
1	9350	4047	1	2004-10-28
2	9350	1697	2	2004-10-28
3	9350	7071	2	2004-10-28
1	9351	1580	3	2004-10-04
2	9351	7413	1	2004-10-04
3	9351	7518	3	2004-10-04
4	9351	8742	2	2004-10-04
1	9352	1268	1	2004-10-09
2	9352	2350	2	2004-10-09
3	9352	4465	1	2004-10-09
4	9352	5302	1	2004-10-09
5	9352	4075	3	2004-10-09
6	9352	1906	2	2004-10-09
7	9352	3126	3	2004-10-09
1	9353	8309	3	2004-10-06
1	9354	4544	3	2004-10-29
2	9354	790	3	2004-10-29
3	9354	3528	1	2004-10-29
4	9354	4447	2	2004-10-29
5	9354	2007	3	2004-10-29
6	9354	319	2	2004-10-29
7	9354	8125	2	2004-10-29
1	9355	7971	3	2004-10-22
2	9355	7700	3	2004-10-22
3	9355	2429	2	2004-10-22
4	9355	9861	1	2004-10-22
5	9355	3152	3	2004-10-22
6	9355	6459	2	2004-10-22
7	9355	6004	1	2004-10-22
8	9355	4024	3	2004-10-22
1	9356	2346	3	2004-10-26
2	9356	9513	1	2004-10-26
3	9356	6248	3	2004-10-26
1	9357	1790	3	2004-10-26
2	9357	1349	3	2004-10-26
3	9357	7463	2	2004-10-26
1	9358	6497	1	2004-10-13
2	9358	1492	1	2004-10-13
3	9358	1975	2	2004-10-13
4	9358	9293	1	2004-10-13
5	9358	3066	3	2004-10-13
6	9358	2964	2	2004-10-13
7	9358	6838	1	2004-10-13
1	9359	6151	3	2004-10-26
2	9359	9614	3	2004-10-26
3	9359	7760	1	2004-10-26
4	9359	7429	2	2004-10-26
5	9359	4739	1	2004-10-26
6	9359	2545	3	2004-10-26
1	9360	1542	1	2004-10-28
1	9361	7896	2	2004-10-19
2	9361	4309	2	2004-10-19
3	9361	7885	1	2004-10-19
4	9361	7818	3	2004-10-19
5	9361	8744	2	2004-10-19
6	9361	7950	3	2004-10-19
7	9361	1908	2	2004-10-19
8	9361	9318	3	2004-10-19
9	9361	931	2	2004-10-19
1	9362	2517	2	2004-10-03
2	9362	33	2	2004-10-03
3	9362	5732	2	2004-10-03
4	9362	4893	3	2004-10-03
5	9362	4764	1	2004-10-03
6	9362	3585	3	2004-10-03
7	9362	7521	1	2004-10-03
8	9362	1456	2	2004-10-03
9	9362	9467	1	2004-10-03
1	9363	3126	3	2004-10-29
2	9363	551	2	2004-10-29
1	9364	1154	1	2004-10-06
2	9364	8769	1	2004-10-06
3	9364	4107	2	2004-10-06
4	9364	7052	3	2004-10-06
5	9364	2676	1	2004-10-06
1	9365	7730	1	2004-10-06
2	9365	4646	3	2004-10-06
3	9365	2544	2	2004-10-06
4	9365	4613	1	2004-10-06
5	9365	5166	3	2004-10-06
6	9365	8971	2	2004-10-06
7	9365	1794	1	2004-10-06
8	9365	7155	3	2004-10-06
9	9365	6134	3	2004-10-06
1	9366	9402	2	2004-10-30
2	9366	2479	1	2004-10-30
3	9366	8362	2	2004-10-30
4	9366	8339	3	2004-10-30
1	9367	3264	2	2004-10-12
2	9367	2168	3	2004-10-12
3	9367	5236	3	2004-10-12
4	9367	5614	2	2004-10-12
5	9367	3050	3	2004-10-12
6	9367	5105	1	2004-10-12
7	9367	6733	1	2004-10-12
8	9367	8513	2	2004-10-12
1	9368	4553	1	2004-10-20
2	9368	7620	1	2004-10-20
3	9368	6329	2	2004-10-20
4	9368	2165	3	2004-10-20
5	9368	2026	2	2004-10-20
1	9369	3165	1	2004-10-26
1	9370	6187	1	2004-10-24
1	9371	9026	3	2004-10-03
2	9371	7389	3	2004-10-03
3	9371	5362	1	2004-10-03
4	9371	675	1	2004-10-03
5	9371	4856	3	2004-10-03
6	9371	8940	3	2004-10-03
7	9371	6902	1	2004-10-03
8	9371	778	2	2004-10-03
9	9371	6254	3	2004-10-03
1	9372	8197	3	2004-10-17
2	9372	3582	2	2004-10-17
3	9372	1583	2	2004-10-17
1	9373	5082	1	2004-10-23
2	9373	4939	1	2004-10-23
3	9373	3164	2	2004-10-23
4	9373	3425	3	2004-10-23
5	9373	2616	1	2004-10-23
6	9373	5039	3	2004-10-23
1	9374	4490	3	2004-10-11
2	9374	9000	2	2004-10-11
3	9374	2752	3	2004-10-11
4	9374	5436	2	2004-10-11
5	9374	1580	3	2004-10-11
6	9374	785	3	2004-10-11
7	9374	2280	2	2004-10-11
8	9374	5209	3	2004-10-11
9	9374	5842	1	2004-10-11
1	9375	7025	3	2004-10-25
2	9375	3592	1	2004-10-25
1	9376	6502	1	2004-10-25
2	9376	2263	2	2004-10-25
3	9376	8664	2	2004-10-25
1	9377	1116	1	2004-10-09
2	9377	3158	2	2004-10-09
3	9377	6750	3	2004-10-09
4	9377	756	1	2004-10-09
1	9378	9787	3	2004-10-27
2	9378	2646	2	2004-10-27
3	9378	685	1	2004-10-27
4	9378	298	3	2004-10-27
1	9379	2301	3	2004-10-10
2	9379	243	2	2004-10-10
3	9379	3695	1	2004-10-10
4	9379	9274	2	2004-10-10
5	9379	3720	1	2004-10-10
1	9380	3062	3	2004-10-26
2	9380	7520	2	2004-10-26
3	9380	3579	3	2004-10-26
4	9380	3279	2	2004-10-26
5	9380	684	2	2004-10-26
6	9380	6763	1	2004-10-26
7	9380	2527	3	2004-10-26
8	9380	7780	2	2004-10-26
9	9380	4958	1	2004-10-26
1	9381	6789	2	2004-10-10
2	9381	1562	1	2004-10-10
3	9381	6783	3	2004-10-10
4	9381	979	3	2004-10-10
5	9381	8728	2	2004-10-10
6	9381	6888	2	2004-10-10
7	9381	8697	1	2004-10-10
1	9382	5938	2	2004-10-12
2	9382	5216	3	2004-10-12
3	9382	3183	1	2004-10-12
4	9382	1924	3	2004-10-12
1	9383	1730	1	2004-10-10
2	9383	2505	1	2004-10-10
3	9383	636	3	2004-10-10
4	9383	3058	1	2004-10-10
5	9383	6866	1	2004-10-10
6	9383	5653	2	2004-10-10
7	9383	8032	2	2004-10-10
8	9383	4220	1	2004-10-10
1	9384	4364	1	2004-10-20
2	9384	726	3	2004-10-20
3	9384	4030	1	2004-10-20
1	9385	5259	3	2004-10-18
2	9385	9152	3	2004-10-18
3	9385	2648	3	2004-10-18
4	9385	7050	2	2004-10-18
5	9385	1400	2	2004-10-18
6	9385	7491	3	2004-10-18
7	9385	7669	2	2004-10-18
8	9385	1401	1	2004-10-18
9	9385	7105	3	2004-10-18
1	9386	3958	1	2004-10-09
2	9386	4709	3	2004-10-09
3	9386	3360	1	2004-10-09
4	9386	5093	1	2004-10-09
5	9386	9418	1	2004-10-09
6	9386	344	3	2004-10-09
7	9386	8114	1	2004-10-09
1	9387	9078	2	2004-10-26
2	9387	6808	3	2004-10-26
3	9387	1709	3	2004-10-26
4	9387	8633	3	2004-10-26
5	9387	5933	1	2004-10-26
6	9387	1737	2	2004-10-26
7	9387	8593	2	2004-10-26
8	9387	6629	1	2004-10-26
9	9387	3681	3	2004-10-26
1	9388	9125	1	2004-10-12
2	9388	1682	3	2004-10-12
3	9388	4311	1	2004-10-12
1	9389	9195	2	2004-10-08
2	9389	8224	1	2004-10-08
1	9390	8288	1	2004-10-15
1	9391	182	1	2004-10-21
2	9391	3274	2	2004-10-21
3	9391	9602	2	2004-10-21
1	9392	5965	3	2004-10-22
2	9392	8708	3	2004-10-22
3	9392	2885	3	2004-10-22
4	9392	9844	1	2004-10-22
5	9392	5101	3	2004-10-22
6	9392	2984	3	2004-10-22
7	9392	4924	1	2004-10-22
8	9392	647	1	2004-10-22
1	9393	590	1	2004-10-13
2	9393	2129	2	2004-10-13
1	9394	456	2	2004-10-13
2	9394	9809	2	2004-10-13
1	9395	7017	2	2004-10-12
2	9395	8521	1	2004-10-12
3	9395	2697	1	2004-10-12
4	9395	2025	3	2004-10-12
5	9395	4205	1	2004-10-12
6	9395	833	3	2004-10-12
1	9396	1198	1	2004-10-31
1	9397	6486	2	2004-10-14
2	9397	6216	2	2004-10-14
3	9397	393	3	2004-10-14
1	9398	9808	2	2004-10-15
2	9398	3944	1	2004-10-15
1	9399	8640	1	2004-10-20
1	9400	9178	1	2004-10-28
2	9400	242	2	2004-10-28
3	9400	8426	2	2004-10-28
4	9400	6142	2	2004-10-28
5	9400	7731	1	2004-10-28
6	9400	1205	3	2004-10-28
7	9400	2128	2	2004-10-28
8	9400	3301	3	2004-10-28
1	9401	5613	3	2004-10-25
2	9401	7755	2	2004-10-25
1	9402	5007	3	2004-10-31
2	9402	6996	2	2004-10-31
3	9402	1655	3	2004-10-31
4	9402	7788	1	2004-10-31
5	9402	997	2	2004-10-31
6	9402	4992	3	2004-10-31
7	9402	6286	2	2004-10-31
8	9402	6849	3	2004-10-31
1	9403	3258	3	2004-10-07
1	9404	4607	3	2004-10-06
2	9404	5986	1	2004-10-06
3	9404	7412	1	2004-10-06
4	9404	9877	2	2004-10-06
5	9404	5177	1	2004-10-06
6	9404	1645	1	2004-10-06
7	9404	1611	1	2004-10-06
8	9404	6893	2	2004-10-06
9	9404	1368	1	2004-10-06
1	9405	8366	3	2004-10-09
2	9405	5061	1	2004-10-09
3	9405	8167	3	2004-10-09
4	9405	493	3	2004-10-09
5	9405	6493	2	2004-10-09
1	9406	3472	2	2004-10-20
2	9406	7982	3	2004-10-20
3	9406	7807	3	2004-10-20
4	9406	1612	3	2004-10-20
1	9407	1683	3	2004-10-08
2	9407	1851	1	2004-10-08
3	9407	3826	1	2004-10-08
4	9407	1618	3	2004-10-08
1	9408	7077	1	2004-10-06
2	9408	7429	1	2004-10-06
3	9408	4757	2	2004-10-06
1	9409	6875	3	2004-10-22
2	9409	4422	3	2004-10-22
3	9409	7329	3	2004-10-22
4	9409	6991	2	2004-10-22
5	9409	324	3	2004-10-22
1	9410	2389	2	2004-10-07
2	9410	4877	2	2004-10-07
3	9410	3348	1	2004-10-07
4	9410	6557	1	2004-10-07
5	9410	2940	2	2004-10-07
6	9410	3664	3	2004-10-07
1	9411	5274	1	2004-10-25
2	9411	5830	3	2004-10-25
3	9411	1285	1	2004-10-25
4	9411	6385	3	2004-10-25
5	9411	6507	3	2004-10-25
6	9411	6948	3	2004-10-25
7	9411	8881	3	2004-10-25
8	9411	4662	1	2004-10-25
1	9412	200	1	2004-10-08
2	9412	6228	1	2004-10-08
3	9412	6038	3	2004-10-08
4	9412	836	2	2004-10-08
5	9412	369	3	2004-10-08
6	9412	1770	2	2004-10-08
1	9413	759	1	2004-10-30
1	9414	5937	3	2004-10-29
2	9414	4959	1	2004-10-29
3	9414	8579	3	2004-10-29
4	9414	136	2	2004-10-29
5	9414	3219	1	2004-10-29
6	9414	6127	3	2004-10-29
1	9415	6016	3	2004-10-11
2	9415	1069	3	2004-10-11
3	9415	5347	1	2004-10-11
4	9415	5386	1	2004-10-11
1	9416	3409	1	2004-10-05
1	9417	9943	3	2004-10-21
2	9417	9026	1	2004-10-21
1	9418	1689	2	2004-10-03
2	9418	9086	1	2004-10-03
3	9418	8196	2	2004-10-03
4	9418	730	3	2004-10-03
5	9418	2888	2	2004-10-03
6	9418	9890	3	2004-10-03
7	9418	6759	1	2004-10-03
1	9419	9995	3	2004-10-14
2	9419	7171	3	2004-10-14
3	9419	211	3	2004-10-14
4	9419	4856	3	2004-10-14
5	9419	7192	2	2004-10-14
6	9419	1480	3	2004-10-14
7	9419	2572	1	2004-10-14
8	9419	1491	1	2004-10-14
1	9420	8949	3	2004-10-13
2	9420	999	3	2004-10-13
3	9420	7920	3	2004-10-13
4	9420	199	1	2004-10-13
5	9420	6919	1	2004-10-13
1	9421	5049	1	2004-10-01
2	9421	4445	3	2004-10-01
3	9421	191	1	2004-10-01
4	9421	5554	1	2004-10-01
5	9421	9240	3	2004-10-01
6	9421	4838	1	2004-10-01
7	9421	9783	3	2004-10-01
1	9422	6189	2	2004-10-02
2	9422	8203	2	2004-10-02
3	9422	2709	3	2004-10-02
4	9422	6444	3	2004-10-02
5	9422	547	2	2004-10-02
6	9422	6540	1	2004-10-02
7	9422	3937	1	2004-10-02
8	9422	2246	3	2004-10-02
9	9422	1492	1	2004-10-02
1	9423	5171	3	2004-10-01
2	9423	9986	2	2004-10-01
3	9423	7975	1	2004-10-01
4	9423	1496	1	2004-10-01
5	9423	9766	3	2004-10-01
6	9423	6880	3	2004-10-01
7	9423	1793	3	2004-10-01
8	9423	6370	3	2004-10-01
9	9423	9215	3	2004-10-01
1	9424	7343	1	2004-10-16
2	9424	7158	3	2004-10-16
3	9424	2888	3	2004-10-16
4	9424	5881	3	2004-10-16
5	9424	6431	1	2004-10-16
6	9424	5937	2	2004-10-16
7	9424	6005	2	2004-10-16
8	9424	6817	3	2004-10-16
1	9425	4550	3	2004-10-19
2	9425	2305	1	2004-10-19
3	9425	5213	1	2004-10-19
1	9426	8831	2	2004-10-25
2	9426	6492	2	2004-10-25
3	9426	3451	3	2004-10-25
4	9426	3163	3	2004-10-25
5	9426	6373	3	2004-10-25
6	9426	382	1	2004-10-25
1	9427	3886	1	2004-10-19
2	9427	9408	3	2004-10-19
3	9427	4775	2	2004-10-19
1	9428	8599	1	2004-10-19
2	9428	1313	2	2004-10-19
1	9429	6132	2	2004-10-28
2	9429	4621	3	2004-10-28
3	9429	3270	1	2004-10-28
4	9429	8886	2	2004-10-28
5	9429	3302	2	2004-10-28
1	9430	1580	3	2004-10-01
2	9430	2993	2	2004-10-01
3	9430	1084	3	2004-10-01
4	9430	3434	2	2004-10-01
1	9431	7906	3	2004-10-01
2	9431	1753	3	2004-10-01
1	9432	7178	2	2004-10-09
2	9432	8277	2	2004-10-09
3	9432	9254	1	2004-10-09
4	9432	958	3	2004-10-09
5	9432	1100	3	2004-10-09
6	9432	3214	1	2004-10-09
7	9432	5804	2	2004-10-09
1	9433	2847	2	2004-10-29
2	9433	4499	1	2004-10-29
3	9433	7153	1	2004-10-29
1	9434	6789	1	2004-10-28
2	9434	8883	2	2004-10-28
1	9435	8737	1	2004-10-28
2	9435	7277	3	2004-10-28
3	9435	9663	1	2004-10-28
4	9435	2516	2	2004-10-28
5	9435	6696	1	2004-10-28
6	9435	2353	1	2004-10-28
7	9435	4014	2	2004-10-28
8	9435	7484	3	2004-10-28
1	9436	3542	1	2004-10-21
2	9436	7254	1	2004-10-21
3	9436	4845	2	2004-10-21
4	9436	4297	2	2004-10-21
5	9436	3296	2	2004-10-21
6	9436	1564	1	2004-10-21
1	9437	9331	2	2004-10-17
2	9437	441	2	2004-10-17
3	9437	5932	1	2004-10-17
4	9437	7968	3	2004-10-17
5	9437	7993	2	2004-10-17
1	9438	363	2	2004-10-27
2	9438	1089	3	2004-10-27
3	9438	3958	2	2004-10-27
4	9438	3753	3	2004-10-27
5	9438	9510	3	2004-10-27
6	9438	2580	1	2004-10-27
7	9438	9080	3	2004-10-27
8	9438	9915	1	2004-10-27
9	9438	2866	3	2004-10-27
1	9439	6099	1	2004-10-17
2	9439	1208	2	2004-10-17
1	9440	9040	3	2004-10-27
2	9440	2405	1	2004-10-27
3	9440	6779	2	2004-10-27
4	9440	6061	1	2004-10-27
5	9440	4617	2	2004-10-27
6	9440	7579	3	2004-10-27
7	9440	6644	2	2004-10-27
8	9440	5088	2	2004-10-27
1	9441	1259	1	2004-10-24
2	9441	4202	3	2004-10-24
3	9441	4314	2	2004-10-24
1	9442	1780	2	2004-10-05
1	9443	546	1	2004-10-30
2	9443	6722	2	2004-10-30
3	9443	5873	2	2004-10-30
4	9443	2358	1	2004-10-30
5	9443	959	3	2004-10-30
6	9443	9075	3	2004-10-30
1	9444	5952	2	2004-10-17
2	9444	4015	1	2004-10-17
3	9444	1114	2	2004-10-17
4	9444	3269	2	2004-10-17
5	9444	5712	2	2004-10-17
6	9444	302	2	2004-10-17
1	9445	4846	3	2004-10-29
2	9445	4938	1	2004-10-29
3	9445	2335	3	2004-10-29
4	9445	3234	1	2004-10-29
5	9445	4740	1	2004-10-29
6	9445	1858	1	2004-10-29
7	9445	7185	2	2004-10-29
8	9445	6794	1	2004-10-29
9	9445	9066	1	2004-10-29
1	9446	6366	1	2004-10-11
2	9446	1718	3	2004-10-11
3	9446	7107	1	2004-10-11
4	9446	1211	3	2004-10-11
5	9446	725	2	2004-10-11
6	9446	6455	2	2004-10-11
7	9446	6774	3	2004-10-11
1	9447	2314	2	2004-10-10
2	9447	7835	3	2004-10-10
3	9447	7302	2	2004-10-10
4	9447	2636	2	2004-10-10
5	9447	5436	2	2004-10-10
6	9447	6545	1	2004-10-10
7	9447	2708	1	2004-10-10
1	9448	5374	1	2004-10-12
1	9449	1761	2	2004-10-29
2	9449	4460	2	2004-10-29
3	9449	3626	2	2004-10-29
4	9449	2416	2	2004-10-29
5	9449	484	1	2004-10-29
6	9449	5438	3	2004-10-29
1	9450	4111	1	2004-10-16
1	9451	1245	1	2004-10-07
2	9451	6507	2	2004-10-07
3	9451	3975	2	2004-10-07
4	9451	2717	1	2004-10-07
5	9451	1393	2	2004-10-07
6	9451	4439	2	2004-10-07
1	9452	4003	1	2004-10-29
2	9452	1862	3	2004-10-29
1	9453	7056	1	2004-10-03
2	9453	5510	3	2004-10-03
3	9453	8444	3	2004-10-03
4	9453	4788	3	2004-10-03
5	9453	2302	1	2004-10-03
1	9454	7096	3	2004-10-20
2	9454	3501	1	2004-10-20
3	9454	4260	1	2004-10-20
4	9454	9598	2	2004-10-20
5	9454	4309	2	2004-10-20
6	9454	9532	2	2004-10-20
7	9454	3041	1	2004-10-20
8	9454	2911	1	2004-10-20
9	9454	5008	3	2004-10-20
1	9455	9633	2	2004-10-07
1	9456	8211	1	2004-10-01
2	9456	5640	2	2004-10-01
3	9456	546	3	2004-10-01
4	9456	6841	2	2004-10-01
5	9456	1838	2	2004-10-01
6	9456	1460	2	2004-10-01
1	9457	1185	2	2004-10-01
2	9457	3635	2	2004-10-01
3	9457	5194	2	2004-10-01
1	9458	8066	3	2004-10-21
2	9458	8276	1	2004-10-21
3	9458	3363	2	2004-10-21
4	9458	5327	3	2004-10-21
5	9458	1793	2	2004-10-21
6	9458	8144	3	2004-10-21
1	9459	6128	2	2004-10-03
2	9459	3128	3	2004-10-03
1	9460	504	3	2004-10-26
2	9460	7637	3	2004-10-26
1	9461	818	1	2004-10-10
2	9461	4355	2	2004-10-10
1	9462	5554	1	2004-10-26
1	9463	8368	3	2004-10-28
2	9463	8919	1	2004-10-28
3	9463	5878	3	2004-10-28
4	9463	5807	3	2004-10-28
1	9464	3521	1	2004-10-28
2	9464	640	3	2004-10-28
3	9464	2680	1	2004-10-28
4	9464	8902	3	2004-10-28
5	9464	5638	3	2004-10-28
6	9464	6715	3	2004-10-28
1	9465	8498	1	2004-10-23
2	9465	9870	3	2004-10-23
3	9465	8888	3	2004-10-23
4	9465	8360	2	2004-10-23
5	9465	5896	2	2004-10-23
6	9465	4314	2	2004-10-23
1	9466	4241	1	2004-10-02
2	9466	1069	3	2004-10-02
3	9466	3491	3	2004-10-02
4	9466	3954	3	2004-10-02
1	9467	2935	3	2004-10-23
2	9467	566	1	2004-10-23
3	9467	9547	1	2004-10-23
4	9467	8298	3	2004-10-23
5	9467	9223	2	2004-10-23
1	9468	9946	1	2004-10-10
2	9468	240	1	2004-10-10
3	9468	5295	2	2004-10-10
4	9468	3374	2	2004-10-10
5	9468	1400	3	2004-10-10
6	9468	6333	2	2004-10-10
7	9468	5991	2	2004-10-10
1	9469	2032	3	2004-10-19
2	9469	388	1	2004-10-19
3	9469	9025	3	2004-10-19
4	9469	14	3	2004-10-19
5	9469	5343	1	2004-10-19
6	9469	3366	2	2004-10-19
7	9469	725	1	2004-10-19
8	9469	7465	1	2004-10-19
9	9469	4651	1	2004-10-19
1	9470	4888	2	2004-10-17
2	9470	2197	1	2004-10-17
3	9470	8972	3	2004-10-17
4	9470	4816	3	2004-10-17
5	9470	7174	3	2004-10-17
6	9470	5585	3	2004-10-17
7	9470	8427	2	2004-10-17
1	9471	1652	2	2004-10-20
2	9471	7756	1	2004-10-20
1	9472	7978	3	2004-10-30
2	9472	2208	3	2004-10-30
3	9472	5628	3	2004-10-30
4	9472	2553	3	2004-10-30
1	9473	8520	1	2004-10-25
2	9473	9637	2	2004-10-25
3	9473	777	3	2004-10-25
1	9474	8613	3	2004-10-28
2	9474	7791	2	2004-10-28
1	9475	1507	3	2004-10-02
2	9475	2656	2	2004-10-02
3	9475	6664	3	2004-10-02
4	9475	809	3	2004-10-02
1	9476	1569	3	2004-10-19
2	9476	5363	1	2004-10-19
1	9477	3162	2	2004-10-11
2	9477	3646	1	2004-10-11
1	9478	8760	3	2004-10-13
2	9478	8329	1	2004-10-13
3	9478	9293	1	2004-10-13
4	9478	3980	2	2004-10-13
5	9478	9266	2	2004-10-13
1	9479	7521	2	2004-10-17
2	9479	5176	1	2004-10-17
3	9479	6343	3	2004-10-17
4	9479	9023	2	2004-10-17
5	9479	618	1	2004-10-17
6	9479	1382	2	2004-10-17
1	9480	9764	2	2004-10-13
2	9480	1827	3	2004-10-13
1	9481	7077	3	2004-10-15
2	9481	3493	1	2004-10-15
3	9481	3713	3	2004-10-15
4	9481	8165	1	2004-10-15
5	9481	2200	2	2004-10-15
6	9481	4117	3	2004-10-15
7	9481	1881	1	2004-10-15
8	9481	4153	1	2004-10-15
1	9482	841	1	2004-10-17
2	9482	1379	1	2004-10-17
3	9482	6921	1	2004-10-17
4	9482	8696	1	2004-10-17
5	9482	4325	3	2004-10-17
6	9482	351	1	2004-10-17
7	9482	6112	2	2004-10-17
8	9482	3651	3	2004-10-17
9	9482	905	1	2004-10-17
1	9483	1646	3	2004-10-04
2	9483	8312	2	2004-10-04
3	9483	9535	2	2004-10-04
4	9483	1331	2	2004-10-04
5	9483	2915	1	2004-10-04
1	9484	7499	1	2004-10-28
2	9484	7324	1	2004-10-28
3	9484	9241	3	2004-10-28
4	9484	3225	2	2004-10-28
5	9484	1517	3	2004-10-28
6	9484	5177	1	2004-10-28
1	9485	1407	3	2004-10-27
2	9485	884	3	2004-10-27
3	9485	2968	1	2004-10-27
4	9485	3354	2	2004-10-27
1	9486	561	3	2004-10-21
2	9486	1151	3	2004-10-21
3	9486	715	3	2004-10-21
4	9486	9883	3	2004-10-21
5	9486	6148	1	2004-10-21
1	9487	85	3	2004-10-17
1	9488	2780	2	2004-10-21
2	9488	7843	2	2004-10-21
3	9488	3823	1	2004-10-21
4	9488	45	1	2004-10-21
5	9488	7463	2	2004-10-21
6	9488	6009	3	2004-10-21
7	9488	5758	3	2004-10-21
8	9488	6083	2	2004-10-21
1	9489	9074	1	2004-10-18
2	9489	9444	3	2004-10-18
1	9490	5138	1	2004-10-07
2	9490	7058	3	2004-10-07
3	9490	3655	2	2004-10-07
4	9490	3663	3	2004-10-07
5	9490	6095	2	2004-10-07
6	9490	8014	2	2004-10-07
7	9490	221	2	2004-10-07
8	9490	1581	2	2004-10-07
9	9490	1181	3	2004-10-07
1	9491	8593	1	2004-10-08
2	9491	610	3	2004-10-08
3	9491	1758	1	2004-10-08
4	9491	7565	3	2004-10-08
5	9491	1761	1	2004-10-08
6	9491	9738	3	2004-10-08
7	9491	619	2	2004-10-08
8	9491	3718	2	2004-10-08
1	9492	3369	3	2004-10-03
2	9492	2904	2	2004-10-03
3	9492	4186	2	2004-10-03
4	9492	2612	2	2004-10-03
5	9492	896	2	2004-10-03
6	9492	5511	3	2004-10-03
7	9492	8942	2	2004-10-03
8	9492	7524	1	2004-10-03
1	9493	7790	3	2004-10-28
1	9494	2689	2	2004-10-30
2	9494	3054	1	2004-10-30
3	9494	3066	2	2004-10-30
1	9495	53	2	2004-10-28
2	9495	9707	1	2004-10-28
3	9495	222	2	2004-10-28
1	9496	9862	1	2004-10-02
2	9496	3048	1	2004-10-02
3	9496	992	1	2004-10-02
4	9496	9971	1	2004-10-02
5	9496	9245	1	2004-10-02
6	9496	3759	1	2004-10-02
7	9496	7470	3	2004-10-02
8	9496	2611	1	2004-10-02
1	9497	4568	2	2004-10-11
2	9497	8587	2	2004-10-11
3	9497	7506	3	2004-10-11
4	9497	9491	3	2004-10-11
5	9497	7971	1	2004-10-11
1	9498	7879	1	2004-10-19
2	9498	9785	3	2004-10-19
3	9498	2619	3	2004-10-19
4	9498	1135	2	2004-10-19
5	9498	963	3	2004-10-19
6	9498	3190	2	2004-10-19
7	9498	9140	2	2004-10-19
8	9498	5069	2	2004-10-19
9	9498	1030	3	2004-10-19
1	9499	8425	2	2004-10-07
2	9499	7649	2	2004-10-07
3	9499	4227	2	2004-10-07
4	9499	4227	2	2004-10-07
5	9499	2498	1	2004-10-07
6	9499	7439	1	2004-10-07
7	9499	9954	1	2004-10-07
8	9499	1311	1	2004-10-07
9	9499	6435	1	2004-10-07
1	9500	6049	1	2004-10-31
2	9500	4475	3	2004-10-31
3	9500	549	3	2004-10-31
4	9500	6695	2	2004-10-31
5	9500	6384	2	2004-10-31
6	9500	7857	2	2004-10-31
7	9500	1514	1	2004-10-31
8	9500	7581	2	2004-10-31
1	9501	2360	3	2004-10-24
2	9501	4916	2	2004-10-24
3	9501	8887	1	2004-10-24
4	9501	5944	3	2004-10-24
5	9501	975	1	2004-10-24
1	9502	4102	1	2004-10-23
2	9502	8560	1	2004-10-23
1	9503	8975	3	2004-10-24
2	9503	7650	2	2004-10-24
3	9503	3170	2	2004-10-24
4	9503	6634	1	2004-10-24
5	9503	9928	3	2004-10-24
6	9503	8814	2	2004-10-24
1	9504	6279	3	2004-10-09
2	9504	399	2	2004-10-09
3	9504	4191	1	2004-10-09
4	9504	5570	3	2004-10-09
5	9504	6354	2	2004-10-09
6	9504	9090	2	2004-10-09
7	9504	9073	2	2004-10-09
8	9504	9631	3	2004-10-09
1	9505	2349	1	2004-10-08
2	9505	6620	1	2004-10-08
3	9505	231	2	2004-10-08
4	9505	7119	1	2004-10-08
5	9505	3134	1	2004-10-08
6	9505	1504	3	2004-10-08
1	9506	5004	3	2004-10-02
2	9506	2963	1	2004-10-02
3	9506	2797	1	2004-10-02
4	9506	5421	1	2004-10-02
5	9506	7057	2	2004-10-02
1	9507	5095	2	2004-10-31
2	9507	5756	1	2004-10-31
3	9507	6955	2	2004-10-31
4	9507	7147	2	2004-10-31
5	9507	8881	1	2004-10-31
1	9508	2287	1	2004-10-23
2	9508	2534	3	2004-10-23
3	9508	1457	2	2004-10-23
4	9508	8647	2	2004-10-23
5	9508	7548	2	2004-10-23
6	9508	6122	2	2004-10-23
7	9508	9118	2	2004-10-23
8	9508	4094	1	2004-10-23
1	9509	902	1	2004-10-02
2	9509	2298	3	2004-10-02
3	9509	7153	1	2004-10-02
4	9509	8327	2	2004-10-02
5	9509	1564	3	2004-10-02
6	9509	2401	2	2004-10-02
1	9510	430	3	2004-10-03
2	9510	6516	3	2004-10-03
3	9510	3853	1	2004-10-03
1	9511	4418	3	2004-10-08
2	9511	5863	1	2004-10-08
3	9511	5543	3	2004-10-08
4	9511	3624	3	2004-10-08
5	9511	4811	1	2004-10-08
6	9511	9020	1	2004-10-08
7	9511	5313	1	2004-10-08
1	9512	2647	2	2004-10-04
2	9512	4225	1	2004-10-04
1	9513	3378	2	2004-10-17
2	9513	2180	1	2004-10-17
3	9513	308	2	2004-10-17
4	9513	1284	2	2004-10-17
5	9513	7141	3	2004-10-17
6	9513	2934	1	2004-10-17
7	9513	4668	3	2004-10-17
8	9513	1540	2	2004-10-17
9	9513	882	3	2004-10-17
1	9514	3999	3	2004-10-14
2	9514	4272	3	2004-10-14
3	9514	289	3	2004-10-14
4	9514	8964	1	2004-10-14
5	9514	8838	1	2004-10-14
6	9514	4976	1	2004-10-14
7	9514	4394	2	2004-10-14
8	9514	7614	2	2004-10-14
1	9515	5518	3	2004-10-05
2	9515	2131	3	2004-10-05
3	9515	858	1	2004-10-05
4	9515	3909	2	2004-10-05
1	9516	5686	3	2004-10-16
2	9516	7269	2	2004-10-16
3	9516	7725	2	2004-10-16
4	9516	7316	2	2004-10-16
5	9516	8573	1	2004-10-16
6	9516	7579	1	2004-10-16
7	9516	7575	2	2004-10-16
8	9516	8643	3	2004-10-16
9	9516	9947	1	2004-10-16
1	9517	2521	3	2004-10-11
2	9517	8559	2	2004-10-11
3	9517	4301	2	2004-10-11
4	9517	4903	3	2004-10-11
5	9517	2653	1	2004-10-11
1	9518	6154	2	2004-10-20
2	9518	511	2	2004-10-20
3	9518	6170	3	2004-10-20
4	9518	7693	2	2004-10-20
1	9519	7482	2	2004-10-11
2	9519	8691	2	2004-10-11
3	9519	1736	1	2004-10-11
1	9520	3901	1	2004-10-16
2	9520	7402	2	2004-10-16
3	9520	3131	2	2004-10-16
4	9520	6475	3	2004-10-16
5	9520	7574	1	2004-10-16
6	9520	3571	3	2004-10-16
7	9520	7355	3	2004-10-16
8	9520	6172	2	2004-10-16
9	9520	3484	3	2004-10-16
1	9521	2446	1	2004-10-05
2	9521	4663	2	2004-10-05
3	9521	2582	3	2004-10-05
4	9521	4474	1	2004-10-05
5	9521	8912	3	2004-10-05
6	9521	2765	2	2004-10-05
7	9521	4928	2	2004-10-05
8	9521	9938	1	2004-10-05
1	9522	5594	1	2004-10-18
2	9522	8897	1	2004-10-18
3	9522	6430	1	2004-10-18
4	9522	1219	3	2004-10-18
5	9522	8637	2	2004-10-18
6	9522	6674	1	2004-10-18
7	9522	5270	1	2004-10-18
8	9522	5262	3	2004-10-18
9	9522	973	3	2004-10-18
1	9523	6197	1	2004-10-26
1	9524	3644	3	2004-10-21
2	9524	1476	3	2004-10-21
3	9524	9852	1	2004-10-21
1	9525	4093	1	2004-10-04
2	9525	6120	1	2004-10-04
1	9526	9241	1	2004-10-08
2	9526	7469	3	2004-10-08
3	9526	2960	2	2004-10-08
4	9526	8152	3	2004-10-08
5	9526	8616	2	2004-10-08
6	9526	5290	1	2004-10-08
7	9526	7203	3	2004-10-08
1	9527	9051	3	2004-10-05
2	9527	7656	1	2004-10-05
1	9528	2515	2	2004-10-05
2	9528	8905	2	2004-10-05
3	9528	3395	3	2004-10-05
4	9528	7694	1	2004-10-05
5	9528	5459	1	2004-10-05
6	9528	6442	2	2004-10-05
7	9528	9809	2	2004-10-05
1	9529	4032	3	2004-10-27
2	9529	4375	1	2004-10-27
3	9529	1008	2	2004-10-27
4	9529	1376	3	2004-10-27
5	9529	5229	1	2004-10-27
6	9529	413	3	2004-10-27
1	9530	7545	3	2004-10-01
2	9530	7335	2	2004-10-01
3	9530	8340	1	2004-10-01
4	9530	5891	2	2004-10-01
5	9530	6404	2	2004-10-01
6	9530	9838	2	2004-10-01
7	9530	797	3	2004-10-01
8	9530	595	2	2004-10-01
9	9530	7582	2	2004-10-01
1	9531	7254	2	2004-10-22
2	9531	1176	3	2004-10-22
3	9531	2044	1	2004-10-22
4	9531	594	2	2004-10-22
5	9531	651	3	2004-10-22
6	9531	3604	3	2004-10-22
7	9531	3376	1	2004-10-22
8	9531	779	3	2004-10-22
1	9532	2080	2	2004-10-21
2	9532	4510	1	2004-10-21
3	9532	589	1	2004-10-21
4	9532	7644	3	2004-10-21
5	9532	682	2	2004-10-21
6	9532	6023	3	2004-10-21
1	9533	8660	2	2004-10-30
2	9533	7833	3	2004-10-30
1	9534	3379	3	2004-10-14
2	9534	6974	1	2004-10-14
3	9534	5255	1	2004-10-14
4	9534	6664	3	2004-10-14
5	9534	7699	1	2004-10-14
6	9534	9	3	2004-10-14
7	9534	3265	3	2004-10-14
1	9535	1882	2	2004-10-19
2	9535	9126	3	2004-10-19
1	9536	7095	3	2004-10-16
2	9536	4327	2	2004-10-16
3	9536	5718	3	2004-10-16
1	9537	4630	2	2004-10-08
2	9537	5052	1	2004-10-08
3	9537	5644	2	2004-10-08
4	9537	616	3	2004-10-08
5	9537	2714	2	2004-10-08
6	9537	2855	2	2004-10-08
7	9537	8448	2	2004-10-08
1	9538	5359	2	2004-10-31
2	9538	7708	1	2004-10-31
3	9538	3907	1	2004-10-31
4	9538	6843	3	2004-10-31
5	9538	9739	3	2004-10-31
1	9539	2016	1	2004-10-08
2	9539	9272	3	2004-10-08
3	9539	7135	3	2004-10-08
4	9539	6568	3	2004-10-08
5	9539	6407	3	2004-10-08
6	9539	6253	2	2004-10-08
7	9539	4160	2	2004-10-08
1	9540	2276	3	2004-10-08
2	9540	238	2	2004-10-08
3	9540	568	3	2004-10-08
4	9540	5806	1	2004-10-08
5	9540	6386	3	2004-10-08
6	9540	7852	2	2004-10-08
7	9540	5064	3	2004-10-08
8	9540	5482	2	2004-10-08
1	9541	2465	1	2004-10-24
2	9541	3517	3	2004-10-24
3	9541	5483	3	2004-10-24
4	9541	4727	3	2004-10-24
1	9542	4088	2	2004-10-13
2	9542	2512	2	2004-10-13
3	9542	3013	3	2004-10-13
4	9542	4962	3	2004-10-13
5	9542	6438	1	2004-10-13
6	9542	2806	1	2004-10-13
1	9543	904	1	2004-10-09
1	9544	2085	2	2004-10-14
2	9544	5496	3	2004-10-14
3	9544	4079	3	2004-10-14
4	9544	2365	3	2004-10-14
5	9544	5880	2	2004-10-14
6	9544	5705	3	2004-10-14
7	9544	1108	3	2004-10-14
8	9544	6710	2	2004-10-14
1	9545	4648	1	2004-10-26
1	9546	543	2	2004-10-29
1	9547	7399	3	2004-10-11
2	9547	2375	1	2004-10-11
3	9547	8938	2	2004-10-11
4	9547	1250	2	2004-10-11
5	9547	1191	3	2004-10-11
6	9547	3210	1	2004-10-11
1	9548	3065	3	2004-10-18
2	9548	4709	3	2004-10-18
3	9548	8813	2	2004-10-18
4	9548	8197	1	2004-10-18
1	9549	9968	1	2004-10-13
2	9549	3070	3	2004-10-13
3	9549	9937	2	2004-10-13
4	9549	8844	3	2004-10-13
5	9549	183	1	2004-10-13
6	9549	3692	1	2004-10-13
7	9549	7049	3	2004-10-13
1	9550	6508	3	2004-10-12
2	9550	9288	1	2004-10-12
1	9551	8684	3	2004-10-24
2	9551	4530	2	2004-10-24
3	9551	6667	2	2004-10-24
4	9551	5890	3	2004-10-24
5	9551	1865	2	2004-10-24
6	9551	5181	1	2004-10-24
1	9552	6737	3	2004-10-15
2	9552	5292	1	2004-10-15
3	9552	570	1	2004-10-15
4	9552	2447	3	2004-10-15
5	9552	1993	1	2004-10-15
6	9552	8293	3	2004-10-15
7	9552	9835	2	2004-10-15
8	9552	5378	3	2004-10-15
1	9553	4405	3	2004-10-09
2	9553	8988	2	2004-10-09
3	9553	5573	2	2004-10-09
4	9553	6978	1	2004-10-09
5	9553	9532	3	2004-10-09
6	9553	8663	2	2004-10-09
7	9553	5629	2	2004-10-09
8	9553	6677	2	2004-10-09
9	9553	6064	3	2004-10-09
1	9554	7643	1	2004-10-11
2	9554	4991	1	2004-10-11
1	9555	6827	3	2004-10-29
2	9555	2815	2	2004-10-29
3	9555	3602	3	2004-10-29
1	9556	8358	3	2004-10-31
2	9556	5782	2	2004-10-31
3	9556	1276	1	2004-10-31
4	9556	184	3	2004-10-31
5	9556	1583	2	2004-10-31
6	9556	5394	1	2004-10-31
7	9556	5024	1	2004-10-31
8	9556	3133	1	2004-10-31
9	9556	6057	1	2004-10-31
1	9557	6317	3	2004-10-24
2	9557	230	3	2004-10-24
3	9557	6610	1	2004-10-24
4	9557	498	2	2004-10-24
1	9558	2841	2	2004-10-31
2	9558	7965	1	2004-10-31
3	9558	1203	3	2004-10-31
4	9558	6481	2	2004-10-31
5	9558	1988	1	2004-10-31
1	9559	7462	3	2004-10-30
2	9559	4672	1	2004-10-30
3	9559	3525	1	2004-10-30
4	9559	1095	2	2004-10-30
5	9559	907	3	2004-10-30
6	9559	3965	1	2004-10-30
1	9560	9194	1	2004-10-10
2	9560	9427	3	2004-10-10
3	9560	6124	1	2004-10-10
4	9560	6706	1	2004-10-10
5	9560	7227	3	2004-10-10
6	9560	4109	3	2004-10-10
1	9561	4737	3	2004-10-12
2	9561	4144	3	2004-10-12
1	9562	2943	2	2004-10-26
2	9562	518	2	2004-10-26
3	9562	9668	1	2004-10-26
4	9562	1477	3	2004-10-26
5	9562	3877	1	2004-10-26
6	9562	6020	3	2004-10-26
7	9562	1534	1	2004-10-26
8	9562	2604	3	2004-10-26
9	9562	1417	3	2004-10-26
1	9563	6502	3	2004-10-18
2	9563	5383	1	2004-10-18
3	9563	5339	2	2004-10-18
4	9563	5884	3	2004-10-18
5	9563	2703	3	2004-10-18
6	9563	3332	1	2004-10-18
7	9563	4741	1	2004-10-18
8	9563	3997	2	2004-10-18
1	9564	7873	3	2004-10-06
2	9564	604	1	2004-10-06
3	9564	7414	1	2004-10-06
4	9564	7189	1	2004-10-06
5	9564	7250	3	2004-10-06
6	9564	1196	2	2004-10-06
7	9564	6606	2	2004-10-06
8	9564	4397	1	2004-10-06
1	9565	9106	1	2004-10-01
2	9565	6089	2	2004-10-01
3	9565	5627	1	2004-10-01
1	9566	5367	2	2004-10-01
2	9566	5837	2	2004-10-01
3	9566	6307	1	2004-10-01
4	9566	7991	2	2004-10-01
5	9566	6282	2	2004-10-01
6	9566	3024	3	2004-10-01
7	9566	8991	3	2004-10-01
1	9567	3667	1	2004-10-13
2	9567	7091	1	2004-10-13
3	9567	3497	1	2004-10-13
4	9567	6617	3	2004-10-13
1	9568	3862	1	2004-10-11
2	9568	7055	3	2004-10-11
1	9569	6857	3	2004-10-25
2	9569	1178	3	2004-10-25
3	9569	6706	1	2004-10-25
4	9569	9510	1	2004-10-25
5	9569	3555	1	2004-10-25
6	9569	4982	3	2004-10-25
1	9570	5251	2	2004-10-07
2	9570	4572	3	2004-10-07
3	9570	3289	1	2004-10-07
4	9570	9739	3	2004-10-07
5	9570	3159	3	2004-10-07
1	9571	7043	3	2004-10-22
2	9571	9025	3	2004-10-22
3	9571	6891	2	2004-10-22
4	9571	8387	2	2004-10-22
5	9571	6491	1	2004-10-22
6	9571	7483	1	2004-10-22
7	9571	9163	3	2004-10-22
8	9571	3543	3	2004-10-22
9	9571	4883	3	2004-10-22
1	9572	636	3	2004-10-18
2	9572	6202	2	2004-10-18
3	9572	3839	1	2004-10-18
4	9572	4900	2	2004-10-18
5	9572	2845	1	2004-10-18
6	9572	1003	1	2004-10-18
7	9572	161	3	2004-10-18
8	9572	7600	3	2004-10-18
9	9572	4294	2	2004-10-18
1	9573	1211	3	2004-10-02
2	9573	8806	2	2004-10-02
3	9573	7898	2	2004-10-02
4	9573	5547	2	2004-10-02
5	9573	3622	2	2004-10-02
6	9573	2253	3	2004-10-02
7	9573	9977	2	2004-10-02
8	9573	2873	2	2004-10-02
9	9573	84	2	2004-10-02
1	9574	8981	2	2004-10-22
2	9574	5525	1	2004-10-22
3	9574	9276	2	2004-10-22
4	9574	5051	2	2004-10-22
5	9574	5664	2	2004-10-22
6	9574	3942	2	2004-10-22
7	9574	2353	1	2004-10-22
1	9575	4082	3	2004-10-29
2	9575	2483	2	2004-10-29
3	9575	5388	2	2004-10-29
1	9576	6558	3	2004-10-28
2	9576	2727	2	2004-10-28
3	9576	3844	3	2004-10-28
4	9576	8812	1	2004-10-28
5	9576	4264	2	2004-10-28
6	9576	7956	3	2004-10-28
1	9577	3736	2	2004-10-01
2	9577	374	1	2004-10-01
3	9577	6094	2	2004-10-01
1	9578	3931	3	2004-10-01
2	9578	934	2	2004-10-01
3	9578	3195	3	2004-10-01
4	9578	3660	2	2004-10-01
5	9578	3029	3	2004-10-01
1	9579	5701	3	2004-10-13
2	9579	8363	2	2004-10-13
3	9579	473	1	2004-10-13
4	9579	8297	2	2004-10-13
5	9579	6192	3	2004-10-13
6	9579	4988	1	2004-10-13
7	9579	3124	2	2004-10-13
8	9579	860	1	2004-10-13
1	9580	9792	1	2004-10-02
2	9580	8951	2	2004-10-02
1	9581	3819	1	2004-10-26
2	9581	801	3	2004-10-26
3	9581	150	3	2004-10-26
1	9582	4832	3	2004-10-17
2	9582	2307	3	2004-10-17
3	9582	397	2	2004-10-17
4	9582	4883	1	2004-10-17
1	9583	6869	2	2004-10-22
2	9583	8416	2	2004-10-22
3	9583	9288	2	2004-10-22
4	9583	7799	1	2004-10-22
5	9583	8975	1	2004-10-22
6	9583	1815	3	2004-10-22
1	9584	2588	1	2004-10-04
2	9584	114	3	2004-10-04
3	9584	8971	1	2004-10-04
4	9584	7237	3	2004-10-04
5	9584	7850	1	2004-10-04
6	9584	624	2	2004-10-04
1	9585	2507	3	2004-10-24
2	9585	215	1	2004-10-24
3	9585	6081	3	2004-10-24
4	9585	2035	2	2004-10-24
1	9586	5813	2	2004-10-30
1	9587	5818	2	2004-10-23
2	9587	9777	1	2004-10-23
3	9587	2967	3	2004-10-23
4	9587	5174	2	2004-10-23
5	9587	2539	1	2004-10-23
6	9587	259	2	2004-10-23
7	9587	7096	1	2004-10-23
1	9588	5323	2	2004-10-10
2	9588	4201	2	2004-10-10
3	9588	443	3	2004-10-10
4	9588	5717	2	2004-10-10
5	9588	2802	1	2004-10-10
6	9588	4656	3	2004-10-10
7	9588	316	1	2004-10-10
8	9588	1030	1	2004-10-10
9	9588	3528	2	2004-10-10
1	9589	1402	3	2004-10-24
1	9590	5807	2	2004-10-12
2	9590	6059	1	2004-10-12
3	9590	1764	1	2004-10-12
4	9590	6081	1	2004-10-12
5	9590	9291	1	2004-10-12
6	9590	8461	1	2004-10-12
7	9590	4757	1	2004-10-12
1	9591	5163	3	2004-10-30
1	9592	3135	3	2004-10-15
2	9592	9980	3	2004-10-15
1	9593	5761	3	2004-10-18
2	9593	2652	3	2004-10-18
1	9594	529	3	2004-10-01
2	9594	1595	2	2004-10-01
3	9594	1306	1	2004-10-01
4	9594	357	2	2004-10-01
5	9594	1668	2	2004-10-01
6	9594	2012	2	2004-10-01
7	9594	8400	3	2004-10-01
8	9594	8350	1	2004-10-01
9	9594	5049	3	2004-10-01
1	9595	2287	2	2004-10-27
2	9595	2367	2	2004-10-27
3	9595	2204	1	2004-10-27
1	9596	123	2	2004-10-12
2	9596	9485	1	2004-10-12
3	9596	4795	3	2004-10-12
4	9596	6323	2	2004-10-12
1	9597	6163	1	2004-10-17
2	9597	5294	1	2004-10-17
3	9597	9357	2	2004-10-17
4	9597	1976	3	2004-10-17
1	9598	9201	2	2004-10-20
2	9598	1170	1	2004-10-20
3	9598	7094	1	2004-10-20
4	9598	7070	3	2004-10-20
5	9598	6931	2	2004-10-20
6	9598	8645	1	2004-10-20
7	9598	6395	2	2004-10-20
8	9598	8187	1	2004-10-20
1	9599	1892	1	2004-10-11
2	9599	675	1	2004-10-11
3	9599	4619	1	2004-10-11
4	9599	9525	1	2004-10-11
5	9599	6913	1	2004-10-11
6	9599	9432	2	2004-10-11
7	9599	7643	1	2004-10-11
8	9599	8984	2	2004-10-11
9	9599	3855	2	2004-10-11
1	9600	2510	3	2004-10-07
1	9601	1561	2	2004-10-18
2	9601	8329	2	2004-10-18
3	9601	7078	3	2004-10-18
4	9601	4700	1	2004-10-18
5	9601	1653	2	2004-10-18
6	9601	2538	3	2004-10-18
7	9601	6707	1	2004-10-18
8	9601	4678	2	2004-10-18
1	9602	9714	1	2004-10-08
2	9602	7210	1	2004-10-08
3	9602	1637	3	2004-10-08
4	9602	1320	3	2004-10-08
5	9602	416	1	2004-10-08
6	9602	6065	1	2004-10-08
1	9603	3396	1	2004-10-26
2	9603	7117	2	2004-10-26
3	9603	4352	3	2004-10-26
4	9603	3615	1	2004-10-26
5	9603	1624	3	2004-10-26
1	9604	620	1	2004-10-17
2	9604	5532	3	2004-10-17
3	9604	3987	3	2004-10-17
4	9604	7549	2	2004-10-17
5	9604	4369	3	2004-10-17
1	9605	4827	2	2004-10-23
2	9605	1146	3	2004-10-23
3	9605	5496	3	2004-10-23
4	9605	3271	3	2004-10-23
5	9605	7917	3	2004-10-23
6	9605	907	3	2004-10-23
1	9606	807	2	2004-10-17
2	9606	8797	2	2004-10-17
3	9606	2183	1	2004-10-17
4	9606	3507	3	2004-10-17
5	9606	8089	3	2004-10-17
6	9606	7695	2	2004-10-17
7	9606	8308	3	2004-10-17
1	9607	1356	3	2004-10-04
2	9607	602	2	2004-10-04
3	9607	8347	3	2004-10-04
1	9608	5567	1	2004-10-05
2	9608	3818	2	2004-10-05
3	9608	6146	1	2004-10-05
4	9608	2712	3	2004-10-05
5	9608	5398	2	2004-10-05
6	9608	8059	2	2004-10-05
7	9608	4093	2	2004-10-05
1	9609	5534	2	2004-10-28
1	9610	1515	1	2004-10-08
2	9610	1607	1	2004-10-08
3	9610	2490	3	2004-10-08
1	9611	4428	3	2004-10-31
2	9611	6147	3	2004-10-31
3	9611	5930	1	2004-10-31
4	9611	3357	2	2004-10-31
1	9612	9849	1	2004-10-16
2	9612	4133	2	2004-10-16
3	9612	9520	2	2004-10-16
4	9612	2271	2	2004-10-16
1	9613	6812	1	2004-10-31
2	9613	980	2	2004-10-31
1	9614	38	2	2004-10-26
2	9614	9757	2	2004-10-26
3	9614	7747	1	2004-10-26
1	9615	6761	1	2004-10-31
2	9615	2826	1	2004-10-31
3	9615	5793	1	2004-10-31
4	9615	7514	3	2004-10-31
5	9615	6755	3	2004-10-31
6	9615	1849	2	2004-10-31
7	9615	8538	3	2004-10-31
8	9615	4535	3	2004-10-31
9	9615	5186	1	2004-10-31
1	9616	1447	2	2004-10-07
2	9616	7957	3	2004-10-07
1	9617	7608	3	2004-10-26
2	9617	9187	1	2004-10-26
3	9617	9623	2	2004-10-26
4	9617	2779	3	2004-10-26
5	9617	3043	3	2004-10-26
6	9617	4359	2	2004-10-26
7	9617	3933	1	2004-10-26
8	9617	3551	3	2004-10-26
1	9618	3979	2	2004-10-08
2	9618	6355	2	2004-10-08
3	9618	1631	2	2004-10-08
4	9618	4619	3	2004-10-08
1	9619	5317	3	2004-10-07
2	9619	264	2	2004-10-07
3	9619	2783	1	2004-10-07
4	9619	2076	2	2004-10-07
5	9619	2575	2	2004-10-07
6	9619	716	2	2004-10-07
7	9619	9331	2	2004-10-07
8	9619	4973	1	2004-10-07
9	9619	3003	2	2004-10-07
1	9620	2407	2	2004-10-19
2	9620	6775	3	2004-10-19
3	9620	4170	3	2004-10-19
1	9621	592	3	2004-10-12
2	9621	3869	2	2004-10-12
3	9621	2133	2	2004-10-12
4	9621	9200	2	2004-10-12
5	9621	2378	3	2004-10-12
6	9621	1214	1	2004-10-12
7	9621	4182	2	2004-10-12
8	9621	3452	3	2004-10-12
9	9621	2350	3	2004-10-12
1	9622	9372	3	2004-10-13
2	9622	3599	2	2004-10-13
3	9622	7796	3	2004-10-13
4	9622	6329	2	2004-10-13
5	9622	6140	3	2004-10-13
6	9622	5714	1	2004-10-13
1	9623	2553	3	2004-10-01
2	9623	9408	2	2004-10-01
3	9623	39	2	2004-10-01
4	9623	9953	2	2004-10-01
5	9623	775	1	2004-10-01
6	9623	3052	2	2004-10-01
7	9623	7348	2	2004-10-01
8	9623	1515	3	2004-10-01
9	9623	3875	2	2004-10-01
1	9624	8294	3	2004-10-01
2	9624	3508	2	2004-10-01
3	9624	8472	2	2004-10-01
4	9624	1853	2	2004-10-01
5	9624	3294	2	2004-10-01
6	9624	2755	1	2004-10-01
1	9625	6284	3	2004-10-26
2	9625	427	3	2004-10-26
3	9625	2007	3	2004-10-26
4	9625	4411	2	2004-10-26
5	9625	4494	3	2004-10-26
6	9625	8634	2	2004-10-26
7	9625	9957	1	2004-10-26
8	9625	1343	3	2004-10-26
1	9626	8652	2	2004-10-30
2	9626	2317	1	2004-10-30
3	9626	8513	2	2004-10-30
4	9626	4648	3	2004-10-30
5	9626	7864	1	2004-10-30
6	9626	4809	2	2004-10-30
7	9626	8005	2	2004-10-30
8	9626	3483	1	2004-10-30
1	9627	6180	1	2004-10-10
2	9627	2258	2	2004-10-10
3	9627	3124	2	2004-10-10
4	9627	4385	1	2004-10-10
5	9627	8451	2	2004-10-10
6	9627	438	3	2004-10-10
7	9627	749	1	2004-10-10
1	9628	5946	2	2004-10-29
2	9628	4634	1	2004-10-29
3	9628	9836	1	2004-10-29
4	9628	5990	1	2004-10-29
1	9629	6504	3	2004-10-09
2	9629	8349	3	2004-10-09
3	9629	3527	1	2004-10-09
4	9629	2361	3	2004-10-09
5	9629	4017	1	2004-10-09
6	9629	4552	2	2004-10-09
1	9630	4561	2	2004-10-25
2	9630	656	1	2004-10-25
3	9630	721	2	2004-10-25
4	9630	1261	1	2004-10-25
5	9630	7926	3	2004-10-25
6	9630	3875	1	2004-10-25
7	9630	6249	2	2004-10-25
1	9631	1513	2	2004-10-21
2	9631	6577	2	2004-10-21
3	9631	3914	1	2004-10-21
4	9631	4686	3	2004-10-21
5	9631	5048	1	2004-10-21
1	9632	7287	1	2004-10-12
2	9632	8831	3	2004-10-12
3	9632	5503	1	2004-10-12
4	9632	8563	2	2004-10-12
5	9632	7341	1	2004-10-12
6	9632	4003	2	2004-10-12
7	9632	7523	1	2004-10-12
8	9632	6342	3	2004-10-12
1	9633	1729	3	2004-10-19
2	9633	3035	2	2004-10-19
3	9633	8382	3	2004-10-19
1	9634	471	3	2004-10-28
2	9634	8785	3	2004-10-28
3	9634	5630	2	2004-10-28
4	9634	9393	2	2004-10-28
5	9634	7715	3	2004-10-28
6	9634	6629	1	2004-10-28
7	9634	323	2	2004-10-28
8	9634	2477	2	2004-10-28
1	9635	782	2	2004-10-13
1	9636	1897	1	2004-10-01
2	9636	597	1	2004-10-01
3	9636	242	1	2004-10-01
4	9636	9855	3	2004-10-01
5	9636	368	2	2004-10-01
6	9636	3314	3	2004-10-01
7	9636	9677	1	2004-10-01
8	9636	6493	2	2004-10-01
1	9637	3479	2	2004-10-09
2	9637	3562	3	2004-10-09
3	9637	4762	2	2004-10-09
4	9637	4243	2	2004-10-09
5	9637	8159	3	2004-10-09
1	9638	2288	3	2004-10-11
2	9638	4945	1	2004-10-11
3	9638	7842	2	2004-10-11
4	9638	7627	1	2004-10-11
1	9639	3608	2	2004-10-16
2	9639	8380	2	2004-10-16
1	9640	9854	2	2004-10-01
2	9640	8054	2	2004-10-01
3	9640	8266	2	2004-10-01
4	9640	997	1	2004-10-01
1	9641	8385	1	2004-10-20
2	9641	696	2	2004-10-20
3	9641	5684	3	2004-10-20
4	9641	7380	1	2004-10-20
5	9641	5624	3	2004-10-20
6	9641	2320	3	2004-10-20
7	9641	4489	1	2004-10-20
8	9641	3296	2	2004-10-20
1	9642	5402	2	2004-10-08
2	9642	6505	2	2004-10-08
3	9642	2613	3	2004-10-08
1	9643	7432	2	2004-10-17
1	9644	6449	3	2004-10-04
2	9644	7451	1	2004-10-04
3	9644	8623	3	2004-10-04
4	9644	1304	1	2004-10-04
5	9644	470	2	2004-10-04
6	9644	7748	1	2004-10-04
7	9644	6567	2	2004-10-04
1	9645	5637	2	2004-10-17
2	9645	9442	1	2004-10-17
1	9646	1968	1	2004-10-13
2	9646	9547	2	2004-10-13
1	9647	8068	1	2004-10-29
2	9647	6421	3	2004-10-29
3	9647	4442	3	2004-10-29
4	9647	3971	1	2004-10-29
5	9647	9917	1	2004-10-29
6	9647	8285	2	2004-10-29
1	9648	5890	3	2004-10-08
2	9648	8993	3	2004-10-08
3	9648	3246	1	2004-10-08
4	9648	1297	2	2004-10-08
5	9648	2990	1	2004-10-08
6	9648	8863	1	2004-10-08
7	9648	6838	1	2004-10-08
8	9648	8841	2	2004-10-08
1	9649	2152	3	2004-10-09
2	9649	9534	1	2004-10-09
3	9649	8785	3	2004-10-09
4	9649	7420	1	2004-10-09
5	9649	8600	2	2004-10-09
6	9649	9431	2	2004-10-09
7	9649	1445	3	2004-10-09
1	9650	9904	1	2004-10-14
2	9650	6505	3	2004-10-14
3	9650	4089	2	2004-10-14
4	9650	338	1	2004-10-14
5	9650	8249	1	2004-10-14
6	9650	8190	1	2004-10-14
1	9651	2410	3	2004-10-02
1	9652	4541	1	2004-10-25
2	9652	1024	2	2004-10-25
3	9652	8701	2	2004-10-25
4	9652	676	3	2004-10-25
5	9652	1052	1	2004-10-25
6	9652	9508	3	2004-10-25
1	9653	6525	3	2004-10-29
2	9653	2924	2	2004-10-29
3	9653	1672	2	2004-10-29
4	9653	5056	1	2004-10-29
5	9653	3626	3	2004-10-29
6	9653	2001	1	2004-10-29
7	9653	7293	1	2004-10-29
8	9653	8097	1	2004-10-29
9	9653	3124	3	2004-10-29
1	9654	9433	2	2004-10-25
2	9654	9073	3	2004-10-25
3	9654	3117	3	2004-10-25
4	9654	2536	2	2004-10-25
5	9654	8102	3	2004-10-25
6	9654	3161	1	2004-10-25
7	9654	3774	2	2004-10-25
8	9654	4533	3	2004-10-25
1	9655	9719	2	2004-10-23
2	9655	2124	3	2004-10-23
3	9655	5420	2	2004-10-23
4	9655	6936	1	2004-10-23
5	9655	7070	1	2004-10-23
6	9655	1731	2	2004-10-23
7	9655	7007	1	2004-10-23
8	9655	5443	1	2004-10-23
9	9655	9222	3	2004-10-23
1	9656	8348	1	2004-10-13
2	9656	2131	1	2004-10-13
3	9656	9641	3	2004-10-13
4	9656	1038	2	2004-10-13
5	9656	8684	1	2004-10-13
6	9656	9520	1	2004-10-13
7	9656	8573	2	2004-10-13
1	9657	6954	3	2004-10-19
2	9657	9625	2	2004-10-19
3	9657	711	2	2004-10-19
1	9658	7256	1	2004-10-13
2	9658	5519	2	2004-10-13
3	9658	895	3	2004-10-13
4	9658	8484	1	2004-10-13
5	9658	7056	3	2004-10-13
6	9658	6469	2	2004-10-13
7	9658	278	2	2004-10-13
8	9658	6546	3	2004-10-13
1	9659	5721	1	2004-10-03
2	9659	9012	2	2004-10-03
3	9659	5271	3	2004-10-03
4	9659	413	3	2004-10-03
5	9659	9655	2	2004-10-03
6	9659	7575	3	2004-10-03
7	9659	3540	1	2004-10-03
8	9659	2514	2	2004-10-03
9	9659	743	1	2004-10-03
1	9660	3538	1	2004-10-16
2	9660	7426	1	2004-10-16
1	9661	7457	3	2004-10-30
2	9661	5314	2	2004-10-30
3	9661	3746	1	2004-10-30
4	9661	6191	2	2004-10-30
1	9662	2755	1	2004-10-31
2	9662	607	2	2004-10-31
3	9662	5588	1	2004-10-31
4	9662	6266	1	2004-10-31
5	9662	9149	3	2004-10-31
6	9662	1993	1	2004-10-31
7	9662	7578	3	2004-10-31
1	9663	1226	2	2004-10-09
2	9663	3851	2	2004-10-09
3	9663	1696	3	2004-10-09
4	9663	7123	3	2004-10-09
5	9663	1755	3	2004-10-09
1	9664	524	2	2004-10-12
2	9664	1754	2	2004-10-12
3	9664	6531	3	2004-10-12
4	9664	6667	2	2004-10-12
5	9664	4802	3	2004-10-12
6	9664	8365	1	2004-10-12
1	9665	6584	1	2004-10-26
2	9665	1073	1	2004-10-26
3	9665	7366	1	2004-10-26
4	9665	8032	2	2004-10-26
5	9665	653	3	2004-10-26
6	9665	1550	2	2004-10-26
1	9666	1305	1	2004-10-29
2	9666	5790	3	2004-10-29
3	9666	642	1	2004-10-29
4	9666	3513	2	2004-10-29
5	9666	1115	1	2004-10-29
6	9666	7823	3	2004-10-29
7	9666	3013	3	2004-10-29
8	9666	5037	3	2004-10-29
9	9666	8253	2	2004-10-29
1	9667	108	3	2004-10-01
2	9667	7848	1	2004-10-01
3	9667	3913	3	2004-10-01
4	9667	7781	2	2004-10-01
5	9667	6681	3	2004-10-01
6	9667	7405	1	2004-10-01
7	9667	6920	3	2004-10-01
8	9667	4927	1	2004-10-01
1	9668	5233	2	2004-10-11
2	9668	8738	1	2004-10-11
1	9669	2609	2	2004-10-16
2	9669	3011	1	2004-10-16
3	9669	4784	1	2004-10-16
4	9669	4374	3	2004-10-16
5	9669	7860	1	2004-10-16
1	9670	7012	3	2004-10-11
1	9671	7980	1	2004-10-28
2	9671	3729	1	2004-10-28
3	9671	6222	1	2004-10-28
1	9672	6089	1	2004-10-11
2	9672	5112	3	2004-10-11
3	9672	4781	3	2004-10-11
4	9672	9956	3	2004-10-11
5	9672	8591	3	2004-10-11
6	9672	1308	1	2004-10-11
7	9672	2357	1	2004-10-11
8	9672	2951	3	2004-10-11
9	9672	704	1	2004-10-11
1	9673	194	3	2004-10-05
2	9673	2498	2	2004-10-05
3	9673	490	2	2004-10-05
4	9673	7555	3	2004-10-05
5	9673	5837	2	2004-10-05
6	9673	2010	1	2004-10-05
7	9673	2742	3	2004-10-05
8	9673	844	1	2004-10-05
9	9673	5944	3	2004-10-05
1	9674	9797	2	2004-10-02
2	9674	2238	1	2004-10-02
3	9674	6331	2	2004-10-02
1	9675	8649	2	2004-10-31
2	9675	6402	3	2004-10-31
3	9675	1305	2	2004-10-31
4	9675	9083	3	2004-10-31
5	9675	7599	1	2004-10-31
6	9675	8089	1	2004-10-31
7	9675	7883	3	2004-10-31
8	9675	3038	2	2004-10-31
9	9675	8367	2	2004-10-31
1	9676	4321	3	2004-10-04
1	9677	1276	2	2004-10-05
2	9677	1155	3	2004-10-05
1	9678	1513	3	2004-10-02
2	9678	8801	3	2004-10-02
1	9679	5822	1	2004-10-29
2	9679	944	2	2004-10-29
3	9679	6038	1	2004-10-29
4	9679	4057	1	2004-10-29
5	9679	2895	3	2004-10-29
6	9679	1114	2	2004-10-29
7	9679	9028	1	2004-10-29
1	9680	227	3	2004-10-17
2	9680	4147	3	2004-10-17
3	9680	358	2	2004-10-17
4	9680	7430	3	2004-10-17
5	9680	4769	2	2004-10-17
6	9680	6048	2	2004-10-17
1	9681	6057	1	2004-10-12
2	9681	6747	1	2004-10-12
3	9681	5203	3	2004-10-12
4	9681	8490	2	2004-10-12
5	9681	3909	3	2004-10-12
1	9682	5935	3	2004-10-30
2	9682	6669	1	2004-10-30
3	9682	7333	3	2004-10-30
4	9682	5739	2	2004-10-30
5	9682	6184	1	2004-10-30
6	9682	1428	1	2004-10-30
7	9682	4727	2	2004-10-30
8	9682	4100	1	2004-10-30
1	9683	269	3	2004-10-31
2	9683	6323	3	2004-10-31
3	9683	5697	1	2004-10-31
4	9683	6276	2	2004-10-31
5	9683	9576	2	2004-10-31
6	9683	3297	2	2004-10-31
7	9683	2141	3	2004-10-31
1	9684	4237	1	2004-10-18
2	9684	1836	2	2004-10-18
1	9685	7997	1	2004-10-17
2	9685	9660	1	2004-10-17
3	9685	7494	3	2004-10-17
4	9685	1558	2	2004-10-17
5	9685	8687	3	2004-10-17
6	9685	4048	2	2004-10-17
7	9685	2581	2	2004-10-17
8	9685	9058	2	2004-10-17
9	9685	9133	1	2004-10-17
1	9686	6052	2	2004-10-19
2	9686	6005	3	2004-10-19
3	9686	573	1	2004-10-19
1	9687	2257	1	2004-10-14
2	9687	4623	3	2004-10-14
3	9687	500	2	2004-10-14
1	9688	4149	2	2004-10-12
2	9688	1236	1	2004-10-12
3	9688	1893	1	2004-10-12
4	9688	4405	3	2004-10-12
5	9688	5092	2	2004-10-12
6	9688	566	1	2004-10-12
7	9688	9985	2	2004-10-12
1	9689	2003	3	2004-10-28
2	9689	5925	2	2004-10-28
3	9689	9462	1	2004-10-28
4	9689	4009	3	2004-10-28
1	9690	5188	1	2004-10-21
1	9691	6793	1	2004-10-20
2	9691	5805	1	2004-10-20
3	9691	5985	2	2004-10-20
4	9691	3027	2	2004-10-20
5	9691	2941	1	2004-10-20
6	9691	6526	1	2004-10-20
7	9691	5534	3	2004-10-20
8	9691	9810	1	2004-10-20
1	9692	9234	3	2004-10-09
2	9692	4371	3	2004-10-09
3	9692	8893	3	2004-10-09
4	9692	1679	2	2004-10-09
5	9692	5983	3	2004-10-09
6	9692	3141	1	2004-10-09
7	9692	9091	3	2004-10-09
1	9693	1044	3	2004-10-15
2	9693	9740	3	2004-10-15
3	9693	9175	2	2004-10-15
4	9693	6097	3	2004-10-15
5	9693	6732	3	2004-10-15
6	9693	8257	3	2004-10-15
7	9693	5681	3	2004-10-15
1	9694	9610	3	2004-10-24
2	9694	1431	2	2004-10-24
3	9694	5733	2	2004-10-24
4	9694	8367	2	2004-10-24
5	9694	3516	1	2004-10-24
6	9694	9898	3	2004-10-24
1	9695	8509	2	2004-10-03
1	9696	3489	2	2004-10-18
2	9696	1191	3	2004-10-18
3	9696	990	3	2004-10-18
1	9697	4412	2	2004-10-29
2	9697	4421	1	2004-10-29
3	9697	1020	1	2004-10-29
4	9697	4968	2	2004-10-29
5	9697	5812	2	2004-10-29
6	9697	3366	2	2004-10-29
7	9697	5805	1	2004-10-29
8	9697	6970	2	2004-10-29
1	9698	5147	1	2004-10-21
2	9698	5454	2	2004-10-21
1	9699	3305	1	2004-10-05
1	9700	7861	3	2004-10-30
2	9700	6831	1	2004-10-30
3	9700	2017	1	2004-10-30
4	9700	7692	2	2004-10-30
1	9701	7809	1	2004-10-29
2	9701	8825	3	2004-10-29
3	9701	4497	2	2004-10-29
4	9701	9132	3	2004-10-29
5	9701	308	1	2004-10-29
6	9701	6394	2	2004-10-29
1	9702	7414	1	2004-10-05
2	9702	5167	2	2004-10-05
1	9703	4640	2	2004-10-29
2	9703	6659	2	2004-10-29
1	9704	5034	3	2004-10-29
2	9704	3824	3	2004-10-29
3	9704	2731	1	2004-10-29
4	9704	9480	1	2004-10-29
5	9704	3662	2	2004-10-29
6	9704	8341	2	2004-10-29
7	9704	5571	2	2004-10-29
1	9705	8258	2	2004-10-20
2	9705	3448	2	2004-10-20
1	9706	1891	1	2004-10-19
2	9706	5117	1	2004-10-19
3	9706	8538	1	2004-10-19
1	9707	5317	3	2004-10-02
2	9707	6356	3	2004-10-02
3	9707	5033	2	2004-10-02
1	9708	3587	2	2004-10-13
1	9709	8202	2	2004-10-06
2	9709	3410	1	2004-10-06
3	9709	7070	2	2004-10-06
4	9709	1793	1	2004-10-06
5	9709	7127	1	2004-10-06
1	9710	1032	3	2004-10-08
2	9710	1177	3	2004-10-08
1	9711	6812	1	2004-10-22
2	9711	1548	1	2004-10-22
1	9712	8743	1	2004-10-14
2	9712	7137	1	2004-10-14
3	9712	797	2	2004-10-14
1	9713	2919	3	2004-10-24
2	9713	2293	2	2004-10-24
3	9713	745	1	2004-10-24
4	9713	3615	1	2004-10-24
5	9713	712	1	2004-10-24
1	9714	3229	1	2004-10-26
2	9714	5341	3	2004-10-26
3	9714	6691	3	2004-10-26
4	9714	141	2	2004-10-26
5	9714	8026	3	2004-10-26
1	9715	1411	3	2004-10-24
2	9715	9615	2	2004-10-24
3	9715	6603	1	2004-10-24
4	9715	9938	3	2004-10-24
5	9715	5231	2	2004-10-24
1	9716	8737	2	2004-10-29
2	9716	2341	1	2004-10-29
3	9716	9143	3	2004-10-29
4	9716	9412	2	2004-10-29
5	9716	5263	3	2004-10-29
6	9716	1267	1	2004-10-29
7	9716	6829	3	2004-10-29
1	9717	6186	2	2004-10-07
2	9717	7850	1	2004-10-07
3	9717	5409	3	2004-10-07
4	9717	136	1	2004-10-07
1	9718	6803	2	2004-10-05
2	9718	1364	3	2004-10-05
3	9718	7283	1	2004-10-05
4	9718	6823	3	2004-10-05
5	9718	6340	1	2004-10-05
1	9719	6457	3	2004-10-20
2	9719	1386	1	2004-10-20
3	9719	1006	3	2004-10-20
1	9720	6642	1	2004-10-12
2	9720	9894	3	2004-10-12
3	9720	9899	2	2004-10-12
4	9720	3471	3	2004-10-12
5	9720	1793	2	2004-10-12
6	9720	5844	3	2004-10-12
7	9720	5340	1	2004-10-12
8	9720	5769	1	2004-10-12
9	9720	4752	1	2004-10-12
1	9721	7611	2	2004-10-29
2	9721	6086	3	2004-10-29
3	9721	4047	3	2004-10-29
4	9721	7470	2	2004-10-29
5	9721	9185	2	2004-10-29
6	9721	4902	3	2004-10-29
1	9722	1501	3	2004-10-07
2	9722	397	3	2004-10-07
3	9722	6419	2	2004-10-07
4	9722	11	1	2004-10-07
5	9722	7416	2	2004-10-07
6	9722	4202	3	2004-10-07
1	9723	5766	3	2004-10-16
2	9723	1114	3	2004-10-16
3	9723	8458	3	2004-10-16
1	9724	6719	2	2004-10-14
2	9724	3920	1	2004-10-14
3	9724	350	2	2004-10-14
4	9724	9615	1	2004-10-14
5	9724	2764	2	2004-10-14
6	9724	6482	1	2004-10-14
7	9724	8220	2	2004-10-14
8	9724	7536	1	2004-10-14
9	9724	597	1	2004-10-14
1	9725	1566	2	2004-10-06
2	9725	7289	1	2004-10-06
3	9725	4618	1	2004-10-06
4	9725	7665	3	2004-10-06
5	9725	626	2	2004-10-06
6	9725	2099	2	2004-10-06
7	9725	6654	1	2004-10-06
1	9726	2301	3	2004-10-31
2	9726	5503	1	2004-10-31
3	9726	3571	1	2004-10-31
1	9727	7206	1	2004-10-10
2	9727	2129	3	2004-10-10
3	9727	6419	3	2004-10-10
4	9727	8795	1	2004-10-10
5	9727	924	2	2004-10-10
1	9728	6095	3	2004-10-26
1	9729	8788	2	2004-10-09
2	9729	5763	2	2004-10-09
3	9729	6585	3	2004-10-09
4	9729	7330	3	2004-10-09
5	9729	3500	1	2004-10-09
6	9729	4178	1	2004-10-09
1	9730	5723	3	2004-10-10
2	9730	630	2	2004-10-10
3	9730	4729	3	2004-10-10
4	9730	8196	2	2004-10-10
5	9730	9425	2	2004-10-10
6	9730	3067	1	2004-10-10
7	9730	349	3	2004-10-10
8	9730	8407	3	2004-10-10
9	9730	2895	2	2004-10-10
1	9731	9005	3	2004-10-11
1	9732	9488	3	2004-10-11
2	9732	6317	2	2004-10-11
3	9732	5454	3	2004-10-11
4	9732	1857	1	2004-10-11
5	9732	5924	1	2004-10-11
6	9732	5754	2	2004-10-11
7	9732	4343	3	2004-10-11
1	9733	3828	3	2004-10-24
2	9733	243	3	2004-10-24
3	9733	8025	2	2004-10-24
4	9733	8011	3	2004-10-24
5	9733	747	1	2004-10-24
6	9733	210	3	2004-10-24
1	9734	4907	1	2004-10-26
2	9734	1543	3	2004-10-26
3	9734	1274	3	2004-10-26
4	9734	6816	3	2004-10-26
5	9734	2813	1	2004-10-26
1	9735	6553	3	2004-10-19
2	9735	43	3	2004-10-19
1	9736	5096	1	2004-10-22
2	9736	6500	2	2004-10-22
3	9736	9741	2	2004-10-22
4	9736	5003	2	2004-10-22
5	9736	9377	3	2004-10-22
1	9737	8384	2	2004-10-21
2	9737	4769	1	2004-10-21
3	9737	4647	1	2004-10-21
4	9737	1676	1	2004-10-21
5	9737	2113	3	2004-10-21
6	9737	173	1	2004-10-21
7	9737	5024	3	2004-10-21
1	9738	6850	3	2004-10-01
2	9738	623	2	2004-10-01
3	9738	3326	2	2004-10-01
4	9738	1968	1	2004-10-01
5	9738	5534	3	2004-10-01
1	9739	5695	1	2004-10-12
2	9739	3201	1	2004-10-12
1	9740	3105	1	2004-10-05
2	9740	5829	3	2004-10-05
3	9740	8114	2	2004-10-05
4	9740	3692	1	2004-10-05
1	9741	7132	1	2004-10-05
2	9741	7617	3	2004-10-05
1	9742	5357	2	2004-10-15
2	9742	359	1	2004-10-15
3	9742	4658	2	2004-10-15
4	9742	1392	2	2004-10-15
5	9742	8436	1	2004-10-15
6	9742	9893	1	2004-10-15
7	9742	3237	2	2004-10-15
8	9742	9668	1	2004-10-15
1	9743	3901	1	2004-10-06
2	9743	5132	1	2004-10-06
3	9743	2247	1	2004-10-06
1	9744	5333	1	2004-10-01
2	9744	1377	2	2004-10-01
3	9744	2305	2	2004-10-01
4	9744	9250	2	2004-10-01
5	9744	2254	3	2004-10-01
6	9744	5924	1	2004-10-01
7	9744	9225	3	2004-10-01
1	9745	2253	1	2004-10-25
2	9745	2779	2	2004-10-25
3	9745	2235	3	2004-10-25
4	9745	7186	2	2004-10-25
5	9745	659	3	2004-10-25
6	9745	1460	2	2004-10-25
7	9745	4982	3	2004-10-25
8	9745	7811	2	2004-10-25
9	9745	2484	1	2004-10-25
1	9746	9419	3	2004-10-08
2	9746	6791	3	2004-10-08
3	9746	8894	2	2004-10-08
4	9746	7537	3	2004-10-08
5	9746	4296	3	2004-10-08
1	9747	4985	1	2004-10-05
2	9747	8140	2	2004-10-05
3	9747	444	3	2004-10-05
4	9747	2200	2	2004-10-05
1	9748	124	2	2004-10-20
2	9748	610	2	2004-10-20
3	9748	8820	1	2004-10-20
4	9748	3668	2	2004-10-20
5	9748	8673	1	2004-10-20
6	9748	268	2	2004-10-20
7	9748	1966	2	2004-10-20
8	9748	5998	2	2004-10-20
1	9749	5067	2	2004-10-06
2	9749	2266	2	2004-10-06
3	9749	4786	2	2004-10-06
4	9749	935	1	2004-10-06
5	9749	4474	1	2004-10-06
6	9749	54	2	2004-10-06
1	9750	692	1	2004-10-22
2	9750	1322	3	2004-10-22
3	9750	4762	1	2004-10-22
4	9750	5573	3	2004-10-22
5	9750	6153	1	2004-10-22
6	9750	116	3	2004-10-22
1	9751	2350	3	2004-10-11
2	9751	4087	3	2004-10-11
3	9751	1143	2	2004-10-11
4	9751	8313	2	2004-10-11
5	9751	7738	3	2004-10-11
6	9751	214	2	2004-10-11
7	9751	9029	3	2004-10-11
8	9751	339	3	2004-10-11
1	9752	3249	2	2004-10-03
2	9752	2433	3	2004-10-03
3	9752	6226	1	2004-10-03
4	9752	7191	3	2004-10-03
5	9752	9711	1	2004-10-03
6	9752	8311	1	2004-10-03
1	9753	7419	3	2004-10-26
2	9753	5039	2	2004-10-26
3	9753	5874	2	2004-10-26
4	9753	9784	2	2004-10-26
5	9753	3998	1	2004-10-26
6	9753	4622	2	2004-10-26
7	9753	1782	2	2004-10-26
8	9753	648	2	2004-10-26
9	9753	8361	1	2004-10-26
1	9754	4321	2	2004-10-14
2	9754	3224	1	2004-10-14
1	9755	928	1	2004-10-23
2	9755	4102	2	2004-10-23
3	9755	7602	3	2004-10-23
4	9755	1219	3	2004-10-23
5	9755	4877	2	2004-10-23
6	9755	7507	3	2004-10-23
1	9756	4319	1	2004-10-01
1	9757	371	1	2004-10-13
2	9757	4851	2	2004-10-13
3	9757	3102	1	2004-10-13
4	9757	5099	3	2004-10-13
5	9757	8843	2	2004-10-13
6	9757	578	1	2004-10-13
7	9757	1992	3	2004-10-13
8	9757	2918	1	2004-10-13
9	9757	5565	3	2004-10-13
1	9758	2360	1	2004-10-27
2	9758	9389	3	2004-10-27
3	9758	2060	1	2004-10-27
4	9758	5428	3	2004-10-27
5	9758	2786	2	2004-10-27
6	9758	8680	3	2004-10-27
7	9758	9393	1	2004-10-27
8	9758	9886	2	2004-10-27
1	9759	1672	1	2004-10-31
1	9760	2383	2	2004-10-27
2	9760	7303	3	2004-10-27
3	9760	2728	3	2004-10-27
4	9760	171	1	2004-10-27
1	9761	439	3	2004-10-20
2	9761	7567	3	2004-10-20
1	9762	1451	1	2004-10-19
2	9762	4425	1	2004-10-19
3	9762	1299	2	2004-10-19
4	9762	4476	3	2004-10-19
5	9762	685	1	2004-10-19
6	9762	4198	1	2004-10-19
1	9763	1163	1	2004-10-14
2	9763	9183	3	2004-10-14
3	9763	5143	2	2004-10-14
4	9763	9271	2	2004-10-14
5	9763	2750	3	2004-10-14
6	9763	4698	3	2004-10-14
7	9763	3797	2	2004-10-14
1	9764	7214	3	2004-10-14
2	9764	4780	1	2004-10-14
3	9764	7671	2	2004-10-14
4	9764	1884	1	2004-10-14
5	9764	8532	2	2004-10-14
6	9764	3368	1	2004-10-14
7	9764	3289	2	2004-10-14
8	9764	4187	1	2004-10-14
1	9765	4910	3	2004-10-07
2	9765	8141	3	2004-10-07
1	9766	7183	1	2004-10-26
2	9766	1297	2	2004-10-26
3	9766	9315	2	2004-10-26
1	9767	8853	1	2004-10-19
2	9767	4191	1	2004-10-19
3	9767	1347	3	2004-10-19
4	9767	6751	2	2004-10-19
5	9767	9951	3	2004-10-19
6	9767	4862	3	2004-10-19
7	9767	87	3	2004-10-19
8	9767	6788	3	2004-10-19
1	9768	7756	3	2004-10-30
2	9768	6193	3	2004-10-30
3	9768	1744	2	2004-10-30
4	9768	5130	3	2004-10-30
5	9768	2492	3	2004-10-30
1	9769	3564	3	2004-10-18
2	9769	7468	1	2004-10-18
3	9769	3621	3	2004-10-18
4	9769	9098	3	2004-10-18
5	9769	4413	3	2004-10-18
6	9769	8254	1	2004-10-18
7	9769	7413	3	2004-10-18
8	9769	6343	3	2004-10-18
9	9769	2214	2	2004-10-18
1	9770	3913	3	2004-10-16
2	9770	4496	2	2004-10-16
3	9770	4950	1	2004-10-16
4	9770	7747	1	2004-10-16
5	9770	282	1	2004-10-16
6	9770	9779	3	2004-10-16
1	9771	1881	3	2004-10-06
1	9772	7766	3	2004-10-31
2	9772	4897	3	2004-10-31
3	9772	1219	3	2004-10-31
4	9772	8385	2	2004-10-31
5	9772	6486	1	2004-10-31
6	9772	2650	1	2004-10-31
7	9772	8700	3	2004-10-31
1	9773	7758	3	2004-10-04
2	9773	9305	3	2004-10-04
1	9774	4051	1	2004-10-08
2	9774	4482	2	2004-10-08
3	9774	7334	1	2004-10-08
4	9774	1950	1	2004-10-08
1	9775	7539	3	2004-10-07
1	9776	7788	1	2004-10-10
2	9776	8052	3	2004-10-10
1	9777	5192	3	2004-10-08
2	9777	6119	2	2004-10-08
1	9778	4999	1	2004-10-10
2	9778	9689	3	2004-10-10
3	9778	4873	1	2004-10-10
4	9778	117	3	2004-10-10
5	9778	2523	3	2004-10-10
6	9778	5456	2	2004-10-10
7	9778	7844	2	2004-10-10
1	9779	2709	3	2004-10-22
2	9779	895	3	2004-10-22
3	9779	9750	2	2004-10-22
4	9779	7468	2	2004-10-22
5	9779	1383	1	2004-10-22
1	9780	9336	3	2004-10-19
1	9781	1130	1	2004-10-25
2	9781	5756	2	2004-10-25
3	9781	7425	2	2004-10-25
4	9781	1555	2	2004-10-25
5	9781	9230	3	2004-10-25
6	9781	9544	1	2004-10-25
7	9781	5416	1	2004-10-25
8	9781	793	2	2004-10-25
1	9782	8689	3	2004-10-21
2	9782	4599	2	2004-10-21
3	9782	8108	2	2004-10-21
4	9782	4118	2	2004-10-21
5	9782	8142	2	2004-10-21
6	9782	4193	3	2004-10-21
7	9782	5587	3	2004-10-21
8	9782	5855	1	2004-10-21
1	9783	4723	3	2004-10-11
2	9783	4714	1	2004-10-11
3	9783	7450	2	2004-10-11
1	9784	1879	1	2004-10-17
2	9784	3408	2	2004-10-17
3	9784	9013	1	2004-10-17
4	9784	411	1	2004-10-17
5	9784	7608	3	2004-10-17
6	9784	6722	1	2004-10-17
1	9785	5318	2	2004-10-25
2	9785	1087	1	2004-10-25
3	9785	8072	2	2004-10-25
4	9785	9798	1	2004-10-25
1	9786	1220	1	2004-10-19
2	9786	7585	1	2004-10-19
1	9787	2508	3	2004-10-14
2	9787	6654	1	2004-10-14
3	9787	8537	2	2004-10-14
4	9787	1917	2	2004-10-14
1	9788	8961	1	2004-10-18
1	9789	9818	1	2004-10-12
2	9789	830	3	2004-10-12
3	9789	4124	1	2004-10-12
4	9789	165	1	2004-10-12
1	9790	8198	2	2004-10-16
2	9790	4708	2	2004-10-16
3	9790	5324	1	2004-10-16
4	9790	8226	3	2004-10-16
5	9790	9602	2	2004-10-16
1	9791	759	3	2004-10-03
2	9791	6898	3	2004-10-03
3	9791	2275	3	2004-10-03
4	9791	563	1	2004-10-03
5	9791	4823	2	2004-10-03
6	9791	5154	2	2004-10-03
7	9791	6394	1	2004-10-03
8	9791	9662	3	2004-10-03
9	9791	5023	3	2004-10-03
1	9792	2974	1	2004-10-14
2	9792	6863	1	2004-10-14
3	9792	4843	3	2004-10-14
4	9792	2212	3	2004-10-14
5	9792	7633	1	2004-10-14
6	9792	8442	2	2004-10-14
7	9792	658	1	2004-10-14
8	9792	1246	1	2004-10-14
9	9792	3821	2	2004-10-14
1	9793	9275	1	2004-10-19
2	9793	1393	2	2004-10-19
3	9793	8577	2	2004-10-19
1	9794	2222	1	2004-10-13
2	9794	9575	3	2004-10-13
3	9794	9946	1	2004-10-13
4	9794	6813	3	2004-10-13
5	9794	4757	2	2004-10-13
6	9794	2109	2	2004-10-13
7	9794	5971	2	2004-10-13
1	9795	8765	1	2004-10-21
2	9795	4842	3	2004-10-21
3	9795	1196	2	2004-10-21
1	9796	1058	3	2004-10-08
2	9796	3363	1	2004-10-08
3	9796	9419	1	2004-10-08
4	9796	343	3	2004-10-08
5	9796	4723	3	2004-10-08
6	9796	6943	3	2004-10-08
1	9797	2405	1	2004-10-08
2	9797	8172	1	2004-10-08
3	9797	4069	3	2004-10-08
4	9797	2306	3	2004-10-08
5	9797	4975	2	2004-10-08
6	9797	5144	3	2004-10-08
7	9797	3273	3	2004-10-08
8	9797	3674	2	2004-10-08
1	9798	9973	3	2004-10-14
2	9798	3094	2	2004-10-14
3	9798	5108	1	2004-10-14
4	9798	4175	3	2004-10-14
1	9799	596	2	2004-10-29
2	9799	3319	2	2004-10-29
1	9800	9126	3	2004-10-04
2	9800	3291	1	2004-10-04
3	9800	5789	3	2004-10-04
4	9800	6729	1	2004-10-04
5	9800	4000	2	2004-10-04
6	9800	3829	2	2004-10-04
1	9801	6959	1	2004-10-08
2	9801	4917	2	2004-10-08
3	9801	1908	1	2004-10-08
4	9801	7537	1	2004-10-08
5	9801	4884	1	2004-10-08
6	9801	7167	2	2004-10-08
7	9801	6481	1	2004-10-08
1	9802	8004	2	2004-10-06
2	9802	2123	2	2004-10-06
3	9802	5347	2	2004-10-06
4	9802	9071	3	2004-10-06
5	9802	94	1	2004-10-06
1	9803	1601	2	2004-10-19
2	9803	9102	2	2004-10-19
3	9803	4491	2	2004-10-19
1	9804	5263	2	2004-10-19
2	9804	3919	3	2004-10-19
3	9804	9580	2	2004-10-19
1	9805	2315	2	2004-10-08
2	9805	536	1	2004-10-08
3	9805	3148	1	2004-10-08
4	9805	2746	3	2004-10-08
1	9806	5183	1	2004-10-30
1	9807	9048	2	2004-10-14
1	9808	1442	3	2004-10-12
2	9808	982	2	2004-10-12
3	9808	6674	3	2004-10-12
4	9808	8146	3	2004-10-12
5	9808	3580	3	2004-10-12
6	9808	372	3	2004-10-12
7	9808	9310	1	2004-10-12
1	9809	9687	3	2004-10-19
2	9809	9678	2	2004-10-19
3	9809	9479	3	2004-10-19
4	9809	4690	3	2004-10-19
5	9809	3257	3	2004-10-19
6	9809	2838	1	2004-10-19
7	9809	5979	2	2004-10-19
8	9809	1858	3	2004-10-19
1	9810	7518	1	2004-10-25
2	9810	4838	3	2004-10-25
3	9810	6874	2	2004-10-25
4	9810	1008	1	2004-10-25
5	9810	2845	2	2004-10-25
6	9810	1119	1	2004-10-25
1	9811	8516	1	2004-10-17
2	9811	3443	1	2004-10-17
3	9811	9779	2	2004-10-17
4	9811	4540	2	2004-10-17
5	9811	559	2	2004-10-17
1	9812	4727	1	2004-10-09
2	9812	9433	3	2004-10-09
3	9812	335	2	2004-10-09
4	9812	3712	1	2004-10-09
5	9812	9152	2	2004-10-09
6	9812	6974	1	2004-10-09
7	9812	9089	1	2004-10-09
8	9812	1067	2	2004-10-09
9	9812	7325	3	2004-10-09
1	9813	7047	2	2004-10-23
2	9813	2743	3	2004-10-23
3	9813	2290	2	2004-10-23
4	9813	6176	3	2004-10-23
5	9813	4746	1	2004-10-23
6	9813	9662	2	2004-10-23
7	9813	467	3	2004-10-23
1	9814	735	3	2004-10-02
2	9814	9906	3	2004-10-02
3	9814	722	1	2004-10-02
4	9814	5626	3	2004-10-02
5	9814	554	1	2004-10-02
6	9814	8814	1	2004-10-02
7	9814	9817	2	2004-10-02
8	9814	7801	1	2004-10-02
9	9814	3465	1	2004-10-02
1	9815	542	3	2004-10-25
2	9815	6942	1	2004-10-25
3	9815	6965	3	2004-10-25
1	9816	6615	3	2004-10-17
2	9816	5745	3	2004-10-17
3	9816	7937	1	2004-10-17
4	9816	5382	3	2004-10-17
5	9816	4201	2	2004-10-17
6	9816	397	2	2004-10-17
1	9817	8287	2	2004-10-01
2	9817	3159	2	2004-10-01
3	9817	7358	2	2004-10-01
4	9817	2562	2	2004-10-01
1	9818	7828	3	2004-10-15
2	9818	5817	2	2004-10-15
3	9818	5748	1	2004-10-15
4	9818	1778	2	2004-10-15
5	9818	2931	3	2004-10-15
6	9818	2174	3	2004-10-15
7	9818	1354	1	2004-10-15
8	9818	1148	1	2004-10-15
9	9818	767	3	2004-10-15
1	9819	4647	3	2004-10-16
2	9819	1784	3	2004-10-16
3	9819	3973	2	2004-10-16
4	9819	6734	2	2004-10-16
5	9819	6387	2	2004-10-16
6	9819	4480	1	2004-10-16
7	9819	9004	1	2004-10-16
8	9819	3763	1	2004-10-16
1	9820	3825	3	2004-10-13
2	9820	8654	2	2004-10-13
3	9820	701	3	2004-10-13
4	9820	2696	2	2004-10-13
5	9820	8475	2	2004-10-13
6	9820	3710	1	2004-10-13
1	9821	1984	3	2004-10-15
2	9821	4356	3	2004-10-15
3	9821	1625	3	2004-10-15
4	9821	573	1	2004-10-15
5	9821	9062	2	2004-10-15
6	9821	1409	1	2004-10-15
7	9821	1029	3	2004-10-15
8	9821	9057	2	2004-10-15
1	9822	7131	1	2004-10-27
2	9822	4968	2	2004-10-27
3	9822	7533	3	2004-10-27
4	9822	8727	1	2004-10-27
5	9822	4170	3	2004-10-27
6	9822	879	2	2004-10-27
7	9822	6119	2	2004-10-27
8	9822	4524	3	2004-10-27
9	9822	4070	2	2004-10-27
1	9823	6104	1	2004-10-26
2	9823	9128	2	2004-10-26
3	9823	5312	3	2004-10-26
4	9823	2870	2	2004-10-26
5	9823	7111	1	2004-10-26
6	9823	7657	1	2004-10-26
7	9823	5606	2	2004-10-26
8	9823	756	2	2004-10-26
9	9823	7408	2	2004-10-26
1	9824	3521	2	2004-10-11
2	9824	7250	3	2004-10-11
3	9824	698	2	2004-10-11
4	9824	721	1	2004-10-11
5	9824	5399	3	2004-10-11
6	9824	588	2	2004-10-11
7	9824	1984	2	2004-10-11
8	9824	2296	2	2004-10-11
9	9824	1036	3	2004-10-11
1	9825	3880	1	2004-10-16
1	9826	9574	3	2004-10-15
2	9826	7684	1	2004-10-15
3	9826	3846	2	2004-10-15
4	9826	684	2	2004-10-15
5	9826	553	1	2004-10-15
6	9826	4671	2	2004-10-15
7	9826	8228	2	2004-10-15
8	9826	478	1	2004-10-15
1	9827	2180	3	2004-10-04
2	9827	885	2	2004-10-04
1	9828	6052	1	2004-10-02
2	9828	3344	2	2004-10-02
3	9828	1314	1	2004-10-02
4	9828	8719	2	2004-10-02
5	9828	5961	3	2004-10-02
1	9829	2465	3	2004-10-31
2	9829	9632	1	2004-10-31
3	9829	9245	1	2004-10-31
4	9829	5716	2	2004-10-31
1	9830	1561	2	2004-10-10
2	9830	8631	3	2004-10-10
3	9830	9769	2	2004-10-10
4	9830	536	1	2004-10-10
1	9831	7009	1	2004-10-01
2	9831	8426	3	2004-10-01
3	9831	6616	3	2004-10-01
4	9831	1083	3	2004-10-01
5	9831	8266	1	2004-10-01
6	9831	2023	3	2004-10-01
7	9831	1504	3	2004-10-01
8	9831	1820	2	2004-10-01
9	9831	5635	2	2004-10-01
1	9832	4660	1	2004-10-26
2	9832	1663	2	2004-10-26
3	9832	3530	1	2004-10-26
4	9832	7045	3	2004-10-26
5	9832	993	2	2004-10-26
6	9832	7772	3	2004-10-26
7	9832	764	2	2004-10-26
1	9833	2561	2	2004-10-27
2	9833	4426	2	2004-10-27
3	9833	3229	2	2004-10-27
4	9833	8549	3	2004-10-27
5	9833	2291	3	2004-10-27
6	9833	6058	1	2004-10-27
7	9833	3881	1	2004-10-27
1	9834	7511	1	2004-10-11
2	9834	4555	3	2004-10-11
3	9834	7012	1	2004-10-11
4	9834	7922	3	2004-10-11
5	9834	6714	2	2004-10-11
6	9834	9622	1	2004-10-11
7	9834	3487	1	2004-10-11
1	9835	4156	2	2004-10-18
2	9835	7764	2	2004-10-18
3	9835	1694	2	2004-10-18
4	9835	9384	2	2004-10-18
5	9835	4540	1	2004-10-18
6	9835	1117	1	2004-10-18
7	9835	9624	3	2004-10-18
8	9835	3411	2	2004-10-18
9	9835	7131	1	2004-10-18
1	9836	1624	3	2004-10-21
2	9836	3400	2	2004-10-21
3	9836	9999	3	2004-10-21
1	9837	1038	2	2004-10-10
2	9837	3623	1	2004-10-10
3	9837	9557	1	2004-10-10
4	9837	8306	2	2004-10-10
5	9837	5746	3	2004-10-10
6	9837	4549	2	2004-10-10
7	9837	8050	3	2004-10-10
1	9838	233	2	2004-10-30
2	9838	9271	1	2004-10-30
3	9838	4394	1	2004-10-30
4	9838	6966	2	2004-10-30
5	9838	1742	3	2004-10-30
6	9838	636	3	2004-10-30
1	9839	4406	2	2004-10-23
1	9840	2133	2	2004-10-12
2	9840	4907	1	2004-10-12
3	9840	1607	2	2004-10-12
4	9840	5363	3	2004-10-12
5	9840	507	2	2004-10-12
6	9840	6563	3	2004-10-12
7	9840	7451	1	2004-10-12
8	9840	2448	2	2004-10-12
9	9840	5348	2	2004-10-12
1	9841	7657	3	2004-10-14
2	9841	2350	1	2004-10-14
1	9842	5680	3	2004-10-14
2	9842	7102	1	2004-10-14
3	9842	7087	3	2004-10-14
4	9842	5041	1	2004-10-14
1	9843	5325	2	2004-10-27
2	9843	6213	3	2004-10-27
3	9843	9909	1	2004-10-27
4	9843	1962	2	2004-10-27
5	9843	7543	2	2004-10-27
1	9844	7262	3	2004-10-19
2	9844	4365	1	2004-10-19
3	9844	3020	1	2004-10-19
4	9844	8938	1	2004-10-19
5	9844	631	2	2004-10-19
6	9844	8829	2	2004-10-19
7	9844	8473	3	2004-10-19
8	9844	1218	2	2004-10-19
1	9845	4315	1	2004-10-09
2	9845	552	2	2004-10-09
3	9845	6226	3	2004-10-09
4	9845	2140	1	2004-10-09
5	9845	3294	3	2004-10-09
6	9845	321	1	2004-10-09
7	9845	6919	2	2004-10-09
8	9845	2588	3	2004-10-09
9	9845	4729	1	2004-10-09
1	9846	1030	2	2004-10-01
2	9846	6410	1	2004-10-01
3	9846	2537	3	2004-10-01
4	9846	8790	2	2004-10-01
5	9846	8181	1	2004-10-01
6	9846	6461	3	2004-10-01
7	9846	9381	1	2004-10-01
8	9846	6827	1	2004-10-01
1	9847	675	2	2004-10-15
2	9847	9791	1	2004-10-15
3	9847	5729	2	2004-10-15
4	9847	4788	2	2004-10-15
5	9847	9878	1	2004-10-15
1	9848	3155	1	2004-10-15
1	9849	5050	1	2004-10-01
2	9849	7186	2	2004-10-01
3	9849	4587	2	2004-10-01
4	9849	5952	3	2004-10-01
5	9849	4132	2	2004-10-01
6	9849	4476	2	2004-10-01
7	9849	615	2	2004-10-01
8	9849	8069	2	2004-10-01
1	9850	5194	3	2004-10-28
2	9850	9571	2	2004-10-28
3	9850	7890	1	2004-10-28
4	9850	4448	3	2004-10-28
5	9850	4671	3	2004-10-28
6	9850	6617	3	2004-10-28
7	9850	1788	2	2004-10-28
8	9850	4151	2	2004-10-28
1	9851	4926	1	2004-10-25
2	9851	6752	2	2004-10-25
1	9852	7676	2	2004-10-14
2	9852	1936	1	2004-10-14
3	9852	822	1	2004-10-14
1	9853	6874	3	2004-10-20
1	9854	7292	1	2004-10-03
2	9854	8918	2	2004-10-03
3	9854	2876	2	2004-10-03
1	9855	3342	3	2004-10-22
2	9855	8623	2	2004-10-22
3	9855	2641	2	2004-10-22
4	9855	9242	2	2004-10-22
1	9856	8775	1	2004-10-29
2	9856	6456	2	2004-10-29
3	9856	9215	3	2004-10-29
4	9856	9138	3	2004-10-29
5	9856	9754	2	2004-10-29
6	9856	611	3	2004-10-29
1	9857	1287	3	2004-10-05
2	9857	2391	2	2004-10-05
3	9857	7585	1	2004-10-05
4	9857	9855	1	2004-10-05
5	9857	7312	3	2004-10-05
6	9857	4801	2	2004-10-05
7	9857	9160	1	2004-10-05
8	9857	2067	3	2004-10-05
1	9858	5734	1	2004-10-04
1	9859	4159	1	2004-10-26
2	9859	2343	3	2004-10-26
3	9859	9272	2	2004-10-26
4	9859	5707	1	2004-10-26
5	9859	8258	1	2004-10-26
6	9859	2676	3	2004-10-26
7	9859	3517	3	2004-10-26
8	9859	7208	3	2004-10-26
1	9860	4301	1	2004-10-21
2	9860	7057	3	2004-10-21
3	9860	804	1	2004-10-21
4	9860	602	3	2004-10-21
5	9860	8278	3	2004-10-21
6	9860	7907	1	2004-10-21
7	9860	436	1	2004-10-21
8	9860	9928	3	2004-10-21
1	9861	8926	2	2004-10-13
2	9861	249	1	2004-10-13
1	9862	3824	3	2004-10-13
1	9863	6007	1	2004-10-29
2	9863	8879	2	2004-10-29
3	9863	205	3	2004-10-29
4	9863	6359	3	2004-10-29
5	9863	9593	3	2004-10-29
6	9863	8361	3	2004-10-29
1	9864	4377	2	2004-10-21
2	9864	1917	2	2004-10-21
3	9864	6522	2	2004-10-21
4	9864	2081	3	2004-10-21
5	9864	6450	2	2004-10-21
6	9864	7238	2	2004-10-21
7	9864	4028	3	2004-10-21
8	9864	1572	1	2004-10-21
1	9865	7607	1	2004-10-28
2	9865	7058	3	2004-10-28
3	9865	9795	2	2004-10-28
4	9865	6719	2	2004-10-28
5	9865	7658	1	2004-10-28
6	9865	4168	1	2004-10-28
7	9865	5953	2	2004-10-28
8	9865	6659	1	2004-10-28
9	9865	2035	3	2004-10-28
1	9866	3967	3	2004-10-31
2	9866	4580	2	2004-10-31
3	9866	8705	1	2004-10-31
4	9866	5989	2	2004-10-31
5	9866	2269	2	2004-10-31
6	9866	8348	3	2004-10-31
7	9866	796	3	2004-10-31
1	9867	9387	3	2004-10-15
2	9867	4436	2	2004-10-15
3	9867	4691	1	2004-10-15
1	9868	5210	2	2004-10-25
2	9868	4560	3	2004-10-25
3	9868	3148	3	2004-10-25
4	9868	4714	1	2004-10-25
5	9868	2461	1	2004-10-25
6	9868	7200	2	2004-10-25
7	9868	4299	2	2004-10-25
1	9869	2608	3	2004-10-13
2	9869	1201	1	2004-10-13
3	9869	6733	2	2004-10-13
4	9869	7335	1	2004-10-13
5	9869	6731	2	2004-10-13
6	9869	8149	2	2004-10-13
7	9869	2717	2	2004-10-13
8	9869	1041	3	2004-10-13
1	9870	6040	3	2004-10-08
2	9870	7950	1	2004-10-08
3	9870	3605	1	2004-10-08
4	9870	8786	3	2004-10-08
5	9870	7343	1	2004-10-08
6	9870	6458	3	2004-10-08
7	9870	600	3	2004-10-08
1	9871	8755	1	2004-10-07
2	9871	4428	3	2004-10-07
3	9871	6590	3	2004-10-07
4	9871	260	3	2004-10-07
5	9871	4420	1	2004-10-07
6	9871	1817	1	2004-10-07
7	9871	40	3	2004-10-07
8	9871	9710	3	2004-10-07
9	9871	1096	1	2004-10-07
1	9872	2355	3	2004-10-01
2	9872	7531	1	2004-10-01
3	9872	5089	3	2004-10-01
4	9872	286	3	2004-10-01
5	9872	8756	3	2004-10-01
6	9872	8409	1	2004-10-01
7	9872	5943	2	2004-10-01
1	9873	8996	2	2004-10-02
2	9873	5580	3	2004-10-02
3	9873	2301	2	2004-10-02
4	9873	7025	2	2004-10-02
5	9873	8604	3	2004-10-02
1	9874	7007	1	2004-10-11
2	9874	8586	1	2004-10-11
3	9874	1850	3	2004-10-11
4	9874	480	1	2004-10-11
5	9874	7912	3	2004-10-11
6	9874	3788	2	2004-10-11
1	9875	8860	3	2004-10-13
2	9875	956	2	2004-10-13
3	9875	8087	1	2004-10-13
4	9875	9729	2	2004-10-13
5	9875	6653	3	2004-10-13
6	9875	2373	3	2004-10-13
1	9876	9590	2	2004-10-25
2	9876	7011	1	2004-10-25
3	9876	3018	3	2004-10-25
4	9876	2045	1	2004-10-25
5	9876	6377	2	2004-10-25
1	9877	6774	3	2004-10-15
2	9877	3890	3	2004-10-15
3	9877	3245	1	2004-10-15
4	9877	986	1	2004-10-15
5	9877	7086	3	2004-10-15
1	9878	6675	1	2004-10-05
2	9878	4127	2	2004-10-05
3	9878	7276	1	2004-10-05
4	9878	7705	1	2004-10-05
5	9878	8626	3	2004-10-05
6	9878	1221	2	2004-10-05
7	9878	5582	2	2004-10-05
8	9878	5265	2	2004-10-05
9	9878	841	1	2004-10-05
1	9879	6706	1	2004-10-14
2	9879	552	2	2004-10-14
3	9879	8393	1	2004-10-14
4	9879	3250	2	2004-10-14
5	9879	1068	3	2004-10-14
6	9879	9090	2	2004-10-14
7	9879	6189	2	2004-10-14
1	9880	3643	3	2004-10-20
2	9880	9959	3	2004-10-20
3	9880	3881	2	2004-10-20
4	9880	4753	2	2004-10-20
5	9880	7262	3	2004-10-20
1	9881	7784	3	2004-10-30
2	9881	9947	2	2004-10-30
3	9881	9072	1	2004-10-30
4	9881	2136	1	2004-10-30
5	9881	3121	1	2004-10-30
6	9881	5333	3	2004-10-30
1	9882	6618	3	2004-10-24
2	9882	2124	2	2004-10-24
3	9882	6071	2	2004-10-24
4	9882	1799	1	2004-10-24
1	9883	6089	2	2004-10-03
1	9884	48	1	2004-10-20
2	9884	9474	1	2004-10-20
3	9884	3003	1	2004-10-20
4	9884	3408	3	2004-10-20
5	9884	1904	1	2004-10-20
6	9884	9998	2	2004-10-20
1	9885	3191	3	2004-10-17
2	9885	3371	2	2004-10-17
3	9885	8846	2	2004-10-17
4	9885	4049	3	2004-10-17
5	9885	4270	1	2004-10-17
6	9885	5330	1	2004-10-17
7	9885	4009	3	2004-10-17
1	9886	6239	2	2004-10-22
2	9886	8945	3	2004-10-22
3	9886	3322	1	2004-10-22
4	9886	645	1	2004-10-22
5	9886	5955	2	2004-10-22
6	9886	9933	3	2004-10-22
1	9887	8113	2	2004-10-11
2	9887	721	1	2004-10-11
3	9887	3530	2	2004-10-11
4	9887	2298	3	2004-10-11
5	9887	5591	2	2004-10-11
6	9887	7981	1	2004-10-11
1	9888	4951	3	2004-10-02
2	9888	6247	3	2004-10-02
3	9888	8612	3	2004-10-02
4	9888	1590	2	2004-10-02
5	9888	2779	1	2004-10-02
6	9888	2474	2	2004-10-02
1	9889	3178	2	2004-10-15
2	9889	4919	3	2004-10-15
3	9889	8371	3	2004-10-15
1	9890	6430	2	2004-10-18
2	9890	3513	2	2004-10-18
3	9890	484	3	2004-10-18
4	9890	3012	3	2004-10-18
1	9891	6190	2	2004-10-21
2	9891	9848	3	2004-10-21
3	9891	2433	2	2004-10-21
4	9891	7067	2	2004-10-21
5	9891	7252	1	2004-10-21
6	9891	8472	1	2004-10-21
7	9891	6953	3	2004-10-21
8	9891	9387	1	2004-10-21
1	9892	6791	3	2004-10-03
2	9892	2482	3	2004-10-03
3	9892	8042	2	2004-10-03
4	9892	4004	2	2004-10-03
5	9892	7117	3	2004-10-03
6	9892	3102	1	2004-10-03
7	9892	4025	1	2004-10-03
1	9893	1549	2	2004-10-07
2	9893	9282	1	2004-10-07
3	9893	6865	2	2004-10-07
4	9893	6863	2	2004-10-07
5	9893	8753	3	2004-10-07
6	9893	9159	2	2004-10-07
7	9893	4899	2	2004-10-07
8	9893	4399	3	2004-10-07
9	9893	3223	1	2004-10-07
1	9894	4852	1	2004-10-09
2	9894	3296	3	2004-10-09
3	9894	3268	2	2004-10-09
4	9894	5334	1	2004-10-09
5	9894	4302	3	2004-10-09
6	9894	5404	2	2004-10-09
7	9894	6904	1	2004-10-09
8	9894	9817	2	2004-10-09
9	9894	8519	3	2004-10-09
1	9895	3626	3	2004-10-05
2	9895	3710	3	2004-10-05
3	9895	228	2	2004-10-05
4	9895	4076	3	2004-10-05
5	9895	6573	3	2004-10-05
6	9895	7764	3	2004-10-05
1	9896	1742	3	2004-10-25
2	9896	21	3	2004-10-25
3	9896	3019	3	2004-10-25
1	9897	1404	1	2004-10-30
2	9897	5608	2	2004-10-30
3	9897	8450	3	2004-10-30
4	9897	2580	1	2004-10-30
5	9897	6083	1	2004-10-30
6	9897	8742	1	2004-10-30
7	9897	253	2	2004-10-30
8	9897	9085	3	2004-10-30
1	9898	27	1	2004-10-17
1	9899	6970	3	2004-10-31
2	9899	5604	3	2004-10-31
3	9899	5278	3	2004-10-31
1	9900	120	2	2004-10-31
2	9900	386	2	2004-10-31
3	9900	7185	3	2004-10-31
4	9900	6359	3	2004-10-31
5	9900	4441	2	2004-10-31
6	9900	5453	3	2004-10-31
7	9900	2333	2	2004-10-31
8	9900	9939	1	2004-10-31
1	9901	2459	3	2004-10-17
2	9901	570	3	2004-10-17
3	9901	7033	2	2004-10-17
1	9902	5037	3	2004-10-16
2	9902	1246	2	2004-10-16
3	9902	3053	3	2004-10-16
4	9902	4549	3	2004-10-16
5	9902	5867	3	2004-10-16
6	9902	4856	1	2004-10-16
7	9902	8613	3	2004-10-16
1	9903	8240	1	2004-10-19
1	9904	8760	3	2004-10-14
2	9904	748	2	2004-10-14
3	9904	5167	3	2004-10-14
4	9904	696	1	2004-10-14
5	9904	4333	1	2004-10-14
1	9905	6797	2	2004-10-18
1	9906	8840	2	2004-10-29
2	9906	6324	3	2004-10-29
3	9906	4487	2	2004-10-29
4	9906	335	3	2004-10-29
5	9906	5261	1	2004-10-29
6	9906	3720	2	2004-10-29
7	9906	17	2	2004-10-29
1	9907	5385	2	2004-10-25
2	9907	484	1	2004-10-25
3	9907	3666	1	2004-10-25
4	9907	1181	1	2004-10-25
5	9907	7092	1	2004-10-25
6	9907	2115	2	2004-10-25
7	9907	8117	1	2004-10-25
8	9907	8028	2	2004-10-25
1	9908	1333	2	2004-10-29
2	9908	1333	2	2004-10-29
3	9908	8284	1	2004-10-29
4	9908	9520	2	2004-10-29
5	9908	6531	1	2004-10-29
6	9908	4675	1	2004-10-29
7	9908	7749	2	2004-10-29
8	9908	2925	1	2004-10-29
9	9908	6013	2	2004-10-29
1	9909	7754	1	2004-10-06
2	9909	4946	2	2004-10-06
3	9909	7004	2	2004-10-06
4	9909	8295	2	2004-10-06
1	9910	4680	3	2004-10-13
2	9910	6639	2	2004-10-13
3	9910	4686	1	2004-10-13
4	9910	5668	3	2004-10-13
5	9910	5085	2	2004-10-13
1	9911	2115	3	2004-10-15
1	9912	9126	2	2004-10-12
2	9912	7168	2	2004-10-12
1	9913	5089	1	2004-10-31
2	9913	9175	3	2004-10-31
3	9913	961	2	2004-10-31
4	9913	3967	2	2004-10-31
1	9914	3050	3	2004-10-28
2	9914	2076	3	2004-10-28
3	9914	52	2	2004-10-28
4	9914	4588	2	2004-10-28
1	9915	931	1	2004-10-03
2	9915	6007	1	2004-10-03
3	9915	7702	3	2004-10-03
4	9915	4744	1	2004-10-03
5	9915	549	2	2004-10-03
6	9915	2558	1	2004-10-03
7	9915	9730	2	2004-10-03
8	9915	7156	3	2004-10-03
9	9915	6158	1	2004-10-03
1	9916	7088	1	2004-10-09
2	9916	9042	1	2004-10-09
3	9916	5422	3	2004-10-09
4	9916	6962	1	2004-10-09
5	9916	9669	3	2004-10-09
1	9917	3818	2	2004-10-09
1	9918	5876	3	2004-10-10
2	9918	2305	1	2004-10-10
3	9918	5852	3	2004-10-10
4	9918	5193	3	2004-10-10
5	9918	7671	3	2004-10-10
6	9918	3481	2	2004-10-10
1	9919	2314	2	2004-10-27
2	9919	4529	1	2004-10-27
3	9919	1288	3	2004-10-27
4	9919	7658	1	2004-10-27
1	9920	5841	1	2004-10-24
1	9921	4748	2	2004-10-21
2	9921	7468	3	2004-10-21
3	9921	2567	2	2004-10-21
4	9921	6818	2	2004-10-21
5	9921	9896	2	2004-10-21
6	9921	8569	2	2004-10-21
7	9921	9466	1	2004-10-21
8	9921	9723	2	2004-10-21
9	9921	2865	1	2004-10-21
1	9922	1997	2	2004-10-04
2	9922	9870	3	2004-10-04
3	9922	5526	2	2004-10-04
4	9922	9553	2	2004-10-04
5	9922	5574	2	2004-10-04
6	9922	7549	1	2004-10-04
7	9922	4241	1	2004-10-04
8	9922	8179	1	2004-10-04
9	9922	6162	3	2004-10-04
1	9923	5613	2	2004-10-21
2	9923	9950	3	2004-10-21
3	9923	5135	1	2004-10-21
4	9923	9000	2	2004-10-21
5	9923	156	1	2004-10-21
6	9923	764	1	2004-10-21
1	9924	9901	1	2004-10-28
2	9924	2686	3	2004-10-28
3	9924	5207	3	2004-10-28
4	9924	7565	2	2004-10-28
5	9924	7986	2	2004-10-28
6	9924	1459	2	2004-10-28
7	9924	8457	2	2004-10-28
8	9924	431	2	2004-10-28
1	9925	1585	1	2004-10-31
2	9925	1303	1	2004-10-31
3	9925	2542	1	2004-10-31
4	9925	1764	1	2004-10-31
5	9925	8356	3	2004-10-31
1	9926	5706	2	2004-10-31
2	9926	9372	1	2004-10-31
3	9926	9116	3	2004-10-31
1	9927	6435	1	2004-10-22
2	9927	9521	2	2004-10-22
3	9927	2641	1	2004-10-22
4	9927	1540	2	2004-10-22
5	9927	3613	1	2004-10-22
1	9928	7527	1	2004-10-19
2	9928	6086	3	2004-10-19
3	9928	1521	2	2004-10-19
4	9928	9731	3	2004-10-19
5	9928	2339	3	2004-10-19
6	9928	497	1	2004-10-19
7	9928	6459	3	2004-10-19
1	9929	551	1	2004-10-07
2	9929	4882	1	2004-10-07
3	9929	4532	2	2004-10-07
4	9929	7417	3	2004-10-07
5	9929	9263	2	2004-10-07
6	9929	4298	2	2004-10-07
7	9929	1109	1	2004-10-07
8	9929	7436	3	2004-10-07
1	9930	6183	2	2004-10-29
2	9930	7943	3	2004-10-29
3	9930	7595	2	2004-10-29
4	9930	4171	3	2004-10-29
5	9930	2690	3	2004-10-29
6	9930	8085	1	2004-10-29
7	9930	9581	1	2004-10-29
8	9930	6432	2	2004-10-29
1	9931	7229	2	2004-10-30
2	9931	2821	3	2004-10-30
3	9931	8378	1	2004-10-30
4	9931	5531	3	2004-10-30
5	9931	9212	3	2004-10-30
6	9931	6328	2	2004-10-30
7	9931	5474	2	2004-10-30
8	9931	2074	1	2004-10-30
1	9932	3360	1	2004-10-27
2	9932	4602	1	2004-10-27
1	9933	4881	3	2004-10-12
2	9933	1779	1	2004-10-12
3	9933	5861	2	2004-10-12
1	9934	1726	2	2004-10-02
2	9934	5309	3	2004-10-02
3	9934	9462	1	2004-10-02
4	9934	2324	1	2004-10-02
5	9934	3850	1	2004-10-02
6	9934	7779	2	2004-10-02
1	9935	4077	1	2004-10-08
2	9935	7991	1	2004-10-08
3	9935	4185	1	2004-10-08
4	9935	437	2	2004-10-08
5	9935	4980	2	2004-10-08
6	9935	563	2	2004-10-08
7	9935	535	2	2004-10-08
1	9936	314	3	2004-10-05
2	9936	7490	1	2004-10-05
3	9936	480	1	2004-10-05
4	9936	3633	3	2004-10-05
5	9936	7880	2	2004-10-05
6	9936	9395	2	2004-10-05
7	9936	2947	2	2004-10-05
1	9937	3808	2	2004-10-20
1	9938	4211	1	2004-10-20
2	9938	2377	2	2004-10-20
3	9938	4129	1	2004-10-20
4	9938	2319	2	2004-10-20
5	9938	806	3	2004-10-20
6	9938	7081	1	2004-10-20
7	9938	1149	1	2004-10-20
1	9939	4222	3	2004-10-30
2	9939	2410	1	2004-10-30
3	9939	585	3	2004-10-30
4	9939	906	2	2004-10-30
5	9939	2046	3	2004-10-30
6	9939	3179	2	2004-10-30
7	9939	4263	3	2004-10-30
8	9939	5248	2	2004-10-30
9	9939	3000	3	2004-10-30
1	9940	5127	1	2004-10-27
2	9940	591	2	2004-10-27
3	9940	1611	1	2004-10-27
4	9940	5303	3	2004-10-27
5	9940	9071	3	2004-10-27
6	9940	7961	1	2004-10-27
7	9940	9996	3	2004-10-27
8	9940	8490	1	2004-10-27
9	9940	2937	1	2004-10-27
1	9941	3503	3	2004-10-26
2	9941	9107	2	2004-10-26
3	9941	8538	3	2004-10-26
1	9942	3254	3	2004-10-06
2	9942	3223	2	2004-10-06
3	9942	7637	3	2004-10-06
4	9942	3177	3	2004-10-06
5	9942	8049	1	2004-10-06
6	9942	8188	3	2004-10-06
7	9942	9682	3	2004-10-06
1	9943	8732	1	2004-10-28
2	9943	9618	1	2004-10-28
3	9943	288	3	2004-10-28
4	9943	8737	3	2004-10-28
5	9943	6331	1	2004-10-28
6	9943	1181	1	2004-10-28
7	9943	7505	2	2004-10-28
1	9944	9252	1	2004-10-03
2	9944	5091	3	2004-10-03
3	9944	3613	1	2004-10-03
4	9944	5345	1	2004-10-03
5	9944	9955	2	2004-10-03
6	9944	5912	3	2004-10-03
7	9944	1441	2	2004-10-03
8	9944	8294	1	2004-10-03
1	9945	7407	2	2004-10-22
2	9945	6173	3	2004-10-22
3	9945	9355	2	2004-10-22
4	9945	3022	1	2004-10-22
5	9945	4404	1	2004-10-22
6	9945	8484	2	2004-10-22
1	9946	6853	2	2004-10-15
2	9946	1704	3	2004-10-15
3	9946	590	3	2004-10-15
4	9946	3975	1	2004-10-15
5	9946	2259	1	2004-10-15
6	9946	3088	3	2004-10-15
7	9946	849	1	2004-10-15
8	9946	4753	3	2004-10-15
1	9947	4602	3	2004-10-28
2	9947	8435	3	2004-10-28
3	9947	2185	3	2004-10-28
4	9947	2660	3	2004-10-28
5	9947	494	2	2004-10-28
6	9947	5390	3	2004-10-28
7	9947	9914	3	2004-10-28
8	9947	4153	1	2004-10-28
1	9948	395	2	2004-10-15
2	9948	6104	1	2004-10-15
3	9948	8490	1	2004-10-15
4	9948	9499	3	2004-10-15
5	9948	1781	2	2004-10-15
6	9948	5804	2	2004-10-15
7	9948	6205	2	2004-10-15
1	9949	5369	1	2004-10-17
2	9949	1661	1	2004-10-17
3	9949	8996	1	2004-10-17
4	9949	7851	1	2004-10-17
5	9949	2079	1	2004-10-17
6	9949	1276	2	2004-10-17
7	9949	9525	1	2004-10-17
8	9949	234	2	2004-10-17
1	9950	6194	3	2004-10-10
2	9950	8752	1	2004-10-10
3	9950	4647	2	2004-10-10
1	9951	8081	3	2004-10-20
2	9951	9044	3	2004-10-20
3	9951	9472	3	2004-10-20
4	9951	1317	3	2004-10-20
5	9951	1188	2	2004-10-20
6	9951	9880	1	2004-10-20
7	9951	8008	3	2004-10-20
1	9952	6965	1	2004-10-13
2	9952	9457	1	2004-10-13
3	9952	9779	3	2004-10-13
4	9952	5154	2	2004-10-13
5	9952	3164	1	2004-10-13
6	9952	4460	2	2004-10-13
7	9952	8783	1	2004-10-13
1	9953	5865	2	2004-10-17
2	9953	2014	3	2004-10-17
3	9953	6994	1	2004-10-17
4	9953	9516	2	2004-10-17
5	9953	1297	2	2004-10-17
1	9954	7842	1	2004-10-11
1	9955	2047	1	2004-10-11
2	9955	9906	2	2004-10-11
3	9955	8029	3	2004-10-11
4	9955	9047	1	2004-10-11
5	9955	6514	1	2004-10-11
6	9955	7943	1	2004-10-11
7	9955	4928	3	2004-10-11
8	9955	9432	1	2004-10-11
1	9956	2595	1	2004-10-06
2	9956	9473	1	2004-10-06
3	9956	369	3	2004-10-06
1	9957	2247	3	2004-10-11
2	9957	3315	1	2004-10-11
1	9958	4593	3	2004-10-11
2	9958	3864	1	2004-10-11
3	9958	9734	3	2004-10-11
1	9959	8112	3	2004-10-08
2	9959	7484	1	2004-10-08
3	9959	7798	3	2004-10-08
4	9959	3995	3	2004-10-08
1	9960	9226	2	2004-10-14
2	9960	6186	1	2004-10-14
3	9960	6297	3	2004-10-14
4	9960	3884	3	2004-10-14
5	9960	2209	3	2004-10-14
6	9960	4492	2	2004-10-14
7	9960	1012	2	2004-10-14
8	9960	4864	2	2004-10-14
9	9960	3390	2	2004-10-14
1	9961	2208	1	2004-10-25
2	9961	2281	2	2004-10-25
3	9961	9175	2	2004-10-25
4	9961	3633	1	2004-10-25
5	9961	5755	1	2004-10-25
1	9962	1615	3	2004-10-17
2	9962	8649	2	2004-10-17
1	9963	7365	2	2004-10-25
2	9963	2270	1	2004-10-25
3	9963	334	1	2004-10-25
4	9963	2255	2	2004-10-25
5	9963	5435	2	2004-10-25
6	9963	4554	3	2004-10-25
7	9963	664	2	2004-10-25
8	9963	4266	2	2004-10-25
1	9964	1962	1	2004-10-15
1	9965	7399	3	2004-10-05
1	9966	2050	1	2004-10-11
1	9967	5928	2	2004-10-05
2	9967	8151	1	2004-10-05
3	9967	3891	3	2004-10-05
4	9967	4210	3	2004-10-05
1	9968	9025	1	2004-10-10
1	9969	729	1	2004-10-09
2	9969	4244	2	2004-10-09
3	9969	8403	1	2004-10-09
4	9969	4725	1	2004-10-09
5	9969	3233	2	2004-10-09
1	9970	147	3	2004-10-09
2	9970	9245	2	2004-10-09
3	9970	6814	2	2004-10-09
4	9970	2193	3	2004-10-09
5	9970	2463	1	2004-10-09
6	9970	190	1	2004-10-09
7	9970	506	1	2004-10-09
8	9970	2040	2	2004-10-09
1	9971	6812	2	2004-10-24
2	9971	4509	1	2004-10-24
1	9972	1714	3	2004-10-13
2	9972	5784	1	2004-10-13
3	9972	5541	2	2004-10-13
4	9972	5898	1	2004-10-13
5	9972	8482	3	2004-10-13
6	9972	2278	1	2004-10-13
7	9972	8459	1	2004-10-13
1	9973	3182	1	2004-10-08
2	9973	7238	3	2004-10-08
3	9973	5044	2	2004-10-08
4	9973	2244	3	2004-10-08
5	9973	5584	2	2004-10-08
1	9974	820	3	2004-10-23
2	9974	867	2	2004-10-23
3	9974	4261	3	2004-10-23
4	9974	8715	1	2004-10-23
5	9974	4853	1	2004-10-23
6	9974	3686	1	2004-10-23
7	9974	3460	2	2004-10-23
8	9974	2275	3	2004-10-23
9	9974	587	2	2004-10-23
1	9975	1872	2	2004-10-07
2	9975	6669	3	2004-10-07
3	9975	2639	2	2004-10-07
4	9975	734	2	2004-10-07
5	9975	2968	1	2004-10-07
6	9975	5320	2	2004-10-07
7	9975	7915	3	2004-10-07
1	9976	7621	2	2004-10-02
2	9976	8762	1	2004-10-02
3	9976	2125	1	2004-10-02
4	9976	17	1	2004-10-02
5	9976	6493	1	2004-10-02
1	9977	6671	2	2004-10-02
2	9977	9863	3	2004-10-02
3	9977	9839	1	2004-10-02
1	9978	6640	1	2004-10-17
1	9979	2688	2	2004-10-01
2	9979	8624	1	2004-10-01
3	9979	5393	1	2004-10-01
1	9980	7500	2	2004-10-08
2	9980	9436	3	2004-10-08
3	9980	6401	2	2004-10-08
4	9980	2585	2	2004-10-08
5	9980	5415	1	2004-10-08
6	9980	6859	1	2004-10-08
7	9980	5230	3	2004-10-08
8	9980	1524	1	2004-10-08
9	9980	9071	1	2004-10-08
1	9981	75	1	2004-10-29
2	9981	3243	2	2004-10-29
1	9982	4703	3	2004-10-12
2	9982	1257	2	2004-10-12
3	9982	5083	3	2004-10-12
4	9982	245	3	2004-10-12
5	9982	3920	2	2004-10-12
6	9982	91	1	2004-10-12
7	9982	6469	2	2004-10-12
1	9983	9811	2	2004-10-31
2	9983	4619	2	2004-10-31
3	9983	8089	2	2004-10-31
4	9983	7300	1	2004-10-31
5	9983	161	1	2004-10-31
6	9983	7057	1	2004-10-31
7	9983	8368	1	2004-10-31
8	9983	9412	3	2004-10-31
1	9984	2162	1	2004-10-19
2	9984	1803	1	2004-10-19
3	9984	1979	3	2004-10-19
4	9984	7572	1	2004-10-19
5	9984	6264	2	2004-10-19
6	9984	620	2	2004-10-19
1	9985	9933	3	2004-10-04
2	9985	473	1	2004-10-04
3	9985	8721	3	2004-10-04
4	9985	1130	3	2004-10-04
5	9985	9290	1	2004-10-04
6	9985	6712	2	2004-10-04
7	9985	5036	2	2004-10-04
8	9985	1331	3	2004-10-04
9	9985	5193	1	2004-10-04
1	9986	8935	3	2004-10-30
2	9986	1780	3	2004-10-30
3	9986	3743	1	2004-10-30
4	9986	4793	2	2004-10-30
5	9986	1977	2	2004-10-30
6	9986	1677	1	2004-10-30
7	9986	4818	1	2004-10-30
1	9987	6488	2	2004-10-31
2	9987	4456	1	2004-10-31
3	9987	8189	2	2004-10-31
4	9987	8720	2	2004-10-31
5	9987	8920	3	2004-10-31
6	9987	553	1	2004-10-31
7	9987	5189	3	2004-10-31
8	9987	7993	3	2004-10-31
9	9987	9042	1	2004-10-31
1	9988	8559	3	2004-10-31
2	9988	4227	2	2004-10-31
1	9989	3474	2	2004-10-25
2	9989	9548	3	2004-10-25
3	9989	7335	3	2004-10-25
4	9989	3716	2	2004-10-25
5	9989	1119	1	2004-10-25
1	9990	1159	1	2004-10-14
2	9990	6380	1	2004-10-14
3	9990	2685	2	2004-10-14
4	9990	4034	3	2004-10-14
5	9990	7960	1	2004-10-14
6	9990	5948	1	2004-10-14
7	9990	5969	2	2004-10-14
8	9990	6392	2	2004-10-14
9	9990	9165	3	2004-10-14
1	9991	6449	1	2004-10-04
2	9991	4495	3	2004-10-04
3	9991	4144	3	2004-10-04
4	9991	9238	3	2004-10-04
5	9991	8130	1	2004-10-04
6	9991	8053	2	2004-10-04
7	9991	595	1	2004-10-04
8	9991	691	2	2004-10-04
1	9992	837	1	2004-10-29
2	9992	8976	3	2004-10-29
3	9992	8482	3	2004-10-29
4	9992	7094	3	2004-10-29
5	9992	6852	2	2004-10-29
1	9993	866	1	2004-10-25
2	9993	1239	1	2004-10-25
3	9993	7644	3	2004-10-25
1	9994	6434	2	2004-10-02
1	9995	811	2	2004-10-18
2	9995	6132	3	2004-10-18
3	9995	1284	2	2004-10-18
1	9996	3264	1	2004-10-25
2	9996	8078	3	2004-10-25
3	9996	4747	3	2004-10-25
4	9996	202	2	2004-10-25
5	9996	9047	3	2004-10-25
1	9997	640	3	2004-10-17
2	9997	3801	2	2004-10-17
3	9997	5624	3	2004-10-17
4	9997	9305	2	2004-10-17
5	9997	1075	2	2004-10-17
6	9997	6222	1	2004-10-17
7	9997	49	2	2004-10-17
8	9997	734	2	2004-10-17
9	9997	8926	2	2004-10-17
1	9998	5948	2	2004-10-21
2	9998	7206	2	2004-10-21
1	9999	1791	2	2004-10-06
2	9999	5223	2	2004-10-06
3	9999	1542	1	2004-10-06
4	9999	2611	1	2004-10-06
5	9999	7281	2	2004-10-06
1	10000	7650	3	2004-10-20
2	10000	580	2	2004-10-20
3	10000	774	3	2004-10-20
4	10000	3579	2	2004-10-20
5	10000	8275	3	2004-10-20
6	10000	8293	2	2004-10-20
1	10001	6941	2	2004-11-19
2	10001	5365	2	2004-11-19
3	10001	7332	1	2004-11-19
4	10001	6645	1	2004-11-19
5	10001	240	3	2004-11-19
6	10001	6731	3	2004-11-19
7	10001	4020	2	2004-11-19
8	10001	4615	2	2004-11-19
1	10002	6378	3	2004-11-29
2	10002	2423	2	2004-11-29
3	10002	4496	2	2004-11-29
4	10002	9165	1	2004-11-29
5	10002	2507	1	2004-11-29
6	10002	9548	3	2004-11-29
7	10002	6104	2	2004-11-29
8	10002	4499	2	2004-11-29
9	10002	7799	1	2004-11-29
1	10003	7161	2	2004-11-17
2	10003	8585	1	2004-11-17
1	10004	7127	3	2004-11-23
2	10004	706	3	2004-11-23
1	10005	6016	3	2004-11-14
2	10005	5432	2	2004-11-14
3	10005	7541	1	2004-11-14
4	10005	475	1	2004-11-14
1	10006	6312	1	2004-11-15
1	10007	5247	1	2004-11-08
2	10007	9336	3	2004-11-08
1	10008	6011	1	2004-11-16
2	10008	1082	1	2004-11-16
3	10008	6171	3	2004-11-16
4	10008	9694	1	2004-11-16
5	10008	2660	3	2004-11-16
6	10008	3137	1	2004-11-16
1	10009	8549	3	2004-11-28
2	10009	4959	1	2004-11-28
3	10009	1191	1	2004-11-28
1	10010	4838	3	2004-11-08
2	10010	8218	1	2004-11-08
1	10011	5827	1	2004-11-16
2	10011	3362	2	2004-11-16
3	10011	3014	2	2004-11-16
4	10011	2754	2	2004-11-16
5	10011	9155	1	2004-11-16
6	10011	4256	1	2004-11-16
1	10012	3997	3	2004-11-14
2	10012	243	2	2004-11-14
3	10012	5907	2	2004-11-14
4	10012	8174	1	2004-11-14
5	10012	3675	2	2004-11-14
6	10012	3516	3	2004-11-14
7	10012	620	3	2004-11-14
8	10012	5124	2	2004-11-14
9	10012	169	3	2004-11-14
1	10013	9332	2	2004-11-06
2	10013	6748	2	2004-11-06
3	10013	4221	1	2004-11-06
4	10013	6392	1	2004-11-06
5	10013	671	1	2004-11-06
1	10014	5285	2	2004-11-06
2	10014	8620	3	2004-11-06
3	10014	1371	1	2004-11-06
4	10014	7817	1	2004-11-06
5	10014	893	1	2004-11-06
6	10014	8437	1	2004-11-06
7	10014	1425	1	2004-11-06
8	10014	4244	2	2004-11-06
1	10015	7164	2	2004-11-16
2	10015	3101	2	2004-11-16
1	10016	4684	1	2004-11-19
2	10016	6156	3	2004-11-19
3	10016	5727	2	2004-11-19
4	10016	8927	3	2004-11-19
5	10016	6911	3	2004-11-19
6	10016	9088	3	2004-11-19
7	10016	9684	3	2004-11-19
8	10016	8866	1	2004-11-19
1	10017	6686	2	2004-11-24
2	10017	4922	2	2004-11-24
3	10017	435	3	2004-11-24
1	10018	5024	2	2004-11-23
2	10018	2094	1	2004-11-23
1	10019	4917	1	2004-11-20
2	10019	2116	2	2004-11-20
3	10019	669	1	2004-11-20
4	10019	1529	3	2004-11-20
5	10019	2907	3	2004-11-20
1	10020	6569	3	2004-11-08
2	10020	3178	3	2004-11-08
3	10020	5451	1	2004-11-08
4	10020	3749	3	2004-11-08
5	10020	1927	3	2004-11-08
6	10020	3721	2	2004-11-08
7	10020	9951	1	2004-11-08
8	10020	1839	2	2004-11-08
9	10020	5538	3	2004-11-08
1	10021	9451	1	2004-11-27
2	10021	8973	1	2004-11-27
3	10021	1745	1	2004-11-27
4	10021	2301	2	2004-11-27
5	10021	946	3	2004-11-27
6	10021	1680	2	2004-11-27
7	10021	5873	3	2004-11-27
8	10021	4704	3	2004-11-27
9	10021	4374	2	2004-11-27
1	10022	8261	1	2004-11-26
2	10022	4249	2	2004-11-26
3	10022	9245	1	2004-11-26
4	10022	1450	1	2004-11-26
5	10022	2456	1	2004-11-26
6	10022	2293	1	2004-11-26
7	10022	3258	2	2004-11-26
8	10022	3045	2	2004-11-26
1	10023	8113	1	2004-11-25
2	10023	7099	1	2004-11-25
3	10023	9922	1	2004-11-25
4	10023	9447	3	2004-11-25
5	10023	9567	1	2004-11-25
6	10023	6658	3	2004-11-25
7	10023	2585	1	2004-11-25
8	10023	1624	1	2004-11-25
9	10023	3924	1	2004-11-25
1	10024	7808	3	2004-11-06
2	10024	8164	1	2004-11-06
3	10024	2790	2	2004-11-06
4	10024	4841	3	2004-11-06
1	10025	5770	3	2004-11-20
2	10025	4991	2	2004-11-20
3	10025	5752	2	2004-11-20
4	10025	5312	1	2004-11-20
1	10026	9725	3	2004-11-08
2	10026	7080	1	2004-11-08
3	10026	3618	1	2004-11-08
4	10026	5684	1	2004-11-08
1	10027	300	3	2004-11-25
1	10028	239	2	2004-11-25
2	10028	3246	2	2004-11-25
3	10028	1054	3	2004-11-25
4	10028	9787	2	2004-11-25
5	10028	1407	1	2004-11-25
6	10028	4261	2	2004-11-25
1	10029	5543	2	2004-11-19
2	10029	4309	1	2004-11-19
3	10029	7003	1	2004-11-19
1	10030	6395	1	2004-11-16
2	10030	2092	2	2004-11-16
3	10030	7768	1	2004-11-16
4	10030	2302	1	2004-11-16
5	10030	7560	2	2004-11-16
1	10031	9516	2	2004-11-01
2	10031	6138	2	2004-11-01
1	10032	3675	1	2004-11-24
2	10032	4735	1	2004-11-24
3	10032	5848	3	2004-11-24
4	10032	9955	3	2004-11-24
1	10033	2813	3	2004-11-16
2	10033	9602	2	2004-11-16
3	10033	255	3	2004-11-16
4	10033	8469	1	2004-11-16
5	10033	4508	3	2004-11-16
6	10033	1681	2	2004-11-16
7	10033	2169	3	2004-11-16
1	10034	3644	3	2004-11-30
2	10034	1913	3	2004-11-30
3	10034	267	3	2004-11-30
4	10034	8187	1	2004-11-30
5	10034	7277	2	2004-11-30
6	10034	6571	3	2004-11-30
7	10034	637	3	2004-11-30
8	10034	7995	1	2004-11-30
1	10035	8514	1	2004-11-14
2	10035	1152	1	2004-11-14
3	10035	5930	1	2004-11-14
1	10036	4301	3	2004-11-25
2	10036	3517	2	2004-11-25
3	10036	5477	2	2004-11-25
4	10036	3974	2	2004-11-25
1	10037	3	3	2004-11-13
1	10038	6246	2	2004-11-30
2	10038	7418	2	2004-11-30
3	10038	7211	3	2004-11-30
4	10038	4953	1	2004-11-30
5	10038	1890	1	2004-11-30
1	10039	2443	1	2004-11-27
2	10039	9296	3	2004-11-27
3	10039	4192	1	2004-11-27
1	10040	8772	2	2004-11-05
2	10040	6276	3	2004-11-05
3	10040	2520	2	2004-11-05
4	10040	3183	3	2004-11-05
5	10040	9484	1	2004-11-05
6	10040	3524	3	2004-11-05
7	10040	9170	3	2004-11-05
8	10040	9835	1	2004-11-05
1	10041	1699	3	2004-11-05
2	10041	8740	1	2004-11-05
3	10041	6766	1	2004-11-05
4	10041	4265	3	2004-11-05
5	10041	1128	3	2004-11-05
6	10041	6959	3	2004-11-05
7	10041	3308	1	2004-11-05
8	10041	8629	2	2004-11-05
1	10042	2411	3	2004-11-23
2	10042	3593	1	2004-11-23
3	10042	6591	2	2004-11-23
4	10042	2639	3	2004-11-23
5	10042	2043	3	2004-11-23
6	10042	6363	2	2004-11-23
7	10042	7888	2	2004-11-23
1	10043	3002	3	2004-11-15
2	10043	7784	3	2004-11-15
3	10043	9059	1	2004-11-15
4	10043	3196	3	2004-11-15
5	10043	6918	1	2004-11-15
6	10043	9498	1	2004-11-15
7	10043	7509	1	2004-11-15
8	10043	9625	1	2004-11-15
9	10043	3488	2	2004-11-15
1	10044	5167	1	2004-11-14
2	10044	310	1	2004-11-14
3	10044	5709	2	2004-11-14
4	10044	7709	2	2004-11-14
5	10044	4045	1	2004-11-14
6	10044	2901	1	2004-11-14
1	10045	9647	3	2004-11-03
2	10045	4477	3	2004-11-03
3	10045	1346	1	2004-11-03
4	10045	1052	1	2004-11-03
1	10046	664	1	2004-11-10
2	10046	4181	2	2004-11-10
3	10046	2037	2	2004-11-10
4	10046	8886	3	2004-11-10
5	10046	9536	2	2004-11-10
6	10046	1487	2	2004-11-10
7	10046	7305	2	2004-11-10
1	10047	1843	2	2004-11-17
2	10047	8163	2	2004-11-17
3	10047	5137	3	2004-11-17
4	10047	8304	2	2004-11-17
5	10047	478	1	2004-11-17
6	10047	726	3	2004-11-17
7	10047	9001	1	2004-11-17
8	10047	9091	1	2004-11-17
1	10048	8873	3	2004-11-22
2	10048	2699	1	2004-11-22
3	10048	789	1	2004-11-22
4	10048	4747	2	2004-11-22
5	10048	7979	1	2004-11-22
6	10048	4523	3	2004-11-22
1	10049	2193	2	2004-11-22
2	10049	8410	1	2004-11-22
1	10050	525	3	2004-11-18
2	10050	8015	3	2004-11-18
3	10050	548	2	2004-11-18
4	10050	3849	3	2004-11-18
5	10050	2896	2	2004-11-18
1	10051	9880	2	2004-11-30
2	10051	5619	2	2004-11-30
3	10051	4350	1	2004-11-30
4	10051	7088	1	2004-11-30
5	10051	4927	3	2004-11-30
1	10052	2471	1	2004-11-15
1	10053	739	1	2004-11-17
2	10053	9298	2	2004-11-17
3	10053	1669	1	2004-11-17
4	10053	1135	1	2004-11-17
1	10054	2215	1	2004-11-18
2	10054	159	2	2004-11-18
3	10054	4298	3	2004-11-18
4	10054	7055	3	2004-11-18
5	10054	6525	1	2004-11-18
6	10054	2560	3	2004-11-18
1	10055	8025	1	2004-11-09
2	10055	1959	3	2004-11-09
3	10055	4703	1	2004-11-09
4	10055	3350	2	2004-11-09
5	10055	3449	2	2004-11-09
6	10055	7820	3	2004-11-09
7	10055	2170	2	2004-11-09
8	10055	5082	2	2004-11-09
1	10056	2485	3	2004-11-17
2	10056	8909	3	2004-11-17
3	10056	9990	1	2004-11-17
4	10056	7484	1	2004-11-17
5	10056	6499	3	2004-11-17
6	10056	1089	2	2004-11-17
7	10056	691	1	2004-11-17
8	10056	3287	2	2004-11-17
9	10056	4304	2	2004-11-17
1	10057	7078	1	2004-11-06
2	10057	3379	1	2004-11-06
3	10057	7676	3	2004-11-06
4	10057	7399	3	2004-11-06
5	10057	8451	3	2004-11-06
6	10057	6628	3	2004-11-06
7	10057	8892	2	2004-11-06
8	10057	8828	2	2004-11-06
9	10057	9358	2	2004-11-06
1	10058	3494	1	2004-11-14
2	10058	696	3	2004-11-14
3	10058	9772	1	2004-11-14
4	10058	5550	1	2004-11-14
5	10058	2045	1	2004-11-14
1	10059	4190	1	2004-11-13
2	10059	483	1	2004-11-13
1	10060	3727	3	2004-11-07
1	10061	3532	2	2004-11-22
2	10061	7247	3	2004-11-22
1	10062	403	1	2004-11-22
2	10062	7798	1	2004-11-22
3	10062	2998	1	2004-11-22
4	10062	7871	3	2004-11-22
5	10062	3839	1	2004-11-22
6	10062	9966	2	2004-11-22
7	10062	4701	1	2004-11-22
1	10063	3525	1	2004-11-05
2	10063	8242	3	2004-11-05
3	10063	2267	1	2004-11-05
4	10063	1676	3	2004-11-05
5	10063	8797	3	2004-11-05
1	10064	3989	2	2004-11-23
2	10064	305	3	2004-11-23
3	10064	5495	3	2004-11-23
4	10064	4768	3	2004-11-23
5	10064	236	2	2004-11-23
6	10064	3653	2	2004-11-23
7	10064	6766	2	2004-11-23
8	10064	9635	3	2004-11-23
1	10065	834	1	2004-11-01
2	10065	254	1	2004-11-01
3	10065	1856	3	2004-11-01
4	10065	1320	3	2004-11-01
5	10065	2669	3	2004-11-01
6	10065	7168	2	2004-11-01
7	10065	550	3	2004-11-01
8	10065	3643	2	2004-11-01
1	10066	3145	3	2004-11-17
2	10066	820	3	2004-11-17
3	10066	4113	1	2004-11-17
4	10066	9664	2	2004-11-17
5	10066	3613	3	2004-11-17
6	10066	2834	2	2004-11-17
1	10067	2138	3	2004-11-07
2	10067	3250	2	2004-11-07
3	10067	5311	1	2004-11-07
4	10067	1464	2	2004-11-07
1	10068	3517	3	2004-11-24
2	10068	9422	2	2004-11-24
3	10068	6311	1	2004-11-24
4	10068	6570	1	2004-11-24
1	10069	5974	3	2004-11-03
2	10069	8755	3	2004-11-03
3	10069	695	2	2004-11-03
4	10069	1997	1	2004-11-03
1	10070	5664	3	2004-11-12
2	10070	5157	2	2004-11-12
3	10070	4207	3	2004-11-12
4	10070	7092	3	2004-11-12
5	10070	4342	2	2004-11-12
6	10070	4383	1	2004-11-12
7	10070	6755	1	2004-11-12
8	10070	1075	3	2004-11-12
9	10070	7186	2	2004-11-12
1	10071	1217	2	2004-11-06
1	10072	8460	2	2004-11-19
1	10073	7677	3	2004-11-29
2	10073	1723	2	2004-11-29
3	10073	5650	2	2004-11-29
4	10073	1281	1	2004-11-29
5	10073	6716	3	2004-11-29
1	10074	3639	3	2004-11-03
2	10074	1331	3	2004-11-03
3	10074	7757	1	2004-11-03
4	10074	1246	2	2004-11-03
5	10074	5761	3	2004-11-03
6	10074	4191	2	2004-11-03
7	10074	2848	2	2004-11-03
8	10074	8343	2	2004-11-03
1	10075	787	1	2004-11-26
1	10076	103	1	2004-11-19
2	10076	650	2	2004-11-19
3	10076	9332	2	2004-11-19
1	10077	3210	1	2004-11-09
1	10078	3191	2	2004-11-14
2	10078	2455	1	2004-11-14
3	10078	270	1	2004-11-14
4	10078	7552	2	2004-11-14
5	10078	893	3	2004-11-14
6	10078	4908	3	2004-11-14
7	10078	405	2	2004-11-14
8	10078	9898	1	2004-11-14
1	10079	4834	3	2004-11-19
2	10079	6238	2	2004-11-19
3	10079	9515	3	2004-11-19
4	10079	8843	2	2004-11-19
5	10079	8418	3	2004-11-19
6	10079	2842	1	2004-11-19
1	10080	6109	1	2004-11-11
2	10080	8432	3	2004-11-11
3	10080	9029	2	2004-11-11
4	10080	4039	3	2004-11-11
1	10081	4482	2	2004-11-26
2	10081	244	3	2004-11-26
3	10081	4962	2	2004-11-26
4	10081	5531	2	2004-11-26
5	10081	5929	2	2004-11-26
1	10082	5955	3	2004-11-26
2	10082	6696	3	2004-11-26
1	10083	9805	3	2004-11-04
2	10083	2906	2	2004-11-04
3	10083	8249	1	2004-11-04
4	10083	7778	3	2004-11-04
5	10083	5996	1	2004-11-04
6	10083	4225	2	2004-11-04
7	10083	1575	3	2004-11-04
8	10083	2720	3	2004-11-04
9	10083	3662	3	2004-11-04
1	10084	3620	3	2004-11-05
2	10084	3015	1	2004-11-05
3	10084	8044	2	2004-11-05
4	10084	3120	3	2004-11-05
5	10084	3716	1	2004-11-05
1	10085	7950	2	2004-11-20
2	10085	3082	2	2004-11-20
3	10085	6804	3	2004-11-20
4	10085	184	3	2004-11-20
5	10085	6492	1	2004-11-20
1	10086	2373	2	2004-11-17
2	10086	2509	2	2004-11-17
3	10086	3496	2	2004-11-17
4	10086	6308	1	2004-11-17
5	10086	9674	3	2004-11-17
6	10086	9368	2	2004-11-17
7	10086	2351	2	2004-11-17
1	10087	3663	2	2004-11-01
2	10087	1905	1	2004-11-01
3	10087	1291	1	2004-11-01
4	10087	8845	3	2004-11-01
5	10087	4992	2	2004-11-01
6	10087	7935	2	2004-11-01
7	10087	1290	1	2004-11-01
8	10087	1091	2	2004-11-01
1	10088	6126	3	2004-11-19
2	10088	2035	2	2004-11-19
3	10088	2385	2	2004-11-19
1	10089	356	3	2004-11-05
2	10089	6394	1	2004-11-05
3	10089	7632	3	2004-11-05
1	10090	805	2	2004-11-14
2	10090	5883	1	2004-11-14
3	10090	3707	3	2004-11-14
4	10090	5893	1	2004-11-14
5	10090	1561	2	2004-11-14
6	10090	2613	3	2004-11-14
7	10090	4211	2	2004-11-14
8	10090	3179	2	2004-11-14
9	10090	9033	2	2004-11-14
1	10091	9701	2	2004-11-27
2	10091	1605	3	2004-11-27
3	10091	1171	2	2004-11-27
4	10091	3808	2	2004-11-27
5	10091	5292	2	2004-11-27
6	10091	36	1	2004-11-27
7	10091	6706	2	2004-11-27
8	10091	8149	1	2004-11-27
9	10091	3748	3	2004-11-27
1	10092	1008	1	2004-11-24
2	10092	8618	1	2004-11-24
1	10093	6954	1	2004-11-16
2	10093	5836	3	2004-11-16
3	10093	9607	3	2004-11-16
1	10094	8026	2	2004-11-14
2	10094	978	2	2004-11-14
3	10094	7418	3	2004-11-14
4	10094	7328	1	2004-11-14
5	10094	8835	2	2004-11-14
6	10094	7526	2	2004-11-14
7	10094	7163	3	2004-11-14
8	10094	6802	2	2004-11-14
9	10094	8573	1	2004-11-14
1	10095	3423	1	2004-11-11
1	10096	6444	1	2004-11-27
2	10096	3213	2	2004-11-27
3	10096	4565	2	2004-11-27
4	10096	9199	1	2004-11-27
1	10097	1666	1	2004-11-10
2	10097	8380	3	2004-11-10
1	10098	7239	3	2004-11-28
2	10098	8925	1	2004-11-28
3	10098	8337	1	2004-11-28
4	10098	1888	3	2004-11-28
5	10098	5377	3	2004-11-28
6	10098	646	1	2004-11-28
7	10098	24	2	2004-11-28
1	10099	6570	1	2004-11-19
2	10099	2014	3	2004-11-19
3	10099	3517	2	2004-11-19
4	10099	388	1	2004-11-19
5	10099	2508	3	2004-11-19
1	10100	5111	2	2004-11-22
2	10100	5960	2	2004-11-22
3	10100	8642	3	2004-11-22
4	10100	683	2	2004-11-22
1	10101	5187	1	2004-11-21
2	10101	1593	1	2004-11-21
3	10101	7615	3	2004-11-21
4	10101	4601	3	2004-11-21
5	10101	7879	3	2004-11-21
6	10101	3308	3	2004-11-21
7	10101	13	2	2004-11-21
1	10102	1402	3	2004-11-24
2	10102	1521	3	2004-11-24
3	10102	1488	1	2004-11-24
4	10102	5209	1	2004-11-24
5	10102	4180	1	2004-11-24
1	10103	2145	1	2004-11-11
2	10103	1920	3	2004-11-11
3	10103	8951	2	2004-11-11
4	10103	9387	3	2004-11-11
5	10103	4638	1	2004-11-11
6	10103	5095	2	2004-11-11
7	10103	8508	1	2004-11-11
8	10103	1737	1	2004-11-11
1	10104	500	1	2004-11-25
2	10104	9862	2	2004-11-25
3	10104	3136	2	2004-11-25
4	10104	7898	2	2004-11-25
5	10104	4059	3	2004-11-25
6	10104	5318	2	2004-11-25
7	10104	7882	3	2004-11-25
8	10104	5963	3	2004-11-25
9	10104	3758	2	2004-11-25
1	10105	3045	2	2004-11-11
2	10105	1707	2	2004-11-11
3	10105	7988	3	2004-11-11
4	10105	7920	3	2004-11-11
5	10105	9586	3	2004-11-11
6	10105	8431	3	2004-11-11
7	10105	4128	1	2004-11-11
8	10105	3489	1	2004-11-11
1	10106	3751	3	2004-11-25
2	10106	753	3	2004-11-25
3	10106	3833	2	2004-11-25
4	10106	5061	3	2004-11-25
1	10107	9652	3	2004-11-09
2	10107	731	3	2004-11-09
3	10107	7840	3	2004-11-09
4	10107	5105	3	2004-11-09
5	10107	7071	2	2004-11-09
6	10107	6873	1	2004-11-09
1	10108	7908	1	2004-11-16
2	10108	6815	1	2004-11-16
3	10108	9344	3	2004-11-16
1	10109	669	2	2004-11-05
2	10109	9533	3	2004-11-05
3	10109	933	3	2004-11-05
4	10109	4871	1	2004-11-05
5	10109	6824	1	2004-11-05
6	10109	314	1	2004-11-05
1	10110	8583	1	2004-11-01
2	10110	7369	1	2004-11-01
3	10110	3862	2	2004-11-01
4	10110	4149	1	2004-11-01
5	10110	6935	2	2004-11-01
6	10110	8243	3	2004-11-01
7	10110	6668	1	2004-11-01
1	10111	4252	2	2004-11-15
2	10111	3452	3	2004-11-15
3	10111	7899	1	2004-11-15
4	10111	1832	3	2004-11-15
1	10112	8976	2	2004-11-07
2	10112	8231	2	2004-11-07
3	10112	5985	1	2004-11-07
4	10112	1621	1	2004-11-07
5	10112	2769	3	2004-11-07
6	10112	3626	1	2004-11-07
7	10112	6859	1	2004-11-07
1	10113	5861	1	2004-11-04
2	10113	2871	3	2004-11-04
3	10113	1003	1	2004-11-04
4	10113	9589	1	2004-11-04
5	10113	8982	1	2004-11-04
6	10113	4803	2	2004-11-04
1	10114	122	2	2004-11-29
2	10114	9783	1	2004-11-29
3	10114	4874	1	2004-11-29
4	10114	298	3	2004-11-29
5	10114	3562	3	2004-11-29
6	10114	8792	2	2004-11-29
7	10114	8749	2	2004-11-29
1	10115	3922	3	2004-11-05
2	10115	5167	2	2004-11-05
3	10115	2139	2	2004-11-05
4	10115	5302	3	2004-11-05
1	10116	2452	1	2004-11-27
2	10116	2221	1	2004-11-27
3	10116	2583	3	2004-11-27
4	10116	4785	1	2004-11-27
5	10116	5593	3	2004-11-27
6	10116	36	2	2004-11-27
7	10116	3240	3	2004-11-27
1	10117	9164	3	2004-11-03
2	10117	8409	2	2004-11-03
3	10117	824	1	2004-11-03
4	10117	8478	2	2004-11-03
5	10117	7488	3	2004-11-03
6	10117	887	3	2004-11-03
7	10117	4683	2	2004-11-03
8	10117	9045	3	2004-11-03
9	10117	5572	1	2004-11-03
1	10118	8703	2	2004-11-12
2	10118	3975	1	2004-11-12
3	10118	3326	2	2004-11-12
4	10118	6708	3	2004-11-12
5	10118	3884	2	2004-11-12
6	10118	4032	1	2004-11-12
7	10118	202	2	2004-11-12
8	10118	2840	3	2004-11-12
9	10118	980	1	2004-11-12
1	10119	5204	3	2004-11-18
1	10120	1131	2	2004-11-23
2	10120	1055	3	2004-11-23
1	10121	9808	3	2004-11-25
2	10121	8296	2	2004-11-25
1	10122	7183	3	2004-11-14
2	10122	3233	3	2004-11-14
3	10122	9150	3	2004-11-14
4	10122	29	3	2004-11-14
5	10122	9676	2	2004-11-14
1	10123	8605	3	2004-11-16
2	10123	8171	3	2004-11-16
3	10123	6971	2	2004-11-16
4	10123	4688	3	2004-11-16
5	10123	8000	2	2004-11-16
1	10124	8622	2	2004-11-22
2	10124	6135	2	2004-11-22
1	10125	8480	2	2004-11-09
2	10125	9822	3	2004-11-09
1	10126	9539	2	2004-11-28
2	10126	2370	3	2004-11-28
3	10126	3559	3	2004-11-28
4	10126	4133	3	2004-11-28
5	10126	8086	1	2004-11-28
1	10127	6893	3	2004-11-09
1	10128	2395	3	2004-11-16
2	10128	228	1	2004-11-16
3	10128	813	1	2004-11-16
4	10128	9029	1	2004-11-16
5	10128	5127	2	2004-11-16
6	10128	5271	2	2004-11-16
7	10128	8224	3	2004-11-16
8	10128	2375	1	2004-11-16
1	10129	8639	1	2004-11-21
2	10129	378	3	2004-11-21
3	10129	3695	3	2004-11-21
4	10129	4114	3	2004-11-21
5	10129	298	3	2004-11-21
1	10130	3566	2	2004-11-21
2	10130	7153	1	2004-11-21
3	10130	4636	1	2004-11-21
4	10130	6918	3	2004-11-21
5	10130	6945	2	2004-11-21
6	10130	7546	3	2004-11-21
7	10130	6924	2	2004-11-21
1	10131	9721	3	2004-11-18
2	10131	1531	2	2004-11-18
3	10131	7240	2	2004-11-18
4	10131	2206	3	2004-11-18
5	10131	2610	3	2004-11-18
1	10132	991	2	2004-11-01
2	10132	6390	2	2004-11-01
3	10132	5617	1	2004-11-01
4	10132	5533	1	2004-11-01
1	10133	7604	3	2004-11-26
2	10133	2325	3	2004-11-26
3	10133	2171	1	2004-11-26
4	10133	7165	2	2004-11-26
5	10133	5461	2	2004-11-26
1	10134	6748	1	2004-11-29
2	10134	8349	1	2004-11-29
1	10135	4966	1	2004-11-18
2	10135	5665	1	2004-11-18
3	10135	4447	2	2004-11-18
1	10136	4033	1	2004-11-11
2	10136	8376	2	2004-11-11
1	10137	9945	3	2004-11-12
2	10137	6982	1	2004-11-12
3	10137	1204	2	2004-11-12
4	10137	4059	3	2004-11-12
5	10137	6662	1	2004-11-12
6	10137	8892	1	2004-11-12
7	10137	2383	2	2004-11-12
8	10137	4818	3	2004-11-12
9	10137	4356	3	2004-11-12
1	10138	9112	3	2004-11-07
2	10138	3459	3	2004-11-07
1	10139	6631	1	2004-11-18
2	10139	4981	2	2004-11-18
3	10139	4857	2	2004-11-18
4	10139	7342	3	2004-11-18
5	10139	5737	2	2004-11-18
6	10139	8941	2	2004-11-18
1	10140	9371	1	2004-11-21
2	10140	1018	1	2004-11-21
1	10141	6232	2	2004-11-03
2	10141	7372	1	2004-11-03
3	10141	3953	1	2004-11-03
4	10141	7790	1	2004-11-03
5	10141	3369	1	2004-11-03
6	10141	4196	3	2004-11-03
7	10141	8955	1	2004-11-03
8	10141	7140	2	2004-11-03
9	10141	5541	2	2004-11-03
1	10142	4229	3	2004-11-28
2	10142	649	2	2004-11-28
3	10142	8306	1	2004-11-28
4	10142	1855	1	2004-11-28
5	10142	1308	3	2004-11-28
6	10142	8125	3	2004-11-28
7	10142	145	1	2004-11-28
8	10142	9078	3	2004-11-28
1	10143	670	3	2004-11-08
2	10143	8394	3	2004-11-08
3	10143	4350	2	2004-11-08
4	10143	3889	2	2004-11-08
5	10143	6410	1	2004-11-08
6	10143	1476	1	2004-11-08
7	10143	8064	1	2004-11-08
1	10144	7856	2	2004-11-18
2	10144	5826	2	2004-11-18
3	10144	3534	2	2004-11-18
4	10144	8057	1	2004-11-18
5	10144	3904	1	2004-11-18
6	10144	5056	2	2004-11-18
7	10144	7574	2	2004-11-18
1	10145	9902	3	2004-11-13
2	10145	2284	2	2004-11-13
3	10145	8714	2	2004-11-13
4	10145	6950	3	2004-11-13
5	10145	5884	1	2004-11-13
6	10145	3147	3	2004-11-13
7	10145	574	1	2004-11-13
8	10145	4285	2	2004-11-13
1	10146	429	2	2004-11-21
2	10146	5754	2	2004-11-21
3	10146	881	1	2004-11-21
4	10146	1210	2	2004-11-21
5	10146	9295	2	2004-11-21
1	10147	5507	1	2004-11-12
2	10147	9805	1	2004-11-12
3	10147	7657	2	2004-11-12
4	10147	5291	1	2004-11-12
5	10147	5118	2	2004-11-12
6	10147	1804	3	2004-11-12
1	10148	3822	3	2004-11-07
2	10148	904	3	2004-11-07
3	10148	3134	1	2004-11-07
4	10148	2903	2	2004-11-07
5	10148	6931	1	2004-11-07
1	10149	6737	3	2004-11-28
2	10149	2135	2	2004-11-28
1	10150	594	3	2004-11-29
2	10150	510	1	2004-11-29
3	10150	6749	1	2004-11-29
4	10150	1182	2	2004-11-29
5	10150	7404	2	2004-11-29
1	10151	92	3	2004-11-05
2	10151	9097	3	2004-11-05
3	10151	9677	3	2004-11-05
4	10151	7713	1	2004-11-05
5	10151	9440	2	2004-11-05
1	10152	1366	1	2004-11-24
2	10152	1966	1	2004-11-24
3	10152	564	1	2004-11-24
4	10152	4357	3	2004-11-24
5	10152	5247	2	2004-11-24
6	10152	1282	1	2004-11-24
7	10152	542	1	2004-11-24
1	10153	2599	3	2004-11-03
1	10154	3343	2	2004-11-25
2	10154	231	1	2004-11-25
3	10154	5947	1	2004-11-25
4	10154	8629	3	2004-11-25
5	10154	4439	1	2004-11-25
6	10154	9271	2	2004-11-25
1	10155	9166	2	2004-11-10
2	10155	965	3	2004-11-10
3	10155	6496	1	2004-11-10
4	10155	4826	2	2004-11-10
5	10155	2969	3	2004-11-10
6	10155	898	1	2004-11-10
7	10155	9700	2	2004-11-10
8	10155	6820	1	2004-11-10
1	10156	8271	1	2004-11-01
2	10156	3462	1	2004-11-01
3	10156	3573	1	2004-11-01
4	10156	7711	2	2004-11-01
5	10156	6361	1	2004-11-01
6	10156	4957	2	2004-11-01
1	10157	7843	1	2004-11-11
1	10158	1849	3	2004-11-13
2	10158	993	3	2004-11-13
3	10158	223	1	2004-11-13
4	10158	5719	2	2004-11-13
5	10158	7346	2	2004-11-13
1	10159	3541	2	2004-11-23
2	10159	7766	3	2004-11-23
1	10160	8644	1	2004-11-14
2	10160	8170	2	2004-11-14
3	10160	717	1	2004-11-14
4	10160	7297	3	2004-11-14
5	10160	7598	3	2004-11-14
6	10160	5380	3	2004-11-14
7	10160	7814	2	2004-11-14
8	10160	9786	2	2004-11-14
1	10161	7939	2	2004-11-01
2	10161	8851	1	2004-11-01
3	10161	8625	2	2004-11-01
4	10161	1380	1	2004-11-01
5	10161	9339	3	2004-11-01
6	10161	1110	3	2004-11-01
7	10161	7465	3	2004-11-01
1	10162	6380	3	2004-11-14
2	10162	911	1	2004-11-14
1	10163	2257	3	2004-11-24
2	10163	4819	3	2004-11-24
3	10163	5264	1	2004-11-24
4	10163	3995	2	2004-11-24
5	10163	4237	1	2004-11-24
6	10163	731	2	2004-11-24
7	10163	5677	1	2004-11-24
1	10164	6066	1	2004-11-08
2	10164	8069	3	2004-11-08
3	10164	4285	2	2004-11-08
4	10164	7094	2	2004-11-08
5	10164	6208	2	2004-11-08
6	10164	3921	2	2004-11-08
7	10164	2683	2	2004-11-08
8	10164	1106	3	2004-11-08
9	10164	5954	2	2004-11-08
1	10165	2568	1	2004-11-01
2	10165	112	3	2004-11-01
3	10165	1284	1	2004-11-01
4	10165	5030	3	2004-11-01
5	10165	2422	1	2004-11-01
1	10166	4939	2	2004-11-06
2	10166	1336	1	2004-11-06
3	10166	965	2	2004-11-06
4	10166	4715	2	2004-11-06
5	10166	1432	2	2004-11-06
6	10166	1149	3	2004-11-06
1	10167	5902	3	2004-11-07
2	10167	3888	2	2004-11-07
3	10167	8146	2	2004-11-07
1	10168	4272	2	2004-11-26
1	10169	9119	2	2004-11-05
2	10169	7544	1	2004-11-05
3	10169	9091	1	2004-11-05
4	10169	3731	1	2004-11-05
5	10169	8079	2	2004-11-05
6	10169	7909	1	2004-11-05
1	10170	5145	3	2004-11-19
2	10170	8201	1	2004-11-19
1	10171	7717	1	2004-11-07
2	10171	2870	3	2004-11-07
3	10171	3888	2	2004-11-07
4	10171	5574	1	2004-11-07
5	10171	9206	1	2004-11-07
6	10171	3089	3	2004-11-07
1	10172	1698	3	2004-11-17
2	10172	3723	3	2004-11-17
3	10172	1971	2	2004-11-17
4	10172	171	3	2004-11-17
1	10173	5119	3	2004-11-11
2	10173	2008	1	2004-11-11
3	10173	7611	2	2004-11-11
4	10173	2011	1	2004-11-11
5	10173	248	3	2004-11-11
1	10174	7750	2	2004-11-14
2	10174	4412	2	2004-11-14
3	10174	9529	2	2004-11-14
4	10174	3297	1	2004-11-14
5	10174	4093	2	2004-11-14
6	10174	9918	2	2004-11-14
7	10174	2382	2	2004-11-14
1	10175	9660	1	2004-11-08
2	10175	587	3	2004-11-08
3	10175	5798	1	2004-11-08
4	10175	8769	2	2004-11-08
5	10175	182	1	2004-11-08
6	10175	5498	1	2004-11-08
7	10175	864	1	2004-11-08
1	10176	1385	1	2004-11-21
2	10176	9738	2	2004-11-21
3	10176	8379	3	2004-11-21
4	10176	9740	1	2004-11-21
5	10176	3069	1	2004-11-21
6	10176	3548	1	2004-11-21
1	10177	478	3	2004-11-01
1	10178	2518	1	2004-11-10
2	10178	4372	2	2004-11-10
3	10178	3490	1	2004-11-10
4	10178	8657	1	2004-11-10
1	10179	5518	2	2004-11-24
2	10179	7209	2	2004-11-24
3	10179	5558	1	2004-11-24
4	10179	7631	3	2004-11-24
5	10179	2260	3	2004-11-24
6	10179	2313	2	2004-11-24
7	10179	8465	1	2004-11-24
1	10180	5263	2	2004-11-12
2	10180	8847	3	2004-11-12
3	10180	7936	1	2004-11-12
4	10180	964	2	2004-11-12
5	10180	5643	3	2004-11-12
6	10180	6633	1	2004-11-12
7	10180	6334	1	2004-11-12
8	10180	6858	2	2004-11-12
1	10181	1521	2	2004-11-23
2	10181	2793	2	2004-11-23
3	10181	1242	1	2004-11-23
4	10181	6623	2	2004-11-23
5	10181	3031	3	2004-11-23
1	10182	7927	1	2004-11-12
2	10182	4890	3	2004-11-12
3	10182	7741	1	2004-11-12
1	10183	6524	3	2004-11-24
2	10183	7546	2	2004-11-24
3	10183	1866	1	2004-11-24
4	10183	8970	2	2004-11-24
1	10184	3020	2	2004-11-23
2	10184	3788	2	2004-11-23
3	10184	2500	3	2004-11-23
4	10184	4342	2	2004-11-23
5	10184	48	1	2004-11-23
6	10184	6862	2	2004-11-23
7	10184	1159	2	2004-11-23
8	10184	5471	3	2004-11-23
1	10185	7514	1	2004-11-27
2	10185	9431	3	2004-11-27
3	10185	1742	3	2004-11-27
4	10185	2764	3	2004-11-27
5	10185	163	3	2004-11-27
1	10186	9232	2	2004-11-24
2	10186	9155	2	2004-11-24
1	10187	4141	3	2004-11-07
2	10187	3498	3	2004-11-07
3	10187	5829	1	2004-11-07
4	10187	7674	3	2004-11-07
5	10187	7971	2	2004-11-07
6	10187	9037	3	2004-11-07
7	10187	4566	1	2004-11-07
8	10187	5803	3	2004-11-07
9	10187	9964	2	2004-11-07
1	10188	9497	3	2004-11-22
2	10188	7456	3	2004-11-22
1	10189	8386	1	2004-11-06
2	10189	4797	1	2004-11-06
3	10189	1607	1	2004-11-06
4	10189	4355	3	2004-11-06
5	10189	9286	1	2004-11-06
6	10189	4467	3	2004-11-06
7	10189	9727	3	2004-11-06
8	10189	9099	2	2004-11-06
1	10190	6900	1	2004-11-20
2	10190	4805	2	2004-11-20
3	10190	9021	1	2004-11-20
4	10190	5048	1	2004-11-20
1	10191	4898	2	2004-11-06
1	10192	5783	2	2004-11-07
2	10192	8697	1	2004-11-07
3	10192	1798	3	2004-11-07
4	10192	9281	1	2004-11-07
5	10192	3953	2	2004-11-07
6	10192	9960	2	2004-11-07
1	10193	3254	2	2004-11-28
2	10193	6377	3	2004-11-28
3	10193	6084	3	2004-11-28
4	10193	1204	2	2004-11-28
1	10194	2604	1	2004-11-25
1	10195	8636	3	2004-11-20
2	10195	3769	3	2004-11-20
3	10195	8780	3	2004-11-20
4	10195	3558	3	2004-11-20
5	10195	3168	1	2004-11-20
1	10196	4365	2	2004-11-17
2	10196	7152	1	2004-11-17
3	10196	1491	3	2004-11-17
4	10196	5301	3	2004-11-17
5	10196	4456	2	2004-11-17
6	10196	28	3	2004-11-17
7	10196	6329	3	2004-11-17
8	10196	5445	1	2004-11-17
1	10197	1996	3	2004-11-07
2	10197	3510	2	2004-11-07
3	10197	7814	3	2004-11-07
4	10197	8423	2	2004-11-07
5	10197	5932	2	2004-11-07
6	10197	2261	1	2004-11-07
1	10198	7768	2	2004-11-27
1	10199	9282	2	2004-11-01
1	10200	8805	3	2004-11-21
2	10200	4526	1	2004-11-21
3	10200	7877	3	2004-11-21
4	10200	6353	2	2004-11-21
5	10200	4711	2	2004-11-21
6	10200	9101	1	2004-11-21
7	10200	184	1	2004-11-21
8	10200	939	3	2004-11-21
1	10201	7726	3	2004-11-03
2	10201	765	3	2004-11-03
3	10201	9276	1	2004-11-03
4	10201	3580	2	2004-11-03
5	10201	4772	1	2004-11-03
6	10201	4730	2	2004-11-03
7	10201	885	3	2004-11-03
8	10201	4377	3	2004-11-03
1	10202	5504	2	2004-11-22
2	10202	2642	2	2004-11-22
1	10203	5262	2	2004-11-15
2	10203	4230	1	2004-11-15
3	10203	3101	2	2004-11-15
4	10203	477	1	2004-11-15
5	10203	5040	2	2004-11-15
6	10203	8370	3	2004-11-15
1	10204	2354	3	2004-11-19
2	10204	5785	3	2004-11-19
3	10204	8493	1	2004-11-19
4	10204	1641	2	2004-11-19
5	10204	3788	2	2004-11-19
6	10204	9684	3	2004-11-19
7	10204	7862	2	2004-11-19
1	10205	6111	1	2004-11-14
2	10205	3611	2	2004-11-14
3	10205	3673	3	2004-11-14
4	10205	643	1	2004-11-14
5	10205	8462	3	2004-11-14
6	10205	5141	1	2004-11-14
7	10205	3806	3	2004-11-14
8	10205	9612	3	2004-11-14
1	10206	2101	2	2004-11-22
2	10206	3059	1	2004-11-22
3	10206	2315	1	2004-11-22
4	10206	6114	3	2004-11-22
5	10206	4044	2	2004-11-22
6	10206	5320	1	2004-11-22
7	10206	5603	3	2004-11-22
8	10206	6742	3	2004-11-22
1	10207	4166	2	2004-11-23
2	10207	7890	3	2004-11-23
3	10207	3951	3	2004-11-23
4	10207	7562	1	2004-11-23
5	10207	5607	3	2004-11-23
6	10207	9862	3	2004-11-23
1	10208	3840	2	2004-11-04
2	10208	17	3	2004-11-04
3	10208	9912	2	2004-11-04
1	10209	4791	1	2004-11-25
2	10209	2163	2	2004-11-25
3	10209	7889	2	2004-11-25
4	10209	2564	2	2004-11-25
5	10209	4301	2	2004-11-25
1	10210	9250	3	2004-11-10
2	10210	6593	1	2004-11-10
3	10210	380	2	2004-11-10
4	10210	3565	2	2004-11-10
5	10210	1689	2	2004-11-10
6	10210	2102	1	2004-11-10
7	10210	8919	1	2004-11-10
8	10210	7116	1	2004-11-10
1	10211	8013	1	2004-11-15
2	10211	3409	1	2004-11-15
3	10211	8698	3	2004-11-15
4	10211	7090	1	2004-11-15
5	10211	9571	2	2004-11-15
6	10211	864	3	2004-11-15
7	10211	2149	3	2004-11-15
1	10212	6748	2	2004-11-28
2	10212	6216	3	2004-11-28
3	10212	6830	2	2004-11-28
1	10213	5850	2	2004-11-27
2	10213	984	2	2004-11-27
3	10213	6270	2	2004-11-27
4	10213	4438	2	2004-11-27
1	10214	6216	3	2004-11-07
2	10214	490	3	2004-11-07
1	10215	2194	3	2004-11-16
2	10215	4035	3	2004-11-16
3	10215	6489	1	2004-11-16
4	10215	3543	2	2004-11-16
5	10215	4808	1	2004-11-16
6	10215	9381	1	2004-11-16
7	10215	5212	1	2004-11-16
8	10215	4520	1	2004-11-16
1	10216	485	2	2004-11-15
2	10216	8527	3	2004-11-15
3	10216	1204	3	2004-11-15
4	10216	5066	2	2004-11-15
5	10216	8576	2	2004-11-15
6	10216	5275	1	2004-11-15
7	10216	3599	3	2004-11-15
1	10217	5564	2	2004-11-28
2	10217	4582	2	2004-11-28
3	10217	5639	3	2004-11-28
1	10218	9116	3	2004-11-16
1	10219	6302	1	2004-11-21
2	10219	4463	1	2004-11-21
3	10219	8789	1	2004-11-21
4	10219	7326	2	2004-11-21
5	10219	3807	1	2004-11-21
1	10220	5704	2	2004-11-11
2	10220	8525	1	2004-11-11
3	10220	1520	2	2004-11-11
4	10220	79	3	2004-11-11
1	10221	9074	2	2004-11-13
2	10221	3037	1	2004-11-13
3	10221	9256	3	2004-11-13
4	10221	2511	2	2004-11-13
1	10222	5362	1	2004-11-03
2	10222	8954	3	2004-11-03
3	10222	3545	3	2004-11-03
4	10222	2278	3	2004-11-03
5	10222	6542	1	2004-11-03
6	10222	9534	3	2004-11-03
7	10222	4966	3	2004-11-03
8	10222	4888	3	2004-11-03
1	10223	5587	2	2004-11-03
1	10224	8560	2	2004-11-01
2	10224	4037	2	2004-11-01
3	10224	3830	3	2004-11-01
1	10225	2749	1	2004-11-18
2	10225	8667	3	2004-11-18
3	10225	1213	3	2004-11-18
4	10225	7351	2	2004-11-18
5	10225	7813	1	2004-11-18
6	10225	5465	3	2004-11-18
7	10225	4016	3	2004-11-18
8	10225	8813	3	2004-11-18
9	10225	3946	3	2004-11-18
1	10226	4842	2	2004-11-14
2	10226	8318	3	2004-11-14
3	10226	5214	2	2004-11-14
1	10227	3755	1	2004-11-05
2	10227	3494	2	2004-11-05
3	10227	478	1	2004-11-05
4	10227	1145	3	2004-11-05
1	10228	4796	2	2004-11-10
2	10228	6699	3	2004-11-10
3	10228	4919	1	2004-11-10
4	10228	7783	3	2004-11-10
5	10228	4147	1	2004-11-10
6	10228	2512	1	2004-11-10
7	10228	1296	3	2004-11-10
1	10229	6954	2	2004-11-20
1	10230	1290	1	2004-11-08
2	10230	1311	2	2004-11-08
3	10230	7545	3	2004-11-08
1	10231	1081	3	2004-11-05
2	10231	9310	3	2004-11-05
3	10231	5869	2	2004-11-05
4	10231	1487	3	2004-11-05
5	10231	5919	1	2004-11-05
6	10231	6104	1	2004-11-05
7	10231	5532	3	2004-11-05
8	10231	2839	1	2004-11-05
1	10232	8403	2	2004-11-06
2	10232	2725	3	2004-11-06
1	10233	2610	1	2004-11-26
1	10234	2553	3	2004-11-25
2	10234	992	2	2004-11-25
3	10234	5763	3	2004-11-25
4	10234	6821	1	2004-11-25
5	10234	9484	1	2004-11-25
6	10234	9040	1	2004-11-25
7	10234	4838	1	2004-11-25
1	10235	1991	2	2004-11-24
2	10235	5821	1	2004-11-24
3	10235	5820	2	2004-11-24
4	10235	644	3	2004-11-24
5	10235	6253	3	2004-11-24
6	10235	2119	3	2004-11-24
1	10236	8711	1	2004-11-20
2	10236	4309	2	2004-11-20
3	10236	2781	2	2004-11-20
4	10236	7884	1	2004-11-20
5	10236	6115	1	2004-11-20
6	10236	2858	2	2004-11-20
7	10236	491	2	2004-11-20
1	10237	3064	3	2004-11-30
2	10237	9655	2	2004-11-30
3	10237	5481	2	2004-11-30
4	10237	2577	3	2004-11-30
5	10237	3675	3	2004-11-30
6	10237	2271	3	2004-11-30
1	10238	6513	1	2004-11-20
1	10239	7118	3	2004-11-14
1	10240	88	2	2004-11-14
2	10240	84	1	2004-11-14
3	10240	1168	3	2004-11-14
4	10240	6857	2	2004-11-14
1	10241	8417	2	2004-11-17
2	10241	8146	2	2004-11-17
3	10241	7499	3	2004-11-17
4	10241	5488	2	2004-11-17
5	10241	407	3	2004-11-17
6	10241	8407	2	2004-11-17
7	10241	564	2	2004-11-17
8	10241	1946	2	2004-11-17
9	10241	3131	2	2004-11-17
1	10242	6369	1	2004-11-28
2	10242	9138	1	2004-11-28
3	10242	6757	2	2004-11-28
4	10242	2659	1	2004-11-28
5	10242	4102	1	2004-11-28
6	10242	7522	1	2004-11-28
7	10242	5874	2	2004-11-28
8	10242	133	1	2004-11-28
9	10242	9032	1	2004-11-28
1	10243	2962	3	2004-11-04
2	10243	6871	2	2004-11-04
1	10244	5586	2	2004-11-07
1	10245	9505	1	2004-11-04
2	10245	8868	2	2004-11-04
3	10245	2640	2	2004-11-04
4	10245	5853	3	2004-11-04
5	10245	1410	2	2004-11-04
6	10245	9873	1	2004-11-04
7	10245	6525	1	2004-11-04
8	10245	7880	1	2004-11-04
1	10246	6934	1	2004-11-10
2	10246	6151	2	2004-11-10
3	10246	2100	1	2004-11-10
4	10246	1925	1	2004-11-10
5	10246	6459	1	2004-11-10
6	10246	1071	2	2004-11-10
7	10246	2394	3	2004-11-10
8	10246	9569	2	2004-11-10
9	10246	6328	2	2004-11-10
1	10247	8178	3	2004-11-11
2	10247	4620	2	2004-11-11
3	10247	9743	3	2004-11-11
4	10247	6898	3	2004-11-11
1	10248	77	1	2004-11-24
2	10248	5565	1	2004-11-24
3	10248	5192	1	2004-11-24
4	10248	2832	2	2004-11-24
1	10249	258	1	2004-11-24
2	10249	2977	2	2004-11-24
3	10249	265	2	2004-11-24
4	10249	7221	3	2004-11-24
5	10249	2316	1	2004-11-24
6	10249	4500	1	2004-11-24
7	10249	9554	1	2004-11-24
1	10250	1060	2	2004-11-03
1	10251	8649	1	2004-11-09
2	10251	4170	2	2004-11-09
3	10251	5365	1	2004-11-09
4	10251	4190	2	2004-11-09
5	10251	2898	3	2004-11-09
6	10251	9425	1	2004-11-09
7	10251	1550	2	2004-11-09
8	10251	1606	2	2004-11-09
1	10252	7503	3	2004-11-26
2	10252	5270	1	2004-11-26
3	10252	7499	2	2004-11-26
4	10252	8038	1	2004-11-26
5	10252	2954	2	2004-11-26
6	10252	8120	1	2004-11-26
7	10252	5485	1	2004-11-26
8	10252	8237	1	2004-11-26
1	10253	9592	2	2004-11-08
2	10253	8719	1	2004-11-08
3	10253	2540	1	2004-11-08
4	10253	5008	1	2004-11-08
5	10253	6429	1	2004-11-08
6	10253	9063	2	2004-11-08
1	10254	662	2	2004-11-24
2	10254	5412	2	2004-11-24
3	10254	45	2	2004-11-24
4	10254	5217	2	2004-11-24
5	10254	5819	2	2004-11-24
1	10255	4033	2	2004-11-20
2	10255	8742	1	2004-11-20
3	10255	6613	1	2004-11-20
1	10256	2553	1	2004-11-10
2	10256	3435	1	2004-11-10
3	10256	5701	1	2004-11-10
4	10256	5452	2	2004-11-10
5	10256	4797	1	2004-11-10
6	10256	9977	2	2004-11-10
7	10256	4393	2	2004-11-10
8	10256	369	1	2004-11-10
9	10256	8647	3	2004-11-10
1	10257	9997	3	2004-11-27
2	10257	5471	2	2004-11-27
3	10257	9615	3	2004-11-27
1	10258	3288	1	2004-11-25
1	10259	5351	2	2004-11-04
2	10259	7348	2	2004-11-04
3	10259	1218	1	2004-11-04
4	10259	521	1	2004-11-04
5	10259	1951	3	2004-11-04
6	10259	8332	1	2004-11-04
1	10260	6258	3	2004-11-12
2	10260	300	2	2004-11-12
3	10260	7375	3	2004-11-12
4	10260	7791	2	2004-11-12
1	10261	68	3	2004-11-28
1	10262	745	2	2004-11-21
2	10262	5918	1	2004-11-21
3	10262	7671	3	2004-11-21
4	10262	433	2	2004-11-21
1	10263	7816	1	2004-11-26
2	10263	693	3	2004-11-26
1	10264	3491	2	2004-11-19
2	10264	4925	1	2004-11-19
3	10264	6300	2	2004-11-19
4	10264	8889	1	2004-11-19
1	10265	9841	1	2004-11-02
2	10265	2418	3	2004-11-02
1	10266	6976	3	2004-11-04
2	10266	1462	2	2004-11-04
3	10266	7625	1	2004-11-04
4	10266	2906	2	2004-11-04
5	10266	221	3	2004-11-04
6	10266	7525	2	2004-11-04
7	10266	5504	1	2004-11-04
8	10266	4111	1	2004-11-04
9	10266	7442	1	2004-11-04
1	10267	9004	2	2004-11-15
2	10267	5464	1	2004-11-15
3	10267	4107	2	2004-11-15
1	10268	5062	3	2004-11-13
2	10268	6039	1	2004-11-13
1	10269	8494	2	2004-11-30
2	10269	3702	2	2004-11-30
3	10269	6340	3	2004-11-30
4	10269	5801	2	2004-11-30
5	10269	812	1	2004-11-30
6	10269	1631	3	2004-11-30
7	10269	2973	1	2004-11-30
8	10269	4163	3	2004-11-30
9	10269	2056	3	2004-11-30
1	10270	7575	1	2004-11-15
2	10270	8758	2	2004-11-15
1	10271	8516	1	2004-11-11
1	10272	29	1	2004-11-12
1	10273	8408	2	2004-11-13
2	10273	6277	1	2004-11-13
3	10273	2992	3	2004-11-13
4	10273	839	3	2004-11-13
5	10273	4660	3	2004-11-13
6	10273	9126	1	2004-11-13
1	10274	6410	3	2004-11-24
2	10274	1319	2	2004-11-24
1	10275	5442	3	2004-11-29
2	10275	5353	3	2004-11-29
3	10275	8012	3	2004-11-29
4	10275	5095	2	2004-11-29
5	10275	1492	1	2004-11-29
1	10276	2465	2	2004-11-27
2	10276	6556	1	2004-11-27
3	10276	6596	2	2004-11-27
4	10276	9472	1	2004-11-27
5	10276	5553	2	2004-11-27
6	10276	846	3	2004-11-27
7	10276	807	1	2004-11-27
8	10276	2081	3	2004-11-27
9	10276	4802	3	2004-11-27
1	10277	7090	1	2004-11-16
2	10277	9551	3	2004-11-16
3	10277	3441	3	2004-11-16
1	10278	7506	2	2004-11-10
2	10278	7117	2	2004-11-10
3	10278	9157	2	2004-11-10
4	10278	6544	2	2004-11-10
5	10278	2470	3	2004-11-10
1	10279	1225	1	2004-11-05
2	10279	1183	2	2004-11-05
3	10279	2644	3	2004-11-05
4	10279	9478	3	2004-11-05
1	10280	7567	1	2004-11-01
2	10280	6811	2	2004-11-01
3	10280	6904	2	2004-11-01
4	10280	854	2	2004-11-01
1	10281	4720	1	2004-11-26
2	10281	2350	2	2004-11-26
3	10281	6354	1	2004-11-26
4	10281	9960	3	2004-11-26
5	10281	2528	1	2004-11-26
1	10282	4905	3	2004-11-12
2	10282	2429	1	2004-11-12
3	10282	3192	3	2004-11-12
4	10282	4596	1	2004-11-12
1	10283	5520	1	2004-11-18
2	10283	6791	2	2004-11-18
3	10283	7698	1	2004-11-18
4	10283	9204	1	2004-11-18
5	10283	7810	2	2004-11-18
6	10283	85	3	2004-11-18
7	10283	3135	1	2004-11-18
1	10284	459	1	2004-11-27
2	10284	7737	1	2004-11-27
3	10284	5907	1	2004-11-27
4	10284	2882	1	2004-11-27
5	10284	931	3	2004-11-27
6	10284	2002	2	2004-11-27
7	10284	5589	3	2004-11-27
8	10284	7986	1	2004-11-27
1	10285	5731	1	2004-11-11
2	10285	8409	2	2004-11-11
3	10285	9469	1	2004-11-11
1	10286	6592	3	2004-11-26
2	10286	8899	2	2004-11-26
3	10286	1948	2	2004-11-26
4	10286	5257	2	2004-11-26
5	10286	5308	2	2004-11-26
6	10286	3637	3	2004-11-26
1	10287	1604	3	2004-11-05
2	10287	5104	2	2004-11-05
3	10287	1329	1	2004-11-05
4	10287	7192	3	2004-11-05
5	10287	6650	2	2004-11-05
6	10287	1281	2	2004-11-05
7	10287	5041	3	2004-11-05
8	10287	1288	1	2004-11-05
9	10287	8943	1	2004-11-05
1	10288	5719	1	2004-11-18
2	10288	7404	3	2004-11-18
1	10289	8261	1	2004-11-23
2	10289	915	2	2004-11-23
3	10289	5676	1	2004-11-23
1	10290	9527	1	2004-11-13
1	10291	6200	1	2004-11-18
2	10291	7398	1	2004-11-18
3	10291	2977	1	2004-11-18
4	10291	3376	3	2004-11-18
5	10291	2689	1	2004-11-18
6	10291	8050	1	2004-11-18
7	10291	9619	2	2004-11-18
1	10292	1243	1	2004-11-09
2	10292	5892	2	2004-11-09
3	10292	5353	3	2004-11-09
4	10292	6289	2	2004-11-09
1	10293	9425	2	2004-11-04
2	10293	6362	3	2004-11-04
3	10293	7805	3	2004-11-04
4	10293	9212	1	2004-11-04
1	10294	2196	1	2004-11-25
2	10294	2710	2	2004-11-25
3	10294	9456	3	2004-11-25
4	10294	8577	1	2004-11-25
5	10294	2007	2	2004-11-25
6	10294	6140	3	2004-11-25
1	10295	4641	1	2004-11-08
2	10295	7747	2	2004-11-08
3	10295	7331	2	2004-11-08
4	10295	887	2	2004-11-08
1	10296	1998	3	2004-11-11
2	10296	7559	2	2004-11-11
1	10297	9790	3	2004-11-30
2	10297	7	1	2004-11-30
3	10297	2166	2	2004-11-30
4	10297	9156	2	2004-11-30
5	10297	8574	1	2004-11-30
6	10297	7977	1	2004-11-30
7	10297	3080	2	2004-11-30
8	10297	7279	1	2004-11-30
9	10297	9831	3	2004-11-30
1	10298	4754	1	2004-11-17
2	10298	137	1	2004-11-17
1	10299	9297	1	2004-11-14
2	10299	1272	3	2004-11-14
3	10299	4166	2	2004-11-14
4	10299	5448	1	2004-11-14
1	10300	7235	3	2004-11-24
2	10300	1643	2	2004-11-24
3	10300	8205	1	2004-11-24
4	10300	2679	2	2004-11-24
5	10300	4750	1	2004-11-24
6	10300	5611	3	2004-11-24
1	10301	5735	2	2004-11-04
2	10301	9230	2	2004-11-04
3	10301	6764	1	2004-11-04
4	10301	4333	1	2004-11-04
5	10301	3939	3	2004-11-04
6	10301	4250	1	2004-11-04
1	10302	6758	3	2004-11-12
1	10303	8712	2	2004-11-17
2	10303	9167	2	2004-11-17
3	10303	5168	1	2004-11-17
4	10303	69	3	2004-11-17
5	10303	6025	2	2004-11-17
6	10303	1377	2	2004-11-17
7	10303	834	3	2004-11-17
8	10303	5755	2	2004-11-17
1	10304	1575	3	2004-11-28
2	10304	2283	3	2004-11-28
3	10304	9782	3	2004-11-28
1	10305	3554	1	2004-11-27
2	10305	5401	1	2004-11-27
3	10305	7036	1	2004-11-27
4	10305	3090	3	2004-11-27
5	10305	7552	3	2004-11-27
6	10305	2907	3	2004-11-27
7	10305	4367	2	2004-11-27
8	10305	7069	1	2004-11-27
9	10305	8907	2	2004-11-27
1	10306	2600	1	2004-11-30
2	10306	765	1	2004-11-30
1	10307	9319	1	2004-11-03
2	10307	7494	2	2004-11-03
3	10307	3984	2	2004-11-03
4	10307	5289	3	2004-11-03
5	10307	1632	1	2004-11-03
1	10308	8279	3	2004-11-19
1	10309	1038	2	2004-11-03
1	10310	6019	3	2004-11-06
2	10310	2224	2	2004-11-06
3	10310	1722	1	2004-11-06
1	10311	3744	1	2004-11-15
2	10311	6048	2	2004-11-15
3	10311	4390	1	2004-11-15
4	10311	9913	2	2004-11-15
5	10311	2789	3	2004-11-15
6	10311	4992	2	2004-11-15
7	10311	5376	3	2004-11-15
8	10311	3952	2	2004-11-15
9	10311	4392	2	2004-11-15
1	10312	7499	1	2004-11-01
2	10312	9796	3	2004-11-01
3	10312	2235	2	2004-11-01
4	10312	8435	3	2004-11-01
5	10312	3761	1	2004-11-01
6	10312	47	3	2004-11-01
1	10313	593	2	2004-11-23
2	10313	5657	2	2004-11-23
3	10313	8295	1	2004-11-23
4	10313	5548	1	2004-11-23
5	10313	7445	3	2004-11-23
6	10313	8074	3	2004-11-23
7	10313	495	2	2004-11-23
1	10314	7213	3	2004-11-11
2	10314	8143	2	2004-11-11
3	10314	7966	1	2004-11-11
4	10314	7825	3	2004-11-11
1	10315	2843	1	2004-11-06
2	10315	8585	3	2004-11-06
3	10315	8623	3	2004-11-06
4	10315	9531	2	2004-11-06
1	10316	4469	2	2004-11-28
2	10316	3740	3	2004-11-28
3	10316	2595	1	2004-11-28
4	10316	1388	3	2004-11-28
5	10316	443	3	2004-11-28
6	10316	5454	3	2004-11-28
7	10316	1433	1	2004-11-28
1	10317	6897	1	2004-11-20
2	10317	1906	2	2004-11-20
3	10317	9997	1	2004-11-20
4	10317	2359	3	2004-11-20
5	10317	4699	1	2004-11-20
6	10317	6502	3	2004-11-20
7	10317	8681	1	2004-11-20
8	10317	3410	1	2004-11-20
1	10318	5812	2	2004-11-28
1	10319	4544	3	2004-11-30
2	10319	4493	1	2004-11-30
1	10320	6869	2	2004-11-23
2	10320	9964	3	2004-11-23
3	10320	4220	2	2004-11-23
4	10320	711	1	2004-11-23
5	10320	3469	3	2004-11-23
6	10320	1691	3	2004-11-23
7	10320	1811	1	2004-11-23
8	10320	2883	2	2004-11-23
9	10320	1078	3	2004-11-23
1	10321	2344	2	2004-11-28
2	10321	9946	3	2004-11-28
1	10322	6910	2	2004-11-24
2	10322	7091	3	2004-11-24
3	10322	4321	1	2004-11-24
1	10323	4422	2	2004-11-05
2	10323	1881	2	2004-11-05
3	10323	4413	2	2004-11-05
4	10323	1436	2	2004-11-05
5	10323	3457	1	2004-11-05
1	10324	7919	1	2004-11-20
2	10324	5666	2	2004-11-20
3	10324	9178	2	2004-11-20
4	10324	8019	2	2004-11-20
5	10324	8983	2	2004-11-20
6	10324	2961	1	2004-11-20
7	10324	6420	2	2004-11-20
8	10324	8334	3	2004-11-20
1	10325	8987	2	2004-11-29
2	10325	6141	1	2004-11-29
1	10326	3013	1	2004-11-07
2	10326	7389	1	2004-11-07
3	10326	4356	1	2004-11-07
4	10326	6552	2	2004-11-07
5	10326	6943	2	2004-11-07
6	10326	9622	2	2004-11-07
7	10326	9679	1	2004-11-07
8	10326	9228	2	2004-11-07
1	10327	316	3	2004-11-22
2	10327	7951	3	2004-11-22
3	10327	3305	2	2004-11-22
4	10327	9723	2	2004-11-22
5	10327	3688	1	2004-11-22
6	10327	3939	3	2004-11-22
1	10328	4381	2	2004-11-10
2	10328	1161	1	2004-11-10
3	10328	8752	1	2004-11-10
4	10328	7249	3	2004-11-10
5	10328	3364	2	2004-11-10
6	10328	4528	1	2004-11-10
7	10328	4038	3	2004-11-10
1	10329	3655	3	2004-11-22
2	10329	9054	2	2004-11-22
3	10329	4479	1	2004-11-22
4	10329	3996	3	2004-11-22
5	10329	9442	3	2004-11-22
1	10330	1255	2	2004-11-30
2	10330	5448	1	2004-11-30
3	10330	6834	1	2004-11-30
4	10330	8437	1	2004-11-30
1	10331	2041	3	2004-11-28
2	10331	7563	3	2004-11-28
3	10331	2612	1	2004-11-28
1	10332	4407	3	2004-11-21
2	10332	9833	2	2004-11-21
1	10333	3702	1	2004-11-18
1	10334	1846	1	2004-11-21
2	10334	3830	1	2004-11-21
3	10334	3583	2	2004-11-21
4	10334	4229	2	2004-11-21
1	10335	3007	1	2004-11-07
2	10335	6392	3	2004-11-07
3	10335	1813	1	2004-11-07
4	10335	6189	1	2004-11-07
5	10335	4646	1	2004-11-07
1	10336	7740	3	2004-11-04
2	10336	4074	3	2004-11-04
3	10336	3222	2	2004-11-04
4	10336	539	3	2004-11-04
5	10336	6938	2	2004-11-04
1	10337	2956	1	2004-11-05
2	10337	8358	2	2004-11-05
3	10337	3602	2	2004-11-05
4	10337	3563	2	2004-11-05
1	10338	1793	3	2004-11-17
1	10339	4171	3	2004-11-18
2	10339	3418	3	2004-11-18
3	10339	3197	2	2004-11-18
4	10339	4443	1	2004-11-18
1	10340	9590	2	2004-11-25
2	10340	1028	3	2004-11-25
3	10340	218	2	2004-11-25
4	10340	2696	2	2004-11-25
5	10340	42	3	2004-11-25
6	10340	3531	3	2004-11-25
7	10340	8434	2	2004-11-25
8	10340	5381	2	2004-11-25
1	10341	5863	1	2004-11-30
2	10341	1467	3	2004-11-30
3	10341	5062	2	2004-11-30
4	10341	9193	1	2004-11-30
1	10342	4748	1	2004-11-06
2	10342	9405	2	2004-11-06
1	10343	343	1	2004-11-20
2	10343	3760	3	2004-11-20
3	10343	7599	3	2004-11-20
4	10343	2968	3	2004-11-20
5	10343	7725	1	2004-11-20
6	10343	1579	2	2004-11-20
1	10344	8954	1	2004-11-06
2	10344	9961	1	2004-11-06
3	10344	2332	1	2004-11-06
4	10344	2278	3	2004-11-06
5	10344	2912	1	2004-11-06
6	10344	2045	3	2004-11-06
7	10344	3783	1	2004-11-06
1	10345	2901	1	2004-11-19
2	10345	9087	2	2004-11-19
3	10345	8168	3	2004-11-19
4	10345	6523	3	2004-11-19
5	10345	399	3	2004-11-19
6	10345	2792	1	2004-11-19
7	10345	5105	1	2004-11-19
8	10345	4885	2	2004-11-19
9	10345	2567	3	2004-11-19
1	10346	6526	2	2004-11-18
2	10346	8428	1	2004-11-18
3	10346	7129	2	2004-11-18
4	10346	4433	1	2004-11-18
5	10346	4562	3	2004-11-18
6	10346	857	2	2004-11-18
7	10346	3202	3	2004-11-18
8	10346	460	3	2004-11-18
9	10346	8771	1	2004-11-18
1	10347	3308	3	2004-11-25
2	10347	8177	2	2004-11-25
3	10347	6003	2	2004-11-25
1	10348	6636	1	2004-11-03
2	10348	7552	2	2004-11-03
3	10348	6107	1	2004-11-03
4	10348	3957	1	2004-11-03
5	10348	9319	2	2004-11-03
6	10348	4317	1	2004-11-03
7	10348	3838	2	2004-11-03
1	10349	4172	3	2004-11-07
1	10350	3353	2	2004-11-11
2	10350	5704	2	2004-11-11
1	10351	259	3	2004-11-14
2	10351	5024	2	2004-11-14
1	10352	3795	1	2004-11-03
1	10353	241	1	2004-11-09
2	10353	5184	2	2004-11-09
3	10353	1295	3	2004-11-09
4	10353	1891	3	2004-11-09
5	10353	86	2	2004-11-09
1	10354	4556	1	2004-11-12
2	10354	9831	2	2004-11-12
3	10354	9493	2	2004-11-12
4	10354	1179	1	2004-11-12
5	10354	3834	3	2004-11-12
6	10354	511	3	2004-11-12
7	10354	9560	1	2004-11-12
8	10354	5260	2	2004-11-12
1	10355	9913	3	2004-11-25
2	10355	1861	1	2004-11-25
3	10355	8357	1	2004-11-25
1	10356	873	1	2004-11-22
2	10356	6987	1	2004-11-22
3	10356	7105	2	2004-11-22
4	10356	5557	3	2004-11-22
5	10356	6822	3	2004-11-22
6	10356	6494	3	2004-11-22
1	10357	1738	3	2004-11-22
2	10357	7779	3	2004-11-22
3	10357	1978	3	2004-11-22
1	10358	5784	2	2004-11-24
2	10358	8574	2	2004-11-24
3	10358	2899	3	2004-11-24
4	10358	5809	3	2004-11-24
5	10358	150	1	2004-11-24
6	10358	6365	2	2004-11-24
1	10359	520	1	2004-11-04
2	10359	3743	1	2004-11-04
3	10359	4391	2	2004-11-04
4	10359	9714	1	2004-11-04
5	10359	4659	1	2004-11-04
6	10359	9860	1	2004-11-04
7	10359	5529	3	2004-11-04
1	10360	4832	3	2004-11-27
2	10360	6867	1	2004-11-27
3	10360	8677	3	2004-11-27
4	10360	3554	2	2004-11-27
5	10360	2721	2	2004-11-27
6	10360	8228	3	2004-11-27
7	10360	2440	3	2004-11-27
1	10361	1663	3	2004-11-30
2	10361	6489	2	2004-11-30
3	10361	1204	2	2004-11-30
4	10361	8896	3	2004-11-30
1	10362	5162	1	2004-11-18
2	10362	383	1	2004-11-18
1	10363	4100	1	2004-11-11
2	10363	1821	1	2004-11-11
3	10363	9580	2	2004-11-11
4	10363	1075	3	2004-11-11
5	10363	442	1	2004-11-11
6	10363	3828	1	2004-11-11
7	10363	386	1	2004-11-11
1	10364	8322	1	2004-11-26
2	10364	5063	2	2004-11-26
3	10364	3955	1	2004-11-26
4	10364	9243	2	2004-11-26
5	10364	2252	1	2004-11-26
6	10364	3396	1	2004-11-26
7	10364	9830	3	2004-11-26
1	10365	5910	1	2004-11-10
2	10365	2146	2	2004-11-10
3	10365	1772	2	2004-11-10
1	10366	3746	1	2004-11-26
2	10366	4202	1	2004-11-26
3	10366	5314	3	2004-11-26
4	10366	8434	3	2004-11-26
5	10366	9488	3	2004-11-26
6	10366	3606	1	2004-11-26
7	10366	436	3	2004-11-26
1	10367	1915	2	2004-11-10
2	10367	8728	3	2004-11-10
3	10367	5220	1	2004-11-10
4	10367	4176	3	2004-11-10
5	10367	6846	1	2004-11-10
6	10367	9148	1	2004-11-10
1	10368	4961	1	2004-11-29
2	10368	2977	2	2004-11-29
3	10368	668	1	2004-11-29
4	10368	1069	2	2004-11-29
1	10369	1769	2	2004-11-13
2	10369	3326	2	2004-11-13
3	10369	94	1	2004-11-13
4	10369	1509	2	2004-11-13
5	10369	2927	2	2004-11-13
6	10369	2304	3	2004-11-13
7	10369	8315	1	2004-11-13
1	10370	1541	3	2004-11-09
2	10370	390	2	2004-11-09
3	10370	2699	1	2004-11-09
4	10370	6982	2	2004-11-09
5	10370	5330	1	2004-11-09
6	10370	5272	2	2004-11-09
7	10370	8419	3	2004-11-09
8	10370	2376	1	2004-11-09
9	10370	724	1	2004-11-09
1	10371	7916	1	2004-11-12
2	10371	6496	2	2004-11-12
3	10371	1537	3	2004-11-12
4	10371	4058	2	2004-11-12
5	10371	8393	2	2004-11-12
6	10371	5186	3	2004-11-12
7	10371	116	3	2004-11-12
1	10372	8280	3	2004-11-30
2	10372	1772	3	2004-11-30
3	10372	3963	2	2004-11-30
4	10372	8442	2	2004-11-30
5	10372	6617	1	2004-11-30
1	10373	4484	2	2004-11-21
2	10373	1066	2	2004-11-21
3	10373	4860	2	2004-11-21
4	10373	1900	1	2004-11-21
5	10373	721	3	2004-11-21
1	10374	7933	2	2004-11-07
2	10374	7041	2	2004-11-07
1	10375	2960	1	2004-11-11
2	10375	2190	3	2004-11-11
3	10375	3590	3	2004-11-11
4	10375	3975	1	2004-11-11
5	10375	3943	3	2004-11-11
6	10375	8010	2	2004-11-11
7	10375	4477	1	2004-11-11
1	10376	3462	3	2004-11-01
1	10377	5051	3	2004-11-06
2	10377	5832	3	2004-11-06
3	10377	5884	3	2004-11-06
4	10377	6097	3	2004-11-06
5	10377	94	3	2004-11-06
6	10377	8420	2	2004-11-06
7	10377	7395	1	2004-11-06
8	10377	6235	1	2004-11-06
9	10377	852	2	2004-11-06
1	10378	1705	1	2004-11-20
2	10378	7326	2	2004-11-20
3	10378	1394	3	2004-11-20
4	10378	3597	1	2004-11-20
5	10378	8633	3	2004-11-20
6	10378	8495	2	2004-11-20
1	10379	3222	1	2004-11-22
2	10379	1623	1	2004-11-22
3	10379	6983	3	2004-11-22
4	10379	4035	1	2004-11-22
1	10380	214	2	2004-11-02
2	10380	3172	1	2004-11-02
3	10380	7812	1	2004-11-02
4	10380	7084	3	2004-11-02
5	10380	9510	1	2004-11-02
6	10380	629	3	2004-11-02
7	10380	9328	3	2004-11-02
1	10381	9905	3	2004-11-08
2	10381	9114	1	2004-11-08
3	10381	8364	2	2004-11-08
4	10381	544	1	2004-11-08
5	10381	9314	1	2004-11-08
6	10381	7284	3	2004-11-08
1	10382	9415	3	2004-11-23
1	10383	7179	3	2004-11-04
1	10384	3075	1	2004-11-27
2	10384	7336	1	2004-11-27
1	10385	2546	2	2004-11-26
2	10385	9104	1	2004-11-26
3	10385	5947	2	2004-11-26
4	10385	8635	2	2004-11-26
5	10385	3885	3	2004-11-26
6	10385	4307	1	2004-11-26
7	10385	9149	2	2004-11-26
1	10386	6513	2	2004-11-30
2	10386	3482	2	2004-11-30
3	10386	6782	2	2004-11-30
4	10386	6252	2	2004-11-30
5	10386	9535	2	2004-11-30
6	10386	567	2	2004-11-30
7	10386	1300	1	2004-11-30
1	10387	6791	2	2004-11-28
2	10387	8576	1	2004-11-28
3	10387	3590	1	2004-11-28
4	10387	3974	1	2004-11-28
5	10387	8453	2	2004-11-28
1	10388	55	2	2004-11-01
2	10388	1401	3	2004-11-01
3	10388	785	3	2004-11-01
4	10388	953	1	2004-11-01
5	10388	2246	1	2004-11-01
6	10388	4359	2	2004-11-01
7	10388	4630	2	2004-11-01
1	10389	3205	3	2004-11-12
1	10390	9533	3	2004-11-05
2	10390	9159	3	2004-11-05
3	10390	3191	3	2004-11-05
4	10390	6557	1	2004-11-05
5	10390	4134	3	2004-11-05
1	10391	5238	3	2004-11-01
1	10392	3045	2	2004-11-08
2	10392	6783	1	2004-11-08
3	10392	6085	3	2004-11-08
4	10392	8587	3	2004-11-08
5	10392	6781	3	2004-11-08
6	10392	2884	2	2004-11-08
7	10392	6923	1	2004-11-08
1	10393	3359	2	2004-11-19
2	10393	614	2	2004-11-19
3	10393	999	2	2004-11-19
1	10394	5832	2	2004-11-14
2	10394	4210	3	2004-11-14
3	10394	820	1	2004-11-14
4	10394	403	3	2004-11-14
5	10394	979	3	2004-11-14
6	10394	4402	3	2004-11-14
7	10394	7517	3	2004-11-14
1	10395	4553	1	2004-11-13
1	10396	1352	3	2004-11-09
2	10396	9664	2	2004-11-09
3	10396	4588	2	2004-11-09
4	10396	2854	1	2004-11-09
1	10397	8055	3	2004-11-28
1	10398	6791	2	2004-11-21
2	10398	8623	1	2004-11-21
1	10399	9223	2	2004-11-02
2	10399	3107	2	2004-11-02
3	10399	7306	2	2004-11-02
4	10399	4928	3	2004-11-02
5	10399	285	3	2004-11-02
1	10400	200	3	2004-11-03
2	10400	9953	3	2004-11-03
3	10400	8926	3	2004-11-03
4	10400	7287	3	2004-11-03
5	10400	8227	2	2004-11-03
6	10400	3815	3	2004-11-03
7	10400	4940	2	2004-11-03
8	10400	4799	2	2004-11-03
9	10400	9652	2	2004-11-03
1	10401	7217	2	2004-11-30
2	10401	4111	3	2004-11-30
3	10401	5038	2	2004-11-30
4	10401	639	2	2004-11-30
5	10401	4739	1	2004-11-30
6	10401	4199	2	2004-11-30
7	10401	9093	1	2004-11-30
1	10402	457	2	2004-11-05
2	10402	6656	2	2004-11-05
3	10402	9007	1	2004-11-05
4	10402	1370	3	2004-11-05
5	10402	5474	1	2004-11-05
6	10402	1417	2	2004-11-05
7	10402	8348	3	2004-11-05
8	10402	1593	1	2004-11-05
9	10402	6134	2	2004-11-05
1	10403	7611	2	2004-11-22
2	10403	6704	3	2004-11-22
1	10404	8091	2	2004-11-27
2	10404	4207	2	2004-11-27
3	10404	8937	1	2004-11-27
4	10404	6200	1	2004-11-27
5	10404	1871	1	2004-11-27
6	10404	1513	1	2004-11-27
7	10404	7743	3	2004-11-27
8	10404	1921	3	2004-11-27
9	10404	2318	3	2004-11-27
1	10405	1606	1	2004-11-18
2	10405	3366	3	2004-11-18
3	10405	9141	1	2004-11-18
4	10405	6594	1	2004-11-18
5	10405	1946	2	2004-11-18
6	10405	5764	2	2004-11-18
7	10405	9430	2	2004-11-18
1	10406	7302	2	2004-11-29
2	10406	4523	2	2004-11-29
1	10407	4498	1	2004-11-20
2	10407	8289	3	2004-11-20
3	10407	7913	3	2004-11-20
4	10407	1761	1	2004-11-20
5	10407	8204	1	2004-11-20
6	10407	3566	2	2004-11-20
7	10407	3126	2	2004-11-20
8	10407	9481	3	2004-11-20
1	10408	4538	3	2004-11-05
1	10409	6883	1	2004-11-07
2	10409	3228	1	2004-11-07
3	10409	188	3	2004-11-07
4	10409	1609	3	2004-11-07
5	10409	7049	3	2004-11-07
6	10409	8370	3	2004-11-07
7	10409	799	2	2004-11-07
1	10410	9875	1	2004-11-30
2	10410	1725	1	2004-11-30
3	10410	9760	2	2004-11-30
1	10411	6136	3	2004-11-08
2	10411	1611	1	2004-11-08
3	10411	515	2	2004-11-08
4	10411	4281	1	2004-11-08
5	10411	2563	2	2004-11-08
1	10412	8420	2	2004-11-28
2	10412	4122	3	2004-11-28
3	10412	572	2	2004-11-28
4	10412	966	1	2004-11-28
5	10412	6342	1	2004-11-28
6	10412	1984	2	2004-11-28
7	10412	8005	2	2004-11-28
1	10413	936	1	2004-11-02
2	10413	9552	1	2004-11-02
3	10413	5823	2	2004-11-02
4	10413	2153	3	2004-11-02
5	10413	9721	1	2004-11-02
6	10413	7996	2	2004-11-02
1	10414	4545	1	2004-11-27
2	10414	8493	2	2004-11-27
3	10414	2355	2	2004-11-27
1	10415	8887	1	2004-11-25
2	10415	8119	3	2004-11-25
3	10415	7865	3	2004-11-25
4	10415	9245	3	2004-11-25
5	10415	505	2	2004-11-25
6	10415	1248	1	2004-11-25
1	10416	6099	1	2004-11-11
2	10416	7863	3	2004-11-11
1	10417	7918	1	2004-11-18
2	10417	9194	2	2004-11-18
3	10417	6039	1	2004-11-18
4	10417	2326	2	2004-11-18
1	10418	9498	1	2004-11-05
2	10418	6741	1	2004-11-05
3	10418	7496	3	2004-11-05
4	10418	2659	1	2004-11-05
5	10418	8957	2	2004-11-05
6	10418	2396	2	2004-11-05
7	10418	9514	1	2004-11-05
8	10418	2492	2	2004-11-05
9	10418	2665	1	2004-11-05
1	10419	6702	3	2004-11-30
2	10419	9063	3	2004-11-30
3	10419	4499	1	2004-11-30
4	10419	9470	3	2004-11-30
5	10419	9847	3	2004-11-30
6	10419	112	2	2004-11-30
7	10419	8970	3	2004-11-30
8	10419	4575	1	2004-11-30
9	10419	8556	2	2004-11-30
1	10420	1208	1	2004-11-25
2	10420	3169	2	2004-11-25
3	10420	2915	1	2004-11-25
4	10420	4454	2	2004-11-25
5	10420	1844	1	2004-11-25
6	10420	6024	1	2004-11-25
7	10420	182	1	2004-11-25
8	10420	1428	3	2004-11-25
1	10421	7861	3	2004-11-25
2	10421	5924	1	2004-11-25
3	10421	9217	2	2004-11-25
4	10421	5967	3	2004-11-25
5	10421	5430	2	2004-11-25
6	10421	5278	2	2004-11-25
7	10421	5633	3	2004-11-25
8	10421	510	3	2004-11-25
1	10422	6118	1	2004-11-05
2	10422	4104	2	2004-11-05
3	10422	1543	2	2004-11-05
1	10423	8064	2	2004-11-18
2	10423	2157	2	2004-11-18
3	10423	7101	1	2004-11-18
4	10423	8467	1	2004-11-18
5	10423	8863	2	2004-11-18
1	10424	2587	1	2004-11-23
2	10424	1800	2	2004-11-23
3	10424	6005	3	2004-11-23
1	10425	8421	3	2004-11-22
2	10425	6774	2	2004-11-22
1	10426	8244	1	2004-11-28
2	10426	1159	2	2004-11-28
3	10426	2468	3	2004-11-28
4	10426	8411	1	2004-11-28
5	10426	3522	2	2004-11-28
6	10426	5471	2	2004-11-28
7	10426	9284	3	2004-11-28
1	10427	7880	3	2004-11-16
1	10428	5059	3	2004-11-10
2	10428	6016	2	2004-11-10
1	10429	6049	1	2004-11-03
2	10429	4320	3	2004-11-03
3	10429	2123	1	2004-11-03
4	10429	9847	2	2004-11-03
5	10429	8761	2	2004-11-03
6	10429	9698	3	2004-11-03
7	10429	3374	2	2004-11-03
8	10429	9127	2	2004-11-03
9	10429	5896	3	2004-11-03
1	10430	764	3	2004-11-14
2	10430	2041	3	2004-11-14
3	10430	1929	1	2004-11-14
4	10430	1732	1	2004-11-14
5	10430	1748	3	2004-11-14
1	10431	8798	2	2004-11-18
2	10431	3530	3	2004-11-18
3	10431	1461	1	2004-11-18
4	10431	5602	2	2004-11-18
5	10431	8022	2	2004-11-18
6	10431	206	2	2004-11-18
7	10431	1734	2	2004-11-18
8	10431	3035	2	2004-11-18
1	10432	577	2	2004-11-29
2	10432	4414	1	2004-11-29
1	10433	2229	2	2004-11-23
2	10433	1043	1	2004-11-23
3	10433	2529	2	2004-11-23
1	10434	8824	2	2004-11-26
2	10434	8913	3	2004-11-26
3	10434	9738	1	2004-11-26
4	10434	3744	1	2004-11-26
1	10435	4986	3	2004-11-16
2	10435	1407	3	2004-11-16
3	10435	9454	3	2004-11-16
4	10435	5562	3	2004-11-16
5	10435	1956	3	2004-11-16
6	10435	5928	1	2004-11-16
7	10435	8817	3	2004-11-16
1	10436	1585	1	2004-11-23
2	10436	1192	1	2004-11-23
3	10436	299	1	2004-11-23
4	10436	1142	2	2004-11-23
5	10436	3701	2	2004-11-23
1	10437	7417	2	2004-11-23
2	10437	1772	3	2004-11-23
3	10437	3710	3	2004-11-23
1	10438	8665	2	2004-11-20
2	10438	798	2	2004-11-20
3	10438	1340	1	2004-11-20
1	10439	3421	2	2004-11-05
2	10439	3726	2	2004-11-05
3	10439	8854	3	2004-11-05
1	10440	8613	2	2004-11-03
2	10440	9201	1	2004-11-03
3	10440	1982	1	2004-11-03
4	10440	7718	3	2004-11-03
1	10441	6780	1	2004-11-26
2	10441	3474	3	2004-11-26
3	10441	4775	2	2004-11-26
4	10441	1043	3	2004-11-26
5	10441	7877	2	2004-11-26
6	10441	4099	1	2004-11-26
7	10441	9025	1	2004-11-26
1	10442	4101	3	2004-11-28
2	10442	1835	1	2004-11-28
3	10442	8188	2	2004-11-28
4	10442	6210	2	2004-11-28
5	10442	2210	2	2004-11-28
6	10442	8746	1	2004-11-28
7	10442	2024	2	2004-11-28
1	10443	578	2	2004-11-14
2	10443	8537	3	2004-11-14
3	10443	9150	1	2004-11-14
4	10443	55	3	2004-11-14
5	10443	5587	3	2004-11-14
6	10443	7985	2	2004-11-14
7	10443	5805	1	2004-11-14
8	10443	2582	3	2004-11-14
9	10443	5386	1	2004-11-14
1	10444	6380	2	2004-11-05
2	10444	6608	3	2004-11-05
3	10444	945	1	2004-11-05
4	10444	3902	2	2004-11-05
1	10445	2932	3	2004-11-01
2	10445	1504	1	2004-11-01
3	10445	6600	3	2004-11-01
4	10445	2069	2	2004-11-01
5	10445	1868	3	2004-11-01
6	10445	6670	2	2004-11-01
7	10445	5513	1	2004-11-01
8	10445	5218	3	2004-11-01
1	10446	7310	3	2004-11-11
1	10447	2843	3	2004-11-26
2	10447	6813	1	2004-11-26
3	10447	7521	3	2004-11-26
1	10448	6114	2	2004-11-02
2	10448	1727	3	2004-11-02
3	10448	2673	3	2004-11-02
4	10448	2430	3	2004-11-02
5	10448	450	3	2004-11-02
6	10448	5151	2	2004-11-02
7	10448	9538	2	2004-11-02
1	10449	5102	1	2004-11-13
2	10449	4898	3	2004-11-13
3	10449	9993	1	2004-11-13
1	10450	6538	2	2004-11-01
1	10451	632	1	2004-11-24
2	10451	7869	1	2004-11-24
3	10451	9842	3	2004-11-24
4	10451	707	2	2004-11-24
5	10451	2419	1	2004-11-24
6	10451	774	2	2004-11-24
7	10451	7091	2	2004-11-24
8	10451	9111	1	2004-11-24
9	10451	5133	2	2004-11-24
1	10452	2638	3	2004-11-01
1	10453	1826	1	2004-11-03
2	10453	8023	1	2004-11-03
3	10453	1998	2	2004-11-03
4	10453	5518	1	2004-11-03
5	10453	4211	2	2004-11-03
6	10453	6831	2	2004-11-03
7	10453	6468	3	2004-11-03
8	10453	3177	2	2004-11-03
1	10454	6295	2	2004-11-05
2	10454	1653	1	2004-11-05
3	10454	6082	2	2004-11-05
4	10454	9184	3	2004-11-05
5	10454	3466	1	2004-11-05
6	10454	5433	2	2004-11-05
1	10455	9347	1	2004-11-03
2	10455	4717	2	2004-11-03
3	10455	9489	1	2004-11-03
1	10456	9514	1	2004-11-01
2	10456	5649	2	2004-11-01
3	10456	7076	1	2004-11-01
4	10456	1149	3	2004-11-01
1	10457	4114	2	2004-11-12
2	10457	3680	3	2004-11-12
3	10457	1776	2	2004-11-12
1	10458	2789	1	2004-11-10
2	10458	5904	1	2004-11-10
3	10458	3701	2	2004-11-10
1	10459	3398	2	2004-11-25
2	10459	3010	1	2004-11-25
3	10459	7041	2	2004-11-25
4	10459	9202	1	2004-11-25
5	10459	1389	1	2004-11-25
6	10459	4135	2	2004-11-25
7	10459	8704	3	2004-11-25
1	10460	3	3	2004-11-16
2	10460	398	1	2004-11-16
3	10460	1967	2	2004-11-16
4	10460	5068	2	2004-11-16
5	10460	2389	1	2004-11-16
6	10460	8520	1	2004-11-16
7	10460	1047	1	2004-11-16
8	10460	6936	2	2004-11-16
1	10461	4971	3	2004-11-08
2	10461	3812	3	2004-11-08
1	10462	2995	3	2004-11-16
1	10463	5788	1	2004-11-25
2	10463	4901	1	2004-11-25
3	10463	6741	3	2004-11-25
4	10463	4155	2	2004-11-25
5	10463	9127	2	2004-11-25
6	10463	7177	2	2004-11-25
7	10463	9257	3	2004-11-25
8	10463	37	3	2004-11-25
1	10464	4113	1	2004-11-04
2	10464	7484	1	2004-11-04
3	10464	2329	1	2004-11-04
4	10464	325	1	2004-11-04
5	10464	3475	3	2004-11-04
1	10465	118	3	2004-11-28
2	10465	1319	2	2004-11-28
3	10465	2502	1	2004-11-28
4	10465	9474	3	2004-11-28
1	10466	6200	1	2004-11-20
2	10466	1552	1	2004-11-20
3	10466	5371	2	2004-11-20
4	10466	5447	1	2004-11-20
5	10466	6695	3	2004-11-20
6	10466	3333	3	2004-11-20
1	10467	6070	3	2004-11-25
2	10467	1466	2	2004-11-25
3	10467	4193	1	2004-11-25
4	10467	460	3	2004-11-25
5	10467	3230	3	2004-11-25
6	10467	6373	3	2004-11-25
7	10467	8663	2	2004-11-25
1	10468	8133	1	2004-11-19
2	10468	3495	2	2004-11-19
3	10468	4243	1	2004-11-19
4	10468	1355	3	2004-11-19
5	10468	7209	3	2004-11-19
6	10468	4382	2	2004-11-19
7	10468	7096	1	2004-11-19
8	10468	608	3	2004-11-19
1	10469	1496	2	2004-11-20
2	10469	7030	3	2004-11-20
3	10469	4310	2	2004-11-20
4	10469	3484	1	2004-11-20
5	10469	554	3	2004-11-20
6	10469	8421	3	2004-11-20
7	10469	889	1	2004-11-20
1	10470	2706	3	2004-11-07
2	10470	3281	3	2004-11-07
3	10470	2971	1	2004-11-07
4	10470	7538	2	2004-11-07
1	10471	1273	3	2004-11-27
1	10472	3995	1	2004-11-15
2	10472	9751	2	2004-11-15
3	10472	725	3	2004-11-15
4	10472	3235	1	2004-11-15
5	10472	87	2	2004-11-15
6	10472	6745	1	2004-11-15
7	10472	9121	3	2004-11-15
8	10472	1505	1	2004-11-15
9	10472	6536	2	2004-11-15
1	10473	8249	2	2004-11-09
2	10473	1993	3	2004-11-09
1	10474	6007	1	2004-11-19
2	10474	5269	2	2004-11-19
3	10474	6368	2	2004-11-19
4	10474	3929	3	2004-11-19
1	10475	6207	2	2004-11-23
2	10475	3801	3	2004-11-23
3	10475	6625	1	2004-11-23
4	10475	2187	3	2004-11-23
1	10476	6670	1	2004-11-14
2	10476	2180	1	2004-11-14
3	10476	9953	1	2004-11-14
1	10477	1717	3	2004-11-22
2	10477	8280	2	2004-11-22
3	10477	7793	2	2004-11-22
1	10478	7119	2	2004-11-29
2	10478	3580	2	2004-11-29
3	10478	4374	2	2004-11-29
4	10478	3145	3	2004-11-29
5	10478	6005	2	2004-11-29
6	10478	1442	1	2004-11-29
1	10479	3626	1	2004-11-23
2	10479	3278	2	2004-11-23
3	10479	4952	2	2004-11-23
4	10479	3641	1	2004-11-23
5	10479	641	1	2004-11-23
6	10479	9118	1	2004-11-23
7	10479	4329	3	2004-11-23
1	10480	5190	3	2004-11-19
2	10480	5515	3	2004-11-19
3	10480	6549	1	2004-11-19
4	10480	2593	3	2004-11-19
5	10480	4192	3	2004-11-19
6	10480	1613	3	2004-11-19
7	10480	7278	2	2004-11-19
8	10480	2504	1	2004-11-19
9	10480	688	3	2004-11-19
1	10481	5762	3	2004-11-17
2	10481	6492	1	2004-11-17
3	10481	9158	1	2004-11-17
4	10481	1536	1	2004-11-17
5	10481	2410	3	2004-11-17
6	10481	316	3	2004-11-17
1	10482	4855	2	2004-11-16
2	10482	7612	2	2004-11-16
3	10482	3474	2	2004-11-16
4	10482	1705	2	2004-11-16
5	10482	5444	1	2004-11-16
6	10482	3433	1	2004-11-16
7	10482	6721	2	2004-11-16
1	10483	2572	1	2004-11-22
2	10483	6336	2	2004-11-22
3	10483	5631	3	2004-11-22
4	10483	833	2	2004-11-22
1	10484	3544	3	2004-11-21
2	10484	9747	1	2004-11-21
3	10484	4131	1	2004-11-21
4	10484	6044	2	2004-11-21
5	10484	9197	1	2004-11-21
6	10484	8229	1	2004-11-21
1	10485	7431	1	2004-11-08
2	10485	3337	1	2004-11-08
3	10485	3751	3	2004-11-08
4	10485	4109	3	2004-11-08
5	10485	8417	2	2004-11-08
6	10485	5326	2	2004-11-08
7	10485	833	3	2004-11-08
8	10485	1198	2	2004-11-08
9	10485	5799	1	2004-11-08
1	10486	5765	2	2004-11-17
2	10486	3061	2	2004-11-17
1	10487	5203	2	2004-11-18
2	10487	3406	3	2004-11-18
3	10487	6374	3	2004-11-18
1	10488	5425	1	2004-11-25
2	10488	1714	2	2004-11-25
3	10488	9997	1	2004-11-25
4	10488	634	2	2004-11-25
5	10488	3855	2	2004-11-25
6	10488	5724	3	2004-11-25
1	10489	5481	3	2004-11-24
1	10490	794	2	2004-11-20
2	10490	83	3	2004-11-20
1	10491	4922	1	2004-11-02
2	10491	9061	2	2004-11-02
3	10491	9332	3	2004-11-02
4	10491	9546	3	2004-11-02
5	10491	4851	2	2004-11-02
6	10491	6129	1	2004-11-02
7	10491	1417	2	2004-11-02
1	10492	159	1	2004-11-07
2	10492	1965	1	2004-11-07
3	10492	2551	1	2004-11-07
4	10492	3767	1	2004-11-07
5	10492	9927	2	2004-11-07
6	10492	928	3	2004-11-07
7	10492	1628	2	2004-11-07
1	10493	9744	1	2004-11-02
2	10493	9946	2	2004-11-02
3	10493	5430	2	2004-11-02
4	10493	5170	3	2004-11-02
5	10493	9943	3	2004-11-02
6	10493	9640	2	2004-11-02
7	10493	4775	3	2004-11-02
8	10493	5618	3	2004-11-02
9	10493	59	3	2004-11-02
1	10494	8255	1	2004-11-29
2	10494	7001	3	2004-11-29
3	10494	7579	3	2004-11-29
4	10494	570	1	2004-11-29
5	10494	7632	1	2004-11-29
6	10494	2092	3	2004-11-29
7	10494	4908	3	2004-11-29
8	10494	3653	1	2004-11-29
9	10494	4368	2	2004-11-29
1	10495	3806	2	2004-11-22
2	10495	8823	2	2004-11-22
1	10496	7745	2	2004-11-06
2	10496	4522	2	2004-11-06
3	10496	5826	1	2004-11-06
1	10497	6708	2	2004-11-08
1	10498	1693	2	2004-11-23
2	10498	4852	3	2004-11-23
1	10499	6879	3	2004-11-01
2	10499	7819	3	2004-11-01
3	10499	8227	2	2004-11-01
4	10499	1662	2	2004-11-01
1	10500	8283	1	2004-11-05
2	10500	3671	1	2004-11-05
3	10500	3138	1	2004-11-05
4	10500	4697	1	2004-11-05
5	10500	1994	2	2004-11-05
6	10500	1999	2	2004-11-05
7	10500	2612	3	2004-11-05
1	10501	6714	3	2004-11-09
2	10501	3676	2	2004-11-09
3	10501	5654	1	2004-11-09
4	10501	40	3	2004-11-09
1	10502	8768	1	2004-11-24
2	10502	1698	1	2004-11-24
3	10502	2224	2	2004-11-24
4	10502	2816	3	2004-11-24
5	10502	5577	2	2004-11-24
6	10502	3392	3	2004-11-24
7	10502	8494	2	2004-11-24
8	10502	4425	1	2004-11-24
1	10503	1116	3	2004-11-27
2	10503	9	3	2004-11-27
3	10503	526	1	2004-11-27
4	10503	4085	3	2004-11-27
5	10503	1539	3	2004-11-27
1	10504	2744	1	2004-11-21
2	10504	3517	2	2004-11-21
3	10504	8506	3	2004-11-21
4	10504	369	1	2004-11-21
5	10504	6668	3	2004-11-21
6	10504	7900	1	2004-11-21
7	10504	42	2	2004-11-21
8	10504	5423	2	2004-11-21
1	10505	3307	2	2004-11-07
2	10505	2196	3	2004-11-07
1	10506	4041	2	2004-11-08
2	10506	8204	3	2004-11-08
3	10506	5921	1	2004-11-08
4	10506	2344	2	2004-11-08
5	10506	814	1	2004-11-08
6	10506	6324	3	2004-11-08
7	10506	1574	2	2004-11-08
8	10506	8574	1	2004-11-08
9	10506	887	2	2004-11-08
1	10507	5174	2	2004-11-20
1	10508	1104	2	2004-11-14
2	10508	6420	2	2004-11-14
3	10508	539	2	2004-11-14
4	10508	1929	2	2004-11-14
5	10508	6344	2	2004-11-14
6	10508	886	3	2004-11-14
7	10508	6984	3	2004-11-14
1	10509	174	1	2004-11-14
2	10509	7207	3	2004-11-14
3	10509	5345	3	2004-11-14
1	10510	7888	1	2004-11-22
2	10510	8260	3	2004-11-22
1	10511	9302	2	2004-11-28
2	10511	6013	2	2004-11-28
3	10511	336	3	2004-11-28
4	10511	2802	3	2004-11-28
5	10511	4108	3	2004-11-28
6	10511	5877	2	2004-11-28
7	10511	651	2	2004-11-28
8	10511	7860	3	2004-11-28
9	10511	2829	1	2004-11-28
1	10512	1191	1	2004-11-17
2	10512	9988	3	2004-11-17
3	10512	601	3	2004-11-17
4	10512	4130	2	2004-11-17
5	10512	8555	2	2004-11-17
6	10512	799	2	2004-11-17
7	10512	9077	1	2004-11-17
1	10513	9318	2	2004-11-05
2	10513	1114	3	2004-11-05
3	10513	378	3	2004-11-05
4	10513	7825	1	2004-11-05
5	10513	2177	2	2004-11-05
6	10513	3036	2	2004-11-05
1	10514	3677	3	2004-11-02
1	10515	1239	2	2004-11-29
2	10515	2709	1	2004-11-29
3	10515	4775	2	2004-11-29
4	10515	2194	1	2004-11-29
5	10515	9747	1	2004-11-29
6	10515	7556	1	2004-11-29
7	10515	1479	3	2004-11-29
8	10515	9832	3	2004-11-29
1	10516	7906	1	2004-11-04
2	10516	8401	2	2004-11-04
3	10516	3909	1	2004-11-04
4	10516	3520	2	2004-11-04
1	10517	3	2	2004-11-30
2	10517	1437	2	2004-11-30
1	10518	5141	2	2004-11-26
2	10518	9124	2	2004-11-26
3	10518	3495	3	2004-11-26
4	10518	5924	2	2004-11-26
5	10518	963	3	2004-11-26
6	10518	8809	3	2004-11-26
7	10518	1973	3	2004-11-26
8	10518	4281	2	2004-11-26
1	10519	4163	1	2004-11-28
2	10519	293	2	2004-11-28
3	10519	5356	1	2004-11-28
4	10519	8943	2	2004-11-28
5	10519	5360	3	2004-11-28
6	10519	2137	1	2004-11-28
7	10519	2509	1	2004-11-28
8	10519	7120	2	2004-11-28
9	10519	216	1	2004-11-28
1	10520	47	2	2004-11-02
2	10520	6655	2	2004-11-02
3	10520	9546	2	2004-11-02
4	10520	2128	3	2004-11-02
5	10520	5113	2	2004-11-02
6	10520	9933	2	2004-11-02
7	10520	456	2	2004-11-02
8	10520	7135	3	2004-11-02
9	10520	9161	1	2004-11-02
1	10521	2558	1	2004-11-20
2	10521	4857	1	2004-11-20
3	10521	3157	2	2004-11-20
4	10521	3951	2	2004-11-20
5	10521	4939	2	2004-11-20
6	10521	8514	1	2004-11-20
7	10521	8324	3	2004-11-20
8	10521	7535	1	2004-11-20
1	10522	8053	3	2004-11-21
2	10522	2199	2	2004-11-21
3	10522	6595	1	2004-11-21
4	10522	7682	1	2004-11-21
5	10522	2657	1	2004-11-21
6	10522	1794	2	2004-11-21
7	10522	789	2	2004-11-21
1	10523	8795	3	2004-11-24
2	10523	5933	3	2004-11-24
1	10524	4708	1	2004-11-27
2	10524	8857	1	2004-11-27
3	10524	9258	3	2004-11-27
4	10524	8646	1	2004-11-27
5	10524	2097	2	2004-11-27
6	10524	2816	3	2004-11-27
1	10525	686	1	2004-11-25
2	10525	6625	3	2004-11-25
3	10525	5186	3	2004-11-25
4	10525	608	2	2004-11-25
5	10525	5849	2	2004-11-25
6	10525	1289	2	2004-11-25
7	10525	796	2	2004-11-25
8	10525	732	2	2004-11-25
9	10525	9002	3	2004-11-25
1	10526	9715	3	2004-11-21
2	10526	838	1	2004-11-21
3	10526	8370	3	2004-11-21
4	10526	8003	3	2004-11-21
5	10526	8993	3	2004-11-21
6	10526	63	2	2004-11-21
1	10527	9230	1	2004-11-23
2	10527	4506	1	2004-11-23
3	10527	4757	2	2004-11-23
4	10527	7173	2	2004-11-23
5	10527	804	2	2004-11-23
6	10527	5076	3	2004-11-23
7	10527	4433	1	2004-11-23
8	10527	3353	2	2004-11-23
1	10528	3208	2	2004-11-01
2	10528	7358	1	2004-11-01
3	10528	3368	3	2004-11-01
4	10528	7818	1	2004-11-01
5	10528	2669	1	2004-11-01
6	10528	8693	1	2004-11-01
7	10528	2437	1	2004-11-01
8	10528	2416	3	2004-11-01
1	10529	5763	3	2004-11-26
2	10529	7060	1	2004-11-26
3	10529	9330	1	2004-11-26
4	10529	4342	3	2004-11-26
5	10529	4601	1	2004-11-26
6	10529	8030	3	2004-11-26
7	10529	5699	2	2004-11-26
8	10529	9	3	2004-11-26
9	10529	2807	3	2004-11-26
1	10530	7374	1	2004-11-30
2	10530	1684	3	2004-11-30
3	10530	9658	1	2004-11-30
4	10530	9377	1	2004-11-30
5	10530	9488	2	2004-11-30
6	10530	96	2	2004-11-30
7	10530	5334	3	2004-11-30
8	10530	6958	3	2004-11-30
1	10531	9368	2	2004-11-27
2	10531	2337	3	2004-11-27
3	10531	5460	2	2004-11-27
4	10531	7202	2	2004-11-27
5	10531	619	3	2004-11-27
6	10531	3737	3	2004-11-27
7	10531	9696	2	2004-11-27
1	10532	1692	2	2004-11-24
2	10532	2297	1	2004-11-24
3	10532	1638	3	2004-11-24
4	10532	1212	3	2004-11-24
5	10532	7306	1	2004-11-24
6	10532	154	3	2004-11-24
7	10532	7081	3	2004-11-24
1	10533	4560	2	2004-11-14
2	10533	5105	2	2004-11-14
3	10533	3329	3	2004-11-14
4	10533	3170	1	2004-11-14
5	10533	4262	1	2004-11-14
6	10533	2377	3	2004-11-14
7	10533	8108	2	2004-11-14
8	10533	4958	1	2004-11-14
9	10533	5855	2	2004-11-14
1	10534	7197	2	2004-11-25
2	10534	3339	2	2004-11-25
3	10534	4864	3	2004-11-25
4	10534	3693	2	2004-11-25
5	10534	7585	3	2004-11-25
1	10535	1532	2	2004-11-30
2	10535	6212	2	2004-11-30
3	10535	7550	3	2004-11-30
1	10536	6060	3	2004-11-17
1	10537	9432	1	2004-11-22
2	10537	7744	1	2004-11-22
3	10537	7049	1	2004-11-22
1	10538	8994	2	2004-11-02
2	10538	777	1	2004-11-02
3	10538	9414	1	2004-11-02
4	10538	9023	2	2004-11-02
5	10538	8101	2	2004-11-02
6	10538	4214	2	2004-11-02
7	10538	2229	3	2004-11-02
8	10538	4376	3	2004-11-02
1	10539	3987	1	2004-11-17
1	10540	4338	2	2004-11-12
1	10541	6932	2	2004-11-05
1	10542	1971	2	2004-11-09
2	10542	8530	2	2004-11-09
1	10543	9046	3	2004-11-25
2	10543	4076	1	2004-11-25
3	10543	9386	3	2004-11-25
1	10544	3888	2	2004-11-10
2	10544	2908	2	2004-11-10
3	10544	4835	2	2004-11-10
4	10544	5915	1	2004-11-10
5	10544	27	3	2004-11-10
6	10544	8112	2	2004-11-10
7	10544	807	1	2004-11-10
8	10544	637	3	2004-11-10
1	10545	1240	3	2004-11-19
2	10545	7750	2	2004-11-19
3	10545	566	3	2004-11-19
4	10545	3378	2	2004-11-19
5	10545	248	1	2004-11-19
6	10545	1628	2	2004-11-19
7	10545	7300	2	2004-11-19
8	10545	9540	1	2004-11-19
9	10545	614	2	2004-11-19
1	10546	6921	2	2004-11-12
2	10546	2094	3	2004-11-12
1	10547	7678	3	2004-11-14
2	10547	3677	2	2004-11-14
3	10547	2862	2	2004-11-14
4	10547	2563	2	2004-11-14
5	10547	8047	1	2004-11-14
1	10548	4209	2	2004-11-29
2	10548	8842	2	2004-11-29
3	10548	1940	1	2004-11-29
4	10548	5462	2	2004-11-29
5	10548	4754	1	2004-11-29
6	10548	1353	3	2004-11-29
7	10548	9939	2	2004-11-29
1	10549	3793	2	2004-11-16
2	10549	8310	2	2004-11-16
3	10549	8253	1	2004-11-16
1	10550	5973	1	2004-11-09
2	10550	9010	1	2004-11-09
3	10550	7113	3	2004-11-09
1	10551	5294	2	2004-11-16
1	10552	2444	3	2004-11-09
2	10552	9031	1	2004-11-09
3	10552	284	1	2004-11-09
1	10553	9467	1	2004-11-21
2	10553	1341	1	2004-11-21
3	10553	4673	3	2004-11-21
4	10553	3777	2	2004-11-21
5	10553	7494	1	2004-11-21
1	10554	2960	2	2004-11-05
2	10554	7474	2	2004-11-05
1	10555	7070	3	2004-11-06
2	10555	7103	3	2004-11-06
3	10555	445	2	2004-11-06
4	10555	5947	3	2004-11-06
1	10556	8562	3	2004-11-27
1	10557	3226	1	2004-11-23
2	10557	7575	1	2004-11-23
3	10557	4308	1	2004-11-23
4	10557	8399	1	2004-11-23
5	10557	6340	1	2004-11-23
1	10558	2551	1	2004-11-05
2	10558	5872	1	2004-11-05
3	10558	5596	1	2004-11-05
4	10558	2918	2	2004-11-05
5	10558	7232	2	2004-11-05
6	10558	4804	2	2004-11-05
7	10558	2176	1	2004-11-05
8	10558	8131	1	2004-11-05
1	10559	4523	3	2004-11-23
2	10559	5579	1	2004-11-23
3	10559	1092	1	2004-11-23
4	10559	3200	1	2004-11-23
5	10559	6848	3	2004-11-23
1	10560	2394	2	2004-11-04
2	10560	8751	2	2004-11-04
3	10560	9632	2	2004-11-04
4	10560	522	2	2004-11-04
5	10560	1776	1	2004-11-04
6	10560	6825	3	2004-11-04
7	10560	5521	2	2004-11-04
1	10561	9835	2	2004-11-04
2	10561	8707	1	2004-11-04
3	10561	6835	1	2004-11-04
4	10561	3468	2	2004-11-04
5	10561	9709	2	2004-11-04
6	10561	3080	3	2004-11-04
1	10562	785	2	2004-11-05
1	10563	4004	2	2004-11-19
2	10563	7874	3	2004-11-19
3	10563	9500	3	2004-11-19
4	10563	49	3	2004-11-19
5	10563	4923	3	2004-11-19
6	10563	3755	2	2004-11-19
7	10563	810	1	2004-11-19
8	10563	5535	2	2004-11-19
1	10564	4457	1	2004-11-13
2	10564	2825	3	2004-11-13
3	10564	475	2	2004-11-13
4	10564	2720	3	2004-11-13
5	10564	4916	1	2004-11-13
6	10564	4635	3	2004-11-13
7	10564	6307	1	2004-11-13
1	10565	4645	2	2004-11-26
2	10565	8375	3	2004-11-26
3	10565	197	3	2004-11-26
4	10565	8990	2	2004-11-26
5	10565	3461	1	2004-11-26
6	10565	974	1	2004-11-26
7	10565	612	2	2004-11-26
8	10565	2531	2	2004-11-26
1	10566	9672	1	2004-11-13
2	10566	8024	2	2004-11-13
3	10566	881	2	2004-11-13
4	10566	6815	3	2004-11-13
5	10566	137	3	2004-11-13
6	10566	7816	2	2004-11-13
7	10566	5028	2	2004-11-13
1	10567	955	3	2004-11-10
2	10567	5431	1	2004-11-10
1	10568	9480	1	2004-11-04
2	10568	6635	2	2004-11-04
3	10568	8486	2	2004-11-04
4	10568	8488	2	2004-11-04
1	10569	8693	1	2004-11-02
2	10569	5886	2	2004-11-02
3	10569	5759	1	2004-11-02
4	10569	2698	3	2004-11-02
5	10569	6137	3	2004-11-02
6	10569	1110	3	2004-11-02
7	10569	6905	2	2004-11-02
1	10570	1634	1	2004-11-28
2	10570	7943	3	2004-11-28
3	10570	8589	2	2004-11-28
4	10570	4574	3	2004-11-28
5	10570	2938	2	2004-11-28
6	10570	6445	2	2004-11-28
1	10571	1645	1	2004-11-08
2	10571	9409	2	2004-11-08
3	10571	9453	2	2004-11-08
4	10571	2414	1	2004-11-08
5	10571	2638	3	2004-11-08
6	10571	7103	1	2004-11-08
7	10571	7323	3	2004-11-08
8	10571	8038	3	2004-11-08
1	10572	2408	1	2004-11-06
1	10573	9123	3	2004-11-23
2	10573	8995	2	2004-11-23
3	10573	8089	1	2004-11-23
4	10573	4389	3	2004-11-23
1	10574	4404	2	2004-11-15
2	10574	6713	1	2004-11-15
3	10574	7339	2	2004-11-15
4	10574	1193	2	2004-11-15
5	10574	2992	1	2004-11-15
6	10574	1356	1	2004-11-15
7	10574	3279	2	2004-11-15
1	10575	4549	3	2004-11-07
2	10575	8588	2	2004-11-07
3	10575	2107	3	2004-11-07
4	10575	4182	2	2004-11-07
5	10575	4174	3	2004-11-07
6	10575	336	3	2004-11-07
7	10575	6557	2	2004-11-07
8	10575	2898	1	2004-11-07
9	10575	6246	1	2004-11-07
1	10576	379	3	2004-11-22
1	10577	4348	3	2004-11-02
2	10577	1520	3	2004-11-02
3	10577	8068	1	2004-11-02
1	10578	6669	1	2004-11-08
2	10578	5784	3	2004-11-08
3	10578	8173	1	2004-11-08
4	10578	1745	1	2004-11-08
5	10578	5610	3	2004-11-08
6	10578	1306	1	2004-11-08
1	10579	3885	2	2004-11-17
2	10579	9462	2	2004-11-17
3	10579	6244	2	2004-11-17
4	10579	4454	3	2004-11-17
5	10579	2706	1	2004-11-17
6	10579	7870	2	2004-11-17
1	10580	5609	3	2004-11-09
2	10580	6369	2	2004-11-09
3	10580	9891	3	2004-11-09
4	10580	4852	2	2004-11-09
5	10580	6103	2	2004-11-09
6	10580	8415	1	2004-11-09
7	10580	3076	1	2004-11-09
8	10580	7334	3	2004-11-09
9	10580	5343	3	2004-11-09
1	10581	9349	1	2004-11-05
2	10581	8550	3	2004-11-05
3	10581	8454	1	2004-11-05
4	10581	1871	1	2004-11-05
5	10581	610	3	2004-11-05
6	10581	7771	3	2004-11-05
1	10582	3162	1	2004-11-04
2	10582	2271	1	2004-11-04
3	10582	2722	2	2004-11-04
4	10582	3201	1	2004-11-04
5	10582	2307	3	2004-11-04
6	10582	6849	2	2004-11-04
1	10583	761	3	2004-11-01
2	10583	6696	3	2004-11-01
3	10583	9705	3	2004-11-01
4	10583	9435	1	2004-11-01
5	10583	6045	3	2004-11-01
6	10583	7293	3	2004-11-01
7	10583	4866	1	2004-11-01
8	10583	3419	3	2004-11-01
9	10583	3577	2	2004-11-01
1	10584	6353	2	2004-11-29
2	10584	1348	1	2004-11-29
3	10584	7223	1	2004-11-29
1	10585	5593	3	2004-11-02
2	10585	629	2	2004-11-02
1	10586	7268	1	2004-11-19
2	10586	9567	1	2004-11-19
3	10586	5288	1	2004-11-19
1	10587	5162	3	2004-11-01
2	10587	2571	1	2004-11-01
3	10587	3052	2	2004-11-01
4	10587	4715	1	2004-11-01
5	10587	5396	2	2004-11-01
6	10587	7408	2	2004-11-01
7	10587	6783	1	2004-11-01
8	10587	4001	3	2004-11-01
9	10587	8299	1	2004-11-01
1	10588	6814	1	2004-11-23
2	10588	6875	1	2004-11-23
3	10588	5028	3	2004-11-23
4	10588	965	2	2004-11-23
5	10588	6802	2	2004-11-23
1	10589	3291	1	2004-11-11
2	10589	6740	3	2004-11-11
3	10589	7723	2	2004-11-11
4	10589	5036	2	2004-11-11
5	10589	7147	3	2004-11-11
6	10589	1916	2	2004-11-11
1	10590	4131	2	2004-11-28
2	10590	3771	1	2004-11-28
1	10591	2502	2	2004-11-25
2	10591	5361	2	2004-11-25
3	10591	4216	1	2004-11-25
4	10591	2379	3	2004-11-25
5	10591	5355	3	2004-11-25
6	10591	6192	1	2004-11-25
7	10591	3265	1	2004-11-25
8	10591	7583	1	2004-11-25
9	10591	264	3	2004-11-25
1	10592	1244	1	2004-11-18
2	10592	1380	2	2004-11-18
3	10592	4023	3	2004-11-18
4	10592	3813	1	2004-11-18
5	10592	8885	2	2004-11-18
1	10593	7245	2	2004-11-21
2	10593	8629	1	2004-11-21
1	10594	6048	1	2004-11-12
2	10594	7401	2	2004-11-12
3	10594	2758	1	2004-11-12
4	10594	5827	1	2004-11-12
5	10594	8467	3	2004-11-12
6	10594	4663	3	2004-11-12
7	10594	2084	3	2004-11-12
1	10595	2211	3	2004-11-29
2	10595	2624	2	2004-11-29
3	10595	8778	3	2004-11-29
4	10595	9046	3	2004-11-29
5	10595	2469	1	2004-11-29
6	10595	2226	3	2004-11-29
7	10595	9760	3	2004-11-29
8	10595	1405	3	2004-11-29
1	10596	5807	3	2004-11-14
1	10597	9154	3	2004-11-23
2	10597	5459	3	2004-11-23
3	10597	6603	3	2004-11-23
4	10597	7558	3	2004-11-23
5	10597	2108	2	2004-11-23
6	10597	9095	1	2004-11-23
7	10597	3741	1	2004-11-23
8	10597	3923	2	2004-11-23
9	10597	9708	2	2004-11-23
1	10598	5274	1	2004-11-13
2	10598	9234	1	2004-11-13
3	10598	138	3	2004-11-13
4	10598	1548	3	2004-11-13
5	10598	6276	1	2004-11-13
6	10598	7088	1	2004-11-13
7	10598	604	2	2004-11-13
8	10598	9404	3	2004-11-13
1	10599	2663	3	2004-11-09
2	10599	3574	2	2004-11-09
1	10600	4394	1	2004-11-13
2	10600	7264	3	2004-11-13
3	10600	2364	2	2004-11-13
4	10600	746	1	2004-11-13
5	10600	3211	1	2004-11-13
6	10600	1366	3	2004-11-13
7	10600	2996	3	2004-11-13
8	10600	1221	2	2004-11-13
1	10601	2134	2	2004-11-07
2	10601	7070	2	2004-11-07
3	10601	4491	1	2004-11-07
4	10601	1382	3	2004-11-07
5	10601	3924	1	2004-11-07
1	10602	7984	2	2004-11-22
2	10602	893	3	2004-11-22
3	10602	7622	2	2004-11-22
4	10602	1024	3	2004-11-22
1	10603	7618	3	2004-11-11
2	10603	5434	3	2004-11-11
3	10603	4644	3	2004-11-11
4	10603	5632	1	2004-11-11
5	10603	2365	1	2004-11-11
1	10604	5395	2	2004-11-08
2	10604	4596	3	2004-11-08
3	10604	343	1	2004-11-08
4	10604	3273	1	2004-11-08
5	10604	1309	1	2004-11-08
6	10604	5339	1	2004-11-08
1	10605	3739	2	2004-11-30
2	10605	6907	3	2004-11-30
3	10605	3345	1	2004-11-30
4	10605	6740	3	2004-11-30
5	10605	3262	3	2004-11-30
6	10605	9098	2	2004-11-30
7	10605	2850	3	2004-11-30
1	10606	6397	2	2004-11-06
2	10606	9070	3	2004-11-06
3	10606	5437	1	2004-11-06
4	10606	563	1	2004-11-06
5	10606	2710	1	2004-11-06
6	10606	9704	3	2004-11-06
1	10607	2614	2	2004-11-24
2	10607	6221	3	2004-11-24
3	10607	5348	3	2004-11-24
4	10607	8458	2	2004-11-24
5	10607	5099	1	2004-11-24
1	10608	3484	2	2004-11-08
2	10608	419	1	2004-11-08
3	10608	5617	2	2004-11-08
4	10608	2932	2	2004-11-08
5	10608	6632	2	2004-11-08
6	10608	6623	2	2004-11-08
1	10609	9059	1	2004-11-15
2	10609	4102	2	2004-11-15
3	10609	1745	3	2004-11-15
4	10609	4761	1	2004-11-15
5	10609	3895	3	2004-11-15
6	10609	1509	2	2004-11-15
7	10609	6853	1	2004-11-15
1	10610	2890	1	2004-11-08
2	10610	8744	2	2004-11-08
3	10610	8805	2	2004-11-08
1	10611	9814	1	2004-11-05
2	10611	3893	3	2004-11-05
3	10611	3877	3	2004-11-05
4	10611	4151	2	2004-11-05
5	10611	7444	3	2004-11-05
6	10611	5823	1	2004-11-05
1	10612	8391	1	2004-11-27
2	10612	5959	2	2004-11-27
3	10612	2949	3	2004-11-27
4	10612	8025	1	2004-11-27
5	10612	4670	3	2004-11-27
6	10612	7067	2	2004-11-27
1	10613	262	2	2004-11-07
2	10613	940	2	2004-11-07
1	10614	4003	2	2004-11-13
2	10614	2965	1	2004-11-13
1	10615	617	2	2004-11-09
2	10615	6701	2	2004-11-09
1	10616	1553	1	2004-11-10
2	10616	4005	2	2004-11-10
3	10616	1099	2	2004-11-10
4	10616	5876	1	2004-11-10
5	10616	2488	3	2004-11-10
6	10616	5499	3	2004-11-10
7	10616	1907	2	2004-11-10
8	10616	8296	2	2004-11-10
1	10617	1816	3	2004-11-03
2	10617	5052	1	2004-11-03
3	10617	1433	1	2004-11-03
4	10617	5997	2	2004-11-03
1	10618	3576	2	2004-11-20
2	10618	1837	2	2004-11-20
3	10618	2813	3	2004-11-20
4	10618	6034	2	2004-11-20
5	10618	4528	1	2004-11-20
6	10618	1970	2	2004-11-20
7	10618	6790	1	2004-11-20
8	10618	2342	3	2004-11-20
1	10619	8102	2	2004-11-05
2	10619	5773	3	2004-11-05
3	10619	8182	1	2004-11-05
4	10619	4170	2	2004-11-05
1	10620	3192	2	2004-11-10
2	10620	1271	2	2004-11-10
3	10620	2237	3	2004-11-10
4	10620	1305	3	2004-11-10
5	10620	8838	1	2004-11-10
6	10620	3198	2	2004-11-10
1	10621	6563	2	2004-11-11
2	10621	8407	2	2004-11-11
3	10621	1061	2	2004-11-11
4	10621	4198	3	2004-11-11
5	10621	5948	3	2004-11-11
1	10622	5566	3	2004-11-12
2	10622	1112	3	2004-11-12
3	10622	4242	2	2004-11-12
4	10622	4142	2	2004-11-12
5	10622	112	1	2004-11-12
6	10622	8821	1	2004-11-12
1	10623	7426	2	2004-11-26
2	10623	6491	2	2004-11-26
1	10624	6794	2	2004-11-01
2	10624	2639	1	2004-11-01
3	10624	4930	3	2004-11-01
4	10624	7280	1	2004-11-01
1	10625	1739	1	2004-11-18
1	10626	5159	1	2004-11-18
2	10626	6891	2	2004-11-18
3	10626	4917	2	2004-11-18
4	10626	9417	1	2004-11-18
5	10626	150	3	2004-11-18
1	10627	6123	2	2004-11-27
2	10627	6444	1	2004-11-27
3	10627	4087	2	2004-11-27
4	10627	1547	1	2004-11-27
5	10627	2115	3	2004-11-27
6	10627	174	2	2004-11-27
1	10628	414	1	2004-11-02
2	10628	7861	3	2004-11-02
3	10628	4868	1	2004-11-02
4	10628	1622	2	2004-11-02
5	10628	4184	1	2004-11-02
1	10629	8894	3	2004-11-12
2	10629	3940	2	2004-11-12
3	10629	9106	3	2004-11-12
4	10629	9061	1	2004-11-12
5	10629	8035	1	2004-11-12
6	10629	9532	3	2004-11-12
7	10629	5029	3	2004-11-12
1	10630	1592	1	2004-11-13
2	10630	1810	2	2004-11-13
3	10630	5326	2	2004-11-13
4	10630	743	3	2004-11-13
5	10630	5202	2	2004-11-13
1	10631	5189	2	2004-11-08
2	10631	6882	2	2004-11-08
1	10632	7119	2	2004-11-13
2	10632	263	1	2004-11-13
1	10633	8860	2	2004-11-14
2	10633	1597	1	2004-11-14
3	10633	928	3	2004-11-14
4	10633	4101	1	2004-11-14
5	10633	6431	3	2004-11-14
6	10633	6188	3	2004-11-14
7	10633	6437	3	2004-11-14
8	10633	627	1	2004-11-14
9	10633	4237	3	2004-11-14
1	10634	312	1	2004-11-18
1	10635	4929	2	2004-11-17
2	10635	8756	2	2004-11-17
3	10635	61	1	2004-11-17
4	10635	4458	1	2004-11-17
5	10635	7274	3	2004-11-17
6	10635	2658	2	2004-11-17
7	10635	7861	3	2004-11-17
8	10635	2786	2	2004-11-17
9	10635	7087	2	2004-11-17
1	10636	9580	2	2004-11-18
2	10636	2709	3	2004-11-18
1	10637	7761	2	2004-11-15
2	10637	3246	2	2004-11-15
3	10637	9182	1	2004-11-15
4	10637	6868	2	2004-11-15
5	10637	4293	2	2004-11-15
6	10637	2198	3	2004-11-15
7	10637	7844	1	2004-11-15
1	10638	4041	1	2004-11-18
2	10638	4204	2	2004-11-18
3	10638	2120	2	2004-11-18
1	10639	2884	2	2004-11-28
2	10639	1921	1	2004-11-28
3	10639	9534	2	2004-11-28
4	10639	7160	3	2004-11-28
1	10640	8168	2	2004-11-26
2	10640	9714	2	2004-11-26
3	10640	4611	2	2004-11-26
1	10641	9245	1	2004-11-20
1	10642	6194	1	2004-11-17
2	10642	9236	3	2004-11-17
3	10642	4192	1	2004-11-17
4	10642	9720	2	2004-11-17
5	10642	6322	3	2004-11-17
1	10643	7556	3	2004-11-08
2	10643	9348	3	2004-11-08
3	10643	5085	2	2004-11-08
4	10643	2778	1	2004-11-08
5	10643	2926	1	2004-11-08
1	10644	3534	1	2004-11-08
2	10644	3013	3	2004-11-08
3	10644	187	1	2004-11-08
4	10644	8803	2	2004-11-08
5	10644	3404	3	2004-11-08
6	10644	8103	3	2004-11-08
7	10644	5402	1	2004-11-08
8	10644	4517	2	2004-11-08
1	10645	9342	1	2004-11-17
2	10645	8646	1	2004-11-17
3	10645	2191	1	2004-11-17
4	10645	3286	2	2004-11-17
5	10645	3740	3	2004-11-17
1	10646	7000	3	2004-11-08
2	10646	7900	2	2004-11-08
3	10646	1744	1	2004-11-08
4	10646	4325	3	2004-11-08
5	10646	1027	3	2004-11-08
6	10646	389	2	2004-11-08
1	10647	414	3	2004-11-19
2	10647	1882	3	2004-11-19
1	10648	8667	2	2004-11-28
2	10648	9406	1	2004-11-28
3	10648	1642	2	2004-11-28
1	10649	4444	2	2004-11-21
2	10649	6160	3	2004-11-21
3	10649	5541	3	2004-11-21
4	10649	8495	2	2004-11-21
5	10649	2730	2	2004-11-21
1	10650	7302	3	2004-11-05
2	10650	1129	2	2004-11-05
1	10651	6127	3	2004-11-06
1	10652	6409	3	2004-11-06
2	10652	3687	1	2004-11-06
3	10652	4377	3	2004-11-06
4	10652	9620	3	2004-11-06
5	10652	7032	3	2004-11-06
6	10652	5846	3	2004-11-06
7	10652	2643	3	2004-11-06
8	10652	107	3	2004-11-06
1	10653	3786	3	2004-11-29
1	10654	671	1	2004-11-08
2	10654	6352	2	2004-11-08
3	10654	9579	1	2004-11-08
4	10654	4083	1	2004-11-08
5	10654	3612	3	2004-11-08
6	10654	3111	1	2004-11-08
7	10654	8376	1	2004-11-08
8	10654	1344	2	2004-11-08
1	10655	2574	1	2004-11-30
1	10656	7301	2	2004-11-23
2	10656	3729	2	2004-11-23
1	10657	9800	2	2004-11-10
2	10657	2148	2	2004-11-10
3	10657	9772	2	2004-11-10
4	10657	2342	1	2004-11-10
5	10657	8990	1	2004-11-10
6	10657	3025	1	2004-11-10
7	10657	4938	1	2004-11-10
8	10657	4319	2	2004-11-10
9	10657	2938	3	2004-11-10
1	10658	1560	1	2004-11-24
2	10658	4399	2	2004-11-24
3	10658	9361	3	2004-11-24
4	10658	9687	2	2004-11-24
5	10658	6824	3	2004-11-24
6	10658	2797	3	2004-11-24
7	10658	3369	1	2004-11-24
8	10658	4731	2	2004-11-24
9	10658	5451	2	2004-11-24
1	10659	1403	3	2004-11-20
2	10659	8023	2	2004-11-20
1	10660	5923	2	2004-11-16
2	10660	4326	1	2004-11-16
1	10661	9975	2	2004-11-05
2	10661	716	1	2004-11-05
1	10662	9793	1	2004-11-11
2	10662	2000	2	2004-11-11
3	10662	9265	2	2004-11-11
4	10662	7582	1	2004-11-11
5	10662	4423	2	2004-11-11
6	10662	5008	3	2004-11-11
7	10662	1580	3	2004-11-11
8	10662	829	3	2004-11-11
1	10663	8840	2	2004-11-18
2	10663	8732	3	2004-11-18
3	10663	160	3	2004-11-18
4	10663	1586	2	2004-11-18
5	10663	3531	3	2004-11-18
6	10663	1992	1	2004-11-18
7	10663	7714	2	2004-11-18
1	10664	7645	2	2004-11-29
2	10664	2727	1	2004-11-29
3	10664	4151	2	2004-11-29
4	10664	2357	2	2004-11-29
5	10664	1808	3	2004-11-29
6	10664	134	3	2004-11-29
7	10664	5819	3	2004-11-29
1	10665	3998	3	2004-11-16
2	10665	9082	3	2004-11-16
3	10665	6298	1	2004-11-16
4	10665	851	2	2004-11-16
5	10665	5065	1	2004-11-16
1	10666	9573	1	2004-11-03
2	10666	1288	2	2004-11-03
3	10666	4546	2	2004-11-03
4	10666	8704	2	2004-11-03
5	10666	1961	3	2004-11-03
6	10666	5986	3	2004-11-03
7	10666	7811	1	2004-11-03
8	10666	2330	2	2004-11-03
1	10667	3854	1	2004-11-20
2	10667	6722	2	2004-11-20
3	10667	5281	1	2004-11-20
4	10667	5095	2	2004-11-20
5	10667	6894	1	2004-11-20
6	10667	4905	2	2004-11-20
1	10668	9836	3	2004-11-09
2	10668	3749	1	2004-11-09
3	10668	7730	3	2004-11-09
4	10668	9575	2	2004-11-09
5	10668	930	1	2004-11-09
6	10668	1138	3	2004-11-09
7	10668	8231	2	2004-11-09
1	10669	6788	1	2004-11-10
2	10669	1653	1	2004-11-10
3	10669	8930	3	2004-11-10
4	10669	4492	2	2004-11-10
5	10669	5013	3	2004-11-10
6	10669	27	2	2004-11-10
7	10669	4735	3	2004-11-10
8	10669	4095	3	2004-11-10
9	10669	1658	1	2004-11-10
1	10670	3136	3	2004-11-25
2	10670	6643	1	2004-11-25
3	10670	4611	3	2004-11-25
4	10670	3451	1	2004-11-25
5	10670	9656	1	2004-11-25
6	10670	4648	1	2004-11-25
7	10670	2121	2	2004-11-25
8	10670	9855	2	2004-11-25
9	10670	7412	2	2004-11-25
1	10671	7300	2	2004-11-12
2	10671	7169	3	2004-11-12
3	10671	5988	2	2004-11-12
4	10671	189	2	2004-11-12
5	10671	4531	1	2004-11-12
6	10671	1852	1	2004-11-12
7	10671	4691	2	2004-11-12
8	10671	961	3	2004-11-12
1	10672	1925	1	2004-11-26
2	10672	6676	1	2004-11-26
3	10672	7112	2	2004-11-26
1	10673	9750	3	2004-11-20
2	10673	878	3	2004-11-20
3	10673	7781	3	2004-11-20
4	10673	2303	3	2004-11-20
5	10673	216	3	2004-11-20
6	10673	1295	1	2004-11-20
7	10673	8006	2	2004-11-20
1	10674	9583	1	2004-11-26
2	10674	80	1	2004-11-26
3	10674	3005	3	2004-11-26
4	10674	3287	1	2004-11-26
5	10674	843	3	2004-11-26
6	10674	1180	1	2004-11-26
7	10674	6647	1	2004-11-26
1	10675	4390	1	2004-11-04
2	10675	6941	2	2004-11-04
3	10675	6983	3	2004-11-04
4	10675	6673	2	2004-11-04
5	10675	4220	2	2004-11-04
6	10675	3954	3	2004-11-04
7	10675	2183	2	2004-11-04
8	10675	850	1	2004-11-04
9	10675	5044	2	2004-11-04
1	10676	8262	2	2004-11-28
2	10676	2227	2	2004-11-28
3	10676	6080	2	2004-11-28
4	10676	2433	2	2004-11-28
5	10676	2388	3	2004-11-28
6	10676	4077	3	2004-11-28
7	10676	1427	1	2004-11-28
8	10676	7563	3	2004-11-28
9	10676	6048	1	2004-11-28
1	10677	3538	1	2004-11-10
2	10677	7747	3	2004-11-10
3	10677	4831	3	2004-11-10
4	10677	6910	3	2004-11-10
5	10677	6624	2	2004-11-10
1	10678	2268	1	2004-11-12
1	10679	3984	1	2004-11-12
2	10679	9092	1	2004-11-12
3	10679	8860	2	2004-11-12
4	10679	3328	1	2004-11-12
5	10679	5140	2	2004-11-12
6	10679	7645	3	2004-11-12
7	10679	4431	2	2004-11-12
8	10679	7258	3	2004-11-12
1	10680	9338	1	2004-11-07
2	10680	7630	3	2004-11-07
3	10680	2039	3	2004-11-07
4	10680	1928	2	2004-11-07
5	10680	4553	1	2004-11-07
6	10680	4026	3	2004-11-07
7	10680	2021	1	2004-11-07
8	10680	81	1	2004-11-07
1	10681	6863	1	2004-11-25
2	10681	2073	1	2004-11-25
3	10681	6076	3	2004-11-25
4	10681	554	3	2004-11-25
1	10682	624	2	2004-11-11
2	10682	2251	1	2004-11-11
3	10682	4537	2	2004-11-11
1	10683	7624	3	2004-11-26
2	10683	5800	3	2004-11-26
3	10683	8337	2	2004-11-26
1	10684	2062	3	2004-11-04
2	10684	9268	3	2004-11-04
3	10684	8853	3	2004-11-04
4	10684	6368	1	2004-11-04
5	10684	8434	2	2004-11-04
6	10684	5184	3	2004-11-04
7	10684	8017	3	2004-11-04
8	10684	1721	1	2004-11-04
1	10685	3059	3	2004-11-05
2	10685	4507	3	2004-11-05
3	10685	6969	1	2004-11-05
4	10685	2914	3	2004-11-05
5	10685	4221	1	2004-11-05
6	10685	6056	2	2004-11-05
7	10685	9889	2	2004-11-05
1	10686	1091	2	2004-11-14
1	10687	3708	2	2004-11-13
2	10687	4733	2	2004-11-13
1	10688	5638	3	2004-11-15
2	10688	6647	1	2004-11-15
3	10688	9718	3	2004-11-15
4	10688	687	2	2004-11-15
5	10688	9926	3	2004-11-15
6	10688	219	3	2004-11-15
7	10688	2064	2	2004-11-15
8	10688	8556	3	2004-11-15
1	10689	5921	2	2004-11-17
2	10689	1765	3	2004-11-17
3	10689	7770	2	2004-11-17
4	10689	4947	1	2004-11-17
5	10689	2870	3	2004-11-17
6	10689	289	3	2004-11-17
7	10689	4187	3	2004-11-17
8	10689	1112	2	2004-11-17
9	10689	6496	1	2004-11-17
1	10690	6237	1	2004-11-24
2	10690	2697	2	2004-11-24
3	10690	7808	3	2004-11-24
4	10690	4439	3	2004-11-24
5	10690	7703	1	2004-11-24
6	10690	2005	3	2004-11-24
7	10690	9988	3	2004-11-24
8	10690	5963	2	2004-11-24
1	10691	7339	2	2004-11-07
2	10691	9497	3	2004-11-07
3	10691	337	2	2004-11-07
1	10692	6237	3	2004-11-01
2	10692	9390	3	2004-11-01
3	10692	3442	3	2004-11-01
4	10692	7051	3	2004-11-01
5	10692	5786	2	2004-11-01
6	10692	8241	3	2004-11-01
7	10692	4220	3	2004-11-01
8	10692	7564	1	2004-11-01
1	10693	2398	2	2004-11-10
2	10693	1841	1	2004-11-10
3	10693	4803	1	2004-11-10
4	10693	7886	2	2004-11-10
5	10693	354	1	2004-11-10
1	10694	5523	1	2004-11-12
2	10694	424	1	2004-11-12
3	10694	272	2	2004-11-12
1	10695	6740	1	2004-11-22
2	10695	1730	3	2004-11-22
1	10696	7098	3	2004-11-05
2	10696	5692	1	2004-11-05
3	10696	9326	2	2004-11-05
4	10696	6951	3	2004-11-05
1	10697	4015	1	2004-11-12
2	10697	5218	2	2004-11-12
3	10697	4367	2	2004-11-12
1	10698	3240	1	2004-11-02
2	10698	6209	2	2004-11-02
3	10698	642	3	2004-11-02
4	10698	5714	2	2004-11-02
5	10698	1406	1	2004-11-02
1	10699	674	1	2004-11-10
2	10699	2105	2	2004-11-10
3	10699	2450	3	2004-11-10
1	10700	903	2	2004-11-23
2	10700	8083	1	2004-11-23
3	10700	6226	1	2004-11-23
1	10701	4435	2	2004-11-19
2	10701	11	1	2004-11-19
3	10701	9417	1	2004-11-19
1	10702	4941	3	2004-11-09
2	10702	9331	3	2004-11-09
3	10702	3736	1	2004-11-09
4	10702	5419	1	2004-11-09
5	10702	8245	2	2004-11-09
6	10702	3706	3	2004-11-09
7	10702	119	1	2004-11-09
1	10703	5810	3	2004-11-03
2	10703	9292	1	2004-11-03
3	10703	163	3	2004-11-03
4	10703	392	3	2004-11-03
5	10703	718	2	2004-11-03
6	10703	2095	3	2004-11-03
7	10703	1020	3	2004-11-03
1	10704	2131	3	2004-11-26
2	10704	3261	1	2004-11-26
1	10705	8754	1	2004-11-16
2	10705	1545	1	2004-11-16
3	10705	7106	3	2004-11-16
4	10705	9322	2	2004-11-16
5	10705	7598	3	2004-11-16
1	10706	1340	1	2004-11-18
2	10706	5646	1	2004-11-18
3	10706	8191	2	2004-11-18
4	10706	2709	1	2004-11-18
5	10706	6209	2	2004-11-18
6	10706	1768	3	2004-11-18
1	10707	2052	2	2004-11-16
2	10707	4951	2	2004-11-16
3	10707	7815	1	2004-11-16
4	10707	951	3	2004-11-16
5	10707	8453	3	2004-11-16
1	10708	569	3	2004-11-20
2	10708	6837	2	2004-11-20
3	10708	235	2	2004-11-20
4	10708	275	1	2004-11-20
5	10708	7297	2	2004-11-20
6	10708	7782	3	2004-11-20
1	10709	7730	3	2004-11-18
2	10709	7578	1	2004-11-18
3	10709	1564	2	2004-11-18
1	10710	1062	3	2004-11-15
2	10710	7341	3	2004-11-15
3	10710	4826	3	2004-11-15
1	10711	6690	2	2004-11-17
2	10711	8652	2	2004-11-17
3	10711	882	2	2004-11-17
4	10711	3051	3	2004-11-17
5	10711	9429	3	2004-11-17
6	10711	9223	3	2004-11-17
1	10712	2192	2	2004-11-21
2	10712	1009	2	2004-11-21
3	10712	7762	1	2004-11-21
4	10712	3865	2	2004-11-21
5	10712	9668	3	2004-11-21
6	10712	3011	2	2004-11-21
7	10712	353	3	2004-11-21
8	10712	850	3	2004-11-21
1	10713	5934	2	2004-11-05
2	10713	9250	2	2004-11-05
3	10713	3045	3	2004-11-05
1	10714	8473	3	2004-11-08
2	10714	6931	3	2004-11-08
3	10714	2183	2	2004-11-08
1	10715	4737	1	2004-11-05
2	10715	6361	2	2004-11-05
1	10716	6712	1	2004-11-30
2	10716	3887	1	2004-11-30
1	10717	1609	1	2004-11-22
1	10718	4346	3	2004-11-01
2	10718	8212	2	2004-11-01
3	10718	4507	3	2004-11-01
4	10718	2575	2	2004-11-01
5	10718	982	3	2004-11-01
6	10718	7105	3	2004-11-01
7	10718	2401	3	2004-11-01
8	10718	4554	2	2004-11-01
1	10719	3911	2	2004-11-26
2	10719	5539	1	2004-11-26
3	10719	5211	3	2004-11-26
1	10720	4200	3	2004-11-08
2	10720	5144	1	2004-11-08
3	10720	4901	3	2004-11-08
4	10720	2175	3	2004-11-08
5	10720	3950	1	2004-11-08
1	10721	8098	2	2004-11-15
2	10721	1721	2	2004-11-15
3	10721	6317	3	2004-11-15
4	10721	9015	1	2004-11-15
5	10721	4340	2	2004-11-15
6	10721	2145	3	2004-11-15
7	10721	1700	2	2004-11-15
1	10722	4101	2	2004-11-16
2	10722	1630	3	2004-11-16
3	10722	4712	2	2004-11-16
4	10722	6477	3	2004-11-16
5	10722	6960	1	2004-11-16
6	10722	9715	3	2004-11-16
7	10722	8453	3	2004-11-16
8	10722	2510	1	2004-11-16
9	10722	4425	3	2004-11-16
1	10723	7993	1	2004-11-29
2	10723	3473	3	2004-11-29
3	10723	5785	3	2004-11-29
4	10723	5420	2	2004-11-29
1	10724	8521	2	2004-11-24
2	10724	3145	2	2004-11-24
3	10724	4137	1	2004-11-24
4	10724	6261	2	2004-11-24
5	10724	7562	2	2004-11-24
6	10724	1663	1	2004-11-24
7	10724	4885	2	2004-11-24
8	10724	8897	2	2004-11-24
9	10724	9527	3	2004-11-24
1	10725	7212	2	2004-11-26
2	10725	356	1	2004-11-26
1	10726	7406	1	2004-11-02
2	10726	6873	1	2004-11-02
1	10727	4860	3	2004-11-18
2	10727	6643	2	2004-11-18
1	10728	5996	1	2004-11-25
2	10728	5132	2	2004-11-25
3	10728	9656	2	2004-11-25
4	10728	6251	3	2004-11-25
5	10728	9207	2	2004-11-25
6	10728	9499	3	2004-11-25
7	10728	4672	1	2004-11-25
1	10729	2627	3	2004-11-04
2	10729	9117	1	2004-11-04
3	10729	9921	2	2004-11-04
4	10729	1496	2	2004-11-04
5	10729	499	3	2004-11-04
6	10729	8091	1	2004-11-04
7	10729	6966	2	2004-11-04
8	10729	5246	1	2004-11-04
1	10730	1769	2	2004-11-26
2	10730	1330	1	2004-11-26
3	10730	5421	2	2004-11-26
4	10730	2918	2	2004-11-26
5	10730	8078	2	2004-11-26
1	10731	3985	1	2004-11-15
2	10731	7857	2	2004-11-15
3	10731	9716	3	2004-11-15
4	10731	5263	3	2004-11-15
1	10732	4326	1	2004-11-05
2	10732	1610	1	2004-11-05
3	10732	5090	2	2004-11-05
4	10732	6281	2	2004-11-05
5	10732	4645	1	2004-11-05
6	10732	2419	3	2004-11-05
7	10732	8357	1	2004-11-05
1	10733	7001	2	2004-11-09
2	10733	9186	2	2004-11-09
3	10733	665	3	2004-11-09
4	10733	3213	2	2004-11-09
5	10733	6708	2	2004-11-09
6	10733	8156	3	2004-11-09
1	10734	3181	2	2004-11-05
2	10734	6372	3	2004-11-05
3	10734	474	1	2004-11-05
1	10735	3389	1	2004-11-04
2	10735	2640	2	2004-11-04
3	10735	7414	3	2004-11-04
4	10735	9773	2	2004-11-04
5	10735	4498	1	2004-11-04
6	10735	5500	3	2004-11-04
7	10735	6364	1	2004-11-04
8	10735	2386	2	2004-11-04
9	10735	808	2	2004-11-04
1	10736	3829	1	2004-11-21
1	10737	7196	1	2004-11-29
1	10738	5172	1	2004-11-01
2	10738	2603	2	2004-11-01
3	10738	8123	3	2004-11-01
1	10739	5830	3	2004-11-17
2	10739	6264	2	2004-11-17
1	10740	3444	1	2004-11-03
2	10740	863	1	2004-11-03
3	10740	4542	2	2004-11-03
4	10740	3890	1	2004-11-03
5	10740	7743	2	2004-11-03
6	10740	2320	1	2004-11-03
7	10740	7176	3	2004-11-03
1	10741	6878	3	2004-11-11
2	10741	5120	1	2004-11-11
1	10742	7586	3	2004-11-29
2	10742	9086	2	2004-11-29
3	10742	7577	1	2004-11-29
4	10742	4234	3	2004-11-29
5	10742	5615	3	2004-11-29
6	10742	3453	3	2004-11-29
1	10743	3047	1	2004-11-02
2	10743	323	2	2004-11-02
3	10743	671	1	2004-11-02
1	10744	9236	1	2004-11-24
2	10744	3987	3	2004-11-24
3	10744	5956	1	2004-11-24
1	10745	7570	3	2004-11-24
2	10745	3982	1	2004-11-24
3	10745	8576	3	2004-11-24
4	10745	2689	3	2004-11-24
5	10745	8629	2	2004-11-24
1	10746	8096	3	2004-11-06
2	10746	4999	2	2004-11-06
3	10746	5518	2	2004-11-06
1	10747	2872	1	2004-11-28
2	10747	4612	1	2004-11-28
3	10747	6700	1	2004-11-28
1	10748	7454	3	2004-11-20
1	10749	6549	3	2004-11-24
2	10749	8099	2	2004-11-24
3	10749	1802	2	2004-11-24
4	10749	1816	3	2004-11-24
5	10749	2209	3	2004-11-24
6	10749	2372	1	2004-11-24
1	10750	9735	3	2004-11-07
2	10750	5797	2	2004-11-07
3	10750	9092	1	2004-11-07
4	10750	704	3	2004-11-07
5	10750	2539	3	2004-11-07
1	10751	6758	2	2004-11-23
2	10751	4831	2	2004-11-23
3	10751	8695	2	2004-11-23
4	10751	1050	1	2004-11-23
5	10751	3432	1	2004-11-23
1	10752	3878	3	2004-11-24
2	10752	4889	2	2004-11-24
3	10752	7734	1	2004-11-24
4	10752	46	3	2004-11-24
5	10752	2862	1	2004-11-24
6	10752	5897	2	2004-11-24
7	10752	8907	2	2004-11-24
8	10752	5735	3	2004-11-24
9	10752	8793	1	2004-11-24
1	10753	256	3	2004-11-07
1	10754	9490	2	2004-11-04
2	10754	9033	2	2004-11-04
3	10754	4997	2	2004-11-04
4	10754	6980	1	2004-11-04
5	10754	4605	3	2004-11-04
6	10754	9555	3	2004-11-04
7	10754	7774	2	2004-11-04
8	10754	2866	3	2004-11-04
9	10754	8975	3	2004-11-04
1	10755	1391	3	2004-11-12
2	10755	6687	1	2004-11-12
3	10755	6837	3	2004-11-12
4	10755	5333	3	2004-11-12
5	10755	7047	2	2004-11-12
6	10755	4669	2	2004-11-12
1	10756	2395	2	2004-11-25
2	10756	2195	1	2004-11-25
3	10756	2071	3	2004-11-25
4	10756	7400	2	2004-11-25
5	10756	6648	2	2004-11-25
1	10757	6472	2	2004-11-11
2	10757	3066	1	2004-11-11
3	10757	7178	3	2004-11-11
4	10757	1103	1	2004-11-11
5	10757	8396	3	2004-11-11
1	10758	2729	2	2004-11-22
2	10758	692	2	2004-11-22
3	10758	8834	1	2004-11-22
4	10758	7073	1	2004-11-22
5	10758	2854	2	2004-11-22
1	10759	35	2	2004-11-18
2	10759	4000	2	2004-11-18
3	10759	519	3	2004-11-18
4	10759	9665	3	2004-11-18
5	10759	6968	1	2004-11-18
6	10759	207	2	2004-11-18
7	10759	8916	3	2004-11-18
8	10759	8427	1	2004-11-18
9	10759	3062	1	2004-11-18
1	10760	6640	2	2004-11-23
2	10760	7110	3	2004-11-23
3	10760	7825	1	2004-11-23
4	10760	8996	3	2004-11-23
5	10760	2322	3	2004-11-23
6	10760	3659	2	2004-11-23
1	10761	1874	1	2004-11-17
2	10761	5967	1	2004-11-17
3	10761	5718	2	2004-11-17
4	10761	9619	2	2004-11-17
5	10761	8028	1	2004-11-17
1	10762	1608	1	2004-11-16
2	10762	4931	3	2004-11-16
1	10763	1427	2	2004-11-08
2	10763	592	2	2004-11-08
1	10764	1328	1	2004-11-01
2	10764	4051	3	2004-11-01
3	10764	3215	3	2004-11-01
4	10764	2178	1	2004-11-01
1	10765	5606	1	2004-11-12
2	10765	791	3	2004-11-12
3	10765	5022	2	2004-11-12
4	10765	5931	3	2004-11-12
5	10765	8477	3	2004-11-12
6	10765	9151	3	2004-11-12
7	10765	1583	3	2004-11-12
8	10765	4988	1	2004-11-12
9	10765	5870	2	2004-11-12
1	10766	4492	3	2004-11-17
2	10766	9406	3	2004-11-17
3	10766	1433	1	2004-11-17
4	10766	6874	3	2004-11-17
5	10766	2530	1	2004-11-17
6	10766	8895	1	2004-11-17
7	10766	9693	2	2004-11-17
8	10766	9042	2	2004-11-17
9	10766	1504	3	2004-11-17
1	10767	396	1	2004-11-10
2	10767	6692	2	2004-11-10
3	10767	6658	1	2004-11-10
4	10767	3463	1	2004-11-10
5	10767	1918	3	2004-11-10
1	10768	4642	1	2004-11-02
2	10768	9021	3	2004-11-02
1	10769	1830	3	2004-11-12
2	10769	9291	2	2004-11-12
3	10769	7053	1	2004-11-12
4	10769	3988	2	2004-11-12
1	10770	648	2	2004-11-22
2	10770	6281	2	2004-11-22
3	10770	5582	3	2004-11-22
4	10770	2064	2	2004-11-22
1	10771	8184	3	2004-11-29
2	10771	1333	1	2004-11-29
3	10771	5232	1	2004-11-29
4	10771	5829	3	2004-11-29
1	10772	7628	2	2004-11-05
2	10772	2885	2	2004-11-05
3	10772	8765	3	2004-11-05
4	10772	8938	3	2004-11-05
5	10772	3306	2	2004-11-05
6	10772	3522	3	2004-11-05
7	10772	3415	2	2004-11-05
8	10772	5110	1	2004-11-05
1	10773	723	3	2004-11-07
1	10774	3015	1	2004-11-08
2	10774	3564	2	2004-11-08
3	10774	24	1	2004-11-08
4	10774	7792	1	2004-11-08
5	10774	6129	2	2004-11-08
6	10774	2675	2	2004-11-08
7	10774	5968	2	2004-11-08
8	10774	284	3	2004-11-08
1	10775	6634	3	2004-11-15
2	10775	3384	2	2004-11-15
3	10775	7803	2	2004-11-15
4	10775	2160	1	2004-11-15
5	10775	60	1	2004-11-15
6	10775	8864	1	2004-11-15
7	10775	4027	1	2004-11-15
8	10775	6484	2	2004-11-15
9	10775	3619	2	2004-11-15
1	10776	4814	3	2004-11-21
2	10776	5613	2	2004-11-21
3	10776	6287	1	2004-11-21
4	10776	8796	1	2004-11-21
5	10776	458	2	2004-11-21
6	10776	8708	2	2004-11-21
7	10776	9159	2	2004-11-21
8	10776	7947	1	2004-11-21
9	10776	6929	3	2004-11-21
1	10777	8220	3	2004-11-12
2	10777	1810	1	2004-11-12
3	10777	1840	3	2004-11-12
4	10777	1586	1	2004-11-12
5	10777	8402	2	2004-11-12
6	10777	9468	2	2004-11-12
7	10777	1496	2	2004-11-12
1	10778	5720	2	2004-11-14
2	10778	8792	2	2004-11-14
3	10778	2334	3	2004-11-14
4	10778	6198	3	2004-11-14
5	10778	4744	3	2004-11-14
1	10779	3389	3	2004-11-16
2	10779	5113	2	2004-11-16
3	10779	8267	3	2004-11-16
1	10780	682	2	2004-11-24
2	10780	3121	2	2004-11-24
3	10780	4885	1	2004-11-24
4	10780	127	1	2004-11-24
5	10780	6060	3	2004-11-24
6	10780	5483	3	2004-11-24
7	10780	5657	1	2004-11-24
1	10781	6225	3	2004-11-23
2	10781	5983	3	2004-11-23
3	10781	8796	1	2004-11-23
1	10782	3730	1	2004-11-15
2	10782	105	2	2004-11-15
3	10782	5482	1	2004-11-15
1	10783	970	3	2004-11-29
2	10783	8632	2	2004-11-29
3	10783	7912	2	2004-11-29
4	10783	8132	2	2004-11-29
5	10783	4688	3	2004-11-29
6	10783	8275	1	2004-11-29
7	10783	9038	2	2004-11-29
8	10783	526	3	2004-11-29
9	10783	5352	2	2004-11-29
1	10784	4033	3	2004-11-15
2	10784	3035	3	2004-11-15
3	10784	1433	1	2004-11-15
4	10784	9881	2	2004-11-15
5	10784	2333	1	2004-11-15
6	10784	4413	1	2004-11-15
7	10784	7303	1	2004-11-15
8	10784	5252	2	2004-11-15
1	10785	852	2	2004-11-24
2	10785	423	1	2004-11-24
3	10785	2046	2	2004-11-24
4	10785	6743	3	2004-11-24
5	10785	8918	2	2004-11-24
6	10785	5565	1	2004-11-24
1	10786	1219	1	2004-11-10
2	10786	9380	2	2004-11-10
3	10786	3195	2	2004-11-10
4	10786	4516	1	2004-11-10
5	10786	6118	3	2004-11-10
1	10787	174	1	2004-11-18
1	10788	6370	3	2004-11-16
2	10788	4304	2	2004-11-16
3	10788	3524	3	2004-11-16
4	10788	8237	2	2004-11-16
5	10788	8468	1	2004-11-16
6	10788	1066	3	2004-11-16
7	10788	3045	1	2004-11-16
1	10789	6736	1	2004-11-10
2	10789	7521	1	2004-11-10
3	10789	4363	3	2004-11-10
4	10789	3771	2	2004-11-10
5	10789	7785	3	2004-11-10
6	10789	5132	3	2004-11-10
7	10789	6452	1	2004-11-10
1	10790	623	2	2004-11-26
2	10790	8499	3	2004-11-26
1	10791	9	1	2004-11-18
2	10791	5010	2	2004-11-18
3	10791	9768	1	2004-11-18
4	10791	4600	3	2004-11-18
5	10791	4412	3	2004-11-18
6	10791	4514	3	2004-11-18
7	10791	3498	1	2004-11-18
8	10791	7271	3	2004-11-18
1	10792	4477	3	2004-11-07
1	10793	4190	3	2004-11-08
1	10794	4980	1	2004-11-02
1	10795	2035	3	2004-11-14
2	10795	8211	2	2004-11-14
3	10795	5791	1	2004-11-14
4	10795	8846	1	2004-11-14
5	10795	338	1	2004-11-14
6	10795	6783	1	2004-11-14
7	10795	1276	1	2004-11-14
8	10795	7388	2	2004-11-14
9	10795	6359	3	2004-11-14
1	10796	3514	2	2004-11-14
2	10796	5240	3	2004-11-14
3	10796	4891	3	2004-11-14
4	10796	3241	3	2004-11-14
5	10796	9138	2	2004-11-14
1	10797	9058	1	2004-11-18
2	10797	4545	3	2004-11-18
1	10798	2587	3	2004-11-05
2	10798	6416	3	2004-11-05
3	10798	6582	1	2004-11-05
1	10799	7023	1	2004-11-29
2	10799	1500	1	2004-11-29
3	10799	822	2	2004-11-29
1	10800	7308	1	2004-11-01
2	10800	7179	2	2004-11-01
3	10800	2504	1	2004-11-01
4	10800	5760	2	2004-11-01
5	10800	3051	2	2004-11-01
6	10800	6840	2	2004-11-01
1	10801	4112	2	2004-11-09
2	10801	3036	3	2004-11-09
3	10801	7082	1	2004-11-09
4	10801	738	3	2004-11-09
5	10801	1972	1	2004-11-09
6	10801	3322	1	2004-11-09
7	10801	1519	2	2004-11-09
8	10801	7666	3	2004-11-09
9	10801	5173	2	2004-11-09
1	10802	1709	3	2004-11-16
1	10803	1803	3	2004-11-20
2	10803	8899	2	2004-11-20
3	10803	3913	1	2004-11-20
4	10803	5719	1	2004-11-20
5	10803	1993	2	2004-11-20
6	10803	9577	2	2004-11-20
7	10803	8015	1	2004-11-20
8	10803	5935	3	2004-11-20
9	10803	6235	2	2004-11-20
1	10804	9083	2	2004-11-26
2	10804	4499	1	2004-11-26
3	10804	4629	1	2004-11-26
4	10804	9339	3	2004-11-26
1	10805	7057	2	2004-11-02
2	10805	1349	1	2004-11-02
3	10805	4630	2	2004-11-02
4	10805	9231	2	2004-11-02
5	10805	7305	3	2004-11-02
6	10805	7105	1	2004-11-02
7	10805	6779	2	2004-11-02
8	10805	6840	2	2004-11-02
9	10805	4746	2	2004-11-02
1	10806	4619	2	2004-11-27
2	10806	4256	2	2004-11-27
3	10806	4808	2	2004-11-27
1	10807	8163	2	2004-11-16
2	10807	4931	1	2004-11-16
1	10808	1407	2	2004-11-27
2	10808	9420	3	2004-11-27
3	10808	7442	2	2004-11-27
4	10808	3322	1	2004-11-27
5	10808	1543	1	2004-11-27
6	10808	6015	1	2004-11-27
1	10809	4591	1	2004-11-16
2	10809	4218	3	2004-11-16
3	10809	6096	3	2004-11-16
4	10809	1846	2	2004-11-16
5	10809	3938	3	2004-11-16
6	10809	7051	1	2004-11-16
7	10809	937	2	2004-11-16
8	10809	8994	1	2004-11-16
9	10809	8151	3	2004-11-16
1	10810	7780	2	2004-11-02
2	10810	5856	2	2004-11-02
3	10810	8051	1	2004-11-02
4	10810	4428	2	2004-11-02
1	10811	8709	1	2004-11-02
2	10811	3114	1	2004-11-02
3	10811	6730	3	2004-11-02
4	10811	7330	2	2004-11-02
5	10811	9865	3	2004-11-02
1	10812	7271	1	2004-11-24
2	10812	1572	1	2004-11-24
3	10812	4984	3	2004-11-24
4	10812	8156	1	2004-11-24
5	10812	3145	2	2004-11-24
6	10812	1886	3	2004-11-24
1	10813	7089	2	2004-11-04
2	10813	9865	1	2004-11-04
3	10813	5854	2	2004-11-04
4	10813	7254	1	2004-11-04
5	10813	375	3	2004-11-04
6	10813	1450	3	2004-11-04
7	10813	5976	1	2004-11-04
1	10814	5188	3	2004-11-13
2	10814	5103	2	2004-11-13
3	10814	9018	3	2004-11-13
4	10814	9550	1	2004-11-13
5	10814	5820	1	2004-11-13
6	10814	3282	1	2004-11-13
1	10815	573	2	2004-11-24
2	10815	4418	3	2004-11-24
3	10815	6747	2	2004-11-24
4	10815	4943	3	2004-11-24
5	10815	2994	1	2004-11-24
6	10815	255	3	2004-11-24
7	10815	4164	2	2004-11-24
8	10815	2928	3	2004-11-24
1	10816	6278	1	2004-11-05
1	10817	4508	1	2004-11-05
2	10817	5198	1	2004-11-05
3	10817	8593	2	2004-11-05
4	10817	5781	1	2004-11-05
5	10817	3596	1	2004-11-05
1	10818	9456	1	2004-11-24
1	10819	2971	2	2004-11-24
1	10820	7911	3	2004-11-27
2	10820	7302	1	2004-11-27
3	10820	3072	1	2004-11-27
4	10820	1492	3	2004-11-27
5	10820	4026	1	2004-11-27
1	10821	2334	1	2004-11-13
2	10821	6173	1	2004-11-13
3	10821	1690	2	2004-11-13
4	10821	4037	3	2004-11-13
5	10821	9248	3	2004-11-13
6	10821	558	1	2004-11-13
7	10821	4519	3	2004-11-13
1	10822	9462	1	2004-11-24
2	10822	6516	1	2004-11-24
3	10822	3801	3	2004-11-24
4	10822	803	3	2004-11-24
5	10822	8091	2	2004-11-24
6	10822	7633	1	2004-11-24
1	10823	3024	2	2004-11-08
2	10823	4277	3	2004-11-08
3	10823	3428	2	2004-11-08
4	10823	5525	2	2004-11-08
5	10823	5743	1	2004-11-08
6	10823	3469	2	2004-11-08
7	10823	1261	3	2004-11-08
8	10823	9421	1	2004-11-08
1	10824	3944	2	2004-11-01
2	10824	1776	1	2004-11-01
3	10824	8901	3	2004-11-01
4	10824	3218	1	2004-11-01
1	10825	9064	2	2004-11-29
2	10825	9458	1	2004-11-29
3	10825	7828	2	2004-11-29
1	10826	7196	2	2004-11-20
2	10826	8102	2	2004-11-20
3	10826	7010	3	2004-11-20
4	10826	2552	1	2004-11-20
5	10826	2202	2	2004-11-20
6	10826	4324	2	2004-11-20
7	10826	8528	1	2004-11-20
8	10826	3385	1	2004-11-20
9	10826	4603	1	2004-11-20
1	10827	8932	2	2004-11-22
2	10827	8595	3	2004-11-22
3	10827	9595	2	2004-11-22
4	10827	329	2	2004-11-22
5	10827	5013	3	2004-11-22
6	10827	909	1	2004-11-22
1	10828	8183	2	2004-11-13
2	10828	3185	1	2004-11-13
3	10828	7544	1	2004-11-13
4	10828	5732	1	2004-11-13
5	10828	3459	1	2004-11-13
6	10828	3686	1	2004-11-13
7	10828	4963	3	2004-11-13
1	10829	654	1	2004-11-20
2	10829	268	1	2004-11-20
3	10829	7668	2	2004-11-20
4	10829	8506	3	2004-11-20
5	10829	8395	1	2004-11-20
1	10830	3328	1	2004-11-20
2	10830	7183	1	2004-11-20
3	10830	4234	1	2004-11-20
4	10830	1799	3	2004-11-20
5	10830	3247	2	2004-11-20
1	10831	2104	3	2004-11-25
2	10831	9993	1	2004-11-25
3	10831	823	1	2004-11-25
4	10831	3739	3	2004-11-25
5	10831	5540	1	2004-11-25
1	10832	3695	2	2004-11-22
2	10832	8235	3	2004-11-22
3	10832	6745	2	2004-11-22
4	10832	7894	1	2004-11-22
1	10833	5176	3	2004-11-25
2	10833	9786	3	2004-11-25
1	10834	4646	3	2004-11-05
2	10834	1905	3	2004-11-05
1	10835	1379	2	2004-11-20
2	10835	7213	2	2004-11-20
3	10835	9741	2	2004-11-20
4	10835	2095	2	2004-11-20
1	10836	9681	2	2004-11-03
2	10836	770	2	2004-11-03
3	10836	2992	1	2004-11-03
4	10836	4356	2	2004-11-03
5	10836	2445	1	2004-11-03
6	10836	6291	3	2004-11-03
7	10836	9731	3	2004-11-03
8	10836	5474	2	2004-11-03
9	10836	5639	2	2004-11-03
1	10837	2091	1	2004-11-30
2	10837	2634	2	2004-11-30
3	10837	7845	2	2004-11-30
4	10837	4174	2	2004-11-30
5	10837	2691	2	2004-11-30
6	10837	1440	2	2004-11-30
7	10837	8710	2	2004-11-30
1	10838	4697	2	2004-11-13
2	10838	3551	2	2004-11-13
3	10838	3561	3	2004-11-13
4	10838	746	3	2004-11-13
5	10838	5126	1	2004-11-13
6	10838	6218	3	2004-11-13
1	10839	2493	2	2004-11-24
1	10840	519	1	2004-11-13
2	10840	185	3	2004-11-13
3	10840	7125	2	2004-11-13
4	10840	2293	2	2004-11-13
5	10840	661	3	2004-11-13
6	10840	1567	2	2004-11-13
7	10840	1416	2	2004-11-13
1	10841	2880	1	2004-11-10
2	10841	5103	1	2004-11-10
3	10841	8852	1	2004-11-10
4	10841	1322	1	2004-11-10
5	10841	9151	2	2004-11-10
6	10841	8009	1	2004-11-10
7	10841	2081	3	2004-11-10
8	10841	3097	1	2004-11-10
1	10842	6422	3	2004-11-24
1	10843	3117	2	2004-11-22
2	10843	612	3	2004-11-22
3	10843	2931	2	2004-11-22
4	10843	7988	3	2004-11-22
5	10843	4275	3	2004-11-22
6	10843	1238	2	2004-11-22
7	10843	8183	1	2004-11-22
8	10843	952	2	2004-11-22
1	10844	5298	1	2004-11-03
2	10844	4110	1	2004-11-03
3	10844	2518	1	2004-11-03
4	10844	8890	3	2004-11-03
1	10845	4798	3	2004-11-26
2	10845	9079	3	2004-11-26
1	10846	3906	3	2004-11-07
2	10846	1975	1	2004-11-07
3	10846	7386	1	2004-11-07
4	10846	8278	3	2004-11-07
5	10846	5959	1	2004-11-07
6	10846	2065	1	2004-11-07
1	10847	6705	1	2004-11-17
2	10847	7537	2	2004-11-17
3	10847	2137	2	2004-11-17
4	10847	6860	3	2004-11-17
5	10847	4154	2	2004-11-17
6	10847	4662	2	2004-11-17
7	10847	3005	1	2004-11-17
8	10847	2638	3	2004-11-17
1	10848	7539	3	2004-11-23
2	10848	2983	2	2004-11-23
3	10848	270	2	2004-11-23
4	10848	4755	2	2004-11-23
5	10848	1220	3	2004-11-23
1	10849	3148	1	2004-11-12
2	10849	6795	1	2004-11-12
1	10850	7207	3	2004-11-27
2	10850	3838	3	2004-11-27
3	10850	5860	1	2004-11-27
4	10850	4457	2	2004-11-27
1	10851	5493	1	2004-11-19
2	10851	4095	1	2004-11-19
3	10851	8137	2	2004-11-19
4	10851	8022	1	2004-11-19
5	10851	3238	3	2004-11-19
6	10851	3112	2	2004-11-19
7	10851	9526	3	2004-11-19
8	10851	6393	3	2004-11-19
9	10851	855	1	2004-11-19
1	10852	7906	3	2004-11-06
2	10852	6791	1	2004-11-06
3	10852	2005	1	2004-11-06
4	10852	4357	2	2004-11-06
5	10852	1903	3	2004-11-06
1	10853	1311	3	2004-11-20
2	10853	6531	2	2004-11-20
3	10853	5822	3	2004-11-20
4	10853	934	2	2004-11-20
5	10853	9550	3	2004-11-20
1	10854	8466	1	2004-11-11
2	10854	854	2	2004-11-11
3	10854	8099	3	2004-11-11
4	10854	8732	1	2004-11-11
5	10854	500	1	2004-11-11
1	10855	8400	1	2004-11-13
1	10856	4258	3	2004-11-17
2	10856	1626	2	2004-11-17
1	10857	1579	1	2004-11-07
2	10857	1263	1	2004-11-07
3	10857	3131	1	2004-11-07
4	10857	6415	1	2004-11-07
5	10857	9761	2	2004-11-07
6	10857	1333	1	2004-11-07
1	10858	6350	1	2004-11-25
2	10858	4201	1	2004-11-25
1	10859	2315	2	2004-11-03
2	10859	220	2	2004-11-03
3	10859	6585	1	2004-11-03
4	10859	570	3	2004-11-03
5	10859	4917	1	2004-11-03
1	10860	9277	2	2004-11-25
2	10860	9768	1	2004-11-25
3	10860	3968	3	2004-11-25
4	10860	6182	2	2004-11-25
5	10860	9171	1	2004-11-25
1	10861	8718	3	2004-11-24
2	10861	3490	1	2004-11-24
3	10861	3527	2	2004-11-24
4	10861	5661	1	2004-11-24
5	10861	6446	2	2004-11-24
6	10861	8274	1	2004-11-24
7	10861	8061	2	2004-11-24
8	10861	9410	1	2004-11-24
1	10862	9296	3	2004-11-04
1	10863	8008	2	2004-11-27
2	10863	1411	1	2004-11-27
3	10863	2465	1	2004-11-27
4	10863	456	2	2004-11-27
5	10863	1161	2	2004-11-27
6	10863	9664	3	2004-11-27
7	10863	4093	2	2004-11-27
8	10863	3050	1	2004-11-27
1	10864	3119	3	2004-11-23
2	10864	5568	3	2004-11-23
3	10864	818	2	2004-11-23
4	10864	8518	3	2004-11-23
5	10864	340	2	2004-11-23
6	10864	7727	3	2004-11-23
7	10864	8834	3	2004-11-23
1	10865	7253	1	2004-11-03
2	10865	5125	3	2004-11-03
1	10866	1584	1	2004-11-22
1	10867	380	1	2004-11-05
2	10867	3360	1	2004-11-05
3	10867	7812	1	2004-11-05
4	10867	884	3	2004-11-05
5	10867	6709	3	2004-11-05
1	10868	6840	3	2004-11-20
2	10868	8328	2	2004-11-20
3	10868	7440	2	2004-11-20
4	10868	1009	2	2004-11-20
5	10868	2670	2	2004-11-20
6	10868	4983	2	2004-11-20
7	10868	4533	2	2004-11-20
1	10869	4861	2	2004-11-15
2	10869	6259	1	2004-11-15
3	10869	6152	3	2004-11-15
4	10869	823	1	2004-11-15
5	10869	5753	3	2004-11-15
1	10870	514	1	2004-11-26
2	10870	9334	3	2004-11-26
3	10870	6286	1	2004-11-26
4	10870	2640	3	2004-11-26
5	10870	4377	3	2004-11-26
1	10871	823	2	2004-11-10
2	10871	2954	2	2004-11-10
3	10871	9198	3	2004-11-10
4	10871	8356	2	2004-11-10
5	10871	6355	3	2004-11-10
6	10871	8208	1	2004-11-10
7	10871	6500	2	2004-11-10
8	10871	5607	1	2004-11-10
1	10872	4074	1	2004-11-06
2	10872	1525	3	2004-11-06
1	10873	4812	3	2004-11-28
2	10873	178	2	2004-11-28
3	10873	3269	1	2004-11-28
1	10874	7814	3	2004-11-04
2	10874	8851	2	2004-11-04
3	10874	806	2	2004-11-04
4	10874	2630	2	2004-11-04
5	10874	6356	2	2004-11-04
6	10874	2532	1	2004-11-04
7	10874	5662	2	2004-11-04
8	10874	317	3	2004-11-04
9	10874	3318	3	2004-11-04
1	10875	5997	1	2004-11-10
2	10875	3533	3	2004-11-10
3	10875	4989	2	2004-11-10
4	10875	1731	3	2004-11-10
5	10875	4523	3	2004-11-10
6	10875	6031	2	2004-11-10
7	10875	5565	3	2004-11-10
8	10875	8724	3	2004-11-10
1	10876	5273	3	2004-11-10
2	10876	2384	2	2004-11-10
3	10876	5520	2	2004-11-10
4	10876	4984	3	2004-11-10
5	10876	3354	2	2004-11-10
6	10876	6506	3	2004-11-10
1	10877	4889	1	2004-11-26
2	10877	844	3	2004-11-26
3	10877	9889	3	2004-11-26
4	10877	2785	2	2004-11-26
1	10878	6588	2	2004-11-12
2	10878	2738	1	2004-11-12
3	10878	4653	2	2004-11-12
4	10878	7449	1	2004-11-12
5	10878	823	1	2004-11-12
6	10878	8778	2	2004-11-12
7	10878	9098	2	2004-11-12
1	10879	1132	1	2004-11-11
2	10879	2488	1	2004-11-11
1	10880	7830	1	2004-11-29
2	10880	3915	1	2004-11-29
3	10880	9520	1	2004-11-29
1	10881	7378	3	2004-11-24
2	10881	2619	3	2004-11-24
3	10881	2245	1	2004-11-24
1	10882	8962	1	2004-11-08
2	10882	8047	1	2004-11-08
3	10882	2212	1	2004-11-08
4	10882	2069	1	2004-11-08
5	10882	2910	1	2004-11-08
6	10882	4239	1	2004-11-08
1	10883	8657	1	2004-11-11
2	10883	5256	1	2004-11-11
3	10883	2460	1	2004-11-11
1	10884	6475	1	2004-11-03
2	10884	4416	1	2004-11-03
3	10884	9116	2	2004-11-03
1	10885	7695	2	2004-11-16
2	10885	9198	1	2004-11-16
3	10885	6458	2	2004-11-16
4	10885	1344	3	2004-11-16
5	10885	1590	2	2004-11-16
6	10885	2936	1	2004-11-16
7	10885	3571	3	2004-11-16
1	10886	1108	1	2004-11-04
2	10886	5170	3	2004-11-04
1	10887	2962	2	2004-11-15
2	10887	1147	2	2004-11-15
3	10887	3256	3	2004-11-15
4	10887	1971	1	2004-11-15
1	10888	8365	3	2004-11-29
1	10889	9490	3	2004-11-14
2	10889	3950	1	2004-11-14
3	10889	1087	2	2004-11-14
4	10889	1972	2	2004-11-14
5	10889	2639	3	2004-11-14
6	10889	5841	2	2004-11-14
7	10889	826	3	2004-11-14
8	10889	9264	1	2004-11-14
1	10890	4973	1	2004-11-16
2	10890	5633	1	2004-11-16
3	10890	1049	2	2004-11-16
4	10890	8343	2	2004-11-16
5	10890	5296	2	2004-11-16
6	10890	3317	2	2004-11-16
7	10890	5060	3	2004-11-16
1	10891	2402	2	2004-11-16
2	10891	3912	3	2004-11-16
3	10891	8334	2	2004-11-16
4	10891	7044	3	2004-11-16
5	10891	6710	1	2004-11-16
6	10891	117	3	2004-11-16
7	10891	9482	2	2004-11-16
1	10892	9110	2	2004-11-24
2	10892	4230	2	2004-11-24
3	10892	363	3	2004-11-24
4	10892	9192	2	2004-11-24
5	10892	4813	2	2004-11-24
6	10892	1569	3	2004-11-24
7	10892	1362	2	2004-11-24
8	10892	2096	2	2004-11-24
1	10893	8027	3	2004-11-07
2	10893	1533	3	2004-11-07
3	10893	4245	1	2004-11-07
4	10893	3232	1	2004-11-07
5	10893	6128	3	2004-11-07
6	10893	860	2	2004-11-07
7	10893	3478	2	2004-11-07
8	10893	9644	2	2004-11-07
9	10893	2637	3	2004-11-07
1	10894	4584	2	2004-11-28
1	10895	7110	3	2004-11-15
2	10895	6269	2	2004-11-15
3	10895	6492	3	2004-11-15
4	10895	3279	1	2004-11-15
5	10895	8815	2	2004-11-15
6	10895	2764	2	2004-11-15
7	10895	5694	2	2004-11-15
1	10896	3011	1	2004-11-01
2	10896	8659	1	2004-11-01
3	10896	8798	1	2004-11-01
4	10896	3106	2	2004-11-01
5	10896	6271	3	2004-11-01
6	10896	62	2	2004-11-01
7	10896	4921	3	2004-11-01
8	10896	5802	1	2004-11-01
9	10896	2307	1	2004-11-01
1	10897	2097	2	2004-11-27
2	10897	2748	3	2004-11-27
3	10897	9418	1	2004-11-27
4	10897	6961	3	2004-11-27
5	10897	2751	3	2004-11-27
6	10897	9480	1	2004-11-27
7	10897	2246	3	2004-11-27
8	10897	3193	2	2004-11-27
1	10898	5494	3	2004-11-05
2	10898	8892	1	2004-11-05
1	10899	6783	2	2004-11-29
2	10899	6163	3	2004-11-29
3	10899	2414	3	2004-11-29
4	10899	6669	1	2004-11-29
5	10899	1838	2	2004-11-29
6	10899	9961	2	2004-11-29
7	10899	3602	3	2004-11-29
8	10899	5997	2	2004-11-29
1	10900	8653	2	2004-11-24
2	10900	1097	2	2004-11-24
3	10900	2635	3	2004-11-24
4	10900	5443	1	2004-11-24
5	10900	1186	3	2004-11-24
6	10900	361	3	2004-11-24
7	10900	5652	2	2004-11-24
8	10900	6848	3	2004-11-24
9	10900	5434	2	2004-11-24
1	10901	1859	1	2004-11-30
2	10901	9296	3	2004-11-30
3	10901	6595	3	2004-11-30
4	10901	7046	3	2004-11-30
5	10901	6389	2	2004-11-30
6	10901	2248	3	2004-11-30
7	10901	9845	2	2004-11-30
8	10901	7473	2	2004-11-30
9	10901	6885	3	2004-11-30
1	10902	3770	2	2004-11-13
2	10902	8037	3	2004-11-13
3	10902	6990	3	2004-11-13
4	10902	6475	2	2004-11-13
5	10902	7788	3	2004-11-13
6	10902	4883	3	2004-11-13
7	10902	6189	1	2004-11-13
8	10902	4095	1	2004-11-13
9	10902	9269	1	2004-11-13
1	10903	6398	2	2004-11-27
2	10903	4066	1	2004-11-27
3	10903	4099	3	2004-11-27
4	10903	528	1	2004-11-27
5	10903	8357	2	2004-11-27
6	10903	4198	2	2004-11-27
7	10903	3500	1	2004-11-27
8	10903	4324	3	2004-11-27
1	10904	9194	2	2004-11-16
1	10905	3772	2	2004-11-06
1	10906	7181	3	2004-11-08
2	10906	2143	1	2004-11-08
3	10906	7891	1	2004-11-08
4	10906	2004	2	2004-11-08
5	10906	6967	2	2004-11-08
6	10906	2640	1	2004-11-08
7	10906	7388	3	2004-11-08
8	10906	441	1	2004-11-08
1	10907	3244	2	2004-11-28
2	10907	1556	1	2004-11-28
3	10907	5541	2	2004-11-28
4	10907	7637	3	2004-11-28
5	10907	7068	1	2004-11-28
6	10907	6866	2	2004-11-28
7	10907	2584	3	2004-11-28
8	10907	5527	1	2004-11-28
1	10908	3732	3	2004-11-06
2	10908	9110	1	2004-11-06
3	10908	6324	3	2004-11-06
4	10908	3828	2	2004-11-06
5	10908	8298	3	2004-11-06
6	10908	3665	1	2004-11-06
7	10908	1333	2	2004-11-06
8	10908	2514	3	2004-11-06
1	10909	3228	1	2004-11-02
2	10909	1863	2	2004-11-02
3	10909	751	3	2004-11-02
4	10909	6285	1	2004-11-02
5	10909	4920	1	2004-11-02
6	10909	1072	3	2004-11-02
7	10909	2366	1	2004-11-02
1	10910	4086	3	2004-11-30
2	10910	338	3	2004-11-30
3	10910	9569	1	2004-11-30
4	10910	2971	1	2004-11-30
1	10911	1133	2	2004-11-26
2	10911	5164	1	2004-11-26
3	10911	1271	2	2004-11-26
4	10911	384	3	2004-11-26
1	10912	3954	1	2004-11-26
2	10912	9593	2	2004-11-26
3	10912	1616	3	2004-11-26
4	10912	7321	2	2004-11-26
5	10912	7353	3	2004-11-26
6	10912	3451	3	2004-11-26
7	10912	9328	2	2004-11-26
8	10912	9003	3	2004-11-26
9	10912	9939	1	2004-11-26
1	10913	4066	3	2004-11-04
2	10913	2369	2	2004-11-04
3	10913	5521	1	2004-11-04
4	10913	9752	2	2004-11-04
5	10913	121	2	2004-11-04
6	10913	9008	3	2004-11-04
1	10914	6324	2	2004-11-23
2	10914	2407	3	2004-11-23
3	10914	3310	1	2004-11-23
4	10914	6196	1	2004-11-23
5	10914	9606	2	2004-11-23
1	10915	7353	1	2004-11-11
1	10916	430	2	2004-11-25
2	10916	9810	1	2004-11-25
3	10916	9175	3	2004-11-25
4	10916	264	2	2004-11-25
1	10917	5691	2	2004-11-29
2	10917	5539	3	2004-11-29
3	10917	5491	1	2004-11-29
4	10917	1313	2	2004-11-29
5	10917	7869	2	2004-11-29
6	10917	5993	2	2004-11-29
1	10918	3066	1	2004-11-16
2	10918	7039	2	2004-11-16
3	10918	7534	3	2004-11-16
1	10919	3311	2	2004-11-13
2	10919	3608	2	2004-11-13
3	10919	872	3	2004-11-13
4	10919	8418	2	2004-11-13
1	10920	9004	2	2004-11-25
2	10920	4472	2	2004-11-25
3	10920	1086	3	2004-11-25
4	10920	8342	3	2004-11-25
5	10920	2885	1	2004-11-25
6	10920	9494	3	2004-11-25
7	10920	4901	3	2004-11-25
8	10920	6772	3	2004-11-25
9	10920	3735	1	2004-11-25
1	10921	1707	3	2004-11-10
2	10921	6158	1	2004-11-10
3	10921	4828	2	2004-11-10
4	10921	4033	1	2004-11-10
5	10921	4067	1	2004-11-10
6	10921	8984	3	2004-11-10
7	10921	8033	1	2004-11-10
1	10922	7781	3	2004-11-25
1	10923	1626	3	2004-11-03
2	10923	130	2	2004-11-03
3	10923	4800	3	2004-11-03
4	10923	1738	2	2004-11-03
5	10923	6094	3	2004-11-03
6	10923	6631	1	2004-11-03
7	10923	2352	1	2004-11-03
1	10924	4957	1	2004-11-12
2	10924	2947	1	2004-11-12
3	10924	8106	1	2004-11-12
1	10925	8568	1	2004-11-13
2	10925	2676	1	2004-11-13
3	10925	9212	1	2004-11-13
4	10925	5072	2	2004-11-13
5	10925	481	3	2004-11-13
1	10926	7495	3	2004-11-02
2	10926	7810	1	2004-11-02
3	10926	3473	1	2004-11-02
4	10926	4264	3	2004-11-02
5	10926	3240	3	2004-11-02
6	10926	1498	1	2004-11-02
7	10926	7656	2	2004-11-02
1	10927	6551	1	2004-11-22
2	10927	5994	2	2004-11-22
3	10927	6026	1	2004-11-22
4	10927	9773	2	2004-11-22
5	10927	7874	1	2004-11-22
6	10927	3081	1	2004-11-22
1	10928	1963	1	2004-11-23
2	10928	6754	2	2004-11-23
3	10928	1535	3	2004-11-23
4	10928	3437	1	2004-11-23
5	10928	1338	1	2004-11-23
1	10929	4369	1	2004-11-26
2	10929	2359	1	2004-11-26
3	10929	8498	3	2004-11-26
4	10929	1427	3	2004-11-26
5	10929	4891	3	2004-11-26
6	10929	8559	3	2004-11-26
7	10929	1878	2	2004-11-26
8	10929	8547	1	2004-11-26
9	10929	1241	1	2004-11-26
1	10930	7986	1	2004-11-14
2	10930	9181	3	2004-11-14
3	10930	1265	3	2004-11-14
4	10930	7894	3	2004-11-14
5	10930	6912	1	2004-11-14
6	10930	186	3	2004-11-14
1	10931	6953	1	2004-11-08
2	10931	3351	2	2004-11-08
3	10931	516	2	2004-11-08
4	10931	1507	3	2004-11-08
1	10932	740	2	2004-11-21
2	10932	7503	3	2004-11-21
1	10933	4458	2	2004-11-20
2	10933	5194	1	2004-11-20
3	10933	8204	2	2004-11-20
4	10933	639	1	2004-11-20
5	10933	4061	3	2004-11-20
6	10933	4878	1	2004-11-20
7	10933	838	3	2004-11-20
1	10934	417	1	2004-11-20
2	10934	777	3	2004-11-20
3	10934	1547	1	2004-11-20
4	10934	6296	3	2004-11-20
5	10934	242	1	2004-11-20
6	10934	5734	3	2004-11-20
7	10934	520	1	2004-11-20
8	10934	4232	2	2004-11-20
1	10935	3263	2	2004-11-05
2	10935	492	3	2004-11-05
1	10936	2683	3	2004-11-19
2	10936	721	1	2004-11-19
3	10936	19	1	2004-11-19
1	10937	616	1	2004-11-10
2	10937	2159	2	2004-11-10
3	10937	1545	1	2004-11-10
4	10937	6539	2	2004-11-10
5	10937	8392	3	2004-11-10
6	10937	8212	3	2004-11-10
7	10937	296	1	2004-11-10
8	10937	4636	1	2004-11-10
9	10937	9615	1	2004-11-10
1	10938	5809	2	2004-11-07
2	10938	7898	2	2004-11-07
3	10938	5710	1	2004-11-07
4	10938	7393	3	2004-11-07
5	10938	368	3	2004-11-07
1	10939	5205	1	2004-11-06
2	10939	9297	2	2004-11-06
3	10939	8994	3	2004-11-06
4	10939	3080	3	2004-11-06
1	10940	8516	1	2004-11-27
2	10940	4581	1	2004-11-27
3	10940	6990	1	2004-11-27
4	10940	6218	2	2004-11-27
5	10940	6217	1	2004-11-27
6	10940	5871	2	2004-11-27
7	10940	650	2	2004-11-27
8	10940	1618	1	2004-11-27
1	10941	6870	2	2004-11-27
2	10941	7564	2	2004-11-27
3	10941	2952	1	2004-11-27
4	10941	5152	1	2004-11-27
1	10942	7418	2	2004-11-26
2	10942	8879	2	2004-11-26
3	10942	5501	2	2004-11-26
4	10942	9294	1	2004-11-26
5	10942	7024	2	2004-11-26
6	10942	5326	3	2004-11-26
7	10942	1402	3	2004-11-26
1	10943	4132	3	2004-11-01
2	10943	1889	1	2004-11-01
3	10943	5650	2	2004-11-01
4	10943	2339	1	2004-11-01
5	10943	6773	1	2004-11-01
6	10943	6028	3	2004-11-01
1	10944	7852	3	2004-11-23
2	10944	1543	3	2004-11-23
3	10944	9633	3	2004-11-23
4	10944	2309	2	2004-11-23
5	10944	6240	2	2004-11-23
6	10944	1902	2	2004-11-23
1	10945	4606	2	2004-11-12
2	10945	9702	1	2004-11-12
3	10945	9710	1	2004-11-12
4	10945	1056	2	2004-11-12
5	10945	2735	3	2004-11-12
6	10945	3786	1	2004-11-12
7	10945	528	2	2004-11-12
8	10945	6749	3	2004-11-12
1	10946	6858	3	2004-11-13
2	10946	8707	1	2004-11-13
3	10946	1543	1	2004-11-13
4	10946	9635	2	2004-11-13
1	10947	7488	1	2004-11-17
1	10948	3680	3	2004-11-01
2	10948	8425	3	2004-11-01
1	10949	7332	3	2004-11-25
2	10949	3241	1	2004-11-25
3	10949	1530	1	2004-11-25
4	10949	690	1	2004-11-25
5	10949	3195	1	2004-11-25
1	10950	5446	1	2004-11-03
2	10950	6302	1	2004-11-03
3	10950	4193	2	2004-11-03
4	10950	131	3	2004-11-03
5	10950	7931	2	2004-11-03
6	10950	7254	2	2004-11-03
1	10951	404	1	2004-11-04
2	10951	2724	2	2004-11-04
3	10951	5496	2	2004-11-04
4	10951	3743	2	2004-11-04
5	10951	4490	3	2004-11-04
1	10952	1603	2	2004-11-26
2	10952	7133	3	2004-11-26
3	10952	8145	1	2004-11-26
4	10952	4494	3	2004-11-26
5	10952	682	1	2004-11-26
6	10952	2086	3	2004-11-26
1	10953	8303	2	2004-11-27
2	10953	6725	1	2004-11-27
3	10953	7438	1	2004-11-27
4	10953	5280	1	2004-11-27
1	10954	5102	3	2004-11-26
2	10954	2883	3	2004-11-26
3	10954	3096	1	2004-11-26
4	10954	4610	1	2004-11-26
5	10954	1341	3	2004-11-26
6	10954	9515	1	2004-11-26
7	10954	1526	1	2004-11-26
1	10955	4390	1	2004-11-30
2	10955	7141	1	2004-11-30
3	10955	4289	2	2004-11-30
4	10955	3333	3	2004-11-30
1	10956	8556	2	2004-11-18
2	10956	1759	1	2004-11-18
3	10956	1143	2	2004-11-18
4	10956	1454	2	2004-11-18
1	10957	4816	2	2004-11-19
2	10957	7209	2	2004-11-19
3	10957	6684	1	2004-11-19
4	10957	8120	1	2004-11-19
5	10957	5433	2	2004-11-19
6	10957	2186	3	2004-11-19
1	10958	7255	3	2004-11-30
2	10958	9472	2	2004-11-30
3	10958	3063	1	2004-11-30
4	10958	7249	2	2004-11-30
5	10958	6085	3	2004-11-30
6	10958	9957	1	2004-11-30
1	10959	1191	2	2004-11-05
2	10959	1084	3	2004-11-05
3	10959	7166	3	2004-11-05
4	10959	8948	1	2004-11-05
5	10959	4463	1	2004-11-05
6	10959	2319	2	2004-11-05
1	10960	232	3	2004-11-20
2	10960	9717	1	2004-11-20
3	10960	598	3	2004-11-20
4	10960	7499	3	2004-11-20
1	10961	2267	2	2004-11-17
2	10961	3472	2	2004-11-17
3	10961	1643	2	2004-11-17
4	10961	1332	3	2004-11-17
5	10961	3758	1	2004-11-17
6	10961	1406	3	2004-11-17
7	10961	1413	2	2004-11-17
1	10962	1971	2	2004-11-08
2	10962	1784	1	2004-11-08
3	10962	8855	1	2004-11-08
1	10963	3808	3	2004-11-26
2	10963	1480	2	2004-11-26
3	10963	4571	2	2004-11-26
4	10963	9532	2	2004-11-26
1	10964	1143	2	2004-11-29
2	10964	1482	1	2004-11-29
3	10964	150	2	2004-11-29
1	10965	1040	3	2004-11-02
2	10965	4277	3	2004-11-02
3	10965	584	1	2004-11-02
1	10966	7571	3	2004-11-19
1	10967	8355	1	2004-11-19
2	10967	6524	2	2004-11-19
3	10967	6446	3	2004-11-19
4	10967	9802	3	2004-11-19
5	10967	221	3	2004-11-19
6	10967	1930	1	2004-11-19
1	10968	6551	3	2004-11-17
2	10968	6364	3	2004-11-17
3	10968	636	1	2004-11-17
4	10968	6781	3	2004-11-17
5	10968	2666	2	2004-11-17
6	10968	6612	3	2004-11-17
1	10969	3474	1	2004-11-20
2	10969	8223	3	2004-11-20
3	10969	8645	3	2004-11-20
4	10969	7848	3	2004-11-20
5	10969	7974	3	2004-11-20
1	10970	9873	2	2004-11-30
2	10970	840	2	2004-11-30
3	10970	1809	1	2004-11-30
1	10971	2942	2	2004-11-27
2	10971	307	3	2004-11-27
1	10972	5741	1	2004-11-19
2	10972	9652	2	2004-11-19
3	10972	528	3	2004-11-19
4	10972	3251	3	2004-11-19
5	10972	7276	1	2004-11-19
6	10972	1905	2	2004-11-19
7	10972	6089	1	2004-11-19
8	10972	77	3	2004-11-19
9	10972	8014	1	2004-11-19
1	10973	8372	2	2004-11-26
2	10973	3732	3	2004-11-26
3	10973	2851	3	2004-11-26
4	10973	3440	3	2004-11-26
5	10973	9724	3	2004-11-26
6	10973	9636	3	2004-11-26
7	10973	3565	1	2004-11-26
1	10974	9770	1	2004-11-21
2	10974	9552	2	2004-11-21
3	10974	2346	3	2004-11-21
4	10974	2788	1	2004-11-21
1	10975	8954	2	2004-11-05
2	10975	5405	1	2004-11-05
1	10976	5386	1	2004-11-13
2	10976	6889	2	2004-11-13
3	10976	1776	1	2004-11-13
4	10976	5184	3	2004-11-13
5	10976	7268	2	2004-11-13
6	10976	2800	3	2004-11-13
7	10976	4415	1	2004-11-13
1	10977	7119	2	2004-11-09
2	10977	6875	2	2004-11-09
3	10977	5480	2	2004-11-09
4	10977	9928	1	2004-11-09
5	10977	8513	2	2004-11-09
6	10977	9138	1	2004-11-09
1	10978	9544	2	2004-11-06
2	10978	9246	2	2004-11-06
3	10978	4013	2	2004-11-06
4	10978	8574	3	2004-11-06
5	10978	3552	1	2004-11-06
6	10978	9163	2	2004-11-06
7	10978	9749	1	2004-11-06
8	10978	2131	3	2004-11-06
1	10979	4833	1	2004-11-14
1	10980	4533	3	2004-11-03
1	10981	3484	2	2004-11-14
2	10981	8928	3	2004-11-14
3	10981	1786	3	2004-11-14
4	10981	4308	2	2004-11-14
1	10982	4611	2	2004-11-02
1	10983	9357	3	2004-11-22
2	10983	9444	1	2004-11-22
3	10983	1097	2	2004-11-22
4	10983	486	2	2004-11-22
5	10983	2005	2	2004-11-22
6	10983	3750	3	2004-11-22
7	10983	9344	3	2004-11-22
8	10983	3302	3	2004-11-22
1	10984	424	2	2004-11-15
2	10984	2505	1	2004-11-15
3	10984	6504	3	2004-11-15
4	10984	6123	2	2004-11-15
5	10984	6360	3	2004-11-15
6	10984	1922	2	2004-11-15
7	10984	6795	1	2004-11-15
8	10984	6068	3	2004-11-15
9	10984	6138	2	2004-11-15
1	10985	6172	1	2004-11-11
2	10985	4503	3	2004-11-11
3	10985	9312	3	2004-11-11
4	10985	4560	2	2004-11-11
5	10985	8266	2	2004-11-11
6	10985	1349	1	2004-11-11
7	10985	7190	3	2004-11-11
1	10986	2355	2	2004-11-24
2	10986	9962	3	2004-11-24
3	10986	4750	2	2004-11-24
4	10986	7042	1	2004-11-24
1	10987	7832	2	2004-11-08
2	10987	5319	1	2004-11-08
3	10987	4674	2	2004-11-08
4	10987	1564	3	2004-11-08
1	10988	599	1	2004-11-30
1	10989	2731	3	2004-11-27
1	10990	8721	1	2004-11-12
2	10990	9398	1	2004-11-12
3	10990	3826	3	2004-11-12
4	10990	5581	1	2004-11-12
5	10990	3627	1	2004-11-12
6	10990	3990	3	2004-11-12
7	10990	5530	2	2004-11-12
8	10990	7535	2	2004-11-12
1	10991	3157	2	2004-11-17
2	10991	4464	3	2004-11-17
3	10991	5604	3	2004-11-17
4	10991	4949	3	2004-11-17
5	10991	9886	1	2004-11-17
6	10991	7877	3	2004-11-17
1	10992	5701	2	2004-11-14
2	10992	9918	3	2004-11-14
3	10992	6389	2	2004-11-14
4	10992	7629	1	2004-11-14
5	10992	9461	2	2004-11-14
6	10992	7162	2	2004-11-14
7	10992	6913	2	2004-11-14
8	10992	821	1	2004-11-14
1	10993	2479	1	2004-11-27
2	10993	3664	1	2004-11-27
3	10993	4067	1	2004-11-27
4	10993	970	3	2004-11-27
1	10994	6367	3	2004-11-27
2	10994	3842	1	2004-11-27
3	10994	590	1	2004-11-27
4	10994	4673	1	2004-11-27
5	10994	6632	1	2004-11-27
1	10995	3615	2	2004-11-15
2	10995	996	1	2004-11-15
3	10995	8299	2	2004-11-15
4	10995	4455	1	2004-11-15
5	10995	5838	3	2004-11-15
6	10995	3501	3	2004-11-15
1	10996	6829	2	2004-11-22
2	10996	470	1	2004-11-22
3	10996	6807	1	2004-11-22
4	10996	2141	1	2004-11-22
1	10997	2317	3	2004-11-04
2	10997	1711	2	2004-11-04
3	10997	2618	1	2004-11-04
4	10997	7493	1	2004-11-04
5	10997	6181	1	2004-11-04
6	10997	2878	1	2004-11-04
1	10998	8693	2	2004-11-02
2	10998	1280	2	2004-11-02
3	10998	563	1	2004-11-02
4	10998	6192	3	2004-11-02
5	10998	2808	3	2004-11-02
6	10998	8848	2	2004-11-02
7	10998	7104	1	2004-11-02
1	10999	5353	2	2004-11-30
2	10999	4333	1	2004-11-30
1	11000	2532	2	2004-11-13
2	11000	3569	1	2004-11-13
3	11000	2752	1	2004-11-13
4	11000	7869	2	2004-11-13
5	11000	7783	3	2004-11-13
6	11000	5780	2	2004-11-13
7	11000	5800	3	2004-11-13
1	11001	7259	1	2004-12-16
2	11001	618	1	2004-12-16
3	11001	7328	2	2004-12-16
4	11001	1387	2	2004-12-16
5	11001	3472	1	2004-12-16
6	11001	8008	1	2004-12-16
7	11001	5368	2	2004-12-16
8	11001	7533	3	2004-12-16
9	11001	8538	3	2004-12-16
1	11002	5650	1	2004-12-26
2	11002	6126	1	2004-12-26
3	11002	6751	1	2004-12-26
1	11003	8467	1	2004-12-08
2	11003	9904	2	2004-12-08
3	11003	6427	1	2004-12-08
4	11003	1953	3	2004-12-08
5	11003	2340	3	2004-12-08
6	11003	601	3	2004-12-08
7	11003	4331	3	2004-12-08
8	11003	5758	1	2004-12-08
9	11003	8024	2	2004-12-08
1	11004	9068	1	2004-12-27
2	11004	4294	2	2004-12-27
3	11004	4433	2	2004-12-27
4	11004	1637	2	2004-12-27
1	11005	5897	2	2004-12-20
2	11005	7369	3	2004-12-20
3	11005	3626	3	2004-12-20
4	11005	7810	2	2004-12-20
5	11005	7415	1	2004-12-20
6	11005	2359	1	2004-12-20
1	11006	7399	2	2004-12-16
2	11006	7817	2	2004-12-16
3	11006	7408	1	2004-12-16
4	11006	2284	1	2004-12-16
1	11007	4024	2	2004-12-28
2	11007	970	3	2004-12-28
3	11007	8430	3	2004-12-28
4	11007	7769	1	2004-12-28
5	11007	8046	2	2004-12-28
1	11008	8634	1	2004-12-20
2	11008	9022	2	2004-12-20
3	11008	6313	2	2004-12-20
4	11008	96	2	2004-12-20
5	11008	2887	3	2004-12-20
6	11008	6240	2	2004-12-20
7	11008	9345	2	2004-12-20
8	11008	9092	3	2004-12-20
1	11009	3035	3	2004-12-31
1	11010	6382	3	2004-12-29
2	11010	2660	2	2004-12-29
3	11010	6850	1	2004-12-29
4	11010	6825	2	2004-12-29
5	11010	7141	1	2004-12-29
6	11010	2293	3	2004-12-29
7	11010	7267	2	2004-12-29
1	11011	8461	3	2004-12-15
2	11011	829	3	2004-12-15
3	11011	2557	1	2004-12-15
4	11011	9122	2	2004-12-15
1	11012	5475	1	2004-12-07
2	11012	2288	3	2004-12-07
3	11012	6876	3	2004-12-07
4	11012	9428	2	2004-12-07
1	11013	3805	2	2004-12-16
2	11013	2481	3	2004-12-16
3	11013	7610	1	2004-12-16
4	11013	2631	2	2004-12-16
5	11013	2273	2	2004-12-16
6	11013	4376	2	2004-12-16
7	11013	5733	2	2004-12-16
1	11014	1959	3	2004-12-02
2	11014	9588	2	2004-12-02
3	11014	5380	2	2004-12-02
4	11014	3383	2	2004-12-02
5	11014	163	3	2004-12-02
6	11014	1375	3	2004-12-02
7	11014	5693	2	2004-12-02
1	11015	1004	2	2004-12-04
2	11015	4783	1	2004-12-04
3	11015	9814	3	2004-12-04
4	11015	8104	2	2004-12-04
5	11015	2655	3	2004-12-04
6	11015	3427	2	2004-12-04
7	11015	5335	2	2004-12-04
8	11015	1672	2	2004-12-04
1	11016	1859	1	2004-12-30
2	11016	1405	1	2004-12-30
3	11016	8549	3	2004-12-30
1	11017	8365	2	2004-12-27
2	11017	8492	1	2004-12-27
1	11018	3851	2	2004-12-30
2	11018	6177	3	2004-12-30
3	11018	9385	1	2004-12-30
4	11018	2662	1	2004-12-30
5	11018	6435	1	2004-12-30
6	11018	8108	3	2004-12-30
7	11018	5306	3	2004-12-30
1	11019	3808	1	2004-12-30
2	11019	7568	3	2004-12-30
3	11019	3748	2	2004-12-30
4	11019	5353	1	2004-12-30
5	11019	9079	2	2004-12-30
6	11019	544	1	2004-12-30
7	11019	2558	2	2004-12-30
8	11019	6341	3	2004-12-30
1	11020	6781	3	2004-12-06
2	11020	6625	2	2004-12-06
3	11020	4501	1	2004-12-06
4	11020	4853	2	2004-12-06
1	11021	9663	3	2004-12-27
2	11021	1526	2	2004-12-27
3	11021	5283	3	2004-12-27
1	11022	5743	2	2004-12-18
2	11022	586	1	2004-12-18
3	11022	3075	1	2004-12-18
4	11022	7808	1	2004-12-18
5	11022	6589	2	2004-12-18
6	11022	2	1	2004-12-18
1	11023	8370	2	2004-12-30
2	11023	2380	1	2004-12-30
3	11023	6231	1	2004-12-30
4	11023	9504	3	2004-12-30
1	11024	9148	2	2004-12-17
1	11025	6973	2	2004-12-23
2	11025	133	2	2004-12-23
3	11025	7153	3	2004-12-23
4	11025	9368	3	2004-12-23
5	11025	9935	3	2004-12-23
6	11025	1657	2	2004-12-23
7	11025	3171	1	2004-12-23
8	11025	8860	2	2004-12-23
1	11026	2846	1	2004-12-01
2	11026	4470	3	2004-12-01
3	11026	4142	2	2004-12-01
4	11026	3897	1	2004-12-01
5	11026	8507	2	2004-12-01
6	11026	9310	2	2004-12-01
7	11026	8485	3	2004-12-01
8	11026	259	2	2004-12-01
9	11026	6164	3	2004-12-01
1	11027	1176	1	2004-12-09
2	11027	4475	1	2004-12-09
3	11027	7189	2	2004-12-09
4	11027	5126	2	2004-12-09
5	11027	4336	3	2004-12-09
1	11028	2422	3	2004-12-25
2	11028	3396	1	2004-12-25
1	11029	2147	2	2004-12-13
2	11029	8124	3	2004-12-13
3	11029	6293	1	2004-12-13
1	11030	6401	3	2004-12-14
2	11030	5620	2	2004-12-14
3	11030	4491	1	2004-12-14
4	11030	8369	3	2004-12-14
5	11030	8716	2	2004-12-14
6	11030	7633	2	2004-12-14
1	11031	983	3	2004-12-26
2	11031	4252	3	2004-12-26
1	11032	4709	1	2004-12-01
2	11032	9041	3	2004-12-01
3	11032	5111	2	2004-12-01
4	11032	4702	1	2004-12-01
5	11032	4242	1	2004-12-01
6	11032	5100	3	2004-12-01
7	11032	1065	2	2004-12-01
8	11032	7560	3	2004-12-01
1	11033	5246	3	2004-12-30
2	11033	9356	2	2004-12-30
3	11033	4978	2	2004-12-30
4	11033	3618	2	2004-12-30
5	11033	6	3	2004-12-30
6	11033	3105	2	2004-12-30
7	11033	8024	1	2004-12-30
8	11033	3832	1	2004-12-30
1	11034	8853	3	2004-12-21
1	11035	9698	1	2004-12-30
2	11035	2274	2	2004-12-30
3	11035	677	3	2004-12-30
4	11035	1107	1	2004-12-30
5	11035	3747	2	2004-12-30
6	11035	3640	3	2004-12-30
7	11035	1064	2	2004-12-30
1	11036	6314	1	2004-12-16
2	11036	6196	1	2004-12-16
3	11036	723	1	2004-12-16
1	11037	9494	2	2004-12-12
2	11037	259	3	2004-12-12
3	11037	6663	1	2004-12-12
1	11038	7373	2	2004-12-09
2	11038	26	1	2004-12-09
3	11038	1163	1	2004-12-09
4	11038	4657	2	2004-12-09
1	11039	5207	2	2004-12-17
2	11039	4433	2	2004-12-17
1	11040	1262	2	2004-12-20
2	11040	675	1	2004-12-20
3	11040	4189	3	2004-12-20
4	11040	4053	3	2004-12-20
5	11040	4677	2	2004-12-20
6	11040	967	1	2004-12-20
7	11040	7902	1	2004-12-20
1	11041	5266	3	2004-12-10
2	11041	733	2	2004-12-10
3	11041	8908	2	2004-12-10
4	11041	9986	2	2004-12-10
5	11041	1869	2	2004-12-10
6	11041	1426	3	2004-12-10
7	11041	3163	1	2004-12-10
1	11042	1174	3	2004-12-08
2	11042	3585	2	2004-12-08
3	11042	2363	2	2004-12-08
4	11042	7899	1	2004-12-08
5	11042	5544	1	2004-12-08
6	11042	9329	3	2004-12-08
1	11043	9122	2	2004-12-27
2	11043	5347	3	2004-12-27
3	11043	7211	3	2004-12-27
4	11043	5390	3	2004-12-27
5	11043	4589	3	2004-12-27
6	11043	1324	3	2004-12-27
7	11043	2389	2	2004-12-27
8	11043	3520	2	2004-12-27
9	11043	3790	3	2004-12-27
1	11044	6417	3	2004-12-30
2	11044	8268	2	2004-12-30
3	11044	4824	3	2004-12-30
4	11044	338	3	2004-12-30
5	11044	6350	3	2004-12-30
6	11044	3657	1	2004-12-30
7	11044	8566	1	2004-12-30
1	11045	2507	1	2004-12-28
2	11045	460	2	2004-12-28
3	11045	6357	2	2004-12-28
4	11045	8457	1	2004-12-28
1	11046	5178	1	2004-12-04
2	11046	9940	2	2004-12-04
3	11046	8459	2	2004-12-04
1	11047	8256	3	2004-12-02
2	11047	8433	3	2004-12-02
3	11047	9074	3	2004-12-02
4	11047	777	3	2004-12-02
5	11047	844	1	2004-12-02
6	11047	9404	1	2004-12-02
7	11047	8178	2	2004-12-02
1	11048	4502	1	2004-12-17
2	11048	9106	3	2004-12-17
3	11048	4920	3	2004-12-17
4	11048	3124	2	2004-12-17
5	11048	3809	2	2004-12-17
6	11048	2175	3	2004-12-17
1	11049	7253	2	2004-12-01
2	11049	6024	3	2004-12-01
3	11049	4215	3	2004-12-01
4	11049	1312	2	2004-12-01
5	11049	8171	3	2004-12-01
6	11049	9379	2	2004-12-01
7	11049	6123	2	2004-12-01
8	11049	9819	1	2004-12-01
1	11050	7970	2	2004-12-24
2	11050	5788	1	2004-12-24
3	11050	6936	3	2004-12-24
1	11051	5862	2	2004-12-01
2	11051	2337	1	2004-12-01
3	11051	3674	2	2004-12-01
4	11051	8754	2	2004-12-01
5	11051	169	3	2004-12-01
6	11051	4475	3	2004-12-01
7	11051	378	1	2004-12-01
1	11052	9120	1	2004-12-15
2	11052	4730	3	2004-12-15
3	11052	4950	1	2004-12-15
1	11053	9068	3	2004-12-28
2	11053	5701	2	2004-12-28
3	11053	2517	3	2004-12-28
4	11053	6816	2	2004-12-28
5	11053	4588	2	2004-12-28
6	11053	1176	2	2004-12-28
7	11053	2494	2	2004-12-28
8	11053	4302	1	2004-12-28
9	11053	6248	3	2004-12-28
1	11054	8993	2	2004-12-10
2	11054	9275	2	2004-12-10
1	11055	7143	2	2004-12-21
2	11055	2052	1	2004-12-21
3	11055	9826	2	2004-12-21
4	11055	879	2	2004-12-21
5	11055	759	2	2004-12-21
1	11056	7584	2	2004-12-07
2	11056	7575	2	2004-12-07
3	11056	3656	1	2004-12-07
4	11056	1300	2	2004-12-07
5	11056	2828	1	2004-12-07
1	11057	244	1	2004-12-05
2	11057	3174	3	2004-12-05
3	11057	4958	2	2004-12-05
4	11057	228	2	2004-12-05
5	11057	9793	1	2004-12-05
6	11057	1425	1	2004-12-05
7	11057	6573	2	2004-12-05
8	11057	2485	3	2004-12-05
1	11058	3899	2	2004-12-26
2	11058	6555	2	2004-12-26
3	11058	82	3	2004-12-26
4	11058	5491	1	2004-12-26
5	11058	1485	3	2004-12-26
6	11058	9368	1	2004-12-26
1	11059	7765	3	2004-12-31
2	11059	9527	3	2004-12-31
3	11059	447	1	2004-12-31
4	11059	8108	3	2004-12-31
5	11059	4586	1	2004-12-31
1	11060	8838	2	2004-12-12
2	11060	101	2	2004-12-12
3	11060	9757	1	2004-12-12
4	11060	4775	2	2004-12-12
5	11060	1556	2	2004-12-12
1	11061	3464	3	2004-12-16
2	11061	9501	1	2004-12-16
3	11061	6441	3	2004-12-16
4	11061	8785	3	2004-12-16
5	11061	9978	3	2004-12-16
1	11062	7488	3	2004-12-13
2	11062	2848	2	2004-12-13
3	11062	2701	1	2004-12-13
4	11062	1718	1	2004-12-13
5	11062	3131	2	2004-12-13
6	11062	7703	2	2004-12-13
7	11062	2752	1	2004-12-13
1	11063	7839	3	2004-12-18
2	11063	300	2	2004-12-18
3	11063	5959	3	2004-12-18
4	11063	1165	2	2004-12-18
5	11063	5977	2	2004-12-18
6	11063	499	2	2004-12-18
7	11063	2789	3	2004-12-18
8	11063	1602	2	2004-12-18
9	11063	4311	2	2004-12-18
1	11064	2521	2	2004-12-27
2	11064	6401	2	2004-12-27
1	11065	1082	2	2004-12-23
2	11065	1497	1	2004-12-23
3	11065	8127	3	2004-12-23
4	11065	466	3	2004-12-23
5	11065	3391	2	2004-12-23
1	11066	1875	1	2004-12-14
2	11066	2787	2	2004-12-14
3	11066	5806	1	2004-12-14
4	11066	2214	1	2004-12-14
5	11066	3086	2	2004-12-14
6	11066	7025	3	2004-12-14
7	11066	6	2	2004-12-14
1	11067	9865	1	2004-12-05
2	11067	3959	3	2004-12-05
3	11067	7676	2	2004-12-05
1	11068	4955	1	2004-12-23
2	11068	8795	3	2004-12-23
1	11069	2952	2	2004-12-08
2	11069	642	2	2004-12-08
3	11069	9961	3	2004-12-08
4	11069	5524	3	2004-12-08
5	11069	1826	3	2004-12-08
6	11069	5982	1	2004-12-08
7	11069	9597	2	2004-12-08
8	11069	772	2	2004-12-08
1	11070	9512	3	2004-12-12
2	11070	2762	2	2004-12-12
1	11071	3137	2	2004-12-30
2	11071	9964	2	2004-12-30
1	11072	8271	3	2004-12-30
2	11072	9462	1	2004-12-30
3	11072	4671	2	2004-12-30
4	11072	647	2	2004-12-30
5	11072	1290	1	2004-12-30
6	11072	7822	2	2004-12-30
7	11072	9864	2	2004-12-30
8	11072	6245	3	2004-12-30
9	11072	4647	3	2004-12-30
1	11073	6147	2	2004-12-12
2	11073	9444	2	2004-12-12
3	11073	9788	3	2004-12-12
4	11073	6714	1	2004-12-12
5	11073	8475	2	2004-12-12
1	11074	3381	2	2004-12-30
2	11074	8502	2	2004-12-30
3	11074	7144	2	2004-12-30
4	11074	9796	3	2004-12-30
1	11075	5047	1	2004-12-07
2	11075	1032	2	2004-12-07
3	11075	5360	3	2004-12-07
4	11075	9308	2	2004-12-07
5	11075	3288	3	2004-12-07
6	11075	3782	1	2004-12-07
7	11075	1010	1	2004-12-07
1	11076	4809	2	2004-12-16
1	11077	9634	3	2004-12-18
2	11077	9944	1	2004-12-18
3	11077	4079	2	2004-12-18
1	11078	4733	1	2004-12-27
2	11078	6740	2	2004-12-27
3	11078	6713	1	2004-12-27
4	11078	3135	1	2004-12-27
5	11078	29	2	2004-12-27
6	11078	2750	2	2004-12-27
7	11078	4718	1	2004-12-27
8	11078	5081	3	2004-12-27
9	11078	6516	1	2004-12-27
1	11079	2796	2	2004-12-09
2	11079	4230	3	2004-12-09
3	11079	81	1	2004-12-09
1	11080	8541	3	2004-12-19
1	11081	5747	3	2004-12-15
2	11081	2049	3	2004-12-15
3	11081	4132	3	2004-12-15
4	11081	1439	3	2004-12-15
5	11081	6294	3	2004-12-15
6	11081	86	3	2004-12-15
7	11081	2711	2	2004-12-15
8	11081	1602	2	2004-12-15
1	11082	8590	3	2004-12-24
2	11082	4359	1	2004-12-24
3	11082	9110	1	2004-12-24
4	11082	9971	2	2004-12-24
5	11082	8151	3	2004-12-24
6	11082	1785	2	2004-12-24
7	11082	8176	2	2004-12-24
1	11083	1519	3	2004-12-08
2	11083	1784	1	2004-12-08
3	11083	6024	2	2004-12-08
4	11083	5499	3	2004-12-08
1	11084	875	1	2004-12-01
2	11084	761	2	2004-12-01
3	11084	2955	3	2004-12-01
1	11085	1984	2	2004-12-26
2	11085	180	1	2004-12-26
3	11085	9367	1	2004-12-26
4	11085	2466	3	2004-12-26
5	11085	6403	2	2004-12-26
6	11085	6861	3	2004-12-26
1	11086	509	1	2004-12-18
1	11087	6009	2	2004-12-14
2	11087	341	3	2004-12-14
3	11087	5694	3	2004-12-14
4	11087	1889	3	2004-12-14
5	11087	4755	2	2004-12-14
1	11088	7506	2	2004-12-16
2	11088	4310	2	2004-12-16
3	11088	481	1	2004-12-16
4	11088	2096	2	2004-12-16
1	11089	7460	1	2004-12-13
2	11089	8527	1	2004-12-13
3	11089	6498	2	2004-12-13
4	11089	8349	3	2004-12-13
5	11089	3499	2	2004-12-13
1	11090	9259	3	2004-12-17
1	11091	9785	3	2004-12-16
2	11091	6413	1	2004-12-16
3	11091	8284	3	2004-12-16
1	11092	6901	1	2004-12-20
2	11092	4881	2	2004-12-20
3	11092	3269	1	2004-12-20
4	11092	9963	1	2004-12-20
1	11093	8849	3	2004-12-26
2	11093	3593	3	2004-12-26
3	11093	7605	3	2004-12-26
4	11093	1397	1	2004-12-26
1	11094	1447	2	2004-12-04
2	11094	6017	3	2004-12-04
3	11094	8144	3	2004-12-04
4	11094	1271	2	2004-12-04
5	11094	48	2	2004-12-04
6	11094	471	1	2004-12-04
7	11094	7529	1	2004-12-04
1	11095	9273	1	2004-12-16
1	11096	1457	1	2004-12-31
2	11096	7748	1	2004-12-31
3	11096	3430	2	2004-12-31
4	11096	60	2	2004-12-31
5	11096	1076	2	2004-12-31
6	11096	2658	3	2004-12-31
7	11096	5379	2	2004-12-31
1	11097	8743	3	2004-12-14
2	11097	5167	2	2004-12-14
3	11097	3354	3	2004-12-14
4	11097	4269	1	2004-12-14
5	11097	1806	2	2004-12-14
1	11098	4906	3	2004-12-18
2	11098	9500	3	2004-12-18
3	11098	4362	3	2004-12-18
4	11098	3212	2	2004-12-18
5	11098	5637	2	2004-12-18
6	11098	4656	1	2004-12-18
7	11098	9798	3	2004-12-18
1	11099	7486	3	2004-12-20
2	11099	8859	1	2004-12-20
3	11099	7879	1	2004-12-20
4	11099	3466	3	2004-12-20
5	11099	7131	3	2004-12-20
1	11100	7566	2	2004-12-08
2	11100	5581	1	2004-12-08
3	11100	4964	3	2004-12-08
4	11100	7364	1	2004-12-08
5	11100	4662	1	2004-12-08
6	11100	1615	2	2004-12-08
7	11100	938	3	2004-12-08
1	11101	3405	1	2004-12-14
2	11101	2661	1	2004-12-14
1	11102	5083	1	2004-12-17
2	11102	830	1	2004-12-17
3	11102	553	3	2004-12-17
1	11103	4927	3	2004-12-20
2	11103	1956	3	2004-12-20
1	11104	1625	3	2004-12-31
1	11105	6961	1	2004-12-17
2	11105	9919	1	2004-12-17
3	11105	8990	1	2004-12-17
4	11105	4541	2	2004-12-17
5	11105	4193	2	2004-12-17
6	11105	5059	2	2004-12-17
7	11105	3765	1	2004-12-17
8	11105	880	2	2004-12-17
1	11106	5394	1	2004-12-09
2	11106	8331	3	2004-12-09
3	11106	2121	3	2004-12-09
4	11106	7823	3	2004-12-09
5	11106	4819	3	2004-12-09
1	11107	3966	3	2004-12-19
2	11107	6789	3	2004-12-19
3	11107	3952	1	2004-12-19
4	11107	3876	3	2004-12-19
5	11107	5727	3	2004-12-19
6	11107	461	2	2004-12-19
1	11108	8027	3	2004-12-06
2	11108	4978	2	2004-12-06
3	11108	7245	3	2004-12-06
4	11108	6313	2	2004-12-06
1	11109	2912	2	2004-12-14
1	11110	5383	3	2004-12-20
2	11110	4107	3	2004-12-20
3	11110	6825	3	2004-12-20
1	11111	552	3	2004-12-22
2	11111	2128	3	2004-12-22
3	11111	6655	3	2004-12-22
4	11111	4936	2	2004-12-22
5	11111	4203	1	2004-12-22
6	11111	8966	3	2004-12-22
7	11111	2381	1	2004-12-22
8	11111	9085	2	2004-12-22
1	11112	8548	3	2004-12-19
2	11112	7722	1	2004-12-19
3	11112	6811	2	2004-12-19
4	11112	2488	2	2004-12-19
5	11112	1833	3	2004-12-19
6	11112	2338	1	2004-12-19
7	11112	7778	2	2004-12-19
8	11112	963	2	2004-12-19
9	11112	1570	2	2004-12-19
1	11113	4424	3	2004-12-26
2	11113	9357	2	2004-12-26
3	11113	4820	2	2004-12-26
4	11113	8930	3	2004-12-26
5	11113	5307	3	2004-12-26
6	11113	4541	1	2004-12-26
7	11113	131	1	2004-12-26
1	11114	1546	3	2004-12-24
2	11114	1791	3	2004-12-24
3	11114	1863	1	2004-12-24
4	11114	3756	2	2004-12-24
5	11114	8652	1	2004-12-24
6	11114	9204	2	2004-12-24
7	11114	9385	2	2004-12-24
8	11114	5326	3	2004-12-24
9	11114	7135	1	2004-12-24
1	11115	3541	1	2004-12-13
2	11115	2477	2	2004-12-13
3	11115	3026	1	2004-12-13
4	11115	6289	3	2004-12-13
5	11115	9458	3	2004-12-13
6	11115	5485	1	2004-12-13
7	11115	7158	3	2004-12-13
8	11115	4002	1	2004-12-13
9	11115	778	1	2004-12-13
1	11116	3609	2	2004-12-10
2	11116	1126	1	2004-12-10
3	11116	3921	2	2004-12-10
1	11117	2729	3	2004-12-22
1	11118	3841	3	2004-12-13
1	11119	6671	1	2004-12-26
2	11119	6210	3	2004-12-26
3	11119	4602	3	2004-12-26
4	11119	7431	1	2004-12-26
5	11119	1594	1	2004-12-26
1	11120	7986	3	2004-12-22
1	11121	9892	1	2004-12-06
2	11121	287	3	2004-12-06
3	11121	3258	2	2004-12-06
4	11121	3835	1	2004-12-06
5	11121	3452	1	2004-12-06
1	11122	7571	3	2004-12-21
2	11122	2114	2	2004-12-21
3	11122	1386	2	2004-12-21
1	11123	8963	2	2004-12-19
2	11123	6409	1	2004-12-19
3	11123	7114	2	2004-12-19
4	11123	5298	3	2004-12-19
5	11123	8294	2	2004-12-19
6	11123	4140	1	2004-12-19
7	11123	9711	3	2004-12-19
8	11123	2949	1	2004-12-19
1	11124	2548	1	2004-12-31
2	11124	1823	2	2004-12-31
3	11124	5856	1	2004-12-31
4	11124	8370	1	2004-12-31
1	11125	9209	2	2004-12-05
1	11126	3328	3	2004-12-04
2	11126	2031	3	2004-12-04
3	11126	1311	1	2004-12-04
4	11126	5442	2	2004-12-04
5	11126	4903	2	2004-12-04
6	11126	3902	3	2004-12-04
1	11127	1111	2	2004-12-27
1	11128	4276	2	2004-12-12
2	11128	5523	2	2004-12-12
3	11128	2630	3	2004-12-12
4	11128	9807	2	2004-12-12
5	11128	3119	1	2004-12-12
1	11129	6892	2	2004-12-12
2	11129	9424	1	2004-12-12
3	11129	1240	1	2004-12-12
4	11129	9981	3	2004-12-12
5	11129	9775	3	2004-12-12
1	11130	366	1	2004-12-02
2	11130	9290	2	2004-12-02
3	11130	7214	2	2004-12-02
4	11130	8126	3	2004-12-02
1	11131	1066	3	2004-12-05
2	11131	9752	1	2004-12-05
3	11131	2959	2	2004-12-05
4	11131	7708	1	2004-12-05
5	11131	8438	3	2004-12-05
1	11132	7440	3	2004-12-18
2	11132	6368	1	2004-12-18
3	11132	3458	3	2004-12-18
4	11132	2064	1	2004-12-18
5	11132	1375	3	2004-12-18
1	11133	7432	1	2004-12-24
2	11133	3644	3	2004-12-24
3	11133	854	2	2004-12-24
4	11133	164	2	2004-12-24
5	11133	39	3	2004-12-24
6	11133	6195	3	2004-12-24
7	11133	6819	1	2004-12-24
8	11133	6894	2	2004-12-24
9	11133	7385	2	2004-12-24
1	11134	486	3	2004-12-16
2	11134	1201	1	2004-12-16
3	11134	7031	3	2004-12-16
4	11134	1361	2	2004-12-16
5	11134	7800	3	2004-12-16
6	11134	9213	1	2004-12-16
7	11134	7289	1	2004-12-16
8	11134	4838	3	2004-12-16
1	11135	3352	1	2004-12-13
1	11136	4579	1	2004-12-07
2	11136	3111	1	2004-12-07
3	11136	1284	2	2004-12-07
4	11136	8021	1	2004-12-07
5	11136	5456	2	2004-12-07
6	11136	1243	3	2004-12-07
7	11136	1204	3	2004-12-07
8	11136	5608	1	2004-12-07
9	11136	484	1	2004-12-07
1	11137	198	2	2004-12-02
2	11137	4433	2	2004-12-02
3	11137	7813	2	2004-12-02
4	11137	3795	2	2004-12-02
1	11138	8640	3	2004-12-18
2	11138	2472	2	2004-12-18
3	11138	2242	3	2004-12-18
4	11138	1712	2	2004-12-18
5	11138	4743	1	2004-12-18
6	11138	2526	1	2004-12-18
7	11138	3331	1	2004-12-18
8	11138	3247	2	2004-12-18
1	11139	9267	1	2004-12-26
2	11139	2076	3	2004-12-26
3	11139	9011	2	2004-12-26
4	11139	2725	2	2004-12-26
5	11139	4243	1	2004-12-26
6	11139	3653	1	2004-12-26
7	11139	958	2	2004-12-26
8	11139	9544	1	2004-12-26
1	11140	4170	3	2004-12-13
2	11140	9146	3	2004-12-13
3	11140	2217	1	2004-12-13
4	11140	1311	1	2004-12-13
5	11140	5988	3	2004-12-13
6	11140	9074	2	2004-12-13
7	11140	2087	1	2004-12-13
8	11140	2334	1	2004-12-13
1	11141	6258	3	2004-12-22
2	11141	4146	3	2004-12-22
1	11142	4943	3	2004-12-18
2	11142	8497	3	2004-12-18
3	11142	6305	3	2004-12-18
4	11142	6612	3	2004-12-18
5	11142	34	3	2004-12-18
6	11142	9068	2	2004-12-18
7	11142	7405	3	2004-12-18
8	11142	1275	3	2004-12-18
9	11142	9291	2	2004-12-18
1	11143	7573	2	2004-12-02
2	11143	5986	1	2004-12-02
3	11143	2140	1	2004-12-02
4	11143	5407	1	2004-12-02
5	11143	1338	1	2004-12-02
6	11143	9651	3	2004-12-02
1	11144	4476	3	2004-12-30
2	11144	3995	2	2004-12-30
3	11144	3528	1	2004-12-30
4	11144	1684	2	2004-12-30
5	11144	889	1	2004-12-30
6	11144	8411	1	2004-12-30
1	11145	2003	2	2004-12-23
2	11145	6574	2	2004-12-23
3	11145	5558	1	2004-12-23
4	11145	6696	3	2004-12-23
5	11145	2329	2	2004-12-23
1	11146	7862	3	2004-12-21
2	11146	1711	1	2004-12-21
3	11146	319	2	2004-12-21
4	11146	3255	1	2004-12-21
1	11147	5619	1	2004-12-01
2	11147	5529	2	2004-12-01
3	11147	5115	3	2004-12-01
4	11147	7477	1	2004-12-01
5	11147	1674	1	2004-12-01
6	11147	3667	3	2004-12-01
7	11147	9931	2	2004-12-01
8	11147	4716	2	2004-12-01
1	11148	3791	1	2004-12-25
2	11148	7503	2	2004-12-25
3	11148	7812	1	2004-12-25
4	11148	6111	3	2004-12-25
5	11148	4900	3	2004-12-25
6	11148	6305	1	2004-12-25
1	11149	9365	1	2004-12-29
2	11149	6146	1	2004-12-29
3	11149	4586	3	2004-12-29
4	11149	9407	2	2004-12-29
5	11149	5808	2	2004-12-29
1	11150	9238	2	2004-12-04
2	11150	4610	3	2004-12-04
1	11151	274	1	2004-12-29
2	11151	4235	2	2004-12-29
3	11151	2916	2	2004-12-29
4	11151	8412	3	2004-12-29
5	11151	8038	3	2004-12-29
1	11152	3996	3	2004-12-27
2	11152	7640	3	2004-12-27
3	11152	2342	3	2004-12-27
1	11153	8408	2	2004-12-11
2	11153	9372	3	2004-12-11
3	11153	7880	3	2004-12-11
1	11154	4732	1	2004-12-09
2	11154	405	1	2004-12-09
3	11154	9169	3	2004-12-09
4	11154	918	3	2004-12-09
5	11154	2625	3	2004-12-09
6	11154	832	2	2004-12-09
7	11154	7952	3	2004-12-09
1	11155	3772	3	2004-12-20
2	11155	2449	1	2004-12-20
3	11155	3593	1	2004-12-20
4	11155	9623	1	2004-12-20
5	11155	8689	1	2004-12-20
6	11155	9625	3	2004-12-20
7	11155	9042	2	2004-12-20
8	11155	135	3	2004-12-20
9	11155	7499	3	2004-12-20
1	11156	8148	3	2004-12-25
1	11157	6392	2	2004-12-23
2	11157	3373	1	2004-12-23
3	11157	1734	2	2004-12-23
4	11157	2342	2	2004-12-23
1	11158	4180	2	2004-12-24
2	11158	4284	1	2004-12-24
3	11158	779	2	2004-12-24
4	11158	2669	3	2004-12-24
5	11158	3721	1	2004-12-24
6	11158	6693	1	2004-12-24
1	11159	939	2	2004-12-04
2	11159	1759	3	2004-12-04
3	11159	8489	2	2004-12-04
4	11159	7494	1	2004-12-04
5	11159	952	3	2004-12-04
6	11159	5548	3	2004-12-04
7	11159	1799	1	2004-12-04
8	11159	4921	2	2004-12-04
1	11160	3622	1	2004-12-28
2	11160	7822	3	2004-12-28
3	11160	2425	2	2004-12-28
4	11160	8075	2	2004-12-28
5	11160	9355	2	2004-12-28
6	11160	1698	1	2004-12-28
7	11160	1539	2	2004-12-28
8	11160	7624	1	2004-12-28
9	11160	8587	2	2004-12-28
1	11161	8130	3	2004-12-01
2	11161	8141	1	2004-12-01
3	11161	2729	3	2004-12-01
4	11161	2255	1	2004-12-01
5	11161	6453	2	2004-12-01
6	11161	3797	2	2004-12-01
1	11162	9716	3	2004-12-10
2	11162	7943	1	2004-12-10
1	11163	9509	2	2004-12-27
2	11163	1178	3	2004-12-27
3	11163	2994	2	2004-12-27
4	11163	5553	1	2004-12-27
5	11163	2880	2	2004-12-27
6	11163	4174	2	2004-12-27
1	11164	2304	1	2004-12-02
2	11164	1328	2	2004-12-02
3	11164	7554	1	2004-12-02
4	11164	6816	3	2004-12-02
5	11164	8261	2	2004-12-02
6	11164	8682	3	2004-12-02
7	11164	4239	2	2004-12-02
1	11165	3504	1	2004-12-09
2	11165	65	3	2004-12-09
3	11165	1124	1	2004-12-09
4	11165	2749	2	2004-12-09
1	11166	404	2	2004-12-27
2	11166	7422	1	2004-12-27
3	11166	9552	2	2004-12-27
4	11166	1848	2	2004-12-27
5	11166	2245	1	2004-12-27
6	11166	1124	1	2004-12-27
1	11167	9109	1	2004-12-22
2	11167	3499	1	2004-12-22
3	11167	1485	2	2004-12-22
4	11167	1668	1	2004-12-22
5	11167	6508	2	2004-12-22
6	11167	7906	2	2004-12-22
7	11167	7767	3	2004-12-22
8	11167	1149	3	2004-12-22
9	11167	3660	3	2004-12-22
1	11168	9577	2	2004-12-31
2	11168	1856	1	2004-12-31
1	11169	8224	2	2004-12-21
2	11169	2676	1	2004-12-21
1	11170	6768	1	2004-12-25
2	11170	3867	2	2004-12-25
3	11170	6854	1	2004-12-25
4	11170	4304	3	2004-12-25
5	11170	9802	3	2004-12-25
6	11170	6572	3	2004-12-25
7	11170	1173	1	2004-12-25
8	11170	1451	1	2004-12-25
9	11170	5905	1	2004-12-25
1	11171	3812	1	2004-12-05
2	11171	2683	2	2004-12-05
3	11171	1913	1	2004-12-05
4	11171	648	3	2004-12-05
5	11171	9916	3	2004-12-05
6	11171	8993	2	2004-12-05
7	11171	2089	2	2004-12-05
1	11172	4355	1	2004-12-17
2	11172	4918	2	2004-12-17
3	11172	535	2	2004-12-17
4	11172	6277	2	2004-12-17
5	11172	9675	3	2004-12-17
1	11173	1831	3	2004-12-29
2	11173	9359	2	2004-12-29
3	11173	8386	1	2004-12-29
1	11174	2083	3	2004-12-03
2	11174	5782	3	2004-12-03
3	11174	5903	3	2004-12-03
4	11174	2712	1	2004-12-03
5	11174	49	3	2004-12-03
6	11174	5784	1	2004-12-03
7	11174	3998	1	2004-12-03
8	11174	7022	2	2004-12-03
9	11174	9786	2	2004-12-03
1	11175	2944	3	2004-12-17
2	11175	887	1	2004-12-17
3	11175	8315	1	2004-12-17
4	11175	9630	2	2004-12-17
5	11175	1765	1	2004-12-17
6	11175	5246	3	2004-12-17
7	11175	9209	1	2004-12-17
1	11176	9550	3	2004-12-23
2	11176	7806	2	2004-12-23
3	11176	9249	2	2004-12-23
4	11176	7220	3	2004-12-23
5	11176	908	1	2004-12-23
6	11176	4058	3	2004-12-23
7	11176	9676	3	2004-12-23
1	11177	2392	3	2004-12-26
2	11177	2216	2	2004-12-26
3	11177	9674	3	2004-12-26
4	11177	1702	3	2004-12-26
5	11177	8610	3	2004-12-26
6	11177	802	1	2004-12-26
1	11178	3900	2	2004-12-19
2	11178	8733	1	2004-12-19
3	11178	5487	3	2004-12-19
4	11178	3651	3	2004-12-19
1	11179	3888	2	2004-12-30
2	11179	4143	2	2004-12-30
3	11179	2838	2	2004-12-30
4	11179	436	1	2004-12-30
5	11179	3820	1	2004-12-30
6	11179	1392	1	2004-12-30
7	11179	1014	1	2004-12-30
1	11180	1019	2	2004-12-08
2	11180	6099	3	2004-12-08
3	11180	7564	1	2004-12-08
4	11180	9391	1	2004-12-08
5	11180	1129	3	2004-12-08
6	11180	4540	3	2004-12-08
7	11180	6550	3	2004-12-08
8	11180	2551	1	2004-12-08
9	11180	4708	2	2004-12-08
1	11181	7279	3	2004-12-22
1	11182	5405	2	2004-12-11
2	11182	5392	2	2004-12-11
3	11182	473	1	2004-12-11
4	11182	6174	3	2004-12-11
5	11182	3076	2	2004-12-11
6	11182	9250	2	2004-12-11
1	11183	2218	2	2004-12-14
1	11184	2067	3	2004-12-06
2	11184	9616	3	2004-12-06
3	11184	7006	1	2004-12-06
4	11184	7638	3	2004-12-06
5	11184	8661	1	2004-12-06
6	11184	2517	2	2004-12-06
7	11184	9466	1	2004-12-06
8	11184	5543	2	2004-12-06
1	11185	2822	2	2004-12-04
1	11186	9130	3	2004-12-13
2	11186	3207	3	2004-12-13
3	11186	7093	2	2004-12-13
4	11186	6663	3	2004-12-13
5	11186	4619	2	2004-12-13
6	11186	9624	1	2004-12-13
1	11187	2336	2	2004-12-07
2	11187	7661	3	2004-12-07
3	11187	403	3	2004-12-07
4	11187	6497	1	2004-12-07
5	11187	8960	3	2004-12-07
1	11188	9306	1	2004-12-23
2	11188	2260	1	2004-12-23
3	11188	2097	3	2004-12-23
4	11188	7786	3	2004-12-23
1	11189	4661	2	2004-12-19
2	11189	3967	3	2004-12-19
3	11189	9255	2	2004-12-19
4	11189	4724	3	2004-12-19
5	11189	4181	2	2004-12-19
6	11189	5601	1	2004-12-19
1	11190	7584	2	2004-12-21
2	11190	7900	3	2004-12-21
3	11190	7163	1	2004-12-21
4	11190	9402	3	2004-12-21
1	11191	9593	1	2004-12-30
2	11191	1254	2	2004-12-30
3	11191	5027	2	2004-12-30
4	11191	4213	2	2004-12-30
5	11191	1522	3	2004-12-30
6	11191	1196	2	2004-12-30
1	11192	1356	2	2004-12-13
1	11193	5830	3	2004-12-15
2	11193	2839	2	2004-12-15
3	11193	6812	1	2004-12-15
1	11194	5274	3	2004-12-08
2	11194	6265	1	2004-12-08
1	11195	9414	2	2004-12-14
2	11195	1618	2	2004-12-14
3	11195	2573	3	2004-12-14
4	11195	4267	2	2004-12-14
5	11195	4373	3	2004-12-14
6	11195	2868	2	2004-12-14
1	11196	3929	3	2004-12-06
2	11196	6912	2	2004-12-06
3	11196	3956	2	2004-12-06
4	11196	8358	3	2004-12-06
5	11196	4006	2	2004-12-06
1	11197	4314	2	2004-12-30
2	11197	9887	2	2004-12-30
3	11197	7989	1	2004-12-30
4	11197	3929	1	2004-12-30
1	11198	3064	1	2004-12-20
2	11198	7953	2	2004-12-20
3	11198	7586	1	2004-12-20
4	11198	4505	2	2004-12-20
5	11198	8228	3	2004-12-20
6	11198	9331	2	2004-12-20
7	11198	7690	2	2004-12-20
8	11198	1209	3	2004-12-20
9	11198	1734	2	2004-12-20
1	11199	1978	3	2004-12-05
2	11199	3676	2	2004-12-05
1	11200	9320	3	2004-12-04
2	11200	5388	3	2004-12-04
3	11200	2650	1	2004-12-04
1	11201	5615	3	2004-12-29
2	11201	3967	1	2004-12-29
3	11201	137	2	2004-12-29
4	11201	524	1	2004-12-29
5	11201	1484	1	2004-12-29
6	11201	7918	1	2004-12-29
7	11201	3069	3	2004-12-29
1	11202	6808	1	2004-12-04
2	11202	4544	2	2004-12-04
1	11203	2904	1	2004-12-23
2	11203	7083	1	2004-12-23
3	11203	9933	1	2004-12-23
4	11203	7177	2	2004-12-23
5	11203	6002	3	2004-12-23
6	11203	9075	2	2004-12-23
7	11203	9184	1	2004-12-23
8	11203	8379	3	2004-12-23
9	11203	2864	1	2004-12-23
1	11204	6158	2	2004-12-22
2	11204	2806	1	2004-12-22
3	11204	1126	1	2004-12-22
1	11205	7077	3	2004-12-02
2	11205	3911	3	2004-12-02
3	11205	9791	1	2004-12-02
4	11205	910	2	2004-12-02
1	11206	543	1	2004-12-27
2	11206	4686	2	2004-12-27
3	11206	2145	1	2004-12-27
4	11206	7386	1	2004-12-27
5	11206	4480	2	2004-12-27
6	11206	5336	3	2004-12-27
7	11206	4245	2	2004-12-27
1	11207	8411	3	2004-12-23
2	11207	4475	1	2004-12-23
3	11207	5072	2	2004-12-23
4	11207	3409	2	2004-12-23
5	11207	58	1	2004-12-23
6	11207	5965	1	2004-12-23
7	11207	9394	2	2004-12-23
1	11208	5762	3	2004-12-10
2	11208	5554	1	2004-12-10
3	11208	842	1	2004-12-10
4	11208	7525	2	2004-12-10
5	11208	7350	2	2004-12-10
1	11209	6397	3	2004-12-31
2	11209	694	1	2004-12-31
3	11209	1014	2	2004-12-31
4	11209	7449	1	2004-12-31
5	11209	5911	2	2004-12-31
6	11209	3448	2	2004-12-31
7	11209	9921	2	2004-12-31
8	11209	9384	3	2004-12-31
1	11210	5386	3	2004-12-06
2	11210	8180	1	2004-12-06
3	11210	3061	2	2004-12-06
4	11210	7804	1	2004-12-06
5	11210	3863	1	2004-12-06
6	11210	1395	1	2004-12-06
7	11210	6826	1	2004-12-06
1	11211	8910	1	2004-12-06
2	11211	2589	1	2004-12-06
3	11211	7405	1	2004-12-06
4	11211	8878	3	2004-12-06
5	11211	2343	1	2004-12-06
6	11211	1934	3	2004-12-06
7	11211	7907	3	2004-12-06
8	11211	7451	2	2004-12-06
9	11211	230	1	2004-12-06
1	11212	8112	2	2004-12-06
2	11212	5737	2	2004-12-06
3	11212	7015	3	2004-12-06
4	11212	2776	1	2004-12-06
5	11212	6640	1	2004-12-06
1	11213	1737	1	2004-12-17
2	11213	9498	2	2004-12-17
3	11213	3535	1	2004-12-17
1	11214	7527	3	2004-12-12
1	11215	4619	2	2004-12-05
2	11215	9978	1	2004-12-05
3	11215	62	3	2004-12-05
4	11215	7819	1	2004-12-05
5	11215	196	2	2004-12-05
1	11216	8210	2	2004-12-15
2	11216	1484	3	2004-12-15
3	11216	9502	2	2004-12-15
4	11216	9139	1	2004-12-15
5	11216	6460	3	2004-12-15
6	11216	4063	2	2004-12-15
7	11216	6870	2	2004-12-15
8	11216	3128	2	2004-12-15
1	11217	8101	3	2004-12-02
1	11218	377	2	2004-12-24
2	11218	3294	2	2004-12-24
3	11218	4995	1	2004-12-24
4	11218	9484	2	2004-12-24
5	11218	9210	3	2004-12-24
6	11218	1496	3	2004-12-24
7	11218	2042	3	2004-12-24
8	11218	6238	2	2004-12-24
1	11219	6991	1	2004-12-07
2	11219	2814	2	2004-12-07
3	11219	2919	1	2004-12-07
4	11219	5071	1	2004-12-07
5	11219	6832	3	2004-12-07
1	11220	1271	3	2004-12-26
2	11220	3108	1	2004-12-26
1	11221	666	1	2004-12-16
2	11221	4332	3	2004-12-16
3	11221	7884	2	2004-12-16
4	11221	10	3	2004-12-16
5	11221	1341	3	2004-12-16
6	11221	1878	2	2004-12-16
1	11222	5312	1	2004-12-10
2	11222	5050	2	2004-12-10
3	11222	9107	3	2004-12-10
4	11222	5227	1	2004-12-10
5	11222	6863	3	2004-12-10
6	11222	1132	1	2004-12-10
7	11222	650	1	2004-12-10
8	11222	8121	1	2004-12-10
1	11223	8725	3	2004-12-09
1	11224	4219	3	2004-12-01
2	11224	6772	3	2004-12-01
1	11225	5705	1	2004-12-20
2	11225	9804	1	2004-12-20
1	11226	8410	3	2004-12-03
2	11226	2668	2	2004-12-03
1	11227	5851	3	2004-12-04
2	11227	7673	2	2004-12-04
3	11227	7772	1	2004-12-04
4	11227	7925	1	2004-12-04
5	11227	1125	2	2004-12-04
6	11227	1275	3	2004-12-04
7	11227	6779	1	2004-12-04
8	11227	8766	1	2004-12-04
9	11227	2747	3	2004-12-04
1	11228	5211	2	2004-12-11
2	11228	2592	3	2004-12-11
3	11228	174	2	2004-12-11
1	11229	6863	1	2004-12-10
2	11229	4996	2	2004-12-10
3	11229	3839	1	2004-12-10
4	11229	6624	2	2004-12-10
5	11229	7617	3	2004-12-10
6	11229	2384	2	2004-12-10
7	11229	355	1	2004-12-10
8	11229	6879	1	2004-12-10
9	11229	9718	1	2004-12-10
1	11230	8596	2	2004-12-21
2	11230	9604	3	2004-12-21
1	11231	1846	2	2004-12-30
2	11231	3590	3	2004-12-30
3	11231	9420	3	2004-12-30
1	11232	3942	2	2004-12-31
2	11232	1772	2	2004-12-31
3	11232	5922	3	2004-12-31
4	11232	7398	2	2004-12-31
5	11232	8944	2	2004-12-31
6	11232	591	1	2004-12-31
7	11232	5636	3	2004-12-31
1	11233	8038	2	2004-12-24
2	11233	9513	3	2004-12-24
3	11233	665	1	2004-12-24
4	11233	6724	1	2004-12-24
5	11233	531	2	2004-12-24
6	11233	6129	1	2004-12-24
7	11233	3861	1	2004-12-24
1	11234	4284	1	2004-12-24
2	11234	9256	1	2004-12-24
3	11234	5674	3	2004-12-24
4	11234	5142	1	2004-12-24
1	11235	9483	2	2004-12-28
2	11235	2866	3	2004-12-28
3	11235	4469	2	2004-12-28
4	11235	2098	1	2004-12-28
5	11235	3616	1	2004-12-28
6	11235	7676	3	2004-12-28
7	11235	5549	1	2004-12-28
1	11236	6859	1	2004-12-31
2	11236	5942	2	2004-12-31
3	11236	4679	1	2004-12-31
4	11236	5960	3	2004-12-31
1	11237	1979	1	2004-12-10
2	11237	4060	2	2004-12-10
3	11237	919	3	2004-12-10
4	11237	8376	1	2004-12-10
5	11237	9721	1	2004-12-10
6	11237	5645	3	2004-12-10
7	11237	1735	1	2004-12-10
8	11237	8933	1	2004-12-10
9	11237	4436	2	2004-12-10
1	11238	7409	1	2004-12-18
2	11238	3285	2	2004-12-18
1	11239	5683	1	2004-12-07
2	11239	6418	3	2004-12-07
3	11239	5183	3	2004-12-07
4	11239	8270	2	2004-12-07
5	11239	353	3	2004-12-07
1	11240	7190	2	2004-12-18
2	11240	8832	1	2004-12-18
3	11240	421	2	2004-12-18
4	11240	2920	3	2004-12-18
5	11240	6228	1	2004-12-18
6	11240	207	3	2004-12-18
7	11240	3696	1	2004-12-18
1	11241	2394	1	2004-12-18
2	11241	1145	3	2004-12-18
1	11242	7404	3	2004-12-02
1	11243	7109	1	2004-12-22
2	11243	5669	3	2004-12-22
3	11243	7355	3	2004-12-22
4	11243	5504	2	2004-12-22
1	11244	7969	3	2004-12-28
2	11244	4665	2	2004-12-28
3	11244	217	3	2004-12-28
1	11245	775	2	2004-12-25
2	11245	9258	3	2004-12-25
3	11245	2450	2	2004-12-25
4	11245	969	2	2004-12-25
5	11245	157	3	2004-12-25
6	11245	9212	2	2004-12-25
7	11245	5607	2	2004-12-25
8	11245	4413	1	2004-12-25
1	11246	5937	2	2004-12-01
2	11246	2055	1	2004-12-01
3	11246	9510	1	2004-12-01
1	11247	5802	2	2004-12-24
2	11247	8062	2	2004-12-24
3	11247	2587	1	2004-12-24
1	11248	1633	2	2004-12-04
2	11248	7152	3	2004-12-04
1	11249	4891	2	2004-12-09
2	11249	6091	1	2004-12-09
3	11249	9955	3	2004-12-09
1	11250	6867	2	2004-12-05
2	11250	1382	1	2004-12-05
3	11250	8457	3	2004-12-05
4	11250	7726	1	2004-12-05
5	11250	9955	3	2004-12-05
6	11250	4598	3	2004-12-05
7	11250	224	2	2004-12-05
8	11250	3017	3	2004-12-05
9	11250	3469	2	2004-12-05
1	11251	6984	2	2004-12-28
2	11251	4657	3	2004-12-28
3	11251	2806	2	2004-12-28
4	11251	6403	1	2004-12-28
1	11252	5936	2	2004-12-17
2	11252	6000	2	2004-12-17
3	11252	6771	2	2004-12-17
4	11252	2558	1	2004-12-17
5	11252	2834	1	2004-12-17
6	11252	7598	2	2004-12-17
1	11253	2883	1	2004-12-01
2	11253	2927	3	2004-12-01
3	11253	4799	3	2004-12-01
4	11253	6804	3	2004-12-01
5	11253	3670	1	2004-12-01
6	11253	827	3	2004-12-01
7	11253	6474	3	2004-12-01
8	11253	5400	1	2004-12-01
9	11253	3827	1	2004-12-01
1	11254	1966	1	2004-12-19
2	11254	1411	3	2004-12-19
3	11254	6035	1	2004-12-19
4	11254	630	3	2004-12-19
5	11254	665	2	2004-12-19
6	11254	7742	2	2004-12-19
7	11254	3377	1	2004-12-19
8	11254	1175	1	2004-12-19
1	11255	3687	3	2004-12-01
1	11256	485	3	2004-12-29
2	11256	3492	3	2004-12-29
3	11256	6968	2	2004-12-29
1	11257	9946	2	2004-12-25
2	11257	1658	1	2004-12-25
3	11257	9161	3	2004-12-25
4	11257	4201	1	2004-12-25
1	11258	219	2	2004-12-07
2	11258	3055	2	2004-12-07
1	11259	5018	2	2004-12-19
2	11259	6569	3	2004-12-19
3	11259	1310	2	2004-12-19
4	11259	3967	3	2004-12-19
5	11259	1913	3	2004-12-19
6	11259	3384	1	2004-12-19
7	11259	4637	2	2004-12-19
8	11259	2468	2	2004-12-19
1	11260	2043	3	2004-12-14
2	11260	8464	1	2004-12-14
3	11260	5154	1	2004-12-14
4	11260	6166	1	2004-12-14
5	11260	3642	3	2004-12-14
6	11260	9345	3	2004-12-14
1	11261	9448	1	2004-12-09
2	11261	3270	1	2004-12-09
3	11261	124	2	2004-12-09
4	11261	3218	2	2004-12-09
1	11262	2353	2	2004-12-06
2	11262	2515	2	2004-12-06
3	11262	3945	1	2004-12-06
4	11262	6656	3	2004-12-06
5	11262	2498	1	2004-12-06
6	11262	213	2	2004-12-06
1	11263	5470	1	2004-12-07
2	11263	8547	2	2004-12-07
3	11263	3106	1	2004-12-07
4	11263	6277	1	2004-12-07
5	11263	8470	3	2004-12-07
1	11264	6300	3	2004-12-25
2	11264	1442	3	2004-12-25
3	11264	1927	2	2004-12-25
4	11264	9794	3	2004-12-25
5	11264	4484	1	2004-12-25
6	11264	1402	2	2004-12-25
1	11265	7984	3	2004-12-27
2	11265	5198	2	2004-12-27
3	11265	4640	3	2004-12-27
1	11266	411	3	2004-12-26
2	11266	6982	2	2004-12-26
3	11266	6070	1	2004-12-26
4	11266	3122	3	2004-12-26
5	11266	2096	2	2004-12-26
6	11266	2897	1	2004-12-26
7	11266	3631	3	2004-12-26
1	11267	8410	2	2004-12-13
2	11267	5837	2	2004-12-13
3	11267	6052	1	2004-12-13
1	11268	1607	1	2004-12-10
2	11268	8087	1	2004-12-10
1	11269	8349	1	2004-12-02
2	11269	3971	1	2004-12-02
3	11269	5778	3	2004-12-02
4	11269	2333	3	2004-12-02
5	11269	4247	2	2004-12-02
6	11269	4441	2	2004-12-02
1	11270	9244	3	2004-12-29
2	11270	5990	1	2004-12-29
3	11270	9394	2	2004-12-29
4	11270	3439	1	2004-12-29
5	11270	6195	1	2004-12-29
1	11271	3044	2	2004-12-10
1	11272	3881	3	2004-12-05
2	11272	6539	3	2004-12-05
3	11272	4230	1	2004-12-05
4	11272	4450	2	2004-12-05
5	11272	3829	3	2004-12-05
6	11272	8305	1	2004-12-05
7	11272	5804	2	2004-12-05
1	11273	6196	2	2004-12-17
2	11273	205	3	2004-12-17
3	11273	2399	3	2004-12-17
4	11273	9837	2	2004-12-17
5	11273	1741	1	2004-12-17
6	11273	2456	3	2004-12-17
7	11273	8320	2	2004-12-17
8	11273	4846	2	2004-12-17
1	11274	2424	3	2004-12-14
2	11274	6012	1	2004-12-14
3	11274	2739	1	2004-12-14
4	11274	5022	3	2004-12-14
5	11274	7012	2	2004-12-14
6	11274	6658	1	2004-12-14
7	11274	456	3	2004-12-14
8	11274	2420	1	2004-12-14
9	11274	3661	1	2004-12-14
1	11275	2527	1	2004-12-26
1	11276	6447	1	2004-12-22
2	11276	461	3	2004-12-22
1	11277	8288	2	2004-12-07
2	11277	2842	2	2004-12-07
3	11277	9260	3	2004-12-07
4	11277	8506	3	2004-12-07
5	11277	6362	1	2004-12-07
1	11278	5422	2	2004-12-08
1	11279	5320	2	2004-12-06
2	11279	254	1	2004-12-06
3	11279	7474	1	2004-12-06
4	11279	636	3	2004-12-06
5	11279	7187	1	2004-12-06
6	11279	4461	2	2004-12-06
7	11279	4851	3	2004-12-06
8	11279	773	2	2004-12-06
1	11280	204	2	2004-12-22
2	11280	3186	2	2004-12-22
3	11280	7261	3	2004-12-22
1	11281	7582	1	2004-12-01
2	11281	3418	3	2004-12-01
3	11281	3641	1	2004-12-01
4	11281	8549	2	2004-12-01
5	11281	489	2	2004-12-01
6	11281	4508	2	2004-12-01
7	11281	1210	3	2004-12-01
8	11281	2252	1	2004-12-01
1	11282	2217	1	2004-12-11
2	11282	3689	2	2004-12-11
3	11282	4850	1	2004-12-11
4	11282	4009	2	2004-12-11
5	11282	9828	1	2004-12-11
6	11282	3265	3	2004-12-11
7	11282	2439	3	2004-12-11
1	11283	355	3	2004-12-17
2	11283	9529	2	2004-12-17
3	11283	3011	1	2004-12-17
4	11283	4221	2	2004-12-17
1	11284	4983	2	2004-12-09
2	11284	5443	3	2004-12-09
3	11284	1933	1	2004-12-09
4	11284	9622	2	2004-12-09
1	11285	6859	3	2004-12-16
2	11285	5100	1	2004-12-16
3	11285	5021	1	2004-12-16
4	11285	5898	2	2004-12-16
5	11285	734	2	2004-12-16
6	11285	238	2	2004-12-16
7	11285	6164	2	2004-12-16
8	11285	9006	3	2004-12-16
1	11286	9852	3	2004-12-07
2	11286	5802	1	2004-12-07
3	11286	8598	2	2004-12-07
4	11286	7724	2	2004-12-07
5	11286	4872	2	2004-12-07
6	11286	2169	1	2004-12-07
7	11286	3169	3	2004-12-07
1	11287	3565	1	2004-12-12
2	11287	5158	2	2004-12-12
3	11287	4419	1	2004-12-12
4	11287	8260	2	2004-12-12
5	11287	205	1	2004-12-12
6	11287	6745	1	2004-12-12
7	11287	7537	2	2004-12-12
8	11287	1373	2	2004-12-12
9	11287	8379	3	2004-12-12
1	11288	330	2	2004-12-28
2	11288	5364	2	2004-12-28
3	11288	3157	3	2004-12-28
4	11288	1687	1	2004-12-28
1	11289	9053	3	2004-12-28
2	11289	5409	3	2004-12-28
3	11289	1614	2	2004-12-28
4	11289	7720	3	2004-12-28
1	11290	8595	1	2004-12-27
1	11291	988	3	2004-12-01
2	11291	9634	2	2004-12-01
3	11291	3261	1	2004-12-01
4	11291	5549	2	2004-12-01
1	11292	8565	3	2004-12-19
2	11292	7849	2	2004-12-19
3	11292	6564	3	2004-12-19
4	11292	9586	2	2004-12-19
5	11292	7821	3	2004-12-19
6	11292	9541	1	2004-12-19
7	11292	8319	3	2004-12-19
8	11292	6107	3	2004-12-19
9	11292	5490	2	2004-12-19
1	11293	2828	3	2004-12-07
2	11293	4510	3	2004-12-07
1	11294	56	1	2004-12-11
2	11294	2960	3	2004-12-11
3	11294	5391	3	2004-12-11
4	11294	7368	2	2004-12-11
1	11295	7963	1	2004-12-12
2	11295	1482	2	2004-12-12
3	11295	9903	3	2004-12-12
4	11295	9609	1	2004-12-12
1	11296	3474	3	2004-12-11
2	11296	4652	3	2004-12-11
3	11296	8616	3	2004-12-11
4	11296	693	3	2004-12-11
5	11296	8924	2	2004-12-11
6	11296	6576	2	2004-12-11
1	11297	9131	1	2004-12-10
2	11297	329	3	2004-12-10
3	11297	4092	1	2004-12-10
4	11297	1162	2	2004-12-10
5	11297	8781	1	2004-12-10
6	11297	5984	1	2004-12-10
7	11297	5681	3	2004-12-10
1	11298	6139	2	2004-12-27
2	11298	661	3	2004-12-27
3	11298	5197	3	2004-12-27
1	11299	5714	1	2004-12-02
2	11299	642	2	2004-12-02
3	11299	5720	1	2004-12-02
4	11299	1938	3	2004-12-02
1	11300	3870	3	2004-12-09
2	11300	3790	3	2004-12-09
1	11301	5448	2	2004-12-30
2	11301	3916	2	2004-12-30
3	11301	1675	3	2004-12-30
4	11301	5692	1	2004-12-30
5	11301	884	3	2004-12-30
6	11301	5818	2	2004-12-30
7	11301	2778	2	2004-12-30
1	11302	8308	1	2004-12-05
2	11302	6479	1	2004-12-05
3	11302	1771	1	2004-12-05
4	11302	1901	2	2004-12-05
1	11303	8772	1	2004-12-31
2	11303	3445	1	2004-12-31
3	11303	9408	2	2004-12-31
4	11303	1800	2	2004-12-31
5	11303	7278	1	2004-12-31
6	11303	4689	1	2004-12-31
7	11303	9280	3	2004-12-31
8	11303	9555	1	2004-12-31
1	11304	7193	1	2004-12-19
2	11304	6384	3	2004-12-19
3	11304	926	3	2004-12-19
4	11304	4523	1	2004-12-19
1	11305	5674	1	2004-12-30
2	11305	1124	2	2004-12-30
3	11305	7989	1	2004-12-30
4	11305	180	2	2004-12-30
5	11305	5606	2	2004-12-30
6	11305	8363	2	2004-12-30
7	11305	2336	3	2004-12-30
8	11305	5605	3	2004-12-30
1	11306	283	3	2004-12-16
2	11306	1056	1	2004-12-16
1	11307	7953	1	2004-12-23
2	11307	5339	2	2004-12-23
3	11307	4325	2	2004-12-23
4	11307	8706	1	2004-12-23
5	11307	9386	3	2004-12-23
6	11307	7580	2	2004-12-23
7	11307	3755	2	2004-12-23
1	11308	4389	3	2004-12-31
2	11308	5184	3	2004-12-31
3	11308	851	2	2004-12-31
4	11308	5911	1	2004-12-31
5	11308	6674	1	2004-12-31
1	11309	159	2	2004-12-24
2	11309	9063	2	2004-12-24
3	11309	1850	3	2004-12-24
4	11309	6796	1	2004-12-24
5	11309	6655	2	2004-12-24
1	11310	6499	2	2004-12-20
2	11310	1579	1	2004-12-20
3	11310	2933	3	2004-12-20
4	11310	7846	2	2004-12-20
5	11310	2228	2	2004-12-20
6	11310	5690	3	2004-12-20
1	11311	8612	3	2004-12-22
2	11311	2340	3	2004-12-22
3	11311	2244	2	2004-12-22
4	11311	5443	3	2004-12-22
5	11311	5425	1	2004-12-22
6	11311	3414	1	2004-12-22
7	11311	2505	2	2004-12-22
1	11312	9891	1	2004-12-25
2	11312	6090	3	2004-12-25
3	11312	4619	3	2004-12-25
4	11312	1492	1	2004-12-25
5	11312	7217	3	2004-12-25
6	11312	3483	2	2004-12-25
7	11312	5347	1	2004-12-25
8	11312	2582	3	2004-12-25
9	11312	9769	2	2004-12-25
1	11313	7307	3	2004-12-06
2	11313	8951	3	2004-12-06
3	11313	1008	3	2004-12-06
4	11313	8815	3	2004-12-06
5	11313	6028	3	2004-12-06
6	11313	9748	1	2004-12-06
7	11313	6441	2	2004-12-06
1	11314	6326	3	2004-12-02
2	11314	2470	1	2004-12-02
3	11314	252	2	2004-12-02
4	11314	9358	1	2004-12-02
5	11314	9877	1	2004-12-02
6	11314	5230	2	2004-12-02
7	11314	8535	1	2004-12-02
1	11315	4184	1	2004-12-04
2	11315	937	1	2004-12-04
1	11316	5049	1	2004-12-31
2	11316	4237	3	2004-12-31
3	11316	411	1	2004-12-31
4	11316	7880	1	2004-12-31
5	11316	2234	3	2004-12-31
6	11316	7931	1	2004-12-31
1	11317	1547	1	2004-12-26
2	11317	5917	1	2004-12-26
3	11317	8844	3	2004-12-26
4	11317	4590	1	2004-12-26
1	11318	6209	2	2004-12-30
2	11318	5596	1	2004-12-30
3	11318	8328	3	2004-12-30
4	11318	981	3	2004-12-30
5	11318	395	3	2004-12-30
6	11318	1618	1	2004-12-30
7	11318	6993	3	2004-12-30
8	11318	4221	2	2004-12-30
9	11318	7356	3	2004-12-30
1	11319	1467	3	2004-12-27
2	11319	2703	2	2004-12-27
3	11319	278	1	2004-12-27
4	11319	1582	2	2004-12-27
1	11320	9049	3	2004-12-05
2	11320	6846	1	2004-12-05
3	11320	6149	3	2004-12-05
4	11320	8890	3	2004-12-05
5	11320	9870	2	2004-12-05
6	11320	7315	2	2004-12-05
7	11320	1025	2	2004-12-05
1	11321	3988	2	2004-12-04
2	11321	6792	3	2004-12-04
3	11321	1095	3	2004-12-04
4	11321	8817	1	2004-12-04
5	11321	585	1	2004-12-04
6	11321	467	3	2004-12-04
7	11321	7247	3	2004-12-04
8	11321	7078	2	2004-12-04
9	11321	9545	1	2004-12-04
1	11322	4316	3	2004-12-05
2	11322	5291	2	2004-12-05
1	11323	5969	3	2004-12-10
2	11323	1586	1	2004-12-10
3	11323	5566	1	2004-12-10
4	11323	9828	2	2004-12-10
5	11323	5356	1	2004-12-10
6	11323	4617	2	2004-12-10
1	11324	5955	2	2004-12-01
2	11324	382	3	2004-12-01
3	11324	3316	1	2004-12-01
4	11324	8487	3	2004-12-01
5	11324	9680	2	2004-12-01
6	11324	2973	1	2004-12-01
7	11324	204	3	2004-12-01
1	11325	8931	1	2004-12-29
1	11326	9170	1	2004-12-11
2	11326	4646	3	2004-12-11
3	11326	3165	3	2004-12-11
4	11326	6406	3	2004-12-11
5	11326	4865	3	2004-12-11
6	11326	6404	3	2004-12-11
7	11326	8161	2	2004-12-11
8	11326	5813	3	2004-12-11
1	11327	6646	3	2004-12-27
2	11327	5041	2	2004-12-27
3	11327	483	2	2004-12-27
4	11327	5685	2	2004-12-27
5	11327	2730	1	2004-12-27
6	11327	2773	1	2004-12-27
7	11327	3671	3	2004-12-27
8	11327	1148	3	2004-12-27
1	11328	4340	1	2004-12-23
2	11328	446	1	2004-12-23
3	11328	7247	2	2004-12-23
1	11329	4783	1	2004-12-02
1	11330	3795	1	2004-12-02
1	11331	8424	3	2004-12-16
2	11331	5151	3	2004-12-16
3	11331	3629	1	2004-12-16
4	11331	7124	3	2004-12-16
5	11331	4816	1	2004-12-16
6	11331	1939	2	2004-12-16
7	11331	3964	3	2004-12-16
1	11332	5136	3	2004-12-05
2	11332	8249	2	2004-12-05
3	11332	9705	1	2004-12-05
4	11332	6677	2	2004-12-05
5	11332	4073	1	2004-12-05
6	11332	24	3	2004-12-05
1	11333	8018	3	2004-12-30
2	11333	7075	2	2004-12-30
3	11333	7202	1	2004-12-30
4	11333	6605	3	2004-12-30
5	11333	7150	1	2004-12-30
1	11334	5229	1	2004-12-26
2	11334	3304	2	2004-12-26
3	11334	5672	1	2004-12-26
4	11334	6795	1	2004-12-26
1	11335	8064	2	2004-12-21
2	11335	4978	1	2004-12-21
3	11335	7883	1	2004-12-21
4	11335	9674	2	2004-12-21
5	11335	8136	3	2004-12-21
6	11335	6847	2	2004-12-21
1	11336	2664	1	2004-12-19
2	11336	7762	3	2004-12-19
3	11336	188	1	2004-12-19
4	11336	1369	2	2004-12-19
1	11337	9031	1	2004-12-13
1	11338	9149	2	2004-12-23
2	11338	5084	3	2004-12-23
1	11339	7961	1	2004-12-27
2	11339	9236	1	2004-12-27
3	11339	6051	1	2004-12-27
4	11339	3450	2	2004-12-27
5	11339	9791	2	2004-12-27
1	11340	9322	3	2004-12-16
2	11340	9533	3	2004-12-16
3	11340	9899	2	2004-12-16
4	11340	5447	2	2004-12-16
5	11340	8735	2	2004-12-16
6	11340	8891	2	2004-12-16
7	11340	3418	3	2004-12-16
8	11340	7038	3	2004-12-16
9	11340	2524	2	2004-12-16
1	11341	3658	1	2004-12-03
2	11341	690	2	2004-12-03
3	11341	5355	2	2004-12-03
4	11341	4608	2	2004-12-03
5	11341	4520	2	2004-12-03
6	11341	2555	2	2004-12-03
7	11341	2283	1	2004-12-03
1	11342	2325	3	2004-12-03
2	11342	3249	2	2004-12-03
3	11342	4081	1	2004-12-03
4	11342	4857	2	2004-12-03
5	11342	5285	2	2004-12-03
6	11342	8363	2	2004-12-03
7	11342	2561	1	2004-12-03
8	11342	5270	1	2004-12-03
9	11342	5470	1	2004-12-03
1	11343	4007	3	2004-12-28
2	11343	7389	2	2004-12-28
3	11343	483	3	2004-12-28
4	11343	4018	3	2004-12-28
1	11344	2084	3	2004-12-24
1	11345	2624	2	2004-12-04
2	11345	9887	2	2004-12-04
3	11345	6254	2	2004-12-04
4	11345	8434	1	2004-12-04
5	11345	5780	3	2004-12-04
6	11345	1800	1	2004-12-04
1	11346	2096	3	2004-12-02
2	11346	6061	2	2004-12-02
3	11346	8156	2	2004-12-02
4	11346	2455	2	2004-12-02
5	11346	4341	2	2004-12-02
6	11346	2608	2	2004-12-02
7	11346	1479	3	2004-12-02
8	11346	1726	2	2004-12-02
1	11347	6768	3	2004-12-09
2	11347	687	1	2004-12-09
3	11347	4970	1	2004-12-09
4	11347	3802	2	2004-12-09
5	11347	8293	1	2004-12-09
6	11347	3532	1	2004-12-09
7	11347	2853	3	2004-12-09
8	11347	6501	1	2004-12-09
9	11347	3168	3	2004-12-09
1	11348	2900	2	2004-12-14
2	11348	5435	2	2004-12-14
3	11348	9073	3	2004-12-14
4	11348	6237	3	2004-12-14
5	11348	7109	1	2004-12-14
6	11348	6076	3	2004-12-14
7	11348	5553	1	2004-12-14
1	11349	2440	1	2004-12-01
2	11349	8962	2	2004-12-01
3	11349	9724	2	2004-12-01
4	11349	6301	1	2004-12-01
5	11349	4417	1	2004-12-01
6	11349	400	3	2004-12-01
7	11349	7608	1	2004-12-01
8	11349	2880	1	2004-12-01
1	11350	309	3	2004-12-25
2	11350	7166	2	2004-12-25
3	11350	6090	1	2004-12-25
4	11350	7429	2	2004-12-25
1	11351	4162	2	2004-12-07
2	11351	9804	2	2004-12-07
3	11351	9367	2	2004-12-07
4	11351	6778	2	2004-12-07
5	11351	6755	3	2004-12-07
1	11352	7404	3	2004-12-06
2	11352	6524	3	2004-12-06
3	11352	2561	3	2004-12-06
4	11352	6885	3	2004-12-06
5	11352	3216	1	2004-12-06
1	11353	4675	2	2004-12-08
2	11353	9027	3	2004-12-08
3	11353	8193	3	2004-12-08
4	11353	2723	3	2004-12-08
5	11353	4935	3	2004-12-08
1	11354	6050	3	2004-12-05
2	11354	7607	2	2004-12-05
3	11354	5552	2	2004-12-05
1	11355	7838	2	2004-12-07
2	11355	1901	1	2004-12-07
3	11355	4822	1	2004-12-07
4	11355	4796	3	2004-12-07
5	11355	5531	2	2004-12-07
6	11355	8334	2	2004-12-07
7	11355	2652	1	2004-12-07
8	11355	1283	3	2004-12-07
9	11355	555	1	2004-12-07
1	11356	4382	1	2004-12-29
2	11356	8778	3	2004-12-29
3	11356	7397	1	2004-12-29
4	11356	8045	3	2004-12-29
5	11356	9748	2	2004-12-29
1	11357	2891	1	2004-12-08
2	11357	6853	3	2004-12-08
3	11357	4782	2	2004-12-08
4	11357	2145	3	2004-12-08
5	11357	6241	2	2004-12-08
6	11357	5020	3	2004-12-08
7	11357	6052	2	2004-12-08
1	11358	4979	3	2004-12-13
2	11358	8340	1	2004-12-13
3	11358	9217	2	2004-12-13
4	11358	732	3	2004-12-13
5	11358	2268	1	2004-12-13
6	11358	612	3	2004-12-13
7	11358	623	2	2004-12-13
8	11358	9391	3	2004-12-13
1	11359	1605	3	2004-12-06
2	11359	7495	2	2004-12-06
3	11359	5697	2	2004-12-06
4	11359	918	3	2004-12-06
1	11360	8932	2	2004-12-17
1	11361	7113	2	2004-12-09
2	11361	6609	3	2004-12-09
3	11361	3552	3	2004-12-09
4	11361	1226	1	2004-12-09
1	11362	7218	3	2004-12-15
2	11362	6268	2	2004-12-15
3	11362	5341	1	2004-12-15
4	11362	8259	2	2004-12-15
5	11362	1686	2	2004-12-15
6	11362	6794	3	2004-12-15
7	11362	3754	2	2004-12-15
1	11363	9708	1	2004-12-20
2	11363	4256	2	2004-12-20
3	11363	8710	3	2004-12-20
4	11363	3547	3	2004-12-20
5	11363	750	3	2004-12-20
6	11363	3085	3	2004-12-20
7	11363	5618	1	2004-12-20
8	11363	6580	1	2004-12-20
9	11363	5015	1	2004-12-20
1	11364	6791	2	2004-12-12
2	11364	5348	1	2004-12-12
3	11364	696	1	2004-12-12
4	11364	6909	2	2004-12-12
5	11364	765	2	2004-12-12
1	11365	2828	2	2004-12-18
2	11365	4201	2	2004-12-18
3	11365	4729	3	2004-12-18
4	11365	1439	1	2004-12-18
1	11366	9937	2	2004-12-24
2	11366	5875	3	2004-12-24
3	11366	1613	1	2004-12-24
1	11367	8590	1	2004-12-10
2	11367	8348	3	2004-12-10
3	11367	6733	2	2004-12-10
4	11367	4375	3	2004-12-10
1	11368	778	1	2004-12-26
2	11368	9653	1	2004-12-26
3	11368	1218	3	2004-12-26
1	11369	9528	2	2004-12-01
1	11370	8101	1	2004-12-26
2	11370	5147	3	2004-12-26
1	11371	7397	1	2004-12-06
2	11371	8104	2	2004-12-06
3	11371	7620	2	2004-12-06
4	11371	7932	3	2004-12-06
5	11371	5117	3	2004-12-06
6	11371	615	2	2004-12-06
7	11371	4825	1	2004-12-06
8	11371	9782	2	2004-12-06
1	11372	449	3	2004-12-04
2	11372	670	3	2004-12-04
3	11372	352	2	2004-12-04
4	11372	5239	1	2004-12-04
5	11372	9311	1	2004-12-04
6	11372	496	3	2004-12-04
7	11372	1702	3	2004-12-04
8	11372	2271	3	2004-12-04
9	11372	2845	1	2004-12-04
1	11373	4294	1	2004-12-24
2	11373	9181	2	2004-12-24
3	11373	7276	1	2004-12-24
4	11373	3384	3	2004-12-24
5	11373	9501	2	2004-12-24
6	11373	6420	1	2004-12-24
7	11373	2381	3	2004-12-24
8	11373	5988	3	2004-12-24
1	11374	2006	1	2004-12-28
2	11374	7924	2	2004-12-28
3	11374	9926	1	2004-12-28
4	11374	4478	3	2004-12-28
5	11374	8729	1	2004-12-28
6	11374	5978	1	2004-12-28
7	11374	4873	2	2004-12-28
8	11374	7098	1	2004-12-28
9	11374	5357	1	2004-12-28
1	11375	5029	3	2004-12-31
2	11375	2997	1	2004-12-31
3	11375	4315	1	2004-12-31
4	11375	6314	1	2004-12-31
5	11375	1150	3	2004-12-31
6	11375	3822	3	2004-12-31
1	11376	1391	3	2004-12-09
2	11376	9335	3	2004-12-09
3	11376	1592	2	2004-12-09
4	11376	2527	3	2004-12-09
5	11376	6356	3	2004-12-09
6	11376	9172	2	2004-12-09
7	11376	2741	2	2004-12-09
1	11377	8785	2	2004-12-08
2	11377	7208	2	2004-12-08
3	11377	7711	3	2004-12-08
4	11377	3418	1	2004-12-08
5	11377	7431	2	2004-12-08
1	11378	5842	1	2004-12-17
2	11378	4038	3	2004-12-17
3	11378	6627	2	2004-12-17
4	11378	6123	1	2004-12-17
5	11378	4447	2	2004-12-17
6	11378	9143	3	2004-12-17
7	11378	8779	1	2004-12-17
1	11379	3452	2	2004-12-16
2	11379	8839	1	2004-12-16
3	11379	2477	1	2004-12-16
4	11379	2694	3	2004-12-16
1	11380	4642	1	2004-12-26
2	11380	3772	3	2004-12-26
1	11381	3381	3	2004-12-02
2	11381	1869	1	2004-12-02
3	11381	6877	1	2004-12-02
4	11381	4053	1	2004-12-02
5	11381	9605	1	2004-12-02
6	11381	5573	1	2004-12-02
1	11382	6669	3	2004-12-16
2	11382	7466	2	2004-12-16
3	11382	4885	2	2004-12-16
4	11382	6290	3	2004-12-16
5	11382	7664	1	2004-12-16
6	11382	8206	3	2004-12-16
7	11382	460	2	2004-12-16
1	11383	6364	1	2004-12-15
2	11383	7206	1	2004-12-15
3	11383	1848	3	2004-12-15
4	11383	1380	3	2004-12-15
5	11383	9867	2	2004-12-15
6	11383	1833	2	2004-12-15
1	11384	3438	2	2004-12-13
2	11384	6131	3	2004-12-13
1	11385	1910	1	2004-12-17
2	11385	7060	2	2004-12-17
3	11385	4089	1	2004-12-17
4	11385	3158	1	2004-12-17
1	11386	7174	1	2004-12-01
2	11386	9482	3	2004-12-01
1	11387	9815	1	2004-12-27
2	11387	4218	1	2004-12-27
3	11387	8002	1	2004-12-27
1	11388	7019	2	2004-12-10
2	11388	3016	2	2004-12-10
3	11388	2651	3	2004-12-10
1	11389	6172	3	2004-12-14
2	11389	6550	2	2004-12-14
3	11389	669	2	2004-12-14
4	11389	387	3	2004-12-14
5	11389	7345	1	2004-12-14
1	11390	411	1	2004-12-07
2	11390	6675	2	2004-12-07
3	11390	5042	1	2004-12-07
4	11390	6157	1	2004-12-07
5	11390	6869	3	2004-12-07
6	11390	6140	3	2004-12-07
1	11391	4905	1	2004-12-20
2	11391	2252	1	2004-12-20
3	11391	4846	1	2004-12-20
4	11391	7485	2	2004-12-20
1	11392	1988	1	2004-12-08
2	11392	733	1	2004-12-08
3	11392	2010	3	2004-12-08
4	11392	5788	3	2004-12-08
1	11393	1116	2	2004-12-26
2	11393	4613	3	2004-12-26
3	11393	5667	3	2004-12-26
4	11393	1221	1	2004-12-26
5	11393	1441	2	2004-12-26
1	11394	1519	3	2004-12-07
2	11394	4338	3	2004-12-07
3	11394	3097	2	2004-12-07
4	11394	8637	2	2004-12-07
5	11394	8724	1	2004-12-07
6	11394	1237	2	2004-12-07
7	11394	7697	3	2004-12-07
8	11394	6455	3	2004-12-07
9	11394	4553	3	2004-12-07
1	11395	9106	2	2004-12-07
2	11395	8297	1	2004-12-07
3	11395	9654	1	2004-12-07
4	11395	6834	2	2004-12-07
5	11395	9831	3	2004-12-07
6	11395	4736	2	2004-12-07
7	11395	6614	3	2004-12-07
1	11396	5897	1	2004-12-02
2	11396	3727	2	2004-12-02
3	11396	2359	1	2004-12-02
4	11396	402	3	2004-12-02
5	11396	7751	1	2004-12-02
6	11396	6078	1	2004-12-02
7	11396	188	2	2004-12-02
8	11396	8893	3	2004-12-02
9	11396	5730	3	2004-12-02
1	11397	915	3	2004-12-28
2	11397	2804	3	2004-12-28
3	11397	7161	1	2004-12-28
4	11397	2779	3	2004-12-28
5	11397	2513	3	2004-12-28
6	11397	1722	2	2004-12-28
7	11397	2268	2	2004-12-28
8	11397	6420	1	2004-12-28
1	11398	6882	2	2004-12-04
2	11398	2252	2	2004-12-04
3	11398	3802	3	2004-12-04
4	11398	4321	1	2004-12-04
5	11398	544	3	2004-12-04
6	11398	1243	1	2004-12-04
7	11398	8239	2	2004-12-04
1	11399	4222	3	2004-12-28
2	11399	438	2	2004-12-28
1	11400	5375	1	2004-12-19
2	11400	6683	1	2004-12-19
3	11400	8083	2	2004-12-19
1	11401	8316	2	2004-12-19
2	11401	2230	3	2004-12-19
3	11401	2570	2	2004-12-19
4	11401	316	1	2004-12-19
5	11401	7518	3	2004-12-19
6	11401	6208	2	2004-12-19
7	11401	1065	1	2004-12-19
8	11401	4714	1	2004-12-19
9	11401	6373	1	2004-12-19
1	11402	7409	1	2004-12-14
2	11402	86	2	2004-12-14
3	11402	3566	2	2004-12-14
4	11402	5827	1	2004-12-14
5	11402	5531	2	2004-12-14
6	11402	6562	3	2004-12-14
7	11402	3000	3	2004-12-14
8	11402	1233	1	2004-12-14
9	11402	9940	3	2004-12-14
1	11403	6577	3	2004-12-09
2	11403	5183	1	2004-12-09
3	11403	9130	3	2004-12-09
4	11403	9344	1	2004-12-09
1	11404	2245	2	2004-12-28
2	11404	4965	3	2004-12-28
3	11404	8919	1	2004-12-28
4	11404	2212	2	2004-12-28
5	11404	8257	2	2004-12-28
6	11404	4612	3	2004-12-28
7	11404	8527	2	2004-12-28
8	11404	8240	1	2004-12-28
9	11404	699	1	2004-12-28
1	11405	224	3	2004-12-15
1	11406	6320	2	2004-12-30
2	11406	7424	3	2004-12-30
3	11406	216	1	2004-12-30
4	11406	6635	3	2004-12-30
5	11406	2884	3	2004-12-30
6	11406	4615	1	2004-12-30
7	11406	4057	3	2004-12-30
8	11406	629	1	2004-12-30
1	11407	717	3	2004-12-12
2	11407	1750	1	2004-12-12
3	11407	8553	1	2004-12-12
4	11407	191	3	2004-12-12
5	11407	1541	1	2004-12-12
1	11408	6424	2	2004-12-20
2	11408	6126	1	2004-12-20
3	11408	5492	3	2004-12-20
4	11408	1905	1	2004-12-20
1	11409	8545	1	2004-12-01
1	11410	817	3	2004-12-30
1	11411	7317	1	2004-12-04
2	11411	3384	2	2004-12-04
1	11412	5883	2	2004-12-03
2	11412	185	1	2004-12-03
3	11412	2502	1	2004-12-03
4	11412	1479	1	2004-12-03
5	11412	8050	1	2004-12-03
6	11412	3428	2	2004-12-03
7	11412	3916	1	2004-12-03
1	11413	826	2	2004-12-28
2	11413	9049	1	2004-12-28
3	11413	6129	2	2004-12-28
4	11413	4971	3	2004-12-28
5	11413	9996	2	2004-12-28
6	11413	9038	3	2004-12-28
7	11413	2799	2	2004-12-28
8	11413	857	1	2004-12-28
9	11413	6294	2	2004-12-28
1	11414	8582	3	2004-12-16
2	11414	9716	1	2004-12-16
3	11414	2510	3	2004-12-16
1	11415	632	3	2004-12-13
2	11415	6947	3	2004-12-13
3	11415	3673	1	2004-12-13
4	11415	6272	2	2004-12-13
5	11415	7590	2	2004-12-13
1	11416	3372	2	2004-12-04
2	11416	5247	3	2004-12-04
1	11417	693	1	2004-12-14
2	11417	5374	1	2004-12-14
3	11417	9860	3	2004-12-14
1	11418	5425	1	2004-12-29
2	11418	6539	3	2004-12-29
3	11418	3051	1	2004-12-29
4	11418	2767	1	2004-12-29
5	11418	8120	2	2004-12-29
6	11418	1028	3	2004-12-29
7	11418	5688	2	2004-12-29
8	11418	4871	1	2004-12-29
9	11418	2843	3	2004-12-29
1	11419	5689	3	2004-12-07
2	11419	6085	2	2004-12-07
3	11419	6781	2	2004-12-07
1	11420	2101	1	2004-12-12
2	11420	8188	2	2004-12-12
3	11420	4361	1	2004-12-12
4	11420	5790	1	2004-12-12
5	11420	4753	3	2004-12-12
6	11420	830	1	2004-12-12
7	11420	1218	2	2004-12-12
8	11420	1374	2	2004-12-12
9	11420	4865	2	2004-12-12
1	11421	4319	1	2004-12-27
2	11421	9705	1	2004-12-27
3	11421	7763	2	2004-12-27
4	11421	2067	1	2004-12-27
1	11422	9317	3	2004-12-08
1	11423	1925	1	2004-12-05
2	11423	6792	1	2004-12-05
3	11423	7694	3	2004-12-05
4	11423	7203	1	2004-12-05
5	11423	1729	2	2004-12-05
6	11423	9463	3	2004-12-05
1	11424	4881	3	2004-12-31
2	11424	2902	3	2004-12-31
3	11424	1241	2	2004-12-31
4	11424	1114	2	2004-12-31
5	11424	6007	1	2004-12-31
6	11424	4249	3	2004-12-31
7	11424	5537	2	2004-12-31
8	11424	3959	3	2004-12-31
9	11424	7408	1	2004-12-31
1	11425	7659	1	2004-12-02
2	11425	3478	3	2004-12-02
3	11425	8820	1	2004-12-02
4	11425	902	3	2004-12-02
5	11425	2838	2	2004-12-02
6	11425	7992	2	2004-12-02
7	11425	2728	3	2004-12-02
8	11425	1099	2	2004-12-02
1	11426	4712	3	2004-12-15
2	11426	4457	3	2004-12-15
3	11426	7270	1	2004-12-15
4	11426	9422	3	2004-12-15
5	11426	6966	3	2004-12-15
6	11426	5680	2	2004-12-15
7	11426	8982	3	2004-12-15
8	11426	1745	3	2004-12-15
9	11426	2463	1	2004-12-15
1	11427	1038	1	2004-12-23
2	11427	4548	1	2004-12-23
3	11427	4996	3	2004-12-23
4	11427	9242	3	2004-12-23
5	11427	8387	2	2004-12-23
1	11428	4708	1	2004-12-29
2	11428	4219	1	2004-12-29
3	11428	382	3	2004-12-29
4	11428	6298	3	2004-12-29
5	11428	9056	3	2004-12-29
6	11428	7165	1	2004-12-29
1	11429	9806	3	2004-12-03
2	11429	270	2	2004-12-03
3	11429	9991	2	2004-12-03
4	11429	3696	3	2004-12-03
5	11429	4532	1	2004-12-03
6	11429	3186	2	2004-12-03
7	11429	4926	2	2004-12-03
8	11429	9952	3	2004-12-03
9	11429	7855	2	2004-12-03
1	11430	7600	1	2004-12-05
2	11430	5646	2	2004-12-05
3	11430	4640	2	2004-12-05
4	11430	9254	1	2004-12-05
5	11430	5448	3	2004-12-05
6	11430	9312	2	2004-12-05
7	11430	3412	3	2004-12-05
1	11431	9189	1	2004-12-04
2	11431	9122	2	2004-12-04
3	11431	7530	3	2004-12-04
4	11431	3747	2	2004-12-04
5	11431	3242	2	2004-12-04
1	11432	432	3	2004-12-12
2	11432	5984	2	2004-12-12
1	11433	4297	2	2004-12-15
1	11434	4815	2	2004-12-18
2	11434	2298	2	2004-12-18
3	11434	5396	1	2004-12-18
4	11434	8117	1	2004-12-18
5	11434	492	1	2004-12-18
6	11434	8309	2	2004-12-18
7	11434	6917	1	2004-12-18
1	11435	7876	3	2004-12-04
2	11435	6544	1	2004-12-04
1	11436	8911	3	2004-12-14
2	11436	6373	2	2004-12-14
3	11436	5178	1	2004-12-14
4	11436	7727	3	2004-12-14
5	11436	5191	1	2004-12-14
6	11436	8894	1	2004-12-14
7	11436	6047	3	2004-12-14
8	11436	5170	2	2004-12-14
1	11437	1660	3	2004-12-10
2	11437	5633	3	2004-12-10
3	11437	8562	1	2004-12-10
4	11437	2045	1	2004-12-10
1	11438	3034	3	2004-12-17
2	11438	8211	3	2004-12-17
3	11438	9157	2	2004-12-17
4	11438	5687	2	2004-12-17
1	11439	3966	1	2004-12-29
2	11439	9462	3	2004-12-29
3	11439	4910	2	2004-12-29
4	11439	1243	2	2004-12-29
5	11439	5174	3	2004-12-29
1	11440	6666	2	2004-12-19
2	11440	2787	3	2004-12-19
3	11440	8460	2	2004-12-19
4	11440	6231	3	2004-12-19
5	11440	4031	2	2004-12-19
6	11440	2609	3	2004-12-19
7	11440	9733	1	2004-12-19
8	11440	4297	3	2004-12-19
1	11441	5346	2	2004-12-22
2	11441	1980	2	2004-12-22
3	11441	1687	3	2004-12-22
4	11441	3464	3	2004-12-22
5	11441	889	1	2004-12-22
6	11441	5937	3	2004-12-22
1	11442	4543	1	2004-12-22
2	11442	1947	3	2004-12-22
3	11442	7433	2	2004-12-22
4	11442	8291	3	2004-12-22
5	11442	6223	1	2004-12-22
1	11443	9234	2	2004-12-15
2	11443	9878	1	2004-12-15
3	11443	2784	1	2004-12-15
4	11443	8368	2	2004-12-15
5	11443	9353	3	2004-12-15
1	11444	4013	1	2004-12-28
2	11444	855	3	2004-12-28
3	11444	4673	1	2004-12-28
4	11444	7130	1	2004-12-28
5	11444	7356	2	2004-12-28
6	11444	9271	2	2004-12-28
1	11445	8582	2	2004-12-25
2	11445	5053	3	2004-12-25
3	11445	7024	3	2004-12-25
4	11445	24	2	2004-12-25
5	11445	4084	3	2004-12-25
6	11445	4647	1	2004-12-25
7	11445	4667	1	2004-12-25
8	11445	8426	3	2004-12-25
1	11446	2082	2	2004-12-13
2	11446	861	3	2004-12-13
3	11446	9784	1	2004-12-13
4	11446	3015	3	2004-12-13
5	11446	3954	3	2004-12-13
6	11446	6649	1	2004-12-13
7	11446	5401	1	2004-12-13
8	11446	995	1	2004-12-13
1	11447	396	1	2004-12-30
2	11447	6468	2	2004-12-30
3	11447	3918	2	2004-12-30
4	11447	3742	3	2004-12-30
1	11448	5341	3	2004-12-13
2	11448	5692	2	2004-12-13
3	11448	7748	3	2004-12-13
4	11448	2916	1	2004-12-13
5	11448	8297	3	2004-12-13
6	11448	4236	2	2004-12-13
1	11449	6250	2	2004-12-04
1	11450	1708	1	2004-12-14
1	11451	6426	2	2004-12-18
2	11451	6212	1	2004-12-18
3	11451	2685	1	2004-12-18
4	11451	6890	1	2004-12-18
5	11451	609	3	2004-12-18
6	11451	2133	3	2004-12-18
7	11451	9369	2	2004-12-18
8	11451	2603	1	2004-12-18
9	11451	1599	3	2004-12-18
1	11452	4493	3	2004-12-05
2	11452	6749	2	2004-12-05
3	11452	9368	1	2004-12-05
4	11452	1650	3	2004-12-05
5	11452	2488	3	2004-12-05
6	11452	2751	3	2004-12-05
1	11453	5868	1	2004-12-31
2	11453	6533	3	2004-12-31
3	11453	115	2	2004-12-31
4	11453	4368	1	2004-12-31
5	11453	6535	2	2004-12-31
6	11453	1440	3	2004-12-31
7	11453	3813	2	2004-12-31
1	11454	4506	1	2004-12-12
1	11455	4229	1	2004-12-10
2	11455	4294	2	2004-12-10
3	11455	8387	2	2004-12-10
4	11455	797	2	2004-12-10
5	11455	6104	3	2004-12-10
6	11455	2254	2	2004-12-10
1	11456	2586	1	2004-12-11
2	11456	7736	2	2004-12-11
3	11456	4474	1	2004-12-11
4	11456	4704	3	2004-12-11
5	11456	2140	3	2004-12-11
6	11456	147	2	2004-12-11
7	11456	5363	1	2004-12-11
8	11456	842	3	2004-12-11
9	11456	3299	2	2004-12-11
1	11457	5940	2	2004-12-12
2	11457	1785	3	2004-12-12
3	11457	2351	2	2004-12-12
4	11457	4813	1	2004-12-12
5	11457	4781	3	2004-12-12
1	11458	4079	3	2004-12-06
2	11458	3762	2	2004-12-06
3	11458	7708	2	2004-12-06
4	11458	1466	1	2004-12-06
5	11458	4255	1	2004-12-06
6	11458	2661	3	2004-12-06
1	11459	776	2	2004-12-24
2	11459	3602	1	2004-12-24
3	11459	3371	2	2004-12-24
4	11459	7576	3	2004-12-24
5	11459	7240	1	2004-12-24
6	11459	5583	3	2004-12-24
7	11459	4873	3	2004-12-24
1	11460	5170	2	2004-12-16
2	11460	2705	2	2004-12-16
3	11460	8657	3	2004-12-16
4	11460	8941	1	2004-12-16
5	11460	4514	2	2004-12-16
6	11460	7637	2	2004-12-16
7	11460	3852	3	2004-12-16
8	11460	8931	3	2004-12-16
1	11461	486	1	2004-12-04
2	11461	904	2	2004-12-04
3	11461	9547	2	2004-12-04
4	11461	5447	2	2004-12-04
5	11461	4727	1	2004-12-04
6	11461	3380	3	2004-12-04
7	11461	8912	2	2004-12-04
8	11461	6531	3	2004-12-04
1	11462	1854	2	2004-12-10
2	11462	1309	2	2004-12-10
3	11462	4932	1	2004-12-10
4	11462	3158	2	2004-12-10
5	11462	2542	2	2004-12-10
6	11462	4451	1	2004-12-10
7	11462	7210	2	2004-12-10
1	11463	1339	2	2004-12-29
2	11463	7867	2	2004-12-29
3	11463	5752	3	2004-12-29
4	11463	803	1	2004-12-29
5	11463	4345	2	2004-12-29
1	11464	9749	1	2004-12-25
2	11464	5312	2	2004-12-25
3	11464	2952	3	2004-12-25
4	11464	585	2	2004-12-25
5	11464	5034	2	2004-12-25
6	11464	8520	1	2004-12-25
7	11464	389	3	2004-12-25
8	11464	9000	1	2004-12-25
9	11464	2155	1	2004-12-25
1	11465	6799	2	2004-12-23
2	11465	5408	1	2004-12-23
3	11465	9707	1	2004-12-23
1	11466	3821	3	2004-12-14
2	11466	8801	3	2004-12-14
3	11466	6549	3	2004-12-14
4	11466	2265	1	2004-12-14
1	11467	8398	1	2004-12-14
2	11467	6325	1	2004-12-14
3	11467	3165	2	2004-12-14
4	11467	574	3	2004-12-14
5	11467	6823	3	2004-12-14
1	11468	5391	1	2004-12-13
2	11468	4897	3	2004-12-13
3	11468	7005	3	2004-12-13
4	11468	6239	2	2004-12-13
1	11469	4370	3	2004-12-18
2	11469	8538	3	2004-12-18
3	11469	4414	3	2004-12-18
4	11469	1023	1	2004-12-18
5	11469	7488	2	2004-12-18
6	11469	4435	3	2004-12-18
7	11469	2410	1	2004-12-18
1	11470	279	3	2004-12-17
2	11470	6832	2	2004-12-17
3	11470	7037	2	2004-12-17
4	11470	3893	1	2004-12-17
1	11471	7136	1	2004-12-30
2	11471	4436	2	2004-12-30
3	11471	8629	3	2004-12-30
4	11471	2609	3	2004-12-30
5	11471	9587	1	2004-12-30
1	11472	5279	2	2004-12-12
2	11472	2738	3	2004-12-12
3	11472	7538	1	2004-12-12
4	11472	7644	2	2004-12-12
5	11472	8192	2	2004-12-12
6	11472	8206	1	2004-12-12
1	11473	2674	3	2004-12-25
2	11473	4450	3	2004-12-25
3	11473	4277	1	2004-12-25
4	11473	5959	3	2004-12-25
1	11474	9567	2	2004-12-09
2	11474	2813	2	2004-12-09
3	11474	8730	2	2004-12-09
4	11474	3612	2	2004-12-09
5	11474	8567	1	2004-12-09
6	11474	637	3	2004-12-09
1	11475	6688	1	2004-12-19
2	11475	7907	3	2004-12-19
3	11475	8913	1	2004-12-19
4	11475	6471	1	2004-12-19
1	11476	7975	3	2004-12-17
2	11476	4728	3	2004-12-17
3	11476	2194	3	2004-12-17
4	11476	2387	1	2004-12-17
5	11476	3091	2	2004-12-17
6	11476	7192	1	2004-12-17
7	11476	7254	3	2004-12-17
8	11476	8416	1	2004-12-17
1	11477	7568	2	2004-12-21
2	11477	2719	2	2004-12-21
3	11477	7342	3	2004-12-21
4	11477	9669	1	2004-12-21
1	11478	6797	2	2004-12-06
2	11478	7134	3	2004-12-06
3	11478	3204	3	2004-12-06
4	11478	9914	2	2004-12-06
5	11478	5519	3	2004-12-06
6	11478	7951	1	2004-12-06
7	11478	4934	2	2004-12-06
8	11478	5960	1	2004-12-06
9	11478	3625	1	2004-12-06
1	11479	7672	2	2004-12-16
2	11479	6869	3	2004-12-16
3	11479	8139	3	2004-12-16
4	11479	7082	3	2004-12-16
5	11479	8079	2	2004-12-16
6	11479	4738	2	2004-12-16
7	11479	2868	3	2004-12-16
1	11480	9887	1	2004-12-15
1	11481	6423	1	2004-12-10
2	11481	2019	1	2004-12-10
3	11481	3369	1	2004-12-10
4	11481	9063	1	2004-12-10
5	11481	5406	2	2004-12-10
6	11481	8380	2	2004-12-10
7	11481	4418	2	2004-12-10
8	11481	2620	1	2004-12-10
9	11481	9339	3	2004-12-10
1	11482	4988	3	2004-12-24
2	11482	2688	2	2004-12-24
3	11482	1718	2	2004-12-24
1	11483	2446	3	2004-12-31
2	11483	7498	2	2004-12-31
3	11483	6748	2	2004-12-31
4	11483	6854	1	2004-12-31
5	11483	2492	2	2004-12-31
6	11483	5698	3	2004-12-31
1	11484	5674	3	2004-12-03
1	11485	504	1	2004-12-07
2	11485	2100	1	2004-12-07
3	11485	7944	1	2004-12-07
4	11485	2490	1	2004-12-07
5	11485	7907	2	2004-12-07
6	11485	9338	2	2004-12-07
7	11485	749	2	2004-12-07
1	11486	2835	2	2004-12-07
2	11486	1366	2	2004-12-07
3	11486	2251	1	2004-12-07
4	11486	3561	3	2004-12-07
5	11486	7881	2	2004-12-07
1	11487	9666	2	2004-12-28
2	11487	1619	3	2004-12-28
3	11487	6919	2	2004-12-28
4	11487	241	2	2004-12-28
5	11487	9044	3	2004-12-28
6	11487	230	3	2004-12-28
7	11487	5662	1	2004-12-28
8	11487	7393	2	2004-12-28
9	11487	6653	1	2004-12-28
1	11488	8788	3	2004-12-25
1	11489	4098	2	2004-12-25
2	11489	6301	2	2004-12-25
3	11489	1268	3	2004-12-25
4	11489	1372	3	2004-12-25
5	11489	2028	1	2004-12-25
6	11489	3011	1	2004-12-25
7	11489	1190	1	2004-12-25
1	11490	749	1	2004-12-03
2	11490	8482	3	2004-12-03
3	11490	106	1	2004-12-03
4	11490	8666	3	2004-12-03
5	11490	9553	3	2004-12-03
6	11490	5561	1	2004-12-03
7	11490	3577	3	2004-12-03
8	11490	8810	3	2004-12-03
1	11491	8263	3	2004-12-11
2	11491	6404	1	2004-12-11
3	11491	895	3	2004-12-11
4	11491	4514	1	2004-12-11
5	11491	4444	3	2004-12-11
1	11492	3775	1	2004-12-01
2	11492	731	1	2004-12-01
3	11492	1037	1	2004-12-01
4	11492	9114	2	2004-12-01
5	11492	2951	1	2004-12-01
6	11492	6255	1	2004-12-01
7	11492	2568	3	2004-12-01
8	11492	1837	1	2004-12-01
1	11493	1374	1	2004-12-14
1	11494	5838	1	2004-12-27
2	11494	8101	3	2004-12-27
3	11494	1345	1	2004-12-27
1	11495	2358	2	2004-12-01
1	11496	7069	3	2004-12-24
2	11496	3582	3	2004-12-24
3	11496	9050	3	2004-12-24
4	11496	9005	3	2004-12-24
1	11497	6266	1	2004-12-28
2	11497	292	1	2004-12-28
3	11497	6008	3	2004-12-28
4	11497	9978	3	2004-12-28
5	11497	267	3	2004-12-28
6	11497	9429	2	2004-12-28
7	11497	1051	1	2004-12-28
1	11498	2610	2	2004-12-25
2	11498	2814	2	2004-12-25
3	11498	3068	1	2004-12-25
4	11498	4240	1	2004-12-25
1	11499	544	3	2004-12-04
2	11499	4575	1	2004-12-04
1	11500	7936	3	2004-12-03
1	11501	9150	1	2004-12-03
2	11501	545	2	2004-12-03
1	11502	9344	2	2004-12-20
2	11502	889	2	2004-12-20
3	11502	5548	1	2004-12-20
4	11502	6744	3	2004-12-20
5	11502	3406	3	2004-12-20
6	11502	6715	3	2004-12-20
7	11502	8123	3	2004-12-20
8	11502	8564	3	2004-12-20
9	11502	8328	2	2004-12-20
1	11503	961	1	2004-12-22
1	11504	4658	3	2004-12-10
2	11504	8236	2	2004-12-10
3	11504	3138	3	2004-12-10
4	11504	7586	3	2004-12-10
5	11504	1113	2	2004-12-10
6	11504	6684	2	2004-12-10
7	11504	1616	2	2004-12-10
8	11504	2499	3	2004-12-10
9	11504	931	1	2004-12-10
1	11505	8377	1	2004-12-22
2	11505	4846	3	2004-12-22
3	11505	4437	3	2004-12-22
4	11505	842	2	2004-12-22
1	11506	9502	2	2004-12-22
2	11506	4416	3	2004-12-22
3	11506	5180	2	2004-12-22
4	11506	1416	1	2004-12-22
5	11506	46	1	2004-12-22
1	11507	3608	3	2004-12-17
2	11507	5450	1	2004-12-17
3	11507	3783	2	2004-12-17
4	11507	2594	3	2004-12-17
5	11507	3164	3	2004-12-17
6	11507	6473	2	2004-12-17
1	11508	8820	3	2004-12-03
2	11508	575	1	2004-12-03
3	11508	6094	2	2004-12-03
4	11508	8762	3	2004-12-03
1	11509	1352	1	2004-12-24
2	11509	9070	2	2004-12-24
3	11509	3160	2	2004-12-24
1	11510	5570	1	2004-12-19
2	11510	5753	1	2004-12-19
3	11510	5516	2	2004-12-19
4	11510	5570	2	2004-12-19
5	11510	557	2	2004-12-19
6	11510	4028	1	2004-12-19
7	11510	7623	1	2004-12-19
8	11510	6885	2	2004-12-19
1	11511	7380	2	2004-12-24
2	11511	1476	2	2004-12-24
3	11511	1504	2	2004-12-24
4	11511	968	3	2004-12-24
5	11511	1578	3	2004-12-24
6	11511	6354	3	2004-12-24
7	11511	823	1	2004-12-24
8	11511	9189	2	2004-12-24
1	11512	9146	2	2004-12-27
2	11512	268	3	2004-12-27
3	11512	5509	3	2004-12-27
4	11512	3154	1	2004-12-27
5	11512	1654	3	2004-12-27
6	11512	1310	3	2004-12-27
7	11512	4890	1	2004-12-27
8	11512	5482	2	2004-12-27
9	11512	7421	2	2004-12-27
1	11513	6145	2	2004-12-13
1	11514	90	2	2004-12-08
1	11515	6005	2	2004-12-01
1	11516	7503	3	2004-12-24
2	11516	8308	1	2004-12-24
3	11516	2414	2	2004-12-24
4	11516	8785	3	2004-12-24
5	11516	239	1	2004-12-24
6	11516	8832	2	2004-12-24
7	11516	3185	2	2004-12-24
8	11516	2589	2	2004-12-24
9	11516	308	2	2004-12-24
1	11517	9634	3	2004-12-21
2	11517	7399	2	2004-12-21
3	11517	4648	2	2004-12-21
4	11517	4796	1	2004-12-21
5	11517	4294	1	2004-12-21
6	11517	2595	1	2004-12-21
7	11517	4691	2	2004-12-21
1	11518	6283	2	2004-12-20
2	11518	2631	3	2004-12-20
3	11518	8649	2	2004-12-20
4	11518	5135	3	2004-12-20
5	11518	733	1	2004-12-20
6	11518	9354	1	2004-12-20
1	11519	4626	2	2004-12-28
2	11519	1214	3	2004-12-28
3	11519	7611	2	2004-12-28
4	11519	1720	1	2004-12-28
5	11519	8108	2	2004-12-28
6	11519	5214	2	2004-12-28
1	11520	3730	2	2004-12-31
2	11520	5634	1	2004-12-31
3	11520	8976	1	2004-12-31
4	11520	1335	3	2004-12-31
5	11520	2632	1	2004-12-31
6	11520	237	1	2004-12-31
1	11521	4878	3	2004-12-30
2	11521	3722	1	2004-12-30
3	11521	4340	2	2004-12-30
4	11521	2694	1	2004-12-30
1	11522	7964	3	2004-12-06
2	11522	7901	1	2004-12-06
1	11523	4303	2	2004-12-06
1	11524	8361	2	2004-12-02
1	11525	4814	2	2004-12-04
2	11525	8343	3	2004-12-04
3	11525	9233	1	2004-12-04
4	11525	1602	1	2004-12-04
5	11525	8943	3	2004-12-04
6	11525	2818	3	2004-12-04
1	11526	4254	1	2004-12-21
2	11526	9239	3	2004-12-21
3	11526	8073	3	2004-12-21
4	11526	5490	2	2004-12-21
5	11526	491	2	2004-12-21
6	11526	9934	1	2004-12-21
7	11526	9831	1	2004-12-21
8	11526	7323	2	2004-12-21
1	11527	6701	2	2004-12-12
2	11527	4111	2	2004-12-12
3	11527	3944	3	2004-12-12
1	11528	8997	1	2004-12-08
2	11528	3815	3	2004-12-08
1	11529	6052	3	2004-12-02
2	11529	9796	2	2004-12-02
3	11529	9940	3	2004-12-02
4	11529	5989	3	2004-12-02
5	11529	4270	3	2004-12-02
6	11529	2927	3	2004-12-02
1	11530	5270	3	2004-12-09
2	11530	3851	3	2004-12-09
3	11530	7969	1	2004-12-09
4	11530	8964	3	2004-12-09
5	11530	3399	1	2004-12-09
6	11530	5201	2	2004-12-09
7	11530	4664	1	2004-12-09
1	11531	6702	1	2004-12-31
2	11531	9223	1	2004-12-31
3	11531	8856	2	2004-12-31
4	11531	2475	1	2004-12-31
5	11531	1561	2	2004-12-31
6	11531	1409	2	2004-12-31
7	11531	2207	3	2004-12-31
8	11531	2438	2	2004-12-31
9	11531	4495	1	2004-12-31
1	11532	6235	1	2004-12-24
1	11533	1615	3	2004-12-15
2	11533	4207	3	2004-12-15
3	11533	9000	2	2004-12-15
4	11533	1008	3	2004-12-15
5	11533	6923	2	2004-12-15
1	11534	3510	1	2004-12-30
1	11535	6354	2	2004-12-24
2	11535	5674	2	2004-12-24
1	11536	2807	1	2004-12-18
1	11537	2739	3	2004-12-16
2	11537	2594	2	2004-12-16
3	11537	6307	3	2004-12-16
4	11537	7227	2	2004-12-16
5	11537	7998	2	2004-12-16
6	11537	6987	1	2004-12-16
7	11537	6967	2	2004-12-16
8	11537	7455	2	2004-12-16
9	11537	6924	2	2004-12-16
1	11538	4505	2	2004-12-27
2	11538	4466	3	2004-12-27
3	11538	5873	3	2004-12-27
4	11538	1734	2	2004-12-27
1	11539	8217	1	2004-12-27
2	11539	694	2	2004-12-27
1	11540	199	3	2004-12-19
2	11540	7723	3	2004-12-19
3	11540	2400	2	2004-12-19
1	11541	5100	1	2004-12-05
2	11541	2820	3	2004-12-05
3	11541	9058	3	2004-12-05
4	11541	8987	1	2004-12-05
5	11541	4019	3	2004-12-05
6	11541	5263	3	2004-12-05
7	11541	8749	2	2004-12-05
8	11541	7882	3	2004-12-05
9	11541	8924	2	2004-12-05
1	11542	8764	2	2004-12-26
2	11542	5986	1	2004-12-26
3	11542	9292	3	2004-12-26
4	11542	2145	2	2004-12-26
5	11542	6442	3	2004-12-26
6	11542	8281	3	2004-12-26
7	11542	6809	3	2004-12-26
8	11542	7954	2	2004-12-26
1	11543	9768	1	2004-12-26
2	11543	6871	3	2004-12-26
3	11543	1556	2	2004-12-26
4	11543	1559	3	2004-12-26
1	11544	3129	2	2004-12-20
2	11544	6081	1	2004-12-20
3	11544	1454	3	2004-12-20
4	11544	8955	3	2004-12-20
5	11544	5469	3	2004-12-20
1	11545	8071	1	2004-12-23
2	11545	7080	1	2004-12-23
3	11545	6094	3	2004-12-23
4	11545	3549	1	2004-12-23
5	11545	4498	2	2004-12-23
1	11546	4539	1	2004-12-28
2	11546	9828	3	2004-12-28
3	11546	6819	2	2004-12-28
4	11546	88	3	2004-12-28
5	11546	4133	3	2004-12-28
1	11547	1877	1	2004-12-20
2	11547	8431	3	2004-12-20
3	11547	3554	2	2004-12-20
1	11548	2611	3	2004-12-05
2	11548	36	1	2004-12-05
3	11548	2911	2	2004-12-05
4	11548	6279	3	2004-12-05
5	11548	7642	2	2004-12-05
1	11549	2733	2	2004-12-16
2	11549	4246	3	2004-12-16
3	11549	5748	1	2004-12-16
4	11549	2222	3	2004-12-16
5	11549	1374	1	2004-12-16
1	11550	4574	3	2004-12-24
2	11550	3886	3	2004-12-24
3	11550	5375	2	2004-12-24
4	11550	8553	3	2004-12-24
5	11550	8750	2	2004-12-24
6	11550	5734	2	2004-12-24
7	11550	938	1	2004-12-24
8	11550	852	1	2004-12-24
9	11550	6052	2	2004-12-24
1	11551	820	2	2004-12-29
2	11551	2472	1	2004-12-29
3	11551	5358	1	2004-12-29
4	11551	7120	1	2004-12-29
5	11551	8998	1	2004-12-29
1	11552	6805	3	2004-12-01
2	11552	3699	2	2004-12-01
3	11552	2262	3	2004-12-01
4	11552	1945	1	2004-12-01
5	11552	282	1	2004-12-01
1	11553	6630	3	2004-12-20
2	11553	96	3	2004-12-20
3	11553	3569	1	2004-12-20
4	11553	9642	3	2004-12-20
5	11553	2611	3	2004-12-20
1	11554	4492	3	2004-12-02
1	11555	6850	3	2004-12-19
2	11555	9031	3	2004-12-19
3	11555	223	3	2004-12-19
4	11555	1590	2	2004-12-19
5	11555	5646	3	2004-12-19
6	11555	1623	1	2004-12-19
7	11555	6833	1	2004-12-19
8	11555	9724	1	2004-12-19
9	11555	4286	3	2004-12-19
1	11556	8506	2	2004-12-29
2	11556	260	1	2004-12-29
3	11556	1915	2	2004-12-29
4	11556	4293	3	2004-12-29
5	11556	5758	1	2004-12-29
6	11556	3702	2	2004-12-29
7	11556	9937	2	2004-12-29
8	11556	4101	1	2004-12-29
9	11556	298	3	2004-12-29
1	11557	3639	1	2004-12-30
2	11557	6731	3	2004-12-30
3	11557	1111	2	2004-12-30
4	11557	4821	3	2004-12-30
5	11557	5834	1	2004-12-30
6	11557	1820	2	2004-12-30
1	11558	412	3	2004-12-20
1	11559	8038	3	2004-12-06
2	11559	3221	3	2004-12-06
1	11560	9045	2	2004-12-21
2	11560	410	2	2004-12-21
3	11560	1818	1	2004-12-21
4	11560	1835	2	2004-12-21
5	11560	8758	3	2004-12-21
6	11560	9964	1	2004-12-21
7	11560	3761	2	2004-12-21
8	11560	4311	2	2004-12-21
1	11561	8835	3	2004-12-22
2	11561	353	3	2004-12-22
3	11561	3720	2	2004-12-22
4	11561	5207	1	2004-12-22
5	11561	6289	2	2004-12-22
6	11561	9030	2	2004-12-22
7	11561	9355	3	2004-12-22
8	11561	1108	1	2004-12-22
1	11562	610	3	2004-12-03
2	11562	294	2	2004-12-03
3	11562	4060	2	2004-12-03
4	11562	384	1	2004-12-03
5	11562	9326	2	2004-12-03
6	11562	9619	3	2004-12-03
7	11562	1228	3	2004-12-03
8	11562	5033	2	2004-12-03
9	11562	3544	1	2004-12-03
1	11563	5165	2	2004-12-17
2	11563	3781	2	2004-12-17
3	11563	6228	2	2004-12-17
4	11563	9215	2	2004-12-17
1	11564	4194	2	2004-12-14
2	11564	9354	2	2004-12-14
3	11564	6832	3	2004-12-14
4	11564	8984	2	2004-12-14
5	11564	6840	1	2004-12-14
1	11565	2112	1	2004-12-20
2	11565	9797	3	2004-12-20
3	11565	4812	2	2004-12-20
4	11565	2868	3	2004-12-20
5	11565	1233	3	2004-12-20
6	11565	3333	1	2004-12-20
7	11565	3134	3	2004-12-20
8	11565	271	2	2004-12-20
9	11565	2539	2	2004-12-20
1	11566	571	3	2004-12-03
2	11566	4099	3	2004-12-03
3	11566	8237	1	2004-12-03
4	11566	9283	2	2004-12-03
5	11566	486	1	2004-12-03
6	11566	3866	1	2004-12-03
7	11566	9206	3	2004-12-03
1	11567	1169	1	2004-12-17
2	11567	6923	2	2004-12-17
3	11567	8391	3	2004-12-17
4	11567	9248	1	2004-12-17
5	11567	1658	1	2004-12-17
6	11567	2820	1	2004-12-17
1	11568	802	3	2004-12-24
2	11568	2331	1	2004-12-24
1	11569	3099	1	2004-12-02
2	11569	2900	3	2004-12-02
3	11569	2756	1	2004-12-02
4	11569	4818	2	2004-12-02
1	11570	8934	3	2004-12-03
2	11570	89	1	2004-12-03
3	11570	7537	1	2004-12-03
4	11570	1291	2	2004-12-03
5	11570	6300	1	2004-12-03
6	11570	7060	3	2004-12-03
7	11570	6978	3	2004-12-03
8	11570	7184	3	2004-12-03
9	11570	2207	3	2004-12-03
1	11571	3648	1	2004-12-05
2	11571	4625	3	2004-12-05
3	11571	6023	2	2004-12-05
4	11571	206	2	2004-12-05
5	11571	4556	3	2004-12-05
1	11572	7552	1	2004-12-06
2	11572	4507	2	2004-12-06
3	11572	1037	1	2004-12-06
4	11572	952	3	2004-12-06
5	11572	956	3	2004-12-06
6	11572	5349	1	2004-12-06
7	11572	6797	3	2004-12-06
8	11572	8468	2	2004-12-06
9	11572	1361	1	2004-12-06
1	11573	1380	1	2004-12-26
2	11573	8508	2	2004-12-26
3	11573	9924	1	2004-12-26
4	11573	578	3	2004-12-26
1	11574	1981	1	2004-12-30
2	11574	5560	1	2004-12-30
3	11574	9726	2	2004-12-30
4	11574	1068	2	2004-12-30
1	11575	4003	2	2004-12-31
2	11575	260	1	2004-12-31
3	11575	9323	1	2004-12-31
4	11575	6500	1	2004-12-31
5	11575	1624	2	2004-12-31
6	11575	6636	1	2004-12-31
7	11575	5237	3	2004-12-31
8	11575	1201	2	2004-12-31
1	11576	3587	2	2004-12-17
2	11576	257	1	2004-12-17
3	11576	793	1	2004-12-17
4	11576	8385	1	2004-12-17
5	11576	9188	1	2004-12-17
6	11576	8615	1	2004-12-17
7	11576	3701	3	2004-12-17
1	11577	3724	1	2004-12-17
2	11577	6938	1	2004-12-17
1	11578	6897	1	2004-12-09
2	11578	5960	2	2004-12-09
3	11578	240	3	2004-12-09
4	11578	9890	1	2004-12-09
1	11579	1152	1	2004-12-09
2	11579	1604	3	2004-12-09
1	11580	8327	3	2004-12-14
2	11580	1559	1	2004-12-14
3	11580	9693	3	2004-12-14
4	11580	2410	1	2004-12-14
5	11580	669	3	2004-12-14
6	11580	6662	3	2004-12-14
7	11580	2898	1	2004-12-14
8	11580	3179	1	2004-12-14
9	11580	2167	1	2004-12-14
1	11581	6265	2	2004-12-12
2	11581	6462	3	2004-12-12
3	11581	4669	1	2004-12-12
4	11581	3173	1	2004-12-12
5	11581	288	1	2004-12-12
1	11582	342	2	2004-12-06
2	11582	3933	1	2004-12-06
1	11583	3215	1	2004-12-19
2	11583	1976	2	2004-12-19
3	11583	4821	2	2004-12-19
4	11583	404	3	2004-12-19
5	11583	1064	3	2004-12-19
6	11583	3473	3	2004-12-19
7	11583	4537	3	2004-12-19
8	11583	8185	3	2004-12-19
1	11584	318	1	2004-12-05
2	11584	4470	1	2004-12-05
3	11584	8715	3	2004-12-05
1	11585	3493	1	2004-12-06
1	11586	1077	3	2004-12-07
2	11586	5389	1	2004-12-07
3	11586	4662	3	2004-12-07
4	11586	9666	3	2004-12-07
5	11586	7001	3	2004-12-07
6	11586	6906	3	2004-12-07
7	11586	6323	2	2004-12-07
1	11587	7300	3	2004-12-05
2	11587	4436	3	2004-12-05
3	11587	2238	2	2004-12-05
4	11587	9212	2	2004-12-05
5	11587	5642	1	2004-12-05
6	11587	1198	1	2004-12-05
1	11588	4415	2	2004-12-25
2	11588	2274	2	2004-12-25
3	11588	5084	3	2004-12-25
4	11588	1931	1	2004-12-25
1	11589	4893	3	2004-12-24
2	11589	5323	1	2004-12-24
3	11589	4556	3	2004-12-24
4	11589	1160	3	2004-12-24
5	11589	3190	1	2004-12-24
6	11589	2523	3	2004-12-24
7	11589	1579	2	2004-12-24
8	11589	2062	3	2004-12-24
9	11589	5995	1	2004-12-24
1	11590	4490	2	2004-12-10
2	11590	4565	2	2004-12-10
3	11590	6245	1	2004-12-10
4	11590	4673	2	2004-12-10
5	11590	1579	3	2004-12-10
1	11591	6659	1	2004-12-05
2	11591	2667	3	2004-12-05
3	11591	3290	2	2004-12-05
4	11591	8679	2	2004-12-05
5	11591	8911	1	2004-12-05
6	11591	4472	2	2004-12-05
1	11592	2779	3	2004-12-13
2	11592	7455	3	2004-12-13
3	11592	6225	2	2004-12-13
1	11593	464	3	2004-12-30
2	11593	8112	1	2004-12-30
1	11594	4619	3	2004-12-17
2	11594	3095	1	2004-12-17
3	11594	3296	1	2004-12-17
4	11594	4038	3	2004-12-17
5	11594	6910	3	2004-12-17
6	11594	5257	1	2004-12-17
7	11594	1264	3	2004-12-17
8	11594	2029	3	2004-12-17
1	11595	9151	1	2004-12-17
2	11595	6224	3	2004-12-17
3	11595	9826	2	2004-12-17
4	11595	1835	2	2004-12-17
5	11595	9106	3	2004-12-17
1	11596	7022	3	2004-12-10
2	11596	8067	1	2004-12-10
3	11596	6466	2	2004-12-10
4	11596	9124	1	2004-12-10
5	11596	7201	1	2004-12-10
6	11596	9757	3	2004-12-10
1	11597	148	2	2004-12-29
2	11597	1983	2	2004-12-29
1	11598	6872	3	2004-12-20
2	11598	5057	3	2004-12-20
3	11598	3534	1	2004-12-20
4	11598	5901	1	2004-12-20
5	11598	9156	2	2004-12-20
6	11598	1614	2	2004-12-20
7	11598	8943	1	2004-12-20
8	11598	7343	2	2004-12-20
1	11599	2236	1	2004-12-04
1	11600	8753	2	2004-12-06
2	11600	5543	3	2004-12-06
3	11600	3818	1	2004-12-06
4	11600	9269	3	2004-12-06
1	11601	3358	3	2004-12-07
2	11601	2119	2	2004-12-07
3	11601	4108	1	2004-12-07
4	11601	5709	1	2004-12-07
5	11601	7205	3	2004-12-07
6	11601	8551	1	2004-12-07
7	11601	7065	1	2004-12-07
8	11601	5431	3	2004-12-07
1	11602	654	3	2004-12-10
2	11602	1379	2	2004-12-10
1	11603	3450	1	2004-12-02
2	11603	913	3	2004-12-02
3	11603	1163	1	2004-12-02
1	11604	6721	1	2004-12-06
2	11604	4321	2	2004-12-06
3	11604	3874	1	2004-12-06
4	11604	6057	3	2004-12-06
5	11604	202	3	2004-12-06
6	11604	4223	1	2004-12-06
7	11604	1145	2	2004-12-06
1	11605	3171	1	2004-12-03
2	11605	4115	2	2004-12-03
1	11606	8059	2	2004-12-17
2	11606	1800	1	2004-12-17
3	11606	2691	3	2004-12-17
4	11606	3449	3	2004-12-17
5	11606	3792	3	2004-12-17
6	11606	8397	3	2004-12-17
1	11607	1352	1	2004-12-21
1	11608	3553	2	2004-12-18
2	11608	7765	3	2004-12-18
3	11608	2530	1	2004-12-18
4	11608	2696	2	2004-12-18
5	11608	9663	1	2004-12-18
1	11609	9983	2	2004-12-04
2	11609	861	2	2004-12-04
3	11609	3676	3	2004-12-04
4	11609	3622	1	2004-12-04
1	11610	2910	3	2004-12-25
2	11610	1406	2	2004-12-25
3	11610	1947	2	2004-12-25
4	11610	1559	3	2004-12-25
5	11610	2627	2	2004-12-25
6	11610	2844	2	2004-12-25
7	11610	44	1	2004-12-25
8	11610	6077	1	2004-12-25
9	11610	3968	3	2004-12-25
1	11611	7724	3	2004-12-16
2	11611	5171	1	2004-12-16
3	11611	9314	1	2004-12-16
4	11611	4039	1	2004-12-16
5	11611	2235	3	2004-12-16
6	11611	7337	2	2004-12-16
1	11612	8995	1	2004-12-09
2	11612	8243	1	2004-12-09
3	11612	6547	3	2004-12-09
4	11612	4344	1	2004-12-09
1	11613	2262	3	2004-12-30
2	11613	455	3	2004-12-30
3	11613	5954	2	2004-12-30
4	11613	1331	2	2004-12-30
5	11613	8652	2	2004-12-30
1	11614	4526	2	2004-12-18
2	11614	2350	1	2004-12-18
3	11614	9068	1	2004-12-18
1	11615	5597	3	2004-12-14
1	11616	9628	3	2004-12-11
2	11616	2066	1	2004-12-11
3	11616	8085	3	2004-12-11
4	11616	5707	3	2004-12-11
5	11616	3287	2	2004-12-11
1	11617	2083	3	2004-12-15
2	11617	2015	2	2004-12-15
3	11617	2893	1	2004-12-15
4	11617	5777	3	2004-12-15
5	11617	8393	3	2004-12-15
6	11617	8137	2	2004-12-15
7	11617	6485	1	2004-12-15
1	11618	421	3	2004-12-29
2	11618	8784	3	2004-12-29
3	11618	6863	2	2004-12-29
4	11618	7921	1	2004-12-29
5	11618	8848	1	2004-12-29
6	11618	9166	2	2004-12-29
7	11618	9808	1	2004-12-29
8	11618	3861	1	2004-12-29
1	11619	3994	1	2004-12-18
2	11619	416	1	2004-12-18
1	11620	9222	1	2004-12-17
2	11620	3061	3	2004-12-17
3	11620	9407	1	2004-12-17
4	11620	8148	2	2004-12-17
1	11621	8775	2	2004-12-20
2	11621	9273	3	2004-12-20
3	11621	6833	1	2004-12-20
4	11621	403	1	2004-12-20
5	11621	9886	1	2004-12-20
1	11622	6010	3	2004-12-13
2	11622	1285	3	2004-12-13
3	11622	4244	1	2004-12-13
4	11622	358	3	2004-12-13
1	11623	6033	2	2004-12-01
2	11623	4365	1	2004-12-01
3	11623	663	1	2004-12-01
4	11623	8035	3	2004-12-01
5	11623	1721	2	2004-12-01
6	11623	3069	1	2004-12-01
7	11623	7380	1	2004-12-01
8	11623	5430	1	2004-12-01
1	11624	9916	3	2004-12-22
2	11624	2638	2	2004-12-22
3	11624	7525	1	2004-12-22
1	11625	5970	3	2004-12-05
1	11626	3473	3	2004-12-19
2	11626	6692	2	2004-12-19
3	11626	4143	3	2004-12-19
4	11626	7317	1	2004-12-19
5	11626	2714	1	2004-12-19
6	11626	2871	3	2004-12-19
7	11626	2777	3	2004-12-19
1	11627	6852	1	2004-12-08
2	11627	8022	3	2004-12-08
3	11627	821	1	2004-12-08
4	11627	8926	3	2004-12-08
5	11627	9572	2	2004-12-08
1	11628	91	3	2004-12-23
1	11629	5756	1	2004-12-18
2	11629	5851	3	2004-12-18
3	11629	484	3	2004-12-18
1	11630	7901	3	2004-12-23
2	11630	6001	2	2004-12-23
3	11630	6485	3	2004-12-23
1	11631	429	1	2004-12-21
2	11631	7089	1	2004-12-21
3	11631	1331	3	2004-12-21
4	11631	667	3	2004-12-21
5	11631	1413	3	2004-12-21
6	11631	225	3	2004-12-21
1	11632	4703	1	2004-12-31
1	11633	4192	1	2004-12-10
1	11634	6087	1	2004-12-22
2	11634	9986	2	2004-12-22
3	11634	3046	3	2004-12-22
4	11634	8718	2	2004-12-22
1	11635	8275	1	2004-12-14
2	11635	2832	3	2004-12-14
3	11635	7794	3	2004-12-14
4	11635	8416	1	2004-12-14
5	11635	1649	1	2004-12-14
6	11635	8518	3	2004-12-14
1	11636	3386	3	2004-12-09
2	11636	3404	3	2004-12-09
3	11636	411	2	2004-12-09
4	11636	5988	2	2004-12-09
5	11636	463	2	2004-12-09
6	11636	7832	2	2004-12-09
7	11636	4089	3	2004-12-09
8	11636	381	1	2004-12-09
9	11636	1046	1	2004-12-09
1	11637	1336	2	2004-12-02
2	11637	483	3	2004-12-02
3	11637	1010	1	2004-12-02
4	11637	2563	1	2004-12-02
5	11637	2862	2	2004-12-02
6	11637	8512	2	2004-12-02
7	11637	5421	3	2004-12-02
8	11637	9655	1	2004-12-02
1	11638	4833	1	2004-12-08
1	11639	8425	1	2004-12-30
1	11640	3746	1	2004-12-30
1	11641	5167	3	2004-12-02
2	11641	9119	2	2004-12-02
3	11641	4692	2	2004-12-02
1	11642	4463	1	2004-12-09
2	11642	5188	3	2004-12-09
3	11642	2262	2	2004-12-09
4	11642	4507	2	2004-12-09
5	11642	5304	1	2004-12-09
1	11643	5479	3	2004-12-25
2	11643	2171	2	2004-12-25
3	11643	1693	3	2004-12-25
4	11643	9257	3	2004-12-25
5	11643	6162	3	2004-12-25
6	11643	537	1	2004-12-25
7	11643	2914	1	2004-12-25
8	11643	5199	3	2004-12-25
9	11643	8115	3	2004-12-25
1	11644	8026	2	2004-12-03
2	11644	8010	1	2004-12-03
3	11644	6393	2	2004-12-03
1	11645	6522	3	2004-12-25
2	11645	9618	3	2004-12-25
3	11645	5550	3	2004-12-25
4	11645	5074	1	2004-12-25
1	11646	8747	3	2004-12-23
1	11647	165	2	2004-12-28
2	11647	3125	3	2004-12-28
3	11647	9839	1	2004-12-28
4	11647	1519	2	2004-12-28
5	11647	7004	3	2004-12-28
6	11647	5815	1	2004-12-28
7	11647	3102	1	2004-12-28
8	11647	460	1	2004-12-28
9	11647	550	2	2004-12-28
1	11648	1233	1	2004-12-05
2	11648	9002	3	2004-12-05
3	11648	8046	3	2004-12-05
4	11648	6842	2	2004-12-05
5	11648	7967	3	2004-12-05
6	11648	1845	1	2004-12-05
7	11648	5195	1	2004-12-05
8	11648	2225	3	2004-12-05
1	11649	1875	3	2004-12-25
2	11649	6065	1	2004-12-25
3	11649	2104	2	2004-12-25
4	11649	8343	2	2004-12-25
1	11650	6347	1	2004-12-07
2	11650	3450	2	2004-12-07
3	11650	9562	1	2004-12-07
4	11650	9860	3	2004-12-07
1	11651	3388	1	2004-12-23
2	11651	9203	1	2004-12-23
3	11651	72	2	2004-12-23
1	11652	4280	3	2004-12-16
1	11653	8686	1	2004-12-24
2	11653	3418	2	2004-12-24
3	11653	4744	3	2004-12-24
4	11653	9424	2	2004-12-24
5	11653	7158	3	2004-12-24
6	11653	1833	2	2004-12-24
7	11653	987	1	2004-12-24
8	11653	6944	2	2004-12-24
9	11653	1295	2	2004-12-24
1	11654	3312	2	2004-12-18
1	11655	215	2	2004-12-06
2	11655	9462	3	2004-12-06
3	11655	7354	1	2004-12-06
4	11655	3931	1	2004-12-06
5	11655	9746	2	2004-12-06
6	11655	6402	3	2004-12-06
7	11655	2637	3	2004-12-06
8	11655	1357	2	2004-12-06
9	11655	8685	3	2004-12-06
1	11656	1346	2	2004-12-25
2	11656	4384	2	2004-12-25
3	11656	2582	2	2004-12-25
4	11656	2250	2	2004-12-25
1	11657	1363	3	2004-12-18
2	11657	8042	2	2004-12-18
3	11657	9657	3	2004-12-18
4	11657	8648	2	2004-12-18
5	11657	4692	1	2004-12-18
1	11658	4348	1	2004-12-14
2	11658	2956	3	2004-12-14
3	11658	6582	2	2004-12-14
1	11659	7152	1	2004-12-16
2	11659	3512	1	2004-12-16
3	11659	3672	2	2004-12-16
4	11659	8016	2	2004-12-16
5	11659	1279	2	2004-12-16
6	11659	328	1	2004-12-16
7	11659	3846	3	2004-12-16
1	11660	4585	2	2004-12-22
2	11660	4260	3	2004-12-22
1	11661	1518	1	2004-12-26
2	11661	5619	1	2004-12-26
3	11661	47	1	2004-12-26
4	11661	1685	2	2004-12-26
5	11661	5624	2	2004-12-26
1	11662	9697	1	2004-12-23
2	11662	9489	2	2004-12-23
3	11662	9693	2	2004-12-23
4	11662	2078	3	2004-12-23
5	11662	7764	2	2004-12-23
6	11662	5119	1	2004-12-23
7	11662	5594	1	2004-12-23
8	11662	9240	1	2004-12-23
1	11663	1233	2	2004-12-25
2	11663	6235	1	2004-12-25
3	11663	9516	1	2004-12-25
4	11663	8273	3	2004-12-25
1	11664	9380	2	2004-12-18
2	11664	8735	3	2004-12-18
3	11664	1314	1	2004-12-18
4	11664	9024	3	2004-12-18
5	11664	7475	2	2004-12-18
1	11665	6384	2	2004-12-04
1	11666	8253	2	2004-12-04
2	11666	5246	3	2004-12-04
3	11666	6735	2	2004-12-04
1	11667	7425	1	2004-12-15
2	11667	4739	2	2004-12-15
3	11667	633	2	2004-12-15
4	11667	6971	3	2004-12-15
5	11667	5131	2	2004-12-15
6	11667	3797	2	2004-12-15
7	11667	7512	1	2004-12-15
8	11667	6573	2	2004-12-15
9	11667	6307	3	2004-12-15
1	11668	9826	2	2004-12-20
2	11668	2213	2	2004-12-20
3	11668	8761	3	2004-12-20
4	11668	8792	1	2004-12-20
1	11669	2374	1	2004-12-21
2	11669	7469	3	2004-12-21
1	11670	8831	1	2004-12-09
2	11670	7713	2	2004-12-09
3	11670	5196	2	2004-12-09
4	11670	3072	1	2004-12-09
5	11670	8968	1	2004-12-09
6	11670	5830	3	2004-12-09
1	11671	4814	2	2004-12-26
2	11671	8012	1	2004-12-26
3	11671	359	1	2004-12-26
4	11671	2907	1	2004-12-26
5	11671	3647	1	2004-12-26
6	11671	2077	2	2004-12-26
7	11671	2974	2	2004-12-26
1	11672	7207	1	2004-12-10
1	11673	3346	3	2004-12-15
2	11673	2511	1	2004-12-15
3	11673	7619	3	2004-12-15
4	11673	8728	1	2004-12-15
1	11674	7253	3	2004-12-07
2	11674	5098	1	2004-12-07
3	11674	7205	3	2004-12-07
1	11675	1983	1	2004-12-23
1	11676	9466	2	2004-12-04
2	11676	9553	1	2004-12-04
3	11676	5886	1	2004-12-04
4	11676	4468	2	2004-12-04
5	11676	9926	1	2004-12-04
6	11676	5936	1	2004-12-04
1	11677	6689	3	2004-12-31
2	11677	8085	2	2004-12-31
3	11677	6567	2	2004-12-31
4	11677	4072	3	2004-12-31
5	11677	5770	2	2004-12-31
6	11677	9807	3	2004-12-31
7	11677	5243	1	2004-12-31
1	11678	7520	2	2004-12-09
2	11678	4303	1	2004-12-09
3	11678	8067	2	2004-12-09
1	11679	3862	1	2004-12-17
2	11679	2303	1	2004-12-17
3	11679	9851	1	2004-12-17
4	11679	4444	2	2004-12-17
5	11679	5805	3	2004-12-17
1	11680	8428	3	2004-12-19
2	11680	8197	1	2004-12-19
3	11680	4521	3	2004-12-19
4	11680	3355	1	2004-12-19
5	11680	1438	3	2004-12-19
6	11680	4027	3	2004-12-19
1	11681	4325	3	2004-12-06
2	11681	8501	2	2004-12-06
3	11681	7917	3	2004-12-06
4	11681	7014	1	2004-12-06
5	11681	4768	1	2004-12-06
6	11681	877	1	2004-12-06
7	11681	4394	2	2004-12-06
8	11681	6618	1	2004-12-06
1	11682	1689	3	2004-12-17
2	11682	1818	1	2004-12-17
3	11682	4946	2	2004-12-17
4	11682	2629	3	2004-12-17
5	11682	5054	2	2004-12-17
6	11682	4874	3	2004-12-17
7	11682	3501	2	2004-12-17
8	11682	6005	1	2004-12-17
9	11682	1726	1	2004-12-17
1	11683	7282	1	2004-12-12
2	11683	101	2	2004-12-12
3	11683	3052	2	2004-12-12
4	11683	8713	3	2004-12-12
5	11683	5137	1	2004-12-12
1	11684	2799	2	2004-12-14
2	11684	6053	3	2004-12-14
3	11684	2290	1	2004-12-14
4	11684	7230	2	2004-12-14
5	11684	4301	1	2004-12-14
6	11684	7207	2	2004-12-14
7	11684	6254	1	2004-12-14
8	11684	2519	1	2004-12-14
9	11684	5640	3	2004-12-14
1	11685	1098	1	2004-12-08
2	11685	2361	2	2004-12-08
3	11685	2814	2	2004-12-08
4	11685	3189	2	2004-12-08
5	11685	5860	2	2004-12-08
1	11686	2839	1	2004-12-08
2	11686	574	3	2004-12-08
3	11686	4305	3	2004-12-08
4	11686	3166	1	2004-12-08
5	11686	8766	2	2004-12-08
1	11687	144	3	2004-12-09
2	11687	345	1	2004-12-09
3	11687	1596	1	2004-12-09
4	11687	7477	2	2004-12-09
5	11687	9343	1	2004-12-09
1	11688	7115	1	2004-12-03
2	11688	8030	3	2004-12-03
3	11688	1564	3	2004-12-03
1	11689	6427	2	2004-12-22
1	11690	4046	3	2004-12-19
2	11690	611	2	2004-12-19
1	11691	6616	2	2004-12-03
2	11691	9082	3	2004-12-03
3	11691	1640	2	2004-12-03
4	11691	611	3	2004-12-03
5	11691	6229	3	2004-12-03
6	11691	8708	3	2004-12-03
7	11691	7243	2	2004-12-03
8	11691	3660	2	2004-12-03
1	11692	9161	3	2004-12-19
2	11692	3428	1	2004-12-19
1	11693	6245	2	2004-12-25
2	11693	7384	1	2004-12-25
3	11693	1130	2	2004-12-25
4	11693	227	1	2004-12-25
5	11693	2200	1	2004-12-25
6	11693	1523	3	2004-12-25
7	11693	9476	1	2004-12-25
8	11693	6220	3	2004-12-25
9	11693	6030	3	2004-12-25
1	11694	4089	3	2004-12-02
2	11694	7452	3	2004-12-02
3	11694	2333	2	2004-12-02
4	11694	1555	3	2004-12-02
5	11694	4448	3	2004-12-02
6	11694	4621	1	2004-12-02
7	11694	660	2	2004-12-02
8	11694	8297	1	2004-12-02
9	11694	8519	1	2004-12-02
1	11695	271	2	2004-12-06
2	11695	7917	2	2004-12-06
1	11696	7383	1	2004-12-16
2	11696	4113	2	2004-12-16
3	11696	9994	2	2004-12-16
4	11696	315	1	2004-12-16
5	11696	6375	2	2004-12-16
1	11697	6745	2	2004-12-29
1	11698	5305	2	2004-12-03
2	11698	3811	2	2004-12-03
3	11698	9455	1	2004-12-03
1	11699	9464	3	2004-12-06
1	11700	22	1	2004-12-09
2	11700	4280	2	2004-12-09
3	11700	7283	2	2004-12-09
1	11701	8767	2	2004-12-23
2	11701	9399	2	2004-12-23
3	11701	7136	2	2004-12-23
4	11701	8464	1	2004-12-23
1	11702	2396	1	2004-12-01
2	11702	2414	1	2004-12-01
1	11703	7886	2	2004-12-01
2	11703	4759	1	2004-12-01
3	11703	1853	1	2004-12-01
1	11704	3379	2	2004-12-18
2	11704	3946	1	2004-12-18
3	11704	8837	1	2004-12-18
4	11704	7480	3	2004-12-18
5	11704	2028	3	2004-12-18
6	11704	5219	2	2004-12-18
7	11704	9909	3	2004-12-18
8	11704	7362	1	2004-12-18
9	11704	9473	3	2004-12-18
1	11705	367	2	2004-12-24
2	11705	7526	1	2004-12-24
3	11705	6433	1	2004-12-24
4	11705	1463	1	2004-12-24
5	11705	2740	2	2004-12-24
1	11706	7766	2	2004-12-22
2	11706	3170	3	2004-12-22
3	11706	2856	3	2004-12-22
4	11706	4494	1	2004-12-22
5	11706	6002	1	2004-12-22
6	11706	5086	2	2004-12-22
1	11707	7922	1	2004-12-29
2	11707	3274	2	2004-12-29
3	11707	2969	3	2004-12-29
4	11707	8764	2	2004-12-29
5	11707	2056	1	2004-12-29
6	11707	9273	3	2004-12-29
7	11707	8188	3	2004-12-29
8	11707	4958	2	2004-12-29
1	11708	6515	1	2004-12-07
2	11708	7608	1	2004-12-07
3	11708	2094	1	2004-12-07
4	11708	7991	1	2004-12-07
5	11708	5254	3	2004-12-07
1	11709	8623	1	2004-12-01
2	11709	3204	3	2004-12-01
3	11709	6522	2	2004-12-01
4	11709	8889	2	2004-12-01
1	11710	3029	2	2004-12-14
2	11710	7432	3	2004-12-14
3	11710	9518	2	2004-12-14
4	11710	9013	3	2004-12-14
5	11710	6463	1	2004-12-14
6	11710	9819	2	2004-12-14
7	11710	2450	2	2004-12-14
8	11710	2827	1	2004-12-14
9	11710	8248	1	2004-12-14
1	11711	4256	1	2004-12-20
2	11711	4636	1	2004-12-20
3	11711	6355	3	2004-12-20
4	11711	221	3	2004-12-20
5	11711	8288	1	2004-12-20
6	11711	3713	2	2004-12-20
7	11711	2024	1	2004-12-20
8	11711	9665	1	2004-12-20
9	11711	356	2	2004-12-20
1	11712	5246	2	2004-12-07
2	11712	7269	2	2004-12-07
3	11712	5355	2	2004-12-07
4	11712	363	3	2004-12-07
5	11712	2819	2	2004-12-07
1	11713	6438	3	2004-12-31
2	11713	5351	2	2004-12-31
3	11713	1234	3	2004-12-31
4	11713	444	1	2004-12-31
5	11713	2293	1	2004-12-31
6	11713	4295	1	2004-12-31
1	11714	1032	3	2004-12-20
2	11714	222	3	2004-12-20
3	11714	1561	2	2004-12-20
4	11714	1742	1	2004-12-20
5	11714	4971	2	2004-12-20
6	11714	6542	2	2004-12-20
7	11714	2016	2	2004-12-20
1	11715	3179	2	2004-12-04
2	11715	5651	2	2004-12-04
3	11715	6780	3	2004-12-04
4	11715	3731	1	2004-12-04
5	11715	591	3	2004-12-04
6	11715	7513	2	2004-12-04
1	11716	6844	1	2004-12-22
2	11716	2579	3	2004-12-22
3	11716	4963	3	2004-12-22
4	11716	3147	1	2004-12-22
5	11716	2476	2	2004-12-22
6	11716	5808	2	2004-12-22
7	11716	3615	3	2004-12-22
1	11717	415	3	2004-12-01
2	11717	3895	2	2004-12-01
3	11717	9471	2	2004-12-01
4	11717	4112	3	2004-12-01
5	11717	7898	1	2004-12-01
6	11717	5527	3	2004-12-01
1	11718	956	3	2004-12-25
1	11719	9264	2	2004-12-25
1	11720	9672	2	2004-12-14
2	11720	464	1	2004-12-14
3	11720	2802	2	2004-12-14
4	11720	4232	1	2004-12-14
5	11720	8843	3	2004-12-14
1	11721	6118	3	2004-12-29
2	11721	7151	3	2004-12-29
3	11721	7606	3	2004-12-29
4	11721	5915	2	2004-12-29
5	11721	2210	2	2004-12-29
1	11722	4352	1	2004-12-19
1	11723	4109	3	2004-12-16
2	11723	9672	3	2004-12-16
3	11723	1753	3	2004-12-16
4	11723	6683	1	2004-12-16
5	11723	5255	2	2004-12-16
1	11724	9907	1	2004-12-18
2	11724	1045	2	2004-12-18
3	11724	6286	1	2004-12-18
1	11725	2752	3	2004-12-02
1	11726	2918	3	2004-12-08
2	11726	8542	1	2004-12-08
3	11726	5550	1	2004-12-08
4	11726	1104	1	2004-12-08
5	11726	1301	2	2004-12-08
6	11726	8152	3	2004-12-08
7	11726	7730	1	2004-12-08
8	11726	26	3	2004-12-08
9	11726	1859	1	2004-12-08
1	11727	557	3	2004-12-11
2	11727	4180	1	2004-12-11
3	11727	8128	2	2004-12-11
4	11727	912	1	2004-12-11
1	11728	6417	2	2004-12-18
2	11728	4458	3	2004-12-18
3	11728	6221	2	2004-12-18
4	11728	3878	2	2004-12-18
1	11729	9242	3	2004-12-09
2	11729	3941	1	2004-12-09
3	11729	5575	3	2004-12-09
1	11730	9440	2	2004-12-21
1	11731	4179	2	2004-12-24
2	11731	7297	1	2004-12-24
3	11731	9098	1	2004-12-24
1	11732	9689	1	2004-12-26
2	11732	3600	2	2004-12-26
1	11733	5538	3	2004-12-11
2	11733	5435	1	2004-12-11
3	11733	4400	1	2004-12-11
4	11733	3258	2	2004-12-11
5	11733	8190	1	2004-12-11
6	11733	4190	2	2004-12-11
7	11733	3902	3	2004-12-11
1	11734	2953	3	2004-12-31
2	11734	4385	1	2004-12-31
3	11734	9074	2	2004-12-31
4	11734	824	1	2004-12-31
5	11734	9335	2	2004-12-31
6	11734	5513	1	2004-12-31
7	11734	1224	1	2004-12-31
8	11734	295	2	2004-12-31
9	11734	3359	2	2004-12-31
1	11735	7385	1	2004-12-30
2	11735	2457	1	2004-12-30
3	11735	1091	1	2004-12-30
4	11735	2485	1	2004-12-30
5	11735	1494	2	2004-12-30
6	11735	7136	2	2004-12-30
7	11735	5903	2	2004-12-30
1	11736	781	2	2004-12-31
2	11736	1313	1	2004-12-31
3	11736	5444	1	2004-12-31
4	11736	8663	3	2004-12-31
5	11736	6300	3	2004-12-31
6	11736	5419	2	2004-12-31
7	11736	5666	1	2004-12-31
8	11736	7555	3	2004-12-31
9	11736	4090	3	2004-12-31
1	11737	2012	2	2004-12-02
2	11737	7921	3	2004-12-02
1	11738	7158	2	2004-12-07
1	11739	77	2	2004-12-17
1	11740	1209	3	2004-12-30
2	11740	7788	3	2004-12-30
3	11740	7944	1	2004-12-30
4	11740	7408	3	2004-12-30
5	11740	8452	2	2004-12-30
1	11741	8378	2	2004-12-02
2	11741	6329	1	2004-12-02
3	11741	4917	2	2004-12-02
4	11741	8440	1	2004-12-02
5	11741	1956	2	2004-12-02
6	11741	1000	1	2004-12-02
7	11741	1953	1	2004-12-02
8	11741	8409	2	2004-12-02
1	11742	8381	2	2004-12-18
2	11742	5214	2	2004-12-18
3	11742	2368	2	2004-12-18
4	11742	1897	1	2004-12-18
1	11743	7833	3	2004-12-13
2	11743	5525	1	2004-12-13
3	11743	1172	2	2004-12-13
1	11744	5161	1	2004-12-10
2	11744	4550	2	2004-12-10
3	11744	7892	1	2004-12-10
4	11744	3187	2	2004-12-10
1	11745	7355	1	2004-12-11
2	11745	2313	3	2004-12-11
3	11745	2967	2	2004-12-11
4	11745	3093	2	2004-12-11
5	11745	8947	1	2004-12-11
6	11745	2011	2	2004-12-11
7	11745	3674	1	2004-12-11
8	11745	8436	2	2004-12-11
1	11746	48	2	2004-12-20
2	11746	5040	3	2004-12-20
1	11747	9792	3	2004-12-17
2	11747	7372	3	2004-12-17
3	11747	9525	3	2004-12-17
4	11747	6398	1	2004-12-17
5	11747	6125	3	2004-12-17
6	11747	6816	2	2004-12-17
7	11747	416	3	2004-12-17
8	11747	9543	2	2004-12-17
1	11748	6244	1	2004-12-07
2	11748	9791	2	2004-12-07
3	11748	6581	2	2004-12-07
4	11748	4231	1	2004-12-07
5	11748	3056	2	2004-12-07
6	11748	593	1	2004-12-07
7	11748	5454	3	2004-12-07
8	11748	9994	2	2004-12-07
1	11749	5881	2	2004-12-24
2	11749	8845	2	2004-12-24
3	11749	3112	3	2004-12-24
4	11749	385	2	2004-12-24
1	11750	2521	1	2004-12-20
2	11750	8900	3	2004-12-20
3	11750	8060	1	2004-12-20
1	11751	3963	2	2004-12-04
2	11751	9528	2	2004-12-04
1	11752	949	2	2004-12-30
2	11752	1308	3	2004-12-30
3	11752	2524	2	2004-12-30
4	11752	8180	1	2004-12-30
5	11752	9540	2	2004-12-30
6	11752	4040	1	2004-12-30
7	11752	7154	2	2004-12-30
1	11753	9185	2	2004-12-20
2	11753	5385	3	2004-12-20
3	11753	8194	3	2004-12-20
4	11753	2885	3	2004-12-20
1	11754	9462	2	2004-12-11
2	11754	9877	1	2004-12-11
3	11754	5638	1	2004-12-11
4	11754	5189	2	2004-12-11
1	11755	7709	2	2004-12-17
2	11755	5908	2	2004-12-17
3	11755	1571	1	2004-12-17
4	11755	8189	1	2004-12-17
5	11755	8199	2	2004-12-17
6	11755	9063	2	2004-12-17
7	11755	2921	1	2004-12-17
8	11755	4113	2	2004-12-17
9	11755	4386	3	2004-12-17
1	11756	4618	1	2004-12-31
2	11756	2149	3	2004-12-31
3	11756	4310	3	2004-12-31
4	11756	4535	1	2004-12-31
5	11756	6804	1	2004-12-31
6	11756	8190	1	2004-12-31
7	11756	6161	3	2004-12-31
8	11756	4278	2	2004-12-31
9	11756	515	1	2004-12-31
1	11757	1524	1	2004-12-25
1	11758	9758	3	2004-12-22
2	11758	6686	2	2004-12-22
3	11758	7337	3	2004-12-22
4	11758	4181	1	2004-12-22
5	11758	6291	3	2004-12-22
6	11758	4319	1	2004-12-22
7	11758	957	1	2004-12-22
1	11759	1466	1	2004-12-18
1	11760	229	2	2004-12-08
2	11760	4409	3	2004-12-08
1	11761	3244	1	2004-12-31
2	11761	3923	1	2004-12-31
3	11761	9752	3	2004-12-31
4	11761	2225	2	2004-12-31
5	11761	6818	2	2004-12-31
6	11761	9137	3	2004-12-31
7	11761	9051	2	2004-12-31
8	11761	4893	1	2004-12-31
9	11761	5023	2	2004-12-31
1	11762	9009	2	2004-12-13
2	11762	338	2	2004-12-13
3	11762	3268	1	2004-12-13
4	11762	9816	3	2004-12-13
5	11762	9678	1	2004-12-13
6	11762	8415	2	2004-12-13
1	11763	4208	3	2004-12-12
2	11763	2407	2	2004-12-12
3	11763	6297	1	2004-12-12
4	11763	8285	1	2004-12-12
5	11763	2774	1	2004-12-12
6	11763	7547	3	2004-12-12
1	11764	9266	2	2004-12-03
2	11764	3316	1	2004-12-03
3	11764	3795	1	2004-12-03
4	11764	32	2	2004-12-03
5	11764	6190	3	2004-12-03
6	11764	7073	3	2004-12-03
7	11764	6612	3	2004-12-03
8	11764	5692	1	2004-12-03
9	11764	7299	3	2004-12-03
1	11765	4784	1	2004-12-13
2	11765	5755	1	2004-12-13
3	11765	9199	2	2004-12-13
1	11766	6192	3	2004-12-18
2	11766	7421	3	2004-12-18
3	11766	2988	3	2004-12-18
4	11766	3459	3	2004-12-18
5	11766	5898	1	2004-12-18
1	11767	3329	2	2004-12-28
2	11767	2796	3	2004-12-28
3	11767	203	1	2004-12-28
4	11767	9939	2	2004-12-28
5	11767	4677	2	2004-12-28
1	11768	6402	3	2004-12-23
2	11768	7826	1	2004-12-23
3	11768	8737	2	2004-12-23
1	11769	903	3	2004-12-08
2	11769	6571	3	2004-12-08
3	11769	1105	2	2004-12-08
4	11769	4606	2	2004-12-08
5	11769	2487	3	2004-12-08
6	11769	1925	1	2004-12-08
1	11770	7558	2	2004-12-31
2	11770	8302	3	2004-12-31
3	11770	7929	2	2004-12-31
4	11770	8775	2	2004-12-31
1	11771	9236	2	2004-12-23
2	11771	5916	1	2004-12-23
3	11771	2295	1	2004-12-23
4	11771	46	2	2004-12-23
5	11771	8366	2	2004-12-23
6	11771	7833	1	2004-12-23
7	11771	2052	3	2004-12-23
8	11771	3541	1	2004-12-23
9	11771	1621	1	2004-12-23
1	11772	9073	2	2004-12-20
2	11772	9234	3	2004-12-20
3	11772	9887	2	2004-12-20
4	11772	5359	1	2004-12-20
5	11772	6407	2	2004-12-20
1	11773	4809	2	2004-12-15
2	11773	279	1	2004-12-15
3	11773	9429	3	2004-12-15
4	11773	4026	1	2004-12-15
5	11773	7868	3	2004-12-15
6	11773	3282	3	2004-12-15
7	11773	8781	3	2004-12-15
1	11774	9118	1	2004-12-27
2	11774	5585	3	2004-12-27
3	11774	9803	1	2004-12-27
4	11774	9891	2	2004-12-27
5	11774	5537	2	2004-12-27
6	11774	8533	1	2004-12-27
7	11774	1355	2	2004-12-27
1	11775	9744	1	2004-12-16
2	11775	5954	3	2004-12-16
3	11775	8108	3	2004-12-16
4	11775	7100	3	2004-12-16
5	11775	8745	2	2004-12-16
1	11776	6058	3	2004-12-06
1	11777	2071	2	2004-12-31
2	11777	4358	1	2004-12-31
3	11777	5835	2	2004-12-31
4	11777	3945	1	2004-12-31
5	11777	7346	1	2004-12-31
6	11777	5354	3	2004-12-31
7	11777	1002	1	2004-12-31
8	11777	4701	3	2004-12-31
9	11777	542	1	2004-12-31
1	11778	2072	1	2004-12-19
2	11778	8858	3	2004-12-19
3	11778	155	3	2004-12-19
4	11778	3989	1	2004-12-19
5	11778	8734	2	2004-12-19
6	11778	5751	1	2004-12-19
7	11778	6662	1	2004-12-19
8	11778	8805	1	2004-12-19
1	11779	3239	1	2004-12-08
2	11779	9126	3	2004-12-08
3	11779	1175	3	2004-12-08
4	11779	9741	3	2004-12-08
5	11779	8955	3	2004-12-08
6	11779	5041	1	2004-12-08
7	11779	8373	2	2004-12-08
8	11779	9154	3	2004-12-08
1	11780	9201	2	2004-12-09
2	11780	4574	2	2004-12-09
1	11781	9528	3	2004-12-19
2	11781	6331	1	2004-12-19
3	11781	9599	2	2004-12-19
4	11781	706	1	2004-12-19
5	11781	5125	1	2004-12-19
6	11781	7945	2	2004-12-19
7	11781	7751	1	2004-12-19
8	11781	5104	2	2004-12-19
1	11782	7401	2	2004-12-22
2	11782	1114	2	2004-12-22
3	11782	7821	2	2004-12-22
4	11782	2463	2	2004-12-22
5	11782	9065	3	2004-12-22
6	11782	2379	3	2004-12-22
7	11782	6463	3	2004-12-22
8	11782	1359	2	2004-12-22
9	11782	4166	1	2004-12-22
1	11783	3369	1	2004-12-22
2	11783	7763	3	2004-12-22
3	11783	6385	2	2004-12-22
4	11783	2731	1	2004-12-22
5	11783	4277	1	2004-12-22
1	11784	1077	3	2004-12-14
2	11784	6080	1	2004-12-14
1	11785	7167	1	2004-12-26
2	11785	648	1	2004-12-26
3	11785	2157	3	2004-12-26
4	11785	623	2	2004-12-26
5	11785	2259	2	2004-12-26
1	11786	4667	2	2004-12-16
2	11786	2347	3	2004-12-16
1	11787	8952	2	2004-12-17
2	11787	1252	2	2004-12-17
1	11788	3964	1	2004-12-18
2	11788	4376	2	2004-12-18
3	11788	1988	2	2004-12-18
4	11788	2092	1	2004-12-18
1	11789	4372	3	2004-12-04
2	11789	7441	3	2004-12-04
3	11789	4262	3	2004-12-04
4	11789	7981	3	2004-12-04
5	11789	6526	1	2004-12-04
6	11789	1644	2	2004-12-04
1	11790	2272	2	2004-12-24
2	11790	7555	2	2004-12-24
3	11790	4651	1	2004-12-24
1	11791	9249	3	2004-12-03
2	11791	7287	2	2004-12-03
3	11791	5791	1	2004-12-03
1	11792	3019	3	2004-12-16
2	11792	8766	3	2004-12-16
3	11792	990	1	2004-12-16
4	11792	5022	3	2004-12-16
5	11792	3306	2	2004-12-16
6	11792	1983	2	2004-12-16
7	11792	9526	3	2004-12-16
8	11792	1812	2	2004-12-16
9	11792	1468	1	2004-12-16
1	11793	9594	1	2004-12-03
1	11794	8616	2	2004-12-19
1	11795	1180	2	2004-12-01
2	11795	9186	2	2004-12-01
3	11795	3610	1	2004-12-01
4	11795	1731	2	2004-12-01
5	11795	8068	1	2004-12-01
6	11795	5129	3	2004-12-01
7	11795	5433	2	2004-12-01
8	11795	2535	2	2004-12-01
1	11796	1005	1	2004-12-21
2	11796	1506	2	2004-12-21
3	11796	3056	1	2004-12-21
4	11796	774	1	2004-12-21
5	11796	1756	2	2004-12-21
6	11796	1842	1	2004-12-21
1	11797	3518	1	2004-12-30
2	11797	8784	1	2004-12-30
3	11797	2123	2	2004-12-30
1	11798	3802	3	2004-12-05
2	11798	2124	1	2004-12-05
3	11798	3158	1	2004-12-05
4	11798	2336	2	2004-12-05
1	11799	8457	2	2004-12-27
2	11799	4126	1	2004-12-27
3	11799	9474	2	2004-12-27
4	11799	1325	3	2004-12-27
5	11799	6899	2	2004-12-27
6	11799	9476	2	2004-12-27
7	11799	6427	1	2004-12-27
8	11799	9595	3	2004-12-27
9	11799	9153	1	2004-12-27
1	11800	3066	1	2004-12-06
2	11800	7139	2	2004-12-06
3	11800	4961	2	2004-12-06
4	11800	792	3	2004-12-06
1	11801	9546	2	2004-12-17
2	11801	3084	1	2004-12-17
3	11801	4367	3	2004-12-17
4	11801	5713	2	2004-12-17
5	11801	5665	1	2004-12-17
6	11801	5441	2	2004-12-17
7	11801	28	2	2004-12-17
8	11801	5364	1	2004-12-17
9	11801	7548	1	2004-12-17
1	11802	6015	3	2004-12-19
2	11802	8871	3	2004-12-19
3	11802	7506	2	2004-12-19
1	11803	9547	2	2004-12-19
2	11803	6471	2	2004-12-19
3	11803	6565	1	2004-12-19
4	11803	7757	1	2004-12-19
5	11803	4322	1	2004-12-19
6	11803	7489	2	2004-12-19
1	11804	5356	1	2004-12-25
2	11804	5950	3	2004-12-25
3	11804	5251	1	2004-12-25
4	11804	5918	2	2004-12-25
5	11804	8770	2	2004-12-25
1	11805	425	3	2004-12-26
2	11805	8324	3	2004-12-26
1	11806	7118	2	2004-12-03
2	11806	1626	2	2004-12-03
3	11806	7748	3	2004-12-03
4	11806	7458	2	2004-12-03
5	11806	4752	1	2004-12-03
6	11806	6200	1	2004-12-03
7	11806	969	1	2004-12-03
8	11806	2666	3	2004-12-03
1	11807	6260	3	2004-12-18
2	11807	5557	3	2004-12-18
3	11807	4281	2	2004-12-18
4	11807	3578	2	2004-12-18
1	11808	6054	2	2004-12-28
2	11808	491	2	2004-12-28
3	11808	4423	3	2004-12-28
4	11808	7813	3	2004-12-28
5	11808	762	2	2004-12-28
6	11808	9877	1	2004-12-28
1	11809	3977	3	2004-12-17
1	11810	6920	1	2004-12-16
1	11811	3153	3	2004-12-14
2	11811	8935	3	2004-12-14
3	11811	4072	3	2004-12-14
1	11812	7669	3	2004-12-10
1	11813	87	3	2004-12-15
1	11814	4299	2	2004-12-05
2	11814	6577	1	2004-12-05
3	11814	4581	1	2004-12-05
4	11814	1715	1	2004-12-05
5	11814	3911	2	2004-12-05
6	11814	9325	1	2004-12-05
1	11815	1890	3	2004-12-13
2	11815	7897	3	2004-12-13
3	11815	7776	1	2004-12-13
4	11815	7104	3	2004-12-13
5	11815	3019	3	2004-12-13
6	11815	6120	2	2004-12-13
7	11815	1253	2	2004-12-13
1	11816	6769	1	2004-12-02
2	11816	7952	3	2004-12-02
3	11816	2220	1	2004-12-02
4	11816	3350	1	2004-12-02
5	11816	4708	3	2004-12-02
6	11816	4941	3	2004-12-02
7	11816	4501	3	2004-12-02
1	11817	5124	2	2004-12-21
2	11817	2034	3	2004-12-21
3	11817	682	3	2004-12-21
4	11817	2485	1	2004-12-21
1	11818	92	2	2004-12-06
2	11818	1014	3	2004-12-06
3	11818	2737	1	2004-12-06
4	11818	9906	2	2004-12-06
5	11818	4779	2	2004-12-06
6	11818	3508	3	2004-12-06
7	11818	1589	3	2004-12-06
8	11818	6551	3	2004-12-06
9	11818	405	1	2004-12-06
1	11819	3670	3	2004-12-09
2	11819	2787	2	2004-12-09
3	11819	9048	2	2004-12-09
4	11819	9154	2	2004-12-09
5	11819	3520	3	2004-12-09
1	11820	7768	3	2004-12-03
2	11820	9608	1	2004-12-03
3	11820	1805	1	2004-12-03
4	11820	2266	2	2004-12-03
1	11821	1756	2	2004-12-04
2	11821	7056	3	2004-12-04
1	11822	6880	2	2004-12-28
2	11822	6086	2	2004-12-28
1	11823	4139	1	2004-12-03
2	11823	5187	1	2004-12-03
1	11824	7909	3	2004-12-31
2	11824	4956	3	2004-12-31
1	11825	757	3	2004-12-18
2	11825	5477	3	2004-12-18
3	11825	8338	1	2004-12-18
4	11825	1213	2	2004-12-18
5	11825	5125	3	2004-12-18
6	11825	1250	2	2004-12-18
7	11825	6903	2	2004-12-18
1	11826	2947	3	2004-12-24
2	11826	7648	3	2004-12-24
3	11826	413	2	2004-12-24
1	11827	1925	2	2004-12-13
2	11827	6940	1	2004-12-13
3	11827	2756	1	2004-12-13
4	11827	2273	1	2004-12-13
5	11827	3194	2	2004-12-13
6	11827	6310	3	2004-12-13
7	11827	782	3	2004-12-13
8	11827	4322	3	2004-12-13
9	11827	4087	1	2004-12-13
1	11828	2028	1	2004-12-28
2	11828	9071	1	2004-12-28
1	11829	2838	3	2004-12-25
2	11829	7778	3	2004-12-25
3	11829	2414	1	2004-12-25
1	11830	8171	3	2004-12-07
2	11830	3705	3	2004-12-07
3	11830	5496	3	2004-12-07
4	11830	6637	3	2004-12-07
5	11830	16	2	2004-12-07
1	11831	7352	2	2004-12-09
2	11831	7228	2	2004-12-09
3	11831	9290	2	2004-12-09
4	11831	8034	1	2004-12-09
5	11831	4769	2	2004-12-09
1	11832	1868	3	2004-12-06
2	11832	9487	1	2004-12-06
3	11832	5905	1	2004-12-06
4	11832	8991	1	2004-12-06
1	11833	989	2	2004-12-04
2	11833	6094	3	2004-12-04
1	11834	8845	2	2004-12-27
2	11834	793	3	2004-12-27
3	11834	5542	2	2004-12-27
4	11834	2688	3	2004-12-27
5	11834	2743	3	2004-12-27
6	11834	1546	2	2004-12-27
1	11835	4223	2	2004-12-22
2	11835	4305	2	2004-12-22
3	11835	9267	2	2004-12-22
1	11836	8276	3	2004-12-21
2	11836	6212	1	2004-12-21
3	11836	3312	2	2004-12-21
1	11837	9665	2	2004-12-19
2	11837	8801	1	2004-12-19
1	11838	1378	1	2004-12-12
1	11839	1040	2	2004-12-12
2	11839	3147	3	2004-12-12
3	11839	4828	1	2004-12-12
4	11839	480	1	2004-12-12
5	11839	9728	3	2004-12-12
6	11839	5502	1	2004-12-12
7	11839	1748	1	2004-12-12
8	11839	7143	2	2004-12-12
1	11840	9215	1	2004-12-09
2	11840	1815	2	2004-12-09
1	11841	8793	1	2004-12-09
2	11841	4028	3	2004-12-09
3	11841	7778	3	2004-12-09
4	11841	7546	1	2004-12-09
5	11841	9348	3	2004-12-09
6	11841	5708	3	2004-12-09
1	11842	2524	3	2004-12-15
2	11842	147	2	2004-12-15
3	11842	6065	3	2004-12-15
4	11842	6662	2	2004-12-15
5	11842	408	3	2004-12-15
6	11842	1511	1	2004-12-15
1	11843	2615	1	2004-12-06
1	11844	2998	3	2004-12-01
2	11844	5863	3	2004-12-01
3	11844	8809	1	2004-12-01
4	11844	9914	1	2004-12-01
5	11844	7044	1	2004-12-01
6	11844	181	3	2004-12-01
7	11844	7630	2	2004-12-01
8	11844	5640	2	2004-12-01
1	11845	9065	2	2004-12-05
2	11845	2444	3	2004-12-05
3	11845	4896	2	2004-12-05
1	11846	3026	3	2004-12-05
2	11846	1579	3	2004-12-05
1	11847	1310	2	2004-12-23
2	11847	9503	1	2004-12-23
3	11847	3700	3	2004-12-23
4	11847	7735	3	2004-12-23
5	11847	1422	3	2004-12-23
6	11847	5388	2	2004-12-23
7	11847	2292	2	2004-12-23
1	11848	9793	2	2004-12-27
2	11848	8706	2	2004-12-27
3	11848	6005	1	2004-12-27
4	11848	3689	3	2004-12-27
1	11849	7906	3	2004-12-02
1	11850	4539	3	2004-12-21
1	11851	148	1	2004-12-30
2	11851	9476	3	2004-12-30
3	11851	4786	1	2004-12-30
4	11851	2288	2	2004-12-30
5	11851	6335	1	2004-12-30
1	11852	9922	2	2004-12-31
2	11852	4350	3	2004-12-31
3	11852	3429	1	2004-12-31
4	11852	7168	1	2004-12-31
1	11853	6437	3	2004-12-30
2	11853	162	2	2004-12-30
3	11853	4982	1	2004-12-30
4	11853	4247	2	2004-12-30
1	11854	3611	1	2004-12-29
2	11854	2359	2	2004-12-29
1	11855	8424	1	2004-12-17
2	11855	3116	1	2004-12-17
3	11855	3545	1	2004-12-17
4	11855	1877	1	2004-12-17
5	11855	8219	1	2004-12-17
1	11856	8852	3	2004-12-23
2	11856	7878	1	2004-12-23
3	11856	1593	3	2004-12-23
4	11856	2131	3	2004-12-23
5	11856	8323	2	2004-12-23
6	11856	1190	1	2004-12-23
7	11856	9172	2	2004-12-23
1	11857	7401	2	2004-12-18
2	11857	6037	1	2004-12-18
3	11857	5120	3	2004-12-18
4	11857	4152	2	2004-12-18
1	11858	9129	3	2004-12-01
2	11858	9400	3	2004-12-01
3	11858	9942	1	2004-12-01
1	11859	7813	1	2004-12-13
2	11859	2966	3	2004-12-13
3	11859	6900	3	2004-12-13
1	11860	3456	3	2004-12-10
1	11861	1913	3	2004-12-05
2	11861	7151	3	2004-12-05
3	11861	9234	2	2004-12-05
4	11861	6751	3	2004-12-05
5	11861	3285	3	2004-12-05
6	11861	9624	3	2004-12-05
1	11862	9244	1	2004-12-28
2	11862	3562	2	2004-12-28
3	11862	1225	2	2004-12-28
4	11862	4764	2	2004-12-28
5	11862	7152	3	2004-12-28
6	11862	3084	3	2004-12-28
1	11863	6913	1	2004-12-22
2	11863	8613	2	2004-12-22
3	11863	7612	2	2004-12-22
4	11863	4779	1	2004-12-22
5	11863	2056	2	2004-12-22
6	11863	8145	1	2004-12-22
7	11863	3242	3	2004-12-22
8	11863	7397	1	2004-12-22
1	11864	7615	2	2004-12-01
2	11864	5534	2	2004-12-01
1	11865	8562	3	2004-12-05
2	11865	7112	2	2004-12-05
3	11865	8874	2	2004-12-05
4	11865	1620	2	2004-12-05
5	11865	1088	2	2004-12-05
6	11865	7382	1	2004-12-05
7	11865	800	2	2004-12-05
8	11865	3962	2	2004-12-05
1	11866	2317	2	2004-12-10
2	11866	4775	3	2004-12-10
3	11866	8547	1	2004-12-10
4	11866	4698	1	2004-12-10
1	11867	5596	2	2004-12-28
2	11867	2961	2	2004-12-28
3	11867	1397	2	2004-12-28
4	11867	955	1	2004-12-28
5	11867	979	3	2004-12-28
6	11867	5627	1	2004-12-28
7	11867	3863	3	2004-12-28
1	11868	442	1	2004-12-19
2	11868	7502	2	2004-12-19
3	11868	3196	2	2004-12-19
1	11869	5948	2	2004-12-18
2	11869	1937	1	2004-12-18
3	11869	439	2	2004-12-18
4	11869	6012	1	2004-12-18
5	11869	9479	3	2004-12-18
1	11870	2235	3	2004-12-14
2	11870	9535	3	2004-12-14
3	11870	6230	1	2004-12-14
4	11870	401	3	2004-12-14
5	11870	3746	3	2004-12-14
6	11870	1886	3	2004-12-14
7	11870	3949	3	2004-12-14
8	11870	4834	1	2004-12-14
9	11870	1860	1	2004-12-14
1	11871	8695	3	2004-12-16
2	11871	7195	3	2004-12-16
3	11871	5302	1	2004-12-16
4	11871	8630	1	2004-12-16
5	11871	1461	1	2004-12-16
1	11872	1477	3	2004-12-31
2	11872	2669	2	2004-12-31
3	11872	7220	2	2004-12-31
4	11872	2164	1	2004-12-31
5	11872	1965	3	2004-12-31
6	11872	1322	2	2004-12-31
1	11873	1601	2	2004-12-25
1	11874	309	1	2004-12-27
2	11874	4344	1	2004-12-27
3	11874	3982	2	2004-12-27
4	11874	2764	1	2004-12-27
1	11875	9464	3	2004-12-01
2	11875	7335	1	2004-12-01
3	11875	606	3	2004-12-01
1	11876	8169	1	2004-12-27
2	11876	6505	3	2004-12-27
3	11876	7061	2	2004-12-27
4	11876	8564	1	2004-12-27
5	11876	8681	3	2004-12-27
6	11876	4667	1	2004-12-27
1	11877	1548	3	2004-12-02
2	11877	7647	2	2004-12-02
3	11877	26	3	2004-12-02
4	11877	3203	3	2004-12-02
1	11878	5736	3	2004-12-28
2	11878	3766	2	2004-12-28
3	11878	527	1	2004-12-28
4	11878	3674	3	2004-12-28
5	11878	5212	1	2004-12-28
6	11878	9137	2	2004-12-28
7	11878	1111	2	2004-12-28
1	11879	5157	2	2004-12-22
2	11879	1299	1	2004-12-22
3	11879	7765	1	2004-12-22
4	11879	9913	1	2004-12-22
1	11880	6013	1	2004-12-27
2	11880	5124	3	2004-12-27
3	11880	4415	2	2004-12-27
4	11880	47	3	2004-12-27
5	11880	3238	2	2004-12-27
1	11881	6177	2	2004-12-02
2	11881	3188	3	2004-12-02
1	11882	1148	1	2004-12-01
2	11882	2741	1	2004-12-01
1	11883	6765	2	2004-12-05
2	11883	6645	1	2004-12-05
3	11883	5500	1	2004-12-05
4	11883	7539	2	2004-12-05
5	11883	9148	1	2004-12-05
6	11883	805	3	2004-12-05
1	11884	6024	2	2004-12-10
2	11884	7954	2	2004-12-10
3	11884	2443	1	2004-12-10
4	11884	7560	2	2004-12-10
5	11884	971	1	2004-12-10
6	11884	4651	1	2004-12-10
7	11884	1724	2	2004-12-10
8	11884	8462	3	2004-12-10
9	11884	83	2	2004-12-10
1	11885	1128	2	2004-12-02
2	11885	8692	1	2004-12-02
3	11885	4787	1	2004-12-02
4	11885	1889	2	2004-12-02
5	11885	1167	3	2004-12-02
6	11885	9794	3	2004-12-02
7	11885	4054	1	2004-12-02
8	11885	9699	1	2004-12-02
1	11886	2998	2	2004-12-19
1	11887	6565	1	2004-12-15
2	11887	501	1	2004-12-15
3	11887	419	1	2004-12-15
4	11887	8043	3	2004-12-15
5	11887	3562	1	2004-12-15
1	11888	3361	3	2004-12-03
2	11888	1237	3	2004-12-03
1	11889	1605	1	2004-12-02
2	11889	6855	2	2004-12-02
3	11889	4579	1	2004-12-02
4	11889	6061	3	2004-12-02
5	11889	6610	1	2004-12-02
6	11889	9208	3	2004-12-02
1	11890	8735	1	2004-12-17
2	11890	6227	3	2004-12-17
3	11890	7750	2	2004-12-17
4	11890	1802	1	2004-12-17
1	11891	3973	3	2004-12-10
2	11891	2	2	2004-12-10
3	11891	8494	3	2004-12-10
4	11891	179	1	2004-12-10
1	11892	8866	3	2004-12-27
2	11892	2268	2	2004-12-27
3	11892	8610	1	2004-12-27
4	11892	7619	3	2004-12-27
5	11892	3306	2	2004-12-27
1	11893	2165	1	2004-12-22
2	11893	1869	1	2004-12-22
3	11893	5288	2	2004-12-22
4	11893	8242	2	2004-12-22
5	11893	1418	3	2004-12-22
6	11893	2146	1	2004-12-22
7	11893	9807	1	2004-12-22
8	11893	7836	3	2004-12-22
1	11894	922	3	2004-12-19
2	11894	9125	3	2004-12-19
3	11894	4521	1	2004-12-19
4	11894	2386	1	2004-12-19
5	11894	3486	1	2004-12-19
6	11894	381	2	2004-12-19
7	11894	2647	1	2004-12-19
8	11894	6340	3	2004-12-19
1	11895	1316	2	2004-12-26
2	11895	1104	1	2004-12-26
3	11895	6064	3	2004-12-26
4	11895	706	1	2004-12-26
5	11895	5641	3	2004-12-26
6	11895	33	2	2004-12-26
7	11895	6449	3	2004-12-26
8	11895	5103	1	2004-12-26
9	11895	1588	3	2004-12-26
1	11896	723	1	2004-12-08
2	11896	5148	3	2004-12-08
3	11896	9051	1	2004-12-08
1	11897	7645	2	2004-12-06
2	11897	4083	2	2004-12-06
3	11897	2788	2	2004-12-06
1	11898	4991	1	2004-12-18
2	11898	4810	1	2004-12-18
3	11898	1479	2	2004-12-18
4	11898	7581	2	2004-12-18
5	11898	1470	2	2004-12-18
6	11898	6896	1	2004-12-18
1	11899	5280	1	2004-12-23
2	11899	8491	3	2004-12-23
3	11899	3859	2	2004-12-23
4	11899	1873	3	2004-12-23
5	11899	9843	2	2004-12-23
6	11899	2730	2	2004-12-23
1	11900	7301	2	2004-12-10
2	11900	8173	3	2004-12-10
3	11900	2324	2	2004-12-10
4	11900	2777	2	2004-12-10
5	11900	1803	3	2004-12-10
6	11900	5986	3	2004-12-10
7	11900	1716	2	2004-12-10
8	11900	5185	3	2004-12-10
1	11901	9811	3	2004-12-20
2	11901	7940	3	2004-12-20
3	11901	1553	1	2004-12-20
4	11901	5116	2	2004-12-20
5	11901	7460	2	2004-12-20
6	11901	2722	2	2004-12-20
7	11901	2159	1	2004-12-20
8	11901	3539	2	2004-12-20
9	11901	6647	2	2004-12-20
1	11902	7418	3	2004-12-26
2	11902	9502	1	2004-12-26
3	11902	4699	2	2004-12-26
4	11902	6278	3	2004-12-26
1	11903	5741	3	2004-12-18
2	11903	4248	1	2004-12-18
3	11903	2805	1	2004-12-18
4	11903	7090	2	2004-12-18
1	11904	3731	1	2004-12-21
1	11905	6267	3	2004-12-20
2	11905	10	2	2004-12-20
3	11905	1536	2	2004-12-20
1	11906	3902	1	2004-12-05
2	11906	626	3	2004-12-05
3	11906	9200	2	2004-12-05
4	11906	500	1	2004-12-05
5	11906	6580	3	2004-12-05
6	11906	7532	1	2004-12-05
7	11906	6837	2	2004-12-05
1	11907	2573	3	2004-12-10
2	11907	1678	3	2004-12-10
3	11907	7469	1	2004-12-10
4	11907	4606	3	2004-12-10
5	11907	6396	2	2004-12-10
6	11907	6817	1	2004-12-10
7	11907	3062	1	2004-12-10
8	11907	1860	2	2004-12-10
9	11907	361	1	2004-12-10
1	11908	8448	1	2004-12-27
2	11908	8186	2	2004-12-27
3	11908	4548	1	2004-12-27
4	11908	5851	1	2004-12-27
5	11908	607	3	2004-12-27
1	11909	3972	1	2004-12-01
2	11909	6573	1	2004-12-01
3	11909	7882	2	2004-12-01
4	11909	1190	1	2004-12-01
5	11909	4108	1	2004-12-01
6	11909	4630	2	2004-12-01
7	11909	4109	1	2004-12-01
1	11910	7768	2	2004-12-17
2	11910	9059	1	2004-12-17
3	11910	7750	2	2004-12-17
4	11910	3881	3	2004-12-17
1	11911	1551	2	2004-12-11
1	11912	1513	2	2004-12-08
1	11913	88	1	2004-12-04
2	11913	9105	2	2004-12-04
3	11913	497	3	2004-12-04
4	11913	9190	3	2004-12-04
5	11913	3947	3	2004-12-04
6	11913	580	1	2004-12-04
1	11914	8442	1	2004-12-10
2	11914	7086	3	2004-12-10
3	11914	5302	3	2004-12-10
4	11914	8115	1	2004-12-10
5	11914	9891	3	2004-12-10
6	11914	6448	1	2004-12-10
1	11915	8989	2	2004-12-17
2	11915	749	3	2004-12-17
3	11915	3630	3	2004-12-17
4	11915	7750	3	2004-12-17
5	11915	8186	3	2004-12-17
1	11916	7835	1	2004-12-29
2	11916	15	2	2004-12-29
3	11916	1223	2	2004-12-29
4	11916	4468	3	2004-12-29
5	11916	5596	2	2004-12-29
6	11916	8965	1	2004-12-29
7	11916	5535	2	2004-12-29
8	11916	7708	1	2004-12-29
9	11916	9546	3	2004-12-29
1	11917	232	2	2004-12-28
2	11917	29	3	2004-12-28
3	11917	2261	3	2004-12-28
1	11918	6281	3	2004-12-31
2	11918	2515	3	2004-12-31
3	11918	3953	3	2004-12-31
4	11918	6841	3	2004-12-31
5	11918	1340	2	2004-12-31
6	11918	1593	3	2004-12-31
7	11918	18	3	2004-12-31
1	11919	9857	1	2004-12-30
2	11919	778	1	2004-12-30
3	11919	6111	1	2004-12-30
4	11919	8506	3	2004-12-30
5	11919	106	3	2004-12-30
6	11919	3422	3	2004-12-30
7	11919	5861	3	2004-12-30
8	11919	7366	3	2004-12-30
1	11920	868	3	2004-12-23
2	11920	9852	1	2004-12-23
3	11920	3570	3	2004-12-23
4	11920	1760	1	2004-12-23
1	11921	9935	1	2004-12-30
2	11921	9377	2	2004-12-30
3	11921	2980	3	2004-12-30
4	11921	4417	1	2004-12-30
5	11921	6148	3	2004-12-30
6	11921	1815	1	2004-12-30
7	11921	7540	3	2004-12-30
8	11921	382	2	2004-12-30
9	11921	499	2	2004-12-30
1	11922	3827	2	2004-12-28
2	11922	8510	2	2004-12-28
3	11922	9074	3	2004-12-28
4	11922	3343	1	2004-12-28
5	11922	7229	1	2004-12-28
6	11922	2645	2	2004-12-28
7	11922	9323	2	2004-12-28
8	11922	4487	2	2004-12-28
1	11923	2642	3	2004-12-28
1	11924	8761	1	2004-12-31
1	11925	7196	3	2004-12-05
2	11925	983	2	2004-12-05
3	11925	7742	2	2004-12-05
4	11925	6739	2	2004-12-05
5	11925	7602	3	2004-12-05
1	11926	663	2	2004-12-05
2	11926	6697	1	2004-12-05
3	11926	4241	3	2004-12-05
4	11926	1354	2	2004-12-05
5	11926	2362	2	2004-12-05
6	11926	4149	1	2004-12-05
1	11927	1115	3	2004-12-25
2	11927	8956	1	2004-12-25
3	11927	5779	3	2004-12-25
4	11927	6422	1	2004-12-25
5	11927	1667	2	2004-12-25
6	11927	1900	1	2004-12-25
7	11927	948	3	2004-12-25
8	11927	9305	1	2004-12-25
9	11927	624	2	2004-12-25
1	11928	8810	3	2004-12-12
2	11928	416	1	2004-12-12
3	11928	8822	3	2004-12-12
4	11928	8677	1	2004-12-12
5	11928	7434	3	2004-12-12
1	11929	3085	3	2004-12-03
2	11929	8942	2	2004-12-03
3	11929	2335	1	2004-12-03
4	11929	7994	1	2004-12-03
5	11929	7748	3	2004-12-03
6	11929	4891	3	2004-12-03
1	11930	3942	1	2004-12-11
2	11930	6336	2	2004-12-11
3	11930	5003	2	2004-12-11
4	11930	2636	2	2004-12-11
5	11930	6294	1	2004-12-11
6	11930	3472	3	2004-12-11
7	11930	6458	2	2004-12-11
8	11930	3364	3	2004-12-11
1	11931	3146	1	2004-12-12
2	11931	9287	1	2004-12-12
3	11931	9584	2	2004-12-12
4	11931	9265	1	2004-12-12
5	11931	2917	1	2004-12-12
6	11931	1518	3	2004-12-12
1	11932	3011	2	2004-12-15
2	11932	3226	3	2004-12-15
3	11932	3920	3	2004-12-15
4	11932	6243	1	2004-12-15
5	11932	2057	3	2004-12-15
6	11932	9919	2	2004-12-15
7	11932	1911	2	2004-12-15
8	11932	1733	2	2004-12-15
9	11932	6500	1	2004-12-15
1	11933	8965	3	2004-12-19
2	11933	7716	1	2004-12-19
3	11933	4969	1	2004-12-19
4	11933	8336	2	2004-12-19
5	11933	1807	1	2004-12-19
1	11934	1730	3	2004-12-01
2	11934	4329	2	2004-12-01
3	11934	6500	2	2004-12-01
4	11934	9514	3	2004-12-01
1	11935	2265	3	2004-12-27
2	11935	1042	3	2004-12-27
3	11935	4633	1	2004-12-27
4	11935	5572	1	2004-12-27
5	11935	488	1	2004-12-27
1	11936	170	3	2004-12-15
2	11936	1448	1	2004-12-15
3	11936	707	1	2004-12-15
4	11936	7712	2	2004-12-15
5	11936	6963	2	2004-12-15
6	11936	9282	2	2004-12-15
1	11937	2700	3	2004-12-09
2	11937	5505	2	2004-12-09
3	11937	7447	1	2004-12-09
4	11937	3747	1	2004-12-09
5	11937	2487	2	2004-12-09
6	11937	3558	3	2004-12-09
1	11938	7035	2	2004-12-10
2	11938	4046	3	2004-12-10
3	11938	8135	1	2004-12-10
1	11939	1575	3	2004-12-09
2	11939	9799	3	2004-12-09
1	11940	6239	3	2004-12-15
1	11941	4221	1	2004-12-01
2	11941	9903	3	2004-12-01
3	11941	3587	2	2004-12-01
1	11942	8363	2	2004-12-02
2	11942	6309	1	2004-12-02
3	11942	1602	1	2004-12-02
4	11942	3196	1	2004-12-02
5	11942	868	1	2004-12-02
1	11943	5728	1	2004-12-08
2	11943	8489	2	2004-12-08
1	11944	1545	3	2004-12-06
2	11944	3216	2	2004-12-06
3	11944	2170	2	2004-12-06
4	11944	5753	1	2004-12-06
5	11944	8272	2	2004-12-06
6	11944	7044	2	2004-12-06
1	11945	1822	3	2004-12-17
2	11945	1443	2	2004-12-17
3	11945	3272	3	2004-12-17
4	11945	6052	3	2004-12-17
5	11945	8665	2	2004-12-17
6	11945	5047	1	2004-12-17
7	11945	2778	2	2004-12-17
8	11945	6319	2	2004-12-17
1	11946	3255	2	2004-12-09
2	11946	5369	1	2004-12-09
3	11946	9319	1	2004-12-09
4	11946	6107	2	2004-12-09
5	11946	1058	1	2004-12-09
1	11947	7174	2	2004-12-10
2	11947	1396	1	2004-12-10
3	11947	2962	1	2004-12-10
4	11947	7766	3	2004-12-10
5	11947	441	1	2004-12-10
1	11948	6293	2	2004-12-06
2	11948	9399	3	2004-12-06
3	11948	9520	2	2004-12-06
4	11948	1073	3	2004-12-06
5	11948	7180	3	2004-12-06
1	11949	1117	1	2004-12-11
2	11949	891	3	2004-12-11
3	11949	4798	1	2004-12-11
4	11949	1516	3	2004-12-11
5	11949	2346	3	2004-12-11
6	11949	5768	1	2004-12-11
1	11950	2248	2	2004-12-31
2	11950	9002	1	2004-12-31
3	11950	5385	3	2004-12-31
4	11950	6413	2	2004-12-31
5	11950	7359	2	2004-12-31
1	11951	7197	1	2004-12-12
2	11951	4616	3	2004-12-12
3	11951	1236	3	2004-12-12
4	11951	373	1	2004-12-12
1	11952	5505	1	2004-12-23
2	11952	618	2	2004-12-23
3	11952	6543	1	2004-12-23
1	11953	4065	1	2004-12-03
2	11953	2730	1	2004-12-03
3	11953	4516	2	2004-12-03
4	11953	2191	2	2004-12-03
5	11953	147	3	2004-12-03
6	11953	9289	2	2004-12-03
1	11954	3276	1	2004-12-24
2	11954	563	2	2004-12-24
3	11954	4288	2	2004-12-24
4	11954	7165	2	2004-12-24
5	11954	1117	2	2004-12-24
6	11954	7771	1	2004-12-24
7	11954	9250	1	2004-12-24
8	11954	8277	1	2004-12-24
1	11955	7372	3	2004-12-10
2	11955	4064	3	2004-12-10
3	11955	6314	2	2004-12-10
4	11955	2280	2	2004-12-10
5	11955	3878	2	2004-12-10
6	11955	1632	3	2004-12-10
7	11955	7803	1	2004-12-10
1	11956	6997	3	2004-12-08
2	11956	3332	2	2004-12-08
3	11956	1381	1	2004-12-08
4	11956	7049	3	2004-12-08
5	11956	5896	1	2004-12-08
6	11956	663	1	2004-12-08
7	11956	7974	3	2004-12-08
8	11956	7561	1	2004-12-08
9	11956	5552	2	2004-12-08
1	11957	4287	3	2004-12-17
2	11957	6420	1	2004-12-17
3	11957	1486	3	2004-12-17
4	11957	4180	3	2004-12-17
5	11957	8507	1	2004-12-17
6	11957	9122	1	2004-12-17
7	11957	5943	1	2004-12-17
8	11957	4420	1	2004-12-17
9	11957	158	1	2004-12-17
1	11958	8854	3	2004-12-11
2	11958	3255	2	2004-12-11
1	11959	7912	2	2004-12-08
1	11960	3213	1	2004-12-29
1	11961	3558	3	2004-12-02
2	11961	191	3	2004-12-02
3	11961	2900	1	2004-12-02
4	11961	8294	2	2004-12-02
5	11961	1168	3	2004-12-02
6	11961	7361	1	2004-12-02
7	11961	7752	1	2004-12-02
8	11961	4427	1	2004-12-02
9	11961	9261	2	2004-12-02
1	11962	1503	1	2004-12-01
2	11962	340	2	2004-12-01
3	11962	4588	1	2004-12-01
4	11962	6435	3	2004-12-01
5	11962	596	3	2004-12-01
6	11962	8462	1	2004-12-01
7	11962	7970	1	2004-12-01
8	11962	1133	2	2004-12-01
9	11962	7504	1	2004-12-01
1	11963	5480	3	2004-12-18
2	11963	3393	2	2004-12-18
3	11963	3412	2	2004-12-18
1	11964	8394	2	2004-12-06
2	11964	8130	1	2004-12-06
3	11964	4336	2	2004-12-06
4	11964	1534	2	2004-12-06
1	11965	1356	3	2004-12-15
2	11965	8790	3	2004-12-15
3	11965	9150	2	2004-12-15
1	11966	8220	1	2004-12-12
2	11966	3945	1	2004-12-12
3	11966	4518	2	2004-12-12
4	11966	8229	3	2004-12-12
5	11966	9271	2	2004-12-12
6	11966	1037	3	2004-12-12
7	11966	9603	2	2004-12-12
8	11966	1965	1	2004-12-12
9	11966	303	2	2004-12-12
1	11967	2868	3	2004-12-04
2	11967	1348	1	2004-12-04
3	11967	2134	2	2004-12-04
1	11968	631	3	2004-12-11
2	11968	3340	2	2004-12-11
1	11969	8190	2	2004-12-13
2	11969	745	3	2004-12-13
3	11969	9163	1	2004-12-13
4	11969	8929	3	2004-12-13
1	11970	2548	3	2004-12-29
2	11970	6120	2	2004-12-29
3	11970	367	3	2004-12-29
4	11970	8966	2	2004-12-29
5	11970	7940	1	2004-12-29
6	11970	5563	3	2004-12-29
7	11970	1460	3	2004-12-29
8	11970	3717	2	2004-12-29
1	11971	262	3	2004-12-02
2	11971	6451	3	2004-12-02
3	11971	2334	2	2004-12-02
4	11971	8889	1	2004-12-02
5	11971	5440	2	2004-12-02
6	11971	9846	3	2004-12-02
7	11971	2722	2	2004-12-02
8	11971	1882	1	2004-12-02
1	11972	4088	1	2004-12-14
2	11972	727	2	2004-12-14
1	11973	915	3	2004-12-05
2	11973	536	1	2004-12-05
1	11974	2365	3	2004-12-30
2	11974	3482	3	2004-12-30
1	11975	9292	3	2004-12-12
2	11975	9669	2	2004-12-12
3	11975	8520	2	2004-12-12
4	11975	5667	1	2004-12-12
5	11975	9117	2	2004-12-12
6	11975	8155	1	2004-12-12
1	11976	9197	1	2004-12-03
2	11976	2926	3	2004-12-03
1	11977	3013	2	2004-12-31
2	11977	91	3	2004-12-31
3	11977	7506	2	2004-12-31
1	11978	307	1	2004-12-11
2	11978	9731	2	2004-12-11
3	11978	4683	3	2004-12-11
1	11979	2074	1	2004-12-08
2	11979	4952	1	2004-12-08
3	11979	4709	3	2004-12-08
1	11980	6918	2	2004-12-01
1	11981	2891	2	2004-12-16
2	11981	9228	2	2004-12-16
3	11981	7856	3	2004-12-16
1	11982	6433	3	2004-12-27
2	11982	6040	2	2004-12-27
3	11982	1077	3	2004-12-27
1	11983	3906	3	2004-12-24
2	11983	6917	2	2004-12-24
3	11983	178	2	2004-12-24
1	11984	7533	2	2004-12-31
1	11985	6296	3	2004-12-18
2	11985	1186	1	2004-12-18
3	11985	1900	3	2004-12-18
4	11985	9678	3	2004-12-18
1	11986	6783	2	2004-12-11
1	11987	5997	2	2004-12-11
1	11988	6727	3	2004-12-13
2	11988	8609	1	2004-12-13
3	11988	4438	3	2004-12-13
4	11988	6071	1	2004-12-13
5	11988	7484	3	2004-12-13
1	11989	7321	3	2004-12-08
2	11989	2969	2	2004-12-08
1	11990	439	2	2004-12-29
2	11990	2782	2	2004-12-29
3	11990	8709	3	2004-12-29
1	11991	6529	1	2004-12-07
2	11991	1353	1	2004-12-07
3	11991	9087	3	2004-12-07
4	11991	1699	2	2004-12-07
5	11991	4679	2	2004-12-07
6	11991	5953	3	2004-12-07
7	11991	6449	1	2004-12-07
8	11991	7849	3	2004-12-07
1	11992	9724	3	2004-12-21
2	11992	9115	1	2004-12-21
3	11992	6043	3	2004-12-21
4	11992	9321	3	2004-12-21
5	11992	6675	1	2004-12-21
1	11993	4169	1	2004-12-22
2	11993	5854	2	2004-12-22
3	11993	6971	1	2004-12-22
4	11993	102	1	2004-12-22
5	11993	84	2	2004-12-22
6	11993	6196	3	2004-12-22
7	11993	5968	1	2004-12-22
8	11993	5076	2	2004-12-22
1	11994	7304	1	2004-12-26
2	11994	5223	2	2004-12-26
3	11994	8983	1	2004-12-26
4	11994	7637	2	2004-12-26
5	11994	5101	3	2004-12-26
6	11994	4491	3	2004-12-26
7	11994	9351	1	2004-12-26
1	11995	9245	1	2004-12-16
2	11995	1788	2	2004-12-16
3	11995	8892	3	2004-12-16
4	11995	8279	2	2004-12-16
5	11995	2892	2	2004-12-16
1	11996	8421	3	2004-12-28
2	11996	2693	3	2004-12-28
3	11996	1085	1	2004-12-28
4	11996	3464	2	2004-12-28
5	11996	9280	3	2004-12-28
6	11996	5454	3	2004-12-28
1	11997	5828	2	2004-12-26
2	11997	133	3	2004-12-26
3	11997	9635	3	2004-12-26
4	11997	5370	3	2004-12-26
5	11997	2991	3	2004-12-26
6	11997	4478	1	2004-12-26
7	11997	5896	3	2004-12-26
8	11997	7824	2	2004-12-26
9	11997	7629	1	2004-12-26
1	11998	4898	1	2004-12-06
2	11998	3138	1	2004-12-06
3	11998	8755	1	2004-12-06
4	11998	942	2	2004-12-06
5	11998	610	3	2004-12-06
1	11999	9767	3	2004-12-25
2	11999	5449	1	2004-12-25
3	11999	8014	3	2004-12-25
4	11999	4512	2	2004-12-25
5	11999	8368	1	2004-12-25
6	11999	8225	2	2004-12-25
7	11999	2851	3	2004-12-25
1	12000	3821	3	2004-12-15
2	12000	9960	1	2004-12-15
3	12000	9702	1	2004-12-15
4	12000	6281	1	2004-12-15
5	12000	7670	2	2004-12-15
6	12000	1054	1	2004-12-15
7	12000	1717	1	2004-12-15
8	12000	1807	3	2004-12-15
9	12000	3576	3	2004-12-15
\.


--
-- Data for Name: orders; Type: TABLE DATA; Schema: public; Owner: chriskl
--

COPY orders (orderid, orderdate, customerid, netamount, tax, totalamount) FROM stdin;
1	2004-01-27	7888	313.24	25.84	339.08
2	2004-01-01	4858	54.90	4.53	59.43
3	2004-01-17	15399	160.10	13.21	173.31
4	2004-01-28	17019	106.67	8.80	115.47
5	2004-01-09	14771	256.00	21.12	277.12
6	2004-01-11	13734	382.59	31.56	414.15
7	2004-01-05	17622	256.44	21.16	277.60
8	2004-01-18	8331	67.85	5.60	73.45
9	2004-01-06	14902	29.82	2.46	32.28
10	2004-01-18	15112	20.78	1.71	22.49
11	2004-01-31	1082	348.22	28.73	376.95
12	2004-01-19	3608	65.26	5.38	70.64
13	2004-01-17	15146	121.72	10.04	131.76
14	2004-01-28	1540	259.89	21.44	281.33
15	2004-01-03	12662	89.47	7.38	96.85
16	2004-01-14	65	137.98	11.38	149.36
17	2004-01-21	12753	138.85	11.46	150.31
18	2004-01-23	4045	368.37	30.39	398.76
19	2004-01-25	5768	131.86	10.88	142.74
20	2004-01-06	8730	383.46	31.64	415.10
21	2004-01-06	5479	345.84	28.53	374.37
22	2004-01-26	14486	71.29	5.88	77.17
23	2004-01-11	18638	363.40	29.98	393.38
24	2004-01-12	5766	132.56	10.94	143.50
25	2004-01-19	5310	263.50	21.74	285.24
26	2004-01-31	6765	359.03	29.62	388.65
27	2004-01-10	2294	346.22	28.56	374.78
28	2004-01-02	1069	183.09	15.10	198.19
29	2004-01-08	16597	28.04	2.31	30.35
30	2004-01-15	4510	330.71	27.28	357.99
31	2004-01-08	15566	250.39	20.66	271.05
32	2004-01-18	292	152.09	12.55	164.64
33	2004-01-22	6240	258.36	21.31	279.67
34	2004-01-20	12854	207.41	17.11	224.52
35	2004-01-06	12380	280.13	23.11	303.24
36	2004-01-28	3726	62.86	5.19	68.05
37	2004-01-08	18532	220.58	18.20	238.78
38	2004-01-15	3340	318.20	26.25	344.45
39	2004-01-16	970	325.75	26.87	352.62
40	2004-01-18	16259	233.08	19.23	252.31
41	2004-01-23	9258	175.43	14.47	189.90
42	2004-01-29	5152	304.65	25.13	329.78
43	2004-01-21	11927	23.55	1.94	25.49
44	2004-01-16	15905	255.61	21.09	276.70
45	2004-01-20	3525	50.67	4.18	54.85
46	2004-01-29	2018	245.70	20.27	265.97
47	2004-01-14	5864	97.63	8.05	105.68
48	2004-01-24	16067	279.49	23.06	302.55
49	2004-01-28	18911	22.41	1.85	24.26
50	2004-01-07	10453	160.40	13.23	173.63
51	2004-01-07	15185	103.25	8.52	111.77
52	2004-01-17	16427	383.59	31.65	415.24
53	2004-01-29	868	33.77	2.79	36.56
54	2004-01-15	15146	311.01	25.66	336.67
55	2004-01-24	18452	38.57	3.18	41.75
56	2004-01-15	8688	261.62	21.58	283.20
57	2004-01-04	17614	232.98	19.22	252.20
58	2004-01-24	2442	15.31	1.26	16.57
59	2004-01-03	15606	314.38	25.94	340.32
60	2004-01-26	11554	368.63	30.41	399.04
61	2004-01-26	7747	298.92	24.66	323.58
62	2004-01-06	13335	125.20	10.33	135.53
63	2004-01-15	5407	79.89	6.59	86.48
64	2004-01-05	5893	224.41	18.51	242.92
65	2004-01-09	1536	352.01	29.04	381.05
66	2004-01-21	2014	130.29	10.75	141.04
67	2004-01-10	4489	98.43	8.12	106.55
68	2004-01-09	16173	260.20	21.47	281.67
69	2004-01-13	3870	335.20	27.65	362.85
70	2004-01-15	12808	286.84	23.66	310.50
71	2004-01-16	8529	137.41	11.34	148.75
72	2004-01-28	19733	208.51	17.20	225.71
73	2004-01-12	2807	170.63	14.08	184.71
74	2004-01-04	17382	63.73	5.26	68.99
75	2004-01-25	12456	29.46	2.43	31.89
76	2004-01-15	7691	143.30	11.82	155.12
77	2004-01-23	7011	348.82	28.78	377.60
78	2004-01-01	19921	145.50	12.00	157.50
79	2004-01-09	10955	62.09	5.12	67.21
80	2004-01-12	12310	206.96	17.07	224.03
81	2004-01-08	13507	289.60	23.89	313.49
82	2004-01-07	7706	311.14	25.67	336.81
83	2004-01-17	4940	89.86	7.41	97.27
84	2004-01-20	5329	85.90	7.09	92.99
85	2004-01-31	13076	257.81	21.27	279.08
86	2004-01-25	2777	282.12	23.27	305.39
87	2004-01-04	3345	310.36	25.60	335.96
88	2004-01-25	17189	129.08	10.65	139.73
89	2004-01-29	2284	0.02	0.00	0.02
90	2004-01-21	9578	285.28	23.54	308.82
91	2004-01-04	2023	234.00	19.30	253.31
92	2004-01-24	19791	102.60	8.46	111.06
93	2004-01-26	7879	277.00	22.85	299.85
94	2004-01-02	18507	227.24	18.75	245.99
95	2004-01-04	5134	355.34	29.32	384.66
96	2004-01-23	931	387.69	31.98	419.67
97	2004-01-17	4986	258.74	21.35	280.09
98	2004-01-13	9623	33.76	2.79	36.55
99	2004-01-17	7907	395.80	32.65	428.45
100	2004-01-13	11368	22.17	1.83	24.00
101	2004-01-02	10792	131.74	10.87	142.61
102	2004-01-21	14140	373.28	30.80	404.08
103	2004-01-16	8779	104.76	8.64	113.40
104	2004-01-25	17236	245.22	20.23	265.45
105	2004-01-31	10381	245.31	20.24	265.55
106	2004-01-19	7022	194.19	16.02	210.21
107	2004-01-02	16437	142.47	11.75	154.22
108	2004-01-22	10804	249.20	20.56	269.76
109	2004-01-17	18937	317.51	26.19	343.70
110	2004-01-23	10107	200.01	16.50	216.51
111	2004-01-24	1041	71.59	5.91	77.50
112	2004-01-12	12608	120.89	9.97	130.86
113	2004-01-04	13955	303.91	25.07	328.98
114	2004-01-04	16702	185.09	15.27	200.36
115	2004-01-24	5352	130.68	10.78	141.46
116	2004-01-22	3929	59.96	4.95	64.91
117	2004-01-06	17259	380.83	31.42	412.25
118	2004-01-26	18326	231.99	19.14	251.13
119	2004-01-06	16458	343.80	28.36	372.16
120	2004-01-21	16542	40.58	3.35	43.93
121	2004-01-19	3318	390.72	32.23	422.95
122	2004-01-12	19640	18.00	1.49	19.48
123	2004-01-07	6946	184.31	15.21	199.52
124	2004-01-15	2652	372.27	30.71	402.98
125	2004-01-27	19913	363.88	30.02	393.90
126	2004-01-29	16933	132.88	10.96	143.84
127	2004-01-04	5824	229.24	18.91	248.15
128	2004-01-05	12742	198.31	16.36	214.67
129	2004-01-05	17278	159.63	13.17	172.80
130	2004-01-06	5159	179.61	14.82	194.43
131	2004-01-01	351	81.68	6.74	88.42
132	2004-01-27	19182	285.01	23.51	308.52
133	2004-01-04	9124	395.35	32.62	427.97
134	2004-01-14	6511	37.97	3.13	41.10
135	2004-01-28	14524	339.95	28.05	368.00
136	2004-01-06	952	374.12	30.86	404.98
137	2004-01-25	10156	79.85	6.59	86.44
138	2004-01-30	5066	63.21	5.21	68.42
139	2004-01-21	2176	368.20	30.38	398.58
140	2004-01-16	13554	34.43	2.84	37.27
141	2004-01-28	1060	20.75	1.71	22.46
142	2004-01-03	971	220.68	18.21	238.89
143	2004-01-26	10315	201.99	16.66	218.65
144	2004-01-23	13220	135.58	11.19	146.77
145	2004-01-19	123	19.98	1.65	21.63
146	2004-01-29	9986	269.66	22.25	291.91
147	2004-01-16	5657	120.11	9.91	130.02
148	2004-01-17	16216	362.04	29.87	391.91
149	2004-01-19	8933	24.83	2.05	26.88
150	2004-01-24	17457	122.95	10.14	133.09
151	2004-01-30	663	239.52	19.76	259.28
152	2004-01-06	18206	275.81	22.75	298.56
153	2004-01-18	11606	69.30	5.72	75.02
154	2004-01-09	8154	226.65	18.70	245.35
155	2004-01-26	13131	39.01	3.22	42.23
156	2004-01-16	19505	126.78	10.46	137.24
157	2004-01-05	4730	300.02	24.75	324.77
158	2004-01-15	17109	192.95	15.92	208.87
159	2004-01-24	8495	25.18	2.08	27.26
160	2004-01-31	13993	396.44	32.71	429.15
161	2004-01-04	18573	242.35	19.99	262.34
162	2004-01-09	10908	85.24	7.03	92.27
163	2004-01-20	4117	343.88	28.37	372.25
164	2004-01-18	17784	159.10	13.13	172.23
165	2004-01-09	17289	167.52	13.82	181.34
166	2004-01-21	17710	37.64	3.11	40.75
167	2004-01-12	8405	302.28	24.94	327.22
168	2004-01-02	2265	375.65	30.99	406.64
169	2004-01-23	5612	50.18	4.14	54.32
170	2004-01-08	9528	94.43	7.79	102.22
171	2004-01-10	5957	270.31	22.30	292.61
172	2004-01-10	13183	285.64	23.57	309.21
173	2004-01-29	4120	359.56	29.66	389.22
174	2004-01-12	7059	66.71	5.50	72.21
175	2004-01-27	5688	122.23	10.08	132.31
176	2004-01-08	14079	363.11	29.96	393.07
177	2004-01-03	14895	215.29	17.76	233.05
178	2004-01-24	1044	391.27	32.28	423.55
179	2004-01-09	1509	269.12	22.20	291.32
180	2004-01-07	15435	293.03	24.17	317.20
181	2004-01-31	2474	52.50	4.33	56.83
182	2004-01-15	19018	316.19	26.09	342.28
183	2004-01-21	119	108.45	8.95	117.40
184	2004-01-21	12324	311.85	25.73	337.58
185	2004-01-13	7233	11.51	0.95	12.46
186	2004-01-28	16093	158.40	13.07	171.47
187	2004-01-03	2282	325.17	26.83	352.00
188	2004-01-28	5219	345.61	28.51	374.12
189	2004-01-25	8185	3.56	0.29	3.85
190	2004-01-12	1756	145.88	12.04	157.92
191	2004-01-03	7051	290.91	24.00	314.91
192	2004-01-05	14063	375.30	30.96	406.26
193	2004-01-28	1108	290.63	23.98	314.61
194	2004-01-13	13013	112.19	9.26	121.45
195	2004-01-29	19836	211.24	17.43	228.67
196	2004-01-04	9560	184.45	15.22	199.67
197	2004-01-22	11433	267.28	22.05	289.33
198	2004-01-10	13901	369.56	30.49	400.05
199	2004-01-04	4424	27.53	2.27	29.80
200	2004-01-10	13076	3.75	0.31	4.06
201	2004-01-28	1876	67.84	5.60	73.44
202	2004-01-24	2028	90.16	7.44	97.60
203	2004-01-14	7742	307.95	25.41	333.36
204	2004-01-19	16170	353.56	29.17	382.73
205	2004-01-28	15058	187.40	15.46	202.86
206	2004-01-05	9924	304.09	25.09	329.18
207	2004-01-26	6453	90.75	7.49	98.24
208	2004-01-07	6431	254.87	21.03	275.90
209	2004-01-26	19260	296.50	24.46	320.96
210	2004-01-23	7578	62.73	5.18	67.91
211	2004-01-03	15564	397.42	32.79	430.21
212	2004-01-20	2822	395.04	32.59	427.63
213	2004-01-17	12290	23.51	1.94	25.45
214	2004-01-07	8069	331.61	27.36	358.97
215	2004-01-27	15785	195.20	16.10	211.30
216	2004-01-15	8160	255.13	21.05	276.18
217	2004-01-16	4814	388.43	32.05	420.48
218	2004-01-17	11609	40.72	3.36	44.08
219	2004-01-18	8205	399.86	32.99	432.85
220	2004-01-08	11791	309.75	25.55	335.30
221	2004-01-19	18631	10.13	0.84	10.97
222	2004-01-11	13199	265.36	21.89	287.25
223	2004-01-18	12340	322.00	26.57	348.56
224	2004-01-05	78	330.24	27.24	357.48
225	2004-01-23	6196	326.66	26.95	353.61
226	2004-01-08	10432	20.96	1.73	22.69
227	2004-01-08	13953	375.97	31.02	406.99
228	2004-01-21	16074	160.63	13.25	173.88
229	2004-01-27	15328	286.03	23.60	309.63
230	2004-01-29	19989	24.34	2.01	26.35
231	2004-01-18	1271	343.88	28.37	372.25
232	2004-01-24	2634	200.48	16.54	217.02
233	2004-01-04	1686	379.29	31.29	410.58
234	2004-01-25	5751	194.14	16.02	210.16
235	2004-01-23	13707	179.03	14.77	193.80
236	2004-01-20	11518	152.22	12.56	164.78
237	2004-01-18	13392	5.43	0.45	5.88
238	2004-01-16	18916	236.26	19.49	255.75
239	2004-01-27	15234	32.85	2.71	35.56
240	2004-01-31	7989	171.68	14.16	185.84
241	2004-01-24	3340	246.34	20.32	266.66
242	2004-01-17	14552	163.88	13.52	177.40
243	2004-01-26	6958	286.82	23.66	310.48
244	2004-01-07	5311	373.33	30.80	404.13
245	2004-01-07	19485	394.24	32.52	426.76
246	2004-01-10	2884	73.40	6.06	79.46
247	2004-01-14	6463	177.29	14.63	191.92
248	2004-01-06	2718	251.05	20.71	271.76
249	2004-01-29	6782	378.59	31.23	409.82
250	2004-01-15	6957	322.05	26.57	348.62
251	2004-01-22	8116	395.41	32.62	428.03
252	2004-01-26	16809	351.46	29.00	380.46
253	2004-01-13	13398	111.55	9.20	120.75
254	2004-01-05	376	333.69	27.53	361.22
255	2004-01-30	11048	15.90	1.31	17.21
256	2004-01-30	9456	293.28	24.20	317.48
257	2004-01-11	14245	85.77	7.08	92.85
258	2004-01-15	12926	72.85	6.01	78.86
259	2004-01-20	1829	7.69	0.63	8.32
260	2004-01-11	5965	206.34	17.02	223.36
261	2004-01-15	7581	228.64	18.86	247.50
262	2004-01-25	13285	338.66	27.94	366.60
263	2004-01-23	2405	168.58	13.91	182.49
264	2004-01-21	13048	329.95	27.22	357.17
265	2004-01-09	7830	221.16	18.25	239.41
266	2004-01-08	8342	95.38	7.87	103.25
267	2004-01-27	16022	14.30	1.18	15.48
268	2004-01-02	19232	26.67	2.20	28.87
269	2004-01-30	5117	268.88	22.18	291.06
270	2004-01-01	3521	31.86	2.63	34.49
271	2004-01-09	8757	35.22	2.91	38.13
272	2004-01-17	15368	188.09	15.52	203.61
273	2004-01-07	9672	206.09	17.00	223.09
274	2004-01-11	13593	224.08	18.49	242.57
275	2004-01-07	6361	260.83	21.52	282.35
276	2004-01-24	9038	363.74	30.01	393.75
277	2004-01-07	14566	240.93	19.88	260.81
278	2004-01-14	4875	342.46	28.25	370.71
279	2004-01-01	14331	9.04	0.75	9.79
280	2004-01-08	11075	310.84	25.64	336.48
281	2004-01-26	8761	79.56	6.56	86.12
282	2004-01-13	10014	231.56	19.10	250.66
283	2004-01-02	15101	87.26	7.20	94.46
284	2004-01-09	19331	97.00	8.00	105.00
285	2004-01-16	13066	376.11	31.03	407.14
286	2004-01-08	4387	391.82	32.33	424.15
287	2004-01-07	19784	6.49	0.54	7.03
288	2004-01-06	11617	397.86	32.82	430.68
289	2004-01-15	12178	166.28	13.72	180.00
290	2004-01-09	8069	267.63	22.08	289.71
291	2004-01-28	1072	54.24	4.47	58.71
292	2004-01-21	7361	31.38	2.59	33.97
293	2004-01-05	19095	297.03	24.50	321.53
294	2004-01-13	7090	62.67	5.17	67.84
295	2004-01-01	3099	361.87	29.85	391.72
296	2004-01-15	16553	7.12	0.59	7.71
297	2004-01-26	19862	195.64	16.14	211.78
298	2004-01-28	15789	143.12	11.81	154.93
299	2004-01-05	16181	262.60	21.66	284.26
300	2004-01-17	12847	272.72	22.50	295.22
301	2004-01-05	14440	98.24	8.10	106.34
302	2004-01-09	16940	132.42	10.92	143.34
303	2004-01-24	18535	0.91	0.08	0.99
304	2004-01-01	11914	58.92	4.86	63.78
305	2004-01-01	17738	397.26	32.77	430.03
306	2004-01-28	18602	127.73	10.54	138.27
307	2004-01-18	11769	48.24	3.98	52.22
308	2004-01-14	160	343.93	28.37	372.30
309	2004-01-07	18914	46.32	3.82	50.14
310	2004-01-10	15413	151.17	12.47	163.64
311	2004-01-30	5599	76.75	6.33	83.08
312	2004-01-17	12027	162.21	13.38	175.59
313	2004-01-19	7472	55.55	4.58	60.13
314	2004-01-06	7687	378.25	31.21	409.46
315	2004-01-05	14465	281.59	23.23	304.82
316	2004-01-25	5659	142.55	11.76	154.31
317	2004-01-15	13315	266.57	21.99	288.56
318	2004-01-08	14667	280.16	23.11	303.27
319	2004-01-20	13437	141.94	11.71	153.65
320	2004-01-24	4985	129.24	10.66	139.90
321	2004-01-02	19809	237.86	19.62	257.48
322	2004-01-31	18452	297.84	24.57	322.41
323	2004-01-11	15575	271.71	22.42	294.13
324	2004-01-11	13195	187.84	15.50	203.34
325	2004-01-15	13173	152.15	12.55	164.70
326	2004-01-21	19981	144.71	11.94	156.65
327	2004-01-29	3622	317.08	26.16	343.24
328	2004-01-22	7671	296.85	24.49	321.34
329	2004-01-03	13861	290.47	23.96	314.43
330	2004-01-11	19857	183.97	15.18	199.15
331	2004-01-02	17795	101.14	8.34	109.48
332	2004-01-11	5064	338.41	27.92	366.33
333	2004-01-29	160	193.09	15.93	209.02
334	2004-01-28	16649	75.74	6.25	81.99
335	2004-01-29	18217	29.94	2.47	32.41
336	2004-01-30	5606	103.98	8.58	112.56
337	2004-01-03	6967	116.32	9.60	125.92
338	2004-01-03	16697	14.22	1.17	15.39
339	2004-01-27	9626	242.02	19.97	261.99
340	2004-01-09	2904	59.53	4.91	64.44
341	2004-01-08	19587	322.97	26.65	349.62
342	2004-01-10	9688	112.82	9.31	122.13
343	2004-01-07	5526	39.57	3.26	42.83
344	2004-01-10	1349	361.26	29.80	391.06
345	2004-01-11	16417	242.78	20.03	262.81
346	2004-01-10	136	206.56	17.04	223.60
347	2004-01-20	4522	225.56	18.61	244.17
348	2004-01-24	16536	339.09	27.97	367.06
349	2004-01-21	5066	206.60	17.04	223.64
350	2004-01-22	2905	371.61	30.66	402.27
351	2004-01-23	8064	6.29	0.52	6.81
352	2004-01-10	444	93.93	7.75	101.68
353	2004-01-10	1199	297.17	24.52	321.69
354	2004-01-12	13022	286.50	23.64	310.14
355	2004-01-03	11155	63.96	5.28	69.24
356	2004-01-23	2088	260.72	21.51	282.23
357	2004-01-10	5109	266.16	21.96	288.12
358	2004-01-27	13337	217.76	17.97	235.73
359	2004-01-03	10388	237.02	19.55	256.57
360	2004-01-15	6030	254.71	21.01	275.72
361	2004-01-20	3611	324.89	26.80	351.69
362	2004-01-27	4654	67.54	5.57	73.11
363	2004-01-26	19387	298.46	24.62	323.08
364	2004-01-24	12482	28.07	2.32	30.39
365	2004-01-27	6405	315.23	26.01	341.24
366	2004-01-22	250	317.52	26.20	343.72
367	2004-01-04	6817	147.22	12.15	159.37
368	2004-01-15	17740	31.53	2.60	34.13
369	2004-01-20	5131	84.50	6.97	91.47
370	2004-01-17	8987	291.60	24.06	315.66
371	2004-01-02	11905	117.21	9.67	126.88
372	2004-01-14	424	372.36	30.72	403.08
373	2004-01-21	18458	276.55	22.82	299.37
374	2004-01-02	11663	297.77	24.57	322.34
375	2004-01-03	7270	101.19	8.35	109.54
376	2004-01-24	10634	153.13	12.63	165.76
377	2004-01-29	7012	34.41	2.84	37.25
378	2004-01-12	18339	266.14	21.96	288.10
379	2004-01-14	13	227.45	18.76	246.21
380	2004-01-23	1411	6.78	0.56	7.34
381	2004-01-16	3493	154.93	12.78	167.71
382	2004-01-04	15605	218.01	17.99	236.00
383	2004-01-27	10739	223.47	18.44	241.91
384	2004-01-06	18966	352.90	29.11	382.01
385	2004-01-07	4305	327.02	26.98	354.00
386	2004-01-04	4900	10.45	0.86	11.31
387	2004-01-13	2625	354.80	29.27	384.07
388	2004-01-13	4774	281.65	23.24	304.89
389	2004-01-31	18084	194.85	16.08	210.93
390	2004-01-27	17953	14.88	1.23	16.11
391	2004-01-14	10005	112.02	9.24	121.26
392	2004-01-30	18524	374.63	30.91	405.54
393	2004-01-20	5942	180.49	14.89	195.38
394	2004-01-06	4714	295.34	24.37	319.71
395	2004-01-04	12422	146.39	12.08	158.47
396	2004-01-15	683	380.95	31.43	412.38
397	2004-01-10	12185	189.49	15.63	205.12
398	2004-01-22	1644	83.04	6.85	89.89
399	2004-01-16	18249	93.47	7.71	101.18
400	2004-01-18	1381	26.28	2.17	28.45
401	2004-01-29	11980	334.91	27.63	362.54
402	2004-01-09	19006	135.49	11.18	146.67
403	2004-01-29	3507	396.11	32.68	428.79
404	2004-01-19	5596	45.74	3.77	49.51
405	2004-01-30	4556	283.87	23.42	307.29
406	2004-01-27	7784	187.52	15.47	202.99
407	2004-01-18	877	14.68	1.21	15.89
408	2004-01-05	19690	263.12	21.71	284.83
409	2004-01-11	11260	103.92	8.57	112.49
410	2004-01-10	10423	11.24	0.93	12.17
411	2004-01-15	15476	61.58	5.08	66.66
412	2004-01-16	6162	363.79	30.01	393.80
413	2004-01-18	16111	66.38	5.48	71.86
414	2004-01-23	11258	228.38	18.84	247.22
415	2004-01-22	4508	331.01	27.31	358.32
416	2004-01-27	15671	44.58	3.68	48.26
417	2004-01-21	4289	26.57	2.19	28.76
418	2004-01-09	16219	347.11	28.64	375.75
419	2004-01-06	11991	82.86	6.84	89.70
420	2004-01-30	4034	213.34	17.60	230.94
421	2004-01-17	19147	82.76	6.83	89.59
422	2004-01-05	731	7.78	0.64	8.42
423	2004-01-23	18096	93.08	7.68	100.76
424	2004-01-31	12583	118.96	9.81	128.77
425	2004-01-23	18682	370.63	30.58	401.21
426	2004-01-05	9346	245.92	20.29	266.21
427	2004-01-18	16763	187.64	15.48	203.12
428	2004-01-02	16504	71.31	5.88	77.19
429	2004-01-12	326	89.72	7.40	97.12
430	2004-01-17	7080	117.69	9.71	127.40
431	2004-01-23	8776	78.09	6.44	84.53
432	2004-01-12	5072	305.18	25.18	330.36
433	2004-01-14	5332	40.78	3.36	44.14
434	2004-01-14	7090	352.77	29.10	381.87
435	2004-01-07	1896	312.69	25.80	338.49
436	2004-01-27	3288	42.56	3.51	46.07
437	2004-01-01	10941	209.14	17.25	226.39
438	2004-01-11	11390	10.61	0.88	11.49
439	2004-01-11	3841	175.78	14.50	190.28
440	2004-01-23	14889	79.98	6.60	86.58
441	2004-01-15	10861	332.76	27.45	360.21
442	2004-01-11	15076	279.91	23.09	303.00
443	2004-01-17	14423	162.75	13.43	176.18
444	2004-01-24	16402	321.56	26.53	348.09
445	2004-01-03	1985	341.90	28.21	370.11
446	2004-01-31	732	118.10	9.74	127.84
447	2004-01-01	19381	313.55	25.87	339.42
448	2004-01-11	972	277.44	22.89	300.33
449	2004-01-07	9010	18.82	1.55	20.37
450	2004-01-05	10263	224.52	18.52	243.04
451	2004-01-24	7046	147.28	12.15	159.43
452	2004-01-23	5393	375.62	30.99	406.61
453	2004-01-11	11735	326.86	26.97	353.83
454	2004-01-14	14486	104.49	8.62	113.11
455	2004-01-08	13304	183.94	15.18	199.12
456	2004-01-20	18945	195.20	16.10	211.30
457	2004-01-20	7669	100.92	8.33	109.25
458	2004-01-08	12683	62.56	5.16	67.72
459	2004-01-30	11873	4.04	0.33	4.37
460	2004-01-15	7897	338.64	27.94	366.58
461	2004-01-01	2748	140.47	11.59	152.06
462	2004-01-15	5776	2.46	0.20	2.66
463	2004-01-31	517	66.65	5.50	72.15
464	2004-01-06	7660	244.03	20.13	264.16
465	2004-01-07	482	72.75	6.00	78.75
466	2004-01-06	17174	231.87	19.13	251.00
467	2004-01-18	6156	343.00	28.30	371.30
468	2004-01-29	18428	112.69	9.30	121.99
469	2004-01-15	18073	251.54	20.75	272.29
470	2004-01-12	5317	313.65	25.88	339.53
471	2004-01-11	15807	17.88	1.48	19.36
472	2004-01-25	9092	81.55	6.73	88.28
473	2004-01-14	10109	88.03	7.26	95.29
474	2004-01-14	5637	318.90	26.31	345.21
475	2004-01-16	1652	90.25	7.45	97.70
476	2004-01-27	493	8.40	0.69	9.09
477	2004-01-25	11564	341.82	28.20	370.02
478	2004-01-11	14697	202.85	16.74	219.59
479	2004-01-26	11691	153.64	12.68	166.32
480	2004-01-12	14405	385.01	31.76	416.77
481	2004-01-30	16500	341.62	28.18	369.80
482	2004-01-03	10265	77.83	6.42	84.25
483	2004-01-02	7500	391.59	32.31	423.90
484	2004-01-20	10431	360.94	29.78	390.72
485	2004-01-27	9022	127.54	10.52	138.06
486	2004-01-05	16929	68.88	5.68	74.56
487	2004-01-01	4473	122.74	10.13	132.87
488	2004-01-05	8026	320.02	26.40	346.42
489	2004-01-23	12829	277.59	22.90	300.49
490	2004-01-31	16522	71.23	5.88	77.11
491	2004-01-04	3465	20.18	1.66	21.84
492	2004-01-20	11856	209.83	17.31	227.14
493	2004-01-14	12183	22.00	1.82	23.82
494	2004-01-24	2788	340.82	28.12	368.94
495	2004-01-28	4056	5.41	0.45	5.86
496	2004-01-13	5784	178.49	14.73	193.22
497	2004-01-26	2107	171.17	14.12	185.29
498	2004-01-30	15268	32.55	2.69	35.24
499	2004-01-24	5011	108.74	8.97	117.71
500	2004-01-14	906	185.41	15.30	200.71
501	2004-01-26	8735	253.98	20.95	274.93
502	2004-01-30	19136	170.96	14.10	185.06
503	2004-01-08	1350	238.42	19.67	258.09
504	2004-01-24	11774	1.72	0.14	1.86
505	2004-01-13	18281	176.38	14.55	190.93
506	2004-01-23	19795	8.79	0.73	9.52
507	2004-01-05	19308	319.43	26.35	345.78
508	2004-01-28	6470	388.90	32.08	420.98
509	2004-01-29	8328	351.15	28.97	380.12
510	2004-01-08	17630	220.76	18.21	238.97
511	2004-01-31	3490	166.08	13.70	179.78
512	2004-01-22	8031	327.73	27.04	354.77
513	2004-01-01	2569	0.59	0.05	0.64
514	2004-01-21	6177	345.34	28.49	373.83
515	2004-01-01	2323	395.80	32.65	428.45
516	2004-01-20	3187	206.07	17.00	223.07
517	2004-01-19	17446	88.61	7.31	95.92
518	2004-01-06	19783	70.43	5.81	76.24
519	2004-01-23	4511	389.42	32.13	421.55
520	2004-01-01	223	52.32	4.32	56.64
521	2004-01-11	19599	360.22	29.72	389.94
522	2004-01-16	5896	342.51	28.26	370.77
523	2004-01-05	6187	46.65	3.85	50.50
524	2004-01-12	10448	382.52	31.56	414.08
525	2004-01-14	11048	266.56	21.99	288.55
526	2004-01-04	5494	355.88	29.36	385.24
527	2004-01-26	15328	32.64	2.69	35.33
528	2004-01-16	6246	114.56	9.45	124.01
529	2004-01-17	6953	380.82	31.42	412.24
530	2004-01-05	5091	141.17	11.65	152.82
531	2004-01-27	2509	343.52	28.34	371.86
532	2004-01-01	14574	274.01	22.61	296.62
533	2004-01-30	6284	10.72	0.88	11.60
534	2004-01-14	2821	217.19	17.92	235.11
535	2004-01-21	959	105.48	8.70	114.18
536	2004-01-06	15725	321.47	26.52	347.99
537	2004-01-18	2034	221.88	18.31	240.19
538	2004-01-31	14721	36.80	3.04	39.84
539	2004-01-25	8105	25.01	2.06	27.07
540	2004-01-27	18858	337.05	27.81	364.86
541	2004-01-11	13774	26.93	2.22	29.15
542	2004-01-18	595	123.63	10.20	133.83
543	2004-01-15	12847	268.98	22.19	291.17
544	2004-01-09	17962	56.86	4.69	61.55
545	2004-01-09	6358	85.20	7.03	92.23
546	2004-01-23	19138	283.61	23.40	307.01
547	2004-01-05	12268	267.32	22.05	289.37
548	2004-01-22	16984	399.07	32.92	431.99
549	2004-01-03	12346	214.35	17.68	232.03
550	2004-01-15	8890	375.03	30.94	405.97
551	2004-01-30	8467	191.36	15.79	207.15
552	2004-01-29	8682	131.17	10.82	141.99
553	2004-01-25	13151	10.08	0.83	10.91
554	2004-01-30	8051	156.39	12.90	169.29
555	2004-01-08	5717	154.52	12.75	167.27
556	2004-01-06	3122	298.35	24.61	322.96
557	2004-01-31	2815	47.14	3.89	51.03
558	2004-01-11	17689	228.70	18.87	247.57
559	2004-01-24	15201	278.67	22.99	301.66
560	2004-01-06	12514	196.64	16.22	212.86
561	2004-01-03	3811	377.56	31.15	408.71
562	2004-01-07	6991	78.45	6.47	84.92
563	2004-01-01	4075	44.69	3.69	48.38
564	2004-01-22	10212	296.30	24.44	320.74
565	2004-01-15	231	202.86	16.74	219.60
566	2004-01-30	9089	251.43	20.74	272.17
567	2004-01-22	2956	193.54	15.97	209.51
568	2004-01-13	12773	99.17	8.18	107.35
569	2004-01-20	16189	283.39	23.38	306.77
570	2004-01-26	905	391.66	32.31	423.97
571	2004-01-16	6543	131.57	10.85	142.42
572	2004-01-16	6973	346.04	28.55	374.59
573	2004-01-15	600	364.93	30.11	395.04
574	2004-01-05	637	178.65	14.74	193.39
575	2004-01-25	17302	34.20	2.82	37.02
576	2004-01-16	3388	79.05	6.52	85.57
577	2004-01-21	9064	122.90	10.14	133.04
578	2004-01-21	18703	150.15	12.39	162.54
579	2004-01-27	13892	312.40	25.77	338.17
580	2004-01-05	14013	297.48	24.54	322.02
581	2004-01-28	4925	176.72	14.58	191.30
582	2004-01-02	18763	284.99	23.51	308.50
583	2004-01-16	13168	229.69	18.95	248.64
584	2004-01-18	15830	382.92	31.59	414.51
585	2004-01-21	1807	91.97	7.59	99.56
586	2004-01-01	7090	212.87	17.56	230.43
587	2004-01-15	7036	90.30	7.45	97.75
588	2004-01-20	16394	90.98	7.51	98.49
589	2004-01-04	32	194.63	16.06	210.69
590	2004-01-19	5168	303.69	25.05	328.74
591	2004-01-16	10807	338.66	27.94	366.60
592	2004-01-23	4033	84.42	6.96	91.38
593	2004-01-02	10865	186.44	15.38	201.82
594	2004-01-18	5938	114.45	9.44	123.89
595	2004-01-19	7848	19.10	1.58	20.68
596	2004-01-11	11823	398.59	32.88	431.47
597	2004-01-01	8395	6.10	0.50	6.60
598	2004-01-21	4695	283.76	23.41	307.17
599	2004-01-29	15373	399.63	32.97	432.60
600	2004-01-31	4634	381.05	31.44	412.49
601	2004-01-11	5396	20.52	1.69	22.21
602	2004-01-31	12853	180.57	14.90	195.47
603	2004-01-17	15275	11.90	0.98	12.88
604	2004-01-08	17239	310.87	25.65	336.52
605	2004-01-24	10467	296.68	24.48	321.16
606	2004-01-08	8833	221.36	18.26	239.62
607	2004-01-20	19890	189.17	15.61	204.78
608	2004-01-09	5708	72.09	5.95	78.04
609	2004-01-15	7361	312.80	25.81	338.61
610	2004-01-27	5828	103.10	8.51	111.61
611	2004-01-30	2507	180.55	14.90	195.45
612	2004-01-01	14267	7.16	0.59	7.75
613	2004-01-19	15847	225.99	18.64	244.63
614	2004-01-01	862	172.93	14.27	187.20
615	2004-01-30	18741	42.23	3.48	45.71
616	2004-01-28	14586	181.20	14.95	196.15
617	2004-01-04	14273	174.75	14.42	189.17
618	2004-01-12	18868	281.98	23.26	305.24
619	2004-01-21	11201	312.66	25.79	338.45
620	2004-01-28	9329	346.56	28.59	375.15
621	2004-01-23	9796	15.41	1.27	16.68
622	2004-01-15	1766	180.49	14.89	195.38
623	2004-01-03	16876	86.65	7.15	93.80
624	2004-01-19	4894	144.26	11.90	156.16
625	2004-01-12	17368	250.80	20.69	271.49
626	2004-01-17	6866	236.18	19.48	255.66
627	2004-01-08	9766	345.45	28.50	373.95
628	2004-01-05	1859	133.94	11.05	144.99
629	2004-01-27	3064	348.85	28.78	377.63
630	2004-01-30	11607	108.44	8.95	117.39
631	2004-01-29	17012	289.05	23.85	312.90
632	2004-01-24	18124	40.09	3.31	43.40
633	2004-01-11	11351	267.29	22.05	289.34
634	2004-01-29	7290	244.62	20.18	264.80
635	2004-01-06	7973	290.16	23.94	314.10
636	2004-01-17	19648	349.67	28.85	378.52
637	2004-01-16	3790	390.91	32.25	423.16
638	2004-01-11	18697	118.95	9.81	128.76
639	2004-01-13	4897	365.51	30.15	395.66
640	2004-01-10	5823	44.20	3.65	47.85
641	2004-01-27	8267	293.87	24.24	318.11
642	2004-01-01	13655	148.12	12.22	160.34
643	2004-01-24	6154	54.99	4.54	59.53
644	2004-01-28	15021	235.54	19.43	254.97
645	2004-01-21	5685	258.64	21.34	279.98
646	2004-01-31	6356	222.29	18.34	240.63
647	2004-01-05	14924	354.54	29.25	383.79
648	2004-01-14	976	23.37	1.93	25.30
649	2004-01-24	4616	144.87	11.95	156.82
650	2004-01-13	19442	196.40	16.20	212.60
651	2004-01-27	14763	295.16	24.35	319.51
652	2004-01-24	18327	365.67	30.17	395.84
653	2004-01-04	6685	340.18	28.06	368.24
654	2004-01-02	15212	45.10	3.72	48.82
655	2004-01-05	1524	21.28	1.76	23.04
656	2004-01-16	11433	125.09	10.32	135.41
657	2004-01-28	843	382.64	31.57	414.21
658	2004-01-21	6576	46.59	3.84	50.43
659	2004-01-03	2483	107.52	8.87	116.39
660	2004-01-26	2206	21.44	1.77	23.21
661	2004-01-16	8188	213.54	17.62	231.16
662	2004-01-12	18320	123.70	10.21	133.91
663	2004-01-15	16136	173.03	14.27	187.30
664	2004-01-14	4400	371.30	30.63	401.93
665	2004-01-11	13717	268.05	22.11	290.16
666	2004-01-28	17958	312.54	25.78	338.32
667	2004-01-04	11882	340.94	28.13	369.07
668	2004-01-29	902	197.75	16.31	214.06
669	2004-01-11	19974	68.20	5.63	73.83
670	2004-01-02	5619	173.63	14.32	187.95
671	2004-01-11	18508	107.81	8.89	116.70
672	2004-01-16	5997	128.97	10.64	139.61
673	2004-01-01	16545	81.98	6.76	88.74
674	2004-01-18	19580	232.93	19.22	252.15
675	2004-01-13	3445	380.69	31.41	412.10
676	2004-01-02	11451	26.97	2.23	29.20
677	2004-01-27	5909	137.07	11.31	148.38
678	2004-01-09	9173	150.62	12.43	163.05
679	2004-01-11	6125	307.84	25.40	333.24
680	2004-01-25	4484	374.64	30.91	405.55
681	2004-01-11	15007	112.51	9.28	121.79
682	2004-01-08	6458	135.43	11.17	146.60
683	2004-01-03	4598	235.31	19.41	254.72
684	2004-01-26	2983	307.75	25.39	333.14
685	2004-01-20	12035	309.53	25.54	335.07
686	2004-01-08	7671	133.86	11.04	144.90
687	2004-01-28	18110	361.37	29.81	391.18
688	2004-01-09	19062	137.22	11.32	148.54
689	2004-01-05	18862	223.62	18.45	242.07
690	2004-01-01	12116	100.73	8.31	109.04
691	2004-01-07	2952	245.59	20.26	265.85
692	2004-01-20	5631	306.27	25.27	331.54
693	2004-01-19	6029	45.10	3.72	48.82
694	2004-01-03	17133	119.64	9.87	129.51
695	2004-01-23	6654	130.20	10.74	140.94
696	2004-01-22	2800	59.52	4.91	64.43
697	2004-01-14	592	365.75	30.17	395.92
698	2004-01-07	18778	175.30	14.46	189.76
699	2004-01-07	18821	269.00	22.19	291.19
700	2004-01-10	7025	310.14	25.59	335.73
701	2004-01-08	8653	238.32	19.66	257.98
702	2004-01-22	8821	223.83	18.47	242.30
703	2004-01-20	7911	286.10	23.60	309.70
704	2004-01-02	17579	96.51	7.96	104.47
705	2004-01-26	7612	115.16	9.50	124.66
706	2004-01-24	3498	102.34	8.44	110.78
707	2004-01-26	8671	176.72	14.58	191.30
708	2004-01-13	13084	184.24	15.20	199.44
709	2004-01-01	1595	392.67	32.40	425.07
710	2004-01-19	12380	204.84	16.90	221.74
711	2004-01-09	18033	44.58	3.68	48.26
712	2004-01-26	11227	236.87	19.54	256.41
713	2004-01-05	14492	393.25	32.44	425.69
714	2004-01-16	14457	208.78	17.22	226.00
715	2004-01-12	8402	209.59	17.29	226.88
716	2004-01-10	12347	395.78	32.65	428.43
717	2004-01-20	11045	105.86	8.73	114.59
718	2004-01-12	18322	88.90	7.33	96.23
719	2004-01-10	17977	367.73	30.34	398.07
720	2004-01-28	4740	315.81	26.05	341.86
721	2004-01-30	6117	215.56	17.78	233.34
722	2004-01-08	13583	154.55	12.75	167.30
723	2004-01-26	9761	225.93	18.64	244.57
724	2004-01-30	5091	181.88	15.01	196.89
725	2004-01-21	12433	160.73	13.26	173.99
726	2004-01-06	3511	339.97	28.05	368.02
727	2004-01-23	15910	301.30	24.86	326.16
728	2004-01-24	230	345.44	28.50	373.94
729	2004-01-17	8851	138.77	11.45	150.22
730	2004-01-08	11470	298.71	24.64	323.35
731	2004-01-12	4539	351.46	29.00	380.46
732	2004-01-16	19465	295.02	24.34	319.36
733	2004-01-11	13452	360.07	29.71	389.78
734	2004-01-30	922	91.10	7.52	98.62
735	2004-01-07	2442	133.77	11.04	144.81
736	2004-01-23	6545	272.23	22.46	294.69
737	2004-01-24	7564	140.11	11.56	151.67
738	2004-01-04	19873	350.07	28.88	378.95
739	2004-01-12	16794	287.44	23.71	311.15
740	2004-01-19	18371	271.73	22.42	294.15
741	2004-01-11	13680	125.55	10.36	135.91
742	2004-01-27	4819	299.43	24.70	324.13
743	2004-01-01	7237	92.22	7.61	99.83
744	2004-01-06	15213	53.45	4.41	57.86
745	2004-01-16	17732	66.95	5.52	72.47
746	2004-01-17	15616	285.44	23.55	308.99
747	2004-01-30	18674	318.35	26.26	344.61
748	2004-01-01	18212	105.15	8.67	113.82
749	2004-01-28	10835	45.79	3.78	49.57
750	2004-01-10	16026	28.64	2.36	31.00
751	2004-01-26	9214	74.40	6.14	80.54
752	2004-01-11	6145	92.73	7.65	100.38
753	2004-01-09	14936	144.30	11.90	156.20
754	2004-01-22	13111	72.43	5.98	78.41
755	2004-01-24	1823	116.85	9.64	126.49
756	2004-01-21	17905	210.18	17.34	227.52
757	2004-01-17	19306	106.21	8.76	114.97
758	2004-01-08	7445	253.36	20.90	274.26
759	2004-01-15	5257	155.09	12.79	167.88
760	2004-01-24	19423	112.59	9.29	121.88
761	2004-01-20	1782	238.00	19.64	257.63
762	2004-01-02	12255	329.70	27.20	356.90
763	2004-01-31	12852	238.22	19.65	257.87
764	2004-01-27	18207	235.04	19.39	254.43
765	2004-01-16	16711	359.56	29.66	389.22
766	2004-01-14	14868	338.14	27.90	366.04
767	2004-01-06	6848	62.54	5.16	67.70
768	2004-01-03	7413	248.97	20.54	269.51
769	2004-01-31	14431	327.27	27.00	354.27
770	2004-01-01	14844	54.33	4.48	58.81
771	2004-01-15	7703	98.18	8.10	106.28
772	2004-01-02	4397	67.57	5.57	73.14
773	2004-01-08	958	205.60	16.96	222.56
774	2004-01-17	11614	61.42	5.07	66.49
775	2004-01-28	10593	176.60	14.57	191.17
776	2004-01-10	10938	139.97	11.55	151.52
777	2004-01-30	9896	368.86	30.43	399.29
778	2004-01-14	14573	225.99	18.64	244.63
779	2004-01-31	19902	63.12	5.21	68.33
780	2004-01-03	1339	384.20	31.70	415.90
781	2004-01-03	760	189.41	15.63	205.04
782	2004-01-25	13726	223.50	18.44	241.94
783	2004-01-29	18670	316.78	26.13	342.91
784	2004-01-30	19765	1.09	0.09	1.18
785	2004-01-05	4245	370.55	30.57	401.12
786	2004-01-07	12573	381.44	31.47	412.91
787	2004-01-07	11065	373.44	30.81	404.25
788	2004-01-13	16307	228.07	18.82	246.89
789	2004-01-03	16951	156.61	12.92	169.53
790	2004-01-26	14099	77.55	6.40	83.95
791	2004-01-04	12902	217.98	17.98	235.96
792	2004-01-31	16223	276.49	22.81	299.30
793	2004-01-29	5320	227.44	18.76	246.20
794	2004-01-23	1884	137.44	11.34	148.78
795	2004-01-16	1368	100.20	8.27	108.47
796	2004-01-17	11868	190.31	15.70	206.01
797	2004-01-13	16157	99.27	8.19	107.46
798	2004-01-15	19970	215.90	17.81	233.71
799	2004-01-28	10611	382.40	31.55	413.95
800	2004-01-30	6506	12.32	1.02	13.34
801	2004-01-27	4629	179.16	14.78	193.94
802	2004-01-04	6122	329.97	27.22	357.19
803	2004-01-02	9895	307.71	25.39	333.10
804	2004-01-25	1022	365.24	30.13	395.37
805	2004-01-12	7125	202.99	16.75	219.74
806	2004-01-29	9827	338.52	27.93	366.45
807	2004-01-18	17336	177.76	14.67	192.43
808	2004-01-02	5242	226.47	18.68	245.15
809	2004-01-29	12626	346.03	28.55	374.58
810	2004-01-16	10098	391.90	32.33	424.23
811	2004-01-28	454	173.77	14.34	188.11
812	2004-01-22	14384	243.49	20.09	263.58
813	2004-01-05	17652	156.49	12.91	169.40
814	2004-01-12	6688	318.77	26.30	345.07
815	2004-01-31	3903	316.62	26.12	342.74
816	2004-01-25	6799	242.09	19.97	262.06
817	2004-01-11	6557	344.24	28.40	372.64
818	2004-01-26	6380	31.58	2.61	34.19
819	2004-01-03	9411	104.89	8.65	113.54
820	2004-01-17	2086	141.51	11.67	153.18
821	2004-01-30	11581	203.62	16.80	220.42
822	2004-01-03	6453	241.64	19.94	261.58
823	2004-01-31	13141	21.10	1.74	22.84
824	2004-01-18	18516	193.01	15.92	208.93
825	2004-01-21	15181	54.99	4.54	59.53
826	2004-01-23	7529	86.53	7.14	93.67
827	2004-01-03	13046	330.11	27.23	357.34
828	2004-01-16	12168	347.45	28.66	376.11
829	2004-01-17	10708	139.78	11.53	151.31
830	2004-01-07	12681	54.62	4.51	59.13
831	2004-01-31	14409	62.18	5.13	67.31
832	2004-01-29	3369	237.88	19.63	257.51
833	2004-01-10	5509	360.65	29.75	390.40
834	2004-01-25	13502	221.91	18.31	240.22
835	2004-01-04	420	258.10	21.29	279.39
836	2004-01-12	3565	190.01	15.68	205.69
837	2004-01-20	6595	339.06	27.97	367.03
838	2004-01-26	14561	198.03	16.34	214.37
839	2004-01-24	10929	377.42	31.14	408.56
840	2004-01-15	15826	351.84	29.03	380.87
841	2004-01-03	8558	388.67	32.07	420.74
842	2004-01-17	9618	277.45	22.89	300.34
843	2004-01-05	13281	396.23	32.69	428.92
844	2004-01-20	12404	122.04	10.07	132.11
845	2004-01-16	7161	47.60	3.93	51.53
846	2004-01-04	4133	376.11	31.03	407.14
847	2004-01-22	6312	112.82	9.31	122.13
848	2004-01-19	11371	143.71	11.86	155.57
849	2004-01-23	7459	236.99	19.55	256.54
850	2004-01-27	6769	273.40	22.56	295.96
851	2004-01-10	9596	178.23	14.70	192.93
852	2004-01-13	10530	83.20	6.86	90.06
853	2004-01-15	7709	278.19	22.95	301.14
854	2004-01-04	19097	23.79	1.96	25.75
855	2004-01-25	13820	22.80	1.88	24.68
856	2004-01-10	5429	262.14	21.63	283.77
857	2004-01-17	11971	35.67	2.94	38.61
858	2004-01-31	12104	208.98	17.24	226.22
859	2004-01-08	3013	343.69	28.35	372.04
860	2004-01-27	9558	12.83	1.06	13.89
861	2004-01-26	11776	99.80	8.23	108.03
862	2004-01-10	2144	364.92	30.11	395.03
863	2004-01-31	10460	117.92	9.73	127.65
864	2004-01-18	9138	262.74	21.68	284.42
865	2004-01-05	280	267.31	22.05	289.36
866	2004-01-25	495	74.88	6.18	81.06
867	2004-01-09	11615	358.43	29.57	388.00
868	2004-01-07	6980	180.79	14.92	195.71
869	2004-01-17	9030	237.39	19.58	256.97
870	2004-01-13	3029	9.34	0.77	10.11
871	2004-01-08	7227	88.94	7.34	96.28
872	2004-01-02	15126	102.08	8.42	110.50
873	2004-01-27	17175	132.98	10.97	143.95
874	2004-01-08	19077	325.54	26.86	352.40
875	2004-01-25	1018	235.05	19.39	254.44
876	2004-01-21	12792	286.38	23.63	310.01
877	2004-01-01	9819	120.85	9.97	130.82
878	2004-01-29	2837	139.05	11.47	150.52
879	2004-01-19	10034	0.36	0.03	0.39
880	2004-01-27	9588	332.99	27.47	360.46
881	2004-01-28	3934	175.66	14.49	190.15
882	2004-01-05	11526	283.11	23.36	306.47
883	2004-01-27	11874	27.08	2.23	29.31
884	2004-01-13	12785	258.51	21.33	279.84
885	2004-01-10	8648	170.16	14.04	184.20
886	2004-01-02	543	179.17	14.78	193.95
887	2004-01-07	14253	291.25	24.03	315.28
888	2004-01-07	19198	130.17	10.74	140.91
889	2004-01-04	8533	161.19	13.30	174.49
890	2004-01-08	9314	172.35	14.22	186.57
891	2004-01-07	19345	142.07	11.72	153.79
892	2004-01-24	9349	202.51	16.71	219.22
893	2004-01-21	17044	269.04	22.20	291.24
894	2004-01-19	9197	283.39	23.38	306.77
895	2004-01-01	19149	124.77	10.29	135.06
896	2004-01-04	6933	307.75	25.39	333.14
897	2004-01-09	6892	80.97	6.68	87.65
898	2004-01-18	15740	348.18	28.72	376.90
899	2004-01-07	2497	139.58	11.52	151.10
900	2004-01-18	11783	315.28	26.01	341.29
901	2004-01-18	18158	313.52	25.87	339.39
902	2004-01-23	15100	114.63	9.46	124.09
903	2004-01-16	2529	352.38	29.07	381.45
904	2004-01-26	2673	52.33	4.32	56.65
905	2004-01-19	18518	208.02	17.16	225.18
906	2004-01-08	15190	281.86	23.25	305.11
907	2004-01-06	1695	93.37	7.70	101.07
908	2004-01-14	12965	297.91	24.58	322.49
909	2004-01-18	17492	31.33	2.58	33.91
910	2004-01-23	4601	70.44	5.81	76.25
911	2004-01-19	17230	38.07	3.14	41.21
912	2004-01-03	5001	18.15	1.50	19.65
913	2004-01-08	6984	15.08	1.24	16.32
914	2004-01-14	15117	306.38	25.28	331.66
915	2004-01-27	8744	250.74	20.69	271.43
916	2004-01-15	2418	377.16	31.12	408.28
917	2004-01-15	13644	145.11	11.97	157.08
918	2004-01-23	8197	142.01	11.72	153.73
919	2004-01-31	16595	23.07	1.90	24.97
920	2004-01-15	18335	112.74	9.30	122.04
921	2004-01-22	8477	250.47	20.66	271.13
922	2004-01-11	13605	79.02	6.52	85.54
923	2004-01-08	1447	210.12	17.33	227.45
924	2004-01-18	12693	252.68	20.85	273.53
925	2004-01-28	4802	54.86	4.53	59.39
926	2004-01-09	17519	209.01	17.24	226.25
927	2004-01-02	16362	26.61	2.20	28.81
928	2004-01-02	5348	234.68	19.36	254.04
929	2004-01-10	10664	388.80	32.08	420.88
930	2004-01-24	10086	179.88	14.84	194.72
931	2004-01-11	10176	19.27	1.59	20.86
932	2004-01-17	12103	84.28	6.95	91.23
933	2004-01-15	18289	118.34	9.76	128.10
934	2004-01-16	1351	8.86	0.73	9.59
935	2004-01-20	9018	20.33	1.68	22.01
936	2004-01-21	18743	277.25	22.87	300.12
937	2004-01-23	3636	291.14	24.02	315.16
938	2004-01-11	46	135.17	11.15	146.32
939	2004-01-05	14368	253.08	20.88	273.96
940	2004-01-04	11869	363.15	29.96	393.11
941	2004-01-27	17094	384.23	31.70	415.93
942	2004-01-05	6681	182.14	15.03	197.17
943	2004-01-18	3941	60.94	5.03	65.97
944	2004-01-16	17491	295.83	24.41	320.24
945	2004-01-01	11138	48.50	4.00	52.50
946	2004-01-18	2984	197.10	16.26	213.36
947	2004-01-09	484	146.18	12.06	158.24
948	2004-01-23	6065	285.32	23.54	308.86
949	2004-01-10	8291	220.47	18.19	238.66
950	2004-01-13	17138	301.45	24.87	326.32
951	2004-01-25	13427	95.56	7.88	103.44
952	2004-01-19	7063	56.78	4.68	61.46
953	2004-01-12	17575	56.98	4.70	61.68
954	2004-01-11	16334	389.79	32.16	421.95
955	2004-01-02	12296	47.74	3.94	51.68
956	2004-01-04	17667	48.94	4.04	52.98
957	2004-01-31	11476	283.09	23.35	306.44
958	2004-01-25	18447	304.63	25.13	329.76
959	2004-01-28	688	100.72	8.31	109.03
960	2004-01-08	16386	76.34	6.30	82.64
961	2004-01-23	2202	336.19	27.74	363.93
962	2004-01-07	14898	335.22	27.66	362.88
963	2004-01-05	14264	295.46	24.38	319.84
964	2004-01-14	13106	259.08	21.37	280.45
965	2004-01-04	4709	25.46	2.10	27.56
966	2004-01-19	1449	237.28	19.58	256.86
967	2004-01-01	2753	65.43	5.40	70.83
968	2004-01-30	17002	293.33	24.20	317.53
969	2004-01-05	18911	57.96	4.78	62.74
970	2004-01-08	12225	361.00	29.78	390.78
971	2004-01-10	8731	371.25	30.63	401.88
972	2004-01-23	19988	161.23	13.30	174.53
973	2004-01-18	5330	211.89	17.48	229.37
974	2004-01-14	8078	126.92	10.47	137.39
975	2004-01-11	1316	303.04	25.00	328.04
976	2004-01-09	15760	290.62	23.98	314.60
977	2004-01-22	19594	142.07	11.72	153.79
978	2004-01-13	13666	167.47	13.82	181.29
979	2004-01-30	492	45.61	3.76	49.37
980	2004-01-31	19847	182.68	15.07	197.75
981	2004-01-28	16076	283.11	23.36	306.47
982	2004-01-30	14791	191.95	15.84	207.79
983	2004-01-28	8347	322.18	26.58	348.76
984	2004-01-28	14770	192.53	15.88	208.41
985	2004-01-22	19874	378.13	31.20	409.33
986	2004-01-31	2980	96.09	7.93	104.02
987	2004-01-18	7429	228.35	18.84	247.19
988	2004-01-17	12352	292.81	24.16	316.97
989	2004-01-31	18105	389.90	32.17	422.07
990	2004-01-31	9629	25.15	2.07	27.22
991	2004-01-07	9937	309.27	25.51	334.78
992	2004-01-24	12582	387.47	31.97	419.44
993	2004-01-29	3390	122.02	10.07	132.09
994	2004-01-28	5070	78.60	6.48	85.08
995	2004-01-26	10462	251.95	20.79	272.74
996	2004-01-07	6257	105.35	8.69	114.04
997	2004-01-09	279	322.51	26.61	349.12
998	2004-01-17	4728	186.57	15.39	201.96
999	2004-01-24	2218	323.67	26.70	350.37
1000	2004-01-03	18482	336.19	27.74	363.93
1001	2004-02-07	19356	170.63	14.08	184.71
1002	2004-02-15	9043	158.21	13.05	171.26
1003	2004-02-28	403	9.05	0.75	9.80
1004	2004-02-17	16509	302.72	24.97	327.69
1005	2004-02-23	10292	326.14	26.91	353.05
1006	2004-02-13	8489	212.16	17.50	229.66
1007	2004-02-12	7186	223.87	18.47	242.34
1008	2004-02-27	17328	119.07	9.82	128.89
1009	2004-02-21	8149	328.60	27.11	355.71
1010	2004-02-06	4458	63.29	5.22	68.51
1011	2004-02-09	9649	219.60	18.12	237.72
1012	2004-02-05	13660	194.45	16.04	210.49
1013	2004-02-05	19359	218.76	18.05	236.81
1014	2004-02-23	11339	90.55	7.47	98.02
1015	2004-02-28	12519	387.81	31.99	419.80
1016	2004-02-13	3433	101.41	8.37	109.78
1017	2004-02-27	1918	277.45	22.89	300.34
1018	2004-02-12	13443	220.16	18.16	238.32
1019	2004-02-20	1083	133.72	11.03	144.75
1020	2004-02-12	3904	92.94	7.67	100.61
1021	2004-02-26	12389	96.93	8.00	104.93
1022	2004-02-12	16953	127.22	10.50	137.72
1023	2004-02-20	9231	364.01	30.03	394.04
1024	2004-02-25	10243	25.38	2.09	27.47
1025	2004-02-11	14487	377.90	31.18	409.08
1026	2004-02-24	15410	219.18	18.08	237.26
1027	2004-02-04	6997	45.61	3.76	49.37
1028	2004-02-16	8489	248.89	20.53	269.42
1029	2004-02-22	9608	398.66	32.89	431.55
1030	2004-02-19	19986	366.99	30.28	397.27
1031	2004-02-13	16366	187.36	15.46	202.82
1032	2004-02-28	18380	90.55	7.47	98.02
1033	2004-02-16	18161	97.90	8.08	105.98
1034	2004-02-06	11841	345.20	28.48	373.68
1035	2004-02-17	14282	258.70	21.34	280.04
1036	2004-02-06	16738	390.63	32.23	422.86
1037	2004-02-18	14214	234.32	19.33	253.65
1038	2004-02-17	14256	376.44	31.06	407.50
1039	2004-02-26	4296	318.21	26.25	344.46
1040	2004-02-17	11696	311.47	25.70	337.17
1041	2004-02-08	10604	367.12	30.29	397.41
1042	2004-02-09	15751	167.28	13.80	181.08
1043	2004-02-08	9973	324.62	26.78	351.40
1044	2004-02-08	1648	359.01	29.62	388.63
1045	2004-02-19	19654	22.15	1.83	23.98
1046	2004-02-26	4062	135.33	11.16	146.49
1047	2004-02-26	12070	180.87	14.92	195.79
1048	2004-02-24	5442	383.83	31.67	415.50
1049	2004-02-28	8744	390.66	32.23	422.89
1050	2004-02-24	13232	20.62	1.70	22.32
1051	2004-02-10	18115	32.71	2.70	35.41
1052	2004-02-27	5570	353.68	29.18	382.86
1053	2004-02-18	7490	327.85	27.05	354.90
1054	2004-02-20	18294	320.43	26.44	346.87
1055	2004-02-05	7157	237.14	19.56	256.70
1056	2004-02-01	19751	359.89	29.69	389.58
1057	2004-02-25	10522	264.79	21.85	286.64
1058	2004-02-17	6089	18.73	1.55	20.28
1059	2004-02-13	19142	353.14	29.13	382.27
1060	2004-02-01	6017	220.80	18.22	239.02
1061	2004-02-18	7192	132.75	10.95	143.70
1062	2004-02-07	12535	222.59	18.36	240.95
1063	2004-02-03	17422	34.20	2.82	37.02
1064	2004-02-09	6176	30.16	2.49	32.65
1065	2004-02-16	5367	277.21	22.87	300.08
1066	2004-02-06	11299	264.71	21.84	286.55
1067	2004-02-20	7941	250.83	20.69	271.52
1068	2004-02-16	13064	2.43	0.20	2.63
1069	2004-02-02	14040	35.28	2.91	38.19
1070	2004-02-23	4377	280.04	23.10	303.14
1071	2004-02-06	19135	107.04	8.83	115.87
1072	2004-02-07	15242	61.87	5.10	66.97
1073	2004-02-10	16553	253.22	20.89	274.11
1074	2004-02-03	12489	261.27	21.55	282.82
1075	2004-02-19	14830	328.65	27.11	355.76
1076	2004-02-02	11729	246.87	20.37	267.24
1077	2004-02-05	5920	57.34	4.73	62.07
1078	2004-02-10	171	229.23	18.91	248.14
1079	2004-02-08	4177	175.34	14.47	189.81
1080	2004-02-03	9638	232.13	19.15	251.28
1081	2004-02-12	4066	38.01	3.14	41.15
1082	2004-02-22	6514	127.62	10.53	138.15
1083	2004-02-06	16491	1.08	0.09	1.17
1084	2004-02-23	18594	205.10	16.92	222.02
1085	2004-02-14	3141	243.45	20.08	263.53
1086	2004-02-12	11359	84.93	7.01	91.94
1087	2004-02-12	1269	374.76	30.92	405.68
1088	2004-02-07	18272	44.23	3.65	47.88
1089	2004-02-18	10998	231.08	19.06	250.14
1090	2004-02-10	5202	245.50	20.25	265.75
1091	2004-02-24	6869	256.96	21.20	278.16
1092	2004-02-02	19473	113.92	9.40	123.32
1093	2004-02-11	2954	256.68	21.18	277.86
1094	2004-02-02	15606	148.16	12.22	160.38
1095	2004-02-04	3014	307.73	25.39	333.12
1096	2004-02-02	13324	208.84	17.23	226.07
1097	2004-02-21	12126	209.38	17.27	226.65
1098	2004-02-04	18972	264.06	21.78	285.84
1099	2004-02-25	8044	349.80	28.86	378.66
1100	2004-02-05	5174	204.66	16.88	221.54
1101	2004-02-07	13796	313.47	25.86	339.33
1102	2004-02-08	10016	203.92	16.82	220.74
1103	2004-02-15	4505	306.29	25.27	331.56
1104	2004-02-06	12237	392.49	32.38	424.87
1105	2004-02-07	501	232.45	19.18	251.63
1106	2004-02-18	6920	358.13	29.55	387.68
1107	2004-02-18	5234	40.19	3.32	43.51
1108	2004-02-16	7766	376.05	31.02	407.07
1109	2004-02-10	8781	40.02	3.30	43.32
1110	2004-02-01	8968	236.83	19.54	256.37
1111	2004-02-01	16025	242.69	20.02	262.71
1112	2004-02-03	3621	263.94	21.78	285.72
1113	2004-02-11	18737	272.58	22.49	295.07
1114	2004-02-09	1624	176.65	14.57	191.22
1115	2004-02-26	15328	103.38	8.53	111.91
1116	2004-02-26	19116	370.14	30.54	400.68
1117	2004-02-20	14541	159.60	13.17	172.77
1118	2004-02-21	3843	74.80	6.17	80.97
1119	2004-02-17	14780	375.85	31.01	406.86
1120	2004-02-21	1356	154.29	12.73	167.02
1121	2004-02-09	14555	167.06	13.78	180.84
1122	2004-02-21	1449	197.55	16.30	213.85
1123	2004-02-08	9797	34.67	2.86	37.53
1124	2004-02-14	12447	32.55	2.69	35.24
1125	2004-02-14	8712	56.07	4.63	60.70
1126	2004-02-25	9531	222.02	18.32	240.34
1127	2004-02-15	12585	112.34	9.27	121.61
1128	2004-02-09	13172	122.76	10.13	132.89
1129	2004-02-19	875	29.73	2.45	32.18
1130	2004-02-09	6874	245.21	20.23	265.44
1131	2004-02-05	19508	105.94	8.74	114.68
1132	2004-02-17	1938	257.26	21.22	278.48
1133	2004-02-15	1316	91.82	7.58	99.40
1134	2004-02-07	5138	145.34	11.99	157.33
1135	2004-02-23	10970	84.57	6.98	91.55
1136	2004-02-03	5279	325.87	26.88	352.75
1137	2004-02-19	11916	347.80	28.69	376.49
1138	2004-02-26	15075	238.35	19.66	258.01
1139	2004-02-15	9511	243.03	20.05	263.08
1140	2004-02-18	14521	18.20	1.50	19.70
1141	2004-02-21	15648	83.22	6.87	90.09
1142	2004-02-06	17518	32.64	2.69	35.33
1143	2004-02-11	5417	347.08	28.63	375.71
1144	2004-02-27	2377	41.40	3.42	44.82
1145	2004-02-28	16577	272.20	22.46	294.66
1146	2004-02-10	1300	70.49	5.82	76.31
1147	2004-02-07	17750	227.57	18.77	246.34
1148	2004-02-20	9019	141.31	11.66	152.97
1149	2004-02-24	1095	189.27	15.61	204.88
1150	2004-02-12	5758	46.55	3.84	50.39
1151	2004-02-20	5970	330.72	27.28	358.00
1152	2004-02-25	14184	380.92	31.43	412.35
1153	2004-02-14	10050	277.95	22.93	300.88
1154	2004-02-03	13805	376.03	31.02	407.05
1155	2004-02-03	19262	44.14	3.64	47.78
1156	2004-02-21	8981	178.13	14.70	192.83
1157	2004-02-17	10492	48.49	4.00	52.49
1158	2004-02-06	19517	335.08	27.64	362.72
1159	2004-02-13	13139	265.31	21.89	287.20
1160	2004-02-25	1883	239.48	19.76	259.24
1161	2004-02-09	15251	73.45	6.06	79.51
1162	2004-02-16	19993	132.05	10.89	142.94
1163	2004-02-08	12344	164.37	13.56	177.93
1164	2004-02-26	4450	375.71	31.00	406.71
1165	2004-02-20	10219	90.34	7.45	97.79
1166	2004-02-07	15583	15.63	1.29	16.92
1167	2004-02-02	18750	3.69	0.30	3.99
1168	2004-02-03	16451	228.41	18.84	247.25
1169	2004-02-09	1815	258.53	21.33	279.86
1170	2004-02-06	17184	0.61	0.05	0.66
1171	2004-02-26	12930	167.40	13.81	181.21
1172	2004-02-26	7763	100.37	8.28	108.65
1173	2004-02-05	18972	286.97	23.68	310.65
1174	2004-02-05	11557	301.73	24.89	326.62
1175	2004-02-13	14868	217.73	17.96	235.69
1176	2004-02-28	8170	180.56	14.90	195.46
1177	2004-02-20	7131	210.34	17.35	227.69
1178	2004-02-20	11502	349.03	28.79	377.82
1179	2004-02-11	14491	326.74	26.96	353.70
1180	2004-02-01	16641	14.65	1.21	15.86
1181	2004-02-27	1679	147.56	12.17	159.73
1182	2004-02-11	8455	304.19	25.10	329.29
1183	2004-02-03	14661	238.08	19.64	257.72
1184	2004-02-08	1023	253.53	20.92	274.45
1185	2004-02-21	16369	66.42	5.48	71.90
1186	2004-02-22	13347	148.81	12.28	161.09
1187	2004-02-23	11	285.39	23.54	308.93
1188	2004-02-03	12033	334.54	27.60	362.14
1189	2004-02-21	161	62.01	5.12	67.13
1190	2004-02-27	3695	304.98	25.16	330.14
1191	2004-02-14	4187	372.77	30.75	403.52
1192	2004-02-03	5398	385.04	31.77	416.81
1193	2004-02-28	7510	245.51	20.25	265.76
1194	2004-02-23	8651	336.14	27.73	363.87
1195	2004-02-02	9407	389.21	32.11	421.32
1196	2004-02-01	9276	96.24	7.94	104.18
1197	2004-02-22	12961	197.22	16.27	213.49
1198	2004-02-14	9934	317.14	26.16	343.30
1199	2004-02-07	6447	29.18	2.41	31.59
1200	2004-02-11	6771	18.48	1.52	20.00
1201	2004-02-27	5112	340.36	28.08	368.44
1202	2004-02-20	15035	180.10	14.86	194.96
1203	2004-02-25	2536	336.25	27.74	363.99
1204	2004-02-15	11109	348.88	28.78	377.66
1205	2004-02-25	17436	66.25	5.47	71.72
1206	2004-02-25	4582	108.92	8.99	117.91
1207	2004-02-25	9594	149.81	12.36	162.17
1208	2004-02-22	9670	276.66	22.82	299.48
1209	2004-02-03	1622	375.84	31.01	406.85
1210	2004-02-01	15558	66.66	5.50	72.16
1211	2004-02-26	11184	242.47	20.00	262.47
1212	2004-02-17	11851	324.75	26.79	351.54
1213	2004-02-23	1797	265.29	21.89	287.18
1214	2004-02-28	14521	33.20	2.74	35.94
1215	2004-02-24	19592	112.74	9.30	122.04
1216	2004-02-25	17134	255.15	21.05	276.20
1217	2004-02-07	17935	366.20	30.21	396.41
1218	2004-02-12	16580	218.93	18.06	236.99
1219	2004-02-03	4012	303.47	25.04	328.51
1220	2004-02-01	17867	9.05	0.75	9.80
1221	2004-02-05	6746	160.72	13.26	173.98
1222	2004-02-06	18336	200.65	16.55	217.20
1223	2004-02-06	5048	379.39	31.30	410.69
1224	2004-02-23	4285	114.48	9.44	123.92
1225	2004-02-03	10953	56.87	4.69	61.56
1226	2004-02-02	1749	106.96	8.82	115.78
1227	2004-02-13	16161	322.42	26.60	349.02
1228	2004-02-20	1598	255.11	21.05	276.16
1229	2004-02-12	17415	346.18	28.56	374.74
1230	2004-02-07	4746	159.07	13.12	172.19
1231	2004-02-20	7142	214.78	17.72	232.50
1232	2004-02-28	18139	303.39	25.03	328.42
1233	2004-02-01	12770	67.70	5.59	73.29
1234	2004-02-20	17599	89.29	7.37	96.66
1235	2004-02-20	16505	34.15	2.82	36.97
1236	2004-02-09	2781	34.99	2.89	37.88
1237	2004-02-27	18880	224.67	18.54	243.21
1238	2004-02-16	14130	99.09	8.17	107.26
1239	2004-02-28	19237	129.38	10.67	140.05
1240	2004-02-21	457	212.67	17.55	230.22
1241	2004-02-26	5376	49.67	4.10	53.77
1242	2004-02-08	8192	29.89	2.47	32.36
1243	2004-02-26	15120	233.47	19.26	252.73
1244	2004-02-25	7173	182.05	15.02	197.07
1245	2004-02-05	14510	277.14	22.86	300.00
1246	2004-02-03	19902	291.48	24.05	315.53
1247	2004-02-08	11435	152.28	12.56	164.84
1248	2004-02-11	18952	391.42	32.29	423.71
1249	2004-02-10	5101	192.47	15.88	208.35
1250	2004-02-02	5719	281.25	23.20	304.45
1251	2004-02-21	318	126.71	10.45	137.16
1252	2004-02-05	11034	242.50	20.01	262.51
1253	2004-02-26	17201	191.69	15.81	207.50
1254	2004-02-04	5139	374.82	30.92	405.74
1255	2004-02-20	18120	347.24	28.65	375.89
1256	2004-02-17	8431	354.02	29.21	383.23
1257	2004-02-08	11108	264.12	21.79	285.91
1258	2004-02-13	15373	371.99	30.69	402.68
1259	2004-02-10	13191	8.72	0.72	9.44
1260	2004-02-23	1832	296.80	24.49	321.29
1261	2004-02-23	4076	318.45	26.27	344.72
1262	2004-02-24	5028	351.48	29.00	380.48
1263	2004-02-18	5164	321.76	26.55	348.31
1264	2004-02-22	16723	100.31	8.28	108.59
1265	2004-02-12	9751	65.97	5.44	71.41
1266	2004-02-20	17723	108.92	8.99	117.91
1267	2004-02-15	12780	282.34	23.29	305.63
1268	2004-02-15	19634	66.88	5.52	72.40
1269	2004-02-02	17113	66.82	5.51	72.33
1270	2004-02-27	12028	9.35	0.77	10.12
1271	2004-02-24	12184	269.74	22.25	291.99
1272	2004-02-07	7152	16.45	1.36	17.81
1273	2004-02-23	2682	219.93	18.14	238.07
1274	2004-02-03	15070	46.47	3.83	50.30
1275	2004-02-23	14951	323.51	26.69	350.20
1276	2004-02-25	9200	350.52	28.92	379.44
1277	2004-02-06	14806	170.34	14.05	184.39
1278	2004-02-18	7388	237.27	19.57	256.84
1279	2004-02-22	706	293.04	24.18	317.22
1280	2004-02-04	8913	86.49	7.14	93.63
1281	2004-02-03	5956	77.34	6.38	83.72
1282	2004-02-08	17285	232.79	19.21	252.00
1283	2004-02-13	921	336.06	27.72	363.78
1284	2004-02-16	2363	165.66	13.67	179.33
1285	2004-02-13	19526	270.78	22.34	293.12
1286	2004-02-03	11885	214.58	17.70	232.28
1287	2004-02-26	12844	173.96	14.35	188.31
1288	2004-02-05	11909	232.02	19.14	251.16
1289	2004-02-20	8836	22.91	1.89	24.80
1290	2004-02-13	8153	344.27	28.40	372.67
1291	2004-02-08	1819	227.86	18.80	246.66
1292	2004-02-21	4573	183.58	15.15	198.73
1293	2004-02-11	19195	191.32	15.78	207.10
1294	2004-02-03	11911	180.68	14.91	195.59
1295	2004-02-11	795	282.07	23.27	305.34
1296	2004-02-25	19726	132.77	10.95	143.72
1297	2004-02-08	2976	293.80	24.24	318.04
1298	2004-02-12	4000	74.76	6.17	80.93
1299	2004-02-07	10337	224.34	18.51	242.85
1300	2004-02-18	773	221.52	18.28	239.80
1301	2004-02-24	10485	178.90	14.76	193.66
1302	2004-02-28	3439	75.86	6.26	82.12
1303	2004-02-06	13485	387.86	32.00	419.86
1304	2004-02-12	12365	318.56	26.28	344.84
1305	2004-02-22	8477	260.77	21.51	282.28
1306	2004-02-28	12391	225.06	18.57	243.63
1307	2004-02-04	1519	307.25	25.35	332.60
1308	2004-02-03	9948	295.78	24.40	320.18
1309	2004-02-05	16930	335.39	27.67	363.06
1310	2004-02-06	3661	288.84	23.83	312.67
1311	2004-02-13	11853	23.16	1.91	25.07
1312	2004-02-28	15040	232.89	19.21	252.10
1313	2004-02-03	18787	345.35	28.49	373.84
1314	2004-02-22	3709	318.32	26.26	344.58
1315	2004-02-18	10524	6.79	0.56	7.35
1316	2004-02-24	18771	16.91	1.40	18.31
1317	2004-02-24	7936	349.18	28.81	377.99
1318	2004-02-08	18447	286.29	23.62	309.91
1319	2004-02-07	15075	341.00	28.13	369.13
1320	2004-02-22	14738	80.28	6.62	86.90
1321	2004-02-27	10466	319.24	26.34	345.58
1322	2004-02-16	11416	229.62	18.94	248.56
1323	2004-02-22	8489	164.71	13.59	178.30
1324	2004-02-21	9707	346.06	28.55	374.61
1325	2004-02-06	3219	59.95	4.95	64.90
1326	2004-02-16	9840	318.19	26.25	344.44
1327	2004-02-22	629	216.35	17.85	234.20
1328	2004-02-27	17645	233.19	19.24	252.43
1329	2004-02-18	19786	280.27	23.12	303.39
1330	2004-02-21	3079	297.47	24.54	322.01
1331	2004-02-17	11070	339.18	27.98	367.16
1332	2004-02-16	17601	266.64	22.00	288.64
1333	2004-02-14	11951	4.10	0.34	4.44
1334	2004-02-20	1262	371.70	30.67	402.37
1335	2004-02-25	12238	315.06	25.99	341.05
1336	2004-02-24	1596	356.33	29.40	385.73
1337	2004-02-23	1012	48.27	3.98	52.25
1338	2004-02-14	10058	220.98	18.23	239.21
1339	2004-02-24	8747	151.95	12.54	164.49
1340	2004-02-10	12231	351.01	28.96	379.97
1341	2004-02-28	8228	374.27	30.88	405.15
1342	2004-02-04	19233	126.81	10.46	137.27
1343	2004-02-08	10159	20.70	1.71	22.41
1344	2004-02-02	5983	344.09	28.39	372.48
1345	2004-02-02	8203	239.55	19.76	259.31
1346	2004-02-27	12011	176.55	14.57	191.12
1347	2004-02-14	16091	219.30	18.09	237.39
1348	2004-02-11	9819	153.61	12.67	166.28
1349	2004-02-19	19738	389.59	32.14	421.73
1350	2004-02-11	10084	287.47	23.72	311.19
1351	2004-02-26	13098	395.38	32.62	428.00
1352	2004-02-01	15628	40.13	3.31	43.44
1353	2004-02-04	17927	69.40	5.73	75.13
1354	2004-02-28	16746	316.21	26.09	342.30
1355	2004-02-28	15112	352.07	29.05	381.12
1356	2004-02-07	2111	79.89	6.59	86.48
1357	2004-02-09	10131	27.77	2.29	30.06
1358	2004-02-24	5402	25.65	2.12	27.77
1359	2004-02-01	11314	89.73	7.40	97.13
1360	2004-02-09	7611	379.50	31.31	410.81
1361	2004-02-20	16853	208.21	17.18	225.39
1362	2004-02-11	16641	254.05	20.96	275.01
1363	2004-02-07	7937	257.41	21.24	278.65
1364	2004-02-13	12678	234.44	19.34	253.78
1365	2004-02-08	2344	73.42	6.06	79.48
1366	2004-02-02	426	15.08	1.24	16.32
1367	2004-02-03	16131	229.93	18.97	248.90
1368	2004-02-17	14629	269.24	22.21	291.45
1369	2004-02-03	9125	200.25	16.52	216.77
1370	2004-02-01	6472	245.69	20.27	265.96
1371	2004-02-28	17086	299.15	24.68	323.83
1372	2004-02-15	14104	225.00	18.56	243.56
1373	2004-02-05	8422	395.34	32.62	427.96
1374	2004-02-14	18563	298.80	24.65	323.45
1375	2004-02-06	4656	96.35	7.95	104.30
1376	2004-02-21	19969	116.95	9.65	126.60
1377	2004-02-09	10061	385.87	31.83	417.70
1378	2004-02-26	7252	323.56	26.69	350.25
1379	2004-02-10	14207	175.24	14.46	189.70
1380	2004-02-13	13449	237.71	19.61	257.32
1381	2004-02-20	19277	382.33	31.54	413.87
1382	2004-02-24	543	399.21	32.93	432.14
1383	2004-02-26	11952	47.84	3.95	51.79
1384	2004-02-22	6310	232.98	19.22	252.20
1385	2004-02-17	17932	350.50	28.92	379.42
1386	2004-02-19	6086	284.22	23.45	307.67
1387	2004-02-09	18830	82.55	6.81	89.36
1388	2004-02-16	135	348.11	28.72	376.83
1389	2004-02-03	17107	18.91	1.56	20.47
1390	2004-02-23	5060	47.49	3.92	51.41
1391	2004-02-14	14950	189.76	15.66	205.42
1392	2004-02-11	19806	171.18	14.12	185.30
1393	2004-02-15	14457	361.59	29.83	391.42
1394	2004-02-03	1297	67.66	5.58	73.24
1395	2004-02-27	18329	372.18	30.70	402.88
1396	2004-02-11	9078	202.91	16.74	219.65
1397	2004-02-09	10832	83.07	6.85	89.92
1398	2004-02-16	14265	240.79	19.87	260.66
1399	2004-02-24	19988	159.15	13.13	172.28
1400	2004-02-04	7319	6.53	0.54	7.07
1401	2004-02-13	12630	303.10	25.01	328.11
1402	2004-02-09	8947	38.30	3.16	41.46
1403	2004-02-15	10214	392.43	32.38	424.81
1404	2004-02-24	14119	178.32	14.71	193.03
1405	2004-02-07	8620	130.60	10.77	141.37
1406	2004-02-11	18566	276.90	22.84	299.74
1407	2004-02-20	19713	230.78	19.04	249.82
1408	2004-02-04	8562	18.59	1.53	20.12
1409	2004-02-15	5750	164.27	13.55	177.82
1410	2004-02-15	1475	365.61	30.16	395.77
1411	2004-02-14	16438	161.01	13.28	174.29
1412	2004-02-02	11373	181.74	14.99	196.73
1413	2004-02-18	13039	112.47	9.28	121.75
1414	2004-02-09	7662	0.24	0.02	0.26
1415	2004-02-04	6881	117.13	9.66	126.79
1416	2004-02-10	13204	188.49	15.55	204.04
1417	2004-02-07	1203	152.10	12.55	164.65
1418	2004-02-10	720	88.60	7.31	95.91
1419	2004-02-20	8621	305.98	25.24	331.22
1420	2004-02-03	7282	42.96	3.54	46.50
1421	2004-02-10	15512	164.43	13.57	178.00
1422	2004-02-04	6710	8.08	0.67	8.75
1423	2004-02-20	15071	309.15	25.50	334.65
1424	2004-02-09	12999	76.21	6.29	82.50
1425	2004-02-27	5880	58.62	4.84	63.46
1426	2004-02-21	15454	131.78	10.87	142.65
1427	2004-02-23	19516	84.17	6.94	91.11
1428	2004-02-03	13401	96.01	7.92	103.93
1429	2004-02-14	18260	4.76	0.39	5.15
1430	2004-02-07	2733	180.67	14.91	195.58
1431	2004-02-21	2345	212.93	17.57	230.50
1432	2004-02-17	4941	182.07	15.02	197.09
1433	2004-02-12	3736	381.93	31.51	413.44
1434	2004-02-09	1462	224.88	18.55	243.43
1435	2004-02-06	11378	309.94	25.57	335.51
1436	2004-02-01	7849	329.25	27.16	356.41
1437	2004-02-21	5022	73.93	6.10	80.03
1438	2004-02-13	13326	198.03	16.34	214.37
1439	2004-02-21	2101	64.39	5.31	69.70
1440	2004-02-27	1199	307.66	25.38	333.04
1441	2004-02-22	6836	262.47	21.65	284.12
1442	2004-02-07	17861	32.96	2.72	35.68
1443	2004-02-06	12782	256.26	21.14	277.40
1444	2004-02-27	12258	396.89	32.74	429.63
1445	2004-02-10	1926	385.25	31.78	417.03
1446	2004-02-06	11139	205.36	16.94	222.30
1447	2004-02-18	19705	379.06	31.27	410.33
1448	2004-02-11	16274	3.85	0.32	4.17
1449	2004-02-19	14622	138.12	11.39	149.51
1450	2004-02-09	4474	49.93	4.12	54.05
1451	2004-02-15	3754	271.26	22.38	293.64
1452	2004-02-26	12057	106.06	8.75	114.81
1453	2004-02-20	10127	275.91	22.76	298.67
1454	2004-02-11	8614	308.08	25.42	333.50
1455	2004-02-01	17559	360.42	29.73	390.15
1456	2004-02-26	17800	29.97	2.47	32.44
1457	2004-02-24	18276	136.15	11.23	147.38
1458	2004-02-22	8498	34.92	2.88	37.80
1459	2004-02-27	787	225.89	18.64	244.53
1460	2004-02-10	3745	138.03	11.39	149.42
1461	2004-02-17	986	375.74	31.00	406.74
1462	2004-02-25	18263	66.87	5.52	72.39
1463	2004-02-03	16378	372.55	30.74	403.29
1464	2004-02-13	1892	192.04	15.84	207.88
1465	2004-02-24	9469	55.19	4.55	59.74
1466	2004-02-25	5738	110.82	9.14	119.96
1467	2004-02-22	4389	158.54	13.08	171.62
1468	2004-02-20	6578	275.58	22.74	298.32
1469	2004-02-26	18098	299.73	24.73	324.46
1470	2004-02-19	16515	267.71	22.09	289.80
1471	2004-02-22	8561	102.41	8.45	110.86
1472	2004-02-05	16782	102.61	8.47	111.08
1473	2004-02-26	6004	196.08	16.18	212.26
1474	2004-02-15	7718	246.69	20.35	267.04
1475	2004-02-15	15885	348.46	28.75	377.21
1476	2004-02-21	2436	150.00	12.38	162.38
1477	2004-02-18	11845	57.37	4.73	62.10
1478	2004-02-06	16930	399.32	32.94	432.26
1479	2004-02-06	12599	104.03	8.58	112.61
1480	2004-02-27	8498	151.42	12.49	163.91
1481	2004-02-10	19665	377.63	31.15	408.78
1482	2004-02-19	5497	19.11	1.58	20.69
1483	2004-02-05	18360	108.64	8.96	117.60
1484	2004-02-27	6190	66.40	5.48	71.88
1485	2004-02-01	14717	12.28	1.01	13.29
1486	2004-02-19	95	264.44	21.82	286.26
1487	2004-02-20	16073	340.31	28.08	368.39
1488	2004-02-24	18297	14.97	1.24	16.21
1489	2004-02-28	10370	200.42	16.53	216.95
1490	2004-02-26	1526	163.81	13.51	177.32
1491	2004-02-22	19576	109.26	9.01	118.27
1492	2004-02-09	5702	30.26	2.50	32.76
1493	2004-02-17	2862	257.50	21.24	278.74
1494	2004-02-27	2043	283.64	23.40	307.04
1495	2004-02-04	15384	178.49	14.73	193.22
1496	2004-02-13	4206	284.99	23.51	308.50
1497	2004-02-03	18881	356.63	29.42	386.05
1498	2004-02-27	9479	350.13	28.89	379.02
1499	2004-02-27	17411	247.23	20.40	267.63
1500	2004-02-27	3330	111.68	9.21	120.89
1501	2004-02-17	16643	33.91	2.80	36.71
1502	2004-02-08	19898	212.73	17.55	230.28
1503	2004-02-24	15749	230.41	19.01	249.42
1504	2004-02-28	3490	287.95	23.76	311.71
1505	2004-02-27	14615	311.66	25.71	337.37
1506	2004-02-15	5927	104.16	8.59	112.75
1507	2004-02-16	2176	31.42	2.59	34.01
1508	2004-02-09	6817	270.60	22.32	292.92
1509	2004-02-06	13428	18.52	1.53	20.05
1510	2004-02-14	17329	15.62	1.29	16.91
1511	2004-02-26	4694	280.54	23.14	303.68
1512	2004-02-28	5489	51.07	4.21	55.28
1513	2004-02-13	8855	334.75	27.62	362.37
1514	2004-02-21	8673	369.49	30.48	399.97
1515	2004-02-03	12849	163.64	13.50	177.14
1516	2004-02-15	15452	317.55	26.20	343.75
1517	2004-02-24	17731	67.17	5.54	72.71
1518	2004-02-07	11115	130.71	10.78	141.49
1519	2004-02-28	4645	294.00	24.26	318.25
1520	2004-02-04	14196	20.08	1.66	21.74
1521	2004-02-23	5181	329.69	27.20	356.89
1522	2004-02-16	15746	236.80	19.54	256.34
1523	2004-02-20	10916	153.08	12.63	165.71
1524	2004-02-07	83	103.81	8.56	112.37
1525	2004-02-03	11475	159.30	13.14	172.44
1526	2004-02-20	13298	179.44	14.80	194.24
1527	2004-02-02	6766	345.96	28.54	374.50
1528	2004-02-08	9845	323.00	26.65	349.65
1529	2004-02-28	18328	227.17	18.74	245.91
1530	2004-02-04	19413	37.29	3.08	40.37
1531	2004-02-24	7187	275.29	22.71	298.00
1532	2004-02-10	4666	349.64	28.85	378.49
1533	2004-02-25	4406	303.05	25.00	328.05
1534	2004-02-01	2173	237.50	19.59	257.09
1535	2004-02-26	3699	237.49	19.59	257.08
1536	2004-02-08	9404	199.82	16.49	216.31
1537	2004-02-03	13463	226.32	18.67	244.99
1538	2004-02-20	14405	170.46	14.06	184.52
1539	2004-02-17	10806	109.83	9.06	118.89
1540	2004-02-12	11005	131.52	10.85	142.37
1541	2004-02-15	861	231.18	19.07	250.25
1542	2004-02-17	19324	94.52	7.80	102.32
1543	2004-02-16	848	108.20	8.93	117.13
1544	2004-02-27	434	1.55	0.13	1.68
1545	2004-02-16	4103	169.88	14.02	183.90
1546	2004-02-03	6389	73.98	6.10	80.08
1547	2004-02-10	3043	338.22	27.90	366.12
1548	2004-02-13	4569	229.80	18.96	248.76
1549	2004-02-13	1326	274.04	22.61	296.65
1550	2004-02-01	18479	385.96	31.84	417.80
1551	2004-02-09	17909	316.92	26.15	343.07
1552	2004-02-16	6966	299.42	24.70	324.12
1553	2004-02-24	1001	185.48	15.30	200.78
1554	2004-02-08	5677	329.04	27.15	356.19
1555	2004-02-24	890	165.94	13.69	179.63
1556	2004-02-23	4940	315.18	26.00	341.18
1557	2004-02-16	8474	247.38	20.41	267.79
1558	2004-02-05	15070	42.03	3.47	45.50
1559	2004-02-24	17725	375.15	30.95	406.10
1560	2004-02-25	15536	388.42	32.04	420.46
1561	2004-02-09	3392	88.10	7.27	95.37
1562	2004-02-16	8383	85.22	7.03	92.25
1563	2004-02-21	11782	338.51	27.93	366.44
1564	2004-02-02	5529	210.36	17.35	227.71
1565	2004-02-24	19098	6.36	0.52	6.88
1566	2004-02-03	4154	36.72	3.03	39.75
1567	2004-02-17	7429	271.40	22.39	293.79
1568	2004-02-19	7584	74.02	6.11	80.13
1569	2004-02-15	1892	23.13	1.91	25.04
1570	2004-02-14	8742	98.68	8.14	106.82
1571	2004-02-07	3606	12.56	1.04	13.60
1572	2004-02-25	15702	83.59	6.90	90.49
1573	2004-02-01	14134	200.78	16.56	217.34
1574	2004-02-17	4745	4.78	0.39	5.17
1575	2004-02-09	11056	126.17	10.41	136.58
1576	2004-02-08	538	323.31	26.67	349.98
1577	2004-02-19	4801	256.71	21.18	277.89
1578	2004-02-16	10128	333.32	27.50	360.82
1579	2004-02-16	15890	27.05	2.23	29.28
1580	2004-02-06	9489	8.89	0.73	9.62
1581	2004-02-08	13945	361.72	29.84	391.56
1582	2004-02-15	15362	158.17	13.05	171.22
1583	2004-02-04	15675	360.68	29.76	390.44
1584	2004-02-26	11159	360.18	29.71	389.89
1585	2004-02-27	3339	221.26	18.25	239.51
1586	2004-02-12	18189	39.35	3.25	42.60
1587	2004-02-21	12292	277.55	22.90	300.45
1588	2004-02-27	10952	270.74	22.34	293.08
1589	2004-02-17	11868	64.11	5.29	69.40
1590	2004-02-20	7877	230.25	19.00	249.25
1591	2004-02-17	17847	143.60	11.85	155.45
1592	2004-02-01	15373	110.49	9.12	119.61
1593	2004-02-23	4172	254.94	21.03	275.97
1594	2004-02-26	8866	267.03	22.03	289.06
1595	2004-02-02	14786	235.23	19.41	254.64
1596	2004-02-23	11924	379.19	31.28	410.47
1597	2004-02-01	19389	256.99	21.20	278.19
1598	2004-02-24	1747	203.38	16.78	220.16
1599	2004-02-11	18855	340.52	28.09	368.61
1600	2004-02-08	4180	285.92	23.59	309.51
1601	2004-02-04	6229	203.53	16.79	220.32
1602	2004-02-21	8831	394.17	32.52	426.69
1603	2004-02-01	13662	360.92	29.78	390.70
1604	2004-02-21	9696	37.86	3.12	40.98
1605	2004-02-01	16922	351.16	28.97	380.13
1606	2004-02-23	15568	83.55	6.89	90.44
1607	2004-02-11	7097	112.54	9.28	121.82
1608	2004-02-25	1256	289.99	23.92	313.91
1609	2004-02-02	5943	177.74	14.66	192.40
1610	2004-02-21	3707	10.44	0.86	11.30
1611	2004-02-02	9169	263.89	21.77	285.66
1612	2004-02-15	5494	73.92	6.10	80.02
1613	2004-02-23	4314	230.27	19.00	249.27
1614	2004-02-05	11822	91.17	7.52	98.69
1615	2004-02-26	12173	75.22	6.21	81.43
1616	2004-02-02	3199	374.94	30.93	405.87
1617	2004-02-23	3125	115.90	9.56	125.46
1618	2004-02-05	6083	154.06	12.71	166.77
1619	2004-02-18	12463	369.68	30.50	400.18
1620	2004-02-26	2995	193.54	15.97	209.51
1621	2004-02-01	2799	266.85	22.02	288.87
1622	2004-02-22	700	275.83	22.76	298.59
1623	2004-02-22	12220	26.70	2.20	28.90
1624	2004-02-17	8689	158.58	13.08	171.66
1625	2004-02-17	18728	395.65	32.64	428.29
1626	2004-02-16	14386	34.34	2.83	37.17
1627	2004-02-25	3686	5.90	0.49	6.39
1628	2004-02-21	6366	331.80	27.37	359.17
1629	2004-02-01	13537	380.27	31.37	411.64
1630	2004-02-21	4947	59.23	4.89	64.12
1631	2004-02-02	4232	377.55	31.15	408.70
1632	2004-02-03	6807	188.59	15.56	204.15
1633	2004-02-17	18469	269.11	22.20	291.31
1634	2004-02-16	14177	136.59	11.27	147.86
1635	2004-02-11	3313	393.76	32.49	426.25
1636	2004-02-10	11802	75.87	6.26	82.13
1637	2004-02-18	11282	108.57	8.96	117.53
1638	2004-02-07	6678	298.00	24.59	322.58
1639	2004-02-04	16294	291.51	24.05	315.56
1640	2004-02-11	5550	278.70	22.99	301.69
1641	2004-02-18	467	127.89	10.55	138.44
1642	2004-02-07	8298	119.14	9.83	128.97
1643	2004-02-11	1901	210.79	17.39	228.18
1644	2004-02-05	5250	267.92	22.10	290.02
1645	2004-02-22	11643	24.17	1.99	26.16
1646	2004-02-17	12589	397.32	32.78	430.10
1647	2004-02-18	8281	208.97	17.24	226.21
1648	2004-02-13	13560	370.70	30.58	401.28
1649	2004-02-16	8889	101.47	8.37	109.84
1650	2004-02-25	16328	187.37	15.46	202.83
1651	2004-02-15	17416	302.72	24.97	327.69
1652	2004-02-25	2711	66.35	5.47	71.82
1653	2004-02-09	18533	340.84	28.12	368.96
1654	2004-02-21	6972	36.27	2.99	39.26
1655	2004-02-19	17654	63.43	5.23	68.66
1656	2004-02-01	3835	127.87	10.55	138.42
1657	2004-02-17	12499	397.02	32.75	429.77
1658	2004-02-04	1800	350.88	28.95	379.83
1659	2004-02-16	12998	18.79	1.55	20.34
1660	2004-02-28	8536	166.75	13.76	180.51
1661	2004-02-18	15616	353.67	29.18	382.85
1662	2004-02-19	2846	86.49	7.14	93.63
1663	2004-02-28	8518	219.41	18.10	237.51
1664	2004-02-26	8685	214.16	17.67	231.83
1665	2004-02-14	19885	380.75	31.41	412.16
1666	2004-02-28	13141	221.02	18.23	239.25
1667	2004-02-23	11824	311.85	25.73	337.58
1668	2004-02-13	6026	342.98	28.30	371.28
1669	2004-02-06	3689	12.07	1.00	13.07
1670	2004-02-27	319	5.76	0.48	6.24
1671	2004-02-17	11393	73.11	6.03	79.14
1672	2004-02-09	15743	47.25	3.90	51.15
1673	2004-02-23	15468	46.36	3.82	50.18
1674	2004-02-20	14871	203.66	16.80	220.46
1675	2004-02-05	19776	345.52	28.51	374.03
1676	2004-02-12	5480	127.75	10.54	138.29
1677	2004-02-04	11727	150.53	12.42	162.95
1678	2004-02-24	1315	225.67	18.62	244.29
1679	2004-02-03	11176	113.58	9.37	122.95
1680	2004-02-27	19143	89.18	7.36	96.54
1681	2004-02-05	19396	321.48	26.52	348.00
1682	2004-02-19	9854	156.99	12.95	169.94
1683	2004-02-02	2937	16.25	1.34	17.59
1684	2004-02-05	12533	36.85	3.04	39.89
1685	2004-02-28	11163	340.64	28.10	368.74
1686	2004-02-15	17166	133.58	11.02	144.60
1687	2004-02-17	11985	298.84	24.65	323.49
1688	2004-02-09	6036	42.88	3.54	46.42
1689	2004-02-19	8158	234.86	19.38	254.24
1690	2004-02-27	17688	305.09	25.17	330.26
1691	2004-02-28	15243	106.30	8.77	115.07
1692	2004-02-21	15563	64.94	5.36	70.30
1693	2004-02-26	16336	348.50	28.75	377.25
1694	2004-02-13	19233	364.02	30.03	394.05
1695	2004-02-25	15167	266.93	22.02	288.95
1696	2004-02-11	10817	327.71	27.04	354.75
1697	2004-02-02	2625	156.22	12.89	169.11
1698	2004-02-13	14669	136.38	11.25	147.63
1699	2004-02-14	6704	128.28	10.58	138.86
1700	2004-02-09	3199	194.90	16.08	210.98
1701	2004-02-16	9638	112.85	9.31	122.16
1702	2004-02-10	15456	84.34	6.96	91.30
1703	2004-02-02	5683	79.21	6.53	85.74
1704	2004-02-23	13947	240.71	19.86	260.57
1705	2004-02-07	5366	236.63	19.52	256.15
1706	2004-02-24	13918	4.39	0.36	4.75
1707	2004-02-16	16655	232.72	19.20	251.92
1708	2004-02-09	8622	255.32	21.06	276.38
1709	2004-02-07	8663	163.16	13.46	176.62
1710	2004-02-26	158	185.83	15.33	201.16
1711	2004-02-13	10192	60.99	5.03	66.02
1712	2004-02-20	1058	272.28	22.46	294.74
1713	2004-02-03	7691	374.83	30.92	405.75
1714	2004-02-07	13878	192.25	15.86	208.11
1715	2004-02-24	1551	373.82	30.84	404.66
1716	2004-02-28	6831	266.46	21.98	288.44
1717	2004-02-05	18714	160.04	13.20	173.24
1718	2004-02-04	11920	193.89	16.00	209.89
1719	2004-02-11	7695	51.02	4.21	55.23
1720	2004-02-03	1270	18.67	1.54	20.21
1721	2004-02-16	14043	361.62	29.83	391.45
1722	2004-02-04	13059	45.18	3.73	48.91
1723	2004-02-24	12062	267.15	22.04	289.19
1724	2004-02-24	2343	155.18	12.80	167.98
1725	2004-02-16	13443	159.30	13.14	172.44
1726	2004-02-28	6694	228.82	18.88	247.70
1727	2004-02-14	104	64.31	5.31	69.62
1728	2004-02-19	16696	106.88	8.82	115.70
1729	2004-02-07	10592	315.97	26.07	342.04
1730	2004-02-09	17751	248.94	20.54	269.48
1731	2004-02-02	4555	376.64	31.07	407.71
1732	2004-02-28	19134	3.17	0.26	3.43
1733	2004-02-18	7201	112.54	9.28	121.82
1734	2004-02-28	19115	110.93	9.15	120.08
1735	2004-02-23	11549	335.23	27.66	362.89
1736	2004-02-28	4810	139.74	11.53	151.27
1737	2004-02-19	10805	82.52	6.81	89.33
1738	2004-02-23	18867	329.18	27.16	356.34
1739	2004-02-27	19348	208.28	17.18	225.46
1740	2004-02-26	10828	298.53	24.63	323.16
1741	2004-02-10	15672	322.96	26.64	349.60
1742	2004-02-16	8450	190.89	15.75	206.64
1743	2004-02-27	18347	395.79	32.65	428.44
1744	2004-02-16	14143	130.69	10.78	141.47
1745	2004-02-07	117	97.58	8.05	105.63
1746	2004-02-01	4845	216.77	17.88	234.65
1747	2004-02-16	4570	362.46	29.90	392.36
1748	2004-02-04	16024	356.05	29.37	385.42
1749	2004-02-28	11337	334.84	27.62	362.46
1750	2004-02-25	14069	239.58	19.77	259.35
1751	2004-02-07	6272	371.37	30.64	402.01
1752	2004-02-05	17323	343.74	28.36	372.10
1753	2004-02-21	12637	218.81	18.05	236.86
1754	2004-02-02	1969	188.01	15.51	203.52
1755	2004-02-27	2663	222.18	18.33	240.51
1756	2004-02-04	3499	97.54	8.05	105.59
1757	2004-02-19	19242	256.59	21.17	277.76
1758	2004-02-12	18459	392.90	32.41	425.31
1759	2004-02-22	599	219.14	18.08	237.22
1760	2004-02-03	6530	332.58	27.44	360.02
1761	2004-02-02	18568	377.95	31.18	409.13
1762	2004-02-15	5213	178.30	14.71	193.01
1763	2004-02-12	6711	56.13	4.63	60.76
1764	2004-02-08	11871	53.08	4.38	57.46
1765	2004-02-10	5927	195.86	16.16	212.02
1766	2004-02-02	13784	143.77	11.86	155.63
1767	2004-02-07	291	239.05	19.72	258.77
1768	2004-02-28	12513	296.69	24.48	321.17
1769	2004-02-06	1459	329.57	27.19	356.76
1770	2004-02-18	5627	47.11	3.89	51.00
1771	2004-02-22	1026	340.75	28.11	368.86
1772	2004-02-13	1278	26.26	2.17	28.43
1773	2004-02-01	11449	344.08	28.39	372.47
1774	2004-02-05	13154	88.18	7.27	95.45
1775	2004-02-20	10919	139.91	11.54	151.45
1776	2004-02-19	9093	119.62	9.87	129.49
1777	2004-02-10	14395	51.22	4.23	55.45
1778	2004-02-18	2138	294.01	24.26	318.27
1779	2004-02-26	2612	392.02	32.34	424.36
1780	2004-02-04	13577	120.10	9.91	130.01
1781	2004-02-11	15490	252.03	20.79	272.82
1782	2004-02-08	9463	92.90	7.66	100.56
1783	2004-02-20	2844	281.85	23.25	305.10
1784	2004-02-25	2780	57.95	4.78	62.73
1785	2004-02-16	11508	141.83	11.70	153.53
1786	2004-02-15	16602	53.84	4.44	58.28
1787	2004-02-02	9763	225.40	18.60	244.00
1788	2004-02-18	17032	344.51	28.42	372.93
1789	2004-02-07	14312	2.55	0.21	2.76
1790	2004-02-09	7307	6.66	0.55	7.21
1791	2004-02-02	5233	121.00	9.98	130.98
1792	2004-02-12	12421	172.85	14.26	187.11
1793	2004-02-05	10730	49.70	4.10	53.80
1794	2004-02-02	14867	339.86	28.04	367.90
1795	2004-02-16	15026	87.68	7.23	94.91
1796	2004-02-22	18670	231.38	19.09	250.47
1797	2004-02-17	5070	209.13	17.25	226.38
1798	2004-02-27	12757	176.87	14.59	191.46
1799	2004-02-20	2635	324.25	26.75	351.00
1800	2004-02-11	6957	16.89	1.39	18.28
1801	2004-02-23	2719	168.49	13.90	182.39
1802	2004-02-01	8917	15.59	1.29	16.88
1803	2004-02-23	14393	332.74	27.45	360.19
1804	2004-02-05	17823	166.48	13.73	180.21
1805	2004-02-16	10595	280.05	23.10	303.15
1806	2004-02-02	18473	174.89	14.43	189.32
1807	2004-02-03	5841	214.46	17.69	232.15
1808	2004-02-27	15285	195.44	16.12	211.56
1809	2004-02-01	3926	52.16	4.30	56.46
1810	2004-02-13	3820	379.55	31.31	410.86
1811	2004-02-10	19659	36.20	2.99	39.19
1812	2004-02-24	11558	365.19	30.13	395.32
1813	2004-02-11	17462	118.58	9.78	128.36
1814	2004-02-12	11159	251.01	20.71	271.72
1815	2004-02-03	17842	124.46	10.27	134.73
1816	2004-02-24	11436	61.56	5.08	66.64
1817	2004-02-25	8363	161.00	13.28	174.28
1818	2004-02-04	5797	311.76	25.72	337.48
1819	2004-02-02	4197	349.03	28.79	377.82
1820	2004-02-14	11460	323.55	26.69	350.24
1821	2004-02-06	2196	121.95	10.06	132.01
1822	2004-02-01	1395	350.55	28.92	379.47
1823	2004-02-21	8948	67.09	5.53	72.62
1824	2004-02-24	18622	220.18	18.16	238.34
1825	2004-02-02	18686	253.90	20.95	274.85
1826	2004-02-20	1614	81.85	6.75	88.60
1827	2004-02-21	7558	92.29	7.61	99.90
1828	2004-02-15	8007	374.14	30.87	405.01
1829	2004-02-27	9846	345.41	28.50	373.91
1830	2004-02-27	9342	132.15	10.90	143.05
1831	2004-02-10	2814	114.46	9.44	123.90
1832	2004-02-11	19273	104.60	8.63	113.23
1833	2004-02-09	10741	254.36	20.98	275.34
1834	2004-02-01	6509	161.14	13.29	174.43
1835	2004-02-02	12463	399.28	32.94	432.22
1836	2004-02-21	1678	267.36	22.06	289.42
1837	2004-02-04	10273	258.97	21.37	280.34
1838	2004-02-23	17214	174.13	14.37	188.50
1839	2004-02-06	14791	21.56	1.78	23.34
1840	2004-02-16	7733	60.18	4.96	65.14
1841	2004-02-07	9002	90.00	7.43	97.42
1842	2004-02-04	11113	45.25	3.73	48.98
1843	2004-02-07	7273	75.14	6.20	81.34
1844	2004-02-07	957	210.13	17.34	227.47
1845	2004-02-03	1612	0.50	0.04	0.54
1846	2004-02-20	18851	237.56	19.60	257.16
1847	2004-02-07	6264	176.02	14.52	190.54
1848	2004-02-06	18376	82.70	6.82	89.52
1849	2004-02-21	9575	29.78	2.46	32.24
1850	2004-02-15	4856	195.12	16.10	211.22
1851	2004-02-08	16084	162.96	13.44	176.40
1852	2004-02-01	16799	192.80	15.91	208.71
1853	2004-02-04	8169	47.23	3.90	51.13
1854	2004-02-21	4824	67.40	5.56	72.96
1855	2004-02-21	18823	197.67	16.31	213.98
1856	2004-02-23	10780	354.25	29.23	383.48
1857	2004-02-20	7655	109.77	9.06	118.83
1858	2004-02-24	14910	205.95	16.99	222.94
1859	2004-02-26	14207	87.88	7.25	95.13
1860	2004-02-22	7298	249.72	20.60	270.32
1861	2004-02-28	1043	214.19	17.67	231.86
1862	2004-02-03	2335	310.45	25.61	336.06
1863	2004-02-22	15437	14.13	1.17	15.30
1864	2004-02-10	14700	156.66	12.92	169.58
1865	2004-02-03	8325	384.14	31.69	415.83
1866	2004-02-25	2168	362.33	29.89	392.22
1867	2004-02-04	11179	223.85	18.47	242.32
1868	2004-02-23	7645	354.87	29.28	384.15
1869	2004-02-22	1396	224.50	18.52	243.02
1870	2004-02-08	9966	200.66	16.55	217.21
1871	2004-02-11	580	185.09	15.27	200.36
1872	2004-02-08	11046	374.44	30.89	405.33
1873	2004-02-21	13231	262.02	21.62	283.64
1874	2004-02-27	14157	15.48	1.28	16.76
1875	2004-02-26	5183	230.04	18.98	249.02
1876	2004-02-12	18527	231.56	19.10	250.66
1877	2004-02-23	11320	316.38	26.10	342.48
1878	2004-02-16	12194	131.38	10.84	142.22
1879	2004-02-02	2831	238.67	19.69	258.36
1880	2004-02-18	7176	124.08	10.24	134.32
1881	2004-02-14	3368	395.13	32.60	427.73
1882	2004-02-11	14145	245.37	20.24	265.61
1883	2004-02-20	6165	156.79	12.94	169.73
1884	2004-02-21	17255	81.29	6.71	88.00
1885	2004-02-26	18552	31.08	2.56	33.64
1886	2004-02-07	5862	203.58	16.80	220.38
1887	2004-02-08	11049	244.63	20.18	264.81
1888	2004-02-26	8330	271.11	22.37	293.48
1889	2004-02-01	14170	113.13	9.33	122.46
1890	2004-02-13	2108	360.09	29.71	389.80
1891	2004-02-01	2708	241.11	19.89	261.00
1892	2004-02-16	15905	10.09	0.83	10.92
1893	2004-02-14	17036	248.60	20.51	269.11
1894	2004-02-10	1363	78.58	6.48	85.06
1895	2004-02-11	16381	230.08	18.98	249.06
1896	2004-02-22	12114	297.42	24.54	321.96
1897	2004-02-28	19704	60.22	4.97	65.19
1898	2004-02-11	9256	87.56	7.22	94.78
1899	2004-02-16	10069	235.41	19.42	254.83
1900	2004-02-14	18181	242.79	20.03	262.82
1901	2004-02-21	9840	224.49	18.52	243.01
1902	2004-02-17	13603	360.23	29.72	389.95
1903	2004-02-25	19220	133.37	11.00	144.37
1904	2004-02-01	16900	106.94	8.82	115.76
1905	2004-02-06	13894	333.81	27.54	361.35
1906	2004-02-16	11359	221.71	18.29	240.00
1907	2004-02-04	15698	339.72	28.03	367.75
1908	2004-02-07	9315	350.39	28.91	379.30
1909	2004-02-18	4692	267.44	22.06	289.50
1910	2004-02-25	13406	206.53	17.04	223.57
1911	2004-02-07	7489	393.09	32.43	425.52
1912	2004-02-02	4968	65.94	5.44	71.38
1913	2004-02-23	15882	58.50	4.83	63.33
1914	2004-02-13	15515	31.59	2.61	34.20
1915	2004-02-09	9190	104.59	8.63	113.22
1916	2004-02-11	321	63.91	5.27	69.18
1917	2004-02-06	1919	75.13	6.20	81.33
1918	2004-02-11	2947	147.74	12.19	159.93
1919	2004-02-13	10036	175.65	14.49	190.14
1920	2004-02-16	18335	269.64	22.25	291.89
1921	2004-02-19	6409	125.90	10.39	136.29
1922	2004-02-10	5429	152.36	12.57	164.93
1923	2004-02-21	10911	241.36	19.91	261.27
1924	2004-02-17	12294	15.85	1.31	17.16
1925	2004-02-11	11073	114.59	9.45	124.04
1926	2004-02-03	13135	220.06	18.15	238.21
1927	2004-02-27	14993	273.28	22.55	295.83
1928	2004-02-17	8802	324.13	26.74	350.87
1929	2004-02-25	10941	144.70	11.94	156.64
1930	2004-02-09	19807	308.03	25.41	333.44
1931	2004-02-12	14280	222.07	18.32	240.39
1932	2004-02-01	1043	35.79	2.95	38.74
1933	2004-02-20	16688	262.64	21.67	284.31
1934	2004-02-10	1863	37.48	3.09	40.57
1935	2004-02-11	2388	195.75	16.15	211.90
1936	2004-02-23	14125	91.48	7.55	99.03
1937	2004-02-15	16725	312.68	25.80	338.48
1938	2004-02-20	4830	89.20	7.36	96.56
1939	2004-02-15	18231	97.17	8.02	105.19
1940	2004-02-24	744	377.39	31.13	408.52
1941	2004-02-24	16414	36.24	2.99	39.23
1942	2004-02-05	17061	260.96	21.53	282.49
1943	2004-02-05	11889	63.03	5.20	68.23
1944	2004-02-06	6928	221.89	18.31	240.20
1945	2004-02-01	3745	25.74	2.12	27.86
1946	2004-02-14	9087	20.89	1.72	22.61
1947	2004-02-22	14182	212.02	17.49	229.51
1948	2004-02-10	3525	280.94	23.18	304.12
1949	2004-02-02	6390	372.53	30.73	403.26
1950	2004-02-20	6016	267.26	22.05	289.31
1951	2004-02-28	4809	37.82	3.12	40.94
1952	2004-02-15	207	338.60	27.93	366.53
1953	2004-02-28	13255	119.96	9.90	129.86
1954	2004-02-02	2164	372.46	30.73	403.19
1955	2004-02-28	14468	56.49	4.66	61.15
1956	2004-02-15	2244	153.86	12.69	166.55
1957	2004-02-22	5682	333.08	27.48	360.56
1958	2004-02-27	14414	346.18	28.56	374.74
1959	2004-02-18	12415	111.54	9.20	120.74
1960	2004-02-02	17861	188.33	15.54	203.87
1961	2004-02-21	2641	318.03	26.24	344.27
1962	2004-02-27	18271	173.39	14.30	187.69
1963	2004-02-15	17921	273.41	22.56	295.97
1964	2004-02-25	7161	280.80	23.17	303.97
1965	2004-02-01	17531	316.00	26.07	342.07
1966	2004-02-13	10541	378.88	31.26	410.14
1967	2004-02-20	2236	397.66	32.81	430.47
1968	2004-02-07	14192	39.37	3.25	42.62
1969	2004-02-28	6197	179.60	14.82	194.42
1970	2004-02-08	1109	72.97	6.02	78.99
1971	2004-02-08	10858	360.86	29.77	390.63
1972	2004-02-20	13320	145.83	12.03	157.86
1973	2004-02-28	1711	22.25	1.84	24.09
1974	2004-02-28	6286	66.20	5.46	71.66
1975	2004-02-25	7352	224.49	18.52	243.01
1976	2004-02-27	3739	155.37	12.82	168.19
1977	2004-02-02	15394	383.92	31.67	415.59
1978	2004-02-03	15120	358.21	29.55	387.76
1979	2004-02-28	17740	159.08	13.12	172.20
1980	2004-02-06	17005	215.24	17.76	233.00
1981	2004-02-09	18636	30.38	2.51	32.89
1982	2004-02-24	14263	347.82	28.70	376.52
1983	2004-02-04	9443	102.89	8.49	111.38
1984	2004-02-11	12970	373.72	30.83	404.55
1985	2004-02-28	12033	307.92	25.40	333.32
1986	2004-02-21	5372	193.66	15.98	209.64
1987	2004-02-28	11337	56.71	4.68	61.39
1988	2004-02-02	12544	108.84	8.98	117.82
1989	2004-02-04	1762	363.19	29.96	393.15
1990	2004-02-11	12938	238.96	19.71	258.67
1991	2004-02-21	6703	241.45	19.92	261.37
1992	2004-02-20	9903	328.15	27.07	355.22
1993	2004-02-19	6380	43.46	3.59	47.05
1994	2004-02-15	8628	310.26	25.60	335.86
1995	2004-02-18	9456	323.79	26.71	350.50
1996	2004-02-10	1018	70.43	5.81	76.24
1997	2004-02-04	9851	244.86	20.20	265.06
1998	2004-02-20	16915	74.51	6.15	80.66
1999	2004-02-01	14892	15.41	1.27	16.68
2000	2004-02-14	2426	6.10	0.50	6.60
2001	2004-03-04	931	31.84	2.63	34.47
2002	2004-03-22	14397	357.33	29.48	386.81
2003	2004-03-13	409	172.38	14.22	186.60
2004	2004-03-19	14315	284.06	23.43	307.49
2005	2004-03-14	14589	245.50	20.25	265.75
2006	2004-03-14	18473	33.00	2.72	35.72
2007	2004-03-08	6276	100.79	8.32	109.11
2008	2004-03-26	4374	195.86	16.16	212.02
2009	2004-03-24	11524	110.27	9.10	119.37
2010	2004-03-23	18666	219.16	18.08	237.24
2011	2004-03-13	6593	123.18	10.16	133.34
2012	2004-03-25	7303	364.29	30.05	394.34
2013	2004-03-18	44	320.84	26.47	347.31
2014	2004-03-27	9794	317.35	26.18	343.53
2015	2004-03-04	3441	389.04	32.10	421.14
2016	2004-03-29	11992	383.52	31.64	415.16
2017	2004-03-26	12442	236.78	19.53	256.31
2018	2004-03-30	7915	74.24	6.12	80.36
2019	2004-03-29	4866	294.87	24.33	319.20
2020	2004-03-18	6952	323.59	26.70	350.29
2021	2004-03-24	1305	382.62	31.57	414.19
2022	2004-03-01	4515	205.99	16.99	222.98
2023	2004-03-11	10607	99.83	8.24	108.07
2024	2004-03-03	13577	216.11	17.83	233.94
2025	2004-03-26	1231	330.67	27.28	357.95
2026	2004-03-23	14151	358.60	29.58	388.18
2027	2004-03-13	10651	28.38	2.34	30.72
2028	2004-03-28	17019	391.48	32.30	423.78
2029	2004-03-19	5353	53.33	4.40	57.73
2030	2004-03-27	10607	30.48	2.51	32.99
2031	2004-03-30	1697	294.98	24.34	319.32
2032	2004-03-03	8142	36.75	3.03	39.78
2033	2004-03-18	5663	276.05	22.77	298.82
2034	2004-03-08	9524	331.69	27.36	359.05
2035	2004-03-29	10390	329.20	27.16	356.36
2036	2004-03-13	15275	363.91	30.02	393.93
2037	2004-03-23	12836	248.69	20.52	269.21
2038	2004-03-24	18086	347.64	28.68	376.32
2039	2004-03-31	15297	98.09	8.09	106.18
2040	2004-03-16	1115	262.80	21.68	284.48
2041	2004-03-04	16859	386.93	31.92	418.85
2042	2004-03-29	17339	344.73	28.44	373.17
2043	2004-03-15	478	271.20	22.37	293.57
2044	2004-03-11	14918	371.54	30.65	402.19
2045	2004-03-11	15852	180.19	14.87	195.06
2046	2004-03-31	2443	179.47	14.81	194.28
2047	2004-03-12	6727	384.11	31.69	415.80
2048	2004-03-23	9477	227.71	18.79	246.50
2049	2004-03-19	19126	244.91	20.21	265.12
2050	2004-03-18	18076	68.70	5.67	74.37
2051	2004-03-01	11683	21.11	1.74	22.85
2052	2004-03-18	11991	82.96	6.84	89.80
2053	2004-03-14	11557	125.08	10.32	135.40
2054	2004-03-21	4929	273.01	22.52	295.53
2055	2004-03-12	5406	177.14	14.61	191.75
2056	2004-03-04	2908	328.70	27.12	355.82
2057	2004-03-04	17435	204.30	16.85	221.15
2058	2004-03-29	9682	105.34	8.69	114.03
2059	2004-03-17	2771	214.89	17.73	232.62
2060	2004-03-03	19724	118.85	9.81	128.66
2061	2004-03-10	3307	391.38	32.29	423.67
2062	2004-03-05	2237	187.52	15.47	202.99
2063	2004-03-15	14362	263.53	21.74	285.27
2064	2004-03-26	16701	274.09	22.61	296.70
2065	2004-03-18	18485	9.34	0.77	10.11
2066	2004-03-26	10514	127.77	10.54	138.31
2067	2004-03-07	1693	245.19	20.23	265.42
2068	2004-03-22	826	156.69	12.93	169.62
2069	2004-03-19	4483	154.22	12.72	166.94
2070	2004-03-17	10416	227.22	18.75	245.97
2071	2004-03-27	15996	313.13	25.83	338.96
2072	2004-03-17	7985	146.76	12.11	158.87
2073	2004-03-07	18536	225.50	18.60	244.10
2074	2004-03-29	8898	189.27	15.61	204.88
2075	2004-03-10	2057	95.31	7.86	103.17
2076	2004-03-14	16710	69.46	5.73	75.19
2077	2004-03-05	195	27.92	2.30	30.22
2078	2004-03-01	14335	82.10	6.77	88.87
2079	2004-03-30	4556	364.65	30.08	394.73
2080	2004-03-27	2196	363.26	29.97	393.23
2081	2004-03-23	1340	266.08	21.95	288.03
2082	2004-03-27	9122	8.86	0.73	9.59
2083	2004-03-08	13763	314.05	25.91	339.96
2084	2004-03-08	13790	320.71	26.46	347.17
2085	2004-03-19	5055	315.18	26.00	341.18
2086	2004-03-29	9195	62.86	5.19	68.05
2087	2004-03-29	16686	344.60	28.43	373.03
2088	2004-03-04	6277	211.38	17.44	228.82
2089	2004-03-14	13910	276.69	22.83	299.52
2090	2004-03-12	10124	170.06	14.03	184.09
2091	2004-03-05	380	215.63	17.79	233.42
2092	2004-03-12	12806	214.24	17.67	231.91
2093	2004-03-09	8007	98.86	8.16	107.02
2094	2004-03-17	16039	312.45	25.78	338.23
2095	2004-03-04	2954	46.72	3.85	50.57
2096	2004-03-13	196	146.45	12.08	158.53
2097	2004-03-01	18971	157.15	12.96	170.11
2098	2004-03-28	13031	169.60	13.99	183.59
2099	2004-03-21	8347	53.12	4.38	57.50
2100	2004-03-01	8024	387.43	31.96	419.39
2101	2004-03-09	17864	328.35	27.09	355.44
2102	2004-03-05	5353	15.16	1.25	16.41
2103	2004-03-15	11232	119.74	9.88	129.62
2104	2004-03-25	18278	219.66	18.12	237.78
2105	2004-03-16	3352	37.77	3.12	40.89
2106	2004-03-18	3682	326.76	26.96	353.72
2107	2004-03-09	19171	120.44	9.94	130.38
2108	2004-03-30	3484	216.60	17.87	234.47
2109	2004-03-16	11012	61.23	5.05	66.28
2110	2004-03-04	17139	63.59	5.25	68.84
2111	2004-03-10	19486	32.32	2.67	34.99
2112	2004-03-26	4414	131.19	10.82	142.01
2113	2004-03-17	11368	59.90	4.94	64.84
2114	2004-03-22	17519	240.70	19.86	260.56
2115	2004-03-09	8968	303.22	25.02	328.24
2116	2004-03-22	19454	23.46	1.94	25.40
2117	2004-03-18	13522	15.22	1.26	16.48
2118	2004-03-18	6964	227.13	18.74	245.87
2119	2004-03-05	18794	216.82	17.89	234.71
2120	2004-03-30	17555	222.57	18.36	240.93
2121	2004-03-30	15183	204.67	16.89	221.56
2122	2004-03-02	2548	299.61	24.72	324.33
2123	2004-03-12	4158	7.23	0.60	7.83
2124	2004-03-15	15831	330.84	27.29	358.13
2125	2004-03-02	17872	358.74	29.60	388.34
2126	2004-03-21	7656	78.05	6.44	84.49
2127	2004-03-28	2299	110.61	9.13	119.74
2128	2004-03-17	10337	202.34	16.69	219.03
2129	2004-03-01	18030	252.02	20.79	272.81
2130	2004-03-28	10402	385.88	31.84	417.72
2131	2004-03-14	537	381.71	31.49	413.20
2132	2004-03-28	997	124.27	10.25	134.52
2133	2004-03-02	16175	122.16	10.08	132.24
2134	2004-03-04	9772	30.83	2.54	33.37
2135	2004-03-19	4413	65.57	5.41	70.98
2136	2004-03-03	18112	266.06	21.95	288.01
2137	2004-03-08	15677	195.81	16.15	211.96
2138	2004-03-24	1306	33.68	2.78	36.46
2139	2004-03-19	213	232.56	19.19	251.75
2140	2004-03-05	17942	283.61	23.40	307.01
2141	2004-03-03	16003	214.58	17.70	232.28
2142	2004-03-05	9845	61.94	5.11	67.05
2143	2004-03-04	2859	94.81	7.82	102.63
2144	2004-03-20	9488	36.67	3.03	39.70
2145	2004-03-04	403	88.33	7.29	95.62
2146	2004-03-14	18123	230.96	19.05	250.01
2147	2004-03-06	14532	279.33	23.04	302.37
2148	2004-03-18	5100	27.22	2.25	29.47
2149	2004-03-31	13823	103.96	8.58	112.54
2150	2004-03-07	18061	229.44	18.93	248.37
2151	2004-03-04	11036	87.15	7.19	94.34
2152	2004-03-16	10163	213.54	17.62	231.16
2153	2004-03-05	12098	200.39	16.53	216.92
2154	2004-03-01	14132	30.34	2.50	32.84
2155	2004-03-29	10138	168.95	13.94	182.89
2156	2004-03-28	5557	304.48	25.12	329.60
2157	2004-03-05	16463	286.37	23.63	310.00
2158	2004-03-30	9221	127.83	10.55	138.38
2159	2004-03-11	10641	243.60	20.10	263.70
2160	2004-03-28	18833	83.23	6.87	90.10
2161	2004-03-25	9724	191.22	15.78	207.00
2162	2004-03-12	3338	40.99	3.38	44.37
2163	2004-03-19	19696	399.99	33.00	432.99
2164	2004-03-26	10682	149.80	12.36	162.16
2165	2004-03-28	12929	353.22	29.14	382.36
2166	2004-03-17	17748	218.07	17.99	236.06
2167	2004-03-04	13495	257.56	21.25	278.81
2168	2004-03-19	18202	82.04	6.77	88.81
2169	2004-03-14	18985	196.27	16.19	212.46
2170	2004-03-17	11782	47.21	3.89	51.10
2171	2004-03-29	5068	247.68	20.43	268.11
2172	2004-03-09	18712	329.29	27.17	356.46
2173	2004-03-18	17279	270.93	22.35	293.28
2174	2004-03-08	4011	295.08	24.34	319.42
2175	2004-03-13	19664	362.34	29.89	392.23
2176	2004-03-21	13216	43.95	3.63	47.58
2177	2004-03-27	5027	328.31	27.09	355.40
2178	2004-03-06	13678	268.80	22.18	290.98
2179	2004-03-11	17369	267.34	22.06	289.40
2180	2004-03-15	15892	39.28	3.24	42.52
2181	2004-03-27	17561	168.18	13.87	182.05
2182	2004-03-10	18803	209.07	17.25	226.32
2183	2004-03-02	6837	384.19	31.70	415.89
2184	2004-03-10	10594	64.36	5.31	69.67
2185	2004-03-03	11378	330.87	27.30	358.17
2186	2004-03-31	16771	28.51	2.35	30.86
2187	2004-03-05	475	133.86	11.04	144.90
2188	2004-03-19	8555	184.03	15.18	199.21
2189	2004-03-26	11340	390.90	32.25	423.15
2190	2004-03-31	17264	306.06	25.25	331.31
2191	2004-03-03	8571	383.10	31.61	414.71
2192	2004-03-28	11296	44.05	3.63	47.68
2193	2004-03-25	8372	29.30	2.42	31.72
2194	2004-03-09	17099	390.56	32.22	422.78
2195	2004-03-19	10916	358.68	29.59	388.27
2196	2004-03-22	18676	397.95	32.83	430.78
2197	2004-03-12	8618	27.35	2.26	29.61
2198	2004-03-29	2548	41.77	3.45	45.22
2199	2004-03-19	13558	42.91	3.54	46.45
2200	2004-03-17	5416	355.29	29.31	384.60
2201	2004-03-07	18956	88.55	7.31	95.86
2202	2004-03-30	19340	18.69	1.54	20.23
2203	2004-03-15	654	30.11	2.48	32.59
2204	2004-03-07	13369	218.20	18.00	236.20
2205	2004-03-04	14412	300.86	24.82	325.68
2206	2004-03-16	9821	399.60	32.97	432.57
2207	2004-03-08	9501	246.93	20.37	267.30
2208	2004-03-30	6331	284.53	23.47	308.00
2209	2004-03-08	14012	358.32	29.56	387.88
2210	2004-03-20	2055	124.16	10.24	134.40
2211	2004-03-05	16301	248.71	20.52	269.23
2212	2004-03-17	16877	388.76	32.07	420.83
2213	2004-03-10	14122	244.48	20.17	264.65
2214	2004-03-31	5076	197.43	16.29	213.72
2215	2004-03-02	1368	157.56	13.00	170.56
2216	2004-03-19	6485	380.43	31.39	411.82
2217	2004-03-19	17966	157.43	12.99	170.42
2218	2004-03-10	14062	39.19	3.23	42.42
2219	2004-03-04	12912	175.40	14.47	189.87
2220	2004-03-28	12014	389.03	32.09	421.12
2221	2004-03-17	4081	375.82	31.01	406.83
2222	2004-03-21	10714	198.82	16.40	215.22
2223	2004-03-21	19031	189.02	15.59	204.61
2224	2004-03-11	5652	296.68	24.48	321.16
2225	2004-03-24	18072	8.89	0.73	9.62
2226	2004-03-16	5675	171.31	14.13	185.44
2227	2004-03-25	1084	170.15	14.04	184.19
2228	2004-03-28	7940	34.39	2.84	37.23
2229	2004-03-01	5633	53.70	4.43	58.13
2230	2004-03-25	14683	179.29	14.79	194.08
2231	2004-03-15	417	176.16	14.53	190.69
2232	2004-03-30	10655	376.89	31.09	407.98
2233	2004-03-18	13807	305.55	25.21	330.76
2234	2004-03-27	5128	171.54	14.15	185.69
2235	2004-03-27	327	293.45	24.21	317.66
2236	2004-03-14	13015	17.65	1.46	19.11
2237	2004-03-18	16545	293.66	24.23	317.89
2238	2004-03-24	9387	34.05	2.81	36.86
2239	2004-03-24	11648	96.28	7.94	104.22
2240	2004-03-30	4514	39.21	3.23	42.44
2241	2004-03-27	14099	246.29	20.32	266.61
2242	2004-03-15	16110	332.90	27.46	360.36
2243	2004-03-18	17684	335.40	27.67	363.07
2244	2004-03-13	10123	223.55	18.44	241.99
2245	2004-03-09	4159	107.03	8.83	115.86
2246	2004-03-16	13951	16.10	1.33	17.43
2247	2004-03-22	3952	379.16	31.28	410.44
2248	2004-03-25	10245	209.49	17.28	226.77
2249	2004-03-22	7129	111.41	9.19	120.60
2250	2004-03-18	9451	98.25	8.11	106.36
2251	2004-03-02	10272	317.60	26.20	343.80
2252	2004-03-12	11873	43.52	3.59	47.11
2253	2004-03-29	15967	381.46	31.47	412.93
2254	2004-03-22	19521	393.40	32.46	425.86
2255	2004-03-30	9052	372.18	30.70	402.88
2256	2004-03-09	5428	228.39	18.84	247.23
2257	2004-03-27	1533	178.68	14.74	193.42
2258	2004-03-28	11570	329.09	27.15	356.24
2259	2004-03-04	4019	141.76	11.70	153.46
2260	2004-03-26	12194	240.01	19.80	259.81
2261	2004-03-03	5460	43.84	3.62	47.46
2262	2004-03-23	12259	331.52	27.35	358.87
2263	2004-03-14	8364	189.57	15.64	205.21
2264	2004-03-05	17736	40.94	3.38	44.32
2265	2004-03-21	4558	258.86	21.36	280.22
2266	2004-03-13	18658	279.89	23.09	302.98
2267	2004-03-07	15769	354.91	29.28	384.19
2268	2004-03-20	3605	225.23	18.58	243.81
2269	2004-03-04	5133	386.38	31.88	418.26
2270	2004-03-18	8183	154.43	12.74	167.17
2271	2004-03-01	15399	74.86	6.18	81.04
2272	2004-03-17	704	260.72	21.51	282.23
2273	2004-03-02	14914	251.63	20.76	272.39
2274	2004-03-07	9265	247.95	20.46	268.41
2275	2004-03-09	1771	179.64	14.82	194.46
2276	2004-03-29	2005	272.04	22.44	294.48
2277	2004-03-02	13550	36.04	2.97	39.01
2278	2004-03-20	18184	147.74	12.19	159.93
2279	2004-03-12	3986	55.71	4.60	60.31
2280	2004-03-31	7912	337.19	27.82	365.01
2281	2004-03-25	9254	239.11	19.73	258.84
2282	2004-03-19	16229	377.93	31.18	409.11
2283	2004-03-12	8999	106.87	8.82	115.69
2284	2004-03-03	3227	33.97	2.80	36.77
2285	2004-03-10	11875	105.10	8.67	113.77
2286	2004-03-07	19241	18.21	1.50	19.71
2287	2004-03-02	18409	386.01	31.85	417.86
2288	2004-03-02	3107	194.44	16.04	210.48
2289	2004-03-12	9538	281.31	23.21	304.52
2290	2004-03-15	6212	112.66	9.29	121.95
2291	2004-03-03	15980	32.51	2.68	35.19
2292	2004-03-12	1433	39.57	3.26	42.83
2293	2004-03-10	13348	109.40	9.03	118.43
2294	2004-03-25	16090	312.78	25.80	338.58
2295	2004-03-30	1305	273.22	22.54	295.76
2296	2004-03-02	3638	264.68	21.84	286.52
2297	2004-03-28	8077	295.24	24.36	319.60
2298	2004-03-13	17697	98.95	8.16	107.11
2299	2004-03-31	15621	229.04	18.90	247.94
2300	2004-03-09	5573	216.92	17.90	234.82
2301	2004-03-23	7039	221.31	18.26	239.57
2302	2004-03-11	8074	129.86	10.71	140.57
2303	2004-03-15	17771	24.90	2.05	26.95
2304	2004-03-29	17503	217.36	17.93	235.29
2305	2004-03-27	17732	20.32	1.68	22.00
2306	2004-03-17	13419	277.20	22.87	300.07
2307	2004-03-05	16537	298.98	24.67	323.65
2308	2004-03-27	11517	242.22	19.98	262.20
2309	2004-03-10	11632	38.31	3.16	41.47
2310	2004-03-25	8976	70.02	5.78	75.80
2311	2004-03-04	13528	121.72	10.04	131.76
2312	2004-03-19	5811	324.69	26.79	351.48
2313	2004-03-13	3375	339.64	28.02	367.66
2314	2004-03-02	3119	168.34	13.89	182.23
2315	2004-03-28	17932	355.46	29.33	384.79
2316	2004-03-14	9940	236.41	19.50	255.91
2317	2004-03-26	9188	318.70	26.29	344.99
2318	2004-03-10	18294	30.91	2.55	33.46
2319	2004-03-13	13234	32.80	2.71	35.51
2320	2004-03-19	17303	132.34	10.92	143.26
2321	2004-03-06	518	33.98	2.80	36.78
2322	2004-03-16	4120	265.49	21.90	287.39
2323	2004-03-21	15619	371.41	30.64	402.05
2324	2004-03-08	12538	180.42	14.88	195.30
2325	2004-03-13	8737	23.72	1.96	25.68
2326	2004-03-03	19956	4.79	0.40	5.19
2327	2004-03-27	1038	129.16	10.66	139.82
2328	2004-03-13	6816	55.23	4.56	59.79
2329	2004-03-23	13220	3.70	0.31	4.01
2330	2004-03-21	7530	144.86	11.95	156.81
2331	2004-03-16	11068	136.52	11.26	147.78
2332	2004-03-08	16331	26.95	2.22	29.17
2333	2004-03-27	13140	202.86	16.74	219.60
2334	2004-03-18	2502	337.46	27.84	365.30
2335	2004-03-05	12285	262.29	21.64	283.93
2336	2004-03-29	3229	158.22	13.05	171.27
2337	2004-03-11	3	39.06	3.22	42.28
2338	2004-03-02	8110	355.71	29.35	385.06
2339	2004-03-30	7191	51.02	4.21	55.23
2340	2004-03-06	11943	287.49	23.72	311.21
2341	2004-03-19	16525	272.57	22.49	295.06
2342	2004-03-07	14035	165.77	13.68	179.45
2343	2004-03-14	1474	13.36	1.10	14.46
2344	2004-03-26	19101	113.13	9.33	122.46
2345	2004-03-31	18220	348.62	28.76	377.38
2346	2004-03-21	7372	172.28	14.21	186.49
2347	2004-03-18	18635	345.08	28.47	373.55
2348	2004-03-30	12023	357.42	29.49	386.91
2349	2004-03-21	237	364.77	30.09	394.86
2350	2004-03-18	15360	290.06	23.93	313.99
2351	2004-03-23	9791	123.81	10.21	134.02
2352	2004-03-07	8022	264.22	21.80	286.02
2353	2004-03-27	11456	127.48	10.52	138.00
2354	2004-03-09	14848	298.11	24.59	322.70
2355	2004-03-01	16965	398.49	32.88	431.37
2356	2004-03-01	8837	257.40	21.24	278.64
2357	2004-03-13	14702	150.36	12.40	162.76
2358	2004-03-26	2525	39.84	3.29	43.13
2359	2004-03-23	9091	158.44	13.07	171.51
2360	2004-03-14	6329	88.12	7.27	95.39
2361	2004-03-23	12609	158.76	13.10	171.86
2362	2004-03-02	18135	29.54	2.44	31.98
2363	2004-03-29	15687	216.35	17.85	234.20
2364	2004-03-19	6635	301.04	24.84	325.88
2365	2004-03-28	1456	3.26	0.27	3.53
2366	2004-03-14	19279	121.34	10.01	131.35
2367	2004-03-23	8403	391.54	32.30	423.84
2368	2004-03-18	10092	106.73	8.81	115.54
2369	2004-03-26	14131	389.65	32.15	421.80
2370	2004-03-31	2331	24.92	2.06	26.98
2371	2004-03-03	14412	142.33	11.74	154.07
2372	2004-03-24	4974	398.37	32.87	431.24
2373	2004-03-16	8062	140.12	11.56	151.68
2374	2004-03-11	3246	54.97	4.54	59.51
2375	2004-03-15	1389	327.85	27.05	354.90
2376	2004-03-11	8372	325.92	26.89	352.81
2377	2004-03-02	18206	200.51	16.54	217.05
2378	2004-03-25	5873	370.03	30.53	400.56
2379	2004-03-07	12384	4.95	0.41	5.36
2380	2004-03-16	11088	121.65	10.04	131.69
2381	2004-03-21	9375	356.14	29.38	385.52
2382	2004-03-12	15932	333.08	27.48	360.56
2383	2004-03-09	5985	77.62	6.40	84.02
2384	2004-03-04	5144	120.12	9.91	130.03
2385	2004-03-26	11556	286.99	23.68	310.67
2386	2004-03-27	20000	96.83	7.99	104.82
2387	2004-03-29	16929	257.24	21.22	278.46
2388	2004-03-01	18069	156.17	12.88	169.05
2389	2004-03-10	7485	188.78	15.57	204.35
2390	2004-03-27	17597	276.17	22.78	298.95
2391	2004-03-27	419	118.15	9.75	127.90
2392	2004-03-24	10714	361.78	29.85	391.63
2393	2004-03-13	4856	95.20	7.85	103.05
2394	2004-03-02	81	292.79	24.16	316.95
2395	2004-03-22	6473	284.15	23.44	307.59
2396	2004-03-27	12916	291.97	24.09	316.06
2397	2004-03-08	16613	381.71	31.49	413.20
2398	2004-03-13	14393	85.00	7.01	92.01
2399	2004-03-24	2211	372.00	30.69	402.69
2400	2004-03-27	3735	355.51	29.33	384.84
2401	2004-03-21	18374	87.92	7.25	95.17
2402	2004-03-08	1911	118.66	9.79	128.45
2403	2004-03-27	13445	162.75	13.43	176.18
2404	2004-03-30	18153	377.09	31.11	408.20
2405	2004-03-02	600	119.00	9.82	128.82
2406	2004-03-21	19043	202.28	16.69	218.97
2407	2004-03-01	2863	32.88	2.71	35.59
2408	2004-03-20	15908	216.60	17.87	234.47
2409	2004-03-01	7806	19.80	1.63	21.43
2410	2004-03-11	17749	109.50	9.03	118.53
2411	2004-03-29	16246	341.71	28.19	369.90
2412	2004-03-03	137	117.31	9.68	126.99
2413	2004-03-21	3238	295.86	24.41	320.27
2414	2004-03-03	18091	123.87	10.22	134.09
2415	2004-03-21	19143	282.07	23.27	305.34
2416	2004-03-27	3904	178.17	14.70	192.87
2417	2004-03-08	7486	198.88	16.41	215.29
2418	2004-03-05	15450	317.32	26.18	343.50
2419	2004-03-17	4006	394.27	32.53	426.80
2420	2004-03-22	16783	250.36	20.65	271.01
2421	2004-03-07	18012	17.30	1.43	18.73
2422	2004-03-03	11058	253.01	20.87	273.88
2423	2004-03-03	6272	178.92	14.76	193.68
2424	2004-03-08	17471	278.79	23.00	301.79
2425	2004-03-22	15062	351.79	29.02	380.81
2426	2004-03-01	14865	312.73	25.80	338.53
2427	2004-03-24	6258	178.94	14.76	193.70
2428	2004-03-10	6105	296.68	24.48	321.16
2429	2004-03-12	13874	396.51	32.71	429.22
2430	2004-03-29	19079	240.12	19.81	259.93
2431	2004-03-25	12363	257.89	21.28	279.17
2432	2004-03-20	5891	242.11	19.97	262.08
2433	2004-03-23	11280	123.98	10.23	134.21
2434	2004-03-14	9288	346.62	28.60	375.22
2435	2004-03-01	6180	398.85	32.91	431.76
2436	2004-03-22	6331	231.74	19.12	250.86
2437	2004-03-17	10515	121.61	10.03	131.64
2438	2004-03-29	7900	69.80	5.76	75.56
2439	2004-03-28	8215	159.08	13.12	172.20
2440	2004-03-14	6109	132.45	10.93	143.38
2441	2004-03-31	5213	364.68	30.09	394.77
2442	2004-03-07	9315	88.18	7.27	95.45
2443	2004-03-22	12511	309.68	25.55	335.23
2444	2004-03-29	1364	396.24	32.69	428.93
2445	2004-03-13	12967	130.67	10.78	141.45
2446	2004-03-30	7808	366.33	30.22	396.55
2447	2004-03-23	15094	259.44	21.40	280.84
2448	2004-03-13	7877	91.98	7.59	99.57
2449	2004-03-24	2535	231.26	19.08	250.34
2450	2004-03-29	14588	325.14	26.82	351.96
2451	2004-03-07	16401	194.69	16.06	210.75
2452	2004-03-25	7350	237.58	19.60	257.18
2453	2004-03-08	3660	314.60	25.95	340.55
2454	2004-03-24	15554	122.32	10.09	132.41
2455	2004-03-11	15189	18.86	1.56	20.42
2456	2004-03-14	10625	308.17	25.42	333.59
2457	2004-03-25	6776	274.25	22.63	296.88
2458	2004-03-17	14955	153.59	12.67	166.26
2459	2004-03-18	13317	143.19	11.81	155.00
2460	2004-03-05	4411	90.83	7.49	98.32
2461	2004-03-09	13630	398.25	32.86	431.11
2462	2004-03-09	17596	64.65	5.33	69.98
2463	2004-03-14	2772	330.27	27.25	357.52
2464	2004-03-14	11234	326.03	26.90	352.93
2465	2004-03-02	15879	49.33	4.07	53.40
2466	2004-03-06	10992	193.44	15.96	209.40
2467	2004-03-05	15347	232.22	19.16	251.38
2468	2004-03-06	19747	59.11	4.88	63.99
2469	2004-03-26	12784	357.25	29.47	386.72
2470	2004-03-17	3817	0.13	0.01	0.14
2471	2004-03-30	6509	265.10	21.87	286.97
2472	2004-03-25	11283	214.30	17.68	231.98
2473	2004-03-12	4497	237.20	19.57	256.77
2474	2004-03-25	19967	77.19	6.37	83.56
2475	2004-03-29	18005	165.61	13.66	179.27
2476	2004-03-28	17438	131.70	10.87	142.57
2477	2004-03-20	8143	341.45	28.17	369.62
2478	2004-03-19	14490	2.38	0.20	2.58
2479	2004-03-13	18084	145.53	12.01	157.54
2480	2004-03-24	7440	45.06	3.72	48.78
2481	2004-03-02	1252	95.55	7.88	103.43
2482	2004-03-19	4153	105.93	8.74	114.67
2483	2004-03-17	4929	129.00	10.64	139.64
2484	2004-03-29	15564	239.42	19.75	259.17
2485	2004-03-29	12928	287.00	23.68	310.68
2486	2004-03-28	14187	283.99	23.43	307.42
2487	2004-03-18	12494	97.86	8.07	105.93
2488	2004-03-06	16278	5.27	0.43	5.70
2489	2004-03-19	17191	88.13	7.27	95.40
2490	2004-03-10	348	89.55	7.39	96.94
2491	2004-03-29	19584	96.26	7.94	104.20
2492	2004-03-14	5821	79.32	6.54	85.86
2493	2004-03-24	4580	135.94	11.22	147.16
2494	2004-03-28	12129	6.81	0.56	7.37
2495	2004-03-14	10280	50.51	4.17	54.68
2496	2004-03-27	2976	131.93	10.88	142.81
2497	2004-03-01	9794	250.62	20.68	271.30
2498	2004-03-24	13009	296.55	24.47	321.02
2499	2004-03-14	15301	33.00	2.72	35.72
2500	2004-03-10	16974	289.86	23.91	313.77
2501	2004-03-28	16044	307.79	25.39	333.18
2502	2004-03-04	17809	13.64	1.13	14.77
2503	2004-03-16	13568	54.85	4.53	59.38
2504	2004-03-29	12090	40.54	3.34	43.88
2505	2004-03-11	9577	18.44	1.52	19.96
2506	2004-03-16	12897	104.79	8.65	113.44
2507	2004-03-28	12673	38.22	3.15	41.37
2508	2004-03-08	14219	108.42	8.94	117.36
2509	2004-03-14	590	27.98	2.31	30.29
2510	2004-03-06	1667	283.47	23.39	306.86
2511	2004-03-06	9538	243.06	20.05	263.11
2512	2004-03-04	637	176.04	14.52	190.56
2513	2004-03-17	12205	138.41	11.42	149.83
2514	2004-03-05	18808	196.15	16.18	212.33
2515	2004-03-14	13452	54.91	4.53	59.44
2516	2004-03-14	6222	228.42	18.84	247.26
2517	2004-03-11	15602	323.81	26.71	350.52
2518	2004-03-02	8360	295.50	24.38	319.88
2519	2004-03-29	18531	288.66	23.81	312.47
2520	2004-03-10	4241	28.77	2.37	31.14
2521	2004-03-18	13034	40.95	3.38	44.33
2522	2004-03-02	12154	295.93	24.41	320.34
2523	2004-03-30	2537	270.53	22.32	292.85
2524	2004-03-23	17933	122.08	10.07	132.15
2525	2004-03-08	16211	376.65	31.07	407.72
2526	2004-03-16	5697	117.04	9.66	126.70
2527	2004-03-11	15780	77.78	6.42	84.20
2528	2004-03-20	664	380.23	31.37	411.60
2529	2004-03-17	15207	71.80	5.92	77.72
2530	2004-03-24	12850	26.58	2.19	28.77
2531	2004-03-08	14058	331.08	27.31	358.39
2532	2004-03-14	12747	129.59	10.69	140.28
2533	2004-03-27	8092	13.36	1.10	14.46
2534	2004-03-04	1234	213.73	17.63	231.36
2535	2004-03-27	17479	41.89	3.46	45.35
2536	2004-03-05	17545	94.74	7.82	102.56
2537	2004-03-28	11872	177.14	14.61	191.75
2538	2004-03-11	16782	286.27	23.62	309.89
2539	2004-03-21	800	64.28	5.30	69.58
2540	2004-03-25	5962	16.79	1.39	18.18
2541	2004-03-29	10568	66.34	5.47	71.81
2542	2004-03-19	16847	343.57	28.34	371.91
2543	2004-03-22	3131	38.34	3.16	41.50
2544	2004-03-06	12026	115.60	9.54	125.14
2545	2004-03-12	17244	97.89	8.08	105.97
2546	2004-03-23	4031	182.96	15.09	198.05
2547	2004-03-30	14189	320.42	26.43	346.85
2548	2004-03-30	10087	75.27	6.21	81.48
2549	2004-03-09	1170	62.57	5.16	67.73
2550	2004-03-18	3690	315.72	26.05	341.77
2551	2004-03-10	7474	70.17	5.79	75.96
2552	2004-03-03	16411	279.28	23.04	302.32
2553	2004-03-01	15718	85.55	7.06	92.61
2554	2004-03-21	6759	142.26	11.74	154.00
2555	2004-03-24	3775	391.89	32.33	424.22
2556	2004-03-19	10292	191.18	15.77	206.95
2557	2004-03-14	2222	302.58	24.96	327.54
2558	2004-03-14	14599	382.64	31.57	414.21
2559	2004-03-12	19919	178.20	14.70	192.90
2560	2004-03-22	17050	376.94	31.10	408.04
2561	2004-03-10	3640	24.01	1.98	25.99
2562	2004-03-02	3735	140.48	11.59	152.07
2563	2004-03-08	6219	249.54	20.59	270.13
2564	2004-03-01	1259	160.14	13.21	173.35
2565	2004-03-06	12257	30.11	2.48	32.59
2566	2004-03-06	3242	323.58	26.70	350.28
2567	2004-03-17	14130	117.30	9.68	126.98
2568	2004-03-27	19428	256.95	21.20	278.15
2569	2004-03-10	5018	319.45	26.35	345.80
2570	2004-03-30	4193	198.89	16.41	215.30
2571	2004-03-21	5781	86.84	7.16	94.00
2572	2004-03-24	2074	156.40	12.90	169.30
2573	2004-03-05	14785	209.07	17.25	226.32
2574	2004-03-15	11522	65.26	5.38	70.64
2575	2004-03-19	7334	210.97	17.41	228.38
2576	2004-03-23	19933	247.70	20.44	268.14
2577	2004-03-08	4291	179.46	14.81	194.27
2578	2004-03-02	15865	74.13	6.12	80.25
2579	2004-03-18	9685	187.36	15.46	202.82
2580	2004-03-21	7561	244.27	20.15	264.42
2581	2004-03-21	3482	43.67	3.60	47.27
2582	2004-03-08	5311	203.22	16.77	219.99
2583	2004-03-02	8148	63.12	5.21	68.33
2584	2004-03-01	17842	16.01	1.32	17.33
2585	2004-03-27	4281	126.61	10.45	137.06
2586	2004-03-09	2355	383.02	31.60	414.62
2587	2004-03-07	2784	277.12	22.86	299.98
2588	2004-03-09	10799	187.17	15.44	202.61
2589	2004-03-16	18947	5.28	0.44	5.72
2590	2004-03-05	3349	115.50	9.53	125.03
2591	2004-03-10	12899	228.37	18.84	247.21
2592	2004-03-24	235	207.33	17.10	224.43
2593	2004-03-24	5768	289.52	23.89	313.41
2594	2004-03-25	4320	46.05	3.80	49.85
2595	2004-03-28	17300	156.71	12.93	169.64
2596	2004-03-13	14835	347.53	28.67	376.20
2597	2004-03-24	17453	352.33	29.07	381.40
2598	2004-03-01	8276	224.15	18.49	242.64
2599	2004-03-30	14611	361.18	29.80	390.98
2600	2004-03-18	8275	249.53	20.59	270.12
2601	2004-03-25	2027	202.06	16.67	218.73
2602	2004-03-17	17055	239.65	19.77	259.42
2603	2004-03-12	9421	84.43	6.97	91.40
2604	2004-03-30	19674	312.12	25.75	337.87
2605	2004-03-28	2021	52.71	4.35	57.06
2606	2004-03-08	15016	267.50	22.07	289.57
2607	2004-03-24	14067	326.67	26.95	353.62
2608	2004-03-10	4503	23.12	1.91	25.03
2609	2004-03-28	6745	362.18	29.88	392.06
2610	2004-03-24	8747	92.61	7.64	100.25
2611	2004-03-18	8272	368.53	30.40	398.93
2612	2004-03-27	11439	307.03	25.33	332.36
2613	2004-03-02	11792	245.71	20.27	265.98
2614	2004-03-08	2500	178.40	14.72	193.12
2615	2004-03-13	917	199.26	16.44	215.70
2616	2004-03-23	14897	164.22	13.55	177.77
2617	2004-03-21	18838	155.27	12.81	168.08
2618	2004-03-24	8607	308.12	25.42	333.54
2619	2004-03-27	18312	35.38	2.92	38.30
2620	2004-03-02	7648	350.15	28.89	379.04
2621	2004-03-30	17751	150.31	12.40	162.71
2622	2004-03-19	8098	93.63	7.72	101.35
2623	2004-03-24	9315	316.72	26.13	342.85
2624	2004-03-08	8835	186.84	15.41	202.25
2625	2004-03-06	4774	150.43	12.41	162.84
2626	2004-03-30	16272	175.19	14.45	189.64
2627	2004-03-11	17481	314.51	25.95	340.46
2628	2004-03-12	12179	283.54	23.39	306.93
2629	2004-03-03	16982	396.59	32.72	429.31
2630	2004-03-19	18440	38.70	3.19	41.89
2631	2004-03-28	6257	314.44	25.94	340.38
2632	2004-03-27	18852	323.84	26.72	350.56
2633	2004-03-01	12392	285.00	23.51	308.51
2634	2004-03-26	1557	66.30	5.47	71.77
2635	2004-03-05	18468	133.28	11.00	144.28
2636	2004-03-09	7361	64.91	5.36	70.27
2637	2004-03-10	14621	55.69	4.59	60.28
2638	2004-03-18	13452	126.32	10.42	136.74
2639	2004-03-08	6873	376.34	31.05	407.39
2640	2004-03-08	11564	16.32	1.35	17.67
2641	2004-03-19	6587	85.04	7.02	92.06
2642	2004-03-10	448	201.85	16.65	218.50
2643	2004-03-04	7677	228.56	18.86	247.42
2644	2004-03-28	6680	169.97	14.02	183.99
2645	2004-03-19	6120	303.77	25.06	328.83
2646	2004-03-09	6427	381.04	31.44	412.48
2647	2004-03-07	15224	261.37	21.56	282.93
2648	2004-03-03	4878	144.76	11.94	156.70
2649	2004-03-13	18719	262.79	21.68	284.47
2650	2004-03-05	2655	46.36	3.82	50.18
2651	2004-03-20	12530	358.53	29.58	388.11
2652	2004-03-26	11809	385.75	31.82	417.57
2653	2004-03-06	8982	265.81	21.93	287.74
2654	2004-03-22	14388	277.11	22.86	299.97
2655	2004-03-31	13947	279.09	23.02	302.11
2656	2004-03-29	14893	109.80	9.06	118.86
2657	2004-03-05	3118	62.07	5.12	67.19
2658	2004-03-23	14443	80.38	6.63	87.01
2659	2004-03-26	6531	347.95	28.71	376.66
2660	2004-03-22	6185	273.78	22.59	296.37
2661	2004-03-10	4231	289.74	23.90	313.64
2662	2004-03-01	2627	96.37	7.95	104.32
2663	2004-03-31	5666	14.49	1.20	15.69
2664	2004-03-25	637	197.08	16.26	213.34
2665	2004-03-30	18922	134.27	11.08	145.35
2666	2004-03-23	10806	141.63	11.68	153.31
2667	2004-03-08	13557	365.92	30.19	396.11
2668	2004-03-18	12174	94.95	7.83	102.78
2669	2004-03-25	16234	357.88	29.53	387.41
2670	2004-03-22	5990	259.16	21.38	280.54
2671	2004-03-01	15393	136.37	11.25	147.62
2672	2004-03-10	11923	179.02	14.77	193.79
2673	2004-03-12	10555	45.41	3.75	49.16
2674	2004-03-16	14385	149.98	12.37	162.35
2675	2004-03-29	17980	187.24	15.45	202.69
2676	2004-03-02	2370	198.00	16.34	214.34
2677	2004-03-30	4867	246.75	20.36	267.11
2678	2004-03-05	19873	322.18	26.58	348.76
2679	2004-03-15	2045	353.14	29.13	382.27
2680	2004-03-04	15472	251.81	20.77	272.58
2681	2004-03-05	17856	212.56	17.54	230.10
2682	2004-03-11	7847	375.15	30.95	406.10
2683	2004-03-13	9902	89.92	7.42	97.34
2684	2004-03-26	10452	124.41	10.26	134.67
2685	2004-03-02	12530	227.61	18.78	246.39
2686	2004-03-30	11352	265.40	21.90	287.30
2687	2004-03-24	16705	161.00	13.28	174.28
2688	2004-03-13	6413	176.41	14.55	190.96
2689	2004-03-16	11325	92.72	7.65	100.37
2690	2004-03-14	15061	100.47	8.29	108.76
2691	2004-03-27	2099	201.95	16.66	218.61
2692	2004-03-21	8765	120.11	9.91	130.02
2693	2004-03-23	18610	124.80	10.30	135.10
2694	2004-03-26	13595	21.95	1.81	23.76
2695	2004-03-16	9488	277.71	22.91	300.62
2696	2004-03-17	5794	218.56	18.03	236.59
2697	2004-03-02	14578	228.69	18.87	247.56
2698	2004-03-21	14650	363.49	29.99	393.48
2699	2004-03-10	15663	240.51	19.84	260.35
2700	2004-03-16	11435	132.58	10.94	143.52
2701	2004-03-06	19317	334.84	27.62	362.46
2702	2004-03-20	10691	316.34	26.10	342.44
2703	2004-03-21	19224	31.53	2.60	34.13
2704	2004-03-07	14633	301.67	24.89	326.56
2705	2004-03-03	425	168.38	13.89	182.27
2706	2004-03-18	1767	207.84	17.15	224.99
2707	2004-03-15	12684	176.27	14.54	190.81
2708	2004-03-25	8002	82.58	6.81	89.39
2709	2004-03-12	17527	156.35	12.90	169.25
2710	2004-03-23	13991	47.66	3.93	51.59
2711	2004-03-29	17454	4.84	0.40	5.24
2712	2004-03-02	4643	103.50	8.54	112.04
2713	2004-03-04	3760	192.61	15.89	208.50
2714	2004-03-17	14465	393.19	32.44	425.63
2715	2004-03-08	8361	273.11	22.53	295.64
2716	2004-03-30	1010	55.05	4.54	59.59
2717	2004-03-10	5754	266.15	21.96	288.11
2718	2004-03-04	7856	15.36	1.27	16.63
2719	2004-03-20	8936	238.63	19.69	258.32
2720	2004-03-11	17795	76.11	6.28	82.39
2721	2004-03-14	19887	80.91	6.68	87.59
2722	2004-03-24	18465	112.79	9.31	122.10
2723	2004-03-19	9413	203.72	16.81	220.53
2724	2004-03-05	15021	75.63	6.24	81.87
2725	2004-03-25	10296	355.82	29.36	385.18
2726	2004-03-29	2620	338.24	27.90	366.14
2727	2004-03-09	303	126.84	10.46	137.30
2728	2004-03-24	16823	103.17	8.51	111.68
2729	2004-03-25	8519	342.75	28.28	371.03
2730	2004-03-26	19159	49.19	4.06	53.25
2731	2004-03-16	10950	59.90	4.94	64.84
2732	2004-03-14	17773	210.99	17.41	228.40
2733	2004-03-19	9556	118.61	9.79	128.40
2734	2004-03-07	16345	314.37	25.94	340.31
2735	2004-03-28	18928	76.76	6.33	83.09
2736	2004-03-07	17544	243.01	20.05	263.06
2737	2004-03-24	16705	34.76	2.87	37.63
2738	2004-03-09	16831	175.96	14.52	190.48
2739	2004-03-27	7519	49.51	4.08	53.59
2740	2004-03-06	11701	263.59	21.75	285.34
2741	2004-03-11	12343	107.06	8.83	115.89
2742	2004-03-02	9266	361.72	29.84	391.56
2743	2004-03-20	7406	119.91	9.89	129.80
2744	2004-03-28	17886	123.01	10.15	133.16
2745	2004-03-03	13554	390.24	32.19	422.43
2746	2004-03-27	3429	187.43	15.46	202.89
2747	2004-03-01	3939	183.73	15.16	198.89
2748	2004-03-27	10697	213.13	17.58	230.71
2749	2004-03-30	18098	188.54	15.55	204.09
2750	2004-03-03	6189	220.76	18.21	238.97
2751	2004-03-02	13072	197.34	16.28	213.62
2752	2004-03-24	5240	168.57	13.91	182.48
2753	2004-03-11	2741	94.74	7.82	102.56
2754	2004-03-27	711	335.92	27.71	363.63
2755	2004-03-01	14182	23.95	1.98	25.93
2756	2004-03-01	8032	105.35	8.69	114.04
2757	2004-03-10	1254	339.06	27.97	367.03
2758	2004-03-07	19143	193.24	15.94	209.18
2759	2004-03-19	127	96.99	8.00	104.99
2760	2004-03-15	10077	248.43	20.50	268.93
2761	2004-03-24	12939	367.21	30.29	397.50
2762	2004-03-26	18114	376.83	31.09	407.92
2763	2004-03-23	8912	252.03	20.79	272.82
2764	2004-03-25	19196	125.94	10.39	136.33
2765	2004-03-06	13226	194.57	16.05	210.62
2766	2004-03-28	418	29.75	2.45	32.20
2767	2004-03-25	9444	186.61	15.40	202.01
2768	2004-03-22	7089	330.01	27.23	357.24
2769	2004-03-28	18677	143.75	11.86	155.61
2770	2004-03-26	15785	243.39	20.08	263.47
2771	2004-03-16	16329	145.06	11.97	157.03
2772	2004-03-17	7844	122.72	10.12	132.84
2773	2004-03-17	16494	327.05	26.98	354.03
2774	2004-03-15	12280	285.86	23.58	309.44
2775	2004-03-19	268	313.06	25.83	338.89
2776	2004-03-06	19028	262.91	21.69	284.60
2777	2004-03-25	7960	58.05	4.79	62.84
2778	2004-03-01	16974	290.52	23.97	314.49
2779	2004-03-26	17676	188.92	15.59	204.51
2780	2004-03-11	4989	145.94	12.04	157.98
2781	2004-03-14	12502	143.82	11.87	155.69
2782	2004-03-15	17479	215.48	17.78	233.26
2783	2004-03-31	4946	4.00	0.33	4.33
2784	2004-03-01	8636	261.76	21.60	283.36
2785	2004-03-09	16917	332.95	27.47	360.42
2786	2004-03-10	4815	71.87	5.93	77.80
2787	2004-03-07	874	243.34	20.08	263.42
2788	2004-03-31	14649	202.44	16.70	219.14
2789	2004-03-18	15391	256.25	21.14	277.39
2790	2004-03-04	9646	79.11	6.53	85.64
2791	2004-03-16	10832	376.11	31.03	407.14
2792	2004-03-04	4897	228.66	18.86	247.52
2793	2004-03-24	10641	255.62	21.09	276.71
2794	2004-03-15	13774	173.98	14.35	188.33
2795	2004-03-19	17925	134.71	11.11	145.82
2796	2004-03-04	12777	304.29	25.10	329.39
2797	2004-03-01	16166	259.09	21.37	280.46
2798	2004-03-19	4321	394.68	32.56	427.24
2799	2004-03-18	1418	15.61	1.29	16.90
2800	2004-03-22	11842	314.90	25.98	340.88
2801	2004-03-03	9159	346.92	28.62	375.54
2802	2004-03-01	10688	192.76	15.90	208.66
2803	2004-03-11	5344	53.25	4.39	57.64
2804	2004-03-14	11808	99.24	8.19	107.43
2805	2004-03-16	4476	138.19	11.40	149.59
2806	2004-03-04	19915	84.37	6.96	91.33
2807	2004-03-05	627	260.90	21.52	282.42
2808	2004-03-16	6526	196.81	16.24	213.05
2809	2004-03-08	4792	168.13	13.87	182.00
2810	2004-03-24	2139	76.28	6.29	82.57
2811	2004-03-30	6773	377.58	31.15	408.73
2812	2004-03-03	4574	207.90	17.15	225.05
2813	2004-03-23	19484	351.60	29.01	380.61
2814	2004-03-28	532	263.24	21.72	284.96
2815	2004-03-25	9024	159.88	13.19	173.07
2816	2004-03-11	14365	210.62	17.38	228.00
2817	2004-03-06	8941	22.17	1.83	24.00
2818	2004-03-13	6476	203.06	16.75	219.81
2819	2004-03-31	6580	96.91	8.00	104.91
2820	2004-03-20	10921	74.08	6.11	80.19
2821	2004-03-11	6151	192.97	15.92	208.89
2822	2004-03-14	14062	131.13	10.82	141.95
2823	2004-03-08	8073	319.67	26.37	346.04
2824	2004-03-16	13455	222.59	18.36	240.95
2825	2004-03-30	16356	258.86	21.36	280.22
2826	2004-03-01	4800	275.36	22.72	298.08
2827	2004-03-09	3809	375.93	31.01	406.94
2828	2004-03-03	12517	210.27	17.35	227.62
2829	2004-03-27	19820	176.51	14.56	191.07
2830	2004-03-12	2509	234.16	19.32	253.48
2831	2004-03-05	19202	72.63	5.99	78.62
2832	2004-03-07	4808	124.79	10.30	135.09
2833	2004-03-25	4661	216.35	17.85	234.20
2834	2004-03-09	7370	354.56	29.25	383.81
2835	2004-03-15	9764	321.21	26.50	347.71
2836	2004-03-06	16717	201.10	16.59	217.69
2837	2004-03-05	4107	22.27	1.84	24.11
2838	2004-03-24	8180	21.73	1.79	23.52
2839	2004-03-23	9169	129.93	10.72	140.65
2840	2004-03-24	2818	177.05	14.61	191.66
2841	2004-03-27	6283	58.58	4.83	63.41
2842	2004-03-17	1517	216.68	17.88	234.56
2843	2004-03-20	6934	359.01	29.62	388.63
2844	2004-03-11	13097	58.83	4.85	63.68
2845	2004-03-29	13856	216.05	17.82	233.87
2846	2004-03-16	16168	167.81	13.84	181.65
2847	2004-03-21	16334	306.57	25.29	331.86
2848	2004-03-31	8672	149.68	12.35	162.03
2849	2004-03-29	1050	338.08	27.89	365.97
2850	2004-03-04	16455	286.57	23.64	310.21
2851	2004-03-16	15079	392.70	32.40	425.10
2852	2004-03-23	19425	129.01	10.64	139.65
2853	2004-03-27	4341	185.82	15.33	201.15
2854	2004-03-18	12550	392.17	32.35	424.52
2855	2004-03-15	5464	96.60	7.97	104.57
2856	2004-03-07	7185	343.61	28.35	371.96
2857	2004-03-10	10884	288.44	23.80	312.24
2858	2004-03-26	7360	152.28	12.56	164.84
2859	2004-03-20	4640	394.17	32.52	426.69
2860	2004-03-09	19509	77.03	6.35	83.38
2861	2004-03-07	3762	133.12	10.98	144.10
2862	2004-03-07	2023	37.97	3.13	41.10
2863	2004-03-31	12254	78.83	6.50	85.33
2864	2004-03-08	8426	273.19	22.54	295.73
2865	2004-03-07	9946	231.76	19.12	250.88
2866	2004-03-27	14471	163.38	13.48	176.86
2867	2004-03-10	4994	23.31	1.92	25.23
2868	2004-03-06	16118	202.87	16.74	219.61
2869	2004-03-31	16279	398.15	32.85	431.00
2870	2004-03-29	17393	267.73	22.09	289.82
2871	2004-03-09	11148	168.51	13.90	182.41
2872	2004-03-28	18756	156.13	12.88	169.01
2873	2004-03-07	2628	301.52	24.88	326.40
2874	2004-03-27	18708	155.28	12.81	168.09
2875	2004-03-16	1241	100.36	8.28	108.64
2876	2004-03-25	8243	322.13	26.58	348.71
2877	2004-03-21	10052	123.16	10.16	133.32
2878	2004-03-04	16482	72.24	5.96	78.20
2879	2004-03-31	15562	284.31	23.46	307.77
2880	2004-03-24	102	295.04	24.34	319.38
2881	2004-03-23	17068	320.70	26.46	347.16
2882	2004-03-17	183	81.28	6.71	87.99
2883	2004-03-16	14889	361.46	29.82	391.28
2884	2004-03-20	7857	90.32	7.45	97.77
2885	2004-03-08	12639	0.34	0.03	0.37
2886	2004-03-20	12186	292.67	24.15	316.82
2887	2004-03-27	3003	75.84	6.26	82.10
2888	2004-03-29	16814	42.15	3.48	45.63
2889	2004-03-31	12005	224.67	18.54	243.21
2890	2004-03-27	12554	267.04	22.03	289.07
2891	2004-03-11	14621	240.11	19.81	259.92
2892	2004-03-20	7179	139.50	11.51	151.01
2893	2004-03-20	19485	72.15	5.95	78.10
2894	2004-03-06	10218	391.67	32.31	423.98
2895	2004-03-25	3241	74.23	6.12	80.35
2896	2004-03-17	12091	163.66	13.50	177.16
2897	2004-03-23	953	161.44	13.32	174.76
2898	2004-03-18	8435	2.12	0.17	2.29
2899	2004-03-01	1042	63.76	5.26	69.02
2900	2004-03-15	18377	247.35	20.41	267.76
2901	2004-03-26	19350	54.23	4.47	58.70
2902	2004-03-24	7523	379.21	31.28	410.49
2903	2004-03-27	16453	186.26	15.37	201.63
2904	2004-03-10	883	366.84	30.26	397.10
2905	2004-03-31	16631	146.43	12.08	158.51
2906	2004-03-21	367	3.84	0.32	4.16
2907	2004-03-18	5318	130.54	10.77	141.31
2908	2004-03-12	10542	221.37	18.26	239.63
2909	2004-03-04	15032	66.64	5.50	72.14
2910	2004-03-17	9096	192.71	15.90	208.61
2911	2004-03-09	18662	326.47	26.93	353.40
2912	2004-03-15	7696	137.29	11.33	148.62
2913	2004-03-10	15384	203.70	16.81	220.51
2914	2004-03-01	1779	296.46	24.46	320.92
2915	2004-03-25	4463	124.27	10.25	134.52
2916	2004-03-30	13127	245.27	20.23	265.50
2917	2004-03-15	6839	75.17	6.20	81.37
2918	2004-03-26	12289	347.99	28.71	376.70
2919	2004-03-02	17982	77.58	6.40	83.98
2920	2004-03-30	12990	187.20	15.44	202.64
2921	2004-03-26	8366	345.28	28.49	373.77
2922	2004-03-22	17980	278.77	23.00	301.77
2923	2004-03-15	8823	43.53	3.59	47.12
2924	2004-03-20	1796	365.37	30.14	395.51
2925	2004-03-16	3087	230.92	19.05	249.97
2926	2004-03-13	9429	90.91	7.50	98.41
2927	2004-03-05	5281	114.49	9.45	123.94
2928	2004-03-21	1953	273.85	22.59	296.44
2929	2004-03-11	18338	11.84	0.98	12.82
2930	2004-03-21	18119	253.05	20.88	273.93
2931	2004-03-20	9084	38.40	3.17	41.57
2932	2004-03-07	7167	268.74	22.17	290.91
2933	2004-03-14	9423	262.84	21.68	284.52
2934	2004-03-27	17090	54.68	4.51	59.19
2935	2004-03-02	5257	102.02	8.42	110.44
2936	2004-03-23	7677	66.57	5.49	72.06
2937	2004-03-01	18271	195.92	16.16	212.08
2938	2004-03-12	11370	118.17	9.75	127.92
2939	2004-03-11	11539	244.11	20.14	264.25
2940	2004-03-23	10090	162.85	13.44	176.29
2941	2004-03-20	5230	40.94	3.38	44.32
2942	2004-03-14	10209	74.11	6.11	80.22
2943	2004-03-18	6073	77.28	6.38	83.66
2944	2004-03-03	3852	181.73	14.99	196.72
2945	2004-03-08	14845	80.87	6.67	87.54
2946	2004-03-02	5304	16.58	1.37	17.95
2947	2004-03-23	12234	216.57	17.87	234.44
2948	2004-03-11	2496	269.06	22.20	291.26
2949	2004-03-22	8823	339.77	28.03	367.80
2950	2004-03-05	9697	304.78	25.14	329.92
2951	2004-03-30	3619	335.17	27.65	362.82
2952	2004-03-27	8505	149.41	12.33	161.74
2953	2004-03-21	2077	126.35	10.42	136.77
2954	2004-03-10	16474	368.11	30.37	398.48
2955	2004-03-05	2457	371.88	30.68	402.56
2956	2004-03-18	15946	333.19	27.49	360.68
2957	2004-03-18	3700	26.58	2.19	28.77
2958	2004-03-12	3520	67.39	5.56	72.95
2959	2004-03-05	18729	381.92	31.51	413.43
2960	2004-03-05	324	205.44	16.95	222.39
2961	2004-03-10	1629	147.81	12.19	160.00
2962	2004-03-07	4034	14.03	1.16	15.19
2963	2004-03-23	7016	237.95	19.63	257.58
2964	2004-03-13	13952	36.67	3.03	39.70
2965	2004-03-10	15877	339.64	28.02	367.66
2966	2004-03-05	6024	350.07	28.88	378.95
2967	2004-03-31	2436	347.25	28.65	375.90
2968	2004-03-09	2055	240.08	19.81	259.89
2969	2004-03-20	4787	114.30	9.43	123.73
2970	2004-03-23	13444	165.71	13.67	179.38
2971	2004-03-13	13445	58.65	4.84	63.49
2972	2004-03-28	15775	178.15	14.70	192.85
2973	2004-03-27	7459	112.54	9.28	121.82
2974	2004-03-05	15067	133.97	11.05	145.02
2975	2004-03-10	10615	316.01	26.07	342.08
2976	2004-03-10	10965	41.04	3.39	44.43
2977	2004-03-17	9304	91.87	7.58	99.45
2978	2004-03-20	12333	334.13	27.57	361.70
2979	2004-03-26	4509	149.52	12.34	161.86
2980	2004-03-06	19458	185.09	15.27	200.36
2981	2004-03-16	18539	377.48	31.14	408.62
2982	2004-03-13	15223	226.10	18.65	244.75
2983	2004-03-21	19780	291.58	24.06	315.64
2984	2004-03-16	2080	56.12	4.63	60.75
2985	2004-03-31	4786	128.13	10.57	138.70
2986	2004-03-19	2554	255.04	21.04	276.08
2987	2004-03-05	18435	230.36	19.00	249.36
2988	2004-03-06	5235	55.90	4.61	60.51
2989	2004-03-15	13927	136.30	11.24	147.54
2990	2004-03-03	12110	45.34	3.74	49.08
2991	2004-03-24	5109	59.87	4.94	64.81
2992	2004-03-25	19645	184.90	15.25	200.15
2993	2004-03-16	3724	21.85	1.80	23.65
2994	2004-03-03	6518	129.10	10.65	139.75
2995	2004-03-11	11254	24.09	1.99	26.08
2996	2004-03-31	9921	53.98	4.45	58.43
2997	2004-03-01	10150	245.01	20.21	265.22
2998	2004-03-13	7960	345.25	28.48	373.73
2999	2004-03-11	2305	263.76	21.76	285.52
3000	2004-03-05	3666	108.74	8.97	117.71
3001	2004-04-30	12411	289.62	23.89	313.51
3002	2004-04-08	11537	154.16	12.72	166.88
3003	2004-04-14	7620	293.76	24.24	318.00
3004	2004-04-16	4492	95.39	7.87	103.26
3005	2004-04-14	12752	247.97	20.46	268.43
3006	2004-04-07	13061	224.54	18.52	243.06
3007	2004-04-02	3118	123.23	10.17	133.40
3008	2004-04-14	4076	194.62	16.06	210.68
3009	2004-04-13	6118	80.18	6.61	86.79
3010	2004-04-08	6574	323.64	26.70	350.34
3011	2004-04-10	5625	355.55	29.33	384.88
3012	2004-04-21	15110	150.13	12.39	162.52
3013	2004-04-07	18597	257.80	21.27	279.07
3014	2004-04-11	15965	325.55	26.86	352.41
3015	2004-04-28	6882	341.80	28.20	370.00
3016	2004-04-19	7763	170.01	14.03	184.04
3017	2004-04-19	9778	1.44	0.12	1.56
3018	2004-04-22	5287	102.90	8.49	111.39
3019	2004-04-21	13720	301.52	24.88	326.40
3020	2004-04-03	12069	272.24	22.46	294.70
3021	2004-04-09	969	39.47	3.26	42.73
3022	2004-04-07	8192	211.48	17.45	228.93
3023	2004-04-20	17819	69.90	5.77	75.67
3024	2004-04-21	1465	34.40	2.84	37.24
3025	2004-04-30	16463	119.01	9.82	128.83
3026	2004-04-22	886	167.48	13.82	181.30
3027	2004-04-04	12097	380.22	31.37	411.59
3028	2004-04-14	877	300.50	24.79	325.29
3029	2004-04-30	15208	239.43	19.75	259.18
3030	2004-04-26	2400	91.70	7.57	99.27
3031	2004-04-18	4857	315.41	26.02	341.43
3032	2004-04-30	4298	355.00	29.29	384.29
3033	2004-04-28	8133	57.71	4.76	62.47
3034	2004-04-28	6242	218.85	18.06	236.91
3035	2004-04-15	2708	382.13	31.53	413.66
3036	2004-04-25	8352	291.80	24.07	315.87
3037	2004-04-18	3041	200.79	16.57	217.36
3038	2004-04-01	1529	223.04	18.40	241.44
3039	2004-04-15	15303	192.71	15.90	208.61
3040	2004-04-25	1526	4.35	0.36	4.71
3041	2004-04-09	7089	253.79	20.94	274.73
3042	2004-04-21	9891	164.85	13.60	178.45
3043	2004-04-09	7093	2.96	0.24	3.20
3044	2004-04-15	8899	25.30	2.09	27.39
3045	2004-04-24	8852	98.94	8.16	107.10
3046	2004-04-16	1899	38.51	3.18	41.69
3047	2004-04-27	13088	240.84	19.87	260.71
3048	2004-04-25	5808	43.51	3.59	47.10
3049	2004-04-03	5324	272.07	22.45	294.52
3050	2004-04-07	8512	329.72	27.20	356.92
3051	2004-04-22	10511	238.35	19.66	258.01
3052	2004-04-22	17834	226.82	18.71	245.53
3053	2004-04-22	4068	166.61	13.75	180.36
3054	2004-04-04	98	201.46	16.62	218.08
3055	2004-04-29	17692	388.87	32.08	420.95
3056	2004-04-17	18337	28.51	2.35	30.86
3057	2004-04-15	5348	310.68	25.63	336.31
3058	2004-04-07	9876	276.44	22.81	299.25
3059	2004-04-20	8927	48.00	3.96	51.96
3060	2004-04-10	12020	221.60	18.28	239.88
3061	2004-04-13	539	381.67	31.49	413.16
3062	2004-04-25	1437	392.85	32.41	425.26
3063	2004-04-09	6704	140.76	11.61	152.37
3064	2004-04-19	3961	300.23	24.77	325.00
3065	2004-04-21	13595	288.90	23.83	312.73
3066	2004-04-24	15665	333.37	27.50	360.87
3067	2004-04-28	4357	329.70	27.20	356.90
3068	2004-04-22	14988	175.21	14.45	189.66
3069	2004-04-06	12218	229.13	18.90	248.03
3070	2004-04-19	12975	33.64	2.78	36.42
3071	2004-04-20	13130	390.02	32.18	422.20
3072	2004-04-06	5443	385.19	31.78	416.97
3073	2004-04-29	14694	98.94	8.16	107.10
3074	2004-04-18	6782	37.86	3.12	40.98
3075	2004-04-10	15	33.63	2.77	36.40
3076	2004-04-26	13939	255.65	21.09	276.74
3077	2004-04-18	9604	328.19	27.08	355.27
3078	2004-04-06	19917	329.45	27.18	356.63
3079	2004-04-01	15092	165.69	13.67	179.36
3080	2004-04-03	17078	349.85	28.86	378.71
3081	2004-04-26	10067	363.70	30.01	393.71
3082	2004-04-05	16420	225.19	18.58	243.77
3083	2004-04-17	17704	323.07	26.65	349.72
3084	2004-04-21	5266	26.98	2.23	29.21
3085	2004-04-07	1292	9.28	0.77	10.05
3086	2004-04-29	19376	285.96	23.59	309.55
3087	2004-04-29	10082	77.44	6.39	83.83
3088	2004-04-08	10333	192.77	15.90	208.67
3089	2004-04-22	5285	181.98	15.01	196.99
3090	2004-04-08	12533	257.62	21.25	278.87
3091	2004-04-08	5688	318.44	26.27	344.71
3092	2004-04-30	16171	290.40	23.96	314.36
3093	2004-04-09	15102	242.84	20.03	262.87
3094	2004-04-19	17788	182.52	15.06	197.58
3095	2004-04-21	2168	107.43	8.86	116.29
3096	2004-04-26	12881	148.78	12.27	161.05
3097	2004-04-16	12162	339.43	28.00	367.43
3098	2004-04-06	1383	226.24	18.66	244.90
3099	2004-04-23	13655	98.86	8.16	107.02
3100	2004-04-05	8863	192.74	15.90	208.64
3101	2004-04-14	5393	376.15	31.03	407.18
3102	2004-04-14	2114	373.56	30.82	404.38
3103	2004-04-04	8950	250.65	20.68	271.33
3104	2004-04-30	19922	346.39	28.58	374.97
3105	2004-04-12	6183	176.25	14.54	190.79
3106	2004-04-09	14503	35.68	2.94	38.62
3107	2004-04-01	11467	82.32	6.79	89.11
3108	2004-04-21	4970	16.48	1.36	17.84
3109	2004-04-17	10267	236.62	19.52	256.14
3110	2004-04-06	9310	334.62	27.61	362.23
3111	2004-04-19	10309	225.83	18.63	244.46
3112	2004-04-07	12722	41.81	3.45	45.26
3113	2004-04-25	17756	397.00	32.75	429.75
3114	2004-04-17	15492	98.08	8.09	106.17
3115	2004-04-29	5973	318.27	26.26	344.53
3116	2004-04-10	12468	275.51	22.73	298.24
3117	2004-04-22	15981	122.48	10.10	132.58
3118	2004-04-17	5072	244.52	20.17	264.69
3119	2004-04-08	7677	284.10	23.44	307.54
3120	2004-04-06	17262	232.75	19.20	251.95
3121	2004-04-03	17622	51.62	4.26	55.88
3122	2004-04-20	10789	323.14	26.66	349.80
3123	2004-04-18	9930	5.14	0.42	5.56
3124	2004-04-10	19495	63.84	5.27	69.11
3125	2004-04-23	12580	196.80	16.24	213.04
3126	2004-04-12	10986	56.53	4.66	61.19
3127	2004-04-10	16135	18.26	1.51	19.77
3128	2004-04-17	11310	124.80	10.30	135.10
3129	2004-04-09	11948	167.11	13.79	180.90
3130	2004-04-23	14610	233.24	19.24	252.48
3131	2004-04-23	5727	58.00	4.79	62.78
3132	2004-04-23	6784	396.99	32.75	429.74
3133	2004-04-14	19238	131.34	10.84	142.18
3134	2004-04-17	16268	135.85	11.21	147.06
3135	2004-04-14	16849	321.10	26.49	347.59
3136	2004-04-25	13134	247.89	20.45	268.34
3137	2004-04-10	11280	333.31	27.50	360.81
3138	2004-04-27	1285	168.98	13.94	182.92
3139	2004-04-10	18229	273.66	22.58	296.24
3140	2004-04-17	2993	57.74	4.76	62.50
3141	2004-04-22	7144	88.00	7.26	95.26
3142	2004-04-07	1898	3.49	0.29	3.78
3143	2004-04-21	1844	193.78	15.99	209.77
3144	2004-04-25	3009	244.60	20.18	264.78
3145	2004-04-08	2438	101.47	8.37	109.84
3146	2004-04-04	18944	150.71	12.43	163.14
3147	2004-04-24	2992	38.10	3.14	41.24
3148	2004-04-17	11267	373.16	30.79	403.95
3149	2004-04-08	10014	8.16	0.67	8.83
3150	2004-04-12	5283	274.96	22.68	297.64
3151	2004-04-05	18274	160.86	13.27	174.13
3152	2004-04-13	17308	356.20	29.39	385.59
3153	2004-04-24	7287	288.05	23.76	311.81
3154	2004-04-15	8760	228.66	18.86	247.52
3155	2004-04-14	6042	22.46	1.85	24.31
3156	2004-04-30	13642	60.22	4.97	65.19
3157	2004-04-03	13407	378.81	31.25	410.06
3158	2004-04-03	7711	391.16	32.27	423.43
3159	2004-04-09	18092	331.50	27.35	358.85
3160	2004-04-29	9890	178.89	14.76	193.65
3161	2004-04-16	7366	51.00	4.21	55.21
3162	2004-04-02	17613	244.39	20.16	264.55
3163	2004-04-22	3558	149.46	12.33	161.79
3164	2004-04-11	3625	149.46	12.33	161.79
3165	2004-04-08	2460	280.73	23.16	303.89
3166	2004-04-20	13029	263.23	21.72	284.95
3167	2004-04-05	6842	164.10	13.54	177.64
3168	2004-04-02	18682	149.67	12.35	162.02
3169	2004-04-13	17495	292.40	24.12	316.52
3170	2004-04-05	12045	288.13	23.77	311.90
3171	2004-04-22	4479	149.23	12.31	161.54
3172	2004-04-22	18648	305.63	25.21	330.84
3173	2004-04-27	6927	374.18	30.87	405.05
3174	2004-04-12	11609	34.94	2.88	37.82
3175	2004-04-26	7042	327.72	27.04	354.76
3176	2004-04-27	10656	140.23	11.57	151.80
3177	2004-04-15	16829	379.18	31.28	410.46
3178	2004-04-02	1137	218.86	18.06	236.92
3179	2004-04-06	7411	33.70	2.78	36.48
3180	2004-04-13	8257	317.44	26.19	343.63
3181	2004-04-05	12314	326.31	26.92	353.23
3182	2004-04-05	761	267.37	22.06	289.43
3183	2004-04-14	12647	289.92	23.92	313.84
3184	2004-04-23	2596	349.05	28.80	377.85
3185	2004-04-15	7162	262.52	21.66	284.18
3186	2004-04-30	7459	274.29	22.63	296.92
3187	2004-04-14	15821	77.90	6.43	84.33
3188	2004-04-07	6125	226.95	18.72	245.67
3189	2004-04-14	18159	117.94	9.73	127.67
3190	2004-04-18	11355	70.86	5.85	76.71
3191	2004-04-24	3287	116.71	9.63	126.34
3192	2004-04-02	15206	236.56	19.52	256.08
3193	2004-04-21	7616	189.75	15.65	205.40
3194	2004-04-30	16688	22.23	1.83	24.06
3195	2004-04-04	13148	320.07	26.41	346.48
3196	2004-04-11	1631	124.45	10.27	134.72
3197	2004-04-18	16892	324.38	26.76	351.14
3198	2004-04-30	12025	192.59	15.89	208.48
3199	2004-04-22	16215	172.46	14.23	186.69
3200	2004-04-15	19104	329.49	27.18	356.67
3201	2004-04-16	14414	377.21	31.12	408.33
3202	2004-04-06	9200	39.37	3.25	42.62
3203	2004-04-27	19563	41.10	3.39	44.49
3204	2004-04-24	18910	332.19	27.41	359.60
3205	2004-04-12	14935	29.37	2.42	31.79
3206	2004-04-09	18346	19.78	1.63	21.41
3207	2004-04-19	5361	63.11	5.21	68.32
3208	2004-04-23	7913	104.98	8.66	113.64
3209	2004-04-28	16961	72.91	6.02	78.93
3210	2004-04-24	5728	369.69	30.50	400.19
3211	2004-04-09	13707	259.14	21.38	280.52
3212	2004-04-28	7973	267.92	22.10	290.02
3213	2004-04-13	12418	226.09	18.65	244.74
3214	2004-04-04	9261	384.83	31.75	416.58
3215	2004-04-10	3696	18.48	1.52	20.00
3216	2004-04-17	12286	68.60	5.66	74.26
3217	2004-04-20	17823	156.62	12.92	169.54
3218	2004-04-23	5108	0.35	0.03	0.38
3219	2004-04-10	13413	362.58	29.91	392.49
3220	2004-04-24	9278	185.39	15.29	200.68
3221	2004-04-15	19001	61.60	5.08	66.68
3222	2004-04-11	2026	263.68	21.75	285.43
3223	2004-04-06	1170	361.52	29.83	391.35
3224	2004-04-18	9432	334.21	27.57	361.78
3225	2004-04-24	17667	273.09	22.53	295.62
3226	2004-04-02	12586	18.20	1.50	19.70
3227	2004-04-27	14442	11.58	0.96	12.54
3228	2004-04-05	16291	32.17	2.65	34.82
3229	2004-04-08	6589	259.96	21.45	281.41
3230	2004-04-18	15627	374.76	30.92	405.68
3231	2004-04-01	5526	122.31	10.09	132.40
3232	2004-04-12	12728	98.05	8.09	106.14
3233	2004-04-27	18070	159.66	13.17	172.83
3234	2004-04-16	17448	68.88	5.68	74.56
3235	2004-04-23	14604	57.62	4.75	62.37
3236	2004-04-22	8245	229.67	18.95	248.62
3237	2004-04-03	3508	256.59	21.17	277.76
3238	2004-04-24	4124	165.37	13.64	179.01
3239	2004-04-18	2897	97.05	8.01	105.06
3240	2004-04-09	18509	377.78	31.17	408.95
3241	2004-04-28	17720	345.99	28.54	374.53
3242	2004-04-26	18287	249.12	20.55	269.67
3243	2004-04-02	2403	270.82	22.34	293.16
3244	2004-04-14	2893	334.91	27.63	362.54
3245	2004-04-14	6144	271.77	22.42	294.19
3246	2004-04-17	2711	136.70	11.28	147.98
3247	2004-04-04	16743	95.25	7.86	103.11
3248	2004-04-09	17793	118.10	9.74	127.84
3249	2004-04-22	5414	178.56	14.73	193.29
3250	2004-04-06	4726	211.87	17.48	229.35
3251	2004-04-05	6869	246.58	20.34	266.92
3252	2004-04-27	18358	293.11	24.18	317.29
3253	2004-04-18	3470	28.98	2.39	31.37
3254	2004-04-29	14823	33.63	2.77	36.40
3255	2004-04-28	5581	115.49	9.53	125.02
3256	2004-04-14	14026	360.86	29.77	390.63
3257	2004-04-14	1131	331.92	27.38	359.30
3258	2004-04-04	5640	333.65	27.53	361.18
3259	2004-04-25	2816	361.98	29.86	391.84
3260	2004-04-16	1101	142.96	11.79	154.75
3261	2004-04-13	14798	267.97	22.11	290.08
3262	2004-04-14	5668	20.64	1.70	22.34
3263	2004-04-23	3266	186.14	15.36	201.50
3264	2004-04-10	4142	67.08	5.53	72.61
3265	2004-04-11	10763	269.21	22.21	291.42
3266	2004-04-19	12640	339.19	27.98	367.17
3267	2004-04-28	7282	166.80	13.76	180.56
3268	2004-04-07	16289	385.65	31.82	417.47
3269	2004-04-08	8833	382.09	31.52	413.61
3270	2004-04-01	19448	144.24	11.90	156.14
3271	2004-04-02	12535	71.08	5.86	76.94
3272	2004-04-12	18681	70.29	5.80	76.09
3273	2004-04-02	9770	181.48	14.97	196.45
3274	2004-04-10	2342	56.82	4.69	61.51
3275	2004-04-06	12538	398.31	32.86	431.17
3276	2004-04-30	16447	18.32	1.51	19.83
3277	2004-04-09	12769	37.82	3.12	40.94
3278	2004-04-11	14953	226.72	18.70	245.42
3279	2004-04-23	14042	364.71	30.09	394.80
3280	2004-04-01	15282	79.95	6.60	86.55
3281	2004-04-02	6663	343.57	28.34	371.91
3282	2004-04-03	18167	121.62	10.03	131.65
3283	2004-04-30	14906	385.56	31.81	417.37
3284	2004-04-03	937	255.90	21.11	277.01
3285	2004-04-29	14691	367.59	30.33	397.92
3286	2004-04-26	1923	63.87	5.27	69.14
3287	2004-04-26	10220	125.60	10.36	135.96
3288	2004-04-21	3848	61.42	5.07	66.49
3289	2004-04-06	7773	116.16	9.58	125.74
3290	2004-04-06	1356	64.66	5.33	69.99
3291	2004-04-05	17880	27.97	2.31	30.28
3292	2004-04-30	10469	250.04	20.63	270.67
3293	2004-04-23	12919	13.01	1.07	14.08
3294	2004-04-28	1822	100.18	8.26	108.44
3295	2004-04-29	4339	301.53	24.88	326.41
3296	2004-04-22	366	367.14	30.29	397.43
3297	2004-04-10	10464	108.00	8.91	116.91
3298	2004-04-17	83	227.51	18.77	246.28
3299	2004-04-26	14794	219.35	18.10	237.45
3300	2004-04-08	18222	272.47	22.48	294.95
3301	2004-04-16	4400	22.28	1.84	24.12
3302	2004-04-12	17694	6.47	0.53	7.00
3303	2004-04-05	18277	181.60	14.98	196.58
3304	2004-04-04	2031	297.74	24.56	322.30
3305	2004-04-05	8525	74.02	6.11	80.13
3306	2004-04-23	10441	384.12	31.69	415.81
3307	2004-04-30	7994	46.15	3.81	49.96
3308	2004-04-17	13523	56.84	4.69	61.53
3309	2004-04-19	3392	252.43	20.83	273.26
3310	2004-04-25	6668	312.21	25.76	337.97
3311	2004-04-21	10317	281.32	23.21	304.53
3312	2004-04-16	10791	57.77	4.77	62.54
3313	2004-04-01	16911	200.53	16.54	217.07
3314	2004-04-18	13930	276.10	22.78	298.88
3315	2004-04-20	16380	382.36	31.54	413.90
3316	2004-04-21	7364	341.79	28.20	369.99
3317	2004-04-25	4212	125.80	10.38	136.18
3318	2004-04-01	948	378.00	31.19	409.19
3319	2004-04-10	13190	32.23	2.66	34.89
3320	2004-04-07	17639	208.43	17.20	225.63
3321	2004-04-07	9343	317.89	26.23	344.12
3322	2004-04-08	233	339.31	27.99	367.30
3323	2004-04-14	13606	45.74	3.77	49.51
3324	2004-04-22	13719	276.98	22.85	299.83
3325	2004-04-20	9271	73.11	6.03	79.14
3326	2004-04-12	9977	63.77	5.26	69.03
3327	2004-04-05	4778	135.86	11.21	147.07
3328	2004-04-17	5877	286.48	23.63	310.11
3329	2004-04-28	11520	196.16	16.18	212.34
3330	2004-04-30	148	129.67	10.70	140.37
3331	2004-04-18	2508	296.25	24.44	320.69
3332	2004-04-12	9699	31.95	2.64	34.59
3333	2004-04-20	6199	184.61	15.23	199.84
3334	2004-04-20	12124	308.67	25.47	334.14
3335	2004-04-23	17668	268.97	22.19	291.16
3336	2004-04-10	14550	63.91	5.27	69.18
3337	2004-04-02	10824	1.57	0.13	1.70
3338	2004-04-23	12379	151.73	12.52	164.25
3339	2004-04-16	4993	258.25	21.31	279.56
3340	2004-04-17	10829	276.69	22.83	299.52
3341	2004-04-26	6360	109.80	9.06	118.86
3342	2004-04-11	18040	88.99	7.34	96.33
3343	2004-04-17	8467	303.20	25.01	328.21
3344	2004-04-10	3419	280.87	23.17	304.04
3345	2004-04-15	1939	47.93	3.95	51.88
3346	2004-04-28	15971	385.81	31.83	417.64
3347	2004-04-17	8096	186.92	15.42	202.34
3348	2004-04-26	18624	24.25	2.00	26.25
3349	2004-04-25	13559	327.52	27.02	354.54
3350	2004-04-04	10909	316.11	26.08	342.19
3351	2004-04-14	19776	109.48	9.03	118.51
3352	2004-04-18	4364	76.00	6.27	82.27
3353	2004-04-13	16452	68.73	5.67	74.40
3354	2004-04-24	12943	16.19	1.34	17.53
3355	2004-04-29	10401	68.52	5.65	74.17
3356	2004-04-06	17608	128.16	10.57	138.73
3357	2004-04-11	10919	203.23	16.77	220.00
3358	2004-04-19	18966	391.25	32.28	423.53
3359	2004-04-30	17060	209.07	17.25	226.32
3360	2004-04-20	7656	171.47	14.15	185.62
3361	2004-04-24	8818	379.17	31.28	410.45
3362	2004-04-06	7510	391.49	32.30	423.79
3363	2004-04-04	17428	394.08	32.51	426.59
3364	2004-04-01	856	388.23	32.03	420.26
3365	2004-04-20	17019	138.95	11.46	150.41
3366	2004-04-12	7247	132.91	10.97	143.88
3367	2004-04-04	10045	317.81	26.22	344.03
3368	2004-04-08	13311	352.84	29.11	381.95
3369	2004-04-12	15860	29.93	2.47	32.40
3370	2004-04-02	14582	252.56	20.84	273.40
3371	2004-04-11	7118	67.70	5.59	73.29
3372	2004-04-24	7345	210.71	17.38	228.09
3373	2004-04-01	16928	286.87	23.67	310.54
3374	2004-04-09	10028	296.12	24.43	320.55
3375	2004-04-17	16458	156.03	12.87	168.90
3376	2004-04-03	16230	355.01	29.29	384.30
3377	2004-04-03	2917	237.15	19.56	256.71
3378	2004-04-26	14902	334.88	27.63	362.51
3379	2004-04-21	3535	169.59	13.99	183.58
3380	2004-04-10	7111	329.13	27.15	356.28
3381	2004-04-19	99	328.63	27.11	355.74
3382	2004-04-23	16047	197.76	16.32	214.08
3383	2004-04-15	15239	390.13	32.19	422.32
3384	2004-04-14	12099	361.66	29.84	391.50
3385	2004-04-04	2220	52.77	4.35	57.12
3386	2004-04-02	2902	382.05	31.52	413.57
3387	2004-04-21	12286	293.07	24.18	317.25
3388	2004-04-22	12987	371.18	30.62	401.80
3389	2004-04-15	19196	376.67	31.08	407.75
3390	2004-04-26	7561	180.61	14.90	195.51
3391	2004-04-19	16200	188.61	15.56	204.17
3392	2004-04-01	17145	69.37	5.72	75.09
3393	2004-04-02	13627	323.70	26.71	350.41
3394	2004-04-22	497	35.82	2.96	38.78
3395	2004-04-03	11223	253.55	20.92	274.47
3396	2004-04-28	16280	137.20	11.32	148.52
3397	2004-04-03	14220	194.35	16.03	210.38
3398	2004-04-11	3700	280.29	23.12	303.41
3399	2004-04-27	3577	397.87	32.82	430.69
3400	2004-04-22	17342	366.51	30.24	396.75
3401	2004-04-05	17758	87.91	7.25	95.16
3402	2004-04-28	6114	250.32	20.65	270.97
3403	2004-04-27	19543	96.79	7.99	104.78
3404	2004-04-02	18636	270.46	22.31	292.77
3405	2004-04-06	17781	177.38	14.63	192.01
3406	2004-04-03	14625	58.85	4.86	63.71
3407	2004-04-04	19859	193.32	15.95	209.27
3408	2004-04-14	11903	272.78	22.50	295.28
3409	2004-04-08	19583	239.97	19.80	259.77
3410	2004-04-11	17858	11.60	0.96	12.56
3411	2004-04-10	7425	253.73	20.93	274.66
3412	2004-04-08	16557	256.24	21.14	277.38
3413	2004-04-04	3118	192.06	15.84	207.90
3414	2004-04-24	10610	248.35	20.49	268.84
3415	2004-04-07	13924	18.98	1.57	20.55
3416	2004-04-20	14335	292.39	24.12	316.51
3417	2004-04-07	13818	210.89	17.40	228.29
3418	2004-04-03	10237	34.64	2.86	37.50
3419	2004-04-15	18493	36.83	3.04	39.87
3420	2004-04-21	7580	228.26	18.83	247.09
3421	2004-04-17	13711	83.78	6.91	90.69
3422	2004-04-29	1186	252.75	20.85	273.60
3423	2004-04-20	2660	347.65	28.68	376.33
3424	2004-04-06	11573	112.72	9.30	122.02
3425	2004-04-27	8743	160.29	13.22	173.51
3426	2004-04-03	5247	379.53	31.31	410.84
3427	2004-04-04	3776	218.92	18.06	236.98
3428	2004-04-16	13491	27.59	2.28	29.87
3429	2004-04-16	9370	202.32	16.69	219.01
3430	2004-04-22	7131	178.84	14.75	193.59
3431	2004-04-03	18505	107.77	8.89	116.66
3432	2004-04-09	13317	53.71	4.43	58.14
3433	2004-04-29	11244	110.85	9.15	120.00
3434	2004-04-14	17278	112.14	9.25	121.39
3435	2004-04-03	17175	53.46	4.41	57.87
3436	2004-04-07	15517	254.78	21.02	275.80
3437	2004-04-14	16953	220.65	18.20	238.85
3438	2004-04-10	13949	247.57	20.42	267.99
3439	2004-04-19	15982	78.40	6.47	84.87
3440	2004-04-20	8044	172.95	14.27	187.22
3441	2004-04-28	16188	83.51	6.89	90.40
3442	2004-04-24	12511	149.71	12.35	162.06
3443	2004-04-10	13256	10.72	0.88	11.60
3444	2004-04-13	4313	315.35	26.02	341.37
3445	2004-04-26	11607	44.04	3.63	47.67
3446	2004-04-24	16206	341.27	28.15	369.42
3447	2004-04-20	12989	230.17	18.99	249.16
3448	2004-04-02	14019	36.04	2.97	39.01
3449	2004-04-02	18208	167.92	13.85	181.77
3450	2004-04-03	402	267.81	22.09	289.90
3451	2004-04-30	10377	152.41	12.57	164.98
3452	2004-04-04	12124	110.34	9.10	119.44
3453	2004-04-02	18904	313.64	25.88	339.52
3454	2004-04-23	11864	385.12	31.77	416.89
3455	2004-04-10	15770	233.20	19.24	252.44
3456	2004-04-03	8561	240.43	19.84	260.27
3457	2004-04-12	304	274.38	22.64	297.02
3458	2004-04-15	4898	127.55	10.52	138.07
3459	2004-04-08	14892	253.98	20.95	274.93
3460	2004-04-24	11036	176.53	14.56	191.09
3461	2004-04-23	14642	142.42	11.75	154.17
3462	2004-04-23	14588	143.32	11.82	155.14
3463	2004-04-28	1486	51.57	4.25	55.82
3464	2004-04-19	2137	278.90	23.01	301.91
3465	2004-04-15	3497	24.48	2.02	26.50
3466	2004-04-17	9774	254.26	20.98	275.24
3467	2004-04-01	16621	199.67	16.47	216.14
3468	2004-04-30	11838	369.38	30.47	399.85
3469	2004-04-22	13813	397.18	32.77	429.95
3470	2004-04-20	14159	307.49	25.37	332.86
3471	2004-04-26	17228	36.61	3.02	39.63
3472	2004-04-03	5556	280.17	23.11	303.28
3473	2004-04-06	11091	397.39	32.78	430.17
3474	2004-04-29	1116	186.61	15.40	202.01
3475	2004-04-11	7082	236.95	19.55	256.50
3476	2004-04-11	17749	313.39	25.85	339.24
3477	2004-04-25	748	339.29	27.99	367.28
3478	2004-04-22	16375	163.61	13.50	177.11
3479	2004-04-24	2338	324.73	26.79	351.52
3480	2004-04-14	3175	280.92	23.18	304.10
3481	2004-04-17	7713	28.96	2.39	31.35
3482	2004-04-11	10088	366.53	30.24	396.77
3483	2004-04-09	6581	230.23	18.99	249.22
3484	2004-04-13	12235	173.97	14.35	188.32
3485	2004-04-24	18479	294.48	24.29	318.77
3486	2004-04-22	39	17.24	1.42	18.66
3487	2004-04-22	11754	214.37	17.69	232.06
3488	2004-04-16	1459	348.98	28.79	377.77
3489	2004-04-23	14959	68.28	5.63	73.91
3490	2004-04-14	14358	37.34	3.08	40.42
3491	2004-04-20	9628	323.31	26.67	349.98
3492	2004-04-28	7259	395.17	32.60	427.77
3493	2004-04-03	13692	89.23	7.36	96.59
3494	2004-04-09	2528	226.93	18.72	245.65
3495	2004-04-30	18187	304.80	25.15	329.95
3496	2004-04-26	16198	114.28	9.43	123.71
3497	2004-04-08	2815	333.32	27.50	360.82
3498	2004-04-26	3185	170.56	14.07	184.63
3499	2004-04-06	14771	389.93	32.17	422.10
3500	2004-04-07	12273	392.38	32.37	424.75
3501	2004-04-30	6853	143.70	11.86	155.56
3502	2004-04-20	6189	190.92	15.75	206.67
3503	2004-04-12	13268	230.33	19.00	249.33
3504	2004-04-21	15210	140.73	11.61	152.34
3505	2004-04-08	16215	357.24	29.47	386.71
3506	2004-04-13	12396	271.85	22.43	294.28
3507	2004-04-03	6652	160.19	13.22	173.41
3508	2004-04-12	18217	290.80	23.99	314.79
3509	2004-04-10	539	63.49	5.24	68.73
3510	2004-04-11	402	206.61	17.05	223.66
3511	2004-04-28	5622	71.08	5.86	76.94
3512	2004-04-13	2140	61.15	5.04	66.19
3513	2004-04-14	12820	391.08	32.26	423.34
3514	2004-04-20	5285	188.96	15.59	204.55
3515	2004-04-12	17583	399.17	32.93	432.10
3516	2004-04-27	17253	251.71	20.77	272.48
3517	2004-04-29	13369	276.93	22.85	299.78
3518	2004-04-02	12824	59.32	4.89	64.21
3519	2004-04-10	13961	70.15	5.79	75.94
3520	2004-04-12	9394	145.19	11.98	157.17
3521	2004-04-18	17916	369.42	30.48	399.90
3522	2004-04-17	6310	136.34	11.25	147.59
3523	2004-04-25	7606	378.07	31.19	409.26
3524	2004-04-27	5319	92.31	7.62	99.93
3525	2004-04-05	15029	204.12	16.84	220.96
3526	2004-04-23	13196	301.60	24.88	326.48
3527	2004-04-07	14817	251.73	20.77	272.50
3528	2004-04-08	14161	57.36	4.73	62.09
3529	2004-04-11	17826	366.58	30.24	396.82
3530	2004-04-28	8436	12.30	1.01	13.31
3531	2004-04-11	17973	130.47	10.76	141.23
3532	2004-04-28	1117	26.32	2.17	28.49
3533	2004-04-24	7268	323.91	26.72	350.63
3534	2004-04-21	13771	186.80	15.41	202.21
3535	2004-04-05	13824	77.01	6.35	83.36
3536	2004-04-22	14296	351.17	28.97	380.14
3537	2004-04-30	12402	391.78	32.32	424.10
3538	2004-04-12	4558	244.10	20.14	264.24
3539	2004-04-24	9781	235.18	19.40	254.58
3540	2004-04-17	2338	255.32	21.06	276.38
3541	2004-04-13	15646	184.57	15.23	199.80
3542	2004-04-05	1991	94.25	7.78	102.03
3543	2004-04-13	485	286.62	23.65	310.27
3544	2004-04-18	12414	9.44	0.78	10.22
3545	2004-04-23	19092	124.05	10.23	134.28
3546	2004-04-27	15088	257.54	21.25	278.79
3547	2004-04-06	1254	66.46	5.48	71.94
3548	2004-04-20	4604	111.33	9.18	120.51
3549	2004-04-11	7864	326.90	26.97	353.87
3550	2004-04-13	12002	121.16	10.00	131.16
3551	2004-04-30	2841	87.24	7.20	94.44
3552	2004-04-25	5631	39.56	3.26	42.82
3553	2004-04-11	19091	169.83	14.01	183.84
3554	2004-04-21	14046	114.48	9.44	123.92
3555	2004-04-16	14900	346.48	28.58	375.06
3556	2004-04-29	11761	332.99	27.47	360.46
3557	2004-04-27	14800	66.98	5.53	72.51
3558	2004-04-21	471	384.48	31.72	416.20
3559	2004-04-23	10173	286.98	23.68	310.66
3560	2004-04-27	11197	25.52	2.11	27.63
3561	2004-04-15	6371	36.26	2.99	39.25
3562	2004-04-11	10722	13.30	1.10	14.40
3563	2004-04-08	11490	136.38	11.25	147.63
3564	2004-04-05	14188	148.71	12.27	160.98
3565	2004-04-06	6265	316.81	26.14	342.95
3566	2004-04-28	896	150.13	12.39	162.52
3567	2004-04-30	6704	301.00	24.83	325.83
3568	2004-04-13	3503	98.92	8.16	107.08
3569	2004-04-10	15116	253.21	20.89	274.10
3570	2004-04-17	3777	32.72	2.70	35.42
3571	2004-04-20	9028	5.39	0.44	5.83
3572	2004-04-15	2888	307.97	25.41	333.38
3573	2004-04-03	18999	36.61	3.02	39.63
3574	2004-04-01	14240	197.81	16.32	214.13
3575	2004-04-01	14614	304.81	25.15	329.96
3576	2004-04-13	17787	314.61	25.96	340.57
3577	2004-04-02	3929	370.37	30.56	400.93
3578	2004-04-30	2643	183.84	15.17	199.01
3579	2004-04-10	506	349.20	28.81	378.01
3580	2004-04-29	2986	234.77	19.37	254.14
3581	2004-04-03	2634	267.12	22.04	289.16
3582	2004-04-18	15595	301.47	24.87	326.34
3583	2004-04-20	19557	153.59	12.67	166.26
3584	2004-04-14	16203	129.83	10.71	140.54
3585	2004-04-25	6939	312.44	25.78	338.22
3586	2004-04-30	17546	317.18	26.17	343.35
3587	2004-04-09	5619	45.27	3.73	49.00
3588	2004-04-13	17048	242.64	20.02	262.66
3589	2004-04-25	270	258.83	21.35	280.18
3590	2004-04-16	18048	268.22	22.13	290.35
3591	2004-04-12	920	216.65	17.87	234.52
3592	2004-04-28	4065	36.47	3.01	39.48
3593	2004-04-05	15845	302.93	24.99	327.92
3594	2004-04-12	18003	366.13	30.21	396.34
3595	2004-04-01	9733	162.08	13.37	175.45
3596	2004-04-18	5609	214.27	17.68	231.95
3597	2004-04-13	12056	336.55	27.77	364.32
3598	2004-04-09	2895	204.79	16.90	221.69
3599	2004-04-13	2632	397.05	32.76	429.81
3600	2004-04-02	7795	177.60	14.65	192.25
3601	2004-04-23	5566	206.77	17.06	223.83
3602	2004-04-08	9337	266.00	21.95	287.94
3603	2004-04-23	15560	173.19	14.29	187.48
3604	2004-04-12	13472	363.21	29.96	393.17
3605	2004-04-15	10196	176.82	14.59	191.41
3606	2004-04-23	1551	260.73	21.51	282.24
3607	2004-04-08	12924	50.50	4.17	54.67
3608	2004-04-24	4233	70.83	5.84	76.67
3609	2004-04-25	10644	53.49	4.41	57.90
3610	2004-04-15	3567	233.97	19.30	253.27
3611	2004-04-11	2475	382.58	31.56	414.14
3612	2004-04-02	4334	257.81	21.27	279.08
3613	2004-04-04	5848	104.86	8.65	113.51
3614	2004-04-29	1703	315.48	26.03	341.51
3615	2004-04-21	12042	291.60	24.06	315.66
3616	2004-04-30	15580	107.31	8.85	116.16
3617	2004-04-06	5831	112.10	9.25	121.35
3618	2004-04-03	8441	217.66	17.96	235.62
3619	2004-04-09	11784	242.13	19.98	262.11
3620	2004-04-28	2220	2.84	0.23	3.07
3621	2004-04-30	13147	254.12	20.96	275.08
3622	2004-04-26	8198	44.90	3.70	48.60
3623	2004-04-30	9023	3.38	0.28	3.66
3624	2004-04-09	18744	358.37	29.57	387.94
3625	2004-04-17	9670	183.25	15.12	198.37
3626	2004-04-04	13726	314.96	25.98	340.94
3627	2004-04-22	19172	321.90	26.56	348.46
3628	2004-04-18	17968	36.45	3.01	39.46
3629	2004-04-07	15441	115.00	9.49	124.49
3630	2004-04-03	6566	383.25	31.62	414.87
3631	2004-04-29	5692	294.58	24.30	318.88
3632	2004-04-27	4485	9.65	0.80	10.45
3633	2004-04-17	4407	215.24	17.76	233.00
3634	2004-04-20	8913	100.23	8.27	108.50
3635	2004-04-25	17096	110.45	9.11	119.56
3636	2004-04-28	12223	242.90	20.04	262.94
3637	2004-04-11	6914	199.54	16.46	216.00
3638	2004-04-22	2622	264.40	21.81	286.21
3639	2004-04-18	1887	155.82	12.86	168.68
3640	2004-04-01	3768	373.11	30.78	403.89
3641	2004-04-04	15862	64.45	5.32	69.77
3642	2004-04-03	11769	180.49	14.89	195.38
3643	2004-04-25	7784	105.61	8.71	114.32
3644	2004-04-29	13429	118.17	9.75	127.92
3645	2004-04-03	4610	9.08	0.75	9.83
3646	2004-04-29	1993	252.23	20.81	273.04
3647	2004-04-04	8636	265.93	21.94	287.87
3648	2004-04-22	14529	61.89	5.11	67.00
3649	2004-04-27	14681	285.53	23.56	309.09
3650	2004-04-20	9298	244.15	20.14	264.29
3651	2004-04-04	5642	323.86	26.72	350.58
3652	2004-04-15	124	97.90	8.08	105.98
3653	2004-04-13	143	96.06	7.92	103.98
3654	2004-04-23	10405	39.67	3.27	42.94
3655	2004-04-12	1300	249.94	20.62	270.56
3656	2004-04-25	14756	259.56	21.41	280.97
3657	2004-04-30	4293	387.71	31.99	419.70
3658	2004-04-03	15926	61.91	5.11	67.02
3659	2004-04-15	8608	156.06	12.87	168.93
3660	2004-04-07	14185	144.18	11.89	156.07
3661	2004-04-08	15483	353.15	29.13	382.28
3662	2004-04-17	11609	360.47	29.74	390.21
3663	2004-04-10	15276	364.54	30.07	394.61
3664	2004-04-25	2581	357.78	29.52	387.30
3665	2004-04-04	8815	226.13	18.66	244.79
3666	2004-04-27	8794	329.64	27.20	356.84
3667	2004-04-20	17307	343.88	28.37	372.25
3668	2004-04-07	1622	258.09	21.29	279.38
3669	2004-04-28	1798	134.58	11.10	145.68
3670	2004-04-02	854	198.80	16.40	215.20
3671	2004-04-18	13575	76.41	6.30	82.71
3672	2004-04-21	14225	35.29	2.91	38.20
3673	2004-04-18	17398	273.45	22.56	296.01
3674	2004-04-06	4810	325.59	26.86	352.45
3675	2004-04-27	8112	230.16	18.99	249.15
3676	2004-04-05	16422	208.08	17.17	225.25
3677	2004-04-22	3006	236.10	19.48	255.58
3678	2004-04-08	17538	108.83	8.98	117.81
3679	2004-04-16	6639	43.33	3.57	46.90
3680	2004-04-09	8169	201.30	16.61	217.91
3681	2004-04-12	8119	393.99	32.50	426.49
3682	2004-04-04	19048	157.07	12.96	170.03
3683	2004-04-20	18577	23.21	1.91	25.12
3684	2004-04-03	9664	302.45	24.95	327.40
3685	2004-04-18	7253	398.98	32.92	431.90
3686	2004-04-08	9497	76.28	6.29	82.57
3687	2004-04-20	9803	151.63	12.51	164.14
3688	2004-04-22	4786	97.71	8.06	105.77
3689	2004-04-10	2398	36.54	3.01	39.55
3690	2004-04-01	17204	273.23	22.54	295.77
3691	2004-04-05	8043	289.19	23.86	313.05
3692	2004-04-05	2200	217.55	17.95	235.50
3693	2004-04-08	7475	45.22	3.73	48.95
3694	2004-04-30	11669	224.52	18.52	243.04
3695	2004-04-28	13910	237.94	19.63	257.57
3696	2004-04-07	9362	284.77	23.49	308.26
3697	2004-04-04	9733	281.66	23.24	304.90
3698	2004-04-16	1563	335.00	27.64	362.64
3699	2004-04-10	15710	133.54	11.02	144.56
3700	2004-04-01	5987	77.88	6.43	84.31
3701	2004-04-12	16642	261.48	21.57	283.05
3702	2004-04-24	12119	268.95	22.19	291.14
3703	2004-04-30	6407	147.01	12.13	159.14
3704	2004-04-12	1769	159.45	13.15	172.60
3705	2004-04-20	6676	355.96	29.37	385.33
3706	2004-04-10	15351	107.38	8.86	116.24
3707	2004-04-30	4024	365.51	30.15	395.66
3708	2004-04-15	13386	277.15	22.86	300.01
3709	2004-04-03	892	157.90	13.03	170.93
3710	2004-04-20	12	350.87	28.95	379.82
3711	2004-04-23	793	258.64	21.34	279.98
3712	2004-04-18	7845	329.96	27.22	357.18
3713	2004-04-16	4949	194.45	16.04	210.49
3714	2004-04-10	8356	352.70	29.10	381.80
3715	2004-04-24	5527	326.86	26.97	353.83
3716	2004-04-18	543	255.02	21.04	276.06
3717	2004-04-22	5349	10.12	0.83	10.95
3718	2004-04-18	16943	351.49	29.00	380.49
3719	2004-04-11	4767	32.90	2.71	35.61
3720	2004-04-24	4726	343.09	28.30	371.39
3721	2004-04-05	2023	142.92	11.79	154.71
3722	2004-04-26	2131	91.63	7.56	99.19
3723	2004-04-23	742	167.49	13.82	181.31
3724	2004-04-28	15785	150.55	12.42	162.97
3725	2004-04-29	320	375.47	30.98	406.45
3726	2004-04-25	19523	351.06	28.96	380.02
3727	2004-04-06	4636	81.34	6.71	88.05
3728	2004-04-28	2985	314.32	25.93	340.25
3729	2004-04-26	4919	22.13	1.83	23.96
3730	2004-04-24	13042	40.81	3.37	44.18
3731	2004-04-29	3017	123.84	10.22	134.06
3732	2004-04-06	12286	326.25	26.92	353.17
3733	2004-04-22	19025	193.80	15.99	209.79
3734	2004-04-03	17649	77.84	6.42	84.26
3735	2004-04-14	19914	116.10	9.58	125.68
3736	2004-04-17	12750	70.42	5.81	76.23
3737	2004-04-18	2433	268.98	22.19	291.17
3738	2004-04-11	14298	155.79	12.85	168.64
3739	2004-04-27	16819	353.57	29.17	382.74
3740	2004-04-28	235	19.89	1.64	21.53
3741	2004-04-10	8626	260.60	21.50	282.10
3742	2004-04-25	2291	169.73	14.00	183.73
3743	2004-04-30	14270	230.54	19.02	249.56
3744	2004-04-28	10216	63.38	5.23	68.61
3745	2004-04-08	16070	152.26	12.56	164.82
3746	2004-04-29	18505	100.18	8.26	108.44
3747	2004-04-17	7380	219.82	18.14	237.96
3748	2004-04-25	19954	75.75	6.25	82.00
3749	2004-04-18	733	65.95	5.44	71.39
3750	2004-04-21	8500	60.95	5.03	65.98
3751	2004-04-18	9840	232.94	19.22	252.16
3752	2004-04-15	10919	239.17	19.73	258.90
3753	2004-04-13	8107	335.64	27.69	363.33
3754	2004-04-11	11901	287.55	23.72	311.27
3755	2004-04-02	19572	395.41	32.62	428.03
3756	2004-04-30	4570	37.00	3.05	40.05
3757	2004-04-28	578	10.29	0.85	11.14
3758	2004-04-16	7773	120.94	9.98	130.92
3759	2004-04-13	6357	258.23	21.30	279.53
3760	2004-04-08	6220	302.97	25.00	327.97
3761	2004-04-17	13069	88.52	7.30	95.82
3762	2004-04-07	10793	192.91	15.92	208.83
3763	2004-04-16	8842	18.11	1.49	19.60
3764	2004-04-17	12002	146.89	12.12	159.01
3765	2004-04-30	7707	275.60	22.74	298.34
3766	2004-04-06	6359	107.09	8.83	115.92
3767	2004-04-11	472	105.62	8.71	114.33
3768	2004-04-14	17048	282.76	23.33	306.09
3769	2004-04-09	7931	128.86	10.63	139.49
3770	2004-04-18	7422	142.10	11.72	153.82
3771	2004-04-14	15976	274.54	22.65	297.19
3772	2004-04-26	4952	221.99	18.31	240.30
3773	2004-04-25	1829	3.70	0.31	4.01
3774	2004-04-22	17282	173.03	14.27	187.30
3775	2004-04-27	15133	11.89	0.98	12.87
3776	2004-04-06	169	147.71	12.19	159.90
3777	2004-04-02	14809	333.16	27.49	360.65
3778	2004-04-01	5842	310.23	25.59	335.82
3779	2004-04-11	3478	291.77	24.07	315.84
3780	2004-04-15	11348	3.12	0.26	3.38
3781	2004-04-17	17513	93.32	7.70	101.02
3782	2004-04-04	3528	340.71	28.11	368.82
3783	2004-04-30	6954	121.89	10.06	131.95
3784	2004-04-08	12002	322.07	26.57	348.64
3785	2004-04-17	16108	46.03	3.80	49.83
3786	2004-04-18	10328	18.50	1.53	20.03
3787	2004-04-09	10593	384.96	31.76	416.72
3788	2004-04-13	911	387.77	31.99	419.76
3789	2004-04-09	9213	145.78	12.03	157.81
3790	2004-04-09	2940	307.26	25.35	332.61
3791	2004-04-04	9831	259.01	21.37	280.38
3792	2004-04-09	12074	278.10	22.94	301.04
3793	2004-04-16	13293	231.85	19.13	250.98
3794	2004-04-19	1370	64.72	5.34	70.06
3795	2004-04-04	9526	32.56	2.69	35.25
3796	2004-04-23	13650	363.40	29.98	393.38
3797	2004-04-03	8910	328.94	27.14	356.08
3798	2004-04-12	11367	119.48	9.86	129.34
3799	2004-04-16	7912	332.75	27.45	360.20
3800	2004-04-13	12675	277.67	22.91	300.58
3801	2004-04-03	8599	61.40	5.07	66.47
3802	2004-04-17	11018	279.46	23.06	302.52
3803	2004-04-07	10635	103.00	8.50	111.50
3804	2004-04-12	937	292.17	24.10	316.27
3805	2004-04-10	3507	247.74	20.44	268.18
3806	2004-04-17	598	32.97	2.72	35.69
3807	2004-04-09	7934	232.71	19.20	251.91
3808	2004-04-26	7141	81.90	6.76	88.66
3809	2004-04-12	7566	359.22	29.64	388.86
3810	2004-04-15	12024	149.37	12.32	161.69
3811	2004-04-24	1573	288.66	23.81	312.47
3812	2004-04-04	13252	120.78	9.96	130.74
3813	2004-04-22	8644	239.33	19.74	259.07
3814	2004-04-11	13011	136.72	11.28	148.00
3815	2004-04-24	9310	122.50	10.11	132.61
3816	2004-04-11	10409	134.73	11.12	145.85
3817	2004-04-23	5413	174.12	14.36	188.48
3818	2004-04-09	1642	55.18	4.55	59.73
3819	2004-04-15	8277	94.78	7.82	102.60
3820	2004-04-16	18201	55.20	4.55	59.75
3821	2004-04-11	15507	32.07	2.65	34.72
3822	2004-04-15	13474	119.44	9.85	129.29
3823	2004-04-30	13262	270.29	22.30	292.59
3824	2004-04-03	8501	310.98	25.66	336.64
3825	2004-04-30	1188	387.32	31.95	419.27
3826	2004-04-27	1713	253.99	20.95	274.94
3827	2004-04-07	7669	253.89	20.95	274.84
3828	2004-04-17	9167	15.19	1.25	16.44
3829	2004-04-09	387	82.59	6.81	89.40
3830	2004-04-02	14481	130.94	10.80	141.74
3831	2004-04-30	14998	34.41	2.84	37.25
3832	2004-04-17	10405	94.58	7.80	102.38
3833	2004-04-22	19559	83.48	6.89	90.37
3834	2004-04-02	14570	119.18	9.83	129.01
3835	2004-04-08	913	59.36	4.90	64.26
3836	2004-04-08	10707	256.46	21.16	277.62
3837	2004-04-03	5204	357.61	29.50	387.11
3838	2004-04-01	6059	370.46	30.56	401.02
3839	2004-04-07	1604	284.22	23.45	307.67
3840	2004-04-27	18460	234.12	19.31	253.43
3841	2004-04-08	603	236.80	19.54	256.34
3842	2004-04-20	12993	219.03	18.07	237.10
3843	2004-04-16	12105	312.80	25.81	338.61
3844	2004-04-23	16091	137.59	11.35	148.94
3845	2004-04-15	412	78.31	6.46	84.77
3846	2004-04-13	6287	205.09	16.92	222.01
3847	2004-04-27	3442	305.55	25.21	330.76
3848	2004-04-26	11610	0.48	0.04	0.52
3849	2004-04-12	1999	113.24	9.34	122.58
3850	2004-04-02	12649	229.77	18.96	248.73
3851	2004-04-01	6274	388.74	32.07	420.81
3852	2004-04-04	3135	186.59	15.39	201.98
3853	2004-04-28	14324	338.66	27.94	366.60
3854	2004-04-25	9745	207.62	17.13	224.75
3855	2004-04-21	1744	62.94	5.19	68.13
3856	2004-04-21	4280	222.48	18.35	240.83
3857	2004-04-22	9982	294.11	24.26	318.37
3858	2004-04-19	9874	131.59	10.86	142.45
3859	2004-04-12	12808	359.16	29.63	388.79
3860	2004-04-11	9485	398.76	32.90	431.66
3861	2004-04-25	12701	379.35	31.30	410.65
3862	2004-04-22	6426	25.65	2.12	27.77
3863	2004-04-06	16733	247.01	20.38	267.39
3864	2004-04-02	17902	362.42	29.90	392.32
3865	2004-04-09	3104	393.32	32.45	425.77
3866	2004-04-09	19747	155.52	12.83	168.35
3867	2004-04-12	18523	60.15	4.96	65.11
3868	2004-04-21	9768	111.59	9.21	120.80
3869	2004-04-30	14145	252.10	20.80	272.90
3870	2004-04-30	11752	372.66	30.74	403.40
3871	2004-04-13	19326	163.60	13.50	177.10
3872	2004-04-04	7555	294.68	24.31	318.99
3873	2004-04-23	4572	249.14	20.55	269.69
3874	2004-04-11	7725	86.04	7.10	93.14
3875	2004-04-21	333	225.91	18.64	244.55
3876	2004-04-18	16726	178.14	14.70	192.84
3877	2004-04-09	17028	50.20	4.14	54.34
3878	2004-04-15	11552	231.89	19.13	251.02
3879	2004-04-12	442	328.50	27.10	355.60
3880	2004-04-13	14289	210.33	17.35	227.68
3881	2004-04-02	10832	199.21	16.43	215.64
3882	2004-04-17	13645	7.11	0.59	7.70
3883	2004-04-03	423	398.95	32.91	431.86
3884	2004-04-09	18935	215.35	17.77	233.12
3885	2004-04-29	10941	309.06	25.50	334.56
3886	2004-04-14	8840	175.88	14.51	190.39
3887	2004-04-22	11214	122.09	10.07	132.16
3888	2004-04-10	14629	57.77	4.77	62.54
3889	2004-04-23	11827	188.25	15.53	203.78
3890	2004-04-10	7087	160.83	13.27	174.10
3891	2004-04-10	4259	209.13	17.25	226.38
3892	2004-04-04	7044	34.83	2.87	37.70
3893	2004-04-11	12291	50.13	4.14	54.27
3894	2004-04-15	939	195.29	16.11	211.40
3895	2004-04-11	10555	160.07	13.21	173.28
3896	2004-04-26	1177	5.53	0.46	5.99
3897	2004-04-09	6366	238.14	19.65	257.79
3898	2004-04-17	12174	221.34	18.26	239.60
3899	2004-04-14	15036	274.43	22.64	297.07
3900	2004-04-28	5549	397.36	32.78	430.14
3901	2004-04-05	11327	370.98	30.61	401.59
3902	2004-04-25	14493	321.02	26.48	347.50
3903	2004-04-03	17593	101.56	8.38	109.94
3904	2004-04-20	11477	121.78	10.05	131.83
3905	2004-04-25	237	195.45	16.12	211.57
3906	2004-04-15	10264	126.04	10.40	136.44
3907	2004-04-01	2716	382.53	31.56	414.09
3908	2004-04-29	11902	96.51	7.96	104.47
3909	2004-04-13	3408	395.41	32.62	428.03
3910	2004-04-02	15512	348.67	28.77	377.44
3911	2004-04-01	17832	14.90	1.23	16.13
3912	2004-04-04	11707	261.68	21.59	283.27
3913	2004-04-10	4159	261.23	21.55	282.78
3914	2004-04-23	6617	33.97	2.80	36.77
3915	2004-04-26	3981	355.81	29.35	385.16
3916	2004-04-08	19918	266.81	22.01	288.82
3917	2004-04-25	12234	292.02	24.09	316.11
3918	2004-04-27	6323	346.75	28.61	375.36
3919	2004-04-03	18170	75.84	6.26	82.10
3920	2004-04-06	9425	214.45	17.69	232.14
3921	2004-04-03	2558	119.89	9.89	129.78
3922	2004-04-30	6568	261.95	21.61	283.56
3923	2004-04-26	9464	212.05	17.49	229.54
3924	2004-04-03	18368	216.11	17.83	233.94
3925	2004-04-28	2383	285.15	23.52	308.67
3926	2004-04-13	12776	274.82	22.67	297.49
3927	2004-04-08	16432	2.79	0.23	3.02
3928	2004-04-08	16339	256.23	21.14	277.37
3929	2004-04-29	10385	67.93	5.60	73.53
3930	2004-04-28	5275	139.17	11.48	150.65
3931	2004-04-22	1732	232.43	19.18	251.61
3932	2004-04-30	10360	80.54	6.64	87.18
3933	2004-04-29	6537	301.80	24.90	326.70
3934	2004-04-26	7564	203.59	16.80	220.39
3935	2004-04-28	8756	385.00	31.76	416.76
3936	2004-04-15	10370	317.46	26.19	343.65
3937	2004-04-15	9821	285.84	23.58	309.42
3938	2004-04-06	9277	90.95	7.50	98.45
3939	2004-04-09	5327	113.52	9.37	122.89
3940	2004-04-16	2289	12.65	1.04	13.69
3941	2004-04-27	7625	318.40	26.27	344.67
3942	2004-04-19	8359	115.91	9.56	125.47
3943	2004-04-05	7036	4.43	0.37	4.80
3944	2004-04-26	11851	62.98	5.20	68.18
3945	2004-04-25	7643	158.49	13.08	171.57
3946	2004-04-29	10443	161.22	13.30	174.52
3947	2004-04-22	8483	58.02	4.79	62.81
3948	2004-04-07	5382	241.56	19.93	261.49
3949	2004-04-18	9363	145.87	12.03	157.90
3950	2004-04-06	6648	312.10	25.75	337.85
3951	2004-04-06	18106	132.46	10.93	143.39
3952	2004-04-18	16010	83.27	6.87	90.14
3953	2004-04-04	6262	165.08	13.62	178.70
3954	2004-04-22	19780	364.92	30.11	395.03
3955	2004-04-17	8405	252.20	20.81	273.01
3956	2004-04-22	6702	241.74	19.94	261.68
3957	2004-04-14	972	75.53	6.23	81.76
3958	2004-04-15	13953	283.31	23.37	306.68
3959	2004-04-11	16771	171.38	14.14	185.52
3960	2004-04-17	10750	103.12	8.51	111.63
3961	2004-04-10	14280	367.00	30.28	397.28
3962	2004-04-15	1148	264.36	21.81	286.17
3963	2004-04-22	9375	187.88	15.50	203.38
3964	2004-04-17	18929	27.31	2.25	29.56
3965	2004-04-17	2441	264.57	21.83	286.40
3966	2004-04-05	10343	173.06	14.28	187.34
3967	2004-04-22	3705	305.09	25.17	330.26
3968	2004-04-15	3393	232.50	19.18	251.68
3969	2004-04-13	9733	330.65	27.28	357.93
3970	2004-04-24	6436	144.22	11.90	156.12
3971	2004-04-09	9703	3.50	0.29	3.79
3972	2004-04-20	10272	175.46	14.48	189.94
3973	2004-04-15	7274	145.71	12.02	157.73
3974	2004-04-08	11931	3.44	0.28	3.72
3975	2004-04-06	12331	61.22	5.05	66.27
3976	2004-04-20	731	280.38	23.13	303.51
3977	2004-04-01	4295	1.90	0.16	2.06
3978	2004-04-09	996	154.30	12.73	167.03
3979	2004-04-26	1783	119.55	9.86	129.41
3980	2004-04-11	7015	84.45	6.97	91.42
3981	2004-04-11	798	101.27	8.35	109.62
3982	2004-04-05	3095	144.17	11.89	156.06
3983	2004-04-09	8769	226.14	18.66	244.80
3984	2004-04-01	13531	237.27	19.57	256.84
3985	2004-04-26	16393	293.29	24.20	317.49
3986	2004-04-01	3206	64.03	5.28	69.31
3987	2004-04-08	9771	109.27	9.01	118.28
3988	2004-04-07	12671	219.10	18.08	237.18
3989	2004-04-16	4035	306.72	25.30	332.02
3990	2004-04-10	1047	171.87	14.18	186.05
3991	2004-04-24	16957	269.98	22.27	292.25
3992	2004-04-22	1786	118.77	9.80	128.57
3993	2004-04-25	18843	305.89	25.24	331.13
3994	2004-04-18	13937	191.14	15.77	206.91
3995	2004-04-11	1374	343.94	28.38	372.32
3996	2004-04-14	18508	124.52	10.27	134.79
3997	2004-04-07	3390	227.17	18.74	245.91
3998	2004-04-22	4005	326.48	26.93	353.41
3999	2004-04-06	7327	18.07	1.49	19.56
4000	2004-04-29	6527	28.98	2.39	31.37
4001	2004-05-12	14005	350.60	28.92	379.52
4002	2004-05-25	12910	241.16	19.90	261.06
4003	2004-05-28	7707	242.29	19.99	262.28
4004	2004-05-28	2489	358.32	29.56	387.88
4005	2004-05-30	7577	123.71	10.21	133.92
4006	2004-05-16	35	198.77	16.40	215.17
4007	2004-05-21	15563	277.52	22.90	300.42
4008	2004-05-23	2069	44.22	3.65	47.87
4009	2004-05-07	10934	264.20	21.80	286.00
4010	2004-05-27	8326	361.29	29.81	391.10
4011	2004-05-16	2617	232.96	19.22	252.18
4012	2004-05-16	18110	383.52	31.64	415.16
4013	2004-05-14	2264	79.17	6.53	85.70
4014	2004-05-23	10154	284.83	23.50	308.33
4015	2004-05-26	5341	396.06	32.67	428.73
4016	2004-05-22	1069	187.57	15.47	203.04
4017	2004-05-06	14511	235.69	19.44	255.13
4018	2004-05-07	6791	122.73	10.13	132.86
4019	2004-05-31	4961	311.43	25.69	337.12
4020	2004-05-24	9078	309.48	25.53	335.01
4021	2004-05-14	1001	119.68	9.87	129.55
4022	2004-05-23	9057	151.02	12.46	163.48
4023	2004-05-09	5087	112.41	9.27	121.68
4024	2004-05-04	9029	17.50	1.44	18.94
4025	2004-05-07	14248	230.37	19.01	249.38
4026	2004-05-21	19887	145.73	12.02	157.75
4027	2004-05-28	19260	69.30	5.72	75.02
4028	2004-05-05	17101	361.72	29.84	391.56
4029	2004-05-22	15641	47.77	3.94	51.71
4030	2004-05-07	18016	369.66	30.50	400.16
4031	2004-05-02	11614	137.22	11.32	148.54
4032	2004-05-10	7243	181.72	14.99	196.71
4033	2004-05-12	12846	307.89	25.40	333.29
4034	2004-05-19	10551	304.63	25.13	329.76
4035	2004-05-25	1972	146.77	12.11	158.88
4036	2004-05-26	13586	286.93	23.67	310.60
4037	2004-05-03	1268	130.29	10.75	141.04
4038	2004-05-09	17505	40.87	3.37	44.24
4039	2004-05-30	12954	16.19	1.34	17.53
4040	2004-05-28	143	216.09	17.83	233.92
4041	2004-05-29	12971	1.54	0.13	1.67
4042	2004-05-30	15798	336.53	27.76	364.29
4043	2004-05-05	10254	153.79	12.69	166.48
4044	2004-05-04	1699	235.22	19.41	254.63
4045	2004-05-29	15150	171.06	14.11	185.17
4046	2004-05-18	4162	297.23	24.52	321.75
4047	2004-05-08	10033	1.19	0.10	1.29
4048	2004-05-18	18535	156.98	12.95	169.93
4049	2004-05-10	5426	186.46	15.38	201.84
4050	2004-05-15	17583	238.66	19.69	258.35
4051	2004-05-21	8081	346.15	28.56	374.71
4052	2004-05-03	16498	218.13	18.00	236.13
4053	2004-05-10	17750	203.17	16.76	219.93
4054	2004-05-27	19585	216.25	17.84	234.09
4055	2004-05-09	14407	235.93	19.46	255.39
4056	2004-05-31	8543	50.11	4.13	54.24
4057	2004-05-16	4251	235.07	19.39	254.46
4058	2004-05-13	8926	12.94	1.07	14.01
4059	2004-05-20	6638	194.48	16.04	210.52
4060	2004-05-05	2214	381.65	31.49	413.14
4061	2004-05-26	5193	372.57	30.74	403.31
4062	2004-05-24	5903	107.35	8.86	116.21
4063	2004-05-23	6534	337.16	27.82	364.98
4064	2004-05-11	11084	356.57	29.42	385.99
4065	2004-05-22	3467	135.15	11.15	146.30
4066	2004-05-24	3764	2.13	0.18	2.31
4067	2004-05-07	11834	22.60	1.86	24.46
4068	2004-05-19	15415	310.95	25.65	336.60
4069	2004-05-09	10138	45.49	3.75	49.24
4070	2004-05-24	19600	222.49	18.36	240.85
4071	2004-05-29	15023	97.06	8.01	105.07
4072	2004-05-20	3929	137.09	11.31	148.40
4073	2004-05-10	18512	337.78	27.87	365.65
4074	2004-05-18	9474	238.66	19.69	258.35
4075	2004-05-30	18531	17.51	1.44	18.95
4076	2004-05-21	14690	314.13	25.92	340.05
4077	2004-05-23	16557	234.05	19.31	253.36
4078	2004-05-25	3174	64.88	5.35	70.23
4079	2004-05-21	2662	5.25	0.43	5.68
4080	2004-05-12	11236	175.78	14.50	190.28
4081	2004-05-01	12333	223.99	18.48	242.47
4082	2004-05-22	7213	326.10	26.90	353.00
4083	2004-05-08	15065	229.38	18.92	248.30
4084	2004-05-22	11439	2.66	0.22	2.88
4085	2004-05-23	9253	332.37	27.42	359.79
4086	2004-05-11	2736	385.89	31.84	417.73
4087	2004-05-19	12600	18.86	1.56	20.42
4088	2004-05-31	14424	319.83	26.39	346.22
4089	2004-05-05	12078	350.05	28.88	378.93
4090	2004-05-11	17064	225.86	18.63	244.49
4091	2004-05-28	16691	0.78	0.06	0.84
4092	2004-05-20	4197	231.41	19.09	250.50
4093	2004-05-30	17374	315.86	26.06	341.92
4094	2004-05-18	11664	256.65	21.17	277.82
4095	2004-05-31	5058	348.73	28.77	377.50
4096	2004-05-22	1613	84.17	6.94	91.11
4097	2004-05-30	6644	175.71	14.50	190.21
4098	2004-05-29	16974	294.77	24.32	319.09
4099	2004-05-18	1384	52.64	4.34	56.98
4100	2004-05-21	19339	27.07	2.23	29.30
4101	2004-05-30	14079	173.70	14.33	188.03
4102	2004-05-19	6901	185.79	15.33	201.12
4103	2004-05-01	8297	263.11	21.71	284.82
4104	2004-05-16	16730	388.10	32.02	420.12
4105	2004-05-26	18274	254.53	21.00	275.53
4106	2004-05-16	10912	284.96	23.51	308.47
4107	2004-05-18	1074	356.97	29.45	386.42
4108	2004-05-23	16840	251.77	20.77	272.54
4109	2004-05-20	17851	103.14	8.51	111.65
4110	2004-05-28	16100	226.39	18.68	245.07
4111	2004-05-03	14939	354.04	29.21	383.25
4112	2004-05-21	92	325.90	26.89	352.79
4113	2004-05-25	8799	285.42	23.55	308.97
4114	2004-05-04	6127	331.90	27.38	359.28
4115	2004-05-07	451	307.37	25.36	332.73
4116	2004-05-16	174	324.27	26.75	351.02
4117	2004-05-28	11499	360.41	29.73	390.14
4118	2004-05-16	146	237.36	19.58	256.94
4119	2004-05-04	19164	328.62	27.11	355.73
4120	2004-05-11	19058	60.28	4.97	65.25
4121	2004-05-24	13424	90.28	7.45	97.73
4122	2004-05-08	16906	47.30	3.90	51.20
4123	2004-05-16	4636	187.05	15.43	202.48
4124	2004-05-08	6218	382.37	31.55	413.92
4125	2004-05-14	17532	306.73	25.31	332.04
4126	2004-05-31	5620	38.12	3.14	41.26
4127	2004-05-26	8896	352.39	29.07	381.46
4128	2004-05-02	16106	335.19	27.65	362.84
4129	2004-05-14	17072	256.26	21.14	277.40
4130	2004-05-14	764	72.65	5.99	78.64
4131	2004-05-08	5130	19.09	1.57	20.66
4132	2004-05-02	1772	282.11	23.27	305.38
4133	2004-05-11	1948	253.21	20.89	274.10
4134	2004-05-11	11784	62.03	5.12	67.15
4135	2004-05-15	7695	78.48	6.47	84.95
4136	2004-05-12	19721	100.79	8.32	109.11
4137	2004-05-20	13637	342.66	28.27	370.93
4138	2004-05-17	6185	133.36	11.00	144.36
4139	2004-05-27	1726	118.30	9.76	128.06
4140	2004-05-09	7203	88.26	7.28	95.54
4141	2004-05-03	13437	354.75	29.27	384.02
4142	2004-05-03	13623	54.44	4.49	58.93
4143	2004-05-18	4349	174.07	14.36	188.43
4144	2004-05-16	7776	262.32	21.64	283.96
4145	2004-05-29	13553	327.77	27.04	354.81
4146	2004-05-07	3989	163.16	13.46	176.62
4147	2004-05-17	3150	223.00	18.40	241.40
4148	2004-05-04	7845	221.35	18.26	239.61
4149	2004-05-19	2667	358.02	29.54	387.56
4150	2004-05-24	10219	51.65	4.26	55.91
4151	2004-05-03	7404	173.75	14.33	188.08
4152	2004-05-01	10886	227.23	18.75	245.98
4153	2004-05-05	828	198.40	16.37	214.77
4154	2004-05-30	12990	177.22	14.62	191.84
4155	2004-05-09	10678	358.79	29.60	388.39
4156	2004-05-21	1203	292.86	24.16	317.02
4157	2004-05-01	16619	169.76	14.01	183.77
4158	2004-05-16	16278	212.01	17.49	229.50
4159	2004-05-28	3360	253.01	20.87	273.88
4160	2004-05-02	2428	210.06	17.33	227.39
4161	2004-05-12	17619	188.75	15.57	204.32
4162	2004-05-12	644	64.45	5.32	69.77
4163	2004-05-12	6773	236.68	19.53	256.21
4164	2004-05-28	18540	367.42	30.31	397.73
4165	2004-05-16	258	51.18	4.22	55.40
4166	2004-05-24	8582	67.34	5.56	72.90
4167	2004-05-31	1689	24.97	2.06	27.03
4168	2004-05-02	3389	345.02	28.46	373.48
4169	2004-05-12	7498	184.13	15.19	199.32
4170	2004-05-18	15404	100.60	8.30	108.90
4171	2004-05-06	6546	311.43	25.69	337.12
4172	2004-05-12	4734	20.15	1.66	21.81
4173	2004-05-28	13756	346.98	28.63	375.61
4174	2004-05-08	2964	37.05	3.06	40.11
4175	2004-05-04	11791	94.52	7.80	102.32
4176	2004-05-15	14705	89.06	7.35	96.41
4177	2004-05-06	5436	81.58	6.73	88.31
4178	2004-05-30	4018	383.21	31.61	414.82
4179	2004-05-22	671	187.61	15.48	203.09
4180	2004-05-20	18376	95.74	7.90	103.64
4181	2004-05-18	53	323.19	26.66	349.85
4182	2004-05-28	6496	224.03	18.48	242.51
4183	2004-05-25	2662	69.74	5.75	75.49
4184	2004-05-16	14917	102.72	8.47	111.19
4185	2004-05-30	18065	390.33	32.20	422.53
4186	2004-05-19	5901	24.76	2.04	26.80
4187	2004-05-12	16079	218.62	18.04	236.66
4188	2004-05-26	14635	65.27	5.38	70.65
4189	2004-05-29	10870	145.29	11.99	157.28
4190	2004-05-24	15581	172.23	14.21	186.44
4191	2004-05-23	13704	374.10	30.86	404.96
4192	2004-05-08	8385	237.05	19.56	256.61
4193	2004-05-09	6294	2.72	0.22	2.94
4194	2004-05-19	13303	350.97	28.96	379.93
4195	2004-05-25	16799	143.33	11.82	155.15
4196	2004-05-21	6041	251.64	20.76	272.40
4197	2004-05-27	8212	42.50	3.51	46.01
4198	2004-05-03	13371	58.25	4.81	63.06
4199	2004-05-24	247	114.68	9.46	124.14
4200	2004-05-08	11831	13.89	1.15	15.04
4201	2004-05-19	14759	192.17	15.85	208.02
4202	2004-05-06	5734	109.98	9.07	119.05
4203	2004-05-11	11346	205.19	16.93	222.12
4204	2004-05-04	8218	70.55	5.82	76.37
4205	2004-05-24	19273	3.54	0.29	3.83
4206	2004-05-08	7325	283.40	23.38	306.78
4207	2004-05-16	9859	256.49	21.16	277.65
4208	2004-05-22	13077	63.65	5.25	68.90
4209	2004-05-02	92	152.71	12.60	165.31
4210	2004-05-28	10322	254.68	21.01	275.69
4211	2004-05-29	11760	247.97	20.46	268.43
4212	2004-05-26	10128	1.96	0.16	2.12
4213	2004-05-22	6836	20.87	1.72	22.59
4214	2004-05-17	12734	170.72	14.08	184.80
4215	2004-05-09	17675	122.80	10.13	132.93
4216	2004-05-19	6503	256.45	21.16	277.61
4217	2004-05-15	2096	199.83	16.49	216.32
4218	2004-05-11	6466	121.29	10.01	131.30
4219	2004-05-12	12591	277.94	22.93	300.87
4220	2004-05-24	4260	45.72	3.77	49.49
4221	2004-05-18	17297	341.62	28.18	369.80
4222	2004-05-08	13331	192.04	15.84	207.88
4223	2004-05-03	18047	388.84	32.08	420.92
4224	2004-05-22	17244	270.04	22.28	292.32
4225	2004-05-24	12012	246.51	20.34	266.85
4226	2004-05-09	14170	88.45	7.30	95.75
4227	2004-05-30	12277	121.15	9.99	131.14
4228	2004-05-05	1952	32.30	2.66	34.96
4229	2004-05-30	13638	173.34	14.30	187.64
4230	2004-05-29	17626	254.77	21.02	275.79
4231	2004-05-27	8989	338.44	27.92	366.36
4232	2004-05-25	11910	251.91	20.78	272.69
4233	2004-05-26	638	297.20	24.52	321.72
4234	2004-05-10	9566	397.56	32.80	430.36
4235	2004-05-08	4240	317.49	26.19	343.68
4236	2004-05-20	13010	314.94	25.98	340.92
4237	2004-05-08	12129	324.01	26.73	350.74
4238	2004-05-06	17503	157.60	13.00	170.60
4239	2004-05-04	8914	76.19	6.29	82.48
4240	2004-05-27	19268	100.61	8.30	108.91
4241	2004-05-04	16075	230.26	19.00	249.26
4242	2004-05-27	10440	397.00	32.75	429.75
4243	2004-05-15	15747	265.05	21.87	286.92
4244	2004-05-28	5868	135.16	11.15	146.31
4245	2004-05-05	4311	267.73	22.09	289.82
4246	2004-05-24	11818	234.96	19.38	254.34
4247	2004-05-05	12574	49.03	4.04	53.07
4248	2004-05-06	6441	83.54	6.89	90.43
4249	2004-05-23	9287	77.51	6.39	83.90
4250	2004-05-09	10682	383.78	31.66	415.44
4251	2004-05-06	3580	98.67	8.14	106.81
4252	2004-05-21	6932	312.70	25.80	338.50
4253	2004-05-15	18760	19.76	1.63	21.39
4254	2004-05-15	12901	315.55	26.03	341.58
4255	2004-05-01	12166	23.98	1.98	25.96
4256	2004-05-18	11814	317.50	26.19	343.69
4257	2004-05-10	9035	260.04	21.45	281.49
4258	2004-05-28	15555	268.55	22.16	290.71
4259	2004-05-30	14963	187.43	15.46	202.89
4260	2004-05-08	2920	292.51	24.13	316.64
4261	2004-05-29	1039	130.79	10.79	141.58
4262	2004-05-16	9876	399.27	32.94	432.21
4263	2004-05-24	19969	381.55	31.48	413.03
4264	2004-05-25	18189	173.46	14.31	187.77
4265	2004-05-11	5452	117.65	9.71	127.36
4266	2004-05-03	1635	212.79	17.56	230.35
4267	2004-05-30	14362	83.86	6.92	90.78
4268	2004-05-22	16613	52.82	4.36	57.18
4269	2004-05-18	11561	258.64	21.34	279.98
4270	2004-05-19	15720	283.47	23.39	306.86
4271	2004-05-09	10276	311.16	25.67	336.83
4272	2004-05-23	8547	68.25	5.63	73.88
4273	2004-05-02	17493	234.74	19.37	254.11
4274	2004-05-17	10646	23.10	1.91	25.01
4275	2004-05-22	18880	131.52	10.85	142.37
4276	2004-05-15	16451	25.90	2.14	28.04
4277	2004-05-14	11562	190.24	15.69	205.93
4278	2004-05-04	10743	361.16	29.80	390.96
4279	2004-05-20	11462	325.93	26.89	352.82
4280	2004-05-22	7710	331.42	27.34	358.76
4281	2004-05-06	4579	278.14	22.95	301.09
4282	2004-05-18	12969	90.58	7.47	98.05
4283	2004-05-11	14344	373.90	30.85	404.75
4284	2004-05-12	12862	4.33	0.36	4.69
4285	2004-05-21	15466	22.33	1.84	24.17
4286	2004-05-04	9642	327.26	27.00	354.26
4287	2004-05-24	16829	215.74	17.80	233.54
4288	2004-05-06	17892	315.02	25.99	341.01
4289	2004-05-02	15117	240.12	19.81	259.93
4290	2004-05-16	18956	377.64	31.16	408.80
4291	2004-05-22	1916	5.45	0.45	5.90
4292	2004-05-10	4569	269.27	22.21	291.48
4293	2004-05-23	11815	341.72	28.19	369.91
4294	2004-05-23	14427	214.32	17.68	232.00
4295	2004-05-16	3578	135.66	11.19	146.85
4296	2004-05-23	14738	127.81	10.54	138.35
4297	2004-05-23	11228	126.26	10.42	136.68
4298	2004-05-04	17543	39.38	3.25	42.63
4299	2004-05-17	5292	117.63	9.70	127.33
4300	2004-05-29	8486	274.08	22.61	296.69
4301	2004-05-09	2309	380.65	31.40	412.05
4302	2004-05-05	1269	343.63	28.35	371.98
4303	2004-05-28	8099	125.44	10.35	135.79
4304	2004-05-25	17136	57.61	4.75	62.36
4305	2004-05-03	10577	194.31	16.03	210.34
4306	2004-05-27	19590	155.05	12.79	167.84
4307	2004-05-26	285	279.49	23.06	302.55
4308	2004-05-07	1936	344.77	28.44	373.21
4309	2004-05-17	4245	83.65	6.90	90.55
4310	2004-05-06	5062	67.91	5.60	73.51
4311	2004-05-31	16023	0.63	0.05	0.68
4312	2004-05-14	5088	51.81	4.27	56.08
4313	2004-05-07	6683	233.49	19.26	252.75
4314	2004-05-07	2937	311.49	25.70	337.19
4315	2004-05-20	6172	31.80	2.62	34.42
4316	2004-05-13	7475	373.64	30.83	404.47
4317	2004-05-11	571	38.10	3.14	41.24
4318	2004-05-24	10452	1.92	0.16	2.08
4319	2004-05-07	9548	30.17	2.49	32.66
4320	2004-05-14	17311	22.14	1.83	23.97
4321	2004-05-21	18738	272.87	22.51	295.38
4322	2004-05-18	5578	68.77	5.67	74.44
4323	2004-05-05	15262	310.13	25.59	335.72
4324	2004-05-02	14134	61.27	5.05	66.32
4325	2004-05-13	3946	76.95	6.35	83.30
4326	2004-05-30	18982	233.59	19.27	252.86
4327	2004-05-02	19755	86.73	7.16	93.89
4328	2004-05-23	19888	119.77	9.88	129.65
4329	2004-05-21	13362	100.93	8.33	109.26
4330	2004-05-21	2017	30.15	2.49	32.64
4331	2004-05-17	8319	356.36	29.40	385.76
4332	2004-05-16	8065	116.14	9.58	125.72
4333	2004-05-29	11325	5.92	0.49	6.41
4334	2004-05-16	10076	80.26	6.62	86.88
4335	2004-05-13	4970	131.56	10.85	142.41
4336	2004-05-26	9943	246.17	20.31	266.48
4337	2004-05-04	12359	346.54	28.59	375.13
4338	2004-05-12	1980	372.29	30.71	403.00
4339	2004-05-24	16275	16.89	1.39	18.28
4340	2004-05-26	4477	282.88	23.34	306.22
4341	2004-05-13	2720	10.93	0.90	11.83
4342	2004-05-20	8349	325.11	26.82	351.93
4343	2004-05-30	2980	179.99	14.85	194.84
4344	2004-05-14	10843	245.29	20.24	265.53
4345	2004-05-09	3785	101.91	8.41	110.32
4346	2004-05-12	19678	284.38	23.46	307.84
4347	2004-05-13	18286	187.96	15.51	203.47
4348	2004-05-27	1743	291.97	24.09	316.06
4349	2004-05-26	6977	136.12	11.23	147.35
4350	2004-05-11	17588	332.04	27.39	359.43
4351	2004-05-09	13185	249.72	20.60	270.32
4352	2004-05-14	7150	268.26	22.13	290.39
4353	2004-05-21	7294	10.40	0.86	11.26
4354	2004-05-10	8198	199.17	16.43	215.60
4355	2004-05-31	4837	40.98	3.38	44.36
4356	2004-05-04	792	67.56	5.57	73.13
4357	2004-05-12	15633	222.26	18.34	240.60
4358	2004-05-10	1643	189.25	15.61	204.86
4359	2004-05-05	7971	130.49	10.77	141.26
4360	2004-05-05	8761	268.32	22.14	290.46
4361	2004-05-11	12967	160.74	13.26	174.00
4362	2004-05-20	9026	175.37	14.47	189.84
4363	2004-05-24	1579	292.58	24.14	316.72
4364	2004-05-17	14725	207.90	17.15	225.05
4365	2004-05-22	14167	209.18	17.26	226.44
4366	2004-05-23	8845	3.53	0.29	3.82
4367	2004-05-09	5267	8.09	0.67	8.76
4368	2004-05-06	2718	161.15	13.29	174.44
4369	2004-05-03	6784	131.55	10.85	142.40
4370	2004-05-07	11585	97.26	8.02	105.28
4371	2004-05-18	14085	116.84	9.64	126.48
4372	2004-05-03	1811	330.70	27.28	357.98
4373	2004-05-13	17840	63.20	5.21	68.41
4374	2004-05-31	8924	246.80	20.36	267.16
4375	2004-05-11	19686	227.24	18.75	245.99
4376	2004-05-29	6638	391.63	32.31	423.94
4377	2004-05-16	5220	3.92	0.32	4.24
4378	2004-05-10	4434	158.40	13.07	171.47
4379	2004-05-26	12776	155.22	12.81	168.03
4380	2004-05-02	10857	252.68	20.85	273.53
4381	2004-05-30	19398	108.23	8.93	117.16
4382	2004-05-13	11391	68.30	5.63	73.93
4383	2004-05-13	1279	187.46	15.47	202.93
4384	2004-05-03	13536	180.58	14.90	195.48
4385	2004-05-12	2047	126.83	10.46	137.29
4386	2004-05-11	18239	31.08	2.56	33.64
4387	2004-05-28	14338	187.28	15.45	202.73
4388	2004-05-14	12805	387.28	31.95	419.23
4389	2004-05-19	15680	161.56	13.33	174.89
4390	2004-05-23	7936	127.22	10.50	137.72
4391	2004-05-31	6016	5.24	0.43	5.67
4392	2004-05-12	14082	9.41	0.78	10.19
4393	2004-05-22	4182	144.01	11.88	155.89
4394	2004-05-11	3879	116.74	9.63	126.37
4395	2004-05-25	18586	330.20	27.24	357.44
4396	2004-05-04	6739	179.48	14.81	194.29
4397	2004-05-05	14924	156.15	12.88	169.03
4398	2004-05-20	11363	242.74	20.03	262.77
4399	2004-05-09	18661	329.51	27.18	356.69
4400	2004-05-24	9736	308.17	25.42	333.59
4401	2004-05-13	16356	179.93	14.84	194.77
4402	2004-05-20	7308	281.77	23.25	305.02
4403	2004-05-07	11020	121.30	10.01	131.31
4404	2004-05-09	301	175.63	14.49	190.12
4405	2004-05-05	7434	97.07	8.01	105.08
4406	2004-05-20	15245	371.55	30.65	402.20
4407	2004-05-19	13619	45.54	3.76	49.30
4408	2004-05-04	14859	306.30	25.27	331.57
4409	2004-05-13	15023	160.21	13.22	173.43
4410	2004-05-24	10836	87.69	7.23	94.92
4411	2004-05-24	9670	4.89	0.40	5.29
4412	2004-05-01	10860	347.49	28.67	376.16
4413	2004-05-24	7151	129.50	10.68	140.18
4414	2004-05-31	2657	186.77	15.41	202.18
4415	2004-05-04	8274	146.49	12.09	158.58
4416	2004-05-21	1118	313.55	25.87	339.42
4417	2004-05-06	17359	71.53	5.90	77.43
4418	2004-05-04	12941	366.75	30.26	397.01
4419	2004-05-14	6688	3.17	0.26	3.43
4420	2004-05-25	7606	68.45	5.65	74.10
4421	2004-05-18	18283	24.04	1.98	26.02
4422	2004-05-11	9421	315.39	26.02	341.41
4423	2004-05-23	8057	161.98	13.36	175.34
4424	2004-05-12	15198	4.45	0.37	4.82
4425	2004-05-09	5532	352.39	29.07	381.46
4426	2004-05-12	4556	139.22	11.49	150.71
4427	2004-05-16	16161	378.40	31.22	409.62
4428	2004-05-08	353	278.66	22.99	301.65
4429	2004-05-02	7931	61.05	5.04	66.09
4430	2004-05-19	8872	212.41	17.52	229.93
4431	2004-05-01	17194	160.58	13.25	173.83
4432	2004-05-15	2859	60.78	5.01	65.79
4433	2004-05-22	8083	35.04	2.89	37.93
4434	2004-05-21	8693	318.98	26.32	345.30
4435	2004-05-23	9946	329.49	27.18	356.67
4436	2004-05-12	12437	214.77	17.72	232.49
4437	2004-05-06	3842	40.66	3.35	44.01
4438	2004-05-18	12528	242.99	20.05	263.04
4439	2004-05-15	14382	281.85	23.25	305.10
4440	2004-05-26	7039	208.06	17.16	225.22
4441	2004-05-15	19795	63.10	5.21	68.31
4442	2004-05-03	3794	255.61	21.09	276.70
4443	2004-05-24	11300	382.55	31.56	414.11
4444	2004-05-02	4099	209.53	17.29	226.82
4445	2004-05-12	19890	127.82	10.55	138.37
4446	2004-05-17	7007	67.53	5.57	73.10
4447	2004-05-30	12736	89.62	7.39	97.01
4448	2004-05-26	16476	179.71	14.83	194.54
4449	2004-05-28	8618	312.17	25.75	337.92
4450	2004-05-01	3014	333.79	27.54	361.33
4451	2004-05-25	11744	370.73	30.59	401.32
4452	2004-05-22	16431	305.65	25.22	330.87
4453	2004-05-21	8409	330.28	27.25	357.53
4454	2004-05-21	16716	42.53	3.51	46.04
4455	2004-05-19	9025	103.38	8.53	111.91
4456	2004-05-17	1874	223.14	18.41	241.55
4457	2004-05-08	5470	236.74	19.53	256.27
4458	2004-05-23	9144	286.85	23.67	310.52
4459	2004-05-02	15906	273.52	22.57	296.09
4460	2004-05-15	7180	317.75	26.21	343.96
4461	2004-05-21	19102	22.18	1.83	24.01
4462	2004-05-25	6991	126.34	10.42	136.76
4463	2004-05-31	12526	68.96	5.69	74.65
4464	2004-05-03	4603	148.29	12.23	160.52
4465	2004-05-02	3183	388.46	32.05	420.51
4466	2004-05-09	1158	309.64	25.55	335.19
4467	2004-05-31	10429	193.66	15.98	209.64
4468	2004-05-14	18179	355.92	29.36	385.28
4469	2004-05-13	5789	207.39	17.11	224.50
4470	2004-05-06	6721	245.09	20.22	265.31
4471	2004-05-14	7450	215.19	17.75	232.94
4472	2004-05-27	17419	86.64	7.15	93.79
4473	2004-05-01	6853	376.00	31.02	407.02
4474	2004-05-11	12213	166.38	13.73	180.11
4475	2004-05-20	14258	208.57	17.21	225.78
4476	2004-05-11	13277	368.94	30.44	399.38
4477	2004-05-22	4568	303.22	25.02	328.24
4478	2004-05-08	18157	35.95	2.97	38.92
4479	2004-05-15	14006	94.86	7.83	102.69
4480	2004-05-25	19798	108.73	8.97	117.70
4481	2004-05-06	5156	116.63	9.62	126.25
4482	2004-05-05	1599	204.97	16.91	221.88
4483	2004-05-26	8598	219.42	18.10	237.52
4484	2004-05-04	7437	219.08	18.07	237.15
4485	2004-05-19	11397	204.35	16.86	221.21
4486	2004-05-13	7344	116.75	9.63	126.38
4487	2004-05-11	9767	273.88	22.60	296.48
4488	2004-05-12	2166	390.80	32.24	423.04
4489	2004-05-04	1459	294.48	24.29	318.77
4490	2004-05-13	17355	164.73	13.59	178.32
4491	2004-05-30	19884	346.16	28.56	374.72
4492	2004-05-24	15236	383.76	31.66	415.42
4493	2004-05-16	4850	64.72	5.34	70.06
4494	2004-05-17	145	1.91	0.16	2.07
4495	2004-05-28	1750	244.23	20.15	264.38
4496	2004-05-11	18104	15.30	1.26	16.56
4497	2004-05-19	17422	292.55	24.14	316.69
4498	2004-05-11	686	391.61	32.31	423.92
4499	2004-05-04	8748	285.80	23.58	309.38
4500	2004-05-26	8015	14.51	1.20	15.71
4501	2004-05-19	5056	248.04	20.46	268.50
4502	2004-05-29	13953	185.33	15.29	200.62
4503	2004-05-06	13229	218.34	18.01	236.35
4504	2004-05-27	5647	155.50	12.83	168.33
4505	2004-05-22	8308	365.95	30.19	396.14
4506	2004-05-07	12204	344.57	28.43	373.00
4507	2004-05-16	16729	49.79	4.11	53.90
4508	2004-05-20	17337	115.85	9.56	125.41
4509	2004-05-12	14790	77.47	6.39	83.86
4510	2004-05-10	7077	263.29	21.72	285.01
4511	2004-05-27	5644	153.49	12.66	166.15
4512	2004-05-12	10194	32.80	2.71	35.51
4513	2004-05-08	19739	22.11	1.82	23.93
4514	2004-05-01	2803	329.51	27.18	356.69
4515	2004-05-08	13384	322.56	26.61	349.17
4516	2004-05-25	14790	260.20	21.47	281.67
4517	2004-05-07	612	233.16	19.24	252.40
4518	2004-05-28	6630	326.91	26.97	353.88
4519	2004-05-12	15351	311.31	25.68	336.99
4520	2004-05-24	7526	394.40	32.54	426.94
4521	2004-05-11	1568	65.19	5.38	70.57
4522	2004-05-09	10399	356.77	29.43	386.20
4523	2004-05-21	12079	272.48	22.48	294.96
4524	2004-05-25	15213	161.34	13.31	174.65
4525	2004-05-03	16095	375.65	30.99	406.64
4526	2004-05-06	12202	398.52	32.88	431.40
4527	2004-05-09	14468	321.45	26.52	347.97
4528	2004-05-15	15668	20.82	1.72	22.54
4529	2004-05-03	6990	103.88	8.57	112.45
4530	2004-05-30	19720	8.15	0.67	8.82
4531	2004-05-13	4580	366.30	30.22	396.52
4532	2004-05-10	9636	320.07	26.41	346.48
4533	2004-05-22	2314	132.29	10.91	143.20
4534	2004-05-19	9885	45.33	3.74	49.07
4535	2004-05-22	13840	187.49	15.47	202.96
4536	2004-05-23	5534	373.62	30.82	404.44
4537	2004-05-27	11862	107.34	8.86	116.20
4538	2004-05-28	10252	47.76	3.94	51.70
4539	2004-05-16	4218	129.33	10.67	140.00
4540	2004-05-23	13512	89.56	7.39	96.95
4541	2004-05-21	17104	64.44	5.32	69.76
4542	2004-05-04	3137	105.93	8.74	114.67
4543	2004-05-14	5792	388.39	32.04	420.43
4544	2004-05-06	14520	222.73	18.38	241.11
4545	2004-05-22	365	337.22	27.82	365.04
4546	2004-05-20	10612	333.94	27.55	361.49
4547	2004-05-14	6886	393.40	32.46	425.86
4548	2004-05-03	19473	120.64	9.95	130.59
4549	2004-05-11	613	157.96	13.03	170.99
4550	2004-05-01	7362	198.48	16.37	214.85
4551	2004-05-14	17166	253.12	20.88	274.00
4552	2004-05-23	16111	268.96	22.19	291.15
4553	2004-05-21	56	159.52	13.16	172.68
4554	2004-05-10	6547	170.84	14.09	184.93
4555	2004-05-20	19180	358.45	29.57	388.02
4556	2004-05-11	2565	164.56	13.58	178.14
4557	2004-05-17	2556	155.13	12.80	167.93
4558	2004-05-25	9685	21.32	1.76	23.08
4559	2004-05-09	302	106.27	8.77	115.04
4560	2004-05-10	10144	379.81	31.33	411.14
4561	2004-05-06	8990	19.65	1.62	21.27
4562	2004-05-30	4815	172.78	14.25	187.03
4563	2004-05-12	19077	78.28	6.46	84.74
4564	2004-05-11	15362	99.05	8.17	107.22
4565	2004-05-18	19158	327.10	26.99	354.09
4566	2004-05-08	9719	269.98	22.27	292.25
4567	2004-05-20	10173	352.52	29.08	381.60
4568	2004-05-14	18408	378.25	31.21	409.46
4569	2004-05-25	2446	377.28	31.13	408.41
4570	2004-05-03	3174	25.86	2.13	27.99
4571	2004-05-31	2052	294.78	24.32	319.10
4572	2004-05-27	6621	265.68	21.92	287.60
4573	2004-05-19	6803	41.07	3.39	44.46
4574	2004-05-05	433	109.12	9.00	118.12
4575	2004-05-08	11688	5.63	0.46	6.09
4576	2004-05-01	5134	192.27	15.86	208.13
4577	2004-05-11	304	84.97	7.01	91.98
4578	2004-05-31	6600	55.64	4.59	60.23
4579	2004-05-08	15142	63.29	5.22	68.51
4580	2004-05-04	14670	109.23	9.01	118.24
4581	2004-05-20	13073	234.56	19.35	253.91
4582	2004-05-25	5951	361.49	29.82	391.31
4583	2004-05-27	18727	106.36	8.77	115.13
4584	2004-05-05	19490	220.51	18.19	238.70
4585	2004-05-13	13595	377.34	31.13	408.47
4586	2004-05-07	18536	310.62	25.63	336.25
4587	2004-05-03	17453	20.09	1.66	21.75
4588	2004-05-13	12761	301.19	24.85	326.04
4589	2004-05-20	2550	394.85	32.58	427.43
4590	2004-05-26	14355	101.83	8.40	110.23
4591	2004-05-04	12921	308.01	25.41	333.42
4592	2004-05-10	1357	292.88	24.16	317.04
4593	2004-05-27	15163	38.07	3.14	41.21
4594	2004-05-01	18540	132.83	10.96	143.79
4595	2004-05-23	1750	233.42	19.26	252.68
4596	2004-05-16	10559	235.72	19.45	255.17
4597	2004-05-19	8719	33.01	2.72	35.73
4598	2004-05-17	9616	183.23	15.12	198.35
4599	2004-05-28	8472	239.15	19.73	258.88
4600	2004-05-13	16269	304.06	25.08	329.14
4601	2004-05-14	19918	329.99	27.22	357.21
4602	2004-05-19	5591	45.06	3.72	48.78
4603	2004-05-26	8272	100.17	8.26	108.43
4604	2004-05-07	16622	42.51	3.51	46.02
4605	2004-05-31	13198	222.54	18.36	240.90
4606	2004-05-29	1116	148.45	12.25	160.70
4607	2004-05-30	9292	140.78	11.61	152.39
4608	2004-05-16	10467	386.84	31.91	418.75
4609	2004-05-16	7515	356.24	29.39	385.63
4610	2004-05-26	10648	70.31	5.80	76.11
4611	2004-05-19	8896	31.71	2.62	34.33
4612	2004-05-07	5404	59.94	4.95	64.89
4613	2004-05-05	17308	129.65	10.70	140.35
4614	2004-05-02	379	366.13	30.21	396.34
4615	2004-05-17	19807	295.06	24.34	319.40
4616	2004-05-11	17026	103.09	8.50	111.59
4617	2004-05-12	13824	85.65	7.07	92.72
4618	2004-05-21	2052	107.86	8.90	116.76
4619	2004-05-07	4202	66.63	5.50	72.13
4620	2004-05-09	17676	19.00	1.57	20.57
4621	2004-05-07	18198	79.59	6.57	86.16
4622	2004-05-27	11804	317.73	26.21	343.94
4623	2004-05-12	2454	154.14	12.72	166.86
4624	2004-05-28	15658	69.20	5.71	74.91
4625	2004-05-19	7848	342.23	28.23	370.46
4626	2004-05-29	10333	21.74	1.79	23.53
4627	2004-05-28	10014	285.61	23.56	309.17
4628	2004-05-31	2594	168.32	13.89	182.21
4629	2004-05-03	12326	324.05	26.73	350.78
4630	2004-05-03	16386	152.90	12.61	165.51
4631	2004-05-27	3174	364.01	30.03	394.04
4632	2004-05-04	19538	101.83	8.40	110.23
4633	2004-05-29	5470	125.29	10.34	135.63
4634	2004-05-03	5841	176.17	14.53	190.70
4635	2004-05-16	8546	1.22	0.10	1.32
4636	2004-05-11	16970	17.89	1.48	19.37
4637	2004-05-23	8236	244.75	20.19	264.94
4638	2004-05-12	11457	278.07	22.94	301.01
4639	2004-05-07	7468	50.18	4.14	54.32
4640	2004-05-19	11991	267.94	22.11	290.05
4641	2004-05-07	15397	377.98	31.18	409.16
4642	2004-05-29	9632	70.37	5.81	76.18
4643	2004-05-13	18893	123.83	10.22	134.05
4644	2004-05-22	7575	71.54	5.90	77.44
4645	2004-05-18	8097	28.98	2.39	31.37
4646	2004-05-13	16762	195.90	16.16	212.06
4647	2004-05-06	6388	393.79	32.49	426.28
4648	2004-05-06	7818	137.67	11.36	149.03
4649	2004-05-08	10037	58.38	4.82	63.20
4650	2004-05-25	2663	15.96	1.32	17.28
4651	2004-05-12	16449	139.01	11.47	150.48
4652	2004-05-08	15352	362.95	29.94	392.89
4653	2004-05-15	10634	27.40	2.26	29.66
4654	2004-05-07	6921	157.90	13.03	170.93
4655	2004-05-04	14651	48.63	4.01	52.64
4656	2004-05-31	19858	335.35	27.67	363.02
4657	2004-05-21	19590	229.93	18.97	248.90
4658	2004-05-27	5189	171.84	14.18	186.02
4659	2004-05-27	4871	271.86	22.43	294.29
4660	2004-05-05	8968	171.14	14.12	185.26
4661	2004-05-21	4636	232.60	19.19	251.79
4662	2004-05-29	18243	63.92	5.27	69.19
4663	2004-05-15	10912	303.71	25.06	328.77
4664	2004-05-06	7670	88.48	7.30	95.78
4665	2004-05-12	10307	16.16	1.33	17.49
4666	2004-05-26	13465	146.90	12.12	159.02
4667	2004-05-02	7354	352.97	29.12	382.09
4668	2004-05-30	3290	47.68	3.93	51.61
4669	2004-05-24	18543	118.09	9.74	127.83
4670	2004-05-21	13160	209.48	17.28	226.76
4671	2004-05-02	16596	215.49	17.78	233.27
4672	2004-05-25	87	350.19	28.89	379.08
4673	2004-05-05	7940	197.86	16.32	214.18
4674	2004-05-24	15827	138.54	11.43	149.97
4675	2004-05-25	8378	22.59	1.86	24.45
4676	2004-05-12	11878	334.09	27.56	361.65
4677	2004-05-23	10367	132.63	10.94	143.57
4678	2004-05-18	13571	102.50	8.46	110.96
4679	2004-05-04	18933	261.06	21.54	282.60
4680	2004-05-30	18519	173.79	14.34	188.13
4681	2004-05-21	9645	140.99	11.63	152.62
4682	2004-05-08	19874	329.77	27.21	356.98
4683	2004-05-02	722	139.37	11.50	150.87
4684	2004-05-03	17540	317.17	26.17	343.34
4685	2004-05-06	1927	350.49	28.92	379.41
4686	2004-05-26	17955	367.20	30.29	397.49
4687	2004-05-08	4029	16.60	1.37	17.97
4688	2004-05-15	2295	269.04	22.20	291.24
4689	2004-05-10	1165	143.42	11.83	155.25
4690	2004-05-14	18830	45.24	3.73	48.97
4691	2004-05-02	2341	120.27	9.92	130.19
4692	2004-05-24	7565	113.10	9.33	122.43
4693	2004-05-31	12893	153.15	12.63	165.78
4694	2004-05-16	7870	19.74	1.63	21.37
4695	2004-05-21	12473	388.66	32.06	420.72
4696	2004-05-18	13832	339.35	28.00	367.35
4697	2004-05-10	9440	173.92	14.35	188.27
4698	2004-05-25	6779	366.73	30.26	396.99
4699	2004-05-14	4323	9.73	0.80	10.53
4700	2004-05-10	11221	193.08	15.93	209.01
4701	2004-05-16	18309	365.07	30.12	395.19
4702	2004-05-30	5266	379.00	31.27	410.27
4703	2004-05-02	10684	127.11	10.49	137.60
4704	2004-05-08	15397	229.78	18.96	248.74
4705	2004-05-15	13460	137.47	11.34	148.81
4706	2004-05-19	8037	114.53	9.45	123.98
4707	2004-05-04	10731	201.46	16.62	218.08
4708	2004-05-22	12828	382.92	31.59	414.51
4709	2004-05-13	11833	70.51	5.82	76.33
4710	2004-05-25	4082	152.45	12.58	165.03
4711	2004-05-19	6152	218.50	18.03	236.53
4712	2004-05-08	14947	176.96	14.60	191.56
4713	2004-05-28	8118	154.62	12.76	167.38
4714	2004-05-01	2539	33.47	2.76	36.23
4715	2004-05-18	15167	218.38	18.02	236.40
4716	2004-05-29	8755	61.60	5.08	66.68
4717	2004-05-20	17674	70.86	5.85	76.71
4718	2004-05-15	14207	334.08	27.56	361.64
4719	2004-05-01	11449	331.47	27.35	358.82
4720	2004-05-26	16912	125.31	10.34	135.65
4721	2004-05-29	14306	58.07	4.79	62.86
4722	2004-05-24	1316	168.56	13.91	182.47
4723	2004-05-03	7102	374.09	30.86	404.95
4724	2004-05-17	10184	389.65	32.15	421.80
4725	2004-05-30	12438	378.46	31.22	409.68
4726	2004-05-23	19843	128.85	10.63	139.48
4727	2004-05-16	1375	284.15	23.44	307.59
4728	2004-05-10	8963	162.33	13.39	175.72
4729	2004-05-14	3930	29.84	2.46	32.30
4730	2004-05-23	11964	276.82	22.84	299.66
4731	2004-05-27	17264	24.00	1.98	25.98
4732	2004-05-17	4783	128.82	10.63	139.45
4733	2004-05-19	5719	163.75	13.51	177.26
4734	2004-05-19	11907	162.55	13.41	175.96
4735	2004-05-09	4429	323.61	26.70	350.31
4736	2004-05-02	11273	259.76	21.43	281.19
4737	2004-05-16	19682	336.72	27.78	364.50
4738	2004-05-27	697	365.56	30.16	395.72
4739	2004-05-03	1974	339.59	28.02	367.61
4740	2004-05-23	16286	85.98	7.09	93.07
4741	2004-05-03	13774	306.51	25.29	331.80
4742	2004-05-20	15734	38.21	3.15	41.36
4743	2004-05-31	2566	206.74	17.06	223.80
4744	2004-05-18	6416	57.82	4.77	62.59
4745	2004-05-10	497	207.93	17.15	225.08
4746	2004-05-18	5012	252.07	20.80	272.87
4747	2004-05-26	5132	358.42	29.57	387.99
4748	2004-05-15	8326	64.10	5.29	69.39
4749	2004-05-23	15258	373.78	30.84	404.62
4750	2004-05-12	6308	26.74	2.21	28.95
4751	2004-05-07	11138	16.18	1.33	17.51
4752	2004-05-31	10649	86.62	7.15	93.77
4753	2004-05-03	13774	21.84	1.80	23.64
4754	2004-05-28	6429	270.88	22.35	293.23
4755	2004-05-31	4848	307.64	25.38	333.02
4756	2004-05-03	14484	350.60	28.92	379.52
4757	2004-05-31	14657	168.89	13.93	182.82
4758	2004-05-13	11434	271.32	22.38	293.70
4759	2004-05-13	11322	351.93	29.03	380.96
4760	2004-05-24	15808	278.86	23.01	301.87
4761	2004-05-18	15932	240.49	19.84	260.33
4762	2004-05-30	10506	93.76	7.74	101.50
4763	2004-05-20	614	349.97	28.87	378.84
4764	2004-05-24	14951	68.18	5.62	73.80
4765	2004-05-29	3971	54.62	4.51	59.13
4766	2004-05-01	15763	131.38	10.84	142.22
4767	2004-05-15	16089	356.93	29.45	386.38
4768	2004-05-26	14219	146.92	12.12	159.04
4769	2004-05-20	17537	204.85	16.90	221.75
4770	2004-05-13	80	43.28	3.57	46.85
4771	2004-05-27	9310	169.52	13.99	183.51
4772	2004-05-09	18663	270.49	22.32	292.81
4773	2004-05-08	19471	386.85	31.92	418.77
4774	2004-05-22	15246	128.52	10.60	139.12
4775	2004-05-08	8911	71.77	5.92	77.69
4776	2004-05-08	12660	262.39	21.65	284.04
4777	2004-05-20	15586	192.30	15.86	208.16
4778	2004-05-07	2232	266.86	22.02	288.88
4779	2004-05-03	9050	183.04	15.10	198.14
4780	2004-05-08	9164	237.77	19.62	257.39
4781	2004-05-26	12198	187.67	15.48	203.15
4782	2004-05-16	5849	141.90	11.71	153.61
4783	2004-05-20	396	248.46	20.50	268.96
4784	2004-05-22	14392	140.63	11.60	152.23
4785	2004-05-15	3630	290.04	23.93	313.97
4786	2004-05-28	16894	155.13	12.80	167.93
4787	2004-05-25	788	81.48	6.72	88.20
4788	2004-05-27	2371	391.02	32.26	423.28
4789	2004-05-09	19317	19.09	1.57	20.66
4790	2004-05-17	6906	136.66	11.27	147.93
4791	2004-05-04	17297	256.19	21.14	277.33
4792	2004-05-25	3270	285.99	23.59	309.58
4793	2004-05-27	2303	354.51	29.25	383.76
4794	2004-05-28	8991	333.90	27.55	361.45
4795	2004-05-08	2773	330.16	27.24	357.40
4796	2004-05-24	6735	251.08	20.71	271.79
4797	2004-05-30	227	231.76	19.12	250.88
4798	2004-05-03	16352	142.51	11.76	154.27
4799	2004-05-08	7599	346.58	28.59	375.17
4800	2004-05-05	12581	88.29	7.28	95.57
4801	2004-05-10	15806	81.96	6.76	88.72
4802	2004-05-03	12073	57.85	4.77	62.62
4803	2004-05-11	8213	343.86	28.37	372.23
4804	2004-05-25	18254	196.51	16.21	212.72
4805	2004-05-07	12612	231.60	19.11	250.71
4806	2004-05-25	17468	309.33	25.52	334.85
4807	2004-05-06	4011	147.48	12.17	159.65
4808	2004-05-29	9564	344.90	28.45	373.35
4809	2004-05-08	12532	37.57	3.10	40.67
4810	2004-05-29	16985	305.32	25.19	330.51
4811	2004-05-13	14772	271.24	22.38	293.62
4812	2004-05-31	15073	341.33	28.16	369.49
4813	2004-05-06	7443	209.43	17.28	226.71
4814	2004-05-31	4590	219.20	18.08	237.28
4815	2004-05-29	5047	347.47	28.67	376.14
4816	2004-05-22	8555	374.95	30.93	405.88
4817	2004-05-24	9764	231.14	19.07	250.21
4818	2004-05-11	12637	366.51	30.24	396.75
4819	2004-05-16	1249	83.99	6.93	90.92
4820	2004-05-04	4519	243.00	20.05	263.05
4821	2004-05-13	5886	390.64	32.23	422.87
4822	2004-05-25	4166	385.35	31.79	417.14
4823	2004-05-25	9514	66.68	5.50	72.18
4824	2004-05-08	10658	240.95	19.88	260.83
4825	2004-05-19	7082	366.85	30.27	397.12
4826	2004-05-21	15705	212.99	17.57	230.56
4827	2004-05-15	15811	131.52	10.85	142.37
4828	2004-05-19	17462	210.61	17.38	227.99
4829	2004-05-14	11572	17.98	1.48	19.46
4830	2004-05-26	7125	229.96	18.97	248.93
4831	2004-05-25	8823	33.11	2.73	35.84
4832	2004-05-11	12167	396.33	32.70	429.03
4833	2004-05-21	18822	172.44	14.23	186.67
4834	2004-05-26	17098	272.33	22.47	294.80
4835	2004-05-08	18263	248.66	20.51	269.17
4836	2004-05-29	10238	0.44	0.04	0.48
4837	2004-05-30	183	257.04	21.21	278.25
4838	2004-05-05	6314	74.20	6.12	80.32
4839	2004-05-06	12157	363.43	29.98	393.41
4840	2004-05-16	4227	87.22	7.20	94.42
4841	2004-05-22	11280	145.31	11.99	157.30
4842	2004-05-11	16725	215.68	17.79	233.47
4843	2004-05-27	6059	380.59	31.40	411.99
4844	2004-05-22	2169	107.26	8.85	116.11
4845	2004-05-07	12961	63.05	5.20	68.25
4846	2004-05-09	10358	180.33	14.88	195.21
4847	2004-05-06	1394	166.68	13.75	180.43
4848	2004-05-24	10396	312.96	25.82	338.78
4849	2004-05-02	15376	40.05	3.30	43.35
4850	2004-05-13	16414	313.75	25.88	339.63
4851	2004-05-24	583	112.84	9.31	122.15
4852	2004-05-29	6562	354.84	29.27	384.11
4853	2004-05-08	16218	349.70	28.85	378.55
4854	2004-05-03	16665	307.76	25.39	333.15
4855	2004-05-21	11047	10.47	0.86	11.33
4856	2004-05-26	16259	319.05	26.32	345.37
4857	2004-05-27	9964	48.42	3.99	52.41
4858	2004-05-24	12454	76.08	6.28	82.36
4859	2004-05-08	1610	72.90	6.01	78.91
4860	2004-05-29	18989	163.71	13.51	177.22
4861	2004-05-10	17434	49.85	4.11	53.96
4862	2004-05-20	14989	234.95	19.38	254.33
4863	2004-05-24	16318	96.07	7.93	104.00
4864	2004-05-10	2008	134.39	11.09	145.48
4865	2004-05-18	3290	244.88	20.20	265.08
4866	2004-05-09	14044	228.09	18.82	246.91
4867	2004-05-16	9830	385.88	31.84	417.72
4868	2004-05-06	11302	163.18	13.46	176.64
4869	2004-05-27	4238	382.99	31.60	414.59
4870	2004-05-25	149	314.38	25.94	340.32
4871	2004-05-21	1580	40.82	3.37	44.19
4872	2004-05-22	12115	337.52	27.85	365.37
4873	2004-05-29	637	321.81	26.55	348.36
4874	2004-05-07	18839	305.35	25.19	330.54
4875	2004-05-28	4078	302.09	24.92	327.01
4876	2004-05-10	18930	285.94	23.59	309.53
4877	2004-05-22	62	272.39	22.47	294.86
4878	2004-05-29	2555	388.27	32.03	420.30
4879	2004-05-24	12878	17.65	1.46	19.11
4880	2004-05-03	14943	299.55	24.71	324.26
4881	2004-05-16	2910	229.33	18.92	248.25
4882	2004-05-07	11941	92.56	7.64	100.20
4883	2004-05-28	1102	88.69	7.32	96.01
4884	2004-05-15	4237	384.16	31.69	415.85
4885	2004-05-13	13808	122.34	10.09	132.43
4886	2004-05-12	9338	47.74	3.94	51.68
4887	2004-05-15	16452	319.33	26.34	345.67
4888	2004-05-16	1037	346.72	28.60	375.32
4889	2004-05-29	13360	43.17	3.56	46.73
4890	2004-05-10	14366	205.10	16.92	222.02
4891	2004-05-20	9775	78.50	6.48	84.98
4892	2004-05-06	4733	365.21	30.13	395.34
4893	2004-05-15	10004	27.61	2.28	29.89
4894	2004-05-05	11768	20.77	1.71	22.48
4895	2004-05-17	5983	149.68	12.35	162.03
4896	2004-05-15	6735	399.50	32.96	432.46
4897	2004-05-30	937	222.12	18.32	240.44
4898	2004-05-22	7812	230.96	19.05	250.01
4899	2004-05-05	17824	342.48	28.25	370.73
4900	2004-05-31	13939	29.92	2.47	32.39
4901	2004-05-17	3142	14.09	1.16	15.25
4902	2004-05-03	8351	389.92	32.17	422.09
4903	2004-05-05	9453	327.26	27.00	354.26
4904	2004-05-25	13448	109.73	9.05	118.78
4905	2004-05-04	6890	152.82	12.61	165.43
4906	2004-05-24	8482	208.46	17.20	225.66
4907	2004-05-19	11021	340.52	28.09	368.61
4908	2004-05-23	8412	355.79	29.35	385.14
4909	2004-05-18	16616	374.36	30.88	405.24
4910	2004-05-26	15711	238.18	19.65	257.83
4911	2004-05-02	18950	62.08	5.12	67.20
4912	2004-05-10	14908	338.43	27.92	366.35
4913	2004-05-19	6049	53.11	4.38	57.49
4914	2004-05-01	11015	314.50	25.95	340.45
4915	2004-05-10	15409	372.43	30.73	403.16
4916	2004-05-20	2341	289.42	23.88	313.30
4917	2004-05-31	8467	339.01	27.97	366.98
4918	2004-05-26	3079	48.14	3.97	52.11
4919	2004-05-19	43	48.33	3.99	52.32
4920	2004-05-18	16305	345.99	28.54	374.53
4921	2004-05-16	4066	348.93	28.79	377.72
4922	2004-05-22	3306	285.62	23.56	309.18
4923	2004-05-16	8055	108.71	8.97	117.68
4924	2004-05-12	13362	39.31	3.24	42.55
4925	2004-05-13	1997	147.92	12.20	160.12
4926	2004-05-19	3392	194.08	16.01	210.09
4927	2004-05-16	19056	70.45	5.81	76.26
4928	2004-05-28	13691	149.43	12.33	161.76
4929	2004-05-30	8576	335.61	27.69	363.30
4930	2004-05-13	7071	161.74	13.34	175.08
4931	2004-05-03	16556	159.07	13.12	172.19
4932	2004-05-01	19755	8.23	0.68	8.91
4933	2004-05-18	17323	304.41	25.11	329.52
4934	2004-05-23	1497	331.88	27.38	359.26
4935	2004-05-25	7335	69.14	5.70	74.84
4936	2004-05-08	15450	144.21	11.90	156.11
4937	2004-05-22	17464	289.88	23.92	313.80
4938	2004-05-11	3887	109.40	9.03	118.43
4939	2004-05-09	5162	377.14	31.11	408.25
4940	2004-05-14	13784	339.92	28.04	367.96
4941	2004-05-17	5261	158.37	13.07	171.44
4942	2004-05-31	8814	287.72	23.74	311.46
4943	2004-05-07	13866	340.23	28.07	368.30
4944	2004-05-28	5331	48.60	4.01	52.61
4945	2004-05-20	8483	66.34	5.47	71.81
4946	2004-05-09	19365	316.45	26.11	342.56
4947	2004-05-05	7426	205.14	16.92	222.06
4948	2004-05-05	8854	83.39	6.88	90.27
4949	2004-05-20	19256	46.76	3.86	50.62
4950	2004-05-09	6107	352.90	29.11	382.01
4951	2004-05-31	15170	83.99	6.93	90.92
4952	2004-05-16	2612	268.36	22.14	290.50
4953	2004-05-11	17021	66.65	5.50	72.15
4954	2004-05-04	5495	137.63	11.35	148.98
4955	2004-05-15	17872	184.94	15.26	200.20
4956	2004-05-24	9074	276.58	22.82	299.40
4957	2004-05-14	5071	279.41	23.05	302.46
4958	2004-05-30	9350	299.08	24.67	323.75
4959	2004-05-24	16242	286.04	23.60	309.64
4960	2004-05-07	11869	246.38	20.33	266.71
4961	2004-05-17	6223	10.09	0.83	10.92
4962	2004-05-11	11725	139.03	11.47	150.50
4963	2004-05-14	19275	304.04	25.08	329.12
4964	2004-05-01	14004	17.78	1.47	19.25
4965	2004-05-24	12404	315.54	26.03	341.57
4966	2004-05-16	1647	90.18	7.44	97.62
4967	2004-05-25	7574	121.35	10.01	131.36
4968	2004-05-30	6384	84.82	7.00	91.82
4969	2004-05-04	17140	48.67	4.02	52.69
4970	2004-05-23	16399	224.84	18.55	243.39
4971	2004-05-21	10343	242.88	20.04	262.92
4972	2004-05-27	9565	153.21	12.64	165.85
4973	2004-05-20	13393	374.58	30.90	405.48
4974	2004-05-06	8528	278.98	23.02	302.00
4975	2004-05-21	18540	243.26	20.07	263.33
4976	2004-05-14	17602	212.17	17.50	229.67
4977	2004-05-19	10388	185.37	15.29	200.66
4978	2004-05-17	10395	10.24	0.84	11.08
4979	2004-05-25	16058	138.20	11.40	149.60
4980	2004-05-16	12021	274.73	22.67	297.40
4981	2004-05-01	4653	209.48	17.28	226.76
4982	2004-05-12	8701	109.48	9.03	118.51
4983	2004-05-21	5608	112.87	9.31	122.18
4984	2004-05-13	354	34.11	2.81	36.92
4985	2004-05-25	16316	331.26	27.33	358.59
4986	2004-05-01	5098	250.48	20.66	271.14
4987	2004-05-07	3565	49.45	4.08	53.53
4988	2004-05-24	6374	198.81	16.40	215.21
4989	2004-05-11	15267	385.49	31.80	417.29
4990	2004-05-02	11194	200.57	16.55	217.12
4991	2004-05-30	2924	321.19	26.50	347.69
4992	2004-05-29	18031	250.92	20.70	271.62
4993	2004-05-15	11634	224.39	18.51	242.90
4994	2004-05-29	955	183.39	15.13	198.52
4995	2004-05-06	974	220.45	18.19	238.64
4996	2004-05-29	14873	365.84	30.18	396.02
4997	2004-05-31	15403	95.12	7.85	102.97
4998	2004-05-09	2097	271.50	22.40	293.90
4999	2004-05-28	13205	33.54	2.77	36.31
5000	2004-05-05	12221	287.13	23.69	310.82
5001	2004-06-08	15441	8.36	0.69	9.05
5002	2004-06-14	8400	25.72	2.12	27.84
5003	2004-06-30	8959	218.22	18.00	236.22
5004	2004-06-21	11278	295.03	24.34	319.37
5005	2004-06-10	9859	225.79	18.63	244.42
5006	2004-06-25	19285	130.26	10.75	141.01
5007	2004-06-19	6712	280.62	23.15	303.77
5008	2004-06-20	9615	187.56	15.47	203.03
5009	2004-06-24	2731	129.79	10.71	140.50
5010	2004-06-13	1110	251.58	20.76	272.34
5011	2004-06-22	17358	139.36	11.50	150.86
5012	2004-06-29	10620	352.81	29.11	381.92
5013	2004-06-26	3672	128.96	10.64	139.60
5014	2004-06-07	10493	107.15	8.84	115.99
5015	2004-06-04	11579	259.77	21.43	281.20
5016	2004-06-09	7614	96.95	8.00	104.95
5017	2004-06-07	16116	149.68	12.35	162.03
5018	2004-06-29	3844	271.64	22.41	294.05
5019	2004-06-30	19	256.30	21.14	277.44
5020	2004-06-18	2357	162.75	13.43	176.18
5021	2004-06-09	18727	179.70	14.83	194.53
5022	2004-06-09	12969	86.58	7.14	93.72
5023	2004-06-02	11759	335.99	27.72	363.71
5024	2004-06-12	2951	257.28	21.23	278.51
5025	2004-06-22	9128	217.57	17.95	235.52
5026	2004-06-14	17540	329.12	27.15	356.27
5027	2004-06-30	14844	183.84	15.17	199.01
5028	2004-06-30	12451	346.76	28.61	375.37
5029	2004-06-20	9393	222.28	18.34	240.62
5030	2004-06-26	11259	79.24	6.54	85.78
5031	2004-06-02	17006	131.88	10.88	142.76
5032	2004-06-14	6601	153.75	12.68	166.43
5033	2004-06-06	13832	328.41	27.09	355.50
5034	2004-06-15	19712	163.11	13.46	176.57
5035	2004-06-01	11638	6.61	0.55	7.16
5036	2004-06-02	16485	100.45	8.29	108.74
5037	2004-06-14	14119	121.00	9.98	130.98
5038	2004-06-26	19497	288.80	23.83	312.63
5039	2004-06-21	10771	284.63	23.48	308.11
5040	2004-06-20	4409	246.07	20.30	266.37
5041	2004-06-23	10516	227.90	18.80	246.70
5042	2004-06-07	19838	370.30	30.55	400.85
5043	2004-06-11	7439	183.67	15.15	198.82
5044	2004-06-16	9751	205.67	16.97	222.64
5045	2004-06-26	19830	275.18	22.70	297.88
5046	2004-06-06	12485	342.55	28.26	370.81
5047	2004-06-22	8604	52.49	4.33	56.82
5048	2004-06-18	19166	341.28	28.16	369.44
5049	2004-06-27	13351	338.79	27.95	366.74
5050	2004-06-05	78	349.28	28.82	378.10
5051	2004-06-04	2064	197.64	16.31	213.95
5052	2004-06-17	12405	28.24	2.33	30.57
5053	2004-06-23	2985	295.08	24.34	319.42
5054	2004-06-19	5377	399.28	32.94	432.22
5055	2004-06-10	15861	124.15	10.24	134.39
5056	2004-06-29	7475	51.41	4.24	55.65
5057	2004-06-21	6897	128.62	10.61	139.23
5058	2004-06-26	19552	366.98	30.28	397.26
5059	2004-06-08	8951	215.62	17.79	233.41
5060	2004-06-04	10377	134.78	11.12	145.90
5061	2004-06-17	7124	107.94	8.91	116.85
5062	2004-06-27	15626	158.00	13.04	171.03
5063	2004-06-09	272	252.13	20.80	272.93
5064	2004-06-21	15018	133.53	11.02	144.55
5065	2004-06-14	8411	64.96	5.36	70.32
5066	2004-06-10	968	138.00	11.38	149.38
5067	2004-06-19	17281	253.30	20.90	274.20
5068	2004-06-26	10661	355.98	29.37	385.35
5069	2004-06-01	9982	80.22	6.62	86.84
5070	2004-06-24	5534	333.58	27.52	361.10
5071	2004-06-22	13421	188.91	15.59	204.50
5072	2004-06-29	13529	220.96	18.23	239.19
5073	2004-06-20	16229	355.82	29.36	385.18
5074	2004-06-16	15760	182.57	15.06	197.63
5075	2004-06-04	3317	244.84	20.20	265.04
5076	2004-06-29	11900	241.73	19.94	261.67
5077	2004-06-08	3782	149.01	12.29	161.30
5078	2004-06-28	9538	371.13	30.62	401.75
5079	2004-06-17	5309	62.24	5.13	67.37
5080	2004-06-29	6389	398.74	32.90	431.64
5081	2004-06-14	16624	170.09	14.03	184.12
5082	2004-06-07	6854	248.52	20.50	269.02
5083	2004-06-11	5386	287.65	23.73	311.38
5084	2004-06-30	9822	352.23	29.06	381.29
5085	2004-06-29	5422	88.28	7.28	95.56
5086	2004-06-29	1471	170.11	14.03	184.14
5087	2004-06-27	3367	123.80	10.21	134.01
5088	2004-06-16	12145	392.91	32.42	425.33
5089	2004-06-01	6067	71.97	5.94	77.91
5090	2004-06-21	4450	366.01	30.20	396.21
5091	2004-06-02	15897	396.22	32.69	428.91
5092	2004-06-25	13192	221.23	18.25	239.48
5093	2004-06-06	7567	6.04	0.50	6.54
5094	2004-06-08	7225	127.35	10.51	137.86
5095	2004-06-18	15673	229.34	18.92	248.26
5096	2004-06-29	4335	116.23	9.59	125.82
5097	2004-06-17	9339	261.70	21.59	283.29
5098	2004-06-22	6242	315.80	26.05	341.85
5099	2004-06-24	5717	247.27	20.40	267.67
5100	2004-06-20	1870	310.07	25.58	335.65
5101	2004-06-10	9114	195.30	16.11	211.41
5102	2004-06-08	10135	67.94	5.61	73.55
5103	2004-06-29	15036	166.61	13.75	180.36
5104	2004-06-06	19597	338.93	27.96	366.89
5105	2004-06-02	1482	54.90	4.53	59.43
5106	2004-06-24	17791	289.99	23.92	313.91
5107	2004-06-23	19807	346.33	28.57	374.90
5108	2004-06-13	17053	44.48	3.67	48.15
5109	2004-06-03	684	52.73	4.35	57.08
5110	2004-06-20	13169	163.24	13.47	176.71
5111	2004-06-11	9525	389.68	32.15	421.83
5112	2004-06-09	7309	77.97	6.43	84.40
5113	2004-06-25	2792	20.33	1.68	22.01
5114	2004-06-01	2343	255.21	21.05	276.26
5115	2004-06-24	2636	298.60	24.63	323.23
5116	2004-06-22	10935	299.22	24.69	323.91
5117	2004-06-20	4487	136.82	11.29	148.11
5118	2004-06-30	13678	27.60	2.28	29.88
5119	2004-06-05	16466	87.80	7.24	95.04
5120	2004-06-21	10962	312.74	25.80	338.54
5121	2004-06-19	3490	32.02	2.64	34.66
5122	2004-06-16	10771	73.96	6.10	80.06
5123	2004-06-19	6658	334.30	27.58	361.88
5124	2004-06-05	8174	357.70	29.51	387.21
5125	2004-06-19	16614	119.29	9.84	129.13
5126	2004-06-22	12295	349.50	28.83	378.33
5127	2004-06-30	7659	232.97	19.22	252.19
5128	2004-06-19	6506	205.75	16.97	222.72
5129	2004-06-01	6451	99.88	8.24	108.12
5130	2004-06-09	10567	151.51	12.50	164.01
5131	2004-06-23	10808	205.30	16.94	222.24
5132	2004-06-16	1606	222.34	18.34	240.68
5133	2004-06-21	2702	88.99	7.34	96.33
5134	2004-06-18	14920	309.57	25.54	335.11
5135	2004-06-09	13913	280.30	23.12	303.42
5136	2004-06-25	18850	78.67	6.49	85.16
5137	2004-06-10	9286	160.69	13.26	173.95
5138	2004-06-07	18583	368.46	30.40	398.86
5139	2004-06-06	13424	317.72	26.21	343.93
5140	2004-06-17	4853	316.94	26.15	343.09
5141	2004-06-03	1907	245.67	20.27	265.94
5142	2004-06-21	16119	324.60	26.78	351.38
5143	2004-06-05	17457	34.70	2.86	37.56
5144	2004-06-30	11689	228.28	18.83	247.11
5145	2004-06-23	19757	10.31	0.85	11.16
5146	2004-06-25	12284	65.27	5.38	70.65
5147	2004-06-11	16617	173.37	14.30	187.67
5148	2004-06-29	17955	303.14	25.01	328.15
5149	2004-06-15	5087	32.37	2.67	35.04
5150	2004-06-07	8501	225.21	18.58	243.79
5151	2004-06-22	16632	204.63	16.88	221.51
5152	2004-06-24	5597	384.30	31.70	416.00
5153	2004-06-25	14811	280.73	23.16	303.89
5154	2004-06-23	12697	32.13	2.65	34.78
5155	2004-06-07	5953	22.27	1.84	24.11
5156	2004-06-28	10718	289.61	23.89	313.50
5157	2004-06-05	19868	115.82	9.56	125.38
5158	2004-06-12	2454	391.97	32.34	424.31
5159	2004-06-22	18799	368.14	30.37	398.51
5160	2004-06-21	17876	124.64	10.28	134.92
5161	2004-06-26	169	188.64	15.56	204.20
5162	2004-06-20	7848	242.39	20.00	262.39
5163	2004-06-10	5389	305.26	25.18	330.44
5164	2004-06-24	13600	92.67	7.65	100.32
5165	2004-06-06	15801	363.98	30.03	394.01
5166	2004-06-18	19716	339.96	28.05	368.01
5167	2004-06-26	10508	277.80	22.92	300.72
5168	2004-06-09	14682	69.94	5.77	75.71
5169	2004-06-08	19163	239.83	19.79	259.62
5170	2004-06-22	4456	128.38	10.59	138.97
5171	2004-06-26	16912	65.31	5.39	70.70
5172	2004-06-01	18717	141.79	11.70	153.49
5173	2004-06-07	6001	73.22	6.04	79.26
5174	2004-06-30	16798	157.36	12.98	170.34
5175	2004-06-29	12554	375.83	31.01	406.84
5176	2004-06-14	5477	68.05	5.61	73.66
5177	2004-06-10	533	211.56	17.45	229.01
5178	2004-06-21	19296	253.23	20.89	274.12
5179	2004-06-05	17817	26.29	2.17	28.46
5180	2004-06-21	16108	328.24	27.08	355.32
5181	2004-06-06	6605	2.53	0.21	2.74
5182	2004-06-11	3941	298.57	24.63	323.20
5183	2004-06-26	18988	55.92	4.61	60.53
5184	2004-06-05	5858	70.73	5.84	76.57
5185	2004-06-09	17719	27.01	2.23	29.24
5186	2004-06-23	6388	70.79	5.84	76.63
5187	2004-06-25	8667	288.63	23.81	312.44
5188	2004-06-30	16249	205.15	16.92	222.07
5189	2004-06-23	6707	262.32	21.64	283.96
5190	2004-06-29	14788	279.84	23.09	302.93
5191	2004-06-15	10955	31.08	2.56	33.64
5192	2004-06-08	16416	141.94	11.71	153.65
5193	2004-06-05	13695	253.91	20.95	274.86
5194	2004-06-13	8676	112.20	9.26	121.46
5195	2004-06-13	10246	244.36	20.16	264.52
5196	2004-06-12	609	74.98	6.19	81.17
5197	2004-06-01	9728	11.17	0.92	12.09
5198	2004-06-23	6922	148.95	12.29	161.24
5199	2004-06-29	15664	249.04	20.55	269.59
5200	2004-06-30	13325	67.58	5.58	73.16
5201	2004-06-12	5938	222.88	18.39	241.27
5202	2004-06-28	13142	374.38	30.89	405.27
5203	2004-06-05	14131	385.51	31.80	417.31
5204	2004-06-07	685	256.87	21.19	278.06
5205	2004-06-07	899	31.37	2.59	33.96
5206	2004-06-25	715	291.61	24.06	315.67
5207	2004-06-10	3169	390.87	32.25	423.12
5208	2004-06-23	2258	164.42	13.56	177.98
5209	2004-06-28	19189	5.03	0.41	5.44
5210	2004-06-25	10644	37.02	3.05	40.07
5211	2004-06-19	13859	71.59	5.91	77.50
5212	2004-06-10	2934	192.23	15.86	208.09
5213	2004-06-17	18956	41.36	3.41	44.77
5214	2004-06-10	11313	227.99	18.81	246.80
5215	2004-06-26	19015	190.28	15.70	205.98
5216	2004-06-20	6972	394.31	32.53	426.84
5217	2004-06-24	10865	42.36	3.49	45.85
5218	2004-06-19	4387	384.62	31.73	416.35
5219	2004-06-25	11543	150.64	12.43	163.07
5220	2004-06-22	5642	262.10	21.62	283.72
5221	2004-06-18	5173	381.73	31.49	413.22
5222	2004-06-23	19625	27.32	2.25	29.57
5223	2004-06-20	12296	253.92	20.95	274.87
5224	2004-06-12	2413	224.01	18.48	242.49
5225	2004-06-30	14904	349.39	28.82	378.21
5226	2004-06-29	3489	138.60	11.43	150.03
5227	2004-06-09	15130	263.56	21.74	285.30
5228	2004-06-18	16977	345.24	28.48	373.72
5229	2004-06-01	1552	389.69	32.15	421.84
5230	2004-06-30	4255	221.99	18.31	240.30
5231	2004-06-23	2947	195.30	16.11	211.41
5232	2004-06-29	5132	384.94	31.76	416.70
5233	2004-06-05	973	0.28	0.02	0.30
5234	2004-06-09	858	202.49	16.71	219.20
5235	2004-06-11	15352	28.54	2.35	30.89
5236	2004-06-21	13002	42.38	3.50	45.88
5237	2004-06-30	14889	73.89	6.10	79.99
5238	2004-06-25	15504	294.66	24.31	318.97
5239	2004-06-16	19111	318.43	26.27	344.70
5240	2004-06-01	17314	105.78	8.73	114.51
5241	2004-06-26	6854	86.58	7.14	93.72
5242	2004-06-01	988	206.97	17.08	224.05
5243	2004-06-21	13196	53.34	4.40	57.74
5244	2004-06-26	3803	186.12	15.35	201.47
5245	2004-06-17	7221	53.93	4.45	58.38
5246	2004-06-30	83	28.01	2.31	30.32
5247	2004-06-12	1453	211.90	17.48	229.38
5248	2004-06-06	2321	45.17	3.73	48.90
5249	2004-06-22	2915	145.94	12.04	157.98
5250	2004-06-28	11122	322.09	26.57	348.66
5251	2004-06-04	5997	104.93	8.66	113.59
5252	2004-06-12	9080	174.97	14.44	189.41
5253	2004-06-06	7502	108.62	8.96	117.58
5254	2004-06-15	14826	162.76	13.43	176.19
5255	2004-06-22	12282	194.60	16.05	210.65
5256	2004-06-11	8070	24.69	2.04	26.73
5257	2004-06-01	8947	186.73	15.41	202.14
5258	2004-06-12	15464	164.71	13.59	178.30
5259	2004-06-29	8764	151.12	12.47	163.59
5260	2004-06-04	3204	229.36	18.92	248.28
5261	2004-06-01	10499	240.14	19.81	259.95
5262	2004-06-06	1721	181.17	14.95	196.12
5263	2004-06-16	5125	108.01	8.91	116.92
5264	2004-06-20	5148	112.76	9.30	122.06
5265	2004-06-21	19963	51.55	4.25	55.80
5266	2004-06-14	4606	247.07	20.38	267.45
5267	2004-06-19	2605	49.81	4.11	53.92
5268	2004-06-10	8161	63.84	5.27	69.11
5269	2004-06-06	1943	21.88	1.81	23.69
5270	2004-06-06	14966	195.78	16.15	211.93
5271	2004-06-16	15865	204.65	16.88	221.53
5272	2004-06-06	17893	80.10	6.61	86.71
5273	2004-06-24	49	135.80	11.20	147.00
5274	2004-06-23	12525	250.26	20.65	270.91
5275	2004-06-12	19530	4.82	0.40	5.22
5276	2004-06-14	8174	108.04	8.91	116.95
5277	2004-06-27	1807	158.13	13.05	171.18
5278	2004-06-25	1470	70.87	5.85	76.72
5279	2004-06-06	6889	16.97	1.40	18.37
5280	2004-06-08	13758	119.53	9.86	129.39
5281	2004-06-15	1388	9.61	0.79	10.40
5282	2004-06-23	2950	384.10	31.69	415.79
5283	2004-06-14	16802	356.17	29.38	385.55
5284	2004-06-25	4243	210.46	17.36	227.82
5285	2004-06-15	8358	266.86	22.02	288.88
5286	2004-06-26	1808	179.31	14.79	194.10
5287	2004-06-23	7899	182.53	15.06	197.59
5288	2004-06-06	12071	254.13	20.97	275.10
5289	2004-06-22	9314	118.60	9.78	128.38
5290	2004-06-08	7461	164.47	13.57	178.04
5291	2004-06-25	3310	161.04	13.29	174.33
5292	2004-06-26	8182	35.95	2.97	38.92
5293	2004-06-29	2153	373.56	30.82	404.38
5294	2004-06-23	8605	250.03	20.63	270.66
5295	2004-06-21	9893	324.32	26.76	351.08
5296	2004-06-24	201	221.36	18.26	239.62
5297	2004-06-30	18904	23.83	1.97	25.80
5298	2004-06-11	4536	262.35	21.64	283.99
5299	2004-06-25	6722	107.07	8.83	115.90
5300	2004-06-08	14785	316.96	26.15	343.11
5301	2004-06-09	3047	216.82	17.89	234.71
5302	2004-06-14	3316	143.04	11.80	154.84
5303	2004-06-15	19949	174.74	14.42	189.16
5304	2004-06-02	2965	323.93	26.72	350.65
5305	2004-06-19	7823	71.99	5.94	77.93
5306	2004-06-11	16091	276.31	22.80	299.11
5307	2004-06-01	6329	32.37	2.67	35.04
5308	2004-06-05	331	379.13	31.28	410.41
5309	2004-06-26	11309	158.35	13.06	171.41
5310	2004-06-21	12307	38.88	3.21	42.09
5311	2004-06-11	13376	12.05	0.99	13.04
5312	2004-06-12	3269	116.32	9.60	125.92
5313	2004-06-30	19467	1.90	0.16	2.06
5314	2004-06-08	7897	116.62	9.62	126.24
5315	2004-06-12	12248	18.15	1.50	19.65
5316	2004-06-10	9058	97.02	8.00	105.02
5317	2004-06-13	8377	198.63	16.39	215.02
5318	2004-06-16	14133	251.12	20.72	271.84
5319	2004-06-20	9277	259.94	21.45	281.39
5320	2004-06-06	19157	2.17	0.18	2.35
5321	2004-06-18	939	321.18	26.50	347.68
5322	2004-06-09	15411	20.48	1.69	22.17
5323	2004-06-20	18924	180.81	14.92	195.73
5324	2004-06-17	5691	305.45	25.20	330.65
5325	2004-06-08	12188	237.87	19.62	257.49
5326	2004-06-29	2629	90.64	7.48	98.12
5327	2004-06-07	6181	284.33	23.46	307.79
5328	2004-06-05	12398	381.74	31.49	413.23
5329	2004-06-28	10242	196.81	16.24	213.05
5330	2004-06-06	12839	251.23	20.73	271.96
5331	2004-06-23	3185	169.23	13.96	183.19
5332	2004-06-30	7936	390.05	32.18	422.23
5333	2004-06-19	10738	317.50	26.19	343.69
5334	2004-06-17	1640	397.44	32.79	430.23
5335	2004-06-13	468	152.07	12.55	164.62
5336	2004-06-05	2037	175.45	14.47	189.92
5337	2004-06-15	1792	83.28	6.87	90.15
5338	2004-06-03	15577	181.90	15.01	196.91
5339	2004-06-23	19996	202.72	16.72	219.44
5340	2004-06-15	9426	68.30	5.63	73.93
5341	2004-06-23	13427	276.51	22.81	299.32
5342	2004-06-12	15855	357.05	29.46	386.51
5343	2004-06-20	1780	288.61	23.81	312.42
5344	2004-06-17	13557	29.74	2.45	32.19
5345	2004-06-25	14542	235.03	19.39	254.42
5346	2004-06-11	13480	127.58	10.53	138.11
5347	2004-06-10	7733	155.35	12.82	168.17
5348	2004-06-27	13549	213.21	17.59	230.80
5349	2004-06-29	7970	204.86	16.90	221.76
5350	2004-06-01	8252	36.32	3.00	39.32
5351	2004-06-05	6877	344.41	28.41	372.82
5352	2004-06-11	5028	306.90	25.32	332.22
5353	2004-06-23	16096	258.83	21.35	280.18
5354	2004-06-24	12856	397.87	32.82	430.69
5355	2004-06-02	14190	284.26	23.45	307.71
5356	2004-06-21	4844	29.36	2.42	31.78
5357	2004-06-20	6383	129.63	10.69	140.32
5358	2004-06-03	9510	109.43	9.03	118.46
5359	2004-06-15	19043	351.68	29.01	380.69
5360	2004-06-19	19267	373.07	30.78	403.85
5361	2004-06-17	11365	380.57	31.40	411.97
5362	2004-06-03	161	40.34	3.33	43.67
5363	2004-06-20	17425	375.92	31.01	406.93
5364	2004-06-08	17404	355.30	29.31	384.61
5365	2004-06-25	9316	354.27	29.23	383.50
5366	2004-06-30	16404	399.37	32.95	432.32
5367	2004-06-05	209	151.91	12.53	164.44
5368	2004-06-16	12169	270.64	22.33	292.97
5369	2004-06-10	12766	198.46	16.37	214.83
5370	2004-06-08	6506	56.42	4.65	61.07
5371	2004-06-07	13189	19.94	1.65	21.59
5372	2004-06-09	7493	110.04	9.08	119.12
5373	2004-06-03	14386	206.94	17.07	224.01
5374	2004-06-18	17377	104.79	8.65	113.44
5375	2004-06-25	7467	217.49	17.94	235.43
5376	2004-06-13	1049	393.08	32.43	425.51
5377	2004-06-01	14341	239.18	19.73	258.91
5378	2004-06-24	18462	107.45	8.86	116.31
5379	2004-06-24	10211	161.07	13.29	174.36
5380	2004-06-16	1584	54.66	4.51	59.17
5381	2004-06-14	17630	85.08	7.02	92.10
5382	2004-06-09	10860	348.35	28.74	377.09
5383	2004-06-24	5229	152.17	12.55	164.72
5384	2004-06-12	1705	393.82	32.49	426.31
5385	2004-06-04	14455	175.64	14.49	190.13
5386	2004-06-23	2824	345.82	28.53	374.35
5387	2004-06-11	7744	313.65	25.88	339.53
5388	2004-06-17	5984	51.08	4.21	55.29
5389	2004-06-03	10085	179.17	14.78	193.95
5390	2004-06-01	16755	61.95	5.11	67.06
5391	2004-06-02	6246	371.29	30.63	401.92
5392	2004-06-01	5972	236.72	19.53	256.25
5393	2004-06-09	581	302.20	24.93	327.13
5394	2004-06-12	12170	389.51	32.13	421.64
5395	2004-06-08	10491	320.89	26.47	347.36
5396	2004-06-20	782	128.17	10.57	138.74
5397	2004-06-01	13627	140.48	11.59	152.07
5398	2004-06-23	13291	115.64	9.54	125.18
5399	2004-06-19	11782	114.50	9.45	123.95
5400	2004-06-25	16584	138.79	11.45	150.24
5401	2004-06-06	245	49.74	4.10	53.84
5402	2004-06-09	2774	359.35	29.65	389.00
5403	2004-06-26	10899	325.29	26.84	352.13
5404	2004-06-26	5105	149.55	12.34	161.89
5405	2004-06-05	17619	215.76	17.80	233.56
5406	2004-06-08	14155	188.35	15.54	203.89
5407	2004-06-15	18380	216.67	17.88	234.55
5408	2004-06-04	2848	387.91	32.00	419.91
5409	2004-06-28	16076	196.14	16.18	212.32
5410	2004-06-19	12725	339.32	27.99	367.31
5411	2004-06-12	13332	213.82	17.64	231.46
5412	2004-06-24	4199	270.68	22.33	293.01
5413	2004-06-14	7024	228.91	18.89	247.80
5414	2004-06-02	17860	360.77	29.76	390.53
5415	2004-06-05	10889	221.59	18.28	239.87
5416	2004-06-24	16810	294.67	24.31	318.98
5417	2004-06-01	8964	284.10	23.44	307.54
5418	2004-06-01	16203	46.81	3.86	50.67
5419	2004-06-24	14366	371.60	30.66	402.26
5420	2004-06-07	10866	371.87	30.68	402.55
5421	2004-06-02	3688	330.27	27.25	357.52
5422	2004-06-12	1563	232.22	19.16	251.38
5423	2004-06-05	1778	183.72	15.16	198.88
5424	2004-06-02	2886	136.91	11.30	148.21
5425	2004-06-19	4479	303.03	25.00	328.03
5426	2004-06-29	2614	56.52	4.66	61.18
5427	2004-06-24	6587	338.76	27.95	366.71
5428	2004-06-08	8875	83.85	6.92	90.77
5429	2004-06-06	16424	117.06	9.66	126.72
5430	2004-06-25	13933	330.56	27.27	357.83
5431	2004-06-24	8631	336.58	27.77	364.35
5432	2004-06-26	11555	16.36	1.35	17.71
5433	2004-06-15	9128	359.20	29.63	388.83
5434	2004-06-01	16690	180.26	14.87	195.13
5435	2004-06-21	16020	265.77	21.93	287.70
5436	2004-06-15	2356	98.45	8.12	106.57
5437	2004-06-18	19319	110.66	9.13	119.79
5438	2004-06-01	8468	387.04	31.93	418.97
5439	2004-06-26	5706	305.90	25.24	331.14
5440	2004-06-21	18879	129.80	10.71	140.51
5441	2004-06-30	5467	255.71	21.10	276.81
5442	2004-06-25	3712	162.54	13.41	175.95
5443	2004-06-11	4605	93.63	7.72	101.35
5444	2004-06-13	18936	179.95	14.85	194.80
5445	2004-06-04	8072	285.35	23.54	308.89
5446	2004-06-04	4370	325.81	26.88	352.69
5447	2004-06-26	18973	26.80	2.21	29.01
5448	2004-06-08	14938	2.54	0.21	2.75
5449	2004-06-12	14648	158.10	13.04	171.14
5450	2004-06-01	19407	392.51	32.38	424.89
5451	2004-06-28	18812	32.45	2.68	35.13
5452	2004-06-20	8023	30.96	2.55	33.51
5453	2004-06-05	11649	164.63	13.58	178.21
5454	2004-06-25	5500	213.79	17.64	231.43
5455	2004-06-07	6500	10.46	0.86	11.32
5456	2004-06-05	8187	133.44	11.01	144.45
5457	2004-06-01	5500	109.22	9.01	118.23
5458	2004-06-25	1396	119.46	9.86	129.32
5459	2004-06-24	17796	32.12	2.65	34.77
5460	2004-06-12	6701	137.05	11.31	148.36
5461	2004-06-20	10484	289.91	23.92	313.83
5462	2004-06-27	10329	14.05	1.16	15.21
5463	2004-06-02	2919	236.70	19.53	256.23
5464	2004-06-19	6762	279.83	23.09	302.92
5465	2004-06-15	5115	211.16	17.42	228.58
5466	2004-06-05	9527	318.39	26.27	344.66
5467	2004-06-26	19420	195.67	16.14	211.81
5468	2004-06-13	14720	282.45	23.30	305.75
5469	2004-06-22	16159	159.73	13.18	172.91
5470	2004-06-22	15685	299.43	24.70	324.13
5471	2004-06-20	17227	121.29	10.01	131.30
5472	2004-06-21	19067	1.10	0.09	1.19
5473	2004-06-21	3381	288.53	23.80	312.33
5474	2004-06-27	19126	167.62	13.83	181.45
5475	2004-06-07	5050	206.10	17.00	223.10
5476	2004-06-11	6233	198.17	16.35	214.52
5477	2004-06-03	2434	323.72	26.71	350.43
5478	2004-06-12	14162	342.37	28.25	370.62
5479	2004-06-11	6138	284.31	23.46	307.77
5480	2004-06-22	16270	265.47	21.90	287.37
5481	2004-06-18	18140	201.38	16.61	217.99
5482	2004-06-08	18789	126.05	10.40	136.45
5483	2004-06-14	14465	142.57	11.76	154.33
5484	2004-06-02	17988	256.42	21.15	277.57
5485	2004-06-24	11627	377.92	31.18	409.10
5486	2004-06-16	12492	70.63	5.83	76.46
5487	2004-06-28	11845	235.47	19.43	254.90
5488	2004-06-17	8950	161.82	13.35	175.17
5489	2004-06-13	6755	137.83	11.37	149.20
5490	2004-06-20	18764	292.82	24.16	316.98
5491	2004-06-12	10267	220.21	18.17	238.38
5492	2004-06-21	1059	87.70	7.24	94.94
5493	2004-06-02	6892	192.99	15.92	208.91
5494	2004-06-26	449	219.77	18.13	237.90
5495	2004-06-07	1879	151.26	12.48	163.74
5496	2004-06-22	11643	351.85	29.03	380.88
5497	2004-06-08	5711	31.35	2.59	33.94
5498	2004-06-25	6992	238.61	19.69	258.30
5499	2004-06-12	190	381.62	31.48	413.10
5500	2004-06-21	3847	295.70	24.40	320.10
5501	2004-06-07	6695	40.57	3.35	43.92
5502	2004-06-08	8300	363.31	29.97	393.28
5503	2004-06-08	389	35.11	2.90	38.01
5504	2004-06-24	1330	67.93	5.60	73.53
5505	2004-06-13	12760	51.59	4.26	55.85
5506	2004-06-19	13622	228.49	18.85	247.34
5507	2004-06-04	10111	61.95	5.11	67.06
5508	2004-06-23	10839	244.03	20.13	264.16
5509	2004-06-06	15545	2.51	0.21	2.72
5510	2004-06-21	12214	21.92	1.81	23.73
5511	2004-06-12	6630	373.63	30.82	404.45
5512	2004-06-24	4897	267.90	22.10	290.00
5513	2004-06-22	3924	269.72	22.25	291.97
5514	2004-06-30	3320	321.81	26.55	348.36
5515	2004-06-30	15408	358.68	29.59	388.27
5516	2004-06-09	15528	78.66	6.49	85.15
5517	2004-06-01	12291	29.36	2.42	31.78
5518	2004-06-14	8002	226.79	18.71	245.50
5519	2004-06-25	6823	132.66	10.94	143.60
5520	2004-06-13	13473	162.61	13.42	176.03
5521	2004-06-23	5094	222.50	18.36	240.86
5522	2004-06-26	3227	161.80	13.35	175.15
5523	2004-06-03	1405	240.52	19.84	260.36
5524	2004-06-30	14581	227.85	18.80	246.65
5525	2004-06-29	15418	373.20	30.79	403.99
5526	2004-06-29	14386	168.89	13.93	182.82
5527	2004-06-23	6553	396.25	32.69	428.94
5528	2004-06-09	2775	256.73	21.18	277.91
5529	2004-06-11	4639	111.12	9.17	120.29
5530	2004-06-23	9045	148.87	12.28	161.15
5531	2004-06-22	14243	368.55	30.41	398.96
5532	2004-06-08	13001	191.68	15.81	207.49
5533	2004-06-04	15904	160.13	13.21	173.34
5534	2004-06-14	14997	19.30	1.59	20.89
5535	2004-06-21	3334	285.36	23.54	308.90
5536	2004-06-20	505	138.39	11.42	149.81
5537	2004-06-26	19353	300.30	24.77	325.07
5538	2004-06-27	13477	62.69	5.17	67.86
5539	2004-06-25	14760	175.76	14.50	190.26
5540	2004-06-12	16073	396.68	32.73	429.41
5541	2004-06-25	9753	46.37	3.83	50.20
5542	2004-06-30	11401	76.05	6.27	82.32
5543	2004-06-01	11451	235.91	19.46	255.37
5544	2004-06-27	12114	25.94	2.14	28.08
5545	2004-06-17	14699	53.78	4.44	58.22
5546	2004-06-15	108	134.73	11.12	145.85
5547	2004-06-06	9058	249.21	20.56	269.77
5548	2004-06-07	18740	144.59	11.93	156.52
5549	2004-06-28	4901	192.76	15.90	208.66
5550	2004-06-01	19959	56.56	4.67	61.23
5551	2004-06-30	12932	384.00	31.68	415.68
5552	2004-06-18	12656	380.83	31.42	412.25
5553	2004-06-10	16158	249.98	20.62	270.60
5554	2004-06-19	11960	393.16	32.44	425.60
5555	2004-06-17	3965	32.72	2.70	35.42
5556	2004-06-18	7742	84.84	7.00	91.84
5557	2004-06-26	7686	92.59	7.64	100.23
5558	2004-06-16	9662	295.68	24.39	320.07
5559	2004-06-22	12327	23.64	1.95	25.59
5560	2004-06-23	18828	323.83	26.72	350.55
5561	2004-06-30	17495	191.65	15.81	207.46
5562	2004-06-12	9267	9.54	0.79	10.33
5563	2004-06-13	2846	293.78	24.24	318.02
5564	2004-06-26	2359	262.02	21.62	283.64
5565	2004-06-20	8147	212.73	17.55	230.28
5566	2004-06-04	11704	385.44	31.80	417.24
5567	2004-06-19	1648	226.79	18.71	245.50
5568	2004-06-21	11252	1.52	0.13	1.65
5569	2004-06-03	7947	150.95	12.45	163.40
5570	2004-06-27	13310	203.04	16.75	219.79
5571	2004-06-28	5966	350.81	28.94	379.75
5572	2004-06-08	10217	144.29	11.90	156.19
5573	2004-06-16	3713	160.78	13.26	174.04
5574	2004-06-08	15138	324.32	26.76	351.08
5575	2004-06-06	9948	19.93	1.64	21.57
5576	2004-06-25	11058	351.21	28.97	380.18
5577	2004-06-13	11585	351.10	28.97	380.07
5578	2004-06-24	10155	204.29	16.85	221.14
5579	2004-06-25	6981	71.08	5.86	76.94
5580	2004-06-18	9636	140.84	11.62	152.46
5581	2004-06-27	19887	22.74	1.88	24.62
5582	2004-06-18	3464	190.55	15.72	206.27
5583	2004-06-28	17636	370.22	30.54	400.76
5584	2004-06-06	16693	348.79	28.78	377.57
5585	2004-06-16	5646	117.33	9.68	127.01
5586	2004-06-22	2971	4.84	0.40	5.24
5587	2004-06-25	12063	201.94	16.66	218.60
5588	2004-06-18	9948	398.69	32.89	431.58
5589	2004-06-15	18185	125.60	10.36	135.96
5590	2004-06-23	15360	175.11	14.45	189.56
5591	2004-06-21	5801	336.78	27.78	364.56
5592	2004-06-09	11700	393.94	32.50	426.44
5593	2004-06-18	12938	5.53	0.46	5.99
5594	2004-06-08	13578	166.93	13.77	180.70
5595	2004-06-05	11160	36.52	3.01	39.53
5596	2004-06-09	4908	323.13	26.66	349.79
5597	2004-06-03	17133	70.49	5.82	76.31
5598	2004-06-23	11235	282.90	23.34	306.24
5599	2004-06-07	19944	393.22	32.44	425.66
5600	2004-06-18	10577	28.24	2.33	30.57
5601	2004-06-23	6181	399.51	32.96	432.47
5602	2004-06-03	16646	233.72	19.28	253.00
5603	2004-06-25	13746	252.20	20.81	273.01
5604	2004-06-02	15264	363.26	29.97	393.23
5605	2004-06-27	593	117.31	9.68	126.99
5606	2004-06-06	13840	181.32	14.96	196.28
5607	2004-06-15	18267	67.64	5.58	73.22
5608	2004-06-03	18299	66.27	5.47	71.74
5609	2004-06-13	17362	209.51	17.28	226.79
5610	2004-06-07	2138	377.79	31.17	408.96
5611	2004-06-10	886	262.45	21.65	284.10
5612	2004-06-22	10643	291.10	24.02	315.12
5613	2004-06-27	8643	309.44	25.53	334.97
5614	2004-06-07	12918	386.92	31.92	418.84
5615	2004-06-11	923	258.42	21.32	279.74
5616	2004-06-21	15570	28.10	2.32	30.42
5617	2004-06-05	6616	39.79	3.28	43.07
5618	2004-06-08	14768	43.03	3.55	46.58
5619	2004-06-22	18413	61.43	5.07	66.50
5620	2004-06-10	2985	159.99	13.20	173.19
5621	2004-06-25	9051	222.08	18.32	240.40
5622	2004-06-18	15275	368.86	30.43	399.29
5623	2004-06-14	6589	209.15	17.25	226.40
5624	2004-06-19	2219	233.09	19.23	252.32
5625	2004-06-18	2819	45.61	3.76	49.37
5626	2004-06-26	13122	342.73	28.28	371.01
5627	2004-06-05	1469	239.01	19.72	258.73
5628	2004-06-13	11392	78.01	6.44	84.45
5629	2004-06-10	252	116.02	9.57	125.59
5630	2004-06-25	13999	341.06	28.14	369.20
5631	2004-06-06	19340	398.53	32.88	431.41
5632	2004-06-28	247	22.90	1.89	24.79
5633	2004-06-26	11057	353.36	29.15	382.51
5634	2004-06-01	18671	243.14	20.06	263.20
5635	2004-06-04	4614	35.72	2.95	38.67
5636	2004-06-28	13148	91.86	7.58	99.44
5637	2004-06-13	12152	70.08	5.78	75.86
5638	2004-06-22	12381	253.73	20.93	274.66
5639	2004-06-25	19561	297.45	24.54	321.99
5640	2004-06-30	6336	29.15	2.40	31.55
5641	2004-06-02	13210	210.81	17.39	228.20
5642	2004-06-04	18034	342.31	28.24	370.55
5643	2004-06-25	13686	16.14	1.33	17.47
5644	2004-06-02	7330	331.93	27.38	359.31
5645	2004-06-06	4163	54.18	4.47	58.65
5646	2004-06-21	18537	351.70	29.02	380.72
5647	2004-06-07	1222	176.52	14.56	191.08
5648	2004-06-21	17295	165.50	13.65	179.15
5649	2004-06-16	13731	298.36	24.61	322.97
5650	2004-06-03	7543	121.94	10.06	132.00
5651	2004-06-27	12528	238.26	19.66	257.92
5652	2004-06-05	4735	274.24	22.62	296.86
5653	2004-06-14	10175	130.29	10.75	141.04
5654	2004-06-27	13257	288.70	23.82	312.52
5655	2004-06-29	8731	131.50	10.85	142.35
5656	2004-06-14	3368	31.69	2.61	34.30
5657	2004-06-28	18604	172.43	14.23	186.66
5658	2004-06-13	1549	212.18	17.50	229.68
5659	2004-06-20	14449	179.45	14.80	194.25
5660	2004-06-06	19538	110.05	9.08	119.13
5661	2004-06-22	17312	140.40	11.58	151.98
5662	2004-06-26	12245	247.40	20.41	267.81
5663	2004-06-20	9432	222.01	18.32	240.33
5664	2004-06-03	5394	24.31	2.01	26.32
5665	2004-06-14	8951	269.38	22.22	291.60
5666	2004-06-13	18557	38.08	3.14	41.22
5667	2004-06-15	15180	351.62	29.01	380.63
5668	2004-06-09	5353	102.90	8.49	111.39
5669	2004-06-14	6164	26.00	2.15	28.14
5670	2004-06-18	14665	74.45	6.14	80.59
5671	2004-06-05	732	205.75	16.97	222.72
5672	2004-06-14	9742	367.02	30.28	397.30
5673	2004-06-02	16738	366.25	30.22	396.47
5674	2004-06-19	17651	375.96	31.02	406.98
5675	2004-06-10	13175	122.20	10.08	132.28
5676	2004-06-15	18293	345.26	28.48	373.74
5677	2004-06-18	14112	228.49	18.85	247.34
5678	2004-06-01	14637	191.72	15.82	207.54
5679	2004-06-01	9218	384.56	31.73	416.29
5680	2004-06-24	16980	144.78	11.94	156.72
5681	2004-06-07	9314	196.47	16.21	212.68
5682	2004-06-12	6667	4.04	0.33	4.37
5683	2004-06-05	3892	94.99	7.84	102.83
5684	2004-06-10	8434	24.86	2.05	26.91
5685	2004-06-08	15043	349.56	28.84	378.40
5686	2004-06-13	2361	233.42	19.26	252.68
5687	2004-06-20	812	21.51	1.77	23.28
5688	2004-06-18	6067	278.00	22.94	300.94
5689	2004-06-17	4180	326.49	26.94	353.43
5690	2004-06-08	3570	153.92	12.70	166.62
5691	2004-06-02	3870	289.92	23.92	313.84
5692	2004-06-26	313	324.72	26.79	351.51
5693	2004-06-28	13622	235.46	19.43	254.89
5694	2004-06-07	18967	192.54	15.88	208.42
5695	2004-06-12	10769	238.26	19.66	257.92
5696	2004-06-20	9502	334.52	27.60	362.12
5697	2004-06-10	1276	89.73	7.40	97.13
5698	2004-06-29	3576	321.51	26.52	348.03
5699	2004-06-12	13798	144.25	11.90	156.15
5700	2004-06-08	17795	180.77	14.91	195.68
5701	2004-06-24	17458	57.43	4.74	62.17
5702	2004-06-15	9493	118.75	9.80	128.55
5703	2004-06-20	6682	180.29	14.87	195.16
5704	2004-06-24	3923	317.23	26.17	343.40
5705	2004-06-22	16296	350.68	28.93	379.61
5706	2004-06-26	14277	204.59	16.88	221.47
5707	2004-06-21	3541	319.01	26.32	345.33
5708	2004-06-09	10208	8.35	0.69	9.04
5709	2004-06-21	19649	208.56	17.21	225.77
5710	2004-06-17	12331	358.53	29.58	388.11
5711	2004-06-17	6665	275.06	22.69	297.75
5712	2004-06-12	1814	322.28	26.59	348.87
5713	2004-06-11	3696	243.62	20.10	263.72
5714	2004-06-24	15127	398.03	32.84	430.87
5715	2004-06-09	11184	320.08	26.41	346.49
5716	2004-06-28	1186	391.13	32.27	423.40
5717	2004-06-05	9239	132.38	10.92	143.30
5718	2004-06-25	1930	8.49	0.70	9.19
5719	2004-06-17	18996	137.99	11.38	149.37
5720	2004-06-26	9196	320.86	26.47	347.33
5721	2004-06-28	5505	339.89	28.04	367.93
5722	2004-06-28	18380	166.14	13.71	179.85
5723	2004-06-27	2107	269.98	22.27	292.25
5724	2004-06-15	11178	240.39	19.83	260.22
5725	2004-06-21	1915	240.14	19.81	259.95
5726	2004-06-10	7670	37.20	3.07	40.27
5727	2004-06-05	7646	141.61	11.68	153.29
5728	2004-06-05	13082	263.08	21.70	284.78
5729	2004-06-15	4550	216.11	17.83	233.94
5730	2004-06-10	6016	32.99	2.72	35.71
5731	2004-06-05	3326	111.26	9.18	120.44
5732	2004-06-27	15726	83.54	6.89	90.43
5733	2004-06-25	12513	243.57	20.09	263.66
5734	2004-06-20	1893	215.45	17.77	233.22
5735	2004-06-10	11195	282.34	23.29	305.63
5736	2004-06-18	10543	290.71	23.98	314.69
5737	2004-06-11	5936	159.66	13.17	172.83
5738	2004-06-28	6095	228.76	18.87	247.63
5739	2004-06-26	5832	208.37	17.19	225.56
5740	2004-06-16	17794	89.88	7.42	97.30
5741	2004-06-09	17180	237.72	19.61	257.33
5742	2004-06-23	2421	328.42	27.09	355.51
5743	2004-06-01	19585	114.01	9.41	123.42
5744	2004-06-27	18263	151.15	12.47	163.62
5745	2004-06-17	14450	247.17	20.39	267.56
5746	2004-06-23	370	360.86	29.77	390.63
5747	2004-06-19	5565	102.18	8.43	110.61
5748	2004-06-21	16329	159.73	13.18	172.91
5749	2004-06-06	5087	330.81	27.29	358.10
5750	2004-06-05	8775	166.49	13.74	180.23
5751	2004-06-30	7496	308.81	25.48	334.29
5752	2004-06-20	6947	217.50	17.94	235.44
5753	2004-06-23	7388	344.38	28.41	372.79
5754	2004-06-17	15014	364.81	30.10	394.91
5755	2004-06-23	18726	77.62	6.40	84.02
5756	2004-06-04	571	161.86	13.35	175.21
5757	2004-06-05	12589	320.01	26.40	346.41
5758	2004-06-10	9704	119.43	9.85	129.28
5759	2004-06-11	3688	186.99	15.43	202.42
5760	2004-06-12	13637	237.92	19.63	257.55
5761	2004-06-04	4279	184.79	15.25	200.04
5762	2004-06-18	6835	196.38	16.20	212.58
5763	2004-06-20	17854	120.66	9.95	130.61
5764	2004-06-14	4382	264.13	21.79	285.92
5765	2004-06-25	12656	196.21	16.19	212.40
5766	2004-06-26	7599	326.02	26.90	352.92
5767	2004-06-17	14897	158.35	13.06	171.41
5768	2004-06-24	13137	257.24	21.22	278.46
5769	2004-06-19	14809	70.37	5.81	76.18
5770	2004-06-27	14092	32.84	2.71	35.55
5771	2004-06-13	8239	91.66	7.56	99.22
5772	2004-06-04	11722	259.10	21.38	280.48
5773	2004-06-01	5118	304.72	25.14	329.86
5774	2004-06-25	18606	94.55	7.80	102.35
5775	2004-06-21	3751	96.82	7.99	104.81
5776	2004-06-04	14128	79.63	6.57	86.20
5777	2004-06-07	10449	392.16	32.35	424.51
5778	2004-06-09	2448	2.45	0.20	2.65
5779	2004-06-22	14742	75.36	6.22	81.58
5780	2004-06-15	17375	38.59	3.18	41.77
5781	2004-06-07	8357	238.17	19.65	257.82
5782	2004-06-17	3726	124.69	10.29	134.98
5783	2004-06-20	15416	284.83	23.50	308.33
5784	2004-06-12	9292	185.13	15.27	200.40
5785	2004-06-08	4541	242.15	19.98	262.13
5786	2004-06-28	3983	230.81	19.04	249.85
5787	2004-06-25	5563	160.81	13.27	174.08
5788	2004-06-08	3280	65.76	5.43	71.19
5789	2004-06-19	15165	377.52	31.15	408.67
5790	2004-06-27	3858	386.89	31.92	418.81
5791	2004-06-23	124	291.37	24.04	315.41
5792	2004-06-08	11137	177.54	14.65	192.19
5793	2004-06-25	6407	332.73	27.45	360.18
5794	2004-06-06	9896	85.75	7.07	92.82
5795	2004-06-29	7390	128.66	10.61	139.27
5796	2004-06-28	19563	373.26	30.79	404.05
5797	2004-06-07	17051	380.00	31.35	411.35
5798	2004-06-11	10485	399.84	32.99	432.83
5799	2004-06-20	16578	38.88	3.21	42.09
5800	2004-06-17	3872	252.90	20.86	273.76
5801	2004-06-07	13606	104.81	8.65	113.46
5802	2004-06-28	253	17.53	1.45	18.98
5803	2004-06-13	337	97.76	8.07	105.83
5804	2004-06-25	7803	146.78	12.11	158.89
5805	2004-06-26	7933	44.29	3.65	47.94
5806	2004-06-17	6986	316.53	26.11	342.64
5807	2004-06-29	17364	25.70	2.12	27.82
5808	2004-06-13	6390	68.79	5.68	74.47
5809	2004-06-18	7881	123.23	10.17	133.40
5810	2004-06-11	18900	2.35	0.19	2.54
5811	2004-06-15	5229	346.21	28.56	374.77
5812	2004-06-15	10241	320.52	26.44	346.96
5813	2004-06-04	19571	162.07	13.37	175.44
5814	2004-06-29	14969	86.29	7.12	93.41
5815	2004-06-01	13596	371.92	30.68	402.60
5816	2004-06-16	2235	206.04	17.00	223.04
5817	2004-06-20	17060	306.97	25.33	332.30
5818	2004-06-06	17661	261.62	21.58	283.20
5819	2004-06-10	13067	394.94	32.58	427.52
5820	2004-06-07	16529	22.93	1.89	24.82
5821	2004-06-06	11436	106.49	8.79	115.28
5822	2004-06-17	8991	34.26	2.83	37.09
5823	2004-06-02	18499	120.84	9.97	130.81
5824	2004-06-14	18729	253.40	20.91	274.31
5825	2004-06-13	18239	167.31	13.80	181.11
5826	2004-06-14	12183	68.72	5.67	74.39
5827	2004-06-29	8968	140.28	11.57	151.85
5828	2004-06-23	9942	55.10	4.55	59.65
5829	2004-06-29	10477	56.09	4.63	60.72
5830	2004-06-23	817	194.44	16.04	210.48
5831	2004-06-06	15208	386.45	31.88	418.33
5832	2004-06-02	41	160.75	13.26	174.01
5833	2004-06-22	19394	6.70	0.55	7.25
5834	2004-06-20	3313	379.70	31.33	411.03
5835	2004-06-07	12525	392.41	32.37	424.78
5836	2004-06-14	18274	94.04	7.76	101.80
5837	2004-06-29	10749	89.53	7.39	96.92
5838	2004-06-13	19687	193.37	15.95	209.32
5839	2004-06-10	983	174.37	14.39	188.76
5840	2004-06-18	6856	1.59	0.13	1.72
5841	2004-06-22	7893	257.10	21.21	278.31
5842	2004-06-05	2946	343.24	28.32	371.56
5843	2004-06-06	3774	334.53	27.60	362.13
5844	2004-06-28	8484	31.10	2.57	33.67
5845	2004-06-15	12404	137.42	11.34	148.76
5846	2004-06-14	5341	218.34	18.01	236.35
5847	2004-06-06	19658	340.42	28.08	368.50
5848	2004-06-06	12283	272.99	22.52	295.51
5849	2004-06-23	18868	375.92	31.01	406.93
5850	2004-06-09	7543	178.61	14.74	193.35
5851	2004-06-10	6671	12.52	1.03	13.55
5852	2004-06-11	7668	338.37	27.92	366.29
5853	2004-06-01	3454	95.60	7.89	103.49
5854	2004-06-28	4636	382.18	31.53	413.71
5855	2004-06-20	2145	251.44	20.74	272.18
5856	2004-06-02	6253	184.00	15.18	199.18
5857	2004-06-04	1514	287.91	23.75	311.66
5858	2004-06-10	17165	217.45	17.94	235.39
5859	2004-06-13	1879	15.52	1.28	16.80
5860	2004-06-21	9883	107.44	8.86	116.30
5861	2004-06-04	2068	343.69	28.35	372.04
5862	2004-06-15	19115	290.18	23.94	314.12
5863	2004-06-20	1056	77.12	6.36	83.48
5864	2004-06-21	4278	85.50	7.05	92.55
5865	2004-06-07	5508	225.08	18.57	243.65
5866	2004-06-13	15498	260.24	21.47	281.71
5867	2004-06-11	4604	332.66	27.44	360.10
5868	2004-06-10	14111	93.93	7.75	101.68
5869	2004-06-26	8877	352.31	29.07	381.38
5870	2004-06-01	2585	31.36	2.59	33.95
5871	2004-06-05	5978	62.23	5.13	67.36
5872	2004-06-24	4096	93.39	7.70	101.09
5873	2004-06-26	15482	397.97	32.83	430.80
5874	2004-06-13	15430	226.71	18.70	245.41
5875	2004-06-10	15218	267.77	22.09	289.86
5876	2004-06-22	7027	80.94	6.68	87.62
5877	2004-06-01	12994	141.03	11.63	152.66
5878	2004-06-06	19265	281.33	23.21	304.54
5879	2004-06-12	3440	300.25	24.77	325.02
5880	2004-06-30	17682	224.95	18.56	243.51
5881	2004-06-07	17851	344.48	28.42	372.90
5882	2004-06-07	9248	272.13	22.45	294.58
5883	2004-06-27	15344	86.62	7.15	93.77
5884	2004-06-14	9710	192.35	15.87	208.22
5885	2004-06-18	12098	345.12	28.47	373.59
5886	2004-06-21	9087	342.18	28.23	370.41
5887	2004-06-12	10529	390.63	32.23	422.86
5888	2004-06-11	4870	286.45	23.63	310.08
5889	2004-06-19	19231	335.95	27.72	363.67
5890	2004-06-09	4738	156.34	12.90	169.24
5891	2004-06-30	8157	352.01	29.04	381.05
5892	2004-06-12	14249	130.88	10.80	141.68
5893	2004-06-13	19356	182.03	15.02	197.05
5894	2004-06-30	13545	56.36	4.65	61.01
5895	2004-06-27	18818	240.14	19.81	259.95
5896	2004-06-26	18118	48.68	4.02	52.70
5897	2004-06-10	10445	211.69	17.46	229.15
5898	2004-06-28	4021	310.94	25.65	336.59
5899	2004-06-09	2623	257.09	21.21	278.30
5900	2004-06-05	5258	300.70	24.81	325.51
5901	2004-06-22	8887	297.61	24.55	322.16
5902	2004-06-30	4325	92.70	7.65	100.35
5903	2004-06-08	6666	323.17	26.66	349.83
5904	2004-06-16	13281	236.59	19.52	256.11
5905	2004-06-27	12375	109.81	9.06	118.87
5906	2004-06-12	14683	302.22	24.93	327.15
5907	2004-06-15	13079	249.26	20.56	269.82
5908	2004-06-04	14696	232.99	19.22	252.21
5909	2004-06-23	3116	16.59	1.37	17.96
5910	2004-06-24	3015	392.07	32.35	424.42
5911	2004-06-15	6018	105.46	8.70	114.16
5912	2004-06-27	14427	171.30	14.13	185.43
5913	2004-06-21	12845	19.71	1.63	21.34
5914	2004-06-21	12537	0.27	0.02	0.29
5915	2004-06-07	11153	213.69	17.63	231.32
5916	2004-06-22	10698	238.29	19.66	257.95
5917	2004-06-11	14904	230.81	19.04	249.85
5918	2004-06-18	2700	309.94	25.57	335.51
5919	2004-06-16	15340	265.16	21.88	287.04
5920	2004-06-01	14076	147.05	12.13	159.18
5921	2004-06-08	8120	180.24	14.87	195.11
5922	2004-06-01	8345	351.94	29.04	380.98
5923	2004-06-23	5364	260.45	21.49	281.94
5924	2004-06-27	19621	246.29	20.32	266.61
5925	2004-06-09	4360	71.23	5.88	77.11
5926	2004-06-22	1989	321.97	26.56	348.53
5927	2004-06-21	16354	385.84	31.83	417.67
5928	2004-06-23	1726	34.19	2.82	37.01
5929	2004-06-12	4865	189.53	15.64	205.17
5930	2004-06-05	7561	275.07	22.69	297.76
5931	2004-06-13	5390	80.19	6.62	86.81
5932	2004-06-11	17345	226.12	18.65	244.77
5933	2004-06-15	15744	283.76	23.41	307.17
5934	2004-06-04	4103	275.39	22.72	298.11
5935	2004-06-15	9825	196.83	16.24	213.07
5936	2004-06-04	1589	238.59	19.68	258.27
5937	2004-06-15	8271	235.68	19.44	255.12
5938	2004-06-11	14828	20.83	1.72	22.55
5939	2004-06-28	1562	128.10	10.57	138.67
5940	2004-06-23	67	284.68	23.49	308.17
5941	2004-06-12	18574	195.19	16.10	211.29
5942	2004-06-02	3462	189.44	15.63	205.07
5943	2004-06-02	6306	112.56	9.29	121.85
5944	2004-06-09	5519	352.07	29.05	381.12
5945	2004-06-01	5657	336.91	27.80	364.71
5946	2004-06-18	7638	153.29	12.65	165.94
5947	2004-06-25	10831	73.12	6.03	79.15
5948	2004-06-09	15017	32.34	2.67	35.01
5949	2004-06-29	17455	332.07	27.40	359.47
5950	2004-06-30	14199	331.53	27.35	358.88
5951	2004-06-14	700	300.30	24.77	325.07
5952	2004-06-05	19485	267.31	22.05	289.36
5953	2004-06-24	13401	395.23	32.61	427.84
5954	2004-06-29	1798	60.78	5.01	65.79
5955	2004-06-26	15655	50.39	4.16	54.55
5956	2004-06-01	2250	20.42	1.68	22.10
5957	2004-06-07	4015	343.76	28.36	372.12
5958	2004-06-24	2493	157.61	13.00	170.61
5959	2004-06-12	3620	104.66	8.63	113.29
5960	2004-06-25	652	78.92	6.51	85.43
5961	2004-06-24	14113	196.13	16.18	212.31
5962	2004-06-06	18986	104.58	8.63	113.21
5963	2004-06-10	1285	353.12	29.13	382.25
5964	2004-06-09	13129	50.02	4.13	54.15
5965	2004-06-06	6021	292.00	24.09	316.09
5966	2004-06-14	17682	393.63	32.47	426.10
5967	2004-06-20	3080	252.34	20.82	273.16
5968	2004-06-22	19886	197.39	16.28	213.67
5969	2004-06-27	452	61.12	5.04	66.16
5970	2004-06-07	19948	265.31	21.89	287.20
5971	2004-06-23	7695	50.13	4.14	54.27
5972	2004-06-11	1101	101.18	8.35	109.53
5973	2004-06-06	903	32.00	2.64	34.64
5974	2004-06-29	1360	69.61	5.74	75.35
5975	2004-06-01	13686	266.31	21.97	288.28
5976	2004-06-02	17064	194.57	16.05	210.62
5977	2004-06-25	7723	149.78	12.36	162.14
5978	2004-06-09	9608	298.22	24.60	322.82
5979	2004-06-08	2440	86.94	7.17	94.11
5980	2004-06-21	435	154.51	12.75	167.26
5981	2004-06-03	17297	214.46	17.69	232.15
5982	2004-06-27	13160	300.61	24.80	325.41
5983	2004-06-25	4167	364.25	30.05	394.30
5984	2004-06-29	9483	372.34	30.72	403.06
5985	2004-06-04	3228	59.79	4.93	64.72
5986	2004-06-19	11281	220.39	18.18	238.57
5987	2004-06-24	13622	173.24	14.29	187.53
5988	2004-06-14	11783	336.56	27.77	364.33
5989	2004-06-10	3572	294.54	24.30	318.84
5990	2004-06-18	19481	369.12	30.45	399.57
5991	2004-06-27	19902	167.44	13.81	181.25
5992	2004-06-22	13704	268.85	22.18	291.03
5993	2004-06-21	5849	214.65	17.71	232.36
5994	2004-06-07	15656	28.12	2.32	30.44
5995	2004-06-29	12785	243.99	20.13	264.12
5996	2004-06-05	9280	384.15	31.69	415.84
5997	2004-06-10	19698	258.13	21.30	279.43
5998	2004-06-05	4330	303.76	25.06	328.82
5999	2004-06-30	223	14.10	1.16	15.26
6000	2004-06-24	7525	267.42	22.06	289.48
6001	2004-07-04	16984	67.99	5.61	73.60
6002	2004-07-14	5465	262.95	21.69	284.64
6003	2004-07-20	5650	365.80	30.18	395.98
6004	2004-07-08	3023	378.63	31.24	409.87
6005	2004-07-01	9521	208.61	17.21	225.82
6006	2004-07-15	8131	190.72	15.73	206.45
6007	2004-07-20	7675	238.46	19.67	258.13
6008	2004-07-08	19226	370.03	30.53	400.56
6009	2004-07-24	3743	225.23	18.58	243.81
6010	2004-07-06	4152	332.86	27.46	360.32
6011	2004-07-25	11755	267.96	22.11	290.07
6012	2004-07-20	7606	166.74	13.76	180.50
6013	2004-07-14	5012	76.31	6.30	82.61
6014	2004-07-20	15150	197.57	16.30	213.87
6015	2004-07-03	10217	168.26	13.88	182.14
6016	2004-07-01	19445	298.94	24.66	323.60
6017	2004-07-06	40	55.13	4.55	59.68
6018	2004-07-17	731	107.09	8.83	115.92
6019	2004-07-14	14704	290.82	23.99	314.81
6020	2004-07-08	17249	324.30	26.75	351.05
6021	2004-07-19	17307	9.46	0.78	10.24
6022	2004-07-20	16642	257.43	21.24	278.67
6023	2004-07-12	1856	154.53	12.75	167.28
6024	2004-07-09	5974	5.05	0.42	5.47
6025	2004-07-02	17528	78.22	6.45	84.67
6026	2004-07-06	13128	252.93	20.87	273.80
6027	2004-07-31	91	293.24	24.19	317.43
6028	2004-07-15	13972	270.40	22.31	292.71
6029	2004-07-16	5087	124.37	10.26	134.63
6030	2004-07-21	19978	252.06	20.79	272.85
6031	2004-07-27	2521	159.89	13.19	173.08
6032	2004-07-07	10514	322.90	26.64	349.54
6033	2004-07-30	12113	319.52	26.36	345.88
6034	2004-07-26	12387	3.91	0.32	4.23
6035	2004-07-02	6658	20.66	1.70	22.36
6036	2004-07-25	15008	119.19	9.83	129.02
6037	2004-07-05	4726	286.65	23.65	310.30
6038	2004-07-17	16132	393.77	32.49	426.26
6039	2004-07-07	14340	133.29	11.00	144.29
6040	2004-07-10	441	358.69	29.59	388.28
6041	2004-07-03	1319	162.31	13.39	175.70
6042	2004-07-27	18096	8.95	0.74	9.69
6043	2004-07-19	17190	31.13	2.57	33.70
6044	2004-07-16	19784	236.14	19.48	255.62
6045	2004-07-17	3288	30.63	2.53	33.16
6046	2004-07-15	15016	80.97	6.68	87.65
6047	2004-07-07	19354	120.37	9.93	130.30
6048	2004-07-03	9699	79.14	6.53	85.67
6049	2004-07-12	14177	27.11	2.24	29.35
6050	2004-07-10	17053	164.34	13.56	177.90
6051	2004-07-20	4452	251.31	20.73	272.04
6052	2004-07-12	14533	396.22	32.69	428.91
6053	2004-07-24	7026	270.93	22.35	293.28
6054	2004-07-26	4956	253.94	20.95	274.89
6055	2004-07-24	17383	29.72	2.45	32.17
6056	2004-07-25	11354	173.18	14.29	187.47
6057	2004-07-21	5741	196.99	16.25	213.24
6058	2004-07-21	19581	333.14	27.48	360.62
6059	2004-07-27	15051	156.14	12.88	169.02
6060	2004-07-31	18524	272.65	22.49	295.14
6061	2004-07-04	19795	237.83	19.62	257.45
6062	2004-07-03	19956	260.51	21.49	282.00
6063	2004-07-14	16921	366.87	30.27	397.14
6064	2004-07-22	3287	6.03	0.50	6.53
6065	2004-07-28	6230	151.80	12.52	164.32
6066	2004-07-20	3359	304.09	25.09	329.18
6067	2004-07-15	9720	68.57	5.66	74.23
6068	2004-07-02	16039	71.28	5.88	77.16
6069	2004-07-28	14671	54.22	4.47	58.69
6070	2004-07-30	3329	289.25	23.86	313.11
6071	2004-07-27	16333	53.56	4.42	57.98
6072	2004-07-28	5071	310.76	25.64	336.40
6073	2004-07-05	2027	371.45	30.64	402.09
6074	2004-07-17	8271	45.55	3.76	49.31
6075	2004-07-14	6707	307.22	25.35	332.57
6076	2004-07-25	6247	342.27	28.24	370.51
6077	2004-07-09	6249	358.06	29.54	387.60
6078	2004-07-10	4280	17.45	1.44	18.89
6079	2004-07-05	3583	85.74	7.07	92.81
6080	2004-07-24	4894	176.20	14.54	190.74
6081	2004-07-27	2823	184.23	15.20	199.43
6082	2004-07-09	12948	144.16	11.89	156.05
6083	2004-07-12	1321	303.80	25.06	328.86
6084	2004-07-18	18571	174.57	14.40	188.97
6085	2004-07-16	14530	183.55	15.14	198.69
6086	2004-07-24	10246	146.23	12.06	158.29
6087	2004-07-20	225	57.66	4.76	62.42
6088	2004-07-26	3299	208.89	17.23	226.12
6089	2004-07-04	16584	9.22	0.76	9.98
6090	2004-07-26	17584	287.07	23.68	310.75
6091	2004-07-03	17969	175.07	14.44	189.51
6092	2004-07-19	2456	175.43	14.47	189.90
6093	2004-07-11	14964	360.12	29.71	389.83
6094	2004-07-26	6462	286.18	23.61	309.79
6095	2004-07-01	3784	34.03	2.81	36.84
6096	2004-07-04	665	9.26	0.76	10.02
6097	2004-07-11	4128	329.95	27.22	357.17
6098	2004-07-02	4134	239.51	19.76	259.27
6099	2004-07-26	13544	262.33	21.64	283.97
6100	2004-07-24	16682	134.12	11.06	145.18
6101	2004-07-14	6879	17.58	1.45	19.03
6102	2004-07-31	14160	171.00	14.11	185.11
6103	2004-07-18	372	46.28	3.82	50.10
6104	2004-07-13	18127	210.80	17.39	228.19
6105	2004-07-19	8100	336.48	27.76	364.24
6106	2004-07-26	3135	28.48	2.35	30.83
6107	2004-07-30	18611	396.31	32.70	429.01
6108	2004-07-08	10558	160.06	13.20	173.26
6109	2004-07-09	12180	289.56	23.89	313.45
6110	2004-07-03	11192	312.64	25.79	338.43
6111	2004-07-16	8816	34.70	2.86	37.56
6112	2004-07-23	11897	251.31	20.73	272.04
6113	2004-07-05	3413	118.07	9.74	127.81
6114	2004-07-01	12793	268.09	22.12	290.21
6115	2004-07-17	4857	197.80	16.32	214.12
6116	2004-07-25	9573	59.06	4.87	63.93
6117	2004-07-29	13377	45.86	3.78	49.64
6118	2004-07-02	1646	110.58	9.12	119.70
6119	2004-07-02	4444	124.16	10.24	134.40
6120	2004-07-25	3446	137.13	11.31	148.44
6121	2004-07-12	7312	11.87	0.98	12.85
6122	2004-07-10	2367	94.86	7.83	102.69
6123	2004-07-22	2678	25.59	2.11	27.70
6124	2004-07-14	13443	326.43	26.93	353.36
6125	2004-07-08	12719	257.60	21.25	278.85
6126	2004-07-20	15660	89.54	7.39	96.93
6127	2004-07-11	13301	184.22	15.20	199.42
6128	2004-07-05	4570	242.76	20.03	262.79
6129	2004-07-10	7668	160.78	13.26	174.04
6130	2004-07-31	18567	273.14	22.53	295.67
6131	2004-07-12	14398	248.05	20.46	268.51
6132	2004-07-27	1483	8.29	0.68	8.97
6133	2004-07-08	13278	152.94	12.62	165.56
6134	2004-07-27	1870	308.51	25.45	333.96
6135	2004-07-27	13897	279.83	23.09	302.92
6136	2004-07-02	16684	16.44	1.36	17.80
6137	2004-07-26	15321	1.20	0.10	1.30
6138	2004-07-14	14808	258.92	21.36	280.28
6139	2004-07-28	1853	266.26	21.97	288.23
6140	2004-07-30	5374	393.40	32.46	425.86
6141	2004-07-30	13179	76.08	6.28	82.36
6142	2004-07-28	11196	277.29	22.88	300.17
6143	2004-07-19	5483	59.36	4.90	64.26
6144	2004-07-29	9081	291.30	24.03	315.33
6145	2004-07-30	8011	238.14	19.65	257.79
6146	2004-07-11	17597	298.76	24.65	323.41
6147	2004-07-18	10170	98.78	8.15	106.93
6148	2004-07-23	17916	79.47	6.56	86.03
6149	2004-07-01	5140	155.83	12.86	168.69
6150	2004-07-26	16694	128.56	10.61	139.17
6151	2004-07-01	16906	258.79	21.35	280.14
6152	2004-07-08	11551	186.96	15.42	202.38
6153	2004-07-10	6991	206.95	17.07	224.02
6154	2004-07-06	17263	241.42	19.92	261.34
6155	2004-07-20	2492	1.83	0.15	1.98
6156	2004-07-13	5255	155.60	12.84	168.44
6157	2004-07-29	9161	229.57	18.94	248.51
6158	2004-07-30	12243	73.69	6.08	79.77
6159	2004-07-22	3997	349.64	28.85	378.49
6160	2004-07-13	8808	263.25	21.72	284.97
6161	2004-07-03	1002	91.65	7.56	99.21
6162	2004-07-13	17700	172.41	14.22	186.63
6163	2004-07-22	14656	243.74	20.11	263.85
6164	2004-07-03	15856	11.98	0.99	12.97
6165	2004-07-03	15651	162.45	13.40	175.85
6166	2004-07-29	19348	233.88	19.30	253.18
6167	2004-07-17	17245	143.84	11.87	155.71
6168	2004-07-10	4977	99.38	8.20	107.58
6169	2004-07-29	13292	261.61	21.58	283.19
6170	2004-07-27	18514	55.41	4.57	59.98
6171	2004-07-30	11692	34.92	2.88	37.80
6172	2004-07-03	16857	317.98	26.23	344.21
6173	2004-07-28	1546	248.44	20.50	268.94
6174	2004-07-19	724	38.43	3.17	41.60
6175	2004-07-06	1293	103.99	8.58	112.57
6176	2004-07-02	3138	290.88	24.00	314.88
6177	2004-07-21	18399	388.24	32.03	420.27
6178	2004-07-18	2587	278.93	23.01	301.94
6179	2004-07-04	3124	213.86	17.64	231.50
6180	2004-07-17	8912	362.70	29.92	392.62
6181	2004-07-04	3928	194.41	16.04	210.45
6182	2004-07-29	10315	20.26	1.67	21.93
6183	2004-07-30	17252	285.83	23.58	309.41
6184	2004-07-04	17125	31.50	2.60	34.10
6185	2004-07-20	18024	163.85	13.52	177.37
6186	2004-07-08	19695	390.87	32.25	423.12
6187	2004-07-28	17059	80.24	6.62	86.86
6188	2004-07-31	14379	286.68	23.65	310.33
6189	2004-07-18	1659	197.68	16.31	213.99
6190	2004-07-28	19427	293.64	24.23	317.87
6191	2004-07-15	18397	117.76	9.72	127.48
6192	2004-07-14	445	240.40	19.83	260.23
6193	2004-07-25	7275	349.88	28.87	378.75
6194	2004-07-01	1124	274.71	22.66	297.37
6195	2004-07-02	8915	303.51	25.04	328.55
6196	2004-07-12	3177	116.10	9.58	125.68
6197	2004-07-14	4352	252.92	20.87	273.79
6198	2004-07-26	8313	126.18	10.41	136.59
6199	2004-07-16	1726	63.72	5.26	68.98
6200	2004-07-27	13328	29.01	2.39	31.40
6201	2004-07-05	14305	113.78	9.39	123.17
6202	2004-07-03	10664	358.56	29.58	388.14
6203	2004-07-08	7306	305.59	25.21	330.80
6204	2004-07-17	4316	15.50	1.28	16.78
6205	2004-07-21	15685	129.70	10.70	140.40
6206	2004-07-22	70	344.83	28.45	373.28
6207	2004-07-11	18380	228.57	18.86	247.43
6208	2004-07-13	11960	74.96	6.18	81.14
6209	2004-07-20	19741	256.12	21.13	277.25
6210	2004-07-09	16066	166.83	13.76	180.59
6211	2004-07-22	12357	218.41	18.02	236.43
6212	2004-07-02	10114	31.43	2.59	34.02
6213	2004-07-22	4855	60.76	5.01	65.77
6214	2004-07-23	673	198.54	16.38	214.92
6215	2004-07-18	14636	48.09	3.97	52.06
6216	2004-07-22	4155	203.93	16.82	220.75
6217	2004-07-31	18284	335.61	27.69	363.30
6218	2004-07-17	445	48.03	3.96	51.99
6219	2004-07-26	12407	18.35	1.51	19.86
6220	2004-07-26	7515	18.89	1.56	20.45
6221	2004-07-04	9374	377.42	31.14	408.56
6222	2004-07-16	6908	262.75	21.68	284.43
6223	2004-07-24	15563	32.41	2.67	35.08
6224	2004-07-08	8474	303.53	25.04	328.57
6225	2004-07-07	4329	102.33	8.44	110.77
6226	2004-07-17	4573	159.50	13.16	172.66
6227	2004-07-15	9616	371.88	30.68	402.56
6228	2004-07-07	6847	137.63	11.35	148.98
6229	2004-07-31	4816	7.89	0.65	8.54
6230	2004-07-15	3090	101.12	8.34	109.46
6231	2004-07-03	18137	300.33	24.78	325.11
6232	2004-07-30	15844	362.53	29.91	392.44
6233	2004-07-19	14930	73.43	6.06	79.49
6234	2004-07-22	18539	95.65	7.89	103.54
6235	2004-07-18	155	161.94	13.36	175.30
6236	2004-07-01	17975	369.07	30.45	399.52
6237	2004-07-09	11148	28.09	2.32	30.41
6238	2004-07-16	19584	84.72	6.99	91.71
6239	2004-07-06	7	341.44	28.17	369.61
6240	2004-07-22	19583	43.63	3.60	47.23
6241	2004-07-16	3031	390.36	32.20	422.56
6242	2004-07-16	10398	171.66	14.16	185.82
6243	2004-07-02	15835	129.38	10.67	140.05
6244	2004-07-14	16592	156.75	12.93	169.68
6245	2004-07-17	14344	44.92	3.71	48.63
6246	2004-07-13	11904	237.35	19.58	256.93
6247	2004-07-31	11678	103.17	8.51	111.68
6248	2004-07-04	16960	66.61	5.50	72.11
6249	2004-07-15	4710	7.58	0.63	8.21
6250	2004-07-12	5698	299.06	24.67	323.73
6251	2004-07-29	1394	187.77	15.49	203.26
6252	2004-07-20	6138	287.00	23.68	310.68
6253	2004-07-07	17897	386.98	31.93	418.91
6254	2004-07-05	18523	185.93	15.34	201.27
6255	2004-07-07	10012	343.12	28.31	371.43
6256	2004-07-17	6939	73.37	6.05	79.42
6257	2004-07-27	14413	9.73	0.80	10.53
6258	2004-07-19	10899	244.32	20.16	264.48
6259	2004-07-18	9509	44.67	3.69	48.36
6260	2004-07-28	4064	130.88	10.80	141.68
6261	2004-07-19	15789	369.08	30.45	399.53
6262	2004-07-29	11114	33.77	2.79	36.56
6263	2004-07-01	4496	164.09	13.54	177.63
6264	2004-07-19	12483	113.23	9.34	122.57
6265	2004-07-06	10154	304.27	25.10	329.37
6266	2004-07-11	4291	78.34	6.46	84.80
6267	2004-07-21	4499	189.82	15.66	205.48
6268	2004-07-15	10100	185.56	15.31	200.87
6269	2004-07-29	9451	194.47	16.04	210.51
6270	2004-07-30	14916	59.76	4.93	64.69
6271	2004-07-26	9016	54.18	4.47	58.65
6272	2004-07-05	3848	385.65	31.82	417.47
6273	2004-07-20	18438	166.23	13.71	179.94
6274	2004-07-26	11524	118.20	9.75	127.95
6275	2004-07-13	7665	323.95	26.73	350.68
6276	2004-07-30	7677	71.16	5.87	77.03
6277	2004-07-10	4142	395.53	32.63	428.16
6278	2004-07-18	11103	312.11	25.75	337.86
6279	2004-07-15	7365	221.56	18.28	239.84
6280	2004-07-12	4728	41.60	3.43	45.03
6281	2004-07-10	11995	139.05	11.47	150.52
6282	2004-07-27	2644	116.97	9.65	126.62
6283	2004-07-20	14848	30.79	2.54	33.33
6284	2004-07-15	15506	12.16	1.00	13.16
6285	2004-07-13	17438	331.08	27.31	358.39
6286	2004-07-06	8475	0.89	0.07	0.96
6287	2004-07-09	16242	169.99	14.02	184.01
6288	2004-07-21	1492	399.67	32.97	432.64
6289	2004-07-18	15832	318.32	26.26	344.58
6290	2004-07-19	3071	69.52	5.74	75.26
6291	2004-07-14	4110	366.94	30.27	397.21
6292	2004-07-20	19298	97.83	8.07	105.90
6293	2004-07-27	1533	110.72	9.13	119.85
6294	2004-07-04	12887	174.60	14.40	189.00
6295	2004-07-22	6577	326.18	26.91	353.09
6296	2004-07-16	11253	259.49	21.41	280.90
6297	2004-07-29	1681	306.18	25.26	331.44
6298	2004-07-28	7923	309.32	25.52	334.84
6299	2004-07-23	2133	222.54	18.36	240.90
6300	2004-07-11	153	227.37	18.76	246.13
6301	2004-07-26	7884	127.97	10.56	138.53
6302	2004-07-19	7260	389.36	32.12	421.48
6303	2004-07-14	7716	335.63	27.69	363.32
6304	2004-07-16	7356	369.22	30.46	399.68
6305	2004-07-16	16848	378.24	31.20	409.44
6306	2004-07-26	5524	144.86	11.95	156.81
6307	2004-07-08	10021	12.01	0.99	13.00
6308	2004-07-14	18448	238.95	19.71	258.66
6309	2004-07-03	1949	162.81	13.43	176.24
6310	2004-07-02	16233	221.98	18.31	240.29
6311	2004-07-26	14043	20.71	1.71	22.42
6312	2004-07-06	1368	322.01	26.57	348.58
6313	2004-07-13	19511	146.13	12.06	158.19
6314	2004-07-13	17744	310.36	25.60	335.96
6315	2004-07-31	15025	170.01	14.03	184.04
6316	2004-07-13	4168	238.31	19.66	257.97
6317	2004-07-21	12630	309.00	25.49	334.49
6318	2004-07-09	3670	323.08	26.65	349.73
6319	2004-07-20	16616	154.89	12.78	167.67
6320	2004-07-17	7761	64.00	5.28	69.28
6321	2004-07-26	16532	42.57	3.51	46.08
6322	2004-07-15	18757	247.09	20.38	267.47
6323	2004-07-18	15372	83.92	6.92	90.84
6324	2004-07-17	15939	150.71	12.43	163.14
6325	2004-07-04	13917	22.03	1.82	23.85
6326	2004-07-27	14608	107.79	8.89	116.68
6327	2004-07-30	15688	62.62	5.17	67.79
6328	2004-07-03	12014	286.83	23.66	310.49
6329	2004-07-18	16640	213.61	17.62	231.23
6330	2004-07-08	9629	267.95	22.11	290.06
6331	2004-07-22	17955	250.84	20.69	271.53
6332	2004-07-18	5790	52.73	4.35	57.08
6333	2004-07-01	4605	365.01	30.11	395.12
6334	2004-07-02	10976	65.72	5.42	71.14
6335	2004-07-26	6518	136.50	11.26	147.76
6336	2004-07-14	2035	306.60	25.29	331.89
6337	2004-07-05	10827	219.06	18.07	237.13
6338	2004-07-04	5523	360.95	29.78	390.73
6339	2004-07-12	5256	394.54	32.55	427.09
6340	2004-07-20	12095	314.67	25.96	340.63
6341	2004-07-11	3466	106.99	8.83	115.82
6342	2004-07-01	11659	286.08	23.60	309.68
6343	2004-07-27	14499	194.39	16.04	210.43
6344	2004-07-25	11413	96.35	7.95	104.30
6345	2004-07-23	12309	302.91	24.99	327.90
6346	2004-07-01	3816	155.63	12.84	168.47
6347	2004-07-04	12506	332.19	27.41	359.60
6348	2004-07-11	4837	358.63	29.59	388.22
6349	2004-07-21	8590	221.35	18.26	239.61
6350	2004-07-01	17501	91.91	7.58	99.49
6351	2004-07-28	18063	67.75	5.59	73.34
6352	2004-07-15	9010	237.78	19.62	257.40
6353	2004-07-14	10012	391.83	32.33	424.16
6354	2004-07-04	3584	95.94	7.92	103.86
6355	2004-07-30	8792	64.51	5.32	69.83
6356	2004-07-16	2597	67.56	5.57	73.13
6357	2004-07-01	4353	352.65	29.09	381.74
6358	2004-07-16	14947	69.96	5.77	75.73
6359	2004-07-29	12990	354.58	29.25	383.83
6360	2004-07-25	10209	213.40	17.61	231.01
6361	2004-07-07	12027	195.81	16.15	211.96
6362	2004-07-10	16766	26.73	2.21	28.94
6363	2004-07-13	18233	246.00	20.30	266.30
6364	2004-07-20	5505	2.31	0.19	2.50
6365	2004-07-19	11839	260.36	21.48	281.84
6366	2004-07-17	18943	120.04	9.90	129.94
6367	2004-07-13	7678	33.35	2.75	36.10
6368	2004-07-05	13169	313.83	25.89	339.72
6369	2004-07-24	6543	279.32	23.04	302.36
6370	2004-07-19	6595	280.11	23.11	303.22
6371	2004-07-28	15132	72.24	5.96	78.20
6372	2004-07-08	7516	141.82	11.70	153.52
6373	2004-07-03	19248	95.92	7.91	103.83
6374	2004-07-30	7706	88.50	7.30	95.80
6375	2004-07-03	2667	340.63	28.10	368.73
6376	2004-07-17	9576	336.06	27.72	363.78
6377	2004-07-19	1782	110.29	9.10	119.39
6378	2004-07-29	5564	6.07	0.50	6.57
6379	2004-07-28	6299	205.06	16.92	221.98
6380	2004-07-13	12358	45.83	3.78	49.61
6381	2004-07-26	14241	67.43	5.56	72.99
6382	2004-07-24	3307	113.08	9.33	122.41
6383	2004-07-30	12115	88.90	7.33	96.23
6384	2004-07-22	7498	30.30	2.50	32.80
6385	2004-07-08	634	208.67	17.22	225.89
6386	2004-07-23	9883	166.78	13.76	180.54
6387	2004-07-27	9738	314.91	25.98	340.89
6388	2004-07-20	14685	144.29	11.90	156.19
6389	2004-07-28	17143	70.75	5.84	76.59
6390	2004-07-21	17421	338.35	27.91	366.26
6391	2004-07-06	1946	63.60	5.25	68.85
6392	2004-07-26	4068	246.27	20.32	266.59
6393	2004-07-29	889	344.19	28.40	372.59
6394	2004-07-24	4083	86.54	7.14	93.68
6395	2004-07-05	18136	159.97	13.20	173.17
6396	2004-07-15	3719	322.04	26.57	348.61
6397	2004-07-23	12617	366.23	30.21	396.44
6398	2004-07-20	8248	92.13	7.60	99.73
6399	2004-07-31	3208	146.16	12.06	158.22
6400	2004-07-09	13519	68.89	5.68	74.57
6401	2004-07-18	990	199.64	16.47	216.11
6402	2004-07-08	15095	110.87	9.15	120.02
6403	2004-07-15	4375	305.30	25.19	330.49
6404	2004-07-24	14354	387.66	31.98	419.64
6405	2004-07-18	19155	315.38	26.02	341.40
6406	2004-07-26	3468	136.79	11.29	148.08
6407	2004-07-17	12184	76.78	6.33	83.11
6408	2004-07-11	15997	327.99	27.06	355.05
6409	2004-07-18	11461	338.50	27.93	366.43
6410	2004-07-22	5976	324.56	26.78	351.34
6411	2004-07-12	14284	178.67	14.74	193.41
6412	2004-07-03	10933	87.19	7.19	94.38
6413	2004-07-20	2046	261.93	21.61	283.54
6414	2004-07-07	10215	346.42	28.58	375.00
6415	2004-07-04	10204	345.37	28.49	373.86
6416	2004-07-11	11523	399.20	32.93	432.13
6417	2004-07-01	7294	306.63	25.30	331.93
6418	2004-07-27	8737	57.26	4.72	61.98
6419	2004-07-17	17787	256.59	21.17	277.76
6420	2004-07-30	17815	125.53	10.36	135.89
6421	2004-07-02	8282	164.97	13.61	178.58
6422	2004-07-05	2338	76.00	6.27	82.27
6423	2004-07-01	15305	10.05	0.83	10.88
6424	2004-07-04	7242	94.46	7.79	102.25
6425	2004-07-17	16505	384.47	31.72	416.19
6426	2004-07-26	8663	125.63	10.36	135.99
6427	2004-07-11	6195	221.30	18.26	239.56
6428	2004-07-13	11060	128.36	10.59	138.95
6429	2004-07-05	3754	396.51	32.71	429.22
6430	2004-07-12	9243	97.88	8.08	105.96
6431	2004-07-09	4217	127.58	10.53	138.11
6432	2004-07-21	19639	302.19	24.93	327.12
6433	2004-07-17	4070	187.47	15.47	202.94
6434	2004-07-29	10526	95.90	7.91	103.81
6435	2004-07-23	5084	103.92	8.57	112.49
6436	2004-07-24	12072	99.62	8.22	107.84
6437	2004-07-26	3861	91.88	7.58	99.46
6438	2004-07-30	13682	49.42	4.08	53.50
6439	2004-07-19	8424	251.37	20.74	272.11
6440	2004-07-30	3145	101.58	8.38	109.96
6441	2004-07-04	17601	327.58	27.03	354.61
6442	2004-07-17	14205	309.60	25.54	335.14
6443	2004-07-18	10948	170.51	14.07	184.58
6444	2004-07-05	5410	83.20	6.86	90.06
6445	2004-07-26	5173	197.86	16.32	214.18
6446	2004-07-04	18933	388.33	32.04	420.37
6447	2004-07-18	11278	354.20	29.22	383.42
6448	2004-07-11	17250	279.96	23.10	303.06
6449	2004-07-26	9048	359.05	29.62	388.67
6450	2004-07-13	5338	285.07	23.52	308.59
6451	2004-07-23	3862	396.64	32.72	429.36
6452	2004-07-15	15727	8.72	0.72	9.44
6453	2004-07-25	14085	134.33	11.08	145.41
6454	2004-07-29	3708	64.36	5.31	69.67
6455	2004-07-02	8477	133.16	10.99	144.15
6456	2004-07-17	8700	359.20	29.63	388.83
6457	2004-07-23	5760	95.81	7.90	103.71
6458	2004-07-20	17469	363.34	29.98	393.32
6459	2004-07-10	4036	292.68	24.15	316.83
6460	2004-07-07	8510	195.87	16.16	212.03
6461	2004-07-05	16239	71.38	5.89	77.27
6462	2004-07-03	1861	89.79	7.41	97.20
6463	2004-07-28	11030	150.29	12.40	162.69
6464	2004-07-12	11399	281.38	23.21	304.59
6465	2004-07-28	16405	125.44	10.35	135.79
6466	2004-07-01	8209	171.77	14.17	185.94
6467	2004-07-16	6633	305.79	25.23	331.02
6468	2004-07-03	13786	394.30	32.53	426.83
6469	2004-07-11	9969	164.76	13.59	178.35
6470	2004-07-18	9787	194.57	16.05	210.62
6471	2004-07-03	17722	15.28	1.26	16.54
6472	2004-07-22	15476	20.57	1.70	22.27
6473	2004-07-05	12885	310.72	25.63	336.35
6474	2004-07-31	16302	34.57	2.85	37.42
6475	2004-07-01	11970	253.78	20.94	274.72
6476	2004-07-17	15275	220.35	18.18	238.53
6477	2004-07-14	9741	394.30	32.53	426.83
6478	2004-07-11	11422	194.44	16.04	210.48
6479	2004-07-14	10306	389.68	32.15	421.83
6480	2004-07-21	15142	39.69	3.27	42.96
6481	2004-07-13	18506	239.95	19.80	259.75
6482	2004-07-18	8727	69.01	5.69	74.70
6483	2004-07-06	16320	89.79	7.41	97.20
6484	2004-07-04	3013	131.40	10.84	142.24
6485	2004-07-26	1049	260.57	21.50	282.07
6486	2004-07-25	12510	201.57	16.63	218.20
6487	2004-07-08	16280	395.75	32.65	428.40
6488	2004-07-06	5856	102.34	8.44	110.78
6489	2004-07-13	17407	264.80	21.85	286.65
6490	2004-07-21	6487	374.32	30.88	405.20
6491	2004-07-06	18943	350.57	28.92	379.49
6492	2004-07-22	4481	396.11	32.68	428.79
6493	2004-07-16	4779	133.68	11.03	144.71
6494	2004-07-23	11430	204.84	16.90	221.74
6495	2004-07-21	13919	305.34	25.19	330.53
6496	2004-07-01	1027	55.74	4.60	60.34
6497	2004-07-08	1020	345.05	28.47	373.52
6498	2004-07-08	11221	315.61	26.04	341.65
6499	2004-07-26	5883	60.87	5.02	65.89
6500	2004-07-01	1842	256.30	21.14	277.44
6501	2004-07-25	16249	331.76	27.37	359.13
6502	2004-07-05	8270	40.23	3.32	43.55
6503	2004-07-19	11224	122.79	10.13	132.92
6504	2004-07-13	3458	364.80	30.10	394.90
6505	2004-07-23	9054	206.25	17.02	223.27
6506	2004-07-11	17835	221.25	18.25	239.50
6507	2004-07-01	7515	388.83	32.08	420.91
6508	2004-07-04	10927	0.45	0.04	0.49
6509	2004-07-05	15428	397.80	32.82	430.62
6510	2004-07-19	18286	374.37	30.89	405.26
6511	2004-07-23	12563	158.97	13.12	172.09
6512	2004-07-05	13361	72.10	5.95	78.05
6513	2004-07-06	4338	264.62	21.83	286.45
6514	2004-07-03	72	148.97	12.29	161.26
6515	2004-07-16	5826	276.03	22.77	298.80
6516	2004-07-20	11250	155.58	12.84	168.42
6517	2004-07-31	6315	235.65	19.44	255.09
6518	2004-07-18	12758	39.52	3.26	42.78
6519	2004-07-03	1730	79.02	6.52	85.54
6520	2004-07-24	9251	82.75	6.83	89.58
6521	2004-07-27	4951	253.94	20.95	274.89
6522	2004-07-09	18087	394.60	32.55	427.15
6523	2004-07-05	19866	246.07	20.30	266.37
6524	2004-07-08	13084	168.49	13.90	182.39
6525	2004-07-04	16268	21.15	1.74	22.89
6526	2004-07-25	5489	121.91	10.06	131.97
6527	2004-07-23	9588	193.19	15.94	209.13
6528	2004-07-13	4897	280.71	23.16	303.87
6529	2004-07-05	4401	7.95	0.66	8.61
6530	2004-07-29	12107	48.25	3.98	52.23
6531	2004-07-31	1696	162.67	13.42	176.09
6532	2004-07-05	18689	166.25	13.72	179.97
6533	2004-07-24	16435	121.28	10.01	131.29
6534	2004-07-17	4445	350.02	28.88	378.90
6535	2004-07-01	2395	35.22	2.91	38.13
6536	2004-07-30	912	256.56	21.17	277.73
6537	2004-07-26	16266	39.97	3.30	43.27
6538	2004-07-01	17036	125.88	10.39	136.27
6539	2004-07-18	12385	12.15	1.00	13.15
6540	2004-07-24	8367	159.16	13.13	172.29
6541	2004-07-03	13618	214.23	17.67	231.90
6542	2004-07-29	11238	308.83	25.48	334.31
6543	2004-07-20	16691	75.66	6.24	81.90
6544	2004-07-10	15573	148.56	12.26	160.82
6545	2004-07-30	16499	25.32	2.09	27.41
6546	2004-07-10	19381	141.82	11.70	153.52
6547	2004-07-16	10324	231.45	19.09	250.54
6548	2004-07-19	8383	192.67	15.90	208.57
6549	2004-07-24	9515	106.89	8.82	115.71
6550	2004-07-28	510	353.29	29.15	382.44
6551	2004-07-19	9698	234.54	19.35	253.89
6552	2004-07-06	695	163.01	13.45	176.46
6553	2004-07-05	15336	343.44	28.33	371.77
6554	2004-07-03	12791	230.11	18.98	249.09
6555	2004-07-10	13865	366.52	30.24	396.76
6556	2004-07-21	16555	92.04	7.59	99.63
6557	2004-07-04	9870	130.54	10.77	141.31
6558	2004-07-15	1638	119.60	9.87	129.47
6559	2004-07-18	2410	28.70	2.37	31.07
6560	2004-07-02	14051	64.51	5.32	69.83
6561	2004-07-18	17786	323.25	26.67	349.92
6562	2004-07-28	699	2.14	0.18	2.32
6563	2004-07-04	4797	206.87	17.07	223.94
6564	2004-07-10	1389	10.94	0.90	11.84
6565	2004-07-29	14060	1.14	0.09	1.23
6566	2004-07-24	2356	260.99	21.53	282.52
6567	2004-07-30	8786	161.91	13.36	175.27
6568	2004-07-23	10487	353.98	29.20	383.18
6569	2004-07-17	10118	387.88	32.00	419.88
6570	2004-07-27	15173	40.29	3.32	43.61
6571	2004-07-24	19051	208.54	17.20	225.74
6572	2004-07-09	7233	137.47	11.34	148.81
6573	2004-07-12	7826	248.14	20.47	268.61
6574	2004-07-30	2409	200.18	16.51	216.69
6575	2004-07-06	7701	300.58	24.80	325.38
6576	2004-07-23	18408	348.12	28.72	376.84
6577	2004-07-30	6369	193.56	15.97	209.53
6578	2004-07-09	6065	193.06	15.93	208.99
6579	2004-07-08	7646	282.10	23.27	305.37
6580	2004-07-19	5618	219.47	18.11	237.58
6581	2004-07-31	19507	0.28	0.02	0.30
6582	2004-07-28	10830	339.34	28.00	367.34
6583	2004-07-10	2409	55.34	4.57	59.91
6584	2004-07-08	16069	70.35	5.80	76.15
6585	2004-07-11	7870	38.97	3.22	42.19
6586	2004-07-01	7439	354.85	29.28	384.13
6587	2004-07-01	9765	47.73	3.94	51.67
6588	2004-07-11	19000	84.56	6.98	91.54
6589	2004-07-18	3693	167.09	13.78	180.87
6590	2004-07-27	17251	80.78	6.66	87.44
6591	2004-07-16	5726	196.07	16.18	212.25
6592	2004-07-12	13096	139.01	11.47	150.48
6593	2004-07-09	10226	189.89	15.67	205.56
6594	2004-07-04	11786	278.12	22.94	301.06
6595	2004-07-29	5074	339.66	28.02	367.68
6596	2004-07-02	9117	30.17	2.49	32.66
6597	2004-07-27	92	289.53	23.89	313.42
6598	2004-07-23	984	238.07	19.64	257.71
6599	2004-07-31	8763	40.80	3.37	44.17
6600	2004-07-17	16774	363.37	29.98	393.35
6601	2004-07-17	9203	272.42	22.47	294.89
6602	2004-07-09	13163	70.05	5.78	75.83
6603	2004-07-03	6704	199.75	16.48	216.23
6604	2004-07-04	12371	246.91	20.37	267.28
6605	2004-07-12	17600	305.55	25.21	330.76
6606	2004-07-14	15845	306.55	25.29	331.84
6607	2004-07-21	1881	132.87	10.96	143.83
6608	2004-07-31	17197	324.80	26.80	351.60
6609	2004-07-20	15396	112.64	9.29	121.93
6610	2004-07-18	1909	44.18	3.64	47.82
6611	2004-07-07	4017	181.29	14.96	196.25
6612	2004-07-18	16312	166.73	13.76	180.49
6613	2004-07-08	1907	109.52	9.04	118.56
6614	2004-07-07	307	41.08	3.39	44.47
6615	2004-07-19	18863	34.38	2.84	37.22
6616	2004-07-30	8967	337.38	27.83	365.21
6617	2004-07-15	15051	227.33	18.75	246.08
6618	2004-07-02	9440	77.91	6.43	84.34
6619	2004-07-21	394	272.66	22.49	295.15
6620	2004-07-04	6304	399.98	33.00	432.98
6621	2004-07-14	14946	28.92	2.39	31.31
6622	2004-07-08	859	176.97	14.60	191.57
6623	2004-07-03	3175	129.99	10.72	140.71
6624	2004-07-03	6228	258.37	21.32	279.69
6625	2004-07-21	11385	101.89	8.41	110.30
6626	2004-07-14	12275	1.25	0.10	1.35
6627	2004-07-06	12891	19.57	1.61	21.18
6628	2004-07-28	18607	358.07	29.54	387.61
6629	2004-07-18	10643	68.64	5.66	74.30
6630	2004-07-20	4514	383.99	31.68	415.67
6631	2004-07-24	14885	300.92	24.83	325.75
6632	2004-07-21	15858	357.67	29.51	387.18
6633	2004-07-17	12282	295.68	24.39	320.07
6634	2004-07-29	2769	79.91	6.59	86.50
6635	2004-07-28	14022	188.30	15.53	203.83
6636	2004-07-17	12372	342.24	28.23	370.47
6637	2004-07-18	19865	378.13	31.20	409.33
6638	2004-07-27	3320	327.41	27.01	354.42
6639	2004-07-07	18781	380.06	31.35	411.41
6640	2004-07-31	7381	154.19	12.72	166.91
6641	2004-07-20	9197	287.75	23.74	311.49
6642	2004-07-15	18581	66.27	5.47	71.74
6643	2004-07-14	16763	147.77	12.19	159.96
6644	2004-07-03	10272	365.65	30.17	395.82
6645	2004-07-31	13629	206.62	17.05	223.67
6646	2004-07-06	13364	296.77	24.48	321.25
6647	2004-07-12	10817	72.14	5.95	78.09
6648	2004-07-11	6231	382.58	31.56	414.14
6649	2004-07-31	11536	35.55	2.93	38.48
6650	2004-07-25	18323	62.09	5.12	67.21
6651	2004-07-28	11973	158.21	13.05	171.26
6652	2004-07-26	9111	284.62	23.48	308.10
6653	2004-07-07	15696	236.37	19.50	255.87
6654	2004-07-26	3332	30.71	2.53	33.24
6655	2004-07-10	888	70.63	5.83	76.46
6656	2004-07-07	17735	255.80	21.10	276.90
6657	2004-07-08	1466	156.99	12.95	169.94
6658	2004-07-18	3127	162.06	13.37	175.43
6659	2004-07-16	16266	152.81	12.61	165.42
6660	2004-07-27	19768	391.49	32.30	423.79
6661	2004-07-01	13707	217.90	17.98	235.88
6662	2004-07-22	13420	308.00	25.41	333.41
6663	2004-07-22	5953	152.30	12.56	164.86
6664	2004-07-11	2785	260.64	21.50	282.14
6665	2004-07-23	8123	175.54	14.48	190.02
6666	2004-07-23	8915	31.55	2.60	34.15
6667	2004-07-21	951	20.43	1.69	22.12
6668	2004-07-04	1594	206.06	17.00	223.06
6669	2004-07-03	9318	240.91	19.88	260.79
6670	2004-07-14	8101	9.77	0.81	10.58
6671	2004-07-14	15943	111.94	9.24	121.18
6672	2004-07-13	17639	163.29	13.47	176.76
6673	2004-07-23	613	38.51	3.18	41.69
6674	2004-07-08	4499	22.37	1.85	24.22
6675	2004-07-14	6596	3.34	0.28	3.62
6676	2004-07-06	11556	222.51	18.36	240.87
6677	2004-07-22	18990	218.81	18.05	236.86
6678	2004-07-26	16338	133.39	11.00	144.39
6679	2004-07-12	11957	325.38	26.84	352.22
6680	2004-07-19	7592	27.50	2.27	29.77
6681	2004-07-28	10283	179.83	14.84	194.67
6682	2004-07-15	8620	150.94	12.45	163.39
6683	2004-07-30	10533	106.12	8.75	114.87
6684	2004-07-15	11738	12.14	1.00	13.14
6685	2004-07-09	6528	309.48	25.53	335.01
6686	2004-07-29	16775	221.24	18.25	239.49
6687	2004-07-10	2384	131.42	10.84	142.26
6688	2004-07-12	849	127.27	10.50	137.77
6689	2004-07-30	7687	352.13	29.05	381.18
6690	2004-07-15	5027	130.73	10.79	141.52
6691	2004-07-27	8557	9.88	0.82	10.70
6692	2004-07-31	4985	329.06	27.15	356.21
6693	2004-07-31	10138	256.09	21.13	277.22
6694	2004-07-02	1918	387.10	31.94	419.04
6695	2004-07-21	16109	223.63	18.45	242.08
6696	2004-07-19	8309	305.80	25.23	331.03
6697	2004-07-24	18176	163.12	13.46	176.58
6698	2004-07-05	2043	217.44	17.94	235.38
6699	2004-07-13	2759	8.29	0.68	8.97
6700	2004-07-21	7205	21.66	1.79	23.45
6701	2004-07-17	17530	273.32	22.55	295.87
6702	2004-07-04	13153	49.94	4.12	54.06
6703	2004-07-01	9839	153.28	12.65	165.93
6704	2004-07-22	2097	69.28	5.72	75.00
6705	2004-07-26	14690	364.46	30.07	394.53
6706	2004-07-15	15706	383.55	31.64	415.19
6707	2004-07-02	15847	154.10	12.71	166.81
6708	2004-07-03	5638	234.10	19.31	253.41
6709	2004-07-31	17990	126.87	10.47	137.34
6710	2004-07-06	7641	19.70	1.63	21.33
6711	2004-07-08	14688	86.55	7.14	93.69
6712	2004-07-06	5505	314.97	25.99	340.96
6713	2004-07-21	19568	38.45	3.17	41.62
6714	2004-07-28	15822	165.85	13.68	179.53
6715	2004-07-04	15894	264.04	21.78	285.82
6716	2004-07-21	9174	384.02	31.68	415.70
6717	2004-07-04	967	326.89	26.97	353.86
6718	2004-07-14	18513	201.01	16.58	217.59
6719	2004-07-31	4522	32.96	2.72	35.68
6720	2004-07-18	19167	206.39	17.03	223.42
6721	2004-07-30	18419	282.06	23.27	305.33
6722	2004-07-07	11621	343.94	28.38	372.32
6723	2004-07-21	12543	183.65	15.15	198.80
6724	2004-07-05	16126	128.15	10.57	138.72
6725	2004-07-06	8660	10.95	0.90	11.85
6726	2004-07-17	9272	399.36	32.95	432.31
6727	2004-07-29	3859	206.01	17.00	223.01
6728	2004-07-03	17400	140.55	11.60	152.15
6729	2004-07-12	1550	59.40	4.90	64.30
6730	2004-07-03	6679	312.35	25.77	338.12
6731	2004-07-19	14646	40.38	3.33	43.71
6732	2004-07-10	1411	50.47	4.16	54.63
6733	2004-07-02	8661	53.01	4.37	57.38
6734	2004-07-31	14887	62.79	5.18	67.97
6735	2004-07-20	16756	249.23	20.56	269.79
6736	2004-07-11	15857	361.98	29.86	391.84
6737	2004-07-12	13821	83.72	6.91	90.63
6738	2004-07-29	14675	18.05	1.49	19.54
6739	2004-07-26	4385	63.11	5.21	68.32
6740	2004-07-09	14413	138.54	11.43	149.97
6741	2004-07-26	12098	2.91	0.24	3.15
6742	2004-07-16	4094	128.42	10.59	139.01
6743	2004-07-23	15339	274.55	22.65	297.20
6744	2004-07-03	18200	16.38	1.35	17.73
6745	2004-07-20	18599	175.00	14.44	189.44
6746	2004-07-25	17458	300.53	24.79	325.32
6747	2004-07-22	15644	251.14	20.72	271.86
6748	2004-07-23	19248	123.56	10.19	133.75
6749	2004-07-27	209	104.05	8.58	112.63
6750	2004-07-30	19583	320.02	26.40	346.42
6751	2004-07-28	14277	267.72	22.09	289.81
6752	2004-07-13	14114	265.77	21.93	287.70
6753	2004-07-18	5609	392.28	32.36	424.64
6754	2004-07-05	19405	380.19	31.37	411.56
6755	2004-07-18	11688	371.65	30.66	402.31
6756	2004-07-29	12305	211.09	17.41	228.50
6757	2004-07-02	14626	84.99	7.01	92.00
6758	2004-07-16	1902	120.35	9.93	130.28
6759	2004-07-10	8455	63.31	5.22	68.53
6760	2004-07-26	9875	267.87	22.10	289.97
6761	2004-07-21	284	237.07	19.56	256.63
6762	2004-07-20	431	53.49	4.41	57.90
6763	2004-07-02	9798	252.61	20.84	273.45
6764	2004-07-28	878	332.20	27.41	359.61
6765	2004-07-11	18595	153.49	12.66	166.15
6766	2004-07-25	8662	307.19	25.34	332.53
6767	2004-07-09	14493	94.89	7.83	102.72
6768	2004-07-14	6529	189.89	15.67	205.56
6769	2004-07-15	10995	386.43	31.88	418.31
6770	2004-07-22	15491	389.49	32.13	421.62
6771	2004-07-23	8937	217.47	17.94	235.41
6772	2004-07-18	11020	105.06	8.67	113.73
6773	2004-07-11	252	251.45	20.74	272.19
6774	2004-07-18	10784	350.71	28.93	379.64
6775	2004-07-14	11133	245.98	20.29	266.27
6776	2004-07-07	7594	132.15	10.90	143.05
6777	2004-07-18	6057	44.46	3.67	48.13
6778	2004-07-14	18036	121.44	10.02	131.46
6779	2004-07-15	647	278.00	22.94	300.94
6780	2004-07-18	15723	54.83	4.52	59.35
6781	2004-07-06	19767	369.17	30.46	399.63
6782	2004-07-19	8615	397.28	32.78	430.06
6783	2004-07-26	6017	33.29	2.75	36.04
6784	2004-07-20	12888	341.74	28.19	369.93
6785	2004-07-03	4917	101.57	8.38	109.95
6786	2004-07-14	9153	6.08	0.50	6.58
6787	2004-07-08	4235	390.43	32.21	422.64
6788	2004-07-25	1378	13.00	1.07	14.07
6789	2004-07-22	16659	61.17	5.05	66.22
6790	2004-07-19	7911	161.21	13.30	174.51
6791	2004-07-23	3735	113.23	9.34	122.57
6792	2004-07-13	6798	154.77	12.77	167.54
6793	2004-07-16	61	358.73	29.60	388.33
6794	2004-07-30	16021	229.00	18.89	247.89
6795	2004-07-15	15531	388.73	32.07	420.80
6796	2004-07-23	3098	303.22	25.02	328.24
6797	2004-07-13	1419	344.52	28.42	372.94
6798	2004-07-29	17552	352.53	29.08	381.61
6799	2004-07-20	1253	392.11	32.35	424.46
6800	2004-07-18	19326	129.01	10.64	139.65
6801	2004-07-29	3690	87.00	7.18	94.18
6802	2004-07-14	529	260.16	21.46	281.62
6803	2004-07-03	5644	186.26	15.37	201.63
6804	2004-07-11	17414	216.66	17.87	234.53
6805	2004-07-21	15058	118.78	9.80	128.58
6806	2004-07-29	7695	285.94	23.59	309.53
6807	2004-07-22	17252	166.67	13.75	180.42
6808	2004-07-18	15887	341.28	28.16	369.44
6809	2004-07-23	8509	120.12	9.91	130.03
6810	2004-07-02	12216	194.05	16.01	210.06
6811	2004-07-15	1865	67.91	5.60	73.51
6812	2004-07-03	16354	92.06	7.59	99.65
6813	2004-07-06	11226	10.82	0.89	11.71
6814	2004-07-08	19894	21.00	1.73	22.73
6815	2004-07-26	9474	90.78	7.49	98.27
6816	2004-07-22	12668	139.19	11.48	150.67
6817	2004-07-01	2943	46.22	3.81	50.03
6818	2004-07-22	6535	347.46	28.67	376.13
6819	2004-07-17	18432	255.07	21.04	276.11
6820	2004-07-20	3377	153.62	12.67	166.29
6821	2004-07-16	4078	285.52	23.56	309.08
6822	2004-07-19	3884	41.86	3.45	45.31
6823	2004-07-12	2371	149.85	12.36	162.21
6824	2004-07-27	13218	219.29	18.09	237.38
6825	2004-07-08	15094	306.37	25.28	331.65
6826	2004-07-10	16087	373.66	30.83	404.49
6827	2004-07-04	17506	355.56	29.33	384.89
6828	2004-07-16	3863	380.53	31.39	411.92
6829	2004-07-23	12281	391.39	32.29	423.68
6830	2004-07-01	11038	149.66	12.35	162.01
6831	2004-07-12	7579	83.18	6.86	90.04
6832	2004-07-12	5434	152.25	12.56	164.81
6833	2004-07-09	9551	307.40	25.36	332.76
6834	2004-07-19	10670	222.11	18.32	240.43
6835	2004-07-11	3791	303.08	25.00	328.08
6836	2004-07-04	11635	153.75	12.68	166.43
6837	2004-07-30	12102	277.05	22.86	299.91
6838	2004-07-15	10598	185.09	15.27	200.36
6839	2004-07-27	7132	13.34	1.10	14.44
6840	2004-07-14	14798	305.17	25.18	330.35
6841	2004-07-31	12979	226.12	18.65	244.77
6842	2004-07-28	13553	19.93	1.64	21.57
6843	2004-07-24	6357	317.51	26.19	343.70
6844	2004-07-17	17374	155.85	12.86	168.71
6845	2004-07-17	18211	232.12	19.15	251.27
6846	2004-07-24	14674	131.78	10.87	142.65
6847	2004-07-10	2413	104.94	8.66	113.60
6848	2004-07-31	13603	179.74	14.83	194.57
6849	2004-07-06	12689	196.32	16.20	212.52
6850	2004-07-28	17492	311.98	25.74	337.72
6851	2004-07-09	4423	341.04	28.14	369.18
6852	2004-07-30	691	14.54	1.20	15.74
6853	2004-07-16	2364	111.15	9.17	120.32
6854	2004-07-27	16270	18.26	1.51	19.77
6855	2004-07-05	5550	29.41	2.43	31.84
6856	2004-07-09	16600	272.10	22.45	294.55
6857	2004-07-06	7395	198.40	16.37	214.77
6858	2004-07-17	14328	282.78	23.33	306.11
6859	2004-07-10	9448	239.69	19.77	259.46
6860	2004-07-03	8990	19.06	1.57	20.63
6861	2004-07-07	19046	367.38	30.31	397.69
6862	2004-07-28	10955	281.32	23.21	304.53
6863	2004-07-06	10747	49.91	4.12	54.03
6864	2004-07-23	4168	133.75	11.03	144.78
6865	2004-07-26	12551	63.26	5.22	68.48
6866	2004-07-31	8880	305.92	25.24	331.16
6867	2004-07-23	9248	183.42	15.13	198.55
6868	2004-07-14	6042	272.81	22.51	295.32
6869	2004-07-20	6869	253.83	20.94	274.77
6870	2004-07-01	4768	93.80	7.74	101.54
6871	2004-07-23	1724	149.87	12.36	162.23
6872	2004-07-03	2622	69.28	5.72	75.00
6873	2004-07-29	19822	105.21	8.68	113.89
6874	2004-07-20	9230	198.45	16.37	214.82
6875	2004-07-14	14783	340.58	28.10	368.68
6876	2004-07-12	13320	72.00	5.94	77.94
6877	2004-07-31	3585	191.22	15.78	207.00
6878	2004-07-03	13477	84.76	6.99	91.75
6879	2004-07-11	8086	158.43	13.07	171.50
6880	2004-07-10	15307	296.95	24.50	321.45
6881	2004-07-29	5351	2.04	0.17	2.21
6882	2004-07-14	2352	205.55	16.96	222.51
6883	2004-07-26	1651	160.45	13.24	173.69
6884	2004-07-27	9889	151.50	12.50	164.00
6885	2004-07-14	9634	105.20	8.68	113.88
6886	2004-07-22	4856	218.66	18.04	236.70
6887	2004-07-05	154	102.75	8.48	111.23
6888	2004-07-01	5594	276.19	22.79	298.98
6889	2004-07-18	17938	258.25	21.31	279.56
6890	2004-07-17	1629	76.08	6.28	82.36
6891	2004-07-01	1151	270.45	22.31	292.76
6892	2004-07-26	7947	3.71	0.31	4.02
6893	2004-07-02	12126	371.28	30.63	401.91
6894	2004-07-02	17915	231.51	19.10	250.61
6895	2004-07-02	19379	136.24	11.24	147.48
6896	2004-07-01	10877	72.85	6.01	78.86
6897	2004-07-12	15233	272.06	22.44	294.50
6898	2004-07-02	8125	344.63	28.43	373.06
6899	2004-07-30	8416	6.42	0.53	6.95
6900	2004-07-20	1897	33.73	2.78	36.51
6901	2004-07-19	10266	143.99	11.88	155.87
6902	2004-07-07	19231	268.62	22.16	290.78
6903	2004-07-19	10316	233.37	19.25	252.62
6904	2004-07-26	7833	251.75	20.77	272.52
6905	2004-07-07	2646	278.46	22.97	301.43
6906	2004-07-10	9485	80.15	6.61	86.76
6907	2004-07-04	15270	152.93	12.62	165.55
6908	2004-07-09	6290	318.69	26.29	344.98
6909	2004-07-27	14250	103.14	8.51	111.65
6910	2004-07-30	1407	145.64	12.02	157.66
6911	2004-07-04	1988	218.07	17.99	236.06
6912	2004-07-17	15772	396.53	32.71	429.24
6913	2004-07-07	14658	40.99	3.38	44.37
6914	2004-07-29	1159	76.62	6.32	82.94
6915	2004-07-17	16958	4.46	0.37	4.83
6916	2004-07-07	14360	396.53	32.71	429.24
6917	2004-07-24	1166	378.70	31.24	409.94
6918	2004-07-21	18439	334.15	27.57	361.72
6919	2004-07-25	15443	225.89	18.64	244.53
6920	2004-07-09	17061	305.81	25.23	331.04
6921	2004-07-05	12020	209.35	17.27	226.62
6922	2004-07-03	19475	205.04	16.92	221.96
6923	2004-07-28	14581	363.19	29.96	393.15
6924	2004-07-02	13539	114.76	9.47	124.23
6925	2004-07-01	12260	351.79	29.02	380.81
6926	2004-07-04	15253	45.59	3.76	49.35
6927	2004-07-16	11103	124.56	10.28	134.84
6928	2004-07-21	7014	219.99	18.15	238.14
6929	2004-07-13	12518	209.11	17.25	226.36
6930	2004-07-19	6767	277.43	22.89	300.32
6931	2004-07-29	16523	393.98	32.50	426.48
6932	2004-07-01	1335	310.52	25.62	336.14
6933	2004-07-01	18010	51.95	4.29	56.24
6934	2004-07-12	10784	78.65	6.49	85.14
6935	2004-07-09	4323	335.11	27.65	362.76
6936	2004-07-09	12342	243.85	20.12	263.97
6937	2004-07-18	729	37.94	3.13	41.07
6938	2004-07-03	13097	2.24	0.18	2.42
6939	2004-07-13	3039	368.57	30.41	398.98
6940	2004-07-15	7345	370.76	30.59	401.35
6941	2004-07-21	4812	15.64	1.29	16.93
6942	2004-07-19	17880	161.56	13.33	174.89
6943	2004-07-08	7844	270.94	22.35	293.29
6944	2004-07-29	2065	329.00	27.14	356.14
6945	2004-07-19	2828	2.74	0.23	2.97
6946	2004-07-18	12531	218.10	17.99	236.09
6947	2004-07-26	3287	22.89	1.89	24.78
6948	2004-07-26	2326	194.66	16.06	210.72
6949	2004-07-05	12013	313.49	25.86	339.35
6950	2004-07-23	14763	113.51	9.36	122.87
6951	2004-07-06	9592	239.92	19.79	259.71
6952	2004-07-07	7505	9.63	0.79	10.42
6953	2004-07-30	12749	331.48	27.35	358.83
6954	2004-07-22	12664	397.41	32.79	430.20
6955	2004-07-07	5074	352.57	29.09	381.66
6956	2004-07-30	7556	229.24	18.91	248.15
6957	2004-07-23	16339	322.87	26.64	349.51
6958	2004-07-07	18487	14.83	1.22	16.05
6959	2004-07-21	11568	228.30	18.83	247.13
6960	2004-07-10	13452	189.02	15.59	204.61
6961	2004-07-08	9453	141.23	11.65	152.88
6962	2004-07-05	10066	221.71	18.29	240.00
6963	2004-07-25	11509	257.08	21.21	278.29
6964	2004-07-07	12306	83.67	6.90	90.57
6965	2004-07-04	4762	156.65	12.92	169.57
6966	2004-07-15	5763	231.88	19.13	251.01
6967	2004-07-17	10024	121.94	10.06	132.00
6968	2004-07-15	4381	62.01	5.12	67.13
6969	2004-07-27	3333	4.94	0.41	5.35
6970	2004-07-06	10464	321.45	26.52	347.97
6971	2004-07-01	13113	348.82	28.78	377.60
6972	2004-07-06	15147	73.86	6.09	79.95
6973	2004-07-11	496	60.94	5.03	65.97
6974	2004-07-13	4079	73.95	6.10	80.05
6975	2004-07-28	14686	162.49	13.41	175.90
6976	2004-07-14	5389	191.40	15.79	207.19
6977	2004-07-21	18361	134.43	11.09	145.52
6978	2004-07-11	15780	14.54	1.20	15.74
6979	2004-07-18	452	342.07	28.22	370.29
6980	2004-07-29	12507	276.52	22.81	299.33
6981	2004-07-23	6895	155.58	12.84	168.42
6982	2004-07-28	7377	343.42	28.33	371.75
6983	2004-07-24	13208	303.94	25.08	329.02
6984	2004-07-29	15739	248.28	20.48	268.76
6985	2004-07-26	18805	77.50	6.39	83.89
6986	2004-07-19	15463	354.32	29.23	383.55
6987	2004-07-20	10685	2.82	0.23	3.05
6988	2004-07-28	4300	90.46	7.46	97.92
6989	2004-07-03	19631	347.53	28.67	376.20
6990	2004-07-29	15896	336.59	27.77	364.36
6991	2004-07-09	18742	362.28	29.89	392.17
6992	2004-07-22	785	102.09	8.42	110.51
6993	2004-07-12	15438	189.13	15.60	204.73
6994	2004-07-05	14343	198.72	16.39	215.11
6995	2004-07-10	8518	202.53	16.71	219.24
6996	2004-07-04	14577	125.34	10.34	135.68
6997	2004-07-30	1882	116.01	9.57	125.58
6998	2004-07-21	7837	333.31	27.50	360.81
6999	2004-07-06	11408	274.22	22.62	296.84
7000	2004-07-01	8958	109.08	9.00	118.08
7001	2004-08-16	8391	123.98	10.23	134.21
7002	2004-08-15	18655	96.03	7.92	103.95
7003	2004-08-01	15040	43.70	3.61	47.31
7004	2004-08-18	9001	178.95	14.76	193.71
7005	2004-08-10	2795	264.47	21.82	286.29
7006	2004-08-02	4050	152.56	12.59	165.15
7007	2004-08-21	10562	308.21	25.43	333.64
7008	2004-08-30	18799	107.27	8.85	116.12
7009	2004-08-11	5598	395.27	32.61	427.88
7010	2004-08-06	19628	63.21	5.21	68.42
7011	2004-08-24	13717	78.93	6.51	85.44
7012	2004-08-31	17088	385.57	31.81	417.38
7013	2004-08-21	7439	248.31	20.49	268.80
7014	2004-08-08	18515	14.47	1.19	15.66
7015	2004-08-26	15787	146.90	12.12	159.02
7016	2004-08-27	8503	396.15	32.68	428.83
7017	2004-08-23	17336	389.92	32.17	422.09
7018	2004-08-23	14472	285.88	23.59	309.47
7019	2004-08-21	3485	363.79	30.01	393.80
7020	2004-08-21	11611	246.28	20.32	266.60
7021	2004-08-23	4688	368.27	30.38	398.65
7022	2004-08-18	13701	120.21	9.92	130.13
7023	2004-08-26	18933	215.53	17.78	233.31
7024	2004-08-05	772	80.61	6.65	87.26
7025	2004-08-29	4779	50.23	4.14	54.37
7026	2004-08-09	17876	165.49	13.65	179.14
7027	2004-08-21	9100	31.82	2.63	34.45
7028	2004-08-14	1823	42.66	3.52	46.18
7029	2004-08-01	12877	154.90	12.78	167.68
7030	2004-08-29	8062	106.96	8.82	115.78
7031	2004-08-03	366	21.37	1.76	23.13
7032	2004-08-11	8753	186.65	15.40	202.05
7033	2004-08-27	12292	191.15	15.77	206.92
7034	2004-08-24	16335	347.92	28.70	376.62
7035	2004-08-18	4270	248.83	20.53	269.36
7036	2004-08-10	17045	68.02	5.61	73.63
7037	2004-08-10	15012	140.75	11.61	152.36
7038	2004-08-03	13942	167.17	13.79	180.96
7039	2004-08-17	18208	135.70	11.20	146.90
7040	2004-08-26	7004	225.71	18.62	244.33
7041	2004-08-10	2570	281.32	23.21	304.53
7042	2004-08-10	12665	14.77	1.22	15.99
7043	2004-08-09	12108	370.68	30.58	401.26
7044	2004-08-30	6116	119.75	9.88	129.63
7045	2004-08-20	2258	22.91	1.89	24.80
7046	2004-08-15	16943	73.76	6.09	79.85
7047	2004-08-31	3071	340.18	28.06	368.24
7048	2004-08-12	11930	232.98	19.22	252.20
7049	2004-08-01	2472	91.28	7.53	98.81
7050	2004-08-30	6124	86.20	7.11	93.31
7051	2004-08-04	12323	372.12	30.70	402.82
7052	2004-08-18	9561	278.71	22.99	301.70
7053	2004-08-28	8786	291.41	24.04	315.45
7054	2004-08-30	13526	83.88	6.92	90.80
7055	2004-08-06	17928	75.87	6.26	82.13
7056	2004-08-22	4758	72.79	6.01	78.80
7057	2004-08-05	5515	269.22	22.21	291.43
7058	2004-08-11	18375	282.61	23.32	305.93
7059	2004-08-18	2766	100.34	8.28	108.62
7060	2004-08-28	19001	293.26	24.19	317.45
7061	2004-08-28	15104	297.04	24.51	321.55
7062	2004-08-27	13000	244.55	20.18	264.73
7063	2004-08-09	10224	316.40	26.10	342.50
7064	2004-08-08	18479	21.85	1.80	23.65
7065	2004-08-27	7863	358.77	29.60	388.37
7066	2004-08-31	16551	75.30	6.21	81.51
7067	2004-08-21	19426	141.88	11.71	153.59
7068	2004-08-26	10891	36.51	3.01	39.52
7069	2004-08-13	148	211.52	17.45	228.97
7070	2004-08-11	13678	121.36	10.01	131.37
7071	2004-08-19	9466	339.14	27.98	367.12
7072	2004-08-28	17842	291.53	24.05	315.58
7073	2004-08-31	11781	367.35	30.31	397.66
7074	2004-08-08	3555	374.60	30.90	405.50
7075	2004-08-02	22	33.86	2.79	36.65
7076	2004-08-12	7385	28.98	2.39	31.37
7077	2004-08-31	14553	297.23	24.52	321.75
7078	2004-08-29	7759	221.73	18.29	240.02
7079	2004-08-04	5278	43.34	3.58	46.92
7080	2004-08-26	17945	25.82	2.13	27.95
7081	2004-08-27	3123	81.90	6.76	88.66
7082	2004-08-31	13755	137.36	11.33	148.69
7083	2004-08-02	6544	76.63	6.32	82.95
7084	2004-08-04	16697	210.13	17.34	227.47
7085	2004-08-03	14988	286.32	23.62	309.94
7086	2004-08-06	17838	268.05	22.11	290.16
7087	2004-08-11	13539	121.56	10.03	131.59
7088	2004-08-13	15201	103.96	8.58	112.54
7089	2004-08-25	1042	66.04	5.45	71.49
7090	2004-08-28	1342	62.02	5.12	67.14
7091	2004-08-24	3772	96.39	7.95	104.34
7092	2004-08-14	14425	42.09	3.47	45.56
7093	2004-08-03	2678	37.32	3.08	40.40
7094	2004-08-09	10454	121.75	10.04	131.79
7095	2004-08-01	7971	262.38	21.65	284.03
7096	2004-08-14	15183	255.36	21.07	276.43
7097	2004-08-15	14010	363.94	30.03	393.97
7098	2004-08-31	7954	288.94	23.84	312.78
7099	2004-08-25	7781	122.71	10.12	132.83
7100	2004-08-05	1820	282.40	23.30	305.70
7101	2004-08-31	16949	108.78	8.97	117.75
7102	2004-08-23	932	179.62	14.82	194.44
7103	2004-08-17	15256	302.42	24.95	327.37
7104	2004-08-27	7740	30.07	2.48	32.55
7105	2004-08-21	17668	158.97	13.12	172.09
7106	2004-08-02	3823	17.71	1.46	19.17
7107	2004-08-25	16682	336.00	27.72	363.72
7108	2004-08-07	15916	251.84	20.78	272.62
7109	2004-08-20	7771	329.83	27.21	357.04
7110	2004-08-10	11691	45.46	3.75	49.21
7111	2004-08-14	13036	215.06	17.74	232.80
7112	2004-08-30	6881	352.41	29.07	381.48
7113	2004-08-01	7023	27.31	2.25	29.56
7114	2004-08-12	3980	120.74	9.96	130.70
7115	2004-08-16	230	68.10	5.62	73.72
7116	2004-08-19	13944	135.22	11.16	146.38
7117	2004-08-09	7291	80.14	6.61	86.75
7118	2004-08-26	7539	328.55	27.11	355.66
7119	2004-08-25	16794	27.18	2.24	29.42
7120	2004-08-13	1526	300.98	24.83	325.81
7121	2004-08-20	14992	113.30	9.35	122.65
7122	2004-08-26	10351	7.49	0.62	8.11
7123	2004-08-05	5820	200.44	16.54	216.98
7124	2004-08-28	19887	7.36	0.61	7.97
7125	2004-08-19	420	54.42	4.49	58.91
7126	2004-08-08	2917	121.84	10.05	131.89
7127	2004-08-19	5273	373.22	30.79	404.01
7128	2004-08-12	18879	295.48	24.38	319.86
7129	2004-08-29	1922	152.95	12.62	165.57
7130	2004-08-04	12612	181.09	14.94	196.03
7131	2004-08-11	14666	153.34	12.65	165.99
7132	2004-08-07	10277	240.32	19.83	260.15
7133	2004-08-16	4849	321.26	26.50	347.76
7134	2004-08-29	1846	117.35	9.68	127.03
7135	2004-08-15	12146	146.45	12.08	158.53
7136	2004-08-08	19483	20.82	1.72	22.54
7137	2004-08-26	14404	163.87	13.52	177.39
7138	2004-08-04	3218	61.03	5.03	66.06
7139	2004-08-17	7916	301.90	24.91	326.81
7140	2004-08-08	7503	222.91	18.39	241.30
7141	2004-08-08	12532	183.89	15.17	199.06
7142	2004-08-13	5076	256.25	21.14	277.39
7143	2004-08-04	19359	77.80	6.42	84.22
7144	2004-08-23	6204	155.08	12.79	167.87
7145	2004-08-09	15588	188.90	15.58	204.48
7146	2004-08-25	10750	238.51	19.68	258.19
7147	2004-08-27	8905	331.18	27.32	358.50
7148	2004-08-13	18572	120.51	9.94	130.45
7149	2004-08-28	5083	120.03	9.90	129.93
7150	2004-08-16	5243	66.11	5.45	71.56
7151	2004-08-17	13432	114.08	9.41	123.49
7152	2004-08-02	815	200.70	16.56	217.26
7153	2004-08-31	4987	318.20	26.25	344.45
7154	2004-08-29	17890	28.22	2.33	30.55
7155	2004-08-10	5488	1.07	0.09	1.16
7156	2004-08-21	19033	140.48	11.59	152.07
7157	2004-08-14	8300	158.88	13.11	171.99
7158	2004-08-17	16890	342.07	28.22	370.29
7159	2004-08-17	15716	69.96	5.77	75.73
7160	2004-08-23	4967	181.93	15.01	196.94
7161	2004-08-04	670	390.03	32.18	422.21
7162	2004-08-12	4067	105.60	8.71	114.31
7163	2004-08-04	19330	77.19	6.37	83.56
7164	2004-08-06	2290	205.35	16.94	222.29
7165	2004-08-10	17050	44.29	3.65	47.94
7166	2004-08-03	6407	217.24	17.92	235.16
7167	2004-08-25	6981	34.35	2.83	37.18
7168	2004-08-15	1394	116.25	9.59	125.84
7169	2004-08-02	4288	76.42	6.30	82.72
7170	2004-08-20	12321	187.93	15.50	203.43
7171	2004-08-24	8263	264.60	21.83	286.43
7172	2004-08-14	17380	139.67	11.52	151.19
7173	2004-08-30	1095	116.24	9.59	125.83
7174	2004-08-11	663	366.02	30.20	396.22
7175	2004-08-31	17483	363.99	30.03	394.02
7176	2004-08-01	17608	392.16	32.35	424.51
7177	2004-08-07	12297	295.48	24.38	319.86
7178	2004-08-02	10118	311.43	25.69	337.12
7179	2004-08-27	10452	292.18	24.10	316.28
7180	2004-08-13	15212	284.79	23.50	308.29
7181	2004-08-03	7735	397.13	32.76	429.89
7182	2004-08-31	4187	244.76	20.19	264.95
7183	2004-08-24	1848	326.46	26.93	353.39
7184	2004-08-05	8604	85.91	7.09	93.00
7185	2004-08-16	13402	24.53	2.02	26.55
7186	2004-08-06	9002	68.37	5.64	74.01
7187	2004-08-19	7524	357.84	29.52	387.36
7188	2004-08-14	16151	185.67	15.32	200.99
7189	2004-08-03	9531	387.53	31.97	419.50
7190	2004-08-01	16679	306.83	25.31	332.14
7191	2004-08-13	12745	23.45	1.93	25.38
7192	2004-08-07	19654	235.23	19.41	254.64
7193	2004-08-26	13270	80.51	6.64	87.15
7194	2004-08-25	3395	379.78	31.33	411.11
7195	2004-08-08	1713	181.65	14.99	196.64
7196	2004-08-17	5155	105.76	8.73	114.49
7197	2004-08-03	19821	380.55	31.40	411.95
7198	2004-08-09	4279	133.96	11.05	145.01
7199	2004-08-15	3731	200.63	16.55	217.18
7200	2004-08-21	12459	300.43	24.79	325.22
7201	2004-08-10	11873	331.41	27.34	358.75
7202	2004-08-07	4533	189.99	15.67	205.66
7203	2004-08-08	7771	279.87	23.09	302.96
7204	2004-08-07	1053	55.05	4.54	59.59
7205	2004-08-22	2275	183.32	15.12	198.44
7206	2004-08-28	6081	5.00	0.41	5.41
7207	2004-08-07	5662	115.80	9.55	125.35
7208	2004-08-17	5469	223.99	18.48	242.47
7209	2004-08-15	11965	54.29	4.48	58.77
7210	2004-08-15	13402	53.92	4.45	58.37
7211	2004-08-09	19959	121.31	10.01	131.32
7212	2004-08-18	6270	350.16	28.89	379.05
7213	2004-08-20	15593	391.06	32.26	423.32
7214	2004-08-07	11839	112.01	9.24	121.25
7215	2004-08-10	4263	124.44	10.27	134.71
7216	2004-08-07	13479	144.74	11.94	156.68
7217	2004-08-20	3352	24.60	2.03	26.63
7218	2004-08-02	15176	223.90	18.47	242.37
7219	2004-08-04	10831	398.25	32.86	431.11
7220	2004-08-24	19704	72.38	5.97	78.35
7221	2004-08-30	17181	195.77	16.15	211.92
7222	2004-08-17	4058	289.86	23.91	313.77
7223	2004-08-29	10958	201.30	16.61	217.91
7224	2004-08-09	938	389.63	32.14	421.77
7225	2004-08-20	11536	98.18	8.10	106.28
7226	2004-08-01	2365	78.14	6.45	84.59
7227	2004-08-12	18712	265.25	21.88	287.13
7228	2004-08-27	14653	292.81	24.16	316.97
7229	2004-08-01	17746	92.75	7.65	100.40
7230	2004-08-15	14021	126.10	10.40	136.50
7231	2004-08-29	16053	249.41	20.58	269.99
7232	2004-08-28	15972	382.28	31.54	413.82
7233	2004-08-20	3350	209.06	17.25	226.31
7234	2004-08-01	13031	385.06	31.77	416.83
7235	2004-08-24	15742	37.91	3.13	41.04
7236	2004-08-13	18437	157.03	12.95	169.98
7237	2004-08-29	2482	30.58	2.52	33.10
7238	2004-08-22	9990	386.40	31.88	418.28
7239	2004-08-23	419	89.70	7.40	97.10
7240	2004-08-06	19484	14.78	1.22	16.00
7241	2004-08-27	19380	63.20	5.21	68.41
7242	2004-08-02	8061	107.51	8.87	116.38
7243	2004-08-19	16462	203.50	16.79	220.29
7244	2004-08-05	934	345.16	28.48	373.64
7245	2004-08-30	12094	23.39	1.93	25.32
7246	2004-08-12	1461	176.38	14.55	190.93
7247	2004-08-06	5335	200.48	16.54	217.02
7248	2004-08-17	19970	388.18	32.02	420.20
7249	2004-08-27	9827	281.44	23.22	304.66
7250	2004-08-02	13091	235.65	19.44	255.09
7251	2004-08-04	12892	31.04	2.56	33.60
7252	2004-08-22	12304	355.52	29.33	384.85
7253	2004-08-24	12654	385.54	31.81	417.35
7254	2004-08-10	13238	332.28	27.41	359.69
7255	2004-08-10	12335	56.63	4.67	61.30
7256	2004-08-19	13720	182.62	15.07	197.69
7257	2004-08-28	16025	106.48	8.78	115.26
7258	2004-08-01	13538	345.37	28.49	373.86
7259	2004-08-11	11169	112.08	9.25	121.33
7260	2004-08-12	6954	373.88	30.85	404.73
7261	2004-08-14	18040	119.80	9.88	129.68
7262	2004-08-21	7026	216.93	17.90	234.83
7263	2004-08-14	16670	61.67	5.09	66.76
7264	2004-08-11	502	2.89	0.24	3.13
7265	2004-08-30	7519	65.56	5.41	70.97
7266	2004-08-08	6496	23.99	1.98	25.97
7267	2004-08-01	12658	163.85	13.52	177.37
7268	2004-08-08	17138	367.63	30.33	397.96
7269	2004-08-12	5908	82.43	6.80	89.23
7270	2004-08-24	4850	162.58	13.41	175.99
7271	2004-08-27	4198	75.17	6.20	81.37
7272	2004-08-31	18670	242.26	19.99	262.25
7273	2004-08-21	3958	95.92	7.91	103.83
7274	2004-08-12	10812	357.79	29.52	387.31
7275	2004-08-21	4158	374.54	30.90	405.44
7276	2004-08-18	9700	13.24	1.09	14.33
7277	2004-08-07	19935	110.42	9.11	119.53
7278	2004-08-02	19163	256.83	21.19	278.02
7279	2004-08-05	12841	158.88	13.11	171.99
7280	2004-08-06	15192	274.78	22.67	297.45
7281	2004-08-05	10728	45.80	3.78	49.58
7282	2004-08-11	2072	132.95	10.97	143.92
7283	2004-08-05	8413	278.29	22.96	301.25
7284	2004-08-16	19487	2.50	0.21	2.71
7285	2004-08-01	2868	65.30	5.39	70.69
7286	2004-08-22	9028	56.71	4.68	61.39
7287	2004-08-14	5724	30.59	2.52	33.11
7288	2004-08-10	8334	386.82	31.91	418.73
7289	2004-08-30	7158	75.08	6.19	81.27
7290	2004-08-15	16300	63.38	5.23	68.61
7291	2004-08-25	16251	269.26	22.21	291.47
7292	2004-08-11	1769	377.39	31.13	408.52
7293	2004-08-24	11975	155.41	12.82	168.23
7294	2004-08-29	10425	124.98	10.31	135.29
7295	2004-08-18	16802	250.85	20.70	271.55
7296	2004-08-14	9749	288.45	23.80	312.25
7297	2004-08-17	176	7.67	0.63	8.30
7298	2004-08-28	11338	374.58	30.90	405.48
7299	2004-08-24	9260	190.16	15.69	205.85
7300	2004-08-18	19006	223.37	18.43	241.80
7301	2004-08-13	4985	4.52	0.37	4.89
7302	2004-08-08	12028	293.65	24.23	317.88
7303	2004-08-14	2235	290.99	24.01	315.00
7304	2004-08-27	19091	221.27	18.25	239.52
7305	2004-08-04	18907	213.49	17.61	231.10
7306	2004-08-02	6835	179.44	14.80	194.24
7307	2004-08-09	4238	158.61	13.09	171.70
7308	2004-08-07	19300	386.68	31.90	418.58
7309	2004-08-19	2846	267.91	22.10	290.01
7310	2004-08-20	14765	40.34	3.33	43.67
7311	2004-08-26	6472	311.55	25.70	337.25
7312	2004-08-18	2691	277.68	22.91	300.59
7313	2004-08-21	6109	287.94	23.76	311.70
7314	2004-08-06	13523	352.59	29.09	381.68
7315	2004-08-11	12371	362.56	29.91	392.47
7316	2004-08-18	7118	245.81	20.28	266.09
7317	2004-08-07	4436	319.55	26.36	345.91
7318	2004-08-20	18839	7.35	0.61	7.96
7319	2004-08-19	10533	52.40	4.32	56.72
7320	2004-08-28	14152	163.17	13.46	176.63
7321	2004-08-09	15403	163.56	13.49	177.05
7322	2004-08-16	18928	313.16	25.84	339.00
7323	2004-08-06	19317	162.16	13.38	175.54
7324	2004-08-02	8558	311.11	25.67	336.78
7325	2004-08-27	6249	318.15	26.25	344.40
7326	2004-08-08	1019	72.04	5.94	77.98
7327	2004-08-03	18676	363.79	30.01	393.80
7328	2004-08-21	15853	378.56	31.23	409.79
7329	2004-08-01	11559	91.62	7.56	99.18
7330	2004-08-17	2907	55.64	4.59	60.23
7331	2004-08-10	4658	43.36	3.58	46.94
7332	2004-08-05	4862	76.29	6.29	82.58
7333	2004-08-26	11082	317.95	26.23	344.18
7334	2004-08-01	2000	48.41	3.99	52.40
7335	2004-08-01	18308	195.85	16.16	212.01
7336	2004-08-10	17572	291.24	24.03	315.27
7337	2004-08-15	2058	69.50	5.73	75.23
7338	2004-08-17	16076	213.13	17.58	230.71
7339	2004-08-04	2856	196.38	16.20	212.58
7340	2004-08-24	8108	136.85	11.29	148.14
7341	2004-08-18	5180	379.00	31.27	410.27
7342	2004-08-21	7432	52.54	4.33	56.87
7343	2004-08-23	4822	100.40	8.28	108.68
7344	2004-08-07	15305	220.68	18.21	238.89
7345	2004-08-28	4398	308.09	25.42	333.51
7346	2004-08-26	6286	282.18	23.28	305.46
7347	2004-08-07	1840	227.87	18.80	246.67
7348	2004-08-27	6426	136.04	11.22	147.26
7349	2004-08-20	8620	164.37	13.56	177.93
7350	2004-08-16	2725	331.31	27.33	358.64
7351	2004-08-18	5212	78.18	6.45	84.63
7352	2004-08-23	4020	26.79	2.21	29.00
7353	2004-08-03	19686	29.13	2.40	31.53
7354	2004-08-08	11445	374.46	30.89	405.35
7355	2004-08-27	10878	290.58	23.97	314.55
7356	2004-08-11	7665	351.52	29.00	380.52
7357	2004-08-27	9508	271.36	22.39	293.75
7358	2004-08-28	3300	258.16	21.30	279.46
7359	2004-08-15	12462	162.06	13.37	175.43
7360	2004-08-16	18903	52.11	4.30	56.41
7361	2004-08-22	8020	269.23	22.21	291.44
7362	2004-08-05	15999	383.11	31.61	414.72
7363	2004-08-05	12070	179.44	14.80	194.24
7364	2004-08-03	16601	261.77	21.60	283.37
7365	2004-08-17	431	214.42	17.69	232.11
7366	2004-08-17	6916	212.27	17.51	229.78
7367	2004-08-27	15463	395.06	32.59	427.65
7368	2004-08-30	2393	352.85	29.11	381.96
7369	2004-08-25	9526	262.42	21.65	284.07
7370	2004-08-14	8686	84.85	7.00	91.85
7371	2004-08-11	8569	193.65	15.98	209.63
7372	2004-08-04	14048	56.24	4.64	60.88
7373	2004-08-26	1725	217.48	17.94	235.42
7374	2004-08-26	13583	350.96	28.95	379.91
7375	2004-08-09	969	27.98	2.31	30.29
7376	2004-08-02	14601	368.33	30.39	398.72
7377	2004-08-18	7072	85.44	7.05	92.49
7378	2004-08-05	2846	107.76	8.89	116.65
7379	2004-08-21	14196	82.85	6.84	89.69
7380	2004-08-24	14919	357.62	29.50	387.12
7381	2004-08-10	4199	368.47	30.40	398.87
7382	2004-08-13	814	208.11	17.17	225.28
7383	2004-08-04	2368	289.30	23.87	313.17
7384	2004-08-20	19573	192.10	15.85	207.95
7385	2004-08-03	15395	291.16	24.02	315.18
7386	2004-08-03	708	164.31	13.56	177.87
7387	2004-08-23	19705	69.56	5.74	75.30
7388	2004-08-20	12820	333.47	27.51	360.98
7389	2004-08-31	19379	236.47	19.51	255.98
7390	2004-08-17	9150	39.90	3.29	43.19
7391	2004-08-18	3758	51.77	4.27	56.04
7392	2004-08-27	8580	133.25	10.99	144.24
7393	2004-08-22	17609	181.08	14.94	196.02
7394	2004-08-01	18777	185.96	15.34	201.30
7395	2004-08-31	14900	97.36	8.03	105.39
7396	2004-08-11	3786	149.22	12.31	161.53
7397	2004-08-15	1844	232.12	19.15	251.27
7398	2004-08-28	8165	275.92	22.76	298.68
7399	2004-08-24	17987	263.71	21.76	285.47
7400	2004-08-09	18148	129.87	10.71	140.58
7401	2004-08-06	3010	81.06	6.69	87.75
7402	2004-08-26	14666	46.29	3.82	50.11
7403	2004-08-25	14356	58.08	4.79	62.87
7404	2004-08-30	9429	344.41	28.41	372.82
7405	2004-08-11	2490	105.21	8.68	113.89
7406	2004-08-26	8930	222.73	18.38	241.11
7407	2004-08-06	2805	30.04	2.48	32.52
7408	2004-08-20	14792	217.78	17.97	235.75
7409	2004-08-23	8370	180.45	14.89	195.34
7410	2004-08-05	7712	275.73	22.75	298.48
7411	2004-08-01	3786	219.06	18.07	237.13
7412	2004-08-13	15920	75.44	6.22	81.66
7413	2004-08-15	16119	185.81	15.33	201.14
7414	2004-08-08	13603	88.05	7.26	95.31
7415	2004-08-14	1534	352.78	29.10	381.88
7416	2004-08-15	17031	318.49	26.28	344.77
7417	2004-08-13	19162	311.41	25.69	337.10
7418	2004-08-24	19857	49.41	4.08	53.49
7419	2004-08-08	9616	239.45	19.75	259.20
7420	2004-08-24	11940	351.94	29.04	380.98
7421	2004-08-16	3023	358.39	29.57	387.96
7422	2004-08-10	11804	8.34	0.69	9.03
7423	2004-08-09	5613	248.09	20.47	268.56
7424	2004-08-01	15642	34.33	2.83	37.16
7425	2004-08-28	18528	19.04	1.57	20.61
7426	2004-08-01	12199	382.08	31.52	413.60
7427	2004-08-21	17369	25.45	2.10	27.55
7428	2004-08-29	16602	181.85	15.00	196.85
7429	2004-08-03	14607	220.99	18.23	239.22
7430	2004-08-22	11744	7.63	0.63	8.26
7431	2004-08-07	8035	182.92	15.09	198.01
7432	2004-08-10	7844	316.22	26.09	342.31
7433	2004-08-30	18944	306.49	25.29	331.78
7434	2004-08-18	2567	90.27	7.45	97.72
7435	2004-08-03	12123	259.64	21.42	281.06
7436	2004-08-19	16299	231.73	19.12	250.85
7437	2004-08-04	19618	371.98	30.69	402.67
7438	2004-08-12	15065	245.73	20.27	266.00
7439	2004-08-07	16836	320.57	26.45	347.02
7440	2004-08-28	741	26.98	2.23	29.21
7441	2004-08-04	2875	85.25	7.03	92.28
7442	2004-08-17	17776	379.06	31.27	410.33
7443	2004-08-04	5086	319.30	26.34	345.64
7444	2004-08-21	12487	248.58	20.51	269.09
7445	2004-08-09	15515	97.13	8.01	105.14
7446	2004-08-21	9272	139.43	11.50	150.93
7447	2004-08-21	17531	171.06	14.11	185.17
7448	2004-08-03	13485	288.39	23.79	312.18
7449	2004-08-28	18378	219.83	18.14	237.97
7450	2004-08-01	17125	357.35	29.48	386.83
7451	2004-08-10	13279	286.16	23.61	309.77
7452	2004-08-09	18658	112.00	9.24	121.24
7453	2004-08-07	359	124.11	10.24	134.35
7454	2004-08-24	3154	329.38	27.17	356.55
7455	2004-08-20	14320	353.71	29.18	382.89
7456	2004-08-11	3454	376.21	31.04	407.25
7457	2004-08-27	5551	106.92	8.82	115.74
7458	2004-08-21	11601	292.96	24.17	317.13
7459	2004-08-03	5773	285.64	23.57	309.21
7460	2004-08-29	801	325.12	26.82	351.94
7461	2004-08-17	3629	246.71	20.35	267.06
7462	2004-08-17	5903	257.99	21.28	279.27
7463	2004-08-20	16863	314.33	25.93	340.26
7464	2004-08-27	12803	176.42	14.55	190.97
7465	2004-08-27	5748	131.55	10.85	142.40
7466	2004-08-29	2783	369.61	30.49	400.10
7467	2004-08-18	14027	199.74	16.48	216.22
7468	2004-08-15	1421	109.24	9.01	118.25
7469	2004-08-11	989	144.42	11.91	156.33
7470	2004-08-28	17191	180.17	14.86	195.03
7471	2004-08-20	19767	326.22	26.91	353.13
7472	2004-08-22	11414	121.25	10.00	131.25
7473	2004-08-21	17908	51.66	4.26	55.92
7474	2004-08-25	13574	289.20	23.86	313.06
7475	2004-08-08	14959	257.69	21.26	278.95
7476	2004-08-15	16463	371.94	30.69	402.63
7477	2004-08-10	18547	148.60	12.26	160.86
7478	2004-08-02	17838	334.04	27.56	361.60
7479	2004-08-08	4729	162.10	13.37	175.47
7480	2004-08-26	7396	292.51	24.13	316.64
7481	2004-08-17	6196	355.93	29.36	385.29
7482	2004-08-02	13555	155.09	12.79	167.88
7483	2004-08-10	8511	318.02	26.24	344.26
7484	2004-08-18	8352	51.88	4.28	56.16
7485	2004-08-20	5414	56.73	4.68	61.41
7486	2004-08-17	12839	283.20	23.36	306.56
7487	2004-08-13	3255	252.82	20.86	273.68
7488	2004-08-06	15773	119.50	9.86	129.36
7489	2004-08-15	19404	335.19	27.65	362.84
7490	2004-08-23	6415	211.84	17.48	229.32
7491	2004-08-08	13161	27.85	2.30	30.15
7492	2004-08-10	16680	63.61	5.25	68.86
7493	2004-08-28	5090	158.35	13.06	171.41
7494	2004-08-25	509	349.62	28.84	378.46
7495	2004-08-02	5216	375.73	31.00	406.73
7496	2004-08-29	4922	277.97	22.93	300.90
7497	2004-08-12	13359	211.23	17.43	228.66
7498	2004-08-09	10436	232.91	19.22	252.13
7499	2004-08-01	18865	378.59	31.23	409.82
7500	2004-08-17	10695	151.59	12.51	164.10
7501	2004-08-18	10050	148.51	12.25	160.76
7502	2004-08-31	13055	197.75	16.31	214.06
7503	2004-08-10	18996	112.26	9.26	121.52
7504	2004-08-28	6000	148.50	12.25	160.75
7505	2004-08-01	19299	242.26	19.99	262.25
7506	2004-08-01	18869	91.88	7.58	99.46
7507	2004-08-19	15983	190.91	15.75	206.66
7508	2004-08-09	19706	362.92	29.94	392.86
7509	2004-08-09	7870	332.11	27.40	359.51
7510	2004-08-06	15582	376.99	31.10	408.09
7511	2004-08-23	1848	328.53	27.10	355.63
7512	2004-08-29	18069	385.13	31.77	416.90
7513	2004-08-24	3758	330.17	27.24	357.41
7514	2004-08-25	2217	220.34	18.18	238.52
7515	2004-08-09	5169	38.73	3.20	41.93
7516	2004-08-27	12595	45.48	3.75	49.23
7517	2004-08-30	14587	259.60	21.42	281.02
7518	2004-08-25	1030	166.69	13.75	180.44
7519	2004-08-22	7571	54.62	4.51	59.13
7520	2004-08-12	5795	376.39	31.05	407.44
7521	2004-08-16	2863	69.79	5.76	75.55
7522	2004-08-12	14618	186.05	15.35	201.40
7523	2004-08-26	17023	395.47	32.63	428.10
7524	2004-08-21	1337	257.97	21.28	279.25
7525	2004-08-13	7452	84.03	6.93	90.96
7526	2004-08-04	4594	121.60	10.03	131.63
7527	2004-08-15	6802	364.15	30.04	394.19
7528	2004-08-02	9771	172.41	14.22	186.63
7529	2004-08-03	6234	79.92	6.59	86.51
7530	2004-08-25	2109	215.21	17.75	232.96
7531	2004-08-30	13533	250.44	20.66	271.10
7532	2004-08-28	4469	366.73	30.26	396.99
7533	2004-08-29	11148	330.40	27.26	357.66
7534	2004-08-22	18180	22.23	1.83	24.06
7535	2004-08-25	18370	305.99	25.24	331.23
7536	2004-08-19	14525	218.35	18.01	236.36
7537	2004-08-25	4844	333.56	27.52	361.08
7538	2004-08-01	18648	385.27	31.78	417.05
7539	2004-08-12	13434	37.04	3.06	40.10
7540	2004-08-16	4303	8.82	0.73	9.55
7541	2004-08-19	3034	51.46	4.25	55.71
7542	2004-08-24	11121	230.33	19.00	249.33
7543	2004-08-27	5434	38.87	3.21	42.08
7544	2004-08-11	18051	17.15	1.41	18.56
7545	2004-08-31	13251	256.81	21.19	278.00
7546	2004-08-31	17454	218.96	18.06	237.02
7547	2004-08-16	18170	131.15	10.82	141.97
7548	2004-08-24	8221	146.15	12.06	158.21
7549	2004-08-03	11875	331.12	27.32	358.44
7550	2004-08-19	16369	320.08	26.41	346.49
7551	2004-08-16	13367	222.70	18.37	241.07
7552	2004-08-22	5432	31.82	2.63	34.45
7553	2004-08-15	1248	121.44	10.02	131.46
7554	2004-08-18	13744	333.77	27.54	361.31
7555	2004-08-13	9185	388.07	32.02	420.09
7556	2004-08-13	3244	338.35	27.91	366.26
7557	2004-08-02	18618	236.49	19.51	256.00
7558	2004-08-19	8970	188.03	15.51	203.54
7559	2004-08-27	6459	299.66	24.72	324.38
7560	2004-08-18	16192	343.38	28.33	371.71
7561	2004-08-04	11397	207.72	17.14	224.86
7562	2004-08-10	14526	396.24	32.69	428.93
7563	2004-08-22	18619	196.13	16.18	212.31
7564	2004-08-06	10293	155.23	12.81	168.04
7565	2004-08-11	12213	253.06	20.88	273.94
7566	2004-08-16	731	105.62	8.71	114.33
7567	2004-08-15	6528	337.03	27.80	364.83
7568	2004-08-09	8879	265.76	21.93	287.69
7569	2004-08-09	14525	48.29	3.98	52.27
7570	2004-08-28	11059	213.48	17.61	231.09
7571	2004-08-12	3795	105.83	8.73	114.56
7572	2004-08-05	13692	326.35	26.92	353.27
7573	2004-08-17	10301	24.50	2.02	26.52
7574	2004-08-15	16332	28.43	2.35	30.78
7575	2004-08-16	2085	95.27	7.86	103.13
7576	2004-08-24	516	234.13	19.32	253.45
7577	2004-08-09	16537	201.99	16.66	218.65
7578	2004-08-21	18341	154.09	12.71	166.80
7579	2004-08-05	13422	346.30	28.57	374.87
7580	2004-08-10	10491	379.12	31.28	410.40
7581	2004-08-21	19650	295.30	24.36	319.66
7582	2004-08-10	17910	214.13	17.67	231.80
7583	2004-08-28	762	207.02	17.08	224.10
7584	2004-08-14	14639	318.86	26.31	345.17
7585	2004-08-29	17046	177.65	14.66	192.31
7586	2004-08-05	5332	182.94	15.09	198.03
7587	2004-08-22	2841	64.29	5.30	69.59
7588	2004-08-30	8394	192.47	15.88	208.35
7589	2004-08-25	3812	381.25	31.45	412.70
7590	2004-08-30	14956	381.31	31.46	412.77
7591	2004-08-11	7057	323.78	26.71	350.49
7592	2004-08-25	5974	5.88	0.49	6.37
7593	2004-08-02	15887	93.44	7.71	101.15
7594	2004-08-27	7713	224.74	18.54	243.28
7595	2004-08-08	4705	301.23	24.85	326.08
7596	2004-08-10	1882	305.38	25.19	330.57
7597	2004-08-13	5772	322.68	26.62	349.30
7598	2004-08-31	12713	96.01	7.92	103.93
7599	2004-08-29	11353	159.42	13.15	172.57
7600	2004-08-16	15471	259.43	21.40	280.83
7601	2004-08-22	11059	105.65	8.72	114.37
7602	2004-08-28	12208	362.10	29.87	391.97
7603	2004-08-20	2398	52.31	4.32	56.63
7604	2004-08-16	1920	47.09	3.88	50.97
7605	2004-08-09	19485	168.71	13.92	182.63
7606	2004-08-02	5117	291.81	24.07	315.88
7607	2004-08-03	12931	203.32	16.77	220.09
7608	2004-08-03	9957	343.44	28.33	371.77
7609	2004-08-18	18944	13.65	1.13	14.78
7610	2004-08-09	16502	227.63	18.78	246.41
7611	2004-08-03	15666	343.24	28.32	371.56
7612	2004-08-31	15477	17.83	1.47	19.30
7613	2004-08-27	2823	393.21	32.44	425.65
7614	2004-08-10	3671	71.12	5.87	76.99
7615	2004-08-09	15326	163.71	13.51	177.22
7616	2004-08-14	18174	252.97	20.87	273.84
7617	2004-08-19	9341	20.27	1.67	21.94
7618	2004-08-17	4396	50.22	4.14	54.36
7619	2004-08-06	18757	317.20	26.17	343.37
7620	2004-08-02	18052	356.36	29.40	385.76
7621	2004-08-07	14994	369.87	30.51	400.38
7622	2004-08-28	11622	161.66	13.34	175.00
7623	2004-08-26	14417	172.76	14.25	187.01
7624	2004-08-04	16812	30.39	2.51	32.90
7625	2004-08-29	11412	347.28	28.65	375.93
7626	2004-08-10	17056	156.47	12.91	169.38
7627	2004-08-06	10889	111.67	9.21	120.88
7628	2004-08-30	8376	126.77	10.46	137.23
7629	2004-08-04	15388	261.66	21.59	283.25
7630	2004-08-04	4266	102.53	8.46	110.99
7631	2004-08-21	6780	265.78	21.93	287.71
7632	2004-08-17	3469	77.69	6.41	84.10
7633	2004-08-11	8909	346.78	28.61	375.39
7634	2004-08-01	6945	154.32	12.73	167.05
7635	2004-08-14	13950	210.42	17.36	227.78
7636	2004-08-06	7092	179.12	14.78	193.90
7637	2004-08-14	6128	113.06	9.33	122.39
7638	2004-08-16	7345	42.76	3.53	46.29
7639	2004-08-22	18547	196.39	16.20	212.59
7640	2004-08-22	10271	322.90	26.64	349.54
7641	2004-08-31	4633	273.37	22.55	295.92
7642	2004-08-25	15376	133.64	11.03	144.67
7643	2004-08-07	12855	329.97	27.22	357.19
7644	2004-08-14	13198	266.14	21.96	288.10
7645	2004-08-03	10996	146.18	12.06	158.24
7646	2004-08-03	768	109.54	9.04	118.58
7647	2004-08-23	11953	10.69	0.88	11.57
7648	2004-08-03	2073	60.95	5.03	65.98
7649	2004-08-25	17168	70.18	5.79	75.97
7650	2004-08-18	8356	254.79	21.02	275.81
7651	2004-08-16	13858	263.91	21.77	285.68
7652	2004-08-29	13561	386.38	31.88	418.26
7653	2004-08-09	16834	45.20	3.73	48.93
7654	2004-08-13	3117	162.47	13.40	175.87
7655	2004-08-12	10250	153.46	12.66	166.12
7656	2004-08-01	4881	35.43	2.92	38.35
7657	2004-08-08	1831	388.84	32.08	420.92
7658	2004-08-17	19869	34.12	2.81	36.93
7659	2004-08-03	17716	305.09	25.17	330.26
7660	2004-08-22	12908	203.94	16.83	220.77
7661	2004-08-14	17655	292.75	24.15	316.90
7662	2004-08-16	10296	56.52	4.66	61.18
7663	2004-08-05	19049	322.04	26.57	348.61
7664	2004-08-27	7508	0.50	0.04	0.54
7665	2004-08-22	14761	352.86	29.11	381.97
7666	2004-08-18	15669	367.14	30.29	397.43
7667	2004-08-05	18952	167.26	13.80	181.06
7668	2004-08-07	6442	308.50	25.45	333.95
7669	2004-08-16	10338	366.26	30.22	396.48
7670	2004-08-03	14673	296.15	24.43	320.58
7671	2004-08-20	8087	36.84	3.04	39.88
7672	2004-08-16	4135	323.31	26.67	349.98
7673	2004-08-18	10528	130.66	10.78	141.44
7674	2004-08-30	656	37.65	3.11	40.76
7675	2004-08-26	18100	96.86	7.99	104.85
7676	2004-08-01	2469	191.75	15.82	207.57
7677	2004-08-16	16560	368.16	30.37	398.53
7678	2004-08-27	15008	35.13	2.90	38.03
7679	2004-08-06	5662	106.76	8.81	115.57
7680	2004-08-18	8511	226.33	18.67	245.00
7681	2004-08-05	531	109.37	9.02	118.39
7682	2004-08-01	5419	302.62	24.97	327.59
7683	2004-08-19	5365	75.97	6.27	82.24
7684	2004-08-07	6800	101.97	8.41	110.38
7685	2004-08-16	9504	299.29	24.69	323.98
7686	2004-08-19	487	2.36	0.19	2.55
7687	2004-08-07	12603	143.45	11.83	155.28
7688	2004-08-04	4101	209.47	17.28	226.75
7689	2004-08-06	18633	322.44	26.60	349.04
7690	2004-08-13	4505	84.22	6.95	91.17
7691	2004-08-15	9132	149.02	12.29	161.31
7692	2004-08-23	11290	302.20	24.93	327.13
7693	2004-08-16	14613	336.02	27.72	363.74
7694	2004-08-28	7283	276.14	22.78	298.92
7695	2004-08-01	117	53.95	4.45	58.40
7696	2004-08-17	16321	41.01	3.38	44.39
7697	2004-08-25	4689	108.14	8.92	117.06
7698	2004-08-26	8025	2.93	0.24	3.17
7699	2004-08-24	18359	37.11	3.06	40.17
7700	2004-08-27	11285	89.15	7.35	96.50
7701	2004-08-13	15639	29.77	2.46	32.23
7702	2004-08-08	3383	26.42	2.18	28.60
7703	2004-08-13	16121	103.87	8.57	112.44
7704	2004-08-19	611	25.64	2.12	27.76
7705	2004-08-06	1011	129.38	10.67	140.05
7706	2004-08-30	15077	0.79	0.07	0.86
7707	2004-08-07	16347	372.74	30.75	403.49
7708	2004-08-31	4317	176.97	14.60	191.57
7709	2004-08-23	17907	65.29	5.39	70.68
7710	2004-08-09	18294	181.18	14.95	196.13
7711	2004-08-30	9253	76.94	6.35	83.29
7712	2004-08-13	1080	159.09	13.12	172.21
7713	2004-08-31	8450	382.08	31.52	413.60
7714	2004-08-01	11561	78.86	6.51	85.37
7715	2004-08-21	18731	1.12	0.09	1.21
7716	2004-08-09	2846	100.39	8.28	108.67
7717	2004-08-20	7853	13.62	1.12	14.74
7718	2004-08-10	1502	14.41	1.19	15.60
7719	2004-08-07	5931	293.66	24.23	317.89
7720	2004-08-02	1337	153.28	12.65	165.93
7721	2004-08-21	9315	359.61	29.67	389.28
7722	2004-08-05	13139	318.57	26.28	344.85
7723	2004-08-26	17591	175.33	14.46	189.79
7724	2004-08-17	10193	340.19	28.07	368.26
7725	2004-08-29	2084	152.52	12.58	165.10
7726	2004-08-26	14239	111.79	9.22	121.01
7727	2004-08-29	10734	254.27	20.98	275.25
7728	2004-08-04	16599	348.53	28.75	377.28
7729	2004-08-12	19775	238.72	19.69	258.41
7730	2004-08-24	2880	333.26	27.49	360.75
7731	2004-08-18	9515	327.80	27.04	354.84
7732	2004-08-07	11030	122.77	10.13	132.90
7733	2004-08-07	15894	68.95	5.69	74.64
7734	2004-08-10	7621	9.92	0.82	10.74
7735	2004-08-24	15386	210.26	17.35	227.61
7736	2004-08-08	2262	331.86	27.38	359.24
7737	2004-08-29	14959	123.35	10.18	133.53
7738	2004-08-13	90	274.18	22.62	296.80
7739	2004-08-05	17549	124.73	10.29	135.02
7740	2004-08-23	2851	181.68	14.99	196.67
7741	2004-08-08	15534	239.21	19.73	258.94
7742	2004-08-24	14030	343.52	28.34	371.86
7743	2004-08-31	12559	324.51	26.77	351.28
7744	2004-08-29	9836	86.05	7.10	93.15
7745	2004-08-23	19808	135.42	11.17	146.59
7746	2004-08-22	16194	334.18	27.57	361.75
7747	2004-08-02	1486	58.52	4.83	63.35
7748	2004-08-08	15530	267.95	22.11	290.06
7749	2004-08-28	14809	91.33	7.53	98.86
7750	2004-08-04	3161	37.02	3.05	40.07
7751	2004-08-23	16551	133.07	10.98	144.05
7752	2004-08-13	8121	265.30	21.89	287.19
7753	2004-08-24	8538	337.74	27.86	365.60
7754	2004-08-22	524	153.44	12.66	166.10
7755	2004-08-13	3893	120.91	9.98	130.89
7756	2004-08-13	17052	11.10	0.92	12.02
7757	2004-08-20	9193	170.00	14.03	184.03
7758	2004-08-13	5485	230.74	19.04	249.78
7759	2004-08-22	12184	65.24	5.38	70.62
7760	2004-08-12	14083	98.14	8.10	106.24
7761	2004-08-15	6872	275.40	22.72	298.12
7762	2004-08-04	6151	7.26	0.60	7.86
7763	2004-08-31	12703	70.22	5.79	76.01
7764	2004-08-04	5172	61.50	5.07	66.57
7765	2004-08-17	12434	19.03	1.57	20.60
7766	2004-08-31	1912	355.88	29.36	385.24
7767	2004-08-20	6161	241.79	19.95	261.74
7768	2004-08-14	8784	253.58	20.92	274.50
7769	2004-08-17	8280	35.02	2.89	37.91
7770	2004-08-28	6285	295.16	24.35	319.51
7771	2004-08-24	17511	9.78	0.81	10.59
7772	2004-08-26	16130	350.44	28.91	379.35
7773	2004-08-10	3134	391.63	32.31	423.94
7774	2004-08-06	14624	287.46	23.72	311.18
7775	2004-08-10	16741	318.87	26.31	345.18
7776	2004-08-04	4849	93.84	7.74	101.58
7777	2004-08-23	18602	292.28	24.11	316.39
7778	2004-08-13	17723	308.83	25.48	334.31
7779	2004-08-14	12415	204.49	16.87	221.36
7780	2004-08-18	8117	392.68	32.40	425.08
7781	2004-08-12	8500	80.57	6.65	87.22
7782	2004-08-12	12316	332.26	27.41	359.67
7783	2004-08-20	11360	173.74	14.33	188.07
7784	2004-08-02	4302	346.21	28.56	374.77
7785	2004-08-28	8984	90.32	7.45	97.77
7786	2004-08-18	6967	131.00	10.81	141.81
7787	2004-08-02	14216	35.93	2.96	38.89
7788	2004-08-13	941	178.30	14.71	193.01
7789	2004-08-26	14343	200.65	16.55	217.20
7790	2004-08-02	3522	173.18	14.29	187.47
7791	2004-08-28	167	141.06	11.64	152.70
7792	2004-08-12	11624	195.31	16.11	211.42
7793	2004-08-28	18059	17.95	1.48	19.43
7794	2004-08-17	733	85.95	7.09	93.04
7795	2004-08-27	1497	380.45	31.39	411.84
7796	2004-08-05	7068	34.43	2.84	37.27
7797	2004-08-18	5175	276.11	22.78	298.89
7798	2004-08-04	13031	91.61	7.56	99.17
7799	2004-08-14	14323	165.24	13.63	178.87
7800	2004-08-02	9047	207.80	17.14	224.94
7801	2004-08-04	17810	353.88	29.20	383.08
7802	2004-08-23	9850	69.90	5.77	75.67
7803	2004-08-20	8125	383.50	31.64	415.14
7804	2004-08-31	839	8.36	0.69	9.05
7805	2004-08-20	15575	258.51	21.33	279.84
7806	2004-08-11	3276	179.48	14.81	194.29
7807	2004-08-09	41	152.99	12.62	165.61
7808	2004-08-31	9648	81.28	6.71	87.99
7809	2004-08-14	1416	353.75	29.18	382.93
7810	2004-08-27	19315	112.09	9.25	121.34
7811	2004-08-18	10390	264.86	21.85	286.71
7812	2004-08-20	13871	96.01	7.92	103.93
7813	2004-08-03	12483	368.66	30.41	399.07
7814	2004-08-16	8067	363.52	29.99	393.51
7815	2004-08-24	422	185.69	15.32	201.01
7816	2004-08-20	13935	273.06	22.53	295.59
7817	2004-08-02	4152	395.62	32.64	428.26
7818	2004-08-05	15051	48.36	3.99	52.35
7819	2004-08-01	4222	123.93	10.22	134.15
7820	2004-08-26	10565	71.36	5.89	77.25
7821	2004-08-22	5832	320.73	26.46	347.19
7822	2004-08-03	7229	243.52	20.09	263.61
7823	2004-08-12	3432	28.14	2.32	30.46
7824	2004-08-08	19191	79.57	6.56	86.13
7825	2004-08-11	7410	69.19	5.71	74.90
7826	2004-08-21	15001	346.09	28.55	374.64
7827	2004-08-18	15202	8.98	0.74	9.72
7828	2004-08-30	4630	316.22	26.09	342.31
7829	2004-08-05	4525	87.67	7.23	94.90
7830	2004-08-28	684	95.75	7.90	103.65
7831	2004-08-07	5638	351.07	28.96	380.03
7832	2004-08-03	11789	87.56	7.22	94.78
7833	2004-08-13	887	13.62	1.12	14.74
7834	2004-08-10	5043	149.39	12.32	161.71
7835	2004-08-09	15139	282.14	23.28	305.42
7836	2004-08-01	11528	385.70	31.82	417.52
7837	2004-08-29	16155	245.53	20.26	265.79
7838	2004-08-25	17568	41.87	3.45	45.32
7839	2004-08-24	2623	223.38	18.43	241.81
7840	2004-08-18	9812	170.26	14.05	184.31
7841	2004-08-24	8169	223.51	18.44	241.95
7842	2004-08-24	17982	300.30	24.77	325.07
7843	2004-08-13	16766	254.94	21.03	275.97
7844	2004-08-11	3798	122.89	10.14	133.03
7845	2004-08-19	9005	227.33	18.75	246.08
7846	2004-08-06	3128	7.18	0.59	7.77
7847	2004-08-24	18419	50.61	4.18	54.79
7848	2004-08-16	154	273.99	22.60	296.59
7849	2004-08-09	15483	242.10	19.97	262.07
7850	2004-08-22	8721	199.85	16.49	216.34
7851	2004-08-31	8121	288.30	23.78	312.08
7852	2004-08-19	10512	116.21	9.59	125.80
7853	2004-08-03	289	289.35	23.87	313.22
7854	2004-08-10	2907	378.61	31.24	409.85
7855	2004-08-03	16636	176.89	14.59	191.48
7856	2004-08-23	6611	32.50	2.68	35.18
7857	2004-08-14	15654	206.53	17.04	223.57
7858	2004-08-03	3212	344.76	28.44	373.20
7859	2004-08-31	7621	186.62	15.40	202.02
7860	2004-08-28	14903	276.79	22.84	299.63
7861	2004-08-19	8705	82.01	6.77	88.78
7862	2004-08-10	18098	243.77	20.11	263.88
7863	2004-08-10	7390	365.47	30.15	395.62
7864	2004-08-23	12875	392.73	32.40	425.13
7865	2004-08-13	19173	127.54	10.52	138.06
7866	2004-08-23	15471	36.95	3.05	40.00
7867	2004-08-17	1288	105.70	8.72	114.42
7868	2004-08-26	9781	141.71	11.69	153.40
7869	2004-08-04	14764	198.44	16.37	214.81
7870	2004-08-03	4750	170.37	14.06	184.43
7871	2004-08-24	17882	271.54	22.40	293.94
7872	2004-08-19	10793	353.19	29.14	382.33
7873	2004-08-15	12666	95.09	7.84	102.93
7874	2004-08-05	9721	317.95	26.23	344.18
7875	2004-08-28	4592	324.23	26.75	350.98
7876	2004-08-30	328	81.99	6.76	88.75
7877	2004-08-20	6746	71.81	5.92	77.73
7878	2004-08-18	2735	56.78	4.68	61.46
7879	2004-08-15	2156	174.79	14.42	189.21
7880	2004-08-18	2747	79.43	6.55	85.98
7881	2004-08-15	7756	129.33	10.67	140.00
7882	2004-08-28	10114	277.36	22.88	300.24
7883	2004-08-21	9265	340.41	28.08	368.49
7884	2004-08-29	9471	258.91	21.36	280.27
7885	2004-08-23	19971	42.65	3.52	46.17
7886	2004-08-12	18428	357.96	29.53	387.49
7887	2004-08-16	13356	111.35	9.19	120.54
7888	2004-08-02	12467	339.04	27.97	367.01
7889	2004-08-12	15365	41.28	3.41	44.69
7890	2004-08-10	10689	164.16	13.54	177.70
7891	2004-08-19	13159	165.87	13.68	179.55
7892	2004-08-20	4662	347.71	28.69	376.40
7893	2004-08-21	18867	399.71	32.98	432.69
7894	2004-08-11	2666	113.91	9.40	123.31
7895	2004-08-07	6617	25.07	2.07	27.14
7896	2004-08-02	13121	172.02	14.19	186.21
7897	2004-08-09	13504	168.54	13.90	182.44
7898	2004-08-30	16170	79.06	6.52	85.58
7899	2004-08-20	3315	228.90	18.88	247.78
7900	2004-08-02	11221	135.47	11.18	146.65
7901	2004-08-27	6821	296.54	24.46	321.00
7902	2004-08-07	18118	270.04	22.28	292.32
7903	2004-08-04	1264	303.25	25.02	328.27
7904	2004-08-02	734	239.47	19.76	259.23
7905	2004-08-20	13104	66.30	5.47	71.77
7906	2004-08-13	8603	398.32	32.86	431.18
7907	2004-08-09	18034	69.91	5.77	75.68
7908	2004-08-23	3464	361.90	29.86	391.76
7909	2004-08-14	8640	166.13	13.71	179.84
7910	2004-08-03	5682	275.41	22.72	298.13
7911	2004-08-20	13746	364.11	30.04	394.15
7912	2004-08-22	698	352.76	29.10	381.86
7913	2004-08-09	6569	193.75	15.98	209.73
7914	2004-08-12	11621	225.16	18.58	243.74
7915	2004-08-05	13990	361.30	29.81	391.11
7916	2004-08-21	968	387.58	31.98	419.56
7917	2004-08-10	17019	13.87	1.14	15.01
7918	2004-08-28	9999	51.19	4.22	55.41
7919	2004-08-05	11941	58.47	4.82	63.29
7920	2004-08-06	8406	50.37	4.16	54.53
7921	2004-08-14	5392	73.19	6.04	79.23
7922	2004-08-25	16363	374.39	30.89	405.28
7923	2004-08-26	1378	263.63	21.75	285.38
7924	2004-08-25	14063	27.73	2.29	30.02
7925	2004-08-08	17213	311.90	25.73	337.63
7926	2004-08-01	2225	209.02	17.24	226.26
7927	2004-08-19	7914	291.76	24.07	315.83
7928	2004-08-04	11623	248.80	20.53	269.33
7929	2004-08-08	17835	86.00	7.10	93.09
7930	2004-08-27	18514	73.90	6.10	80.00
7931	2004-08-15	6586	338.13	27.90	366.03
7932	2004-08-29	4818	213.92	17.65	231.57
7933	2004-08-18	5284	84.57	6.98	91.55
7934	2004-08-14	6981	73.71	6.08	79.79
7935	2004-08-19	208	270.71	22.33	293.04
7936	2004-08-22	12468	214.57	17.70	232.27
7937	2004-08-16	9089	57.56	4.75	62.31
7938	2004-08-19	6105	110.65	9.13	119.78
7939	2004-08-05	1559	293.79	24.24	318.03
7940	2004-08-20	9475	167.12	13.79	180.91
7941	2004-08-12	15522	76.83	6.34	83.17
7942	2004-08-06	472	271.20	22.37	293.57
7943	2004-08-28	18575	191.04	15.76	206.80
7944	2004-08-25	6359	41.32	3.41	44.73
7945	2004-08-05	7378	161.99	13.36	175.35
7946	2004-08-18	5939	364.54	30.07	394.61
7947	2004-08-06	9534	229.22	18.91	248.13
7948	2004-08-16	5444	204.47	16.87	221.34
7949	2004-08-31	8332	389.66	32.15	421.81
7950	2004-08-19	3103	92.58	7.64	100.22
7951	2004-08-11	18456	175.26	14.46	189.72
7952	2004-08-16	4686	149.90	12.37	162.27
7953	2004-08-20	10778	63.48	5.24	68.72
7954	2004-08-02	19865	19.69	1.62	21.31
7955	2004-08-02	115	305.00	25.16	330.16
7956	2004-08-18	11341	241.17	19.90	261.07
7957	2004-08-08	953	196.42	16.20	212.62
7958	2004-08-09	7676	0.26	0.02	0.28
7959	2004-08-31	2743	229.58	18.94	248.52
7960	2004-08-09	8425	184.14	15.19	199.33
7961	2004-08-15	19955	378.51	31.23	409.74
7962	2004-08-12	7666	356.51	29.41	385.92
7963	2004-08-21	1606	54.40	4.49	58.89
7964	2004-08-19	19953	183.23	15.12	198.35
7965	2004-08-17	12653	92.71	7.65	100.36
7966	2004-08-05	11585	378.87	31.26	410.13
7967	2004-08-03	7023	149.42	12.33	161.75
7968	2004-08-06	10696	305.87	25.23	331.10
7969	2004-08-30	17595	97.95	8.08	106.03
7970	2004-08-30	5536	134.22	11.07	145.29
7971	2004-08-20	15172	225.07	18.57	243.64
7972	2004-08-16	14644	37.31	3.08	40.39
7973	2004-08-31	3260	19.51	1.61	21.12
7974	2004-08-06	3920	99.86	8.24	108.10
7975	2004-08-07	3266	77.02	6.35	83.37
7976	2004-08-29	4115	163.16	13.46	176.62
7977	2004-08-15	876	234.38	19.34	253.72
7978	2004-08-08	9441	31.02	2.56	33.58
7979	2004-08-04	11901	224.32	18.51	242.83
7980	2004-08-24	8193	264.08	21.79	285.87
7981	2004-08-07	19222	321.80	26.55	348.35
7982	2004-08-17	9484	94.74	7.82	102.56
7983	2004-08-25	11306	276.25	22.79	299.04
7984	2004-08-17	11521	53.06	4.38	57.44
7985	2004-08-08	245	74.18	6.12	80.30
7986	2004-08-14	3378	22.41	1.85	24.26
7987	2004-08-10	3261	394.82	32.57	427.39
7988	2004-08-14	10634	63.36	5.23	68.59
7989	2004-08-24	11860	306.83	25.31	332.14
7990	2004-08-15	11485	51.39	4.24	55.63
7991	2004-08-29	12841	355.28	29.31	384.59
7992	2004-08-04	8912	25.47	2.10	27.57
7993	2004-08-26	4356	251.24	20.73	271.97
7994	2004-08-27	12537	242.91	20.04	262.95
7995	2004-08-15	6935	343.47	28.34	371.81
7996	2004-08-12	7266	397.84	32.82	430.66
7997	2004-08-02	2735	283.89	23.42	307.31
7998	2004-08-24	15401	280.79	23.17	303.96
7999	2004-08-24	2993	360.98	29.78	390.76
8000	2004-08-15	810	56.78	4.68	61.46
8001	2004-09-12	9922	384.52	31.72	416.24
8002	2004-09-05	1039	160.02	13.20	173.22
8003	2004-09-10	7980	279.98	23.10	303.08
8004	2004-09-05	1026	117.96	9.73	127.69
8005	2004-09-15	4389	273.66	22.58	296.24
8006	2004-09-29	19408	218.21	18.00	236.21
8007	2004-09-26	4883	337.91	27.88	365.79
8008	2004-09-22	9811	276.44	22.81	299.25
8009	2004-09-16	7271	121.42	10.02	131.44
8010	2004-09-18	19374	82.60	6.81	89.41
8011	2004-09-06	12438	297.44	24.54	321.98
8012	2004-09-16	7636	325.22	26.83	352.05
8013	2004-09-16	1532	97.35	8.03	105.38
8014	2004-09-30	14559	337.14	27.81	364.95
8015	2004-09-26	13068	113.85	9.39	123.24
8016	2004-09-10	17958	27.54	2.27	29.81
8017	2004-09-30	17313	339.29	27.99	367.28
8018	2004-09-05	14013	246.81	20.36	267.17
8019	2004-09-15	18519	64.66	5.33	69.99
8020	2004-09-01	703	208.22	17.18	225.40
8021	2004-09-20	10075	230.66	19.03	249.69
8022	2004-09-03	16948	368.35	30.39	398.74
8023	2004-09-05	8308	395.59	32.64	428.23
8024	2004-09-22	14138	239.15	19.73	258.88
8025	2004-09-24	14732	289.80	23.91	313.71
8026	2004-09-22	17612	49.81	4.11	53.92
8027	2004-09-20	6775	92.46	7.63	100.09
8028	2004-09-24	15337	25.56	2.11	27.67
8029	2004-09-17	18748	273.56	22.57	296.13
8030	2004-09-11	19019	112.22	9.26	121.48
8031	2004-09-30	6162	148.53	12.25	160.78
8032	2004-09-23	10114	124.10	10.24	134.34
8033	2004-09-18	11700	213.36	17.60	230.96
8034	2004-09-09	2979	109.53	9.04	118.57
8035	2004-09-29	7291	363.73	30.01	393.74
8036	2004-09-16	13324	255.73	21.10	276.83
8037	2004-09-15	14113	230.29	19.00	249.29
8038	2004-09-18	4809	86.10	7.10	93.20
8039	2004-09-22	18424	60.05	4.95	65.00
8040	2004-09-16	19486	132.78	10.95	143.73
8041	2004-09-13	11287	31.47	2.60	34.07
8042	2004-09-29	8837	375.22	30.96	406.18
8043	2004-09-23	13952	354.60	29.25	383.85
8044	2004-09-14	15068	158.80	13.10	171.90
8045	2004-09-20	11532	79.99	6.60	86.59
8046	2004-09-23	976	320.18	26.41	346.59
8047	2004-09-27	14013	84.46	6.97	91.43
8048	2004-09-30	14836	56.37	4.65	61.02
8049	2004-09-11	7942	221.49	18.27	239.76
8050	2004-09-11	16792	16.92	1.40	18.32
8051	2004-09-15	4496	230.75	19.04	249.79
8052	2004-09-20	14209	163.58	13.50	177.08
8053	2004-09-27	11921	269.02	22.19	291.21
8054	2004-09-12	1645	19.97	1.65	21.62
8055	2004-09-29	14431	227.30	18.75	246.05
8056	2004-09-26	17685	239.83	19.79	259.62
8057	2004-09-18	12614	233.09	19.23	252.32
8058	2004-09-05	11502	235.28	19.41	254.69
8059	2004-09-03	17018	384.99	31.76	416.75
8060	2004-09-21	13794	249.47	20.58	270.05
8061	2004-09-11	8142	309.99	25.57	335.56
8062	2004-09-01	4572	31.59	2.61	34.20
8063	2004-09-22	8141	87.99	7.26	95.25
8064	2004-09-21	3266	33.69	2.78	36.47
8065	2004-09-02	3479	294.99	24.34	319.33
8066	2004-09-24	12898	281.47	23.22	304.69
8067	2004-09-28	2964	71.52	5.90	77.42
8068	2004-09-06	7932	219.12	18.08	237.20
8069	2004-09-09	15541	313.81	25.89	339.70
8070	2004-09-24	5217	124.32	10.26	134.58
8071	2004-09-22	8206	13.99	1.15	15.14
8072	2004-09-15	18702	96.45	7.96	104.41
8073	2004-09-16	3559	116.50	9.61	126.11
8074	2004-09-20	1749	303.05	25.00	328.05
8075	2004-09-18	17766	62.30	5.14	67.44
8076	2004-09-15	15505	103.90	8.57	112.47
8077	2004-09-04	19039	386.51	31.89	418.40
8078	2004-09-18	11095	224.71	18.54	243.25
8079	2004-09-17	10559	57.30	4.73	62.03
8080	2004-09-21	14438	301.00	24.83	325.83
8081	2004-09-05	13636	318.50	26.28	344.78
8082	2004-09-22	9564	143.74	11.86	155.60
8083	2004-09-29	13617	277.81	22.92	300.73
8084	2004-09-07	13322	274.86	22.68	297.54
8085	2004-09-03	9371	196.93	16.25	213.18
8086	2004-09-23	13580	102.71	8.47	111.18
8087	2004-09-05	19204	329.29	27.17	356.46
8088	2004-09-09	8900	322.53	26.61	349.14
8089	2004-09-06	6839	155.69	12.84	168.53
8090	2004-09-08	16376	399.63	32.97	432.60
8091	2004-09-21	4860	219.80	18.13	237.93
8092	2004-09-09	4870	319.67	26.37	346.04
8093	2004-09-08	15217	218.06	17.99	236.05
8094	2004-09-04	7152	333.20	27.49	360.69
8095	2004-09-26	4416	112.88	9.31	122.19
8096	2004-09-22	18420	194.88	16.08	210.96
8097	2004-09-20	1119	192.60	15.89	208.49
8098	2004-09-01	6133	156.81	12.94	169.75
8099	2004-09-06	12568	351.19	28.97	380.16
8100	2004-09-30	17602	7.99	0.66	8.65
8101	2004-09-05	13889	358.71	29.59	388.30
8102	2004-09-02	12585	312.97	25.82	338.79
8103	2004-09-22	14542	347.45	28.66	376.11
8104	2004-09-28	9959	21.59	1.78	23.37
8105	2004-09-22	10770	199.05	16.42	215.47
8106	2004-09-27	8253	289.24	23.86	313.10
8107	2004-09-26	19511	86.46	7.13	93.59
8108	2004-09-01	11645	391.55	32.30	423.85
8109	2004-09-11	8354	76.12	6.28	82.40
8110	2004-09-28	15113	122.08	10.07	132.15
8111	2004-09-23	2772	379.49	31.31	410.80
8112	2004-09-13	14798	41.76	3.45	45.21
8113	2004-09-06	14040	361.14	29.79	390.93
8114	2004-09-17	2567	38.56	3.18	41.74
8115	2004-09-19	10826	140.27	11.57	151.84
8116	2004-09-29	9752	331.41	27.34	358.75
8117	2004-09-26	9365	238.73	19.70	258.43
8118	2004-09-25	3433	160.21	13.22	173.43
8119	2004-09-28	6227	126.67	10.45	137.12
8120	2004-09-03	17145	33.38	2.75	36.13
8121	2004-09-17	6895	29.03	2.39	31.42
8122	2004-09-11	10139	172.26	14.21	186.47
8123	2004-09-20	1236	189.86	15.66	205.52
8124	2004-09-23	2867	371.16	30.62	401.78
8125	2004-09-04	2474	116.95	9.65	126.60
8126	2004-09-02	10051	165.94	13.69	179.63
8127	2004-09-12	1224	274.08	22.61	296.69
8128	2004-09-16	4719	366.34	30.22	396.56
8129	2004-09-01	7538	65.90	5.44	71.34
8130	2004-09-07	4636	32.34	2.67	35.01
8131	2004-09-19	10734	12.94	1.07	14.01
8132	2004-09-22	10520	399.00	32.92	431.92
8133	2004-09-18	4151	177.48	14.64	192.12
8134	2004-09-21	6606	322.64	26.62	349.26
8135	2004-09-06	15987	224.11	18.49	242.60
8136	2004-09-26	5029	305.23	25.18	330.41
8137	2004-09-24	3253	91.81	7.57	99.38
8138	2004-09-29	15233	173.25	14.29	187.54
8139	2004-09-14	10028	378.04	31.19	409.23
8140	2004-09-24	14745	343.82	28.37	372.19
8141	2004-09-22	15962	83.07	6.85	89.92
8142	2004-09-01	5285	270.98	22.36	293.34
8143	2004-09-12	18131	108.46	8.95	117.41
8144	2004-09-01	17147	136.41	11.25	147.66
8145	2004-09-21	2686	108.40	8.94	117.34
8146	2004-09-26	7249	64.00	5.28	69.28
8147	2004-09-14	8847	195.53	16.13	211.66
8148	2004-09-07	6164	152.71	12.60	165.31
8149	2004-09-12	12175	375.37	30.97	406.34
8150	2004-09-25	2531	18.09	1.49	19.58
8151	2004-09-15	5648	166.24	13.71	179.95
8152	2004-09-28	18430	130.00	10.72	140.72
8153	2004-09-24	5076	146.50	12.09	158.59
8154	2004-09-15	3547	128.41	10.59	139.00
8155	2004-09-28	19054	231.74	19.12	250.86
8156	2004-09-03	15601	199.31	16.44	215.75
8157	2004-09-05	4913	335.90	27.71	363.61
8158	2004-09-12	17233	30.17	2.49	32.66
8159	2004-09-18	8588	62.37	5.15	67.52
8160	2004-09-25	17694	87.27	7.20	94.47
8161	2004-09-04	3442	382.36	31.54	413.90
8162	2004-09-30	17167	52.04	4.29	56.33
8163	2004-09-30	14131	36.70	3.03	39.73
8164	2004-09-11	11639	330.07	27.23	357.30
8165	2004-09-14	13330	87.91	7.25	95.16
8166	2004-09-26	19523	27.61	2.28	29.89
8167	2004-09-28	14128	274.24	22.62	296.86
8168	2004-09-06	12037	296.58	24.47	321.05
8169	2004-09-26	1873	20.36	1.68	22.04
8170	2004-09-30	7332	106.37	8.78	115.15
8171	2004-09-26	14721	110.36	9.10	119.46
8172	2004-09-12	6426	183.63	15.15	198.78
8173	2004-09-08	4560	119.05	9.82	128.87
8174	2004-09-09	2910	143.83	11.87	155.70
8175	2004-09-01	16646	232.43	19.18	251.61
8176	2004-09-14	4826	159.95	13.20	173.15
8177	2004-09-29	1529	244.21	20.15	264.36
8178	2004-09-02	2875	189.74	15.65	205.39
8179	2004-09-16	2252	7.67	0.63	8.30
8180	2004-09-18	19169	28.56	2.36	30.92
8181	2004-09-12	11283	36.04	2.97	39.01
8182	2004-09-09	5354	159.18	13.13	172.31
8183	2004-09-06	18604	393.89	32.50	426.39
8184	2004-09-02	7801	88.50	7.30	95.80
8185	2004-09-30	7617	381.90	31.51	413.41
8186	2004-09-28	13346	287.96	23.76	311.72
8187	2004-09-04	11765	281.88	23.26	305.14
8188	2004-09-03	122	31.84	2.63	34.47
8189	2004-09-12	14268	190.80	15.74	206.54
8190	2004-09-24	4600	225.00	18.56	243.56
8191	2004-09-08	7427	203.37	16.78	220.15
8192	2004-09-12	6631	344.62	28.43	373.05
8193	2004-09-14	4006	79.46	6.56	86.02
8194	2004-09-20	4883	239.40	19.75	259.15
8195	2004-09-10	11471	200.15	16.51	216.66
8196	2004-09-05	3691	38.64	3.19	41.83
8197	2004-09-27	1205	67.39	5.56	72.95
8198	2004-09-12	16130	14.44	1.19	15.63
8199	2004-09-25	2392	283.76	23.41	307.17
8200	2004-09-13	15096	225.60	18.61	244.21
8201	2004-09-02	19127	325.11	26.82	351.93
8202	2004-09-17	12024	354.33	29.23	383.56
8203	2004-09-07	19484	132.73	10.95	143.68
8204	2004-09-01	12050	262.31	21.64	283.95
8205	2004-09-16	8800	297.51	24.54	322.05
8206	2004-09-28	9215	229.67	18.95	248.62
8207	2004-09-11	1364	10.39	0.86	11.25
8208	2004-09-07	8446	339.81	28.03	367.84
8209	2004-09-14	8601	31.74	2.62	34.36
8210	2004-09-05	1915	280.56	23.15	303.71
8211	2004-09-17	17644	101.94	8.41	110.35
8212	2004-09-10	8730	189.40	15.63	205.03
8213	2004-09-21	5772	238.78	19.70	258.48
8214	2004-09-03	12146	265.44	21.90	287.34
8215	2004-09-18	16866	13.61	1.12	14.73
8216	2004-09-25	10724	133.94	11.05	144.99
8217	2004-09-04	8197	177.58	14.65	192.23
8218	2004-09-09	15652	349.07	28.80	377.87
8219	2004-09-13	15803	180.05	14.85	194.90
8220	2004-09-30	3304	173.89	14.35	188.24
8221	2004-09-08	2377	381.75	31.49	413.24
8222	2004-09-05	16149	228.87	18.88	247.75
8223	2004-09-06	17885	169.61	13.99	183.60
8224	2004-09-12	19895	72.24	5.96	78.20
8225	2004-09-04	17714	359.24	29.64	388.88
8226	2004-09-11	5004	131.84	10.88	142.72
8227	2004-09-21	12486	381.54	31.48	413.02
8228	2004-09-13	10497	59.35	4.90	64.25
8229	2004-09-09	13974	152.72	12.60	165.32
8230	2004-09-13	10983	349.96	28.87	378.83
8231	2004-09-30	18912	238.90	19.71	258.61
8232	2004-09-01	9187	324.56	26.78	351.34
8233	2004-09-24	6625	53.58	4.42	58.00
8234	2004-09-19	9804	29.63	2.44	32.07
8235	2004-09-16	7121	207.39	17.11	224.50
8236	2004-09-21	11637	383.09	31.60	414.69
8237	2004-09-03	6560	208.25	17.18	225.43
8238	2004-09-12	7158	211.95	17.49	229.44
8239	2004-09-24	9534	148.35	12.24	160.59
8240	2004-09-07	11085	361.46	29.82	391.28
8241	2004-09-06	3060	237.99	19.63	257.62
8242	2004-09-10	12582	260.71	21.51	282.22
8243	2004-09-07	9941	305.34	25.19	330.53
8244	2004-09-26	8283	303.54	25.04	328.58
8245	2004-09-04	9418	34.52	2.85	37.37
8246	2004-09-26	3521	237.86	19.62	257.48
8247	2004-09-09	19855	328.32	27.09	355.41
8248	2004-09-16	6791	162.82	13.43	176.25
8249	2004-09-14	12521	156.75	12.93	169.68
8250	2004-09-20	6587	110.27	9.10	119.37
8251	2004-09-27	8935	162.11	13.37	175.48
8252	2004-09-22	18090	65.77	5.43	71.20
8253	2004-09-07	7117	101.78	8.40	110.18
8254	2004-09-20	19063	264.31	21.81	286.12
8255	2004-09-14	11714	205.92	16.99	222.91
8256	2004-09-26	635	242.86	20.04	262.90
8257	2004-09-08	19695	387.68	31.98	419.66
8258	2004-09-16	5224	120.50	9.94	130.44
8259	2004-09-05	6495	36.41	3.00	39.41
8260	2004-09-29	14028	379.33	31.29	410.62
8261	2004-09-25	14968	364.60	30.08	394.68
8262	2004-09-07	9337	73.35	6.05	79.40
8263	2004-09-20	5204	377.25	31.12	408.37
8264	2004-09-19	6999	219.76	18.13	237.89
8265	2004-09-20	8357	171.45	14.14	185.59
8266	2004-09-03	12770	146.62	12.10	158.72
8267	2004-09-14	16291	230.92	19.05	249.97
8268	2004-09-26	13319	344.41	28.41	372.82
8269	2004-09-24	9526	244.95	20.21	265.16
8270	2004-09-25	7289	1.49	0.12	1.61
8271	2004-09-06	16857	286.40	23.63	310.03
8272	2004-09-26	1065	128.83	10.63	139.46
8273	2004-09-11	19896	23.28	1.92	25.20
8274	2004-09-06	12071	338.32	27.91	366.23
8275	2004-09-23	11723	229.84	18.96	248.80
8276	2004-09-24	12215	172.55	14.24	186.79
8277	2004-09-21	16386	133.30	11.00	144.30
8278	2004-09-10	6372	101.66	8.39	110.05
8279	2004-09-25	12031	47.65	3.93	51.58
8280	2004-09-15	3669	106.41	8.78	115.19
8281	2004-09-05	12624	55.50	4.58	60.08
8282	2004-09-11	7481	216.96	17.90	234.86
8283	2004-09-15	17445	61.83	5.10	66.93
8284	2004-09-29	14261	136.16	11.23	147.39
8285	2004-09-10	13128	162.24	13.38	175.62
8286	2004-09-16	13311	240.23	19.82	260.05
8287	2004-09-29	291	79.85	6.59	86.44
8288	2004-09-25	7252	352.26	29.06	381.32
8289	2004-09-13	6614	103.51	8.54	112.05
8290	2004-09-09	5645	131.85	10.88	142.73
8291	2004-09-22	19149	215.50	17.78	233.28
8292	2004-09-29	15207	253.53	20.92	274.45
8293	2004-09-04	6024	46.55	3.84	50.39
8294	2004-09-01	8051	6.74	0.56	7.30
8295	2004-09-23	13751	394.90	32.58	427.48
8296	2004-09-12	4676	112.76	9.30	122.06
8297	2004-09-21	3852	69.24	5.71	74.95
8298	2004-09-27	13779	218.33	18.01	236.34
8299	2004-09-20	5853	279.09	23.02	302.11
8300	2004-09-09	5399	167.87	13.85	181.72
8301	2004-09-21	19905	50.12	4.13	54.25
8302	2004-09-14	19747	211.44	17.44	228.88
8303	2004-09-14	9105	55.68	4.59	60.27
8304	2004-09-30	12720	150.93	12.45	163.38
8305	2004-09-24	1315	145.33	11.99	157.32
8306	2004-09-12	4010	77.43	6.39	83.82
8307	2004-09-13	19128	103.11	8.51	111.62
8308	2004-09-21	14230	294.54	24.30	318.84
8309	2004-09-12	18830	195.76	16.15	211.91
8310	2004-09-19	12265	292.97	24.17	317.14
8311	2004-09-15	6441	172.11	14.20	186.31
8312	2004-09-03	12782	354.76	29.27	384.03
8313	2004-09-15	2500	39.60	3.27	42.87
8314	2004-09-05	11090	333.28	27.50	360.78
8315	2004-09-01	10343	308.44	25.45	333.89
8316	2004-09-13	7029	379.99	31.35	411.34
8317	2004-09-25	5407	52.47	4.33	56.80
8318	2004-09-27	11001	150.44	12.41	162.85
8319	2004-09-14	10460	101.30	8.36	109.66
8320	2004-09-11	1675	60.38	4.98	65.36
8321	2004-09-19	1080	38.62	3.19	41.81
8322	2004-09-11	7838	2.41	0.20	2.61
8323	2004-09-30	14524	208.78	17.22	226.00
8324	2004-09-22	19045	67.93	5.60	73.53
8325	2004-09-30	19138	385.01	31.76	416.77
8326	2004-09-25	16648	277.35	22.88	300.23
8327	2004-09-11	5120	110.36	9.10	119.46
8328	2004-09-03	18639	143.99	11.88	155.87
8329	2004-09-24	9471	103.56	8.54	112.10
8330	2004-09-24	816	382.24	31.53	413.77
8331	2004-09-09	10383	373.76	30.84	404.60
8332	2004-09-04	18248	249.09	20.55	269.64
8333	2004-09-13	4484	11.65	0.96	12.61
8334	2004-09-30	15876	377.00	31.10	408.10
8335	2004-09-26	8313	182.61	15.07	197.68
8336	2004-09-18	489	146.33	12.07	158.40
8337	2004-09-29	12117	369.17	30.46	399.63
8338	2004-09-14	8396	178.21	14.70	192.91
8339	2004-09-28	5704	275.64	22.74	298.38
8340	2004-09-15	14062	131.27	10.83	142.10
8341	2004-09-05	1577	175.64	14.49	190.13
8342	2004-09-18	13473	73.25	6.04	79.29
8343	2004-09-11	4871	238.13	19.65	257.78
8344	2004-09-28	15220	183.66	15.15	198.81
8345	2004-09-16	1007	31.17	2.57	33.74
8346	2004-09-27	14359	208.72	17.22	225.94
8347	2004-09-20	16361	186.38	15.38	201.76
8348	2004-09-08	5399	231.70	19.12	250.82
8349	2004-09-14	6370	83.70	6.91	90.61
8350	2004-09-03	5624	261.17	21.55	282.72
8351	2004-09-21	6776	10.94	0.90	11.84
8352	2004-09-21	51	2.34	0.19	2.53
8353	2004-09-13	13637	43.98	3.63	47.61
8354	2004-09-26	14171	156.19	12.89	169.08
8355	2004-09-12	10634	244.17	20.14	264.31
8356	2004-09-03	10684	204.44	16.87	221.31
8357	2004-09-04	7790	63.84	5.27	69.11
8358	2004-09-21	13765	61.58	5.08	66.66
8359	2004-09-02	15740	32.59	2.69	35.28
8360	2004-09-21	16230	132.40	10.92	143.32
8361	2004-09-27	17799	258.39	21.32	279.71
8362	2004-09-27	13948	221.91	18.31	240.22
8363	2004-09-25	10957	196.38	16.20	212.58
8364	2004-09-15	11405	29.95	2.47	32.42
8365	2004-09-22	17860	248.65	20.51	269.16
8366	2004-09-02	10949	79.50	6.56	86.06
8367	2004-09-20	6351	187.37	15.46	202.83
8368	2004-09-13	346	342.51	28.26	370.77
8369	2004-09-20	5672	176.88	14.59	191.47
8370	2004-09-23	11792	395.39	32.62	428.01
8371	2004-09-15	17034	61.90	5.11	67.01
8372	2004-09-27	1144	80.05	6.60	86.65
8373	2004-09-16	19316	245.80	20.28	266.08
8374	2004-09-04	1431	349.95	28.87	378.82
8375	2004-09-27	18942	382.20	31.53	413.73
8376	2004-09-24	19686	207.95	17.16	225.11
8377	2004-09-11	3877	225.86	18.63	244.49
8378	2004-09-04	17103	171.51	14.15	185.66
8379	2004-09-17	2942	185.41	15.30	200.71
8380	2004-09-30	4496	174.31	14.38	188.69
8381	2004-09-20	15783	331.11	27.32	358.43
8382	2004-09-20	4671	206.74	17.06	223.80
8383	2004-09-15	8808	109.10	9.00	118.10
8384	2004-09-06	13789	353.33	29.15	382.48
8385	2004-09-26	13820	42.83	3.53	46.36
8386	2004-09-22	4344	126.91	10.47	137.38
8387	2004-09-23	17240	79.68	6.57	86.25
8388	2004-09-06	162	133.57	11.02	144.59
8389	2004-09-17	19705	111.05	9.16	120.21
8390	2004-09-02	1184	139.20	11.48	150.68
8391	2004-09-11	5960	372.37	30.72	403.09
8392	2004-09-27	8141	378.04	31.19	409.23
8393	2004-09-09	9892	11.30	0.93	12.23
8394	2004-09-17	8200	361.38	29.81	391.19
8395	2004-09-15	2872	167.72	13.84	181.56
8396	2004-09-24	18042	298.55	24.63	323.18
8397	2004-09-21	9047	170.42	14.06	184.48
8398	2004-09-17	17478	171.59	14.16	185.75
8399	2004-09-04	14700	45.38	3.74	49.12
8400	2004-09-16	8870	365.92	30.19	396.11
8401	2004-09-26	3027	356.88	29.44	386.32
8402	2004-09-09	16003	326.95	26.97	353.92
8403	2004-09-15	8051	46.35	3.82	50.17
8404	2004-09-03	12483	15.23	1.26	16.49
8405	2004-09-13	8559	69.49	5.73	75.22
8406	2004-09-17	3342	45.32	3.74	49.06
8407	2004-09-11	5585	229.17	18.91	248.08
8408	2004-09-04	4952	375.28	30.96	406.24
8409	2004-09-18	8599	300.23	24.77	325.00
8410	2004-09-05	19635	303.27	25.02	328.29
8411	2004-09-20	16891	320.78	26.46	347.24
8412	2004-09-10	8128	110.29	9.10	119.39
8413	2004-09-09	14591	2.59	0.21	2.80
8414	2004-09-28	12050	236.67	19.53	256.20
8415	2004-09-10	15877	201.63	16.63	218.26
8416	2004-09-26	2883	100.24	8.27	108.51
8417	2004-09-27	17725	38.02	3.14	41.16
8418	2004-09-05	12352	349.87	28.86	378.73
8419	2004-09-18	7560	380.89	31.42	412.31
8420	2004-09-19	17409	396.43	32.71	429.14
8421	2004-09-25	4528	129.15	10.65	139.80
8422	2004-09-09	12183	75.12	6.20	81.32
8423	2004-09-27	1298	382.36	31.54	413.90
8424	2004-09-15	13796	115.14	9.50	124.64
8425	2004-09-20	14768	91.11	7.52	98.63
8426	2004-09-28	19921	142.81	11.78	154.59
8427	2004-09-07	11435	29.39	2.42	31.81
8428	2004-09-29	10292	171.55	14.15	185.70
8429	2004-09-05	2350	18.21	1.50	19.71
8430	2004-09-11	3750	102.98	8.50	111.48
8431	2004-09-06	16372	296.84	24.49	321.33
8432	2004-09-29	13993	367.89	30.35	398.24
8433	2004-09-13	19796	134.52	11.10	145.62
8434	2004-09-05	3421	361.29	29.81	391.10
8435	2004-09-24	3364	212.50	17.53	230.03
8436	2004-09-06	8442	313.24	25.84	339.08
8437	2004-09-05	1924	49.15	4.05	53.20
8438	2004-09-03	17926	279.26	23.04	302.30
8439	2004-09-02	18770	309.50	25.53	335.03
8440	2004-09-04	16023	397.67	32.81	430.48
8441	2004-09-11	2870	190.20	15.69	205.89
8442	2004-09-23	19555	100.63	8.30	108.93
8443	2004-09-03	13169	350.04	28.88	378.92
8444	2004-09-19	512	236.93	19.55	256.48
8445	2004-09-30	10283	384.13	31.69	415.82
8446	2004-09-27	8430	137.77	11.37	149.14
8447	2004-09-10	2873	189.74	15.65	205.39
8448	2004-09-19	2485	298.26	24.61	322.87
8449	2004-09-05	4979	61.21	5.05	66.26
8450	2004-09-10	10524	293.26	24.19	317.45
8451	2004-09-18	3758	180.97	14.93	195.90
8452	2004-09-06	18616	77.33	6.38	83.71
8453	2004-09-15	2987	346.24	28.56	374.80
8454	2004-09-25	16950	109.56	9.04	118.60
8455	2004-09-08	18954	88.42	7.29	95.71
8456	2004-09-24	17387	31.31	2.58	33.89
8457	2004-09-04	11765	187.28	15.45	202.73
8458	2004-09-28	8327	204.38	16.86	221.24
8459	2004-09-20	6245	396.56	32.72	429.28
8460	2004-09-20	4701	371.48	30.65	402.13
8461	2004-09-18	13358	247.08	20.38	267.46
8462	2004-09-04	14828	46.40	3.83	50.23
8463	2004-09-30	19991	321.16	26.50	347.66
8464	2004-09-25	15090	253.77	20.94	274.71
8465	2004-09-11	13185	34.71	2.86	37.57
8466	2004-09-05	6238	202.10	16.67	218.77
8467	2004-09-06	3275	296.34	24.45	320.79
8468	2004-09-27	1922	254.13	20.97	275.10
8469	2004-09-06	8985	169.98	14.02	184.00
8470	2004-09-26	5432	239.41	19.75	259.16
8471	2004-09-29	9158	348.48	28.75	377.23
8472	2004-09-27	16137	344.74	28.44	373.18
8473	2004-09-18	9376	337.23	27.82	365.05
8474	2004-09-08	14269	221.53	18.28	239.81
8475	2004-09-27	17419	31.14	2.57	33.71
8476	2004-09-12	1567	131.53	10.85	142.38
8477	2004-09-07	13204	247.48	20.42	267.90
8478	2004-09-30	6408	345.64	28.52	374.16
8479	2004-09-30	19684	147.89	12.20	160.09
8480	2004-09-12	12105	185.43	15.30	200.73
8481	2004-09-12	19627	186.93	15.42	202.35
8482	2004-09-19	18724	34.18	2.82	37.00
8483	2004-09-02	19929	37.27	3.07	40.34
8484	2004-09-12	1482	325.99	26.89	352.88
8485	2004-09-16	10463	104.80	8.65	113.45
8486	2004-09-10	15272	283.60	23.40	307.00
8487	2004-09-11	5883	124.11	10.24	134.35
8488	2004-09-29	15371	138.98	11.47	150.45
8489	2004-09-07	11533	126.50	10.44	136.94
8490	2004-09-08	3240	250.44	20.66	271.10
8491	2004-09-06	19835	328.42	27.09	355.51
8492	2004-09-04	14232	175.99	14.52	190.51
8493	2004-09-21	4865	99.87	8.24	108.11
8494	2004-09-01	13283	47.64	3.93	51.57
8495	2004-09-18	12381	295.32	24.36	319.68
8496	2004-09-09	16955	177.16	14.62	191.78
8497	2004-09-12	19744	79.30	6.54	85.84
8498	2004-09-10	8098	145.07	11.97	157.04
8499	2004-09-13	5816	347.12	28.64	375.76
8500	2004-09-12	13834	133.38	11.00	144.38
8501	2004-09-23	7270	174.80	14.42	189.22
8502	2004-09-22	13504	124.04	10.23	134.27
8503	2004-09-16	18055	341.67	28.19	369.86
8504	2004-09-29	5046	27.48	2.27	29.75
8505	2004-09-06	18157	98.78	8.15	106.93
8506	2004-09-27	1558	156.09	12.88	168.97
8507	2004-09-22	7994	109.81	9.06	118.87
8508	2004-09-28	17985	289.44	23.88	313.32
8509	2004-09-28	15692	68.92	5.69	74.61
8510	2004-09-22	15293	263.28	21.72	285.00
8511	2004-09-14	15231	245.11	20.22	265.33
8512	2004-09-01	13396	42.78	3.53	46.31
8513	2004-09-24	18234	10.64	0.88	11.52
8514	2004-09-21	8370	364.91	30.11	395.02
8515	2004-09-07	4007	220.02	18.15	238.17
8516	2004-09-09	11787	10.40	0.86	11.26
8517	2004-09-27	2586	382.39	31.55	413.94
8518	2004-09-22	13046	291.28	24.03	315.31
8519	2004-09-04	5768	92.41	7.62	100.03
8520	2004-09-03	4703	214.05	17.66	231.71
8521	2004-09-13	10587	239.98	19.80	259.78
8522	2004-09-15	5913	228.56	18.86	247.42
8523	2004-09-14	18081	73.32	6.05	79.37
8524	2004-09-19	12997	38.76	3.20	41.96
8525	2004-09-13	7003	164.95	13.61	178.56
8526	2004-09-19	19311	107.44	8.86	116.30
8527	2004-09-07	15196	301.22	24.85	326.07
8528	2004-09-02	7790	270.02	22.28	292.30
8529	2004-09-27	14257	271.61	22.41	294.02
8530	2004-09-11	19388	362.99	29.95	392.94
8531	2004-09-20	9181	237.67	19.61	257.28
8532	2004-09-04	2574	201.90	16.66	218.56
8533	2004-09-07	6116	303.54	25.04	328.58
8534	2004-09-06	12348	179.43	14.80	194.23
8535	2004-09-14	10334	212.28	17.51	229.79
8536	2004-09-18	19792	388.59	32.06	420.65
8537	2004-09-25	4111	217.67	17.96	235.63
8538	2004-09-30	13768	368.50	30.40	398.90
8539	2004-09-19	6539	140.25	11.57	151.82
8540	2004-09-21	3305	374.96	30.93	405.89
8541	2004-09-18	7712	354.40	29.24	383.64
8542	2004-09-16	4015	5.12	0.42	5.54
8543	2004-09-27	8810	243.69	20.10	263.79
8544	2004-09-11	9804	124.79	10.30	135.09
8545	2004-09-12	11716	242.95	20.04	262.99
8546	2004-09-14	4903	395.67	32.64	428.31
8547	2004-09-16	16178	255.99	21.12	277.11
8548	2004-09-29	12155	229.38	18.92	248.30
8549	2004-09-03	19920	222.67	18.37	241.04
8550	2004-09-10	9033	362.20	29.88	392.08
8551	2004-09-11	5408	4.67	0.39	5.06
8552	2004-09-21	15612	131.91	10.88	142.79
8553	2004-09-29	6979	22.90	1.89	24.79
8554	2004-09-03	4007	386.91	31.92	418.83
8555	2004-09-04	18082	199.49	16.46	215.95
8556	2004-09-26	4596	146.03	12.05	158.08
8557	2004-09-23	417	174.57	14.40	188.97
8558	2004-09-04	4025	157.68	13.01	170.69
8559	2004-09-21	6113	250.30	20.65	270.95
8560	2004-09-19	18687	69.64	5.75	75.39
8561	2004-09-22	13913	194.57	16.05	210.62
8562	2004-09-28	14950	124.77	10.29	135.06
8563	2004-09-17	11148	191.49	15.80	207.29
8564	2004-09-29	5498	64.70	5.34	70.04
8565	2004-09-02	16764	207.24	17.10	224.34
8566	2004-09-07	2542	321.85	26.55	348.40
8567	2004-09-30	12164	14.42	1.19	15.61
8568	2004-09-07	3292	325.48	26.85	352.33
8569	2004-09-05	7145	266.07	21.95	288.02
8570	2004-09-09	19183	91.58	7.56	99.14
8571	2004-09-27	2336	289.79	23.91	313.70
8572	2004-09-17	9346	156.20	12.89	169.09
8573	2004-09-22	6616	58.91	4.86	63.77
8574	2004-09-26	5067	372.84	30.76	403.60
8575	2004-09-18	13590	173.39	14.30	187.69
8576	2004-09-08	7051	90.51	7.47	97.98
8577	2004-09-23	13668	365.36	30.14	395.50
8578	2004-09-04	9603	221.31	18.26	239.57
8579	2004-09-13	16097	172.87	14.26	187.13
8580	2004-09-11	8313	25.17	2.08	27.25
8581	2004-09-17	11820	325.54	26.86	352.40
8582	2004-09-16	8672	114.85	9.48	124.33
8583	2004-09-04	14254	171.48	14.15	185.63
8584	2004-09-12	4612	113.03	9.32	122.35
8585	2004-09-02	19221	61.70	5.09	66.79
8586	2004-09-06	7489	269.23	22.21	291.44
8587	2004-09-30	9344	231.31	19.08	250.39
8588	2004-09-09	18833	286.51	23.64	310.15
8589	2004-09-14	4397	187.31	15.45	202.76
8590	2004-09-07	5509	217.90	17.98	235.88
8591	2004-09-09	432	245.64	20.27	265.91
8592	2004-09-05	5056	82.76	6.83	89.59
8593	2004-09-17	16285	351.37	28.99	380.36
8594	2004-09-14	9022	325.94	26.89	352.83
8595	2004-09-11	7773	134.81	11.12	145.93
8596	2004-09-28	19385	348.26	28.73	376.99
8597	2004-09-29	19698	103.85	8.57	112.42
8598	2004-09-28	12774	77.66	6.41	84.07
8599	2004-09-04	11787	324.82	26.80	351.62
8600	2004-09-07	1343	204.70	16.89	221.59
8601	2004-09-10	6171	46.86	3.87	50.73
8602	2004-09-25	15908	328.71	27.12	355.83
8603	2004-09-09	2772	300.72	24.81	325.53
8604	2004-09-26	19199	150.58	12.42	163.00
8605	2004-09-06	15180	167.52	13.82	181.34
8606	2004-09-01	15463	136.32	11.25	147.57
8607	2004-09-21	15804	331.89	27.38	359.27
8608	2004-09-28	1111	170.93	14.10	185.03
8609	2004-09-27	12748	215.62	17.79	233.41
8610	2004-09-28	12770	199.11	16.43	215.54
8611	2004-09-23	17757	262.94	21.69	284.63
8612	2004-09-09	12143	359.50	29.66	389.16
8613	2004-09-09	7908	7.31	0.60	7.91
8614	2004-09-28	19432	262.57	21.66	284.23
8615	2004-09-15	15528	144.46	11.92	156.38
8616	2004-09-06	9532	74.56	6.15	80.71
8617	2004-09-09	2652	20.41	1.68	22.09
8618	2004-09-29	17892	270.34	22.30	292.64
8619	2004-09-06	4203	31.01	2.56	33.57
8620	2004-09-24	5393	320.76	26.46	347.22
8621	2004-09-06	9205	317.01	26.15	343.16
8622	2004-09-29	1697	186.33	15.37	201.70
8623	2004-09-19	12223	188.58	15.56	204.14
8624	2004-09-26	15601	317.98	26.23	344.21
8625	2004-09-18	16709	27.23	2.25	29.48
8626	2004-09-26	11657	395.09	32.59	427.68
8627	2004-09-20	6988	267.75	22.09	289.84
8628	2004-09-08	9059	231.14	19.07	250.21
8629	2004-09-29	999	395.37	32.62	427.99
8630	2004-09-02	11233	361.11	29.79	390.90
8631	2004-09-17	3325	262.09	21.62	283.71
8632	2004-09-18	9378	302.98	25.00	327.98
8633	2004-09-14	7803	378.68	31.24	409.92
8634	2004-09-05	2398	212.59	17.54	230.13
8635	2004-09-24	746	141.52	11.68	153.20
8636	2004-09-22	18125	303.80	25.06	328.86
8637	2004-09-21	5390	224.56	18.53	243.09
8638	2004-09-11	1854	122.98	10.15	133.13
8639	2004-09-12	8768	190.90	15.75	206.65
8640	2004-09-23	10399	205.98	16.99	222.97
8641	2004-09-22	12802	387.80	31.99	419.79
8642	2004-09-30	6417	161.00	13.28	174.28
8643	2004-09-15	5838	38.93	3.21	42.14
8644	2004-09-03	7680	336.58	27.77	364.35
8645	2004-09-04	4974	328.53	27.10	355.63
8646	2004-09-19	17655	97.44	8.04	105.48
8647	2004-09-17	3665	274.01	22.61	296.62
8648	2004-09-23	2689	316.06	26.07	342.13
8649	2004-09-26	8683	136.05	11.22	147.27
8650	2004-09-27	13881	9.02	0.74	9.76
8651	2004-09-21	15433	29.85	2.46	32.31
8652	2004-09-14	12275	57.31	4.73	62.04
8653	2004-09-19	5370	335.19	27.65	362.84
8654	2004-09-17	19662	290.45	23.96	314.41
8655	2004-09-20	16013	271.50	22.40	293.90
8656	2004-09-18	17721	237.54	19.60	257.14
8657	2004-09-04	9559	34.30	2.83	37.13
8658	2004-09-27	274	140.37	11.58	151.95
8659	2004-09-13	19297	317.70	26.21	343.91
8660	2004-09-12	5089	398.50	32.88	431.38
8661	2004-09-15	19320	196.07	16.18	212.25
8662	2004-09-05	810	98.99	8.17	107.16
8663	2004-09-26	7897	50.86	4.20	55.06
8664	2004-09-08	6078	211.02	17.41	228.43
8665	2004-09-12	9830	387.61	31.98	419.59
8666	2004-09-18	4744	20.70	1.71	22.41
8667	2004-09-15	2369	278.26	22.96	301.22
8668	2004-09-17	2956	18.19	1.50	19.69
8669	2004-09-07	17788	299.16	24.68	323.84
8670	2004-09-17	13231	16.85	1.39	18.24
8671	2004-09-06	1609	267.86	22.10	289.96
8672	2004-09-21	8871	109.01	8.99	118.00
8673	2004-09-21	15137	62.02	5.12	67.14
8674	2004-09-16	15515	238.22	19.65	257.87
8675	2004-09-05	948	177.22	14.62	191.84
8676	2004-09-24	17812	156.65	12.92	169.57
8677	2004-09-26	536	118.70	9.79	128.49
8678	2004-09-25	16547	125.24	10.33	135.57
8679	2004-09-26	19573	146.95	12.12	159.07
8680	2004-09-29	6990	359.96	29.70	389.66
8681	2004-09-05	16238	351.22	28.98	380.20
8682	2004-09-28	19592	47.63	3.93	51.56
8683	2004-09-20	18186	170.41	14.06	184.47
8684	2004-09-27	9902	97.97	8.08	106.05
8685	2004-09-23	3072	393.90	32.50	426.40
8686	2004-09-04	15044	337.43	27.84	365.27
8687	2004-09-25	4710	232.28	19.16	251.44
8688	2004-09-07	8848	167.63	13.83	181.46
8689	2004-09-21	6936	318.84	26.30	345.14
8690	2004-09-06	1334	384.35	31.71	416.06
8691	2004-09-06	3505	135.55	11.18	146.73
8692	2004-09-15	15606	151.33	12.48	163.81
8693	2004-09-30	9108	326.58	26.94	353.52
8694	2004-09-05	15195	217.25	17.92	235.17
8695	2004-09-23	8965	299.51	24.71	324.22
8696	2004-09-15	13233	217.10	17.91	235.01
8697	2004-09-24	9905	151.16	12.47	163.63
8698	2004-09-22	2816	48.49	4.00	52.49
8699	2004-09-26	1713	315.66	26.04	341.70
8700	2004-09-27	3973	322.05	26.57	348.62
8701	2004-09-27	1025	9.02	0.74	9.76
8702	2004-09-18	9796	276.27	22.79	299.06
8703	2004-09-16	1746	330.42	27.26	357.68
8704	2004-09-25	13246	32.67	2.70	35.37
8705	2004-09-04	17310	100.48	8.29	108.77
8706	2004-09-30	8690	112.48	9.28	121.76
8707	2004-09-19	1312	140.43	11.59	152.02
8708	2004-09-14	174	117.11	9.66	126.77
8709	2004-09-02	5050	153.67	12.68	166.35
8710	2004-09-27	16701	371.32	30.63	401.95
8711	2004-09-13	2649	282.69	23.32	306.01
8712	2004-09-06	5689	362.84	29.93	392.77
8713	2004-09-15	1667	161.93	13.36	175.29
8714	2004-09-11	2304	388.62	32.06	420.68
8715	2004-09-23	11185	269.08	22.20	291.28
8716	2004-09-14	1962	279.94	23.10	303.04
8717	2004-09-02	8172	244.52	20.17	264.69
8718	2004-09-25	1289	237.16	19.57	256.73
8719	2004-09-15	19437	361.67	29.84	391.51
8720	2004-09-12	4815	211.00	17.41	228.41
8721	2004-09-28	14529	334.86	27.63	362.49
8722	2004-09-08	15095	180.01	14.85	194.86
8723	2004-09-02	18183	10.57	0.87	11.44
8724	2004-09-27	1370	158.45	13.07	171.52
8725	2004-09-03	17777	286.25	23.62	309.87
8726	2004-09-18	17121	57.77	4.77	62.54
8727	2004-09-03	3860	207.26	17.10	224.36
8728	2004-09-06	15162	149.70	12.35	162.05
8729	2004-09-12	6576	392.05	32.34	424.39
8730	2004-09-07	5406	170.36	14.05	184.41
8731	2004-09-01	19008	146.56	12.09	158.65
8732	2004-09-01	1919	301.39	24.86	326.25
8733	2004-09-24	18013	258.67	21.34	280.01
8734	2004-09-19	19967	211.31	17.43	228.74
8735	2004-09-10	19447	352.95	29.12	382.07
8736	2004-09-18	13100	140.06	11.55	151.61
8737	2004-09-18	15187	31.69	2.61	34.30
8738	2004-09-19	17148	237.91	19.63	257.54
8739	2004-09-27	11359	166.95	13.77	180.72
8740	2004-09-28	8252	389.91	32.17	422.08
8741	2004-09-26	2258	208.94	17.24	226.18
8742	2004-09-11	7845	221.32	18.26	239.58
8743	2004-09-04	9911	351.18	28.97	380.15
8744	2004-09-01	18778	234.42	19.34	253.76
8745	2004-09-19	3470	388.61	32.06	420.67
8746	2004-09-08	14555	271.75	22.42	294.17
8747	2004-09-09	14692	391.78	32.32	424.10
8748	2004-09-03	19698	15.98	1.32	17.30
8749	2004-09-17	4374	68.50	5.65	74.15
8750	2004-09-27	14315	68.37	5.64	74.01
8751	2004-09-07	1052	83.75	6.91	90.66
8752	2004-09-12	10131	367.85	30.35	398.20
8753	2004-09-16	19040	296.06	24.42	320.48
8754	2004-09-19	5716	172.81	14.26	187.07
8755	2004-09-08	291	176.87	14.59	191.46
8756	2004-09-17	6604	190.64	15.73	206.37
8757	2004-09-09	839	251.10	20.72	271.82
8758	2004-09-19	19642	77.92	6.43	84.35
8759	2004-09-24	4034	98.45	8.12	106.57
8760	2004-09-15	12278	233.72	19.28	253.00
8761	2004-09-09	18165	180.19	14.87	195.06
8762	2004-09-30	6242	312.43	25.78	338.21
8763	2004-09-03	19063	368.66	30.41	399.07
8764	2004-09-27	969	397.09	32.76	429.85
8765	2004-09-28	18412	293.17	24.19	317.36
8766	2004-09-07	6923	345.50	28.50	374.00
8767	2004-09-20	9111	222.05	18.32	240.37
8768	2004-09-03	3953	313.22	25.84	339.06
8769	2004-09-29	15977	148.70	12.27	160.97
8770	2004-09-02	14500	246.38	20.33	266.71
8771	2004-09-17	7361	219.82	18.14	237.96
8772	2004-09-27	1375	132.47	10.93	143.40
8773	2004-09-02	9315	304.29	25.10	329.39
8774	2004-09-05	19927	108.99	8.99	117.98
8775	2004-09-04	7910	170.36	14.05	184.41
8776	2004-09-30	6317	36.70	3.03	39.73
8777	2004-09-26	18856	125.10	10.32	135.42
8778	2004-09-23	9086	26.42	2.18	28.60
8779	2004-09-29	306	202.30	16.69	218.99
8780	2004-09-09	9136	237.64	19.61	257.25
8781	2004-09-14	19698	252.88	20.86	273.74
8782	2004-09-30	18791	32.72	2.70	35.42
8783	2004-09-11	3322	392.48	32.38	424.86
8784	2004-09-05	19294	158.58	13.08	171.66
8785	2004-09-24	8131	18.82	1.55	20.37
8786	2004-09-09	17676	281.43	23.22	304.65
8787	2004-09-04	7198	85.31	7.04	92.35
8788	2004-09-02	5351	45.45	3.75	49.20
8789	2004-09-20	3257	23.46	1.94	25.40
8790	2004-09-17	9008	11.17	0.92	12.09
8791	2004-09-09	5422	81.77	6.75	88.52
8792	2004-09-02	9398	262.16	21.63	283.79
8793	2004-09-29	13210	166.58	13.74	180.32
8794	2004-09-25	1019	144.64	11.93	156.57
8795	2004-09-10	11792	137.78	11.37	149.15
8796	2004-09-13	14787	122.70	10.12	132.82
8797	2004-09-04	16067	254.95	21.03	275.98
8798	2004-09-02	12979	256.86	21.19	278.05
8799	2004-09-10	17656	142.04	11.72	153.76
8800	2004-09-22	18744	153.43	12.66	166.09
8801	2004-09-23	15827	94.41	7.79	102.20
8802	2004-09-13	2036	352.00	29.04	381.04
8803	2004-09-25	6869	201.86	16.65	218.51
8804	2004-09-09	14331	154.16	12.72	166.88
8805	2004-09-29	1694	362.95	29.94	392.89
8806	2004-09-04	5757	306.66	25.30	331.96
8807	2004-09-12	1697	141.40	11.67	153.07
8808	2004-09-27	7834	225.58	18.61	244.19
8809	2004-09-19	12615	38.73	3.20	41.93
8810	2004-09-12	11937	397.13	32.76	429.89
8811	2004-09-11	6192	370.54	30.57	401.11
8812	2004-09-08	12526	132.58	10.94	143.52
8813	2004-09-11	8733	247.05	20.38	267.43
8814	2004-09-07	2595	76.17	6.28	82.45
8815	2004-09-27	2288	366.53	30.24	396.77
8816	2004-09-17	19837	163.98	13.53	177.51
8817	2004-09-04	16921	13.37	1.10	14.47
8818	2004-09-20	18974	12.18	1.00	13.18
8819	2004-09-18	8838	381.40	31.47	412.87
8820	2004-09-17	4235	300.20	24.77	324.97
8821	2004-09-30	18208	196.23	16.19	212.42
8822	2004-09-12	16409	315.96	26.07	342.03
8823	2004-09-20	18193	97.21	8.02	105.23
8824	2004-09-26	10567	39.40	3.25	42.65
8825	2004-09-24	14152	334.57	27.60	362.17
8826	2004-09-22	1284	47.91	3.95	51.86
8827	2004-09-07	10228	54.68	4.51	59.19
8828	2004-09-27	17136	129.47	10.68	140.15
8829	2004-09-19	5653	94.69	7.81	102.50
8830	2004-09-21	2185	158.23	13.05	171.28
8831	2004-09-26	13221	262.70	21.67	284.37
8832	2004-09-09	15339	301.30	24.86	326.16
8833	2004-09-29	17400	67.40	5.56	72.96
8834	2004-09-16	13869	27.00	2.23	29.23
8835	2004-09-30	14034	323.99	26.73	350.72
8836	2004-09-27	7331	301.99	24.91	326.90
8837	2004-09-15	13784	367.50	30.32	397.82
8838	2004-09-04	19839	221.02	18.23	239.25
8839	2004-09-03	13973	254.83	21.02	275.85
8840	2004-09-06	19777	289.79	23.91	313.70
8841	2004-09-15	7043	19.81	1.63	21.44
8842	2004-09-23	15448	110.22	9.09	119.31
8843	2004-09-14	1613	88.61	7.31	95.92
8844	2004-09-14	13051	235.18	19.40	254.58
8845	2004-09-09	17392	33.66	2.78	36.44
8846	2004-09-13	17644	129.06	10.65	139.71
8847	2004-09-21	18949	140.76	11.61	152.37
8848	2004-09-09	2483	256.81	21.19	278.00
8849	2004-09-11	2128	61.79	5.10	66.89
8850	2004-09-06	11238	68.24	5.63	73.87
8851	2004-09-01	2849	41.94	3.46	45.40
8852	2004-09-25	1831	376.19	31.04	407.23
8853	2004-09-19	8865	367.17	30.29	397.46
8854	2004-09-02	6738	67.80	5.59	73.39
8855	2004-09-28	5191	202.01	16.67	218.68
8856	2004-09-22	12967	29.89	2.47	32.36
8857	2004-09-09	4237	225.21	18.58	243.79
8858	2004-09-24	15296	242.49	20.01	262.50
8859	2004-09-04	14484	163.62	13.50	177.12
8860	2004-09-12	17106	257.01	21.20	278.21
8861	2004-09-23	8027	23.70	1.96	25.66
8862	2004-09-28	8220	57.62	4.75	62.37
8863	2004-09-03	11978	86.85	7.17	94.02
8864	2004-09-07	183	348.50	28.75	377.25
8865	2004-09-28	11604	193.12	15.93	209.05
8866	2004-09-12	18749	119.11	9.83	128.94
8867	2004-09-09	6521	268.93	22.19	291.12
8868	2004-09-19	18525	10.10	0.83	10.93
8869	2004-09-28	19940	218.25	18.01	236.26
8870	2004-09-24	9858	224.59	18.53	243.12
8871	2004-09-24	3027	230.82	19.04	249.86
8872	2004-09-17	18360	354.95	29.28	384.23
8873	2004-09-02	4255	284.99	23.51	308.50
8874	2004-09-10	18678	86.24	7.11	93.35
8875	2004-09-22	11896	393.92	32.50	426.42
8876	2004-09-14	6242	128.04	10.56	138.60
8877	2004-09-07	4959	305.49	25.20	330.69
8878	2004-09-09	6777	226.21	18.66	244.87
8879	2004-09-16	17069	152.09	12.55	164.64
8880	2004-09-18	12774	330.80	27.29	358.09
8881	2004-09-06	17522	4.97	0.41	5.38
8882	2004-09-14	5399	136.42	11.25	147.67
8883	2004-09-12	15426	272.17	22.45	294.62
8884	2004-09-19	9050	80.22	6.62	86.84
8885	2004-09-17	6973	28.36	2.34	30.70
8886	2004-09-23	1253	57.36	4.73	62.09
8887	2004-09-30	9097	78.01	6.44	84.45
8888	2004-09-21	9160	295.91	24.41	320.32
8889	2004-09-07	19754	247.90	20.45	268.35
8890	2004-09-22	197	107.31	8.85	116.16
8891	2004-09-28	19077	214.77	17.72	232.49
8892	2004-09-08	16858	260.60	21.50	282.10
8893	2004-09-27	5323	330.20	27.24	357.44
8894	2004-09-18	6881	362.37	29.90	392.27
8895	2004-09-21	1600	280.86	23.17	304.03
8896	2004-09-06	16256	268.42	22.14	290.56
8897	2004-09-21	15768	212.17	17.50	229.67
8898	2004-09-15	12612	324.39	26.76	351.15
8899	2004-09-12	8327	41.46	3.42	44.88
8900	2004-09-21	9221	144.40	11.91	156.31
8901	2004-09-26	12996	131.75	10.87	142.62
8902	2004-09-15	5286	323.80	26.71	350.51
8903	2004-09-22	14593	261.30	21.56	282.86
8904	2004-09-27	16817	334.34	27.58	361.92
8905	2004-09-13	3363	241.42	19.92	261.34
8906	2004-09-03	8885	41.21	3.40	44.61
8907	2004-09-11	466	140.15	11.56	151.71
8908	2004-09-21	6704	41.61	3.43	45.04
8909	2004-09-05	18230	32.50	2.68	35.18
8910	2004-09-21	13748	226.33	18.67	245.00
8911	2004-09-12	909	271.07	22.36	293.43
8912	2004-09-29	15094	173.60	14.32	187.92
8913	2004-09-21	13850	238.73	19.70	258.43
8914	2004-09-18	8861	161.84	13.35	175.19
8915	2004-09-04	2499	331.70	27.37	359.07
8916	2004-09-24	13225	327.54	27.02	354.56
8917	2004-09-29	14102	384.29	31.70	415.99
8918	2004-09-11	18268	82.58	6.81	89.39
8919	2004-09-17	11321	324.60	26.78	351.38
8920	2004-09-30	9218	229.26	18.91	248.17
8921	2004-09-04	1882	273.61	22.57	296.18
8922	2004-09-11	8496	134.17	11.07	145.24
8923	2004-09-26	6635	163.74	13.51	177.25
8924	2004-09-16	267	3.91	0.32	4.23
8925	2004-09-18	17672	126.53	10.44	136.97
8926	2004-09-17	1284	191.03	15.76	206.79
8927	2004-09-27	7639	272.71	22.50	295.21
8928	2004-09-04	5308	182.48	15.05	197.53
8929	2004-09-19	3358	178.31	14.71	193.02
8930	2004-09-05	7003	114.33	9.43	123.76
8931	2004-09-04	4018	230.76	19.04	249.80
8932	2004-09-29	13433	193.08	15.93	209.01
8933	2004-09-15	18137	67.18	5.54	72.72
8934	2004-09-04	15125	119.55	9.86	129.41
8935	2004-09-20	10872	160.99	13.28	174.27
8936	2004-09-13	6941	83.40	6.88	90.28
8937	2004-09-18	18690	63.16	5.21	68.37
8938	2004-09-05	17600	117.04	9.66	126.70
8939	2004-09-06	2994	48.84	4.03	52.87
8940	2004-09-03	10425	132.42	10.92	143.34
8941	2004-09-02	7105	249.62	20.59	270.21
8942	2004-09-03	7083	396.99	32.75	429.74
8943	2004-09-29	3511	318.12	26.24	344.36
8944	2004-09-14	9154	389.30	32.12	421.42
8945	2004-09-22	6337	323.70	26.71	350.41
8946	2004-09-09	19982	195.96	16.17	212.13
8947	2004-09-06	13590	197.67	16.31	213.98
8948	2004-09-11	18375	138.64	11.44	150.08
8949	2004-09-07	10657	109.00	8.99	117.99
8950	2004-09-17	447	303.76	25.06	328.82
8951	2004-09-08	12348	358.96	29.61	388.57
8952	2004-09-25	5662	295.39	24.37	319.76
8953	2004-09-09	8536	137.51	11.34	148.85
8954	2004-09-24	3032	81.44	6.72	88.16
8955	2004-09-27	10024	280.07	23.11	303.18
8956	2004-09-29	7573	17.32	1.43	18.75
8957	2004-09-22	16488	363.85	30.02	393.87
8958	2004-09-03	15826	370.98	30.61	401.59
8959	2004-09-29	10179	197.72	16.31	214.03
8960	2004-09-10	17260	297.52	24.55	322.07
8961	2004-09-11	4672	80.11	6.61	86.72
8962	2004-09-13	10124	66.99	5.53	72.52
8963	2004-09-29	17798	241.41	19.92	261.33
8964	2004-09-19	10120	377.94	31.18	409.12
8965	2004-09-20	13331	68.90	5.68	74.58
8966	2004-09-26	16343	267.35	22.06	289.41
8967	2004-09-27	14319	142.29	11.74	154.03
8968	2004-09-12	1134	290.61	23.98	314.59
8969	2004-09-19	10718	155.12	12.80	167.92
8970	2004-09-01	13864	283.73	23.41	307.14
8971	2004-09-10	14206	387.05	31.93	418.98
8972	2004-09-27	17102	213.06	17.58	230.64
8973	2004-09-21	17241	19.37	1.60	20.97
8974	2004-09-20	11807	144.00	11.88	155.88
8975	2004-09-11	6715	181.90	15.01	196.91
8976	2004-09-20	16073	0.39	0.03	0.42
8977	2004-09-01	5132	320.86	26.47	347.33
8978	2004-09-06	8765	344.21	28.40	372.61
8979	2004-09-24	8129	392.19	32.36	424.55
8980	2004-09-21	14562	198.67	16.39	215.06
8981	2004-09-24	17183	254.32	20.98	275.30
8982	2004-09-07	4491	232.32	19.17	251.49
8983	2004-09-26	2115	72.42	5.97	78.39
8984	2004-09-03	14901	61.51	5.07	66.58
8985	2004-09-21	10717	217.69	17.96	235.65
8986	2004-09-20	13186	70.67	5.83	76.50
8987	2004-09-08	489	196.85	16.24	213.09
8988	2004-09-05	10634	310.07	25.58	335.65
8989	2004-09-17	2555	240.59	19.85	260.44
8990	2004-09-04	17271	74.69	6.16	80.85
8991	2004-09-26	18341	28.13	2.32	30.45
8992	2004-09-22	6300	76.01	6.27	82.28
8993	2004-09-07	3185	305.13	25.17	330.30
8994	2004-09-10	4106	76.39	6.30	82.69
8995	2004-09-09	15069	345.42	28.50	373.92
8996	2004-09-10	5397	313.58	25.87	339.45
8997	2004-09-01	15670	52.97	4.37	57.34
8998	2004-09-11	6594	113.52	9.37	122.89
8999	2004-09-19	10918	3.96	0.33	4.29
9000	2004-09-15	10251	318.68	26.29	344.97
9001	2004-10-24	1490	244.69	20.19	264.88
9002	2004-10-22	10911	226.02	18.65	244.67
9003	2004-10-26	4550	77.89	6.43	84.32
9004	2004-10-22	378	195.62	16.14	211.76
9005	2004-10-04	12926	301.85	24.90	326.75
9006	2004-10-24	15463	388.59	32.06	420.65
9007	2004-10-17	3868	363.72	30.01	393.73
9008	2004-10-04	10228	130.18	10.74	140.92
9009	2004-10-18	6617	35.98	2.97	38.95
9010	2004-10-08	18541	90.17	7.44	97.61
9011	2004-10-26	12372	267.90	22.10	290.00
9012	2004-10-04	12570	266.71	22.00	288.71
9013	2004-10-09	10644	163.63	13.50	177.13
9014	2004-10-31	6421	112.48	9.28	121.76
9015	2004-10-08	13605	308.82	25.48	334.30
9016	2004-10-17	3957	19.09	1.57	20.66
9017	2004-10-05	8055	219.18	18.08	237.26
9018	2004-10-27	19909	198.69	16.39	215.08
9019	2004-10-04	9043	221.69	18.29	239.98
9020	2004-10-15	18711	296.44	24.46	320.90
9021	2004-10-22	10944	239.16	19.73	258.89
9022	2004-10-07	7557	159.61	13.17	172.78
9023	2004-10-12	1568	257.66	21.26	278.92
9024	2004-10-14	5926	235.20	19.40	254.60
9025	2004-10-26	451	343.21	28.31	371.52
9026	2004-10-17	14985	321.44	26.52	347.96
9027	2004-10-13	15108	324.11	26.74	350.85
9028	2004-10-28	5617	156.40	12.90	169.30
9029	2004-10-26	4945	71.79	5.92	77.71
9030	2004-10-24	12394	270.90	22.35	293.25
9031	2004-10-25	5247	98.53	8.13	106.66
9032	2004-10-04	1427	385.31	31.79	417.10
9033	2004-10-21	17854	131.11	10.82	141.93
9034	2004-10-26	9026	105.90	8.74	114.64
9035	2004-10-30	19980	8.64	0.71	9.35
9036	2004-10-27	1270	98.64	8.14	106.78
9037	2004-10-03	11676	242.82	20.03	262.85
9038	2004-10-30	6507	241.29	19.91	261.20
9039	2004-10-30	12584	112.87	9.31	122.18
9040	2004-10-18	844	351.07	28.96	380.03
9041	2004-10-21	17816	167.33	13.80	181.13
9042	2004-10-07	16070	90.56	7.47	98.03
9043	2004-10-31	6491	103.60	8.55	112.15
9044	2004-10-04	1205	88.47	7.30	95.77
9045	2004-10-22	6095	309.55	25.54	335.09
9046	2004-10-04	5961	350.72	28.93	379.65
9047	2004-10-13	1634	82.52	6.81	89.33
9048	2004-10-20	16139	326.70	26.95	353.65
9049	2004-10-05	4578	349.25	28.81	378.06
9050	2004-10-19	16997	160.49	13.24	173.73
9051	2004-10-08	3744	72.97	6.02	78.99
9052	2004-10-19	15086	70.61	5.83	76.44
9053	2004-10-28	11084	60.26	4.97	65.23
9054	2004-10-23	2064	76.35	6.30	82.65
9055	2004-10-17	11570	43.80	3.61	47.41
9056	2004-10-04	13502	121.46	10.02	131.48
9057	2004-10-12	13159	362.36	29.89	392.25
9058	2004-10-03	4765	362.42	29.90	392.32
9059	2004-10-14	1158	2.81	0.23	3.04
9060	2004-10-25	13219	27.38	2.26	29.64
9061	2004-10-29	11036	188.84	15.58	204.42
9062	2004-10-21	9526	29.92	2.47	32.39
9063	2004-10-30	17453	250.83	20.69	271.52
9064	2004-10-09	5800	286.42	23.63	310.05
9065	2004-10-14	7614	231.68	19.11	250.79
9066	2004-10-20	17231	249.10	20.55	269.65
9067	2004-10-31	13283	348.42	28.74	377.16
9068	2004-10-14	2553	144.39	11.91	156.30
9069	2004-10-15	6458	228.71	18.87	247.58
9070	2004-10-09	11656	282.92	23.34	306.26
9071	2004-10-15	2008	79.72	6.58	86.30
9072	2004-10-26	9009	393.80	32.49	426.29
9073	2004-10-08	4813	338.07	27.89	365.96
9074	2004-10-23	12847	231.45	19.09	250.54
9075	2004-10-30	7471	55.79	4.60	60.39
9076	2004-10-11	7986	244.47	20.17	264.64
9077	2004-10-21	6	323.30	26.67	349.97
9078	2004-10-02	2380	329.33	27.17	356.50
9079	2004-10-17	2167	302.39	24.95	327.34
9080	2004-10-19	6594	196.24	16.19	212.43
9081	2004-10-29	13671	26.57	2.19	28.76
9082	2004-10-24	9684	29.62	2.44	32.06
9083	2004-10-25	15502	33.68	2.78	36.46
9084	2004-10-16	13373	233.66	19.28	252.94
9085	2004-10-14	7866	214.46	17.69	232.15
9086	2004-10-22	2200	162.87	13.44	176.31
9087	2004-10-16	13204	87.49	7.22	94.71
9088	2004-10-21	7429	30.83	2.54	33.37
9089	2004-10-07	5732	386.73	31.91	418.64
9090	2004-10-03	15111	102.41	8.45	110.86
9091	2004-10-10	13529	30.81	2.54	33.35
9092	2004-10-28	18747	169.30	13.97	183.27
9093	2004-10-04	2461	150.07	12.38	162.45
9094	2004-10-11	15240	42.66	3.52	46.18
9095	2004-10-25	8122	301.92	24.91	326.83
9096	2004-10-22	19266	155.84	12.86	168.70
9097	2004-10-14	4351	264.02	21.78	285.80
9098	2004-10-10	18355	155.61	12.84	168.45
9099	2004-10-20	11631	205.38	16.94	222.32
9100	2004-10-28	11793	107.71	8.89	116.60
9101	2004-10-23	16014	235.79	19.45	255.24
9102	2004-10-27	11792	91.62	7.56	99.18
9103	2004-10-30	558	156.08	12.88	168.96
9104	2004-10-04	3059	399.42	32.95	432.37
9105	2004-10-24	7037	207.85	17.15	225.00
9106	2004-10-04	5431	23.80	1.96	25.76
9107	2004-10-26	9728	291.08	24.01	315.09
9108	2004-10-27	4366	139.36	11.50	150.86
9109	2004-10-03	13368	244.21	20.15	264.36
9110	2004-10-24	6600	225.79	18.63	244.42
9111	2004-10-18	17386	74.00	6.11	80.11
9112	2004-10-27	1693	322.06	26.57	348.63
9113	2004-10-07	16235	94.43	7.79	102.22
9114	2004-10-06	11857	15.07	1.24	16.31
9115	2004-10-25	17068	60.14	4.96	65.10
9116	2004-10-26	11461	279.46	23.06	302.52
9117	2004-10-13	6658	213.61	17.62	231.23
9118	2004-10-24	14872	291.74	24.07	315.81
9119	2004-10-28	19172	257.89	21.28	279.17
9120	2004-10-13	17439	346.19	28.56	374.75
9121	2004-10-11	7542	155.04	12.79	167.83
9122	2004-10-18	15588	56.95	4.70	61.65
9123	2004-10-27	11220	185.58	15.31	200.89
9124	2004-10-24	9385	390.24	32.19	422.43
9125	2004-10-18	8151	11.52	0.95	12.47
9126	2004-10-19	571	133.16	10.99	144.15
9127	2004-10-14	3800	231.41	19.09	250.50
9128	2004-10-13	6193	80.58	6.65	87.23
9129	2004-10-14	7252	184.96	15.26	200.22
9130	2004-10-18	6278	206.88	17.07	223.95
9131	2004-10-29	6158	381.88	31.51	413.39
9132	2004-10-11	880	28.06	2.31	30.37
9133	2004-10-30	13038	238.67	19.69	258.36
9134	2004-10-15	1575	263.22	21.72	284.94
9135	2004-10-29	8210	233.22	19.24	252.46
9136	2004-10-17	16976	327.61	27.03	354.64
9137	2004-10-30	8844	216.09	17.83	233.92
9138	2004-10-15	19211	151.68	12.51	164.19
9139	2004-10-27	9341	20.49	1.69	22.18
9140	2004-10-10	13985	88.03	7.26	95.29
9141	2004-10-31	16310	212.43	17.53	229.96
9142	2004-10-24	946	324.98	26.81	351.79
9143	2004-10-25	12946	202.30	16.69	218.99
9144	2004-10-19	3131	34.58	2.85	37.43
9145	2004-10-11	5737	121.77	10.05	131.82
9146	2004-10-27	19311	291.29	24.03	315.32
9147	2004-10-19	2235	262.36	21.64	284.00
9148	2004-10-12	18023	159.56	13.16	172.72
9149	2004-10-26	16445	312.49	25.78	338.27
9150	2004-10-18	8835	131.08	10.81	141.89
9151	2004-10-03	8702	64.10	5.29	69.39
9152	2004-10-01	5666	325.14	26.82	351.96
9153	2004-10-02	2778	131.60	10.86	142.46
9154	2004-10-16	8846	283.21	23.36	306.57
9155	2004-10-31	2880	312.66	25.79	338.45
9156	2004-10-26	4491	168.04	13.86	181.90
9157	2004-10-09	7611	327.91	27.05	354.96
9158	2004-10-08	924	369.71	30.50	400.21
9159	2004-10-03	2835	359.57	29.66	389.23
9160	2004-10-02	16077	170.03	14.03	184.06
9161	2004-10-29	18545	12.30	1.01	13.31
9162	2004-10-31	8097	99.22	8.19	107.41
9163	2004-10-31	16753	167.19	13.79	180.98
9164	2004-10-27	11225	357.10	29.46	386.56
9165	2004-10-20	13936	47.69	3.93	51.62
9166	2004-10-04	5769	257.87	21.27	279.14
9167	2004-10-11	10831	186.60	15.39	201.99
9168	2004-10-26	1276	178.12	14.69	192.81
9169	2004-10-23	3220	393.59	32.47	426.06
9170	2004-10-05	1728	278.96	23.01	301.97
9171	2004-10-01	16324	268.36	22.14	290.50
9172	2004-10-19	1656	207.53	17.12	224.65
9173	2004-10-25	17938	336.96	27.80	364.76
9174	2004-10-22	17874	23.43	1.93	25.36
9175	2004-10-07	2293	224.46	18.52	242.98
9176	2004-10-23	16493	76.52	6.31	82.83
9177	2004-10-31	12003	84.25	6.95	91.20
9178	2004-10-11	4020	276.15	22.78	298.93
9179	2004-10-14	17625	73.51	6.06	79.57
9180	2004-10-06	260	243.94	20.13	264.07
9181	2004-10-27	9033	87.37	7.21	94.58
9182	2004-10-30	9396	232.73	19.20	251.93
9183	2004-10-16	9651	292.73	24.15	316.88
9184	2004-10-28	14269	185.26	15.28	200.54
9185	2004-10-16	15058	120.49	9.94	130.43
9186	2004-10-04	5142	188.36	15.54	203.90
9187	2004-10-24	201	296.84	24.49	321.33
9188	2004-10-24	10019	282.15	23.28	305.43
9189	2004-10-14	5314	311.98	25.74	337.72
9190	2004-10-14	1147	168.69	13.92	182.61
9191	2004-10-03	4759	260.01	21.45	281.46
9192	2004-10-19	14946	75.48	6.23	81.71
9193	2004-10-26	15195	126.19	10.41	136.60
9194	2004-10-04	8832	24.51	2.02	26.53
9195	2004-10-31	1870	203.42	16.78	220.20
9196	2004-10-08	2642	100.89	8.32	109.21
9197	2004-10-17	13152	296.69	24.48	321.17
9198	2004-10-27	15004	160.25	13.22	173.47
9199	2004-10-29	3147	164.07	13.54	177.61
9200	2004-10-27	864	46.72	3.85	50.57
9201	2004-10-11	6342	82.73	6.83	89.56
9202	2004-10-25	5697	264.88	21.85	286.73
9203	2004-10-21	13417	162.23	13.38	175.61
9204	2004-10-24	11806	20.01	1.65	21.66
9205	2004-10-27	7313	260.95	21.53	282.48
9206	2004-10-07	10423	382.24	31.53	413.77
9207	2004-10-02	14228	105.32	8.69	114.01
9208	2004-10-05	13356	364.25	30.05	394.30
9209	2004-10-05	1831	226.37	18.68	245.05
9210	2004-10-30	12428	237.47	19.59	257.06
9211	2004-10-15	5083	284.40	23.46	307.86
9212	2004-10-12	17760	278.79	23.00	301.79
9213	2004-10-04	17198	330.30	27.25	357.55
9214	2004-10-01	18614	11.81	0.97	12.78
9215	2004-10-13	18270	238.79	19.70	258.49
9216	2004-10-08	9520	229.80	18.96	248.76
9217	2004-10-26	3215	397.36	32.78	430.14
9218	2004-10-08	4880	218.15	18.00	236.15
9219	2004-10-18	12199	265.16	21.88	287.04
9220	2004-10-03	18802	109.12	9.00	118.12
9221	2004-10-11	8129	362.85	29.94	392.79
9222	2004-10-30	1369	251.42	20.74	272.16
9223	2004-10-02	12824	354.61	29.26	383.87
9224	2004-10-17	581	182.04	15.02	197.06
9225	2004-10-10	3456	265.52	21.91	287.43
9226	2004-10-31	9494	281.45	23.22	304.67
9227	2004-10-14	14275	314.94	25.98	340.92
9228	2004-10-26	6771	196.24	16.19	212.43
9229	2004-10-21	12557	279.57	23.06	302.63
9230	2004-10-01	3534	237.09	19.56	256.65
9231	2004-10-23	17517	241.97	19.96	261.93
9232	2004-10-13	19735	392.84	32.41	425.25
9233	2004-10-23	2743	267.56	22.07	289.63
9234	2004-10-10	16911	155.14	12.80	167.94
9235	2004-10-31	2637	135.03	11.14	146.17
9236	2004-10-24	16444	181.77	15.00	196.77
9237	2004-10-02	5699	110.02	9.08	119.10
9238	2004-10-21	4425	344.39	28.41	372.80
9239	2004-10-08	11591	277.47	22.89	300.36
9240	2004-10-21	2159	162.72	13.42	176.14
9241	2004-10-29	3476	66.32	5.47	71.79
9242	2004-10-17	17009	331.25	27.33	358.58
9243	2004-10-06	9771	116.32	9.60	125.92
9244	2004-10-29	5497	111.76	9.22	120.98
9245	2004-10-18	18603	244.73	20.19	264.92
9246	2004-10-10	17372	180.47	14.89	195.36
9247	2004-10-30	14669	63.13	5.21	68.34
9248	2004-10-09	19217	288.74	23.82	312.56
9249	2004-10-04	11514	45.35	3.74	49.09
9250	2004-10-24	11292	103.29	8.52	111.81
9251	2004-10-04	2945	30.02	2.48	32.50
9252	2004-10-23	2125	208.71	17.22	225.93
9253	2004-10-25	3718	214.42	17.69	232.11
9254	2004-10-12	16901	45.10	3.72	48.82
9255	2004-10-20	18842	77.50	6.39	83.89
9256	2004-10-28	9641	187.48	15.47	202.95
9257	2004-10-15	18848	313.74	25.88	339.62
9258	2004-10-23	18505	185.74	15.32	201.06
9259	2004-10-21	16524	356.26	29.39	385.65
9260	2004-10-23	12643	337.98	27.88	365.86
9261	2004-10-09	10495	342.52	28.26	370.78
9262	2004-10-05	15160	324.62	26.78	351.40
9263	2004-10-01	10518	71.37	5.89	77.26
9264	2004-10-15	2307	19.37	1.60	20.97
9265	2004-10-22	15679	69.15	5.70	74.85
9266	2004-10-14	13703	112.38	9.27	121.65
9267	2004-10-13	1705	221.30	18.26	239.56
9268	2004-10-25	15668	55.79	4.60	60.39
9269	2004-10-22	7178	41.25	3.40	44.65
9270	2004-10-30	2208	87.83	7.25	95.08
9271	2004-10-14	14173	210.92	17.40	228.32
9272	2004-10-14	263	30.19	2.49	32.68
9273	2004-10-13	17606	219.74	18.13	237.87
9274	2004-10-09	15379	352.56	29.09	381.65
9275	2004-10-21	2743	235.13	19.40	254.53
9276	2004-10-14	10345	271.93	22.43	294.36
9277	2004-10-26	7395	269.86	22.26	292.12
9278	2004-10-25	10928	72.92	6.02	78.94
9279	2004-10-28	1709	57.39	4.73	62.12
9280	2004-10-15	17350	241.58	19.93	261.51
9281	2004-10-12	13986	25.12	2.07	27.19
9282	2004-10-07	10165	138.48	11.42	149.90
9283	2004-10-14	5955	162.66	13.42	176.08
9284	2004-10-30	5222	110.41	9.11	119.52
9285	2004-10-24	14009	298.39	24.62	323.01
9286	2004-10-05	1497	394.99	32.59	427.58
9287	2004-10-12	15277	60.61	5.00	65.61
9288	2004-10-11	5704	244.33	20.16	264.49
9289	2004-10-18	18147	15.74	1.30	17.04
9290	2004-10-31	12624	374.11	30.86	404.97
9291	2004-10-16	19645	79.32	6.54	85.86
9292	2004-10-08	7681	82.70	6.82	89.52
9293	2004-10-16	10457	80.01	6.60	86.61
9294	2004-10-25	11325	155.93	12.86	168.79
9295	2004-10-13	4407	221.71	18.29	240.00
9296	2004-10-02	973	210.05	17.33	227.38
9297	2004-10-10	6369	385.76	31.83	417.59
9298	2004-10-05	7729	102.40	8.45	110.85
9299	2004-10-10	15911	282.24	23.28	305.52
9300	2004-10-19	6811	80.88	6.67	87.55
9301	2004-10-17	12532	4.30	0.35	4.65
9302	2004-10-17	9060	279.38	23.05	302.43
9303	2004-10-28	16805	62.68	5.17	67.85
9304	2004-10-11	3974	387.81	31.99	419.80
9305	2004-10-29	17550	57.88	4.78	62.66
9306	2004-10-03	16040	336.71	27.78	364.49
9307	2004-10-31	13386	53.71	4.43	58.14
9308	2004-10-15	5668	10.36	0.85	11.21
9309	2004-10-06	62	341.38	28.16	369.54
9310	2004-10-02	6089	86.74	7.16	93.90
9311	2004-10-15	14620	324.41	26.76	351.17
9312	2004-10-17	9619	179.63	14.82	194.45
9313	2004-10-12	1386	391.84	32.33	424.17
9314	2004-10-10	313	252.52	20.83	273.35
9315	2004-10-30	16032	275.58	22.74	298.32
9316	2004-10-30	971	164.70	13.59	178.29
9317	2004-10-13	10197	51.63	4.26	55.89
9318	2004-10-31	2984	271.38	22.39	293.77
9319	2004-10-02	7119	363.82	30.02	393.84
9320	2004-10-19	5157	397.07	32.76	429.83
9321	2004-10-04	15002	158.76	13.10	171.86
9322	2004-10-29	1673	38.43	3.17	41.60
9323	2004-10-22	11513	86.98	7.18	94.16
9324	2004-10-22	14624	79.61	6.57	86.18
9325	2004-10-02	15000	358.74	29.60	388.34
9326	2004-10-16	1080	75.11	6.20	81.31
9327	2004-10-01	19393	232.24	19.16	251.40
9328	2004-10-28	4469	347.95	28.71	376.66
9329	2004-10-09	1206	259.71	21.43	281.14
9330	2004-10-20	13840	343.74	28.36	372.10
9331	2004-10-28	16402	164.72	13.59	178.31
9332	2004-10-24	14056	115.25	9.51	124.76
9333	2004-10-10	19821	350.84	28.94	379.78
9334	2004-10-04	15856	361.75	29.84	391.59
9335	2004-10-17	10393	381.74	31.49	413.23
9336	2004-10-04	1043	361.29	29.81	391.10
9337	2004-10-23	10423	96.84	7.99	104.83
9338	2004-10-04	2108	83.26	6.87	90.13
9339	2004-10-27	4416	165.67	13.67	179.34
9340	2004-10-14	11966	3.02	0.25	3.27
9341	2004-10-28	7916	211.01	17.41	228.42
9342	2004-10-18	17872	121.88	10.06	131.94
9343	2004-10-05	7068	8.52	0.70	9.22
9344	2004-10-22	19879	134.75	11.12	145.87
9345	2004-10-15	19708	291.99	24.09	316.08
9346	2004-10-17	10926	393.42	32.46	425.88
9347	2004-10-17	16059	99.72	8.23	107.95
9348	2004-10-14	14861	35.61	2.94	38.55
9349	2004-10-05	12385	257.66	21.26	278.92
9350	2004-10-28	19556	235.28	19.41	254.69
9351	2004-10-04	15922	340.90	28.12	369.02
9352	2004-10-09	7443	7.45	0.61	8.06
9353	2004-10-06	8669	277.45	22.89	300.34
9354	2004-10-29	11443	42.62	3.52	46.14
9355	2004-10-22	4400	198.75	16.40	215.15
9356	2004-10-26	15102	310.75	25.64	336.39
9357	2004-10-26	6132	393.50	32.46	425.96
9358	2004-10-13	14647	180.57	14.90	195.47
9359	2004-10-26	6170	4.56	0.38	4.94
9360	2004-10-28	18083	8.99	0.74	9.73
9361	2004-10-19	1669	97.80	8.07	105.87
9362	2004-10-03	6952	132.32	10.92	143.24
9363	2004-10-29	14833	342.21	28.23	370.44
9364	2004-10-06	2878	301.26	24.85	326.11
9365	2004-10-06	12521	35.53	2.93	38.46
9366	2004-10-30	9805	379.77	31.33	411.10
9367	2004-10-12	12135	63.77	5.26	69.03
9368	2004-10-20	16013	383.44	31.63	415.07
9369	2004-10-26	10578	315.83	26.06	341.89
9370	2004-10-24	17558	293.48	24.21	317.69
9371	2004-10-03	5839	147.18	12.14	159.32
9372	2004-10-17	18836	72.17	5.95	78.12
9373	2004-10-23	10524	153.37	12.65	166.02
9374	2004-10-11	11633	181.40	14.97	196.37
9375	2004-10-25	18011	230.37	19.01	249.38
9376	2004-10-25	13840	315.19	26.00	341.19
9377	2004-10-09	8197	53.87	4.44	58.31
9378	2004-10-27	17118	63.86	5.27	69.13
9379	2004-10-10	13599	37.33	3.08	40.41
9380	2004-10-26	940	31.87	2.63	34.50
9381	2004-10-10	10399	203.10	16.76	219.86
9382	2004-10-12	3950	267.64	22.08	289.72
9383	2004-10-10	9959	133.56	11.02	144.58
9384	2004-10-20	1821	232.74	19.20	251.94
9385	2004-10-18	14211	305.10	25.17	330.27
9386	2004-10-09	5847	399.43	32.95	432.38
9387	2004-10-26	10326	347.89	28.70	376.59
9388	2004-10-12	17548	38.99	3.22	42.21
9389	2004-10-08	6016	391.71	32.32	424.03
9390	2004-10-15	13714	388.68	32.07	420.75
9391	2004-10-21	13761	285.88	23.59	309.47
9392	2004-10-22	17453	222.68	18.37	241.05
9393	2004-10-13	14608	3.68	0.30	3.98
9394	2004-10-13	3460	324.45	26.77	351.22
9395	2004-10-12	17033	191.43	15.79	207.22
9396	2004-10-31	1849	386.34	31.87	418.21
9397	2004-10-14	10695	140.65	11.60	152.25
9398	2004-10-15	10357	248.45	20.50	268.95
9399	2004-10-20	11937	5.00	0.41	5.41
9400	2004-10-28	17227	75.26	6.21	81.47
9401	2004-10-25	6217	122.80	10.13	132.93
9402	2004-10-31	12787	267.77	22.09	289.86
9403	2004-10-07	299	270.09	22.28	292.37
9404	2004-10-06	17740	365.08	30.12	395.20
9405	2004-10-09	16432	63.67	5.25	68.92
9406	2004-10-20	4957	256.00	21.12	277.12
9407	2004-10-08	17008	240.77	19.86	260.63
9408	2004-10-06	19568	231.43	19.09	250.52
9409	2004-10-22	16455	4.19	0.35	4.54
9410	2004-10-07	4347	77.84	6.42	84.26
9411	2004-10-25	956	236.96	19.55	256.51
9412	2004-10-08	19075	219.84	18.14	237.98
9413	2004-10-30	15200	213.47	17.61	231.08
9414	2004-10-29	14530	337.14	27.81	364.95
9415	2004-10-11	4329	373.45	30.81	404.26
9416	2004-10-05	12288	96.15	7.93	104.08
9417	2004-10-21	18691	325.66	26.87	352.53
9418	2004-10-03	4488	16.51	1.36	17.87
9419	2004-10-14	18325	77.88	6.43	84.31
9420	2004-10-13	19371	270.38	22.31	292.69
9421	2004-10-01	13826	29.79	2.46	32.25
9422	2004-10-02	13084	158.14	13.05	171.19
9423	2004-10-01	14092	164.23	13.55	177.78
9424	2004-10-16	11509	328.24	27.08	355.32
9425	2004-10-19	13165	207.37	17.11	224.48
9426	2004-10-25	107	290.95	24.00	314.95
9427	2004-10-19	12772	248.78	20.52	269.30
9428	2004-10-19	14160	195.05	16.09	211.14
9429	2004-10-28	286	19.55	1.61	21.16
9430	2004-10-01	19043	308.78	25.47	334.25
9431	2004-10-01	4066	346.81	28.61	375.42
9432	2004-10-09	15768	93.32	7.70	101.02
9433	2004-10-29	13774	209.80	17.31	227.11
9434	2004-10-28	17811	31.91	2.63	34.54
9435	2004-10-28	14318	1.17	0.10	1.27
9436	2004-10-21	9272	36.66	3.02	39.68
9437	2004-10-17	17682	74.75	6.17	80.92
9438	2004-10-27	9418	3.47	0.29	3.76
9439	2004-10-17	6613	210.86	17.40	228.26
9440	2004-10-27	19331	352.00	29.04	381.04
9441	2004-10-24	15906	232.13	19.15	251.28
9442	2004-10-05	6006	202.98	16.75	219.73
9443	2004-10-30	8367	169.67	14.00	183.67
9444	2004-10-17	9755	60.12	4.96	65.08
9445	2004-10-29	9087	52.55	4.34	56.89
9446	2004-10-11	357	250.84	20.69	271.53
9447	2004-10-10	13	83.31	6.87	90.18
9448	2004-10-12	8852	383.14	31.61	414.75
9449	2004-10-29	12197	273.82	22.59	296.41
9450	2004-10-16	16147	166.05	13.70	179.75
9451	2004-10-07	13638	144.28	11.90	156.18
9452	2004-10-29	16128	95.78	7.90	103.68
9453	2004-10-03	13482	300.55	24.80	325.35
9454	2004-10-20	12552	280.62	23.15	303.77
9455	2004-10-07	1034	361.70	29.84	391.54
9456	2004-10-01	3869	204.92	16.91	221.83
9457	2004-10-01	1982	92.67	7.65	100.32
9458	2004-10-21	8472	257.43	21.24	278.67
9459	2004-10-03	19962	202.84	16.73	219.57
9460	2004-10-26	8624	146.85	12.12	158.97
9461	2004-10-10	8144	142.10	11.72	153.82
9462	2004-10-26	19362	127.32	10.50	137.82
9463	2004-10-28	12462	52.28	4.31	56.59
9464	2004-10-28	12619	336.54	27.76	364.30
9465	2004-10-23	4535	5.85	0.48	6.33
9466	2004-10-02	5454	55.77	4.60	60.37
9467	2004-10-23	1336	317.91	26.23	344.14
9468	2004-10-10	10238	32.93	2.72	35.65
9469	2004-10-19	7877	320.95	26.48	347.43
9470	2004-10-17	16048	364.85	30.10	394.95
9471	2004-10-20	16880	114.24	9.42	123.66
9472	2004-10-30	10440	133.61	11.02	144.63
9473	2004-10-25	3049	241.67	19.94	261.61
9474	2004-10-28	14046	260.12	21.46	281.58
9475	2004-10-02	14647	63.48	5.24	68.72
9476	2004-10-19	17562	29.66	2.45	32.11
9477	2004-10-11	12278	370.72	30.58	401.30
9478	2004-10-13	2873	325.65	26.87	352.52
9479	2004-10-17	10745	142.76	11.78	154.54
9480	2004-10-13	10614	228.00	18.81	246.81
9481	2004-10-15	2239	363.00	29.95	392.95
9482	2004-10-17	11067	270.47	22.31	292.78
9483	2004-10-04	6208	206.24	17.01	223.25
9484	2004-10-28	8587	111.00	9.16	120.16
9485	2004-10-27	12467	220.98	18.23	239.21
9486	2004-10-21	12536	258.77	21.35	280.12
9487	2004-10-17	15328	399.32	32.94	432.26
9488	2004-10-21	11219	100.83	8.32	109.15
9489	2004-10-18	11932	257.07	21.21	278.28
9490	2004-10-07	19057	309.19	25.51	334.70
9491	2004-10-08	13625	145.14	11.97	157.11
9492	2004-10-03	19623	319.53	26.36	345.89
9493	2004-10-28	10176	7.43	0.61	8.04
9494	2004-10-30	16816	132.62	10.94	143.56
9495	2004-10-28	11939	54.82	4.52	59.34
9496	2004-10-02	18326	53.48	4.41	57.89
9497	2004-10-11	2992	260.20	21.47	281.67
9498	2004-10-19	15664	44.44	3.67	48.11
9499	2004-10-07	19233	156.35	12.90	169.25
9500	2004-10-31	19249	233.83	19.29	253.12
9501	2004-10-24	157	313.82	25.89	339.71
9502	2004-10-23	14047	108.13	8.92	117.05
9503	2004-10-24	9887	236.63	19.52	256.15
9504	2004-10-09	15401	247.72	20.44	268.16
9505	2004-10-08	14559	184.12	15.19	199.31
9506	2004-10-02	3804	123.92	10.22	134.14
9507	2004-10-31	18981	93.20	7.69	100.89
9508	2004-10-23	770	387.65	31.98	419.63
9509	2004-10-02	18376	245.04	20.22	265.26
9510	2004-10-03	9868	45.57	3.76	49.33
9511	2004-10-08	5941	347.00	28.63	375.63
9512	2004-10-04	15427	177.27	14.62	191.89
9513	2004-10-17	1481	42.14	3.48	45.62
9514	2004-10-14	4073	182.61	15.07	197.68
9515	2004-10-05	9508	100.15	8.26	108.41
9516	2004-10-16	16948	153.04	12.63	165.67
9517	2004-10-11	10928	332.71	27.45	360.16
9518	2004-10-20	19844	262.49	21.66	284.15
9519	2004-10-11	12671	110.92	9.15	120.07
9520	2004-10-16	588	305.60	25.21	330.81
9521	2004-10-05	12513	107.21	8.84	116.05
9522	2004-10-18	15021	161.18	13.30	174.48
9523	2004-10-26	19768	324.41	26.76	351.17
9524	2004-10-21	12268	177.56	14.65	192.21
9525	2004-10-04	12564	110.10	9.08	119.18
9526	2004-10-08	2779	84.11	6.94	91.05
9527	2004-10-05	17357	326.84	26.96	353.80
9528	2004-10-05	3497	127.68	10.53	138.21
9529	2004-10-27	10196	324.44	26.77	351.21
9530	2004-10-01	5855	163.30	13.47	176.77
9531	2004-10-22	17180	335.80	27.70	363.50
9532	2004-10-21	14364	198.58	16.38	214.96
9533	2004-10-30	14397	224.06	18.48	242.54
9534	2004-10-14	2871	291.79	24.07	315.86
9535	2004-10-19	7893	147.65	12.18	159.83
9536	2004-10-16	15571	147.10	12.14	159.24
9537	2004-10-08	5382	312.28	25.76	338.04
9538	2004-10-31	15147	88.79	7.33	96.12
9539	2004-10-08	15091	280.89	23.17	304.06
9540	2004-10-08	12758	33.07	2.73	35.80
9541	2004-10-24	5233	168.89	13.93	182.82
9542	2004-10-13	11107	227.77	18.79	246.56
9543	2004-10-09	16575	233.46	19.26	252.72
9544	2004-10-14	6736	27.48	2.27	29.75
9545	2004-10-26	6293	355.30	29.31	384.61
9546	2004-10-29	969	70.84	5.84	76.68
9547	2004-10-11	2459	155.70	12.85	168.55
9548	2004-10-18	19837	334.68	27.61	362.29
9549	2004-10-13	17478	266.27	21.97	288.24
9550	2004-10-12	5440	272.74	22.50	295.24
9551	2004-10-24	16200	205.29	16.94	222.23
9552	2004-10-15	10727	32.06	2.64	34.70
9553	2004-10-09	19816	154.31	12.73	167.04
9554	2004-10-11	16111	34.32	2.83	37.15
9555	2004-10-29	15151	117.12	9.66	126.78
9556	2004-10-31	1158	346.34	28.57	374.91
9557	2004-10-24	17968	216.38	17.85	234.23
9558	2004-10-31	17710	103.59	8.55	112.14
9559	2004-10-30	10239	60.77	5.01	65.78
9560	2004-10-10	7377	10.37	0.86	11.23
9561	2004-10-12	11256	101.86	8.40	110.26
9562	2004-10-26	10477	80.59	6.65	87.24
9563	2004-10-18	10457	93.61	7.72	101.33
9564	2004-10-06	15746	284.82	23.50	308.32
9565	2004-10-01	560	371.85	30.68	402.53
9566	2004-10-01	14974	318.35	26.26	344.61
9567	2004-10-13	6774	62.92	5.19	68.11
9568	2004-10-11	13358	264.42	21.81	286.23
9569	2004-10-25	6723	117.92	9.73	127.65
9570	2004-10-07	4143	399.70	32.98	432.68
9571	2004-10-22	2210	6.15	0.51	6.66
9572	2004-10-18	18908	292.33	24.12	316.45
9573	2004-10-02	3553	222.46	18.35	240.81
9574	2004-10-22	2174	303.45	25.03	328.48
9575	2004-10-29	15798	281.77	23.25	305.02
9576	2004-10-28	10942	42.87	3.54	46.41
9577	2004-10-01	3794	175.83	14.51	190.34
9578	2004-10-01	17151	340.46	28.09	368.55
9579	2004-10-13	3679	24.84	2.05	26.89
9580	2004-10-02	9580	363.16	29.96	393.12
9581	2004-10-26	3959	38.12	3.14	41.26
9582	2004-10-17	1246	76.83	6.34	83.17
9583	2004-10-22	10817	241.84	19.95	261.79
9584	2004-10-04	3929	357.55	29.50	387.05
9585	2004-10-24	13338	42.22	3.48	45.70
9586	2004-10-30	7698	193.25	15.94	209.19
9587	2004-10-23	16800	185.15	15.27	200.42
9588	2004-10-10	14620	182.37	15.05	197.42
9589	2004-10-24	17403	303.47	25.04	328.51
9590	2004-10-12	16994	24.43	2.02	26.45
9591	2004-10-30	10144	143.56	11.84	155.40
9592	2004-10-15	5760	232.72	19.20	251.92
9593	2004-10-18	1182	155.84	12.86	168.70
9594	2004-10-01	17464	389.16	32.11	421.27
9595	2004-10-27	1529	356.81	29.44	386.25
9596	2004-10-12	3866	83.32	6.87	90.19
9597	2004-10-17	16668	107.10	8.84	115.94
9598	2004-10-20	8525	118.29	9.76	128.05
9599	2004-10-11	1729	220.58	18.20	238.78
9600	2004-10-07	1570	104.24	8.60	112.84
9601	2004-10-18	1393	30.20	2.49	32.69
9602	2004-10-08	7323	363.44	29.98	393.42
9603	2004-10-26	8787	217.13	17.91	235.04
9604	2004-10-17	8389	78.13	6.45	84.58
9605	2004-10-23	866	397.62	32.80	430.42
9606	2004-10-17	12627	149.38	12.32	161.70
9607	2004-10-04	6267	120.12	9.91	130.03
9608	2004-10-05	18506	322.32	26.59	348.91
9609	2004-10-28	4800	135.51	11.18	146.69
9610	2004-10-08	13778	195.59	16.14	211.73
9611	2004-10-31	16111	58.25	4.81	63.06
9612	2004-10-16	14898	389.65	32.15	421.80
9613	2004-10-31	7571	305.82	25.23	331.05
9614	2004-10-26	4871	2.30	0.19	2.49
9615	2004-10-31	5552	22.51	1.86	24.37
9616	2004-10-07	10486	213.68	17.63	231.31
9617	2004-10-26	15823	78.77	6.50	85.27
9618	2004-10-08	17473	47.62	3.93	51.55
9619	2004-10-07	13175	344.72	28.44	373.16
9620	2004-10-19	13964	107.82	8.90	116.72
9621	2004-10-12	5575	353.09	29.13	382.22
9622	2004-10-13	10091	80.98	6.68	87.66
9623	2004-10-01	15692	238.10	19.64	257.74
9624	2004-10-01	3341	92.94	7.67	100.61
9625	2004-10-26	5586	251.66	20.76	272.42
9626	2004-10-30	9701	90.23	7.44	97.67
9627	2004-10-10	15787	141.31	11.66	152.97
9628	2004-10-29	18523	312.99	25.82	338.81
9629	2004-10-09	17999	48.47	4.00	52.47
9630	2004-10-25	10599	288.30	23.78	312.08
9631	2004-10-21	5505	99.07	8.17	107.24
9632	2004-10-12	4510	382.36	31.54	413.90
9633	2004-10-19	15709	240.10	19.81	259.91
9634	2004-10-28	4291	13.44	1.11	14.55
9635	2004-10-13	16681	180.72	14.91	195.63
9636	2004-10-01	7631	106.39	8.78	115.17
9637	2004-10-09	13630	18.28	1.51	19.79
9638	2004-10-11	110	342.92	28.29	371.21
9639	2004-10-16	14605	87.28	7.20	94.48
9640	2004-10-01	3715	346.90	28.62	375.52
9641	2004-10-20	19140	217.05	17.91	234.96
9642	2004-10-08	3936	333.91	27.55	361.46
9643	2004-10-17	17758	282.85	23.34	306.19
9644	2004-10-04	16255	67.24	5.55	72.79
9645	2004-10-17	3937	99.85	8.24	108.09
9646	2004-10-13	13026	59.71	4.93	64.64
9647	2004-10-29	11991	108.37	8.94	117.31
9648	2004-10-08	1562	291.68	24.06	315.74
9649	2004-10-09	10523	171.09	14.11	185.20
9650	2004-10-14	9381	356.35	29.40	385.75
9651	2004-10-02	683	30.90	2.55	33.45
9652	2004-10-25	19658	33.85	2.79	36.64
9653	2004-10-29	7192	35.93	2.96	38.89
9654	2004-10-25	3648	180.40	14.88	195.28
9655	2004-10-23	16316	251.73	20.77	272.50
9656	2004-10-13	14647	281.51	23.22	304.73
9657	2004-10-19	11016	327.07	26.98	354.05
9658	2004-10-13	19865	121.79	10.05	131.84
9659	2004-10-03	5196	174.30	14.38	188.68
9660	2004-10-16	15598	20.71	1.71	22.42
9661	2004-10-30	16706	107.23	8.85	116.08
9662	2004-10-31	11690	304.60	25.13	329.73
9663	2004-10-09	14446	310.80	25.64	336.44
9664	2004-10-12	18739	182.96	15.09	198.05
9665	2004-10-26	2269	384.10	31.69	415.79
9666	2004-10-29	12248	34.76	2.87	37.63
9667	2004-10-01	11238	355.06	29.29	384.35
9668	2004-10-11	12084	92.40	7.62	100.02
9669	2004-10-16	13980	255.11	21.05	276.16
9670	2004-10-11	9082	49.55	4.09	53.64
9671	2004-10-28	3877	343.60	28.35	371.95
9672	2004-10-11	2280	378.24	31.20	409.44
9673	2004-10-05	18587	171.79	14.17	185.96
9674	2004-10-02	14502	60.10	4.96	65.06
9675	2004-10-31	1250	113.16	9.34	122.50
9676	2004-10-04	19737	256.77	21.18	277.95
9677	2004-10-05	1302	88.00	7.26	95.26
9678	2004-10-02	15112	362.43	29.90	392.33
9679	2004-10-29	13780	378.04	31.19	409.23
9680	2004-10-17	606	333.69	27.53	361.22
9681	2004-10-12	3738	268.31	22.14	290.45
9682	2004-10-30	18689	312.79	25.81	338.60
9683	2004-10-31	313	167.19	13.79	180.98
9684	2004-10-18	18948	279.60	23.07	302.67
9685	2004-10-17	13125	34.97	2.89	37.86
9686	2004-10-19	9446	26.88	2.22	29.10
9687	2004-10-14	2893	36.48	3.01	39.49
9688	2004-10-12	18374	137.41	11.34	148.75
9689	2004-10-28	1114	319.16	26.33	345.49
9690	2004-10-21	15150	365.94	30.19	396.13
9691	2004-10-20	12848	260.14	21.46	281.60
9692	2004-10-09	18544	80.19	6.62	86.81
9693	2004-10-15	10149	212.59	17.54	230.13
9694	2004-10-24	103	234.87	19.38	254.25
9695	2004-10-03	1881	283.41	23.38	306.79
9696	2004-10-18	9210	209.76	17.31	227.07
9697	2004-10-29	13723	200.74	16.56	217.30
9698	2004-10-21	5384	356.70	29.43	386.13
9699	2004-10-05	12887	199.80	16.48	216.28
9700	2004-10-30	15432	258.49	21.33	279.82
9701	2004-10-29	6992	233.31	19.25	252.56
9702	2004-10-05	19395	212.61	17.54	230.15
9703	2004-10-29	3995	324.05	26.73	350.78
9704	2004-10-29	4982	397.44	32.79	430.23
9705	2004-10-20	5968	217.31	17.93	235.24
9706	2004-10-19	16176	86.04	7.10	93.14
9707	2004-10-02	4722	387.21	31.94	419.15
9708	2004-10-13	1206	334.05	27.56	361.61
9709	2004-10-06	3688	339.02	27.97	366.99
9710	2004-10-08	15428	107.61	8.88	116.49
9711	2004-10-22	12419	83.33	6.87	90.20
9712	2004-10-14	6842	89.68	7.40	97.08
9713	2004-10-24	5178	255.68	21.09	276.77
9714	2004-10-26	5589	68.90	5.68	74.58
9715	2004-10-24	17644	59.31	4.89	64.20
9716	2004-10-29	11884	166.04	13.70	179.74
9717	2004-10-07	16623	155.48	12.83	168.31
9718	2004-10-05	18808	263.26	21.72	284.98
9719	2004-10-20	15212	214.97	17.74	232.71
9720	2004-10-12	17710	14.39	1.19	15.58
9721	2004-10-29	252	203.57	16.79	220.36
9722	2004-10-07	9601	222.07	18.32	240.39
9723	2004-10-16	18581	97.68	8.06	105.74
9724	2004-10-14	15284	107.79	8.89	116.68
9725	2004-10-06	6077	196.87	16.24	213.11
9726	2004-10-31	12537	127.73	10.54	138.27
9727	2004-10-10	8335	218.50	18.03	236.53
9728	2004-10-26	3099	33.68	2.78	36.46
9729	2004-10-09	12118	150.56	12.42	162.98
9730	2004-10-10	12612	379.06	31.27	410.33
9731	2004-10-11	18959	140.09	11.56	151.65
9732	2004-10-11	6363	308.29	25.43	333.72
9733	2004-10-24	9383	226.02	18.65	244.67
9734	2004-10-26	19394	225.49	18.60	244.09
9735	2004-10-19	959	233.98	19.30	253.28
9736	2004-10-22	16134	21.60	1.78	23.38
9737	2004-10-21	1837	266.90	22.02	288.92
9738	2004-10-01	11127	81.85	6.75	88.60
9739	2004-10-12	4413	247.10	20.39	267.49
9740	2004-10-05	9753	33.46	2.76	36.22
9741	2004-10-05	1083	348.22	28.73	376.95
9742	2004-10-15	6301	301.38	24.86	326.24
9743	2004-10-06	6719	60.39	4.98	65.37
9744	2004-10-01	13959	235.92	19.46	255.38
9745	2004-10-25	17786	20.41	1.68	22.09
9746	2004-10-08	3468	152.42	12.57	164.99
9747	2004-10-05	14149	237.69	19.61	257.30
9748	2004-10-20	19	71.29	5.88	77.17
9749	2004-10-06	3880	281.90	23.26	305.16
9750	2004-10-22	1326	341.27	28.15	369.42
9751	2004-10-11	14327	176.50	14.56	191.06
9752	2004-10-03	3320	363.34	29.98	393.32
9753	2004-10-26	4795	367.81	30.34	398.15
9754	2004-10-14	9172	225.10	18.57	243.67
9755	2004-10-23	3009	201.15	16.59	217.74
9756	2004-10-01	18578	128.13	10.57	138.70
9757	2004-10-13	17499	246.00	20.30	266.30
9758	2004-10-27	6142	291.69	24.06	315.75
9759	2004-10-31	17455	20.68	1.71	22.39
9760	2004-10-27	9178	228.74	18.87	247.61
9761	2004-10-20	4459	215.61	17.79	233.40
9762	2004-10-19	13919	35.94	2.97	38.91
9763	2004-10-14	3001	109.71	9.05	118.76
9764	2004-10-14	10493	256.25	21.14	277.39
9765	2004-10-07	18658	281.77	23.25	305.02
9766	2004-10-26	3874	208.15	17.17	225.32
9767	2004-10-19	13970	61.62	5.08	66.70
9768	2004-10-30	10285	6.57	0.54	7.11
9769	2004-10-18	2688	269.66	22.25	291.91
9770	2004-10-16	16812	126.04	10.40	136.44
9771	2004-10-06	6798	206.68	17.05	223.73
9772	2004-10-31	268	31.15	2.57	33.72
9773	2004-10-04	12893	371.61	30.66	402.27
9774	2004-10-08	8943	4.22	0.35	4.57
9775	2004-10-07	6338	81.95	6.76	88.71
9776	2004-10-10	377	380.60	31.40	412.00
9777	2004-10-08	11618	245.85	20.28	266.13
9778	2004-10-10	339	212.40	17.52	229.92
9779	2004-10-22	11262	230.35	19.00	249.35
9780	2004-10-19	13385	314.83	25.97	340.80
9781	2004-10-25	8416	378.91	31.26	410.17
9782	2004-10-21	16520	41.36	3.41	44.77
9783	2004-10-11	14819	298.73	24.65	323.38
9784	2004-10-17	7946	150.62	12.43	163.05
9785	2004-10-25	4615	69.95	5.77	75.72
9786	2004-10-19	14494	331.64	27.36	359.00
9787	2004-10-14	1985	383.00	31.60	414.60
9788	2004-10-18	7331	1.41	0.12	1.53
9789	2004-10-12	14065	277.19	22.87	300.06
9790	2004-10-16	9349	107.97	8.91	116.88
9791	2004-10-03	19274	196.28	16.19	212.47
9792	2004-10-14	19460	108.39	8.94	117.33
9793	2004-10-19	17948	42.23	3.48	45.71
9794	2004-10-13	2573	212.61	17.54	230.15
9795	2004-10-21	19582	376.90	31.09	407.99
9796	2004-10-08	19544	77.04	6.36	83.40
9797	2004-10-08	18102	195.73	16.15	211.88
9798	2004-10-14	14071	304.40	25.11	329.51
9799	2004-10-29	18135	235.92	19.46	255.38
9800	2004-10-04	11249	142.97	11.80	154.77
9801	2004-10-08	13846	346.65	28.60	375.25
9802	2004-10-06	11211	378.38	31.22	409.60
9803	2004-10-19	17520	350.41	28.91	379.32
9804	2004-10-19	18749	299.78	24.73	324.51
9805	2004-10-08	15166	345.02	28.46	373.48
9806	2004-10-30	3012	92.08	7.60	99.68
9807	2004-10-14	19347	321.70	26.54	348.24
9808	2004-10-12	8622	380.44	31.39	411.83
9809	2004-10-19	17396	184.94	15.26	200.20
9810	2004-10-25	17062	262.71	21.67	284.38
9811	2004-10-17	1593	268.57	22.16	290.73
9812	2004-10-09	17141	197.09	16.26	213.35
9813	2004-10-23	1535	54.16	4.47	58.63
9814	2004-10-02	8357	53.55	4.42	57.97
9815	2004-10-25	19280	292.26	24.11	316.37
9816	2004-10-17	16606	282.39	23.30	305.69
9817	2004-10-01	16395	263.02	21.70	284.72
9818	2004-10-15	19051	68.94	5.69	74.63
9819	2004-10-16	18108	92.69	7.65	100.34
9820	2004-10-13	13387	317.60	26.20	343.80
9821	2004-10-15	10986	13.18	1.09	14.27
9822	2004-10-27	15421	392.98	32.42	425.40
9823	2004-10-26	6262	377.24	31.12	408.36
9824	2004-10-11	16573	43.14	3.56	46.70
9825	2004-10-16	17383	59.40	4.90	64.30
9826	2004-10-15	2575	286.61	23.65	310.26
9827	2004-10-04	5547	202.57	16.71	219.28
9828	2004-10-02	9529	236.21	19.49	255.70
9829	2004-10-31	13028	32.24	2.66	34.90
9830	2004-10-10	15792	169.06	13.95	183.01
9831	2004-10-01	3699	165.63	13.66	179.29
9832	2004-10-26	14390	25.93	2.14	28.07
9833	2004-10-27	3693	138.70	11.44	150.14
9834	2004-10-11	11086	236.53	19.51	256.04
9835	2004-10-18	15823	249.82	20.61	270.43
9836	2004-10-21	10105	327.85	27.05	354.90
9837	2004-10-10	12489	318.86	26.31	345.17
9838	2004-10-30	10361	335.21	27.65	362.86
9839	2004-10-23	3348	217.91	17.98	235.89
9840	2004-10-12	5421	364.00	30.03	394.03
9841	2004-10-14	11967	156.08	12.88	168.96
9842	2004-10-14	12284	190.89	15.75	206.64
9843	2004-10-27	11095	321.72	26.54	348.26
9844	2004-10-19	10399	208.51	17.20	225.71
9845	2004-10-09	13085	80.32	6.63	86.95
9846	2004-10-01	10718	301.98	24.91	326.89
9847	2004-10-15	240	354.91	29.28	384.19
9848	2004-10-15	1815	334.36	27.58	361.94
9849	2004-10-01	3890	217.60	17.95	235.55
9850	2004-10-28	5712	85.26	7.03	92.29
9851	2004-10-25	205	229.79	18.96	248.75
9852	2004-10-14	9640	75.38	6.22	81.60
9853	2004-10-20	17423	169.26	13.96	183.22
9854	2004-10-03	6980	344.90	28.45	373.35
9855	2004-10-22	15603	195.30	16.11	211.41
9856	2004-10-29	127	243.26	20.07	263.33
9857	2004-10-05	6972	133.32	11.00	144.32
9858	2004-10-04	17046	143.27	11.82	155.09
9859	2004-10-26	10976	365.97	30.19	396.16
9860	2004-10-21	12735	367.96	30.36	398.32
9861	2004-10-13	11269	54.80	4.52	59.32
9862	2004-10-13	14913	30.34	2.50	32.84
9863	2004-10-29	16248	14.04	1.16	15.20
9864	2004-10-21	4480	206.17	17.01	223.18
9865	2004-10-28	902	265.68	21.92	287.60
9866	2004-10-31	16969	185.73	15.32	201.05
9867	2004-10-15	15028	177.53	14.65	192.18
9868	2004-10-25	13451	393.34	32.45	425.79
9869	2004-10-13	10188	147.53	12.17	159.70
9870	2004-10-08	8376	256.59	21.17	277.76
9871	2004-10-07	14664	131.79	10.87	142.66
9872	2004-10-01	19762	38.93	3.21	42.14
9873	2004-10-02	12405	105.08	8.67	113.75
9874	2004-10-11	19153	193.73	15.98	209.71
9875	2004-10-13	8228	2.25	0.19	2.44
9876	2004-10-25	14432	222.45	18.35	240.80
9877	2004-10-15	524	397.86	32.82	430.68
9878	2004-10-05	18918	302.72	24.97	327.69
9879	2004-10-14	9460	390.73	32.24	422.97
9880	2004-10-20	7787	266.28	21.97	288.25
9881	2004-10-30	14059	266.61	22.00	288.61
9882	2004-10-24	3325	128.12	10.57	138.69
9883	2004-10-03	18119	396.39	32.70	429.09
9884	2004-10-20	7744	151.65	12.51	164.16
9885	2004-10-17	13230	78.09	6.44	84.53
9886	2004-10-22	8112	79.37	6.55	85.92
9887	2004-10-11	6247	237.18	19.57	256.75
9888	2004-10-02	19930	352.75	29.10	381.85
9889	2004-10-15	16807	106.36	8.77	115.13
9890	2004-10-18	7923	140.87	11.62	152.49
9891	2004-10-21	3247	144.85	11.95	156.80
9892	2004-10-03	5816	242.68	20.02	262.70
9893	2004-10-07	12915	297.69	24.56	322.25
9894	2004-10-09	14454	288.70	23.82	312.52
9895	2004-10-05	15354	135.55	11.18	146.73
9896	2004-10-25	2063	205.34	16.94	222.28
9897	2004-10-30	5669	27.54	2.27	29.81
9898	2004-10-17	13778	361.90	29.86	391.76
9899	2004-10-31	93	317.35	26.18	343.53
9900	2004-10-31	1772	71.96	5.94	77.90
9901	2004-10-17	19379	96.19	7.94	104.13
9902	2004-10-16	13620	269.31	22.22	291.53
9903	2004-10-19	17101	381.83	31.50	413.33
9904	2004-10-14	1395	52.98	4.37	57.35
9905	2004-10-18	14771	14.83	1.22	16.05
9906	2004-10-29	3304	302.30	24.94	327.24
9907	2004-10-25	10365	77.94	6.43	84.37
9908	2004-10-29	5028	360.13	29.71	389.84
9909	2004-10-06	6209	177.91	14.68	192.59
9910	2004-10-13	19254	10.83	0.89	11.72
9911	2004-10-15	16019	193.22	15.94	209.16
9912	2004-10-12	13124	27.97	2.31	30.28
9913	2004-10-31	10924	85.45	7.05	92.50
9914	2004-10-28	19268	200.23	16.52	216.75
9915	2004-10-03	10574	202.89	16.74	219.63
9916	2004-10-09	18416	67.37	5.56	72.93
9917	2004-10-09	11350	350.05	28.88	378.93
9918	2004-10-10	8732	296.47	24.46	320.93
9919	2004-10-27	5044	257.32	21.23	278.55
9920	2004-10-24	2949	141.31	11.66	152.97
9921	2004-10-21	3432	323.43	26.68	350.11
9922	2004-10-04	1045	41.94	3.46	45.40
9923	2004-10-21	9461	176.08	14.53	190.61
9924	2004-10-28	12579	263.73	21.76	285.49
9925	2004-10-31	760	101.84	8.40	110.24
9926	2004-10-31	16514	20.93	1.73	22.66
9927	2004-10-22	1148	73.25	6.04	79.29
9928	2004-10-19	12307	196.34	16.20	212.54
9929	2004-10-07	16579	117.77	9.72	127.49
9930	2004-10-29	17912	152.09	12.55	164.64
9931	2004-10-30	7695	90.25	7.45	97.70
9932	2004-10-27	12489	107.61	8.88	116.49
9933	2004-10-12	2066	282.07	23.27	305.34
9934	2004-10-02	8477	194.21	16.02	210.23
9935	2004-10-08	2275	292.59	24.14	316.73
9936	2004-10-05	4521	379.36	31.30	410.66
9937	2004-10-20	1874	184.02	15.18	199.20
9938	2004-10-20	17573	53.33	4.40	57.73
9939	2004-10-30	18056	268.06	22.11	290.17
9940	2004-10-27	10637	152.73	12.60	165.33
9941	2004-10-26	12229	156.58	12.92	169.50
9942	2004-10-06	4711	276.51	22.81	299.32
9943	2004-10-28	5236	288.49	23.80	312.29
9944	2004-10-03	1453	371.96	30.69	402.65
9945	2004-10-22	17163	391.25	32.28	423.53
9946	2004-10-15	7149	38.20	3.15	41.35
9947	2004-10-28	1850	273.70	22.58	296.28
9948	2004-10-15	16254	101.36	8.36	109.72
9949	2004-10-17	16777	46.30	3.82	50.12
9950	2004-10-10	17447	259.34	21.40	280.74
9951	2004-10-20	69	133.78	11.04	144.82
9952	2004-10-13	16482	201.25	16.60	217.85
9953	2004-10-17	15652	91.30	7.53	98.83
9954	2004-10-11	12655	27.73	2.29	30.02
9955	2004-10-11	15242	334.28	27.58	361.86
9956	2004-10-06	17894	276.88	22.84	299.72
9957	2004-10-11	7462	197.40	16.29	213.69
9958	2004-10-11	2687	33.63	2.77	36.40
9959	2004-10-08	18330	28.52	2.35	30.87
9960	2004-10-14	14863	75.88	6.26	82.14
9961	2004-10-25	3002	128.44	10.60	139.04
9962	2004-10-17	3882	215.93	17.81	233.74
9963	2004-10-25	6280	395.77	32.65	428.42
9964	2004-10-15	41	286.20	23.61	309.81
9965	2004-10-05	7152	73.37	6.05	79.42
9966	2004-10-11	14585	334.38	27.59	361.97
9967	2004-10-05	4767	29.59	2.44	32.03
9968	2004-10-10	18019	327.04	26.98	354.02
9969	2004-10-09	1105	148.52	12.25	160.77
9970	2004-10-09	7945	393.91	32.50	426.41
9971	2004-10-24	5535	213.17	17.59	230.76
9972	2004-10-13	15483	307.78	25.39	333.17
9973	2004-10-08	17928	219.06	18.07	237.13
9974	2004-10-23	6557	137.94	11.38	149.32
9975	2004-10-07	15648	158.70	13.09	171.79
9976	2004-10-02	13257	92.88	7.66	100.54
9977	2004-10-02	920	368.33	30.39	398.72
9978	2004-10-17	5613	85.98	7.09	93.07
9979	2004-10-01	14475	267.67	22.08	289.75
9980	2004-10-08	10818	138.36	11.41	149.77
9981	2004-10-29	11526	177.33	14.63	191.96
9982	2004-10-12	11453	35.03	2.89	37.92
9983	2004-10-31	15986	287.54	23.72	311.26
9984	2004-10-19	8989	291.24	24.03	315.27
9985	2004-10-04	10478	12.69	1.05	13.74
9986	2004-10-30	14342	56.18	4.63	60.81
9987	2004-10-31	11895	299.39	24.70	324.09
9988	2004-10-31	7668	231.74	19.12	250.86
9989	2004-10-25	8412	372.96	30.77	403.73
9990	2004-10-14	3343	118.34	9.76	128.10
9991	2004-10-04	17424	311.77	25.72	337.49
9992	2004-10-29	17301	288.81	23.83	312.64
9993	2004-10-25	6600	255.88	21.11	276.99
9994	2004-10-02	11393	155.12	12.80	167.92
9995	2004-10-18	11298	128.76	10.62	139.38
9996	2004-10-25	16753	167.99	13.86	181.85
9997	2004-10-17	19092	141.66	11.69	153.35
9998	2004-10-21	14007	146.35	12.07	158.42
9999	2004-10-06	5119	181.60	14.98	196.58
10000	2004-10-20	7004	241.67	19.94	261.61
10001	2004-11-19	12934	102.63	8.47	111.10
10002	2004-11-29	2761	174.51	14.40	188.91
10003	2004-11-17	16077	372.85	30.76	403.61
10004	2004-11-23	16213	126.20	10.41	136.61
10005	2004-11-14	10403	223.54	18.44	241.98
10006	2004-11-15	16547	127.28	10.50	137.78
10007	2004-11-08	6944	233.75	19.28	253.03
10008	2004-11-16	12923	317.36	26.18	343.54
10009	2004-11-28	16213	56.28	4.64	60.92
10010	2004-11-08	12874	165.17	13.63	178.80
10011	2004-11-16	8457	209.66	17.30	226.96
10012	2004-11-14	5608	331.19	27.32	358.51
10013	2004-11-06	6365	180.20	14.87	195.07
10014	2004-11-06	1826	272.21	22.46	294.67
10015	2004-11-16	7152	383.55	31.64	415.19
10016	2004-11-19	7543	157.70	13.01	170.71
10017	2004-11-24	6220	281.48	23.22	304.70
10018	2004-11-23	13489	71.74	5.92	77.66
10019	2004-11-20	15640	238.16	19.65	257.81
10020	2004-11-08	19887	100.27	8.27	108.54
10021	2004-11-27	15305	30.41	2.51	32.92
10022	2004-11-26	16189	25.99	2.14	28.13
10023	2004-11-25	7979	177.09	14.61	191.70
10024	2004-11-06	12759	158.96	13.11	172.07
10025	2004-11-20	5906	300.67	24.81	325.48
10026	2004-11-08	15792	132.60	10.94	143.54
10027	2004-11-25	7694	91.04	7.51	98.55
10028	2004-11-25	13440	2.77	0.23	3.00
10029	2004-11-19	7971	78.40	6.47	84.87
10030	2004-11-16	18556	146.73	12.11	158.84
10031	2004-11-01	14692	388.80	32.08	420.88
10032	2004-11-24	16195	357.83	29.52	387.35
10033	2004-11-16	12698	59.01	4.87	63.88
10034	2004-11-30	270	236.61	19.52	256.13
10035	2004-11-14	16498	296.00	24.42	320.42
10036	2004-11-25	11285	138.20	11.40	149.60
10037	2004-11-13	2502	281.14	23.19	304.33
10038	2004-11-30	15994	316.16	26.08	342.24
10039	2004-11-27	10690	275.66	22.74	298.40
10040	2004-11-05	16393	180.82	14.92	195.74
10041	2004-11-05	17233	256.14	21.13	277.27
10042	2004-11-23	3622	183.67	15.15	198.82
10043	2004-11-15	9308	321.30	26.51	347.81
10044	2004-11-14	12251	169.82	14.01	183.83
10045	2004-11-03	3919	116.75	9.63	126.38
10046	2004-11-10	9077	287.36	23.71	311.07
10047	2004-11-17	15951	253.87	20.94	274.81
10048	2004-11-22	2255	306.91	25.32	332.23
10049	2004-11-22	5370	245.58	20.26	265.84
10050	2004-11-18	18270	13.23	1.09	14.32
10051	2004-11-30	7368	262.03	21.62	283.65
10052	2004-11-15	6672	77.97	6.43	84.40
10053	2004-11-17	5989	68.03	5.61	73.64
10054	2004-11-18	15371	238.97	19.72	258.69
10055	2004-11-09	10061	30.14	2.49	32.63
10056	2004-11-17	10479	37.97	3.13	41.10
10057	2004-11-06	15505	44.84	3.70	48.54
10058	2004-11-14	893	393.96	32.50	426.46
10059	2004-11-13	10848	191.42	15.79	207.21
10060	2004-11-07	14220	399.94	33.00	432.94
10061	2004-11-22	6170	166.05	13.70	179.75
10062	2004-11-22	15885	192.85	15.91	208.76
10063	2004-11-05	9398	119.58	9.87	129.45
10064	2004-11-23	7237	228.65	18.86	247.51
10065	2004-11-01	6318	3.07	0.25	3.32
10066	2004-11-17	16822	215.07	17.74	232.81
10067	2004-11-07	6174	278.24	22.95	301.19
10068	2004-11-24	10212	76.17	6.28	82.45
10069	2004-11-03	12467	190.99	15.76	206.75
10070	2004-11-12	10492	305.51	25.20	330.71
10071	2004-11-06	6320	138.26	11.41	149.67
10072	2004-11-19	6427	279.30	23.04	302.34
10073	2004-11-29	8246	148.82	12.28	161.10
10074	2004-11-03	15579	219.42	18.10	237.52
10075	2004-11-26	12038	179.79	14.83	194.62
10076	2004-11-19	4135	7.05	0.58	7.63
10077	2004-11-09	1324	55.28	4.56	59.84
10078	2004-11-14	17941	34.18	2.82	37.00
10079	2004-11-19	1093	243.80	20.11	263.91
10080	2004-11-11	10592	125.62	10.36	135.98
10081	2004-11-26	7871	397.63	32.80	430.43
10082	2004-11-26	8693	162.78	13.43	176.21
10083	2004-11-04	5608	391.44	32.29	423.73
10084	2004-11-05	4440	119.80	9.88	129.68
10085	2004-11-20	13243	270.67	22.33	293.00
10086	2004-11-17	306	62.09	5.12	67.21
10087	2004-11-01	18236	36.16	2.98	39.14
10088	2004-11-19	9173	372.90	30.76	403.66
10089	2004-11-05	4791	140.12	11.56	151.68
10090	2004-11-14	12952	218.62	18.04	236.66
10091	2004-11-27	5071	283.71	23.41	307.12
10092	2004-11-24	12721	295.76	24.40	320.16
10093	2004-11-16	15216	103.01	8.50	111.51
10094	2004-11-14	6828	145.63	12.01	157.64
10095	2004-11-11	2296	176.28	14.54	190.82
10096	2004-11-27	6060	289.91	23.92	313.83
10097	2004-11-10	13053	125.87	10.38	136.25
10098	2004-11-28	10361	184.32	15.21	199.53
10099	2004-11-19	9176	321.96	26.56	348.52
10100	2004-11-22	14231	294.77	24.32	319.09
10101	2004-11-21	2657	233.53	19.27	252.80
10102	2004-11-24	14176	117.19	9.67	126.86
10103	2004-11-11	36	367.82	30.35	398.17
10104	2004-11-25	6278	379.12	31.28	410.40
10105	2004-11-11	16790	321.68	26.54	348.22
10106	2004-11-25	15094	364.76	30.09	394.85
10107	2004-11-09	6205	249.90	20.62	270.52
10108	2004-11-16	722	128.96	10.64	139.60
10109	2004-11-05	6352	83.10	6.86	89.96
10110	2004-11-01	14768	218.53	18.03	236.56
10111	2004-11-15	14673	212.13	17.50	229.63
10112	2004-11-07	3935	223.86	18.47	242.33
10113	2004-11-04	3187	305.16	25.18	330.34
10114	2004-11-29	7556	350.24	28.89	379.13
10115	2004-11-05	9218	332.04	27.39	359.43
10116	2004-11-27	9523	28.72	2.37	31.09
10117	2004-11-03	9533	135.71	11.20	146.91
10118	2004-11-12	713	180.27	14.87	195.14
10119	2004-11-18	3732	341.27	28.15	369.42
10120	2004-11-23	1550	368.15	30.37	398.52
10121	2004-11-25	10058	70.98	5.86	76.84
10122	2004-11-14	4655	239.34	19.75	259.09
10123	2004-11-16	14282	240.26	19.82	260.08
10124	2004-11-22	12590	327.43	27.01	354.44
10125	2004-11-09	18735	158.65	13.09	171.74
10126	2004-11-28	10157	211.82	17.48	229.30
10127	2004-11-09	10625	337.06	27.81	364.87
10128	2004-11-16	6055	114.10	9.41	123.51
10129	2004-11-21	13015	1.14	0.09	1.23
10130	2004-11-21	5385	151.38	12.49	163.87
10131	2004-11-18	13904	383.66	31.65	415.31
10132	2004-11-01	12788	247.42	20.41	267.83
10133	2004-11-26	6156	75.19	6.20	81.39
10134	2004-11-29	15332	77.69	6.41	84.10
10135	2004-11-18	18680	250.80	20.69	271.49
10136	2004-11-11	12653	379.46	31.31	410.77
10137	2004-11-12	11080	396.18	32.68	428.86
10138	2004-11-07	15864	223.64	18.45	242.09
10139	2004-11-18	14629	121.05	9.99	131.04
10140	2004-11-21	2647	339.47	28.01	367.48
10141	2004-11-03	13217	127.21	10.49	137.70
10142	2004-11-28	4952	296.10	24.43	320.53
10143	2004-11-08	4891	28.16	2.32	30.48
10144	2004-11-18	12739	141.87	11.70	153.57
10145	2004-11-13	11934	141.38	11.66	153.04
10146	2004-11-21	15637	94.75	7.82	102.57
10147	2004-11-12	18391	86.67	7.15	93.82
10148	2004-11-07	17569	288.83	23.83	312.66
10149	2004-11-28	1383	55.67	4.59	60.26
10150	2004-11-29	19583	89.14	7.35	96.49
10151	2004-11-05	16614	183.12	15.11	198.23
10152	2004-11-24	3149	39.59	3.27	42.86
10153	2004-11-03	10238	306.10	25.25	331.35
10154	2004-11-25	4550	197.34	16.28	213.62
10155	2004-11-10	7255	92.58	7.64	100.22
10156	2004-11-01	14101	174.00	14.36	188.35
10157	2004-11-11	11843	209.30	17.27	226.57
10158	2004-11-13	1623	299.29	24.69	323.98
10159	2004-11-23	1616	267.88	22.10	289.98
10160	2004-11-14	5445	217.06	17.91	234.97
10161	2004-11-01	14263	300.83	24.82	325.65
10162	2004-11-14	16363	68.60	5.66	74.26
10163	2004-11-24	17450	294.47	24.29	318.76
10164	2004-11-08	13573	322.07	26.57	348.64
10165	2004-11-01	19897	19.35	1.60	20.95
10166	2004-11-06	981	355.08	29.29	384.37
10167	2004-11-07	2814	293.38	24.20	317.58
10168	2004-11-26	6352	180.26	14.87	195.13
10169	2004-11-05	6298	100.03	8.25	108.28
10170	2004-11-19	10486	117.72	9.71	127.43
10171	2004-11-07	13496	258.67	21.34	280.01
10172	2004-11-17	13639	352.77	29.10	381.87
10173	2004-11-11	16741	16.24	1.34	17.58
10174	2004-11-14	18907	28.03	2.31	30.34
10175	2004-11-08	5575	356.51	29.41	385.92
10176	2004-11-21	10551	392.65	32.39	425.04
10177	2004-11-01	6415	116.08	9.58	125.66
10178	2004-11-10	18493	189.77	15.66	205.43
10179	2004-11-24	82	256.73	21.18	277.91
10180	2004-11-12	3546	81.46	6.72	88.18
10181	2004-11-23	4831	152.81	12.61	165.42
10182	2004-11-12	16585	128.53	10.60	139.13
10183	2004-11-24	8747	103.71	8.56	112.27
10184	2004-11-23	3525	288.72	23.82	312.54
10185	2004-11-27	16126	113.25	9.34	122.59
10186	2004-11-24	6365	152.90	12.61	165.51
10187	2004-11-07	18406	233.69	19.28	252.97
10188	2004-11-22	15673	365.90	30.19	396.09
10189	2004-11-06	18980	314.18	25.92	340.10
10190	2004-11-20	18126	59.77	4.93	64.70
10191	2004-11-06	5804	350.79	28.94	379.73
10192	2004-11-07	13007	167.64	13.83	181.47
10193	2004-11-28	13717	243.53	20.09	263.62
10194	2004-11-25	12201	336.74	27.78	364.52
10195	2004-11-20	16772	243.42	20.08	263.50
10196	2004-11-17	18511	279.49	23.06	302.55
10197	2004-11-07	8159	11.86	0.98	12.84
10198	2004-11-27	18826	29.75	2.45	32.20
10199	2004-11-01	4446	390.51	32.22	422.73
10200	2004-11-21	9452	340.18	28.06	368.24
10201	2004-11-03	3364	368.84	30.43	399.27
10202	2004-11-22	1458	178.05	14.69	192.74
10203	2004-11-15	7160	185.80	15.33	201.13
10204	2004-11-19	6198	135.49	11.18	146.67
10205	2004-11-14	6247	327.79	27.04	354.83
10206	2004-11-22	16210	393.04	32.43	425.47
10207	2004-11-23	14769	52.67	4.35	57.02
10208	2004-11-04	5839	379.66	31.32	410.98
10209	2004-11-25	11030	170.66	14.08	184.74
10210	2004-11-10	3724	303.97	25.08	329.05
10211	2004-11-15	3811	201.26	16.60	217.86
10212	2004-11-28	5057	141.62	11.68	153.30
10213	2004-11-27	7889	332.74	27.45	360.19
10214	2004-11-07	3055	277.82	22.92	300.74
10215	2004-11-16	19119	35.73	2.95	38.68
10216	2004-11-15	17916	257.95	21.28	279.23
10217	2004-11-28	176	6.90	0.57	7.47
10218	2004-11-16	316	50.95	4.20	55.15
10219	2004-11-21	19201	44.66	3.68	48.34
10220	2004-11-11	5968	40.48	3.34	43.82
10221	2004-11-13	2704	275.61	22.74	298.35
10222	2004-11-03	2598	270.19	22.29	292.48
10223	2004-11-03	3556	108.90	8.98	117.88
10224	2004-11-01	9684	203.85	16.82	220.67
10225	2004-11-18	5567	325.28	26.84	352.12
10226	2004-11-14	18083	71.13	5.87	77.00
10227	2004-11-05	6691	144.43	11.92	156.35
10228	2004-11-10	13218	282.61	23.32	305.93
10229	2004-11-20	5500	42.78	3.53	46.31
10230	2004-11-08	893	391.65	32.31	423.96
10231	2004-11-05	4681	170.16	14.04	184.20
10232	2004-11-06	10764	117.26	9.67	126.93
10233	2004-11-26	539	323.58	26.70	350.28
10234	2004-11-25	7380	60.61	5.00	65.61
10235	2004-11-24	15538	113.03	9.32	122.35
10236	2004-11-20	9343	206.05	17.00	223.05
10237	2004-11-30	4961	49.33	4.07	53.40
10238	2004-11-20	1962	389.61	32.14	421.75
10239	2004-11-14	8792	173.64	14.33	187.97
10240	2004-11-14	15215	115.26	9.51	124.77
10241	2004-11-17	18867	169.90	14.02	183.92
10242	2004-11-28	6437	357.65	29.51	387.16
10243	2004-11-04	14877	211.45	17.44	228.89
10244	2004-11-07	12373	372.45	30.73	403.18
10245	2004-11-04	9446	356.21	29.39	385.60
10246	2004-11-10	1683	361.70	29.84	391.54
10247	2004-11-11	15474	56.29	4.64	60.93
10248	2004-11-24	7664	395.43	32.62	428.05
10249	2004-11-24	10450	248.04	20.46	268.50
10250	2004-11-03	14463	209.17	17.26	226.43
10251	2004-11-09	13250	292.31	24.12	316.43
10252	2004-11-26	12210	236.98	19.55	256.53
10253	2004-11-08	4852	258.80	21.35	280.15
10254	2004-11-24	8665	266.49	21.99	288.48
10255	2004-11-20	16953	235.16	19.40	254.56
10256	2004-11-10	3241	92.23	7.61	99.84
10257	2004-11-27	9052	383.69	31.65	415.34
10258	2004-11-25	3840	321.99	26.56	348.55
10259	2004-11-04	17977	63.25	5.22	68.47
10260	2004-11-12	15848	134.32	11.08	145.40
10261	2004-11-28	2158	276.34	22.80	299.14
10262	2004-11-21	10835	194.68	16.06	210.74
10263	2004-11-26	8251	157.07	12.96	170.03
10264	2004-11-19	16134	265.75	21.92	287.67
10265	2004-11-02	7512	292.27	24.11	316.38
10266	2004-11-04	5701	140.56	11.60	152.16
10267	2004-11-15	15701	270.22	22.29	292.51
10268	2004-11-13	15242	246.12	20.30	266.42
10269	2004-11-30	17889	254.60	21.00	275.60
10270	2004-11-15	12655	235.60	19.44	255.04
10271	2004-11-11	17054	102.29	8.44	110.73
10272	2004-11-12	4435	201.95	16.66	218.61
10273	2004-11-13	1681	63.33	5.22	68.55
10274	2004-11-24	15766	233.85	19.29	253.14
10275	2004-11-29	10421	285.70	23.57	309.27
10276	2004-11-27	8965	388.13	32.02	420.15
10277	2004-11-16	309	278.98	23.02	302.00
10278	2004-11-10	6288	334.64	27.61	362.25
10279	2004-11-05	6552	307.52	25.37	332.89
10280	2004-11-01	18056	332.57	27.44	360.01
10281	2004-11-26	21	24.32	2.01	26.33
10282	2004-11-12	10343	371.97	30.69	402.66
10283	2004-11-18	2999	172.74	14.25	186.99
10284	2004-11-27	14117	311.34	25.69	337.03
10285	2004-11-11	11366	155.57	12.83	168.40
10286	2004-11-26	16761	344.08	28.39	372.47
10287	2004-11-05	18449	193.19	15.94	209.13
10288	2004-11-18	1781	199.67	16.47	216.14
10289	2004-11-23	17679	343.17	28.31	371.48
10290	2004-11-13	5734	79.21	6.53	85.74
10291	2004-11-18	9135	125.73	10.37	136.10
10292	2004-11-09	15757	272.44	22.48	294.92
10293	2004-11-04	4426	377.86	31.17	409.03
10294	2004-11-25	3799	78.37	6.47	84.84
10295	2004-11-08	4856	89.56	7.39	96.95
10296	2004-11-11	196	252.63	20.84	273.47
10297	2004-11-30	537	364.85	30.10	394.95
10298	2004-11-17	6553	330.54	27.27	357.81
10299	2004-11-14	19977	103.21	8.51	111.72
10300	2004-11-24	8041	188.59	15.56	204.15
10301	2004-11-04	11493	72.58	5.99	78.57
10302	2004-11-12	17928	312.05	25.74	337.79
10303	2004-11-17	9924	36.66	3.02	39.68
10304	2004-11-28	19386	197.86	16.32	214.18
10305	2004-11-27	10657	160.09	13.21	173.30
10306	2004-11-30	7706	378.21	31.20	409.41
10307	2004-11-03	19167	308.38	25.44	333.82
10308	2004-11-19	9077	70.69	5.83	76.52
10309	2004-11-03	14369	198.89	16.41	215.30
10310	2004-11-06	7275	246.59	20.34	266.93
10311	2004-11-15	18430	250.47	20.66	271.13
10312	2004-11-01	1112	338.75	27.95	366.70
10313	2004-11-23	8872	81.71	6.74	88.45
10314	2004-11-11	15985	289.38	23.87	313.25
10315	2004-11-06	10755	97.89	8.08	105.97
10316	2004-11-28	13950	164.34	13.56	177.90
10317	2004-11-20	6286	346.22	28.56	374.78
10318	2004-11-28	12010	135.74	11.20	146.94
10319	2004-11-30	2531	89.75	7.40	97.15
10320	2004-11-23	2777	187.86	15.50	203.36
10321	2004-11-28	1990	398.37	32.87	431.24
10322	2004-11-24	14950	328.98	27.14	356.12
10323	2004-11-05	10062	81.25	6.70	87.95
10324	2004-11-20	6832	70.29	5.80	76.09
10325	2004-11-29	5510	86.88	7.17	94.05
10326	2004-11-07	19194	35.82	2.96	38.78
10327	2004-11-22	15122	181.93	15.01	196.94
10328	2004-11-10	2654	305.25	25.18	330.43
10329	2004-11-22	8706	231.84	19.13	250.97
10330	2004-11-30	14145	195.70	16.15	211.85
10331	2004-11-28	5930	25.45	2.10	27.55
10332	2004-11-21	3331	183.74	15.16	198.90
10333	2004-11-18	19154	36.80	3.04	39.84
10334	2004-11-21	18300	87.25	7.20	94.45
10335	2004-11-07	3581	138.40	11.42	149.82
10336	2004-11-04	11131	111.57	9.20	120.77
10337	2004-11-05	2332	389.79	32.16	421.95
10338	2004-11-17	19501	282.35	23.29	305.64
10339	2004-11-18	9164	128.17	10.57	138.74
10340	2004-11-25	11918	51.99	4.29	56.28
10341	2004-11-30	17171	307.51	25.37	332.88
10342	2004-11-06	985	38.48	3.17	41.65
10343	2004-11-20	4201	349.81	28.86	378.67
10344	2004-11-06	6091	105.86	8.73	114.59
10345	2004-11-19	8250	122.60	10.11	132.71
10346	2004-11-18	9688	171.78	14.17	185.95
10347	2004-11-25	3125	156.13	12.88	169.01
10348	2004-11-03	595	122.54	10.11	132.65
10349	2004-11-07	5218	225.36	18.59	243.95
10350	2004-11-11	14958	332.98	27.47	360.45
10351	2004-11-14	17534	52.55	4.34	56.89
10352	2004-11-03	17961	281.31	23.21	304.52
10353	2004-11-09	15264	244.97	20.21	265.18
10354	2004-11-12	11578	372.54	30.73	403.27
10355	2004-11-25	11001	297.68	24.56	322.24
10356	2004-11-22	4605	309.39	25.52	334.91
10357	2004-11-22	12107	21.27	1.75	23.02
10358	2004-11-24	7676	379.73	31.33	411.06
10359	2004-11-04	6374	203.81	16.81	220.62
10360	2004-11-27	2626	235.68	19.44	255.12
10361	2004-11-30	12365	391.94	32.34	424.28
10362	2004-11-18	15483	321.81	26.55	348.36
10363	2004-11-11	18118	361.73	29.84	391.57
10364	2004-11-26	3178	266.52	21.99	288.51
10365	2004-11-10	3300	392.94	32.42	425.36
10366	2004-11-26	4314	251.53	20.75	272.28
10367	2004-11-10	530	179.91	14.84	194.75
10368	2004-11-29	5787	243.39	20.08	263.47
10369	2004-11-13	3009	50.99	4.21	55.20
10370	2004-11-09	15654	173.79	14.34	188.13
10371	2004-11-12	4465	311.27	25.68	336.95
10372	2004-11-30	14193	66.04	5.45	71.49
10373	2004-11-21	8797	358.48	29.57	388.05
10374	2004-11-07	1673	198.77	16.40	215.17
10375	2004-11-11	17625	116.40	9.60	126.00
10376	2004-11-01	12753	244.89	20.20	265.09
10377	2004-11-06	16862	1.22	0.10	1.32
10378	2004-11-20	10656	284.56	23.48	308.04
10379	2004-11-22	8757	128.26	10.58	138.84
10380	2004-11-02	9772	298.48	24.62	323.10
10381	2004-11-08	13136	140.04	11.55	151.59
10382	2004-11-23	14995	54.06	4.46	58.52
10383	2004-11-04	12997	334.72	27.61	362.33
10384	2004-11-27	13013	324.76	26.79	351.55
10385	2004-11-26	12899	180.22	14.87	195.09
10386	2004-11-30	15034	253.73	20.93	274.66
10387	2004-11-28	806	198.80	16.40	215.20
10388	2004-11-01	9593	29.88	2.47	32.35
10389	2004-11-12	19200	339.33	27.99	367.32
10390	2004-11-05	13588	397.68	32.81	430.49
10391	2004-11-01	9837	224.33	18.51	242.84
10392	2004-11-08	19193	55.94	4.62	60.56
10393	2004-11-19	227	77.87	6.42	84.29
10394	2004-11-14	12471	163.01	13.45	176.46
10395	2004-11-13	8879	373.07	30.78	403.85
10396	2004-11-09	15824	294.14	24.27	318.41
10397	2004-11-28	14126	371.79	30.67	402.46
10398	2004-11-21	18065	347.46	28.67	376.13
10399	2004-11-02	15899	41.36	3.41	44.77
10400	2004-11-03	6275	397.33	32.78	430.11
10401	2004-11-30	5517	23.84	1.97	25.81
10402	2004-11-05	12759	29.40	2.43	31.83
10403	2004-11-22	13545	64.04	5.28	69.32
10404	2004-11-27	16568	123.32	10.17	133.49
10405	2004-11-18	19185	193.07	15.93	209.00
10406	2004-11-29	11257	200.26	16.52	216.78
10407	2004-11-20	12886	175.19	14.45	189.64
10408	2004-11-05	17819	143.56	11.84	155.40
10409	2004-11-07	3678	204.56	16.88	221.44
10410	2004-11-30	8729	54.80	4.52	59.32
10411	2004-11-08	8594	156.35	12.90	169.25
10412	2004-11-28	19222	216.37	17.85	234.22
10413	2004-11-02	3826	374.96	30.93	405.89
10414	2004-11-27	12830	53.50	4.41	57.91
10415	2004-11-25	8678	37.38	3.08	40.46
10416	2004-11-11	1938	159.51	13.16	172.67
10417	2004-11-18	4814	373.79	30.84	404.63
10418	2004-11-05	888	127.39	10.51	137.90
10419	2004-11-30	1164	141.43	11.67	153.10
10420	2004-11-25	1901	343.49	28.34	371.83
10421	2004-11-25	2548	344.75	28.44	373.19
10422	2004-11-05	9926	199.90	16.49	216.39
10423	2004-11-18	19495	272.20	22.46	294.66
10424	2004-11-23	8281	21.33	1.76	23.09
10425	2004-11-22	4245	312.72	25.80	338.52
10426	2004-11-28	7158	357.55	29.50	387.05
10427	2004-11-16	2166	79.91	6.59	86.50
10428	2004-11-10	11395	15.17	1.25	16.42
10429	2004-11-03	9908	53.54	4.42	57.96
10430	2004-11-14	18238	108.14	8.92	117.06
10431	2004-11-18	12135	251.88	20.78	272.66
10432	2004-11-29	7596	87.93	7.25	95.18
10433	2004-11-23	12324	3.55	0.29	3.84
10434	2004-11-26	7979	311.99	25.74	337.73
10435	2004-11-16	6689	262.80	21.68	284.48
10436	2004-11-23	14800	97.84	8.07	105.91
10437	2004-11-23	541	140.16	11.56	151.72
10438	2004-11-20	11331	204.94	16.91	221.85
10439	2004-11-05	5848	180.51	14.89	195.40
10440	2004-11-03	12480	307.83	25.40	333.23
10441	2004-11-26	5682	29.37	2.42	31.79
10442	2004-11-28	19622	367.66	30.33	397.99
10443	2004-11-14	10996	145.78	12.03	157.81
10444	2004-11-05	3191	266.95	22.02	288.97
10445	2004-11-01	8957	371.02	30.61	401.63
10446	2004-11-11	3782	25.22	2.08	27.30
10447	2004-11-26	16509	332.83	27.46	360.29
10448	2004-11-02	18049	109.23	9.01	118.24
10449	2004-11-13	13694	120.77	9.96	130.73
10450	2004-11-01	15027	58.17	4.80	62.97
10451	2004-11-24	5302	359.37	29.65	389.02
10452	2004-11-01	10249	228.71	18.87	247.58
10453	2004-11-03	18350	54.26	4.48	58.74
10454	2004-11-05	4574	229.99	18.97	248.96
10455	2004-11-03	6910	309.92	25.57	335.49
10456	2004-11-01	11912	366.02	30.20	396.22
10457	2004-11-12	14461	120.75	9.96	130.71
10458	2004-11-10	19047	297.53	24.55	322.08
10459	2004-11-25	5703	377.97	31.18	409.15
10460	2004-11-16	959	94.98	7.84	102.82
10461	2004-11-08	7951	328.55	27.11	355.66
10462	2004-11-16	5031	276.76	22.83	299.59
10463	2004-11-25	5994	364.23	30.05	394.28
10464	2004-11-04	10015	282.87	23.34	306.21
10465	2004-11-28	18526	20.09	1.66	21.75
10466	2004-11-20	17460	369.76	30.51	400.27
10467	2004-11-25	13615	257.95	21.28	279.23
10468	2004-11-19	9724	240.71	19.86	260.57
10469	2004-11-20	9602	53.76	4.44	58.20
10470	2004-11-07	10262	84.20	6.95	91.15
10471	2004-11-27	8351	335.14	27.65	362.79
10472	2004-11-15	16606	309.63	25.54	335.17
10473	2004-11-09	8147	322.10	26.57	348.67
10474	2004-11-19	13691	312.98	25.82	338.80
10475	2004-11-23	8031	204.10	16.84	220.94
10476	2004-11-14	478	44.58	3.68	48.26
10477	2004-11-22	11919	72.95	6.02	78.97
10478	2004-11-29	5791	9.49	0.78	10.27
10479	2004-11-23	7244	225.88	18.64	244.52
10480	2004-11-19	2893	135.67	11.19	146.86
10481	2004-11-17	8657	27.46	2.27	29.73
10482	2004-11-16	13729	377.71	31.16	408.87
10483	2004-11-22	4964	156.90	12.94	169.84
10484	2004-11-21	11784	112.37	9.27	121.64
10485	2004-11-08	9898	269.90	22.27	292.17
10486	2004-11-17	19858	166.53	13.74	180.27
10487	2004-11-18	11082	357.66	29.51	387.17
10488	2004-11-25	966	261.45	21.57	283.02
10489	2004-11-24	2977	55.08	4.54	59.62
10490	2004-11-20	8844	4.04	0.33	4.37
10491	2004-11-02	16588	306.01	25.25	331.26
10492	2004-11-07	5588	186.70	15.40	202.10
10493	2004-11-02	1376	99.36	8.20	107.56
10494	2004-11-29	7651	32.07	2.65	34.72
10495	2004-11-22	8014	328.20	27.08	355.28
10496	2004-11-06	16641	307.59	25.38	332.97
10497	2004-11-08	12789	86.47	7.13	93.60
10498	2004-11-23	3231	70.97	5.86	76.83
10499	2004-11-01	6113	43.34	3.58	46.92
10500	2004-11-05	12366	28.62	2.36	30.98
10501	2004-11-09	5520	396.25	32.69	428.94
10502	2004-11-24	2982	139.92	11.54	151.46
10503	2004-11-27	8661	197.96	16.33	214.29
10504	2004-11-21	612	374.49	30.90	405.39
10505	2004-11-07	13076	144.59	11.93	156.52
10506	2004-11-08	7470	198.92	16.41	215.33
10507	2004-11-20	6052	21.34	1.76	23.10
10508	2004-11-14	14739	49.24	4.06	53.30
10509	2004-11-14	17115	57.31	4.73	62.04
10510	2004-11-22	1037	63.20	5.21	68.41
10511	2004-11-28	9359	165.41	13.65	179.06
10512	2004-11-17	19659	148.88	12.28	161.16
10513	2004-11-05	3757	338.11	27.89	366.00
10514	2004-11-02	8453	300.28	24.77	325.05
10515	2004-11-29	15613	113.70	9.38	123.08
10516	2004-11-04	4016	109.02	8.99	118.01
10517	2004-11-30	12724	65.44	5.40	70.84
10518	2004-11-26	7260	320.20	26.42	346.62
10519	2004-11-28	15602	375.03	30.94	405.97
10520	2004-11-02	2356	67.69	5.58	73.27
10521	2004-11-20	2595	119.76	9.88	129.64
10522	2004-11-21	5295	269.67	22.25	291.92
10523	2004-11-24	7891	85.73	7.07	92.80
10524	2004-11-27	8512	214.67	17.71	232.38
10525	2004-11-25	10944	18.09	1.49	19.58
10526	2004-11-21	16518	259.87	21.44	281.31
10527	2004-11-23	10498	175.40	14.47	189.87
10528	2004-11-01	8380	267.10	22.04	289.14
10529	2004-11-26	19177	107.25	8.85	116.10
10530	2004-11-30	10952	1.14	0.09	1.23
10531	2004-11-27	3117	27.79	2.29	30.08
10532	2004-11-24	18706	224.16	18.49	242.65
10533	2004-11-14	18833	355.86	29.36	385.22
10534	2004-11-25	14132	207.59	17.13	224.72
10535	2004-11-30	5379	137.20	11.32	148.52
10536	2004-11-17	11313	106.23	8.76	114.99
10537	2004-11-22	8187	223.02	18.40	241.42
10538	2004-11-02	1484	254.71	21.01	275.72
10539	2004-11-17	3173	95.26	7.86	103.12
10540	2004-11-12	3461	183.32	15.12	198.44
10541	2004-11-05	1411	126.86	10.47	137.33
10542	2004-11-09	12691	250.20	20.64	270.84
10543	2004-11-25	1515	122.11	10.07	132.18
10544	2004-11-10	6225	391.69	32.31	424.00
10545	2004-11-19	17501	3.71	0.31	4.02
10546	2004-11-12	1280	172.15	14.20	186.35
10547	2004-11-14	16718	252.28	20.81	273.09
10548	2004-11-29	19348	277.81	22.92	300.73
10549	2004-11-16	12492	13.41	1.11	14.52
10550	2004-11-09	12597	147.30	12.15	159.45
10551	2004-11-16	18103	23.74	1.96	25.70
10552	2004-11-09	13293	87.79	7.24	95.03
10553	2004-11-21	17188	379.11	31.28	410.39
10554	2004-11-05	4991	397.59	32.80	430.39
10555	2004-11-06	19337	343.62	28.35	371.97
10556	2004-11-27	10827	91.72	7.57	99.29
10557	2004-11-23	4676	25.90	2.14	28.04
10558	2004-11-05	9860	184.09	15.19	199.28
10559	2004-11-23	2714	200.15	16.51	216.66
10560	2004-11-04	18797	380.24	31.37	411.61
10561	2004-11-04	1049	373.54	30.82	404.36
10562	2004-11-05	10947	172.64	14.24	186.88
10563	2004-11-19	2613	335.26	27.66	362.92
10564	2004-11-13	10486	352.20	29.06	381.26
10565	2004-11-26	11613	65.83	5.43	71.26
10566	2004-11-13	6010	281.85	23.25	305.10
10567	2004-11-10	10448	214.94	17.73	232.67
10568	2004-11-04	12086	294.38	24.29	318.67
10569	2004-11-02	18737	33.60	2.77	36.37
10570	2004-11-28	16009	103.34	8.53	111.87
10571	2004-11-08	10274	190.17	15.69	205.86
10572	2004-11-06	11960	288.98	23.84	312.82
10573	2004-11-23	10690	279.30	23.04	302.34
10574	2004-11-15	7683	121.73	10.04	131.77
10575	2004-11-07	1383	364.32	30.06	394.38
10576	2004-11-22	14875	224.47	18.52	242.99
10577	2004-11-02	7313	29.22	2.41	31.63
10578	2004-11-08	348	271.33	22.38	293.71
10579	2004-11-17	13836	128.36	10.59	138.95
10580	2004-11-09	9305	70.66	5.83	76.49
10581	2004-11-05	3173	24.13	1.99	26.12
10582	2004-11-04	15323	203.64	16.80	220.44
10583	2004-11-01	14904	396.40	32.70	429.10
10584	2004-11-29	12596	41.42	3.42	44.84
10585	2004-11-02	14266	38.19	3.15	41.34
10586	2004-11-19	126	224.48	18.52	243.00
10587	2004-11-01	17727	346.99	28.63	375.62
10588	2004-11-23	7820	99.06	8.17	107.23
10589	2004-11-11	18745	305.59	25.21	330.80
10590	2004-11-28	18779	374.19	30.87	405.06
10591	2004-11-25	17598	321.65	26.54	348.19
10592	2004-11-18	19031	355.50	29.33	384.83
10593	2004-11-21	8490	89.14	7.35	96.49
10594	2004-11-12	9641	227.08	18.73	245.81
10595	2004-11-29	11792	29.95	2.47	32.42
10596	2004-11-14	8323	16.61	1.37	17.98
10597	2004-11-23	937	349.10	28.80	377.90
10598	2004-11-13	2224	33.64	2.78	36.42
10599	2004-11-09	3021	179.83	14.84	194.67
10600	2004-11-13	6563	10.69	0.88	11.57
10601	2004-11-07	1248	70.38	5.81	76.19
10602	2004-11-22	16634	110.27	9.10	119.37
10603	2004-11-11	8038	297.64	24.56	322.20
10604	2004-11-08	7493	352.58	29.09	381.67
10605	2004-11-30	17857	254.02	20.96	274.98
10606	2004-11-06	16490	154.36	12.73	167.09
10607	2004-11-24	6884	121.12	9.99	131.11
10608	2004-11-08	13987	382.08	31.52	413.60
10609	2004-11-15	8775	391.08	32.26	423.34
10610	2004-11-08	673	280.34	23.13	303.47
10611	2004-11-05	10853	68.37	5.64	74.01
10612	2004-11-27	14661	303.65	25.05	328.70
10613	2004-11-07	17551	91.81	7.57	99.38
10614	2004-11-13	10182	390.37	32.21	422.58
10615	2004-11-09	1111	335.85	27.71	363.56
10616	2004-11-10	9450	210.27	17.35	227.62
10617	2004-11-03	2521	347.27	28.65	375.92
10618	2004-11-20	2506	100.36	8.28	108.64
10619	2004-11-05	2047	55.10	4.55	59.65
10620	2004-11-10	13358	107.50	8.87	116.37
10621	2004-11-11	11079	130.17	10.74	140.91
10622	2004-11-12	17939	201.84	16.65	218.49
10623	2004-11-26	4721	353.92	29.20	383.12
10624	2004-11-01	15103	0.50	0.04	0.54
10625	2004-11-18	16782	293.28	24.20	317.48
10626	2004-11-18	3700	178.08	14.69	192.77
10627	2004-11-27	324	150.51	12.42	162.93
10628	2004-11-02	11768	228.11	18.82	246.93
10629	2004-11-12	6285	77.30	6.38	83.68
10630	2004-11-13	1462	187.49	15.47	202.96
10631	2004-11-08	14269	82.21	6.78	88.99
10632	2004-11-13	11886	197.89	16.33	214.22
10633	2004-11-14	8709	115.08	9.49	124.57
10634	2004-11-18	16514	138.03	11.39	149.42
10635	2004-11-17	1149	108.60	8.96	117.56
10636	2004-11-18	2647	36.76	3.03	39.79
10637	2004-11-15	16109	18.62	1.54	20.16
10638	2004-11-18	1259	174.23	14.37	188.60
10639	2004-11-28	9658	147.00	12.13	159.13
10640	2004-11-26	8054	94.20	7.77	101.97
10641	2004-11-20	17933	335.56	27.68	363.24
10642	2004-11-17	2729	255.06	21.04	276.10
10643	2004-11-08	9585	36.25	2.99	39.24
10644	2004-11-08	4339	150.36	12.40	162.76
10645	2004-11-17	4145	215.26	17.76	233.02
10646	2004-11-08	14546	287.19	23.69	310.88
10647	2004-11-19	11455	304.62	25.13	329.75
10648	2004-11-28	8144	25.16	2.08	27.24
10649	2004-11-21	17282	158.05	13.04	171.09
10650	2004-11-05	690	237.81	19.62	257.43
10651	2004-11-06	3516	349.58	28.84	378.42
10652	2004-11-06	15535	189.23	15.61	204.84
10653	2004-11-29	14816	256.58	21.17	277.75
10654	2004-11-08	5051	355.13	29.30	384.43
10655	2004-11-30	7973	68.89	5.68	74.57
10656	2004-11-23	17977	79.76	6.58	86.34
10657	2004-11-10	8798	277.15	22.86	300.01
10658	2004-11-24	712	235.23	19.41	254.64
10659	2004-11-20	16950	162.07	13.37	175.44
10660	2004-11-16	11951	187.86	15.50	203.36
10661	2004-11-05	7372	310.27	25.60	335.87
10662	2004-11-11	8167	213.57	17.62	231.19
10663	2004-11-18	10309	312.94	25.82	338.76
10664	2004-11-29	13956	1.73	0.14	1.87
10665	2004-11-16	9101	311.52	25.70	337.22
10666	2004-11-03	10215	300.54	24.79	325.33
10667	2004-11-20	12653	198.86	16.41	215.27
10668	2004-11-09	12384	7.59	0.63	8.22
10669	2004-11-10	4169	295.14	24.35	319.49
10670	2004-11-25	2465	294.55	24.30	318.85
10671	2004-11-12	14875	2.75	0.23	2.98
10672	2004-11-26	1233	335.16	27.65	362.81
10673	2004-11-20	2128	60.98	5.03	66.01
10674	2004-11-26	17933	165.03	13.61	178.64
10675	2004-11-04	15050	313.91	25.90	339.81
10676	2004-11-28	16659	158.80	13.10	171.90
10677	2004-11-10	2	5.08	0.42	5.50
10678	2004-11-12	17701	3.15	0.26	3.41
10679	2004-11-12	9311	373.32	30.80	404.12
10680	2004-11-07	8334	322.43	26.60	349.03
10681	2004-11-25	6817	121.59	10.03	131.62
10682	2004-11-11	17228	280.40	23.13	303.53
10683	2004-11-26	18177	217.52	17.95	235.47
10684	2004-11-04	2754	298.05	24.59	322.64
10685	2004-11-05	753	65.64	5.42	71.06
10686	2004-11-14	17484	205.69	16.97	222.66
10687	2004-11-13	12548	105.36	8.69	114.05
10688	2004-11-15	12746	94.68	7.81	102.49
10689	2004-11-17	19294	31.27	2.58	33.85
10690	2004-11-24	12844	341.57	28.18	369.75
10691	2004-11-07	17664	89.86	7.41	97.27
10692	2004-11-01	16355	96.55	7.97	104.52
10693	2004-11-10	19674	360.60	29.75	390.35
10694	2004-11-12	13181	357.98	29.53	387.51
10695	2004-11-22	17024	159.96	13.20	173.16
10696	2004-11-05	1489	212.35	17.52	229.87
10697	2004-11-12	1577	250.79	20.69	271.48
10698	2004-11-02	3386	160.05	13.20	173.25
10699	2004-11-10	14193	188.43	15.55	203.98
10700	2004-11-23	12929	6.67	0.55	7.22
10701	2004-11-19	18931	112.98	9.32	122.30
10702	2004-11-09	5032	340.47	28.09	368.56
10703	2004-11-03	12688	154.87	12.78	167.65
10704	2004-11-26	701	163.17	13.46	176.63
10705	2004-11-16	13932	380.84	31.42	412.26
10706	2004-11-18	15978	362.48	29.90	392.38
10707	2004-11-16	13702	257.42	21.24	278.66
10708	2004-11-20	8305	261.47	21.57	283.04
10709	2004-11-18	5991	236.61	19.52	256.13
10710	2004-11-15	5027	101.08	8.34	109.42
10711	2004-11-17	3325	164.96	13.61	178.57
10712	2004-11-21	13601	393.51	32.46	425.97
10713	2004-11-05	19002	41.13	3.39	44.52
10714	2004-11-08	19954	210.91	17.40	228.31
10715	2004-11-05	12094	391.74	32.32	424.06
10716	2004-11-30	14422	85.24	7.03	92.27
10717	2004-11-22	6273	320.30	26.42	346.72
10718	2004-11-01	13762	115.38	9.52	124.90
10719	2004-11-26	2530	307.64	25.38	333.02
10720	2004-11-08	10939	161.11	13.29	174.40
10721	2004-11-15	2108	19.94	1.65	21.59
10722	2004-11-16	11455	396.72	32.73	429.45
10723	2004-11-29	6879	362.09	29.87	391.96
10724	2004-11-24	19040	30.57	2.52	33.09
10725	2004-11-26	15039	365.80	30.18	395.98
10726	2004-11-02	16132	86.06	7.10	93.16
10727	2004-11-18	2017	26.15	2.16	28.31
10728	2004-11-25	3055	104.40	8.61	113.01
10729	2004-11-04	4154	92.90	7.66	100.56
10730	2004-11-26	9802	254.97	21.04	276.01
10731	2004-11-15	1408	129.25	10.66	139.91
10732	2004-11-05	4457	75.72	6.25	81.97
10733	2004-11-09	6242	47.99	3.96	51.95
10734	2004-11-05	4962	358.65	29.59	388.24
10735	2004-11-04	5786	343.14	28.31	371.45
10736	2004-11-21	19547	270.54	22.32	292.86
10737	2004-11-29	8606	166.03	13.70	179.73
10738	2004-11-01	1167	164.38	13.56	177.94
10739	2004-11-17	7245	192.40	15.87	208.27
10740	2004-11-03	6526	256.40	21.15	277.55
10741	2004-11-11	19556	97.41	8.04	105.45
10742	2004-11-29	1898	355.32	29.31	384.63
10743	2004-11-02	2390	148.70	12.27	160.97
10744	2004-11-24	15097	22.93	1.89	24.82
10745	2004-11-24	10082	222.69	18.37	241.06
10746	2004-11-06	3349	291.95	24.09	316.04
10747	2004-11-28	9507	228.16	18.82	246.98
10748	2004-11-20	8539	399.20	32.93	432.13
10749	2004-11-24	285	305.71	25.22	330.93
10750	2004-11-07	16150	172.04	14.19	186.23
10751	2004-11-23	669	331.98	27.39	359.37
10752	2004-11-24	11606	180.79	14.92	195.71
10753	2004-11-07	7247	293.92	24.25	318.17
10754	2004-11-04	7375	66.25	5.47	71.72
10755	2004-11-12	15535	43.66	3.60	47.26
10756	2004-11-25	19331	400.00	33.00	433.00
10757	2004-11-11	1067	165.64	13.67	179.31
10758	2004-11-22	6128	169.16	13.96	183.12
10759	2004-11-18	19004	33.87	2.79	36.66
10760	2004-11-23	7508	251.17	20.72	271.89
10761	2004-11-17	8355	135.49	11.18	146.67
10762	2004-11-16	10802	257.36	21.23	278.59
10763	2004-11-08	5511	66.62	5.50	72.12
10764	2004-11-01	12256	370.48	30.56	401.04
10765	2004-11-12	410	220.56	18.20	238.76
10766	2004-11-17	14395	215.38	17.77	233.15
10767	2004-11-10	1308	296.85	24.49	321.34
10768	2004-11-02	2647	184.93	15.26	200.19
10769	2004-11-12	15829	19.68	1.62	21.30
10770	2004-11-22	8766	275.28	22.71	297.99
10771	2004-11-29	13374	331.86	27.38	359.24
10772	2004-11-05	10239	15.79	1.30	17.09
10773	2004-11-07	6813	283.87	23.42	307.29
10774	2004-11-08	11908	10.18	0.84	11.02
10775	2004-11-15	7397	202.97	16.75	219.72
10776	2004-11-21	19495	33.23	2.74	35.97
10777	2004-11-12	11585	43.22	3.57	46.79
10778	2004-11-14	583	284.63	23.48	308.11
10779	2004-11-16	11649	307.54	25.37	332.91
10780	2004-11-24	13335	123.88	10.22	134.10
10781	2004-11-23	801	64.36	5.31	69.67
10782	2004-11-15	14124	311.69	25.71	337.40
10783	2004-11-29	732	138.43	11.42	149.85
10784	2004-11-15	6287	324.16	26.74	350.90
10785	2004-11-24	19879	206.98	17.08	224.06
10786	2004-11-10	17198	98.57	8.13	106.70
10787	2004-11-18	8016	388.26	32.03	420.29
10788	2004-11-16	1192	77.40	6.39	83.79
10789	2004-11-10	12479	169.50	13.98	183.48
10790	2004-11-26	1510	271.54	22.40	293.94
10791	2004-11-18	19127	351.05	28.96	380.01
10792	2004-11-07	7444	5.23	0.43	5.66
10793	2004-11-08	10199	77.76	6.42	84.18
10794	2004-11-02	5932	257.61	21.25	278.86
10795	2004-11-14	9494	127.84	10.55	138.39
10796	2004-11-14	1096	280.03	23.10	303.13
10797	2004-11-18	14697	72.88	6.01	78.89
10798	2004-11-05	2656	394.53	32.55	427.08
10799	2004-11-29	7164	227.73	18.79	246.52
10800	2004-11-01	19919	0.57	0.05	0.62
10801	2004-11-09	6510	183.30	15.12	198.42
10802	2004-11-16	15351	262.69	21.67	284.36
10803	2004-11-20	17097	210.21	17.34	227.55
10804	2004-11-26	2814	337.76	27.87	365.63
10805	2004-11-02	2284	388.86	32.08	420.94
10806	2004-11-27	7656	11.78	0.97	12.75
10807	2004-11-16	9058	167.43	13.81	181.24
10808	2004-11-27	8322	279.93	23.09	303.02
10809	2004-11-16	1267	270.39	22.31	292.70
10810	2004-11-02	11185	186.87	15.42	202.29
10811	2004-11-02	18038	255.07	21.04	276.11
10812	2004-11-24	17716	24.35	2.01	26.36
10813	2004-11-04	4758	263.64	21.75	285.39
10814	2004-11-13	6492	127.76	10.54	138.30
10815	2004-11-24	741	308.40	25.44	333.84
10816	2004-11-05	16061	107.81	8.89	116.70
10817	2004-11-05	4194	112.44	9.28	121.72
10818	2004-11-24	17076	28.97	2.39	31.36
10819	2004-11-24	7239	177.12	14.61	191.73
10820	2004-11-27	11332	267.93	22.10	290.03
10821	2004-11-13	19613	123.73	10.21	133.94
10822	2004-11-24	2435	187.59	15.48	203.07
10823	2004-11-08	19932	83.13	6.86	89.99
10824	2004-11-01	11872	130.23	10.74	140.97
10825	2004-11-29	10592	1.06	0.09	1.15
10826	2004-11-20	7139	201.06	16.59	217.65
10827	2004-11-22	9258	206.19	17.01	223.20
10828	2004-11-13	15835	54.64	4.51	59.15
10829	2004-11-20	7789	138.09	11.39	149.48
10830	2004-11-20	19522	373.42	30.81	404.23
10831	2004-11-25	16419	172.96	14.27	187.23
10832	2004-11-22	7869	195.56	16.13	211.69
10833	2004-11-25	19384	346.76	28.61	375.37
10834	2004-11-05	3778	291.04	24.01	315.05
10835	2004-11-20	14889	25.11	2.07	27.18
10836	2004-11-03	19977	298.54	24.63	323.17
10837	2004-11-30	14035	64.72	5.34	70.06
10838	2004-11-13	6130	363.05	29.95	393.00
10839	2004-11-24	16615	324.07	26.74	350.81
10840	2004-11-13	13331	50.15	4.14	54.29
10841	2004-11-10	4322	173.09	14.28	187.37
10842	2004-11-24	443	258.63	21.34	279.97
10843	2004-11-22	15978	53.47	4.41	57.88
10844	2004-11-03	6065	188.69	15.57	204.26
10845	2004-11-26	453	320.13	26.41	346.54
10846	2004-11-07	14133	230.45	19.01	249.46
10847	2004-11-17	12347	120.82	9.97	130.79
10848	2004-11-23	9225	359.89	29.69	389.58
10849	2004-11-12	15848	387.38	31.96	419.34
10850	2004-11-27	1897	237.82	19.62	257.44
10851	2004-11-19	3990	85.27	7.03	92.30
10852	2004-11-06	16123	51.51	4.25	55.76
10853	2004-11-20	11994	3.79	0.31	4.10
10854	2004-11-11	808	386.53	31.89	418.42
10855	2004-11-13	4805	117.44	9.69	127.13
10856	2004-11-17	19420	45.86	3.78	49.64
10857	2004-11-07	2350	100.68	8.31	108.99
10858	2004-11-25	11145	106.49	8.79	115.28
10859	2004-11-03	10694	151.37	12.49	163.86
10860	2004-11-25	16095	157.90	13.03	170.93
10861	2004-11-24	6742	173.29	14.30	187.59
10862	2004-11-04	17373	228.64	18.86	247.50
10863	2004-11-27	10954	252.51	20.83	273.34
10864	2004-11-23	2221	353.88	29.20	383.08
10865	2004-11-03	2597	370.65	30.58	401.23
10866	2004-11-22	18435	121.05	9.99	131.04
10867	2004-11-05	861	295.20	24.35	319.55
10868	2004-11-20	11084	309.91	25.57	335.48
10869	2004-11-15	3826	36.55	3.02	39.57
10870	2004-11-26	7000	180.24	14.87	195.11
10871	2004-11-10	17820	160.41	13.23	173.64
10872	2004-11-06	12240	153.53	12.67	166.20
10873	2004-11-28	11804	173.38	14.30	187.68
10874	2004-11-04	4931	93.75	7.73	101.48
10875	2004-11-10	15305	67.24	5.55	72.79
10876	2004-11-10	10158	106.88	8.82	115.70
10877	2004-11-26	77	344.61	28.43	373.04
10878	2004-11-12	3018	145.89	12.04	157.93
10879	2004-11-11	15241	212.87	17.56	230.43
10880	2004-11-29	4753	354.01	29.21	383.22
10881	2004-11-24	4514	94.51	7.80	102.31
10882	2004-11-08	2683	267.19	22.04	289.23
10883	2004-11-11	16308	88.64	7.31	95.95
10884	2004-11-03	10156	33.37	2.75	36.12
10885	2004-11-16	14324	138.81	11.45	150.26
10886	2004-11-04	12060	32.96	2.72	35.68
10887	2004-11-15	19170	29.42	2.43	31.85
10888	2004-11-29	16856	235.61	19.44	255.05
10889	2004-11-14	2599	309.05	25.50	334.55
10890	2004-11-16	5038	32.56	2.69	35.25
10891	2004-11-16	12293	92.90	7.66	100.56
10892	2004-11-24	10228	238.06	19.64	257.70
10893	2004-11-07	860	0.44	0.04	0.48
10894	2004-11-28	14898	125.02	10.31	135.33
10895	2004-11-15	13360	390.42	32.21	422.63
10896	2004-11-01	18342	348.52	28.75	377.27
10897	2004-11-27	11171	121.20	10.00	131.20
10898	2004-11-05	18927	130.33	10.75	141.08
10899	2004-11-29	2395	143.59	11.85	155.44
10900	2004-11-24	18380	47.91	3.95	51.86
10901	2004-11-30	14542	285.84	23.58	309.42
10902	2004-11-13	14492	265.04	21.87	286.91
10903	2004-11-27	3031	318.73	26.30	345.03
10904	2004-11-16	4222	332.29	27.41	359.70
10905	2004-11-06	6577	309.22	25.51	334.73
10906	2004-11-08	3480	217.64	17.96	235.60
10907	2004-11-28	17495	116.50	9.61	126.11
10908	2004-11-06	15061	268.84	22.18	291.02
10909	2004-11-02	301	195.10	16.10	211.20
10910	2004-11-30	17378	389.25	32.11	421.36
10911	2004-11-26	7036	89.30	7.37	96.67
10912	2004-11-26	10606	22.44	1.85	24.29
10913	2004-11-04	2143	267.80	22.09	289.89
10914	2004-11-23	1246	361.50	29.82	391.32
10915	2004-11-11	1795	288.22	23.78	312.00
10916	2004-11-25	19441	228.77	18.87	247.64
10917	2004-11-29	18602	54.02	4.46	58.48
10918	2004-11-16	6690	253.77	20.94	274.71
10919	2004-11-13	13417	226.67	18.70	245.37
10920	2004-11-25	7817	325.77	26.88	352.65
10921	2004-11-10	14092	301.84	24.90	326.74
10922	2004-11-25	12749	299.98	24.75	324.73
10923	2004-11-03	5363	160.77	13.26	174.03
10924	2004-11-12	12836	147.95	12.21	160.16
10925	2004-11-13	11773	297.53	24.55	322.08
10926	2004-11-02	13149	188.16	15.52	203.68
10927	2004-11-22	10187	21.82	1.80	23.62
10928	2004-11-23	1151	385.30	31.79	417.09
10929	2004-11-26	17139	247.41	20.41	267.82
10930	2004-11-14	15987	269.44	22.23	291.67
10931	2004-11-08	17366	306.17	25.26	331.43
10932	2004-11-21	5493	382.88	31.59	414.47
10933	2004-11-20	13367	321.96	26.56	348.52
10934	2004-11-20	2708	138.25	11.41	149.66
10935	2004-11-05	4871	43.66	3.60	47.26
10936	2004-11-19	2658	254.75	21.02	275.77
10937	2004-11-10	3132	120.53	9.94	130.47
10938	2004-11-07	11968	139.65	11.52	151.17
10939	2004-11-06	5052	174.27	14.38	188.65
10940	2004-11-27	15429	3.02	0.25	3.27
10941	2004-11-27	11949	245.86	20.28	266.14
10942	2004-11-26	10454	21.23	1.75	22.98
10943	2004-11-01	329	116.70	9.63	126.33
10944	2004-11-23	6890	96.59	7.97	104.56
10945	2004-11-12	9638	119.31	9.84	129.15
10946	2004-11-13	16583	220.98	18.23	239.21
10947	2004-11-17	5234	136.88	11.29	148.17
10948	2004-11-01	14395	206.53	17.04	223.57
10949	2004-11-25	17905	146.65	12.10	158.75
10950	2004-11-03	5658	305.91	25.24	331.15
10951	2004-11-04	10909	212.29	17.51	229.80
10952	2004-11-26	10667	390.65	32.23	422.88
10953	2004-11-27	6722	135.59	11.19	146.78
10954	2004-11-26	19538	324.70	26.79	351.49
10955	2004-11-30	608	198.43	16.37	214.80
10956	2004-11-18	3473	373.45	30.81	404.26
10957	2004-11-19	5588	194.18	16.02	210.20
10958	2004-11-30	11038	371.54	30.65	402.19
10959	2004-11-05	9623	311.48	25.70	337.18
10960	2004-11-20	3214	395.85	32.66	428.51
10961	2004-11-17	14911	354.41	29.24	383.65
10962	2004-11-08	16129	213.20	17.59	230.79
10963	2004-11-26	12706	362.55	29.91	392.46
10964	2004-11-29	1727	200.84	16.57	217.41
10965	2004-11-02	10959	256.73	21.18	277.91
10966	2004-11-19	19295	289.93	23.92	313.85
10967	2004-11-19	4283	147.14	12.14	159.28
10968	2004-11-17	16697	137.16	11.32	148.48
10969	2004-11-20	580	178.20	14.70	192.90
10970	2004-11-30	6807	325.01	26.81	351.82
10971	2004-11-27	17180	374.35	30.88	405.23
10972	2004-11-19	9523	171.26	14.13	185.39
10973	2004-11-26	13720	19.00	1.57	20.57
10974	2004-11-21	13630	346.55	28.59	375.14
10975	2004-11-05	2382	288.74	23.82	312.56
10976	2004-11-13	16509	107.05	8.83	115.88
10977	2004-11-09	13521	79.15	6.53	85.68
10978	2004-11-06	9047	143.52	11.84	155.36
10979	2004-11-14	18011	48.20	3.98	52.18
10980	2004-11-03	6689	213.13	17.58	230.71
10981	2004-11-14	16241	241.02	19.88	260.90
10982	2004-11-02	6940	71.37	5.89	77.26
10983	2004-11-22	18488	116.81	9.64	126.45
10984	2004-11-15	10173	230.94	19.05	249.99
10985	2004-11-11	16284	67.85	5.60	73.45
10986	2004-11-24	6625	58.49	4.83	63.32
10987	2004-11-08	1123	361.15	29.79	390.94
10988	2004-11-30	19657	168.66	13.91	182.57
10989	2004-11-27	16970	188.75	15.57	204.32
10990	2004-11-12	5383	248.92	20.54	269.46
10991	2004-11-17	3502	252.35	20.82	273.17
10992	2004-11-14	14549	396.33	32.70	429.03
10993	2004-11-27	10569	317.83	26.22	344.05
10994	2004-11-27	1756	270.56	22.32	292.88
10995	2004-11-15	7090	212.19	17.51	229.70
10996	2004-11-22	4630	307.40	25.36	332.76
10997	2004-11-04	17545	132.54	10.93	143.47
10998	2004-11-02	12756	353.04	29.13	382.17
10999	2004-11-30	18842	31.18	2.57	33.75
11000	2004-11-13	1027	191.66	15.81	207.47
11001	2004-12-16	4497	362.76	29.93	392.69
11002	2004-12-26	11426	359.72	29.68	389.40
11003	2004-12-08	11638	45.03	3.71	48.74
11004	2004-12-27	14033	281.37	23.21	304.58
11005	2004-12-20	206	292.09	24.10	316.19
11006	2004-12-16	765	288.57	23.81	312.38
11007	2004-12-28	7841	295.97	24.42	320.39
11008	2004-12-20	10922	308.73	25.47	334.20
11009	2004-12-31	6230	57.80	4.77	62.57
11010	2004-12-29	1607	77.18	6.37	83.55
11011	2004-12-15	7012	14.01	1.16	15.17
11012	2004-12-07	16550	255.75	21.10	276.85
11013	2004-12-16	13136	273.49	22.56	296.05
11014	2004-12-02	15762	70.87	5.85	76.72
11015	2004-12-04	16347	148.98	12.29	161.27
11016	2004-12-30	14103	55.42	4.57	59.99
11017	2004-12-27	19304	210.84	17.39	228.23
11018	2004-12-30	16609	92.16	7.60	99.76
11019	2004-12-30	13421	127.94	10.56	138.50
11020	2004-12-06	11449	9.86	0.81	10.67
11021	2004-12-27	16103	71.34	5.89	77.23
11022	2004-12-18	8722	71.29	5.88	77.17
11023	2004-12-30	9004	205.72	16.97	222.69
11024	2004-12-17	9574	185.38	15.29	200.67
11025	2004-12-23	9780	30.27	2.50	32.77
11026	2004-12-01	10180	303.64	25.05	328.69
11027	2004-12-09	12197	338.75	27.95	366.70
11028	2004-12-25	17611	218.05	17.99	236.04
11029	2004-12-13	5410	256.31	21.15	277.46
11030	2004-12-14	9523	214.54	17.70	232.24
11031	2004-12-26	108	140.59	11.60	152.19
11032	2004-12-01	12797	162.26	13.39	175.65
11033	2004-12-30	10383	157.88	13.03	170.91
11034	2004-12-21	17065	185.77	15.33	201.10
11035	2004-12-30	19836	128.46	10.60	139.06
11036	2004-12-16	8337	334.37	27.59	361.96
11037	2004-12-12	19152	23.32	1.92	25.24
11038	2004-12-09	14679	2.06	0.17	2.23
11039	2004-12-17	6032	370.51	30.57	401.08
11040	2004-12-20	16171	220.20	18.17	238.37
11041	2004-12-10	18129	83.24	6.87	90.11
11042	2004-12-08	7674	168.28	13.88	182.16
11043	2004-12-27	9187	198.50	16.38	214.88
11044	2004-12-30	12304	66.25	5.47	71.72
11045	2004-12-28	7910	380.14	31.36	411.50
11046	2004-12-04	15736	251.93	20.78	272.71
11047	2004-12-02	17594	181.99	15.01	197.00
11048	2004-12-17	13268	236.27	19.49	255.76
11049	2004-12-01	862	262.56	21.66	284.22
11050	2004-12-24	17849	12.11	1.00	13.11
11051	2004-12-01	14365	335.71	27.70	363.41
11052	2004-12-15	392	48.86	4.03	52.89
11053	2004-12-28	3772	339.17	27.98	367.15
11054	2004-12-10	14937	58.15	4.80	62.95
11055	2004-12-21	16282	233.11	19.23	252.34
11056	2004-12-07	3868	8.86	0.73	9.59
11057	2004-12-05	4205	169.37	13.97	183.34
11058	2004-12-26	136	52.66	4.34	57.00
11059	2004-12-31	5081	364.52	30.07	394.59
11060	2004-12-12	5849	26.37	2.18	28.55
11061	2004-12-16	1846	319.48	26.36	345.84
11062	2004-12-13	9126	299.33	24.69	324.02
11063	2004-12-18	1477	297.23	24.52	321.75
11064	2004-12-27	12057	270.33	22.30	292.63
11065	2004-12-23	4019	240.42	19.83	260.25
11066	2004-12-14	7778	396.08	32.68	428.76
11067	2004-12-05	12032	348.99	28.79	377.78
11068	2004-12-23	2131	34.66	2.86	37.52
11069	2004-12-08	3162	120.56	9.95	130.51
11070	2004-12-12	16893	319.17	26.33	345.50
11071	2004-12-30	3113	51.78	4.27	56.05
11072	2004-12-30	1209	85.06	7.02	92.08
11073	2004-12-12	8522	22.49	1.86	24.35
11074	2004-12-30	15874	203.22	16.77	219.99
11075	2004-12-07	12080	255.32	21.06	276.38
11076	2004-12-16	1149	7.71	0.64	8.35
11077	2004-12-18	6621	329.71	27.20	356.91
11078	2004-12-27	18249	262.02	21.62	283.64
11079	2004-12-09	9516	152.38	12.57	164.95
11080	2004-12-19	13262	92.83	7.66	100.49
11081	2004-12-15	10505	363.53	29.99	393.52
11082	2004-12-24	11661	95.22	7.86	103.08
11083	2004-12-08	4614	24.00	1.98	25.98
11084	2004-12-01	6293	138.22	11.40	149.62
11085	2004-12-26	5850	149.97	12.37	162.34
11086	2004-12-18	5768	107.27	8.85	116.12
11087	2004-12-14	7929	202.57	16.71	219.28
11088	2004-12-16	9868	161.22	13.30	174.52
11089	2004-12-13	9555	286.25	23.62	309.87
11090	2004-12-17	10775	139.39	11.50	150.89
11091	2004-12-16	6579	112.16	9.25	121.41
11092	2004-12-20	4676	131.42	10.84	142.26
11093	2004-12-26	6924	226.36	18.67	245.03
11094	2004-12-04	2364	300.88	24.82	325.70
11095	2004-12-16	11491	155.81	12.85	168.66
11096	2004-12-31	5731	34.07	2.81	36.88
11097	2004-12-14	10853	3.18	0.26	3.44
11098	2004-12-18	5314	53.75	4.43	58.18
11099	2004-12-20	19754	146.03	12.05	158.08
11100	2004-12-08	16949	236.20	19.49	255.69
11101	2004-12-14	9176	129.55	10.69	140.24
11102	2004-12-17	12251	38.68	3.19	41.87
11103	2004-12-20	12268	12.88	1.06	13.94
11104	2004-12-31	7140	161.88	13.36	175.24
11105	2004-12-17	9727	8.16	0.67	8.83
11106	2004-12-09	11611	70.91	5.85	76.76
11107	2004-12-19	3560	35.62	2.94	38.56
11108	2004-12-06	6533	96.45	7.96	104.41
11109	2004-12-14	2264	123.74	10.21	133.95
11110	2004-12-20	13754	154.55	12.75	167.30
11111	2004-12-22	14571	257.58	21.25	278.83
11112	2004-12-19	10843	86.76	7.16	93.92
11113	2004-12-26	11545	285.89	23.59	309.48
11114	2004-12-24	5237	202.45	16.70	219.15
11115	2004-12-13	12128	285.35	23.54	308.89
11116	2004-12-10	19963	338.01	27.89	365.90
11117	2004-12-22	2110	188.60	15.56	204.16
11118	2004-12-13	11509	289.69	23.90	313.59
11119	2004-12-26	18650	317.94	26.23	344.17
11120	2004-12-22	5439	71.25	5.88	77.13
11121	2004-12-06	5402	357.37	29.48	386.85
11122	2004-12-21	245	149.29	12.32	161.61
11123	2004-12-19	16427	257.07	21.21	278.28
11124	2004-12-31	19287	131.34	10.84	142.18
11125	2004-12-05	9592	388.62	32.06	420.68
11126	2004-12-04	12644	58.64	4.84	63.48
11127	2004-12-27	12899	361.63	29.83	391.46
11128	2004-12-12	18960	271.63	22.41	294.04
11129	2004-12-12	10300	24.04	1.98	26.02
11130	2004-12-02	1772	156.69	12.93	169.62
11131	2004-12-05	15864	157.56	13.00	170.56
11132	2004-12-18	16836	354.91	29.28	384.19
11133	2004-12-24	19001	364.86	30.10	394.96
11134	2004-12-16	7504	227.56	18.77	246.33
11135	2004-12-13	9752	212.93	17.57	230.50
11136	2004-12-07	492	313.29	25.85	339.14
11137	2004-12-02	10643	13.94	1.15	15.09
11138	2004-12-18	16746	338.98	27.97	366.95
11139	2004-12-26	7191	326.86	26.97	353.83
11140	2004-12-13	2509	267.31	22.05	289.36
11141	2004-12-22	10118	234.93	19.38	254.31
11142	2004-12-18	7378	16.56	1.37	17.93
11143	2004-12-02	12620	346.68	28.60	375.28
11144	2004-12-30	11909	298.99	24.67	323.66
11145	2004-12-23	14155	317.45	26.19	343.64
11146	2004-12-21	3580	92.02	7.59	99.61
11147	2004-12-01	8287	119.01	9.82	128.83
11148	2004-12-25	14031	34.49	2.85	37.34
11149	2004-12-29	3667	162.94	13.44	176.38
11150	2004-12-04	7184	45.49	3.75	49.24
11151	2004-12-29	4842	299.88	24.74	324.62
11152	2004-12-27	8366	352.53	29.08	381.61
11153	2004-12-11	6958	33.98	2.80	36.78
11154	2004-12-09	16307	370.61	30.58	401.19
11155	2004-12-20	586	291.39	24.04	315.43
11156	2004-12-25	16833	280.45	23.14	303.59
11157	2004-12-23	12198	252.58	20.84	273.42
11158	2004-12-24	3929	271.90	22.43	294.33
11159	2004-12-04	9681	343.00	28.30	371.30
11160	2004-12-28	18409	368.00	30.36	398.36
11161	2004-12-01	19076	198.06	16.34	214.40
11162	2004-12-10	12442	351.56	29.00	380.56
11163	2004-12-27	18962	194.76	16.07	210.83
11164	2004-12-02	12856	301.46	24.87	326.33
11165	2004-12-09	7493	280.27	23.12	303.39
11166	2004-12-27	6700	69.01	5.69	74.70
11167	2004-12-22	10725	179.09	14.77	193.86
11168	2004-12-31	6421	141.79	11.70	153.49
11169	2004-12-21	17322	242.50	20.01	262.51
11170	2004-12-25	8321	211.45	17.44	228.89
11171	2004-12-05	5240	78.67	6.49	85.16
11172	2004-12-17	12785	153.92	12.70	166.62
11173	2004-12-29	3282	209.51	17.28	226.79
11174	2004-12-03	16602	296.86	24.49	321.35
11175	2004-12-17	10047	358.02	29.54	387.56
11176	2004-12-23	3841	56.20	4.64	60.84
11177	2004-12-26	1125	333.24	27.49	360.73
11178	2004-12-19	704	288.13	23.77	311.90
11179	2004-12-30	6652	261.83	21.60	283.43
11180	2004-12-08	14226	101.81	8.40	110.21
11181	2004-12-22	10285	315.93	26.06	341.99
11182	2004-12-11	16584	59.32	4.89	64.21
11183	2004-12-14	7580	75.15	6.20	81.35
11184	2004-12-06	13850	392.70	32.40	425.10
11185	2004-12-04	17236	48.10	3.97	52.07
11186	2004-12-13	9402	266.17	21.96	288.13
11187	2004-12-07	16568	211.95	17.49	229.44
11188	2004-12-23	6048	160.76	13.26	174.02
11189	2004-12-19	4810	97.06	8.01	105.07
11190	2004-12-21	9120	399.82	32.99	432.81
11191	2004-12-30	14376	320.71	26.46	347.17
11192	2004-12-13	13592	255.20	21.05	276.25
11193	2004-12-15	17880	15.59	1.29	16.88
11194	2004-12-08	9659	316.81	26.14	342.95
11195	2004-12-14	955	183.24	15.12	198.36
11196	2004-12-06	17395	92.60	7.64	100.24
11197	2004-12-30	16797	204.00	16.83	220.83
11198	2004-12-20	16603	51.99	4.29	56.28
11199	2004-12-05	12094	32.87	2.71	35.58
11200	2004-12-04	127	168.29	13.88	182.17
11201	2004-12-29	14309	298.86	24.66	323.52
11202	2004-12-04	13489	232.04	19.14	251.18
11203	2004-12-23	19861	135.96	11.22	147.18
11204	2004-12-22	7958	327.67	27.03	354.70
11205	2004-12-02	9050	0.48	0.04	0.52
11206	2004-12-27	19969	92.74	7.65	100.39
11207	2004-12-23	9751	39.42	3.25	42.67
11208	2004-12-10	8159	396.55	32.72	429.27
11209	2004-12-31	16669	90.95	7.50	98.45
11210	2004-12-06	10291	285.32	23.54	308.86
11211	2004-12-06	15678	247.58	20.43	268.01
11212	2004-12-06	16068	141.33	11.66	152.99
11213	2004-12-17	18456	161.68	13.34	175.02
11214	2004-12-12	2883	350.03	28.88	378.91
11215	2004-12-05	18283	280.57	23.15	303.72
11216	2004-12-15	11000	147.42	12.16	159.58
11217	2004-12-02	15491	360.37	29.73	390.10
11218	2004-12-24	11838	76.34	6.30	82.64
11219	2004-12-07	6214	67.30	5.55	72.85
11220	2004-12-26	14417	136.38	11.25	147.63
11221	2004-12-16	4634	389.56	32.14	421.70
11222	2004-12-10	9591	202.66	16.72	219.38
11223	2004-12-09	4905	328.70	27.12	355.82
11224	2004-12-01	130	209.06	17.25	226.31
11225	2004-12-20	4166	47.31	3.90	51.21
11226	2004-12-03	13332	370.56	30.57	401.13
11227	2004-12-04	10635	359.29	29.64	388.93
11228	2004-12-11	6826	209.38	17.27	226.65
11229	2004-12-10	18311	130.67	10.78	141.45
11230	2004-12-21	9904	118.86	9.81	128.67
11231	2004-12-30	5598	316.96	26.15	343.11
11232	2004-12-31	12088	95.62	7.89	103.51
11233	2004-12-24	10478	318.20	26.25	344.45
11234	2004-12-24	11265	174.63	14.41	189.04
11235	2004-12-28	5241	261.94	21.61	283.55
11236	2004-12-31	6486	286.76	23.66	310.42
11237	2004-12-10	9984	97.64	8.06	105.70
11238	2004-12-18	2589	302.15	24.93	327.08
11239	2004-12-07	12419	334.39	27.59	361.98
11240	2004-12-18	11993	215.45	17.77	233.22
11241	2004-12-18	4110	270.14	22.29	292.43
11242	2004-12-02	18828	45.35	3.74	49.09
11243	2004-12-22	5580	158.61	13.09	171.70
11244	2004-12-28	11419	123.74	10.21	133.95
11245	2004-12-25	2723	185.36	15.29	200.65
11246	2004-12-01	6654	272.76	22.50	295.26
11247	2004-12-24	14804	145.30	11.99	157.29
11248	2004-12-04	7110	277.04	22.86	299.90
11249	2004-12-09	3128	333.93	27.55	361.48
11250	2004-12-05	18929	16.68	1.38	18.06
11251	2004-12-28	3633	342.78	28.28	371.06
11252	2004-12-17	6537	290.87	24.00	314.87
11253	2004-12-01	2132	62.77	5.18	67.95
11254	2004-12-19	1195	294.06	24.26	318.32
11255	2004-12-01	9687	135.42	11.17	146.59
11256	2004-12-29	18172	90.74	7.49	98.23
11257	2004-12-25	16755	200.82	16.57	217.39
11258	2004-12-07	10750	108.68	8.97	117.65
11259	2004-12-19	4247	119.63	9.87	129.50
11260	2004-12-14	13336	253.39	20.90	274.29
11261	2004-12-09	11825	286.79	23.66	310.45
11262	2004-12-06	11370	342.34	28.24	370.58
11263	2004-12-07	19114	191.97	15.84	207.81
11264	2004-12-25	330	207.18	17.09	224.27
11265	2004-12-27	6756	170.13	14.04	184.17
11266	2004-12-26	1832	61.27	5.05	66.32
11267	2004-12-13	10065	83.04	6.85	89.89
11268	2004-12-10	1381	373.46	30.81	404.27
11269	2004-12-02	10137	304.29	25.10	329.39
11270	2004-12-29	5701	106.06	8.75	114.81
11271	2004-12-10	13168	263.74	21.76	285.50
11272	2004-12-05	14028	215.46	17.78	233.24
11273	2004-12-17	10393	384.81	31.75	416.56
11274	2004-12-14	18150	233.47	19.26	252.73
11275	2004-12-26	10801	137.81	11.37	149.18
11276	2004-12-22	14743	264.91	21.86	286.77
11277	2004-12-07	12945	383.88	31.67	415.55
11278	2004-12-08	44	127.27	10.50	137.77
11279	2004-12-06	15897	335.66	27.69	363.35
11280	2004-12-22	18557	153.03	12.62	165.65
11281	2004-12-01	17756	262.21	21.63	283.84
11282	2004-12-11	18106	50.40	4.16	54.56
11283	2004-12-17	12158	302.91	24.99	327.90
11284	2004-12-09	15378	172.59	14.24	186.83
11285	2004-12-16	18899	260.15	21.46	281.61
11286	2004-12-07	6641	114.51	9.45	123.96
11287	2004-12-12	16379	397.63	32.80	430.43
11288	2004-12-28	12204	148.83	12.28	161.11
11289	2004-12-28	10502	150.87	12.45	163.32
11290	2004-12-27	10514	198.14	16.35	214.49
11291	2004-12-01	14711	377.35	31.13	408.48
11292	2004-12-19	8956	7.94	0.66	8.60
11293	2004-12-07	12954	212.11	17.50	229.61
11294	2004-12-11	794	114.16	9.42	123.58
11295	2004-12-12	10377	129.66	10.70	140.36
11296	2004-12-11	9822	148.35	12.24	160.59
11297	2004-12-10	7886	371.60	30.66	402.26
11298	2004-12-27	18310	316.41	26.10	342.51
11299	2004-12-02	3543	155.92	12.86	168.78
11300	2004-12-09	6199	152.20	12.56	164.76
11301	2004-12-30	4586	348.18	28.72	376.90
11302	2004-12-05	16994	297.17	24.52	321.69
11303	2004-12-31	2763	314.07	25.91	339.98
11304	2004-12-19	13968	163.99	13.53	177.52
11305	2004-12-30	4748	376.98	31.10	408.08
11306	2004-12-16	19409	102.78	8.48	111.26
11307	2004-12-23	11157	81.22	6.70	87.92
11308	2004-12-31	12180	154.32	12.73	167.05
11309	2004-12-24	17407	1.97	0.16	2.13
11310	2004-12-20	818	12.65	1.04	13.69
11311	2004-12-22	6350	304.14	25.09	329.23
11312	2004-12-25	18007	316.16	26.08	342.24
11313	2004-12-06	10421	154.57	12.75	167.32
11314	2004-12-02	15863	186.97	15.43	202.40
11315	2004-12-04	14969	93.88	7.75	101.63
11316	2004-12-31	1367	93.12	7.68	100.80
11317	2004-12-26	15614	113.02	9.32	122.34
11318	2004-12-30	11052	129.56	10.69	140.25
11319	2004-12-27	17805	336.23	27.74	363.97
11320	2004-12-05	15582	363.31	29.97	393.28
11321	2004-12-04	19096	142.87	11.79	154.66
11322	2004-12-05	16869	39.67	3.27	42.94
11323	2004-12-10	12853	195.54	16.13	211.67
11324	2004-12-01	3726	213.51	17.61	231.12
11325	2004-12-29	12343	269.46	22.23	291.69
11326	2004-12-11	17516	267.40	22.06	289.46
11327	2004-12-27	17570	19.77	1.63	21.40
11328	2004-12-23	15106	238.12	19.64	257.76
11329	2004-12-02	11827	201.70	16.64	218.34
11330	2004-12-02	19648	202.81	16.73	219.54
11331	2004-12-16	13049	124.95	10.31	135.26
11332	2004-12-05	8606	203.93	16.82	220.75
11333	2004-12-30	16893	159.62	13.17	172.79
11334	2004-12-26	17336	194.85	16.08	210.93
11335	2004-12-21	1736	159.49	13.16	172.65
11336	2004-12-19	7992	212.37	17.52	229.89
11337	2004-12-13	16327	328.31	27.09	355.40
11338	2004-12-23	14189	222.18	18.33	240.51
11339	2004-12-27	6440	227.89	18.80	246.69
11340	2004-12-16	2318	379.85	31.34	411.19
11341	2004-12-03	3518	330.71	27.28	357.99
11342	2004-12-03	15458	316.26	26.09	342.35
11343	2004-12-28	155	219.00	18.07	237.07
11344	2004-12-24	12684	207.43	17.11	224.54
11345	2004-12-04	13881	234.80	19.37	254.17
11346	2004-12-02	11613	371.36	30.64	402.00
11347	2004-12-09	3225	371.41	30.64	402.05
11348	2004-12-14	15017	139.70	11.53	151.23
11349	2004-12-01	18709	264.04	21.78	285.82
11350	2004-12-25	3903	47.46	3.92	51.38
11351	2004-12-07	8060	197.75	16.31	214.06
11352	2004-12-06	8723	19.04	1.57	20.61
11353	2004-12-08	1290	373.74	30.83	404.57
11354	2004-12-05	3378	267.04	22.03	289.07
11355	2004-12-07	16224	38.45	3.17	41.62
11356	2004-12-29	14461	226.40	18.68	245.08
11357	2004-12-08	3295	246.54	20.34	266.88
11358	2004-12-13	3424	384.74	31.74	416.48
11359	2004-12-06	8343	106.43	8.78	115.21
11360	2004-12-17	1072	325.14	26.82	351.96
11361	2004-12-09	16298	114.13	9.42	123.55
11362	2004-12-15	6299	284.52	23.47	307.99
11363	2004-12-20	12730	154.95	12.78	167.73
11364	2004-12-12	6546	327.08	26.98	354.06
11365	2004-12-18	10041	117.27	9.67	126.94
11366	2004-12-24	16035	89.23	7.36	96.59
11367	2004-12-10	13921	128.34	10.59	138.93
11368	2004-12-26	14403	245.69	20.27	265.96
11369	2004-12-01	6896	393.67	32.48	426.15
11370	2004-12-26	2280	335.23	27.66	362.89
11371	2004-12-06	6989	241.77	19.95	261.72
11372	2004-12-04	18617	15.28	1.26	16.54
11373	2004-12-24	15922	311.43	25.69	337.12
11374	2004-12-28	10597	356.12	29.38	385.50
11375	2004-12-31	9716	172.55	14.24	186.79
11376	2004-12-09	7494	393.65	32.48	426.13
11377	2004-12-08	15538	7.18	0.59	7.77
11378	2004-12-17	14544	123.37	10.18	133.55
11379	2004-12-16	17916	276.46	22.81	299.27
11380	2004-12-26	15945	287.13	23.69	310.82
11381	2004-12-02	797	209.74	17.30	227.04
11382	2004-12-16	8824	168.73	13.92	182.65
11383	2004-12-15	7681	125.53	10.36	135.89
11384	2004-12-13	17002	39.86	3.29	43.15
11385	2004-12-17	7588	391.54	32.30	423.84
11386	2004-12-01	727	34.69	2.86	37.55
11387	2004-12-27	2628	45.00	3.71	48.71
11388	2004-12-10	6816	165.70	13.67	179.37
11389	2004-12-14	11618	302.19	24.93	327.12
11390	2004-12-07	14318	145.29	11.99	157.28
11391	2004-12-20	831	213.13	17.58	230.71
11392	2004-12-08	9658	269.72	22.25	291.97
11393	2004-12-26	3888	364.48	30.07	394.55
11394	2004-12-07	12574	255.70	21.10	276.80
11395	2004-12-07	18331	198.44	16.37	214.81
11396	2004-12-02	10501	66.49	5.49	71.98
11397	2004-12-28	5125	183.66	15.15	198.81
11398	2004-12-04	8341	205.21	16.93	222.14
11399	2004-12-28	10799	293.68	24.23	317.91
11400	2004-12-19	5411	0.91	0.08	0.99
11401	2004-12-19	669	373.53	30.82	404.35
11402	2004-12-14	12790	132.76	10.95	143.71
11403	2004-12-09	12295	144.39	11.91	156.30
11404	2004-12-28	13505	98.00	8.09	106.09
11405	2004-12-15	14550	6.89	0.57	7.46
11406	2004-12-30	19135	70.02	5.78	75.80
11407	2004-12-12	17736	149.01	12.29	161.30
11408	2004-12-20	15720	245.68	20.27	265.95
11409	2004-12-01	11923	373.22	30.79	404.01
11410	2004-12-30	4539	303.22	25.02	328.24
11411	2004-12-04	18739	52.09	4.30	56.39
11412	2004-12-03	19051	294.71	24.31	319.02
11413	2004-12-28	2993	137.41	11.34	148.75
11414	2004-12-16	15545	240.36	19.83	260.19
11415	2004-12-13	11891	330.34	27.25	357.59
11416	2004-12-04	777	9.15	0.75	9.90
11417	2004-12-14	2512	62.61	5.17	67.78
11418	2004-12-29	16235	167.45	13.81	181.26
11419	2004-12-07	8816	81.63	6.73	88.36
11420	2004-12-12	1935	200.45	16.54	216.99
11421	2004-12-27	13810	257.83	21.27	279.10
11422	2004-12-08	8334	172.94	14.27	187.21
11423	2004-12-05	10214	46.61	3.85	50.46
11424	2004-12-31	7562	28.19	2.33	30.52
11425	2004-12-02	10202	356.64	29.42	386.06
11426	2004-12-15	14211	170.85	14.10	184.95
11427	2004-12-23	10599	337.09	27.81	364.90
11428	2004-12-29	5687	104.96	8.66	113.62
11429	2004-12-03	8979	272.68	22.50	295.18
11430	2004-12-05	16473	162.69	13.42	176.11
11431	2004-12-04	14214	341.38	28.16	369.54
11432	2004-12-12	14618	106.27	8.77	115.04
11433	2004-12-15	10475	261.12	21.54	282.66
11434	2004-12-18	15416	205.64	16.97	222.61
11435	2004-12-04	19146	125.91	10.39	136.30
11436	2004-12-14	6144	103.76	8.56	112.32
11437	2004-12-10	4173	251.31	20.73	272.04
11438	2004-12-17	9278	63.84	5.27	69.11
11439	2004-12-29	9161	306.13	25.26	331.39
11440	2004-12-19	7471	362.08	29.87	391.95
11441	2004-12-22	16525	8.36	0.69	9.05
11442	2004-12-22	17447	232.64	19.19	251.83
11443	2004-12-15	5996	34.00	2.81	36.80
11444	2004-12-28	10580	272.41	22.47	294.88
11445	2004-12-25	7644	263.04	21.70	284.74
11446	2004-12-13	18562	289.39	23.87	313.26
11447	2004-12-30	2038	312.58	25.79	338.37
11448	2004-12-13	1953	270.22	22.29	292.51
11449	2004-12-04	10461	244.84	20.20	265.04
11450	2004-12-14	13291	255.85	21.11	276.96
11451	2004-12-18	10899	332.55	27.44	359.99
11452	2004-12-05	15695	106.34	8.77	115.11
11453	2004-12-31	10871	24.05	1.98	26.03
11454	2004-12-12	16610	126.10	10.40	136.50
11455	2004-12-10	12309	8.06	0.66	8.72
11456	2004-12-11	13241	357.42	29.49	386.91
11457	2004-12-12	3372	1.15	0.09	1.24
11458	2004-12-06	5032	151.87	12.53	164.40
11459	2004-12-24	12640	369.58	30.49	400.07
11460	2004-12-16	17903	315.14	26.00	341.14
11461	2004-12-04	4604	136.26	11.24	147.50
11462	2004-12-10	10943	355.37	29.32	384.69
11463	2004-12-29	13513	45.18	3.73	48.91
11464	2004-12-25	6457	56.12	4.63	60.75
11465	2004-12-23	42	202.29	16.69	218.98
11466	2004-12-14	2218	110.72	9.13	119.85
11467	2004-12-14	1568	153.06	12.63	165.69
11468	2004-12-13	4460	340.57	28.10	368.67
11469	2004-12-18	5575	207.54	17.12	224.66
11470	2004-12-17	12982	139.48	11.51	150.99
11471	2004-12-30	18765	242.49	20.01	262.50
11472	2004-12-12	8044	326.32	26.92	353.24
11473	2004-12-25	15691	58.67	4.84	63.51
11474	2004-12-09	11091	279.26	23.04	302.30
11475	2004-12-19	17685	353.72	29.18	382.90
11476	2004-12-17	4858	2.94	0.24	3.18
11477	2004-12-21	14517	283.14	23.36	306.50
11478	2004-12-06	19483	37.44	3.09	40.53
11479	2004-12-16	2385	320.93	26.48	347.41
11480	2004-12-15	5563	169.39	13.97	183.36
11481	2004-12-10	9639	342.07	28.22	370.29
11482	2004-12-24	4413	211.91	17.48	229.39
11483	2004-12-31	539	187.51	15.47	202.98
11484	2004-12-03	16633	376.17	31.03	407.20
11485	2004-12-07	1942	381.96	31.51	413.47
11486	2004-12-07	15203	329.49	27.18	356.67
11487	2004-12-28	14859	121.05	9.99	131.04
11488	2004-12-25	16036	150.20	12.39	162.59
11489	2004-12-25	13336	124.63	10.28	134.91
11490	2004-12-03	13701	217.44	17.94	235.38
11491	2004-12-11	155	311.85	25.73	337.58
11492	2004-12-01	10385	81.52	6.73	88.25
11493	2004-12-14	200	7.49	0.62	8.11
11494	2004-12-27	11775	113.56	9.37	122.93
11495	2004-12-01	4151	172.59	14.24	186.83
11496	2004-12-24	10617	244.75	20.19	264.94
11497	2004-12-28	757	12.73	1.05	13.78
11498	2004-12-25	17406	283.78	23.41	307.19
11499	2004-12-04	6320	98.04	8.09	106.13
11500	2004-12-03	1166	369.09	30.45	399.54
11501	2004-12-03	14728	162.96	13.44	176.40
11502	2004-12-20	6307	16.27	1.34	17.61
11503	2004-12-22	18238	154.51	12.75	167.26
11504	2004-12-10	3010	370.26	30.55	400.81
11505	2004-12-22	18517	302.48	24.95	327.43
11506	2004-12-22	11000	134.26	11.08	145.34
11507	2004-12-17	5090	110.69	9.13	119.82
11508	2004-12-03	7056	380.23	31.37	411.60
11509	2004-12-24	17615	21.56	1.78	23.34
11510	2004-12-19	13884	333.83	27.54	361.37
11511	2004-12-24	9003	207.68	17.13	224.81
11512	2004-12-27	9516	54.37	4.49	58.86
11513	2004-12-13	17996	230.54	19.02	249.56
11514	2004-12-08	10665	116.99	9.65	126.64
11515	2004-12-01	18472	386.84	31.91	418.75
11516	2004-12-24	18316	332.78	27.45	360.23
11517	2004-12-21	796	391.88	32.33	424.21
11518	2004-12-20	6949	193.69	15.98	209.67
11519	2004-12-28	17975	399.87	32.99	432.86
11520	2004-12-31	112	45.01	3.71	48.72
11521	2004-12-30	467	304.81	25.15	329.96
11522	2004-12-06	15815	277.76	22.92	300.68
11523	2004-12-06	7070	162.81	13.43	176.24
11524	2004-12-02	13868	243.71	20.11	263.82
11525	2004-12-04	11962	2.78	0.23	3.01
11526	2004-12-21	1438	343.92	28.37	372.29
11527	2004-12-12	11330	151.92	12.53	164.45
11528	2004-12-08	1116	305.91	25.24	331.15
11529	2004-12-02	3774	319.27	26.34	345.61
11530	2004-12-09	19253	138.67	11.44	150.11
11531	2004-12-31	1432	66.15	5.46	71.61
11532	2004-12-24	6916	294.83	24.32	319.15
11533	2004-12-15	1798	230.10	18.98	249.08
11534	2004-12-30	16966	350.66	28.93	379.59
11535	2004-12-24	11895	281.20	23.20	304.40
11536	2004-12-18	3816	251.78	20.77	272.55
11537	2004-12-16	8844	378.12	31.19	409.31
11538	2004-12-27	5193	301.27	24.85	326.12
11539	2004-12-27	8943	151.13	12.47	163.60
11540	2004-12-19	17383	57.49	4.74	62.23
11541	2004-12-05	1962	289.69	23.90	313.59
11542	2004-12-26	721	276.96	22.85	299.81
11543	2004-12-26	3943	134.60	11.10	145.70
11544	2004-12-20	16965	320.82	26.47	347.29
11545	2004-12-23	4553	182.94	15.09	198.03
11546	2004-12-28	12112	191.72	15.82	207.54
11547	2004-12-20	19202	251.11	20.72	271.83
11548	2004-12-05	19294	94.31	7.78	102.09
11549	2004-12-16	8921	80.58	6.65	87.23
11550	2004-12-24	9854	246.49	20.34	266.83
11551	2004-12-29	594	99.35	8.20	107.55
11552	2004-12-01	5767	355.12	29.30	384.42
11553	2004-12-20	12667	255.19	21.05	276.24
11554	2004-12-02	3217	338.20	27.90	366.10
11555	2004-12-19	2592	190.52	15.72	206.24
11556	2004-12-29	13794	245.09	20.22	265.31
11557	2004-12-30	3840	80.83	6.67	87.50
11558	2004-12-20	7468	90.10	7.43	97.53
11559	2004-12-06	8226	111.93	9.23	121.16
11560	2004-12-21	5432	10.20	0.84	11.04
11561	2004-12-22	9444	160.92	13.28	174.20
11562	2004-12-03	5885	312.41	25.77	338.18
11563	2004-12-17	19663	228.04	18.81	246.85
11564	2004-12-14	19648	72.47	5.98	78.45
11565	2004-12-20	3744	206.35	17.02	223.37
11566	2004-12-03	3784	361.68	29.84	391.52
11567	2004-12-17	4146	290.78	23.99	314.77
11568	2004-12-24	6782	349.00	28.79	377.79
11569	2004-12-02	5634	59.08	4.87	63.95
11570	2004-12-03	3481	329.04	27.15	356.19
11571	2004-12-05	10611	373.73	30.83	404.56
11572	2004-12-06	9288	389.21	32.11	421.32
11573	2004-12-26	11969	23.18	1.91	25.09
11574	2004-12-30	16260	26.98	2.23	29.21
11575	2004-12-31	15728	79.12	6.53	85.65
11576	2004-12-17	3750	348.68	28.77	377.45
11577	2004-12-17	6045	388.55	32.06	420.61
11578	2004-12-09	4347	302.91	24.99	327.90
11579	2004-12-09	1364	72.81	6.01	78.82
11580	2004-12-14	10609	345.65	28.52	374.17
11581	2004-12-12	10047	150.00	12.38	162.38
11582	2004-12-06	3692	141.96	11.71	153.67
11583	2004-12-19	1187	342.99	28.30	371.29
11584	2004-12-05	16945	368.30	30.38	398.68
11585	2004-12-06	9309	359.83	29.69	389.52
11586	2004-12-07	10936	303.61	25.05	328.66
11587	2004-12-05	13281	354.78	29.27	384.05
11588	2004-12-25	4549	48.99	4.04	53.03
11589	2004-12-24	16506	324.10	26.74	350.84
11590	2004-12-10	820	366.89	30.27	397.16
11591	2004-12-05	13802	70.32	5.80	76.12
11592	2004-12-13	14978	212.59	17.54	230.13
11593	2004-12-30	1795	321.82	26.55	348.37
11594	2004-12-17	9541	205.56	16.96	222.52
11595	2004-12-17	16507	96.65	7.97	104.62
11596	2004-12-10	7448	216.08	17.83	233.91
11597	2004-12-29	10272	299.31	24.69	324.00
11598	2004-12-20	3617	28.21	2.33	30.54
11599	2004-12-04	14200	214.89	17.73	232.62
11600	2004-12-06	4765	379.52	31.31	410.83
11601	2004-12-07	5605	373.25	30.79	404.04
11602	2004-12-10	9838	102.05	8.42	110.47
11603	2004-12-02	1294	133.78	11.04	144.82
11604	2004-12-06	10541	163.71	13.51	177.22
11605	2004-12-03	5047	373.92	30.85	404.77
11606	2004-12-17	10056	137.04	11.31	148.35
11607	2004-12-21	17198	362.87	29.94	392.81
11608	2004-12-18	4397	109.59	9.04	118.63
11609	2004-12-04	2924	116.24	9.59	125.83
11610	2004-12-25	5386	45.97	3.79	49.76
11611	2004-12-16	7901	213.47	17.61	231.08
11612	2004-12-09	18567	343.94	28.38	372.32
11613	2004-12-30	16623	64.22	5.30	69.52
11614	2004-12-18	1772	92.67	7.65	100.32
11615	2004-12-14	14621	127.29	10.50	137.79
11616	2004-12-11	10172	233.50	19.26	252.76
11617	2004-12-15	18033	209.75	17.30	227.05
11618	2004-12-29	4644	271.13	22.37	293.50
11619	2004-12-18	13506	116.13	9.58	125.71
11620	2004-12-17	13800	151.40	12.49	163.89
11621	2004-12-20	12138	256.73	21.18	277.91
11622	2004-12-13	7759	184.05	15.18	199.23
11623	2004-12-01	19528	365.92	30.19	396.11
11624	2004-12-22	62	229.36	18.92	248.28
11625	2004-12-05	15347	110.35	9.10	119.45
11626	2004-12-19	668	49.69	4.10	53.79
11627	2004-12-08	5384	224.92	18.56	243.48
11628	2004-12-23	1628	70.95	5.85	76.80
11629	2004-12-18	8467	328.97	27.14	356.11
11630	2004-12-23	5747	52.77	4.35	57.12
11631	2004-12-21	10821	144.46	11.92	156.38
11632	2004-12-31	12150	231.72	19.12	250.84
11633	2004-12-10	12043	235.06	19.39	254.45
11634	2004-12-22	1354	347.96	28.71	376.67
11635	2004-12-14	18769	59.80	4.93	64.73
11636	2004-12-09	5419	376.07	31.03	407.10
11637	2004-12-02	17679	73.48	6.06	79.54
11638	2004-12-08	234	244.52	20.17	264.69
11639	2004-12-30	10425	102.62	8.47	111.09
11640	2004-12-30	522	76.58	6.32	82.90
11641	2004-12-02	9511	222.60	18.36	240.96
11642	2004-12-09	8691	237.89	19.63	257.52
11643	2004-12-25	9447	127.67	10.53	138.20
11644	2004-12-03	6605	358.20	29.55	387.75
11645	2004-12-25	19168	225.73	18.62	244.35
11646	2004-12-23	11220	102.55	8.46	111.01
11647	2004-12-28	13724	296.90	24.49	321.39
11648	2004-12-05	11246	308.80	25.48	334.28
11649	2004-12-25	18457	251.34	20.74	272.08
11650	2004-12-07	12126	101.44	8.37	109.81
11651	2004-12-23	3409	344.75	28.44	373.19
11652	2004-12-16	3892	194.85	16.08	210.93
11653	2004-12-24	5246	26.80	2.21	29.01
11654	2004-12-18	2733	65.30	5.39	70.69
11655	2004-12-06	15183	139.12	11.48	150.60
11656	2004-12-25	19960	177.83	14.67	192.50
11657	2004-12-18	4927	8.28	0.68	8.96
11658	2004-12-14	12096	196.32	16.20	212.52
11659	2004-12-16	1930	358.37	29.57	387.94
11660	2004-12-22	17074	10.37	0.86	11.23
11661	2004-12-26	14431	308.95	25.49	334.44
11662	2004-12-23	7278	15.60	1.29	16.89
11663	2004-12-25	1513	236.45	19.51	255.96
11664	2004-12-18	17326	213.82	17.64	231.46
11665	2004-12-04	6135	293.30	24.20	317.50
11666	2004-12-04	4591	345.69	28.52	374.21
11667	2004-12-15	4463	87.22	7.20	94.42
11668	2004-12-20	9897	399.89	32.99	432.88
11669	2004-12-21	12431	100.05	8.25	108.30
11670	2004-12-09	5198	151.54	12.50	164.04
11671	2004-12-26	16085	214.10	17.66	231.76
11672	2004-12-10	3608	286.59	23.64	310.23
11673	2004-12-15	555	149.86	12.36	162.22
11674	2004-12-07	13479	156.94	12.95	169.89
11675	2004-12-23	357	121.51	10.02	131.53
11676	2004-12-04	18377	102.50	8.46	110.96
11677	2004-12-31	19719	171.87	14.18	186.05
11678	2004-12-09	9417	347.11	28.64	375.75
11679	2004-12-17	8005	246.40	20.33	266.73
11680	2004-12-19	3149	182.79	15.08	197.87
11681	2004-12-06	18418	140.22	11.57	151.79
11682	2004-12-17	9628	157.42	12.99	170.41
11683	2004-12-12	12986	233.51	19.26	252.77
11684	2004-12-14	13909	141.07	11.64	152.71
11685	2004-12-08	11479	147.98	12.21	160.19
11686	2004-12-08	3825	153.61	12.67	166.28
11687	2004-12-09	8809	219.38	18.10	237.48
11688	2004-12-03	10405	266.14	21.96	288.10
11689	2004-12-22	11737	255.37	21.07	276.44
11690	2004-12-19	18151	382.16	31.53	413.69
11691	2004-12-03	4414	283.80	23.41	307.21
11692	2004-12-19	172	351.05	28.96	380.01
11693	2004-12-25	8077	303.88	25.07	328.95
11694	2004-12-02	4176	398.59	32.88	431.47
11695	2004-12-06	82	356.98	29.45	386.43
11696	2004-12-16	16523	335.53	27.68	363.21
11697	2004-12-29	1990	263.75	21.76	285.51
11698	2004-12-03	10527	215.47	17.78	233.25
11699	2004-12-06	8954	399.53	32.96	432.49
11700	2004-12-09	7154	88.24	7.28	95.52
11701	2004-12-23	7753	145.27	11.98	157.25
11702	2004-12-01	15837	106.93	8.82	115.75
11703	2004-12-01	10307	217.44	17.94	235.38
11704	2004-12-18	18487	236.69	19.53	256.22
11705	2004-12-24	9818	385.31	31.79	417.10
11706	2004-12-22	13369	304.75	25.14	329.89
11707	2004-12-29	5122	15.33	1.26	16.59
11708	2004-12-07	16254	229.82	18.96	248.78
11709	2004-12-01	6351	364.91	30.11	395.02
11710	2004-12-14	14153	107.37	8.86	116.23
11711	2004-12-20	13740	161.60	13.33	174.93
11712	2004-12-07	348	23.19	1.91	25.10
11713	2004-12-31	14910	310.53	25.62	336.15
11714	2004-12-20	12877	112.87	9.31	122.18
11715	2004-12-04	16906	91.53	7.55	99.08
11716	2004-12-22	17088	59.19	4.88	64.07
11717	2004-12-01	13586	64.70	5.34	70.04
11718	2004-12-25	4741	96.69	7.98	104.67
11719	2004-12-25	8205	355.34	29.32	384.66
11720	2004-12-14	5758	111.48	9.20	120.68
11721	2004-12-29	13481	369.45	30.48	399.93
11722	2004-12-19	2947	379.54	31.31	410.85
11723	2004-12-16	8046	267.19	22.04	289.23
11724	2004-12-18	2744	122.03	10.07	132.10
11725	2004-12-02	4826	189.07	15.60	204.67
11726	2004-12-08	15206	124.04	10.23	134.27
11727	2004-12-11	16288	172.93	14.27	187.20
11728	2004-12-18	7657	337.55	27.85	365.40
11729	2004-12-09	3213	222.92	18.39	241.31
11730	2004-12-21	12264	292.56	24.14	316.70
11731	2004-12-24	702	266.83	22.01	288.84
11732	2004-12-26	10635	300.51	24.79	325.30
11733	2004-12-11	5682	107.70	8.89	116.59
11734	2004-12-31	2397	358.59	29.58	388.17
11735	2004-12-30	13233	341.30	28.16	369.46
11736	2004-12-31	13454	355.24	29.31	384.55
11737	2004-12-02	13149	348.03	28.71	376.74
11738	2004-12-07	15745	185.65	15.32	200.97
11739	2004-12-17	16941	297.02	24.50	321.52
11740	2004-12-30	12753	166.27	13.72	179.99
11741	2004-12-02	927	77.81	6.42	84.23
11742	2004-12-18	19235	237.25	19.57	256.82
11743	2004-12-13	7684	54.32	4.48	58.80
11744	2004-12-10	6256	393.19	32.44	425.63
11745	2004-12-11	3133	307.91	25.40	333.31
11746	2004-12-20	16531	25.69	2.12	27.81
11747	2004-12-17	16452	70.50	5.82	76.32
11748	2004-12-07	15957	29.88	2.47	32.35
11749	2004-12-24	12782	298.76	24.65	323.41
11750	2004-12-20	2264	137.61	11.35	148.96
11751	2004-12-04	2231	364.95	30.11	395.06
11752	2004-12-30	14351	13.86	1.14	15.00
11753	2004-12-20	12108	226.43	18.68	245.11
11754	2004-12-11	4878	195.86	16.16	212.02
11755	2004-12-17	9457	334.52	27.60	362.12
11756	2004-12-31	7696	194.16	16.02	210.18
11757	2004-12-25	19154	354.74	29.27	384.01
11758	2004-12-22	11820	79.62	6.57	86.19
11759	2004-12-18	14235	90.68	7.48	98.16
11760	2004-12-08	18775	94.32	7.78	102.10
11761	2004-12-31	12798	169.23	13.96	183.19
11762	2004-12-13	15164	229.81	18.96	248.77
11763	2004-12-12	16332	68.16	5.62	73.78
11764	2004-12-03	6584	133.11	10.98	144.09
11765	2004-12-13	7191	382.17	31.53	413.70
11766	2004-12-18	5053	261.68	21.59	283.27
11767	2004-12-28	5019	372.35	30.72	403.07
11768	2004-12-23	7751	93.52	7.72	101.24
11769	2004-12-08	3449	107.94	8.91	116.85
11770	2004-12-31	3727	306.97	25.33	332.30
11771	2004-12-23	15023	40.01	3.30	43.31
11772	2004-12-20	18355	248.18	20.47	268.65
11773	2004-12-15	4646	189.26	15.61	204.87
11774	2004-12-27	9970	161.59	13.33	174.92
11775	2004-12-16	3267	260.63	21.50	282.13
11776	2004-12-06	5569	140.10	11.56	151.66
11777	2004-12-31	11721	1.20	0.10	1.30
11778	2004-12-19	18574	302.60	24.96	327.56
11779	2004-12-08	12300	42.60	3.51	46.11
11780	2004-12-09	6285	348.41	28.74	377.15
11781	2004-12-19	6756	258.69	21.34	280.03
11782	2004-12-22	8516	185.97	15.34	201.31
11783	2004-12-22	18581	100.42	8.28	108.70
11784	2004-12-14	10779	269.27	22.21	291.48
11785	2004-12-26	16915	349.35	28.82	378.17
11786	2004-12-16	44	98.58	8.13	106.71
11787	2004-12-17	13478	173.29	14.30	187.59
11788	2004-12-18	18753	139.53	11.51	151.04
11789	2004-12-04	8701	264.09	21.79	285.88
11790	2004-12-24	5791	20.32	1.68	22.00
11791	2004-12-03	13277	338.53	27.93	366.46
11792	2004-12-16	6464	27.85	2.30	30.15
11793	2004-12-03	19862	223.69	18.45	242.14
11794	2004-12-19	10769	181.46	14.97	196.43
11795	2004-12-01	3270	156.38	12.90	169.28
11796	2004-12-21	16253	252.40	20.82	273.22
11797	2004-12-30	2054	365.43	30.15	395.58
11798	2004-12-05	15110	20.37	1.68	22.05
11799	2004-12-27	10782	191.36	15.79	207.15
11800	2004-12-06	5909	285.61	23.56	309.17
11801	2004-12-17	18497	251.35	20.74	272.09
11802	2004-12-19	1226	112.04	9.24	121.28
11803	2004-12-19	7579	139.93	11.54	151.47
11804	2004-12-25	5704	250.55	20.67	271.22
11805	2004-12-26	9649	288.50	23.80	312.30
11806	2004-12-03	9776	363.09	29.95	393.04
11807	2004-12-18	2871	12.38	1.02	13.40
11808	2004-12-28	5311	135.29	11.16	146.45
11809	2004-12-17	5084	344.66	28.43	373.09
11810	2004-12-16	472	257.89	21.28	279.17
11811	2004-12-14	994	227.25	18.75	246.00
11812	2004-12-10	16988	294.91	24.33	319.24
11813	2004-12-15	15090	394.55	32.55	427.10
11814	2004-12-05	8126	296.23	24.44	320.67
11815	2004-12-13	6792	90.78	7.49	98.27
11816	2004-12-02	11102	295.12	24.35	319.47
11817	2004-12-21	4794	255.57	21.08	276.65
11818	2004-12-06	5999	299.40	24.70	324.10
11819	2004-12-09	11057	257.27	21.22	278.49
11820	2004-12-03	9068	291.51	24.05	315.56
11821	2004-12-04	17633	64.01	5.28	69.29
11822	2004-12-28	1451	212.02	17.49	229.51
11823	2004-12-03	19210	211.10	17.42	228.52
11824	2004-12-31	9587	178.09	14.69	192.78
11825	2004-12-18	13113	22.29	1.84	24.13
11826	2004-12-24	2082	363.68	30.00	393.68
11827	2004-12-13	10737	183.45	15.13	198.58
11828	2004-12-28	6357	193.77	15.99	209.76
11829	2004-12-25	6374	312.34	25.77	338.11
11830	2004-12-07	9372	65.04	5.37	70.41
11831	2004-12-09	9721	281.31	23.21	304.52
11832	2004-12-06	14365	253.72	20.93	274.65
11833	2004-12-04	11254	39.25	3.24	42.49
11834	2004-12-27	6891	164.96	13.61	178.57
11835	2004-12-22	2064	185.97	15.34	201.31
11836	2004-12-21	509	361.06	29.79	390.85
11837	2004-12-19	8208	77.37	6.38	83.75
11838	2004-12-12	692	280.72	23.16	303.88
11839	2004-12-12	11200	212.26	17.51	229.77
11840	2004-12-09	13615	332.17	27.40	359.57
11841	2004-12-09	6385	315.95	26.07	342.02
11842	2004-12-15	2419	84.59	6.98	91.57
11843	2004-12-06	18819	367.35	30.31	397.66
11844	2004-12-01	785	15.43	1.27	16.70
11845	2004-12-05	12095	110.66	9.13	119.79
11846	2004-12-05	10376	217.99	17.98	235.97
11847	2004-12-23	773	378.69	31.24	409.93
11848	2004-12-27	9470	108.00	8.91	116.91
11849	2004-12-02	1681	318.75	26.30	345.05
11850	2004-12-21	14816	30.70	2.53	33.23
11851	2004-12-30	11920	310.37	25.61	335.98
11852	2004-12-31	4678	108.93	8.99	117.92
11853	2004-12-30	15871	12.85	1.06	13.91
11854	2004-12-29	18065	265.27	21.88	287.15
11855	2004-12-17	10163	277.59	22.90	300.49
11856	2004-12-23	9311	86.19	7.11	93.30
11857	2004-12-18	12222	68.82	5.68	74.50
11858	2004-12-01	3119	319.73	26.38	346.11
11859	2004-12-13	4145	368.61	30.41	399.02
11860	2004-12-10	17240	116.47	9.61	126.08
11861	2004-12-05	17151	274.40	22.64	297.04
11862	2004-12-28	17679	381.30	31.46	412.76
11863	2004-12-22	19887	167.31	13.80	181.11
11864	2004-12-01	1917	345.15	28.47	373.62
11865	2004-12-05	17236	134.31	11.08	145.39
11866	2004-12-10	2718	261.07	21.54	282.61
11867	2004-12-28	16111	342.46	28.25	370.71
11868	2004-12-19	14130	37.89	3.13	41.02
11869	2004-12-18	15785	248.20	20.48	268.68
11870	2004-12-14	913	212.10	17.50	229.60
11871	2004-12-16	7594	92.95	7.67	100.62
11872	2004-12-31	1990	356.73	29.43	386.16
11873	2004-12-25	12484	304.85	25.15	330.00
11874	2004-12-27	17590	179.54	14.81	194.35
11875	2004-12-01	8482	88.72	7.32	96.04
11876	2004-12-27	3855	124.95	10.31	135.26
11877	2004-12-02	17297	285.43	23.55	308.98
11878	2004-12-28	7617	266.35	21.97	288.32
11879	2004-12-22	3504	98.05	8.09	106.14
11880	2004-12-27	17300	191.02	15.76	206.78
11881	2004-12-02	4748	366.05	30.20	396.25
11882	2004-12-01	16690	105.06	8.67	113.73
11883	2004-12-05	2847	388.41	32.04	420.45
11884	2004-12-10	19912	36.40	3.00	39.40
11885	2004-12-02	11164	246.60	20.34	266.94
11886	2004-12-19	1339	76.55	6.32	82.87
11887	2004-12-15	2919	85.04	7.02	92.06
11888	2004-12-03	10899	340.98	28.13	369.11
11889	2004-12-02	1871	361.11	29.79	390.90
11890	2004-12-17	19252	349.55	28.84	378.39
11891	2004-12-10	6076	340.98	28.13	369.11
11892	2004-12-27	12479	391.06	32.26	423.32
11893	2004-12-22	2111	343.86	28.37	372.23
11894	2004-12-19	13402	342.68	28.27	370.95
11895	2004-12-26	9163	128.96	10.64	139.60
11896	2004-12-08	10146	338.78	27.95	366.73
11897	2004-12-06	4549	109.78	9.06	118.84
11898	2004-12-18	16858	162.44	13.40	175.84
11899	2004-12-23	4087	370.21	30.54	400.75
11900	2004-12-10	13581	44.66	3.68	48.34
11901	2004-12-20	7352	200.80	16.57	217.37
11902	2004-12-26	16899	239.50	19.76	259.26
11903	2004-12-18	12177	264.42	21.81	286.23
11904	2004-12-21	18497	256.82	21.19	278.01
11905	2004-12-20	4012	60.65	5.00	65.65
11906	2004-12-05	15627	177.06	14.61	191.67
11907	2004-12-10	1134	280.75	23.16	303.91
11908	2004-12-27	1719	122.57	10.11	132.68
11909	2004-12-01	4568	290.47	23.96	314.43
11910	2004-12-17	14345	333.14	27.48	360.62
11911	2004-12-11	7964	25.58	2.11	27.69
11912	2004-12-08	16246	199.13	16.43	215.56
11913	2004-12-04	11240	368.67	30.42	399.09
11914	2004-12-10	8921	2.07	0.17	2.24
11915	2004-12-17	11329	283.69	23.40	307.09
11916	2004-12-29	2687	111.57	9.20	120.77
11917	2004-12-28	589	247.28	20.40	267.68
11918	2004-12-31	10100	344.92	28.46	373.38
11919	2004-12-30	19126	239.86	19.79	259.65
11920	2004-12-23	2638	214.23	17.67	231.90
11921	2004-12-30	15513	55.86	4.61	60.47
11922	2004-12-28	2733	97.30	8.03	105.33
11923	2004-12-28	1269	63.05	5.20	68.25
11924	2004-12-31	6047	154.39	12.74	167.13
11925	2004-12-05	2386	51.65	4.26	55.91
11926	2004-12-05	13848	200.27	16.52	216.79
11927	2004-12-25	11438	92.59	7.64	100.23
11928	2004-12-12	9728	213.54	17.62	231.16
11929	2004-12-03	12777	75.56	6.23	81.79
11930	2004-12-11	17479	129.41	10.68	140.09
11931	2004-12-12	4610	171.75	14.17	185.92
11932	2004-12-15	15707	48.57	4.01	52.58
11933	2004-12-19	12166	207.82	17.15	224.97
11934	2004-12-01	10065	26.00	2.15	28.14
11935	2004-12-27	2493	138.67	11.44	150.11
11936	2004-12-15	17647	268.90	22.18	291.08
11937	2004-12-09	15483	308.92	25.49	334.41
11938	2004-12-10	560	140.41	11.58	151.99
11939	2004-12-09	10195	238.76	19.70	258.46
11940	2004-12-15	4996	371.37	30.64	402.01
11941	2004-12-01	19972	389.97	32.17	422.14
11942	2004-12-02	1243	334.80	27.62	362.42
11943	2004-12-08	11091	219.67	18.12	237.79
11944	2004-12-06	16475	354.21	29.22	383.43
11945	2004-12-17	17292	274.34	22.63	296.97
11946	2004-12-09	19068	378.08	31.19	409.27
11947	2004-12-10	5760	27.65	2.28	29.93
11948	2004-12-06	13518	194.54	16.05	210.59
11949	2004-12-11	16475	5.77	0.48	6.25
11950	2004-12-31	15356	381.83	31.50	413.33
11951	2004-12-12	1535	73.15	6.03	79.18
11952	2004-12-23	5436	81.30	6.71	88.01
11953	2004-12-03	11088	180.44	14.89	195.33
11954	2004-12-24	1049	167.02	13.78	180.80
11955	2004-12-10	2012	189.49	15.63	205.12
11956	2004-12-08	4182	330.40	27.26	357.66
11957	2004-12-17	15663	306.44	25.28	331.72
11958	2004-12-11	1640	37.96	3.13	41.09
11959	2004-12-08	17290	89.46	7.38	96.84
11960	2004-12-29	8663	344.45	28.42	372.87
11961	2004-12-02	3439	158.64	13.09	171.73
11962	2004-12-01	14344	127.42	10.51	137.93
11963	2004-12-18	9729	92.88	7.66	100.54
11964	2004-12-06	13194	123.60	10.20	133.80
11965	2004-12-15	19991	228.64	18.86	247.50
11966	2004-12-12	2943	302.08	24.92	327.00
11967	2004-12-04	12037	361.96	29.86	391.82
11968	2004-12-11	19372	171.00	14.11	185.11
11969	2004-12-13	3135	110.18	9.09	119.27
11970	2004-12-29	121	219.32	18.09	237.41
11971	2004-12-02	12943	355.16	29.30	384.46
11972	2004-12-14	1695	277.73	22.91	300.64
11973	2004-12-05	8887	43.26	3.57	46.83
11974	2004-12-30	13972	23.97	1.98	25.95
11975	2004-12-12	6655	231.65	19.11	250.76
11976	2004-12-03	18473	96.04	7.92	103.96
11977	2004-12-31	7050	27.88	2.30	30.18
11978	2004-12-11	13595	142.19	11.73	153.92
11979	2004-12-08	5675	374.87	30.93	405.80
11980	2004-12-01	9262	56.10	4.63	60.73
11981	2004-12-16	14017	51.42	4.24	55.66
11982	2004-12-27	15172	220.33	18.18	238.51
11983	2004-12-24	12057	375.28	30.96	406.24
11984	2004-12-31	10205	33.68	2.78	36.46
11985	2004-12-18	13522	7.10	0.59	7.69
11986	2004-12-11	1509	242.03	19.97	262.00
11987	2004-12-11	1377	194.56	16.05	210.61
11988	2004-12-13	11438	5.75	0.47	6.22
11989	2004-12-08	18765	194.95	16.08	211.03
11990	2004-12-29	19502	352.14	29.05	381.19
11991	2004-12-07	17705	67.69	5.58	73.27
11992	2004-12-21	14287	366.74	30.26	397.00
11993	2004-12-22	6407	52.55	4.34	56.89
11994	2004-12-26	9598	189.74	15.65	205.39
11995	2004-12-16	12643	35.02	2.89	37.91
11996	2004-12-28	15270	158.58	13.08	171.66
11997	2004-12-26	1180	198.05	16.34	214.39
11998	2004-12-06	17427	33.81	2.79	36.60
11999	2004-12-25	1485	175.34	14.47	189.81
12000	2004-12-15	7393	205.09	16.92	222.01
\.


--
-- Data for Name: products; Type: TABLE DATA; Schema: public; Owner: chriskl
--

COPY products (prod_id, category, title, actor, price, special, common_prod_id) FROM stdin;
1	14	ACADEMY ACADEMY	PENELOPE GUINESS	25.99	0	1976
2	6	ACADEMY ACE	EWAN RICKMAN	20.99	0	6289
3	6	ACADEMY ADAPTATION	VIVIEN KAHN	28.99	0	7173
4	3	ACADEMY AFFAIR	ALAN MARX	14.99	0	8042
5	3	ACADEMY AFRICAN	CARRIE HANNAH	11.99	1	2183
6	9	ACADEMY AGENT	LISA SPACEK	15.99	0	5243
7	8	ACADEMY AIRPLANE	FRANCES WINFREY	25.99	0	7700
8	7	ACADEMY AIRPORT	FARRAH TOMEI	16.99	0	9191
9	2	ACADEMY ALABAMA	JULIETTE WEAVER	10.99	0	6633
10	15	ACADEMY ALADDIN	ANNETTE FREEMAN	9.99	0	631
11	4	ACADEMY ALAMO	SOPHIA WINFREY	26.99	0	5398
12	7	ACADEMY ALASKA	JUDY REYNOLDS	23.99	0	393
13	8	ACADEMY ALI	TIM WASHINGTON	24.99	0	7386
14	11	ACADEMY ALICE	MENA GABLE	12.99	0	8801
15	14	ACADEMY ALIEN	DORIS FONDA	27.99	0	6867
16	16	ACADEMY ALLEY	MARLON LUGOSI	27.99	0	9240
17	7	ACADEMY ALONE	MEL SILVERSTONE	28.99	0	2159
18	16	ACADEMY ALTER	CHARLIZE WAHLBERG	27.99	0	4320
19	10	ACADEMY AMADEUS	RALPH DREYFUSS	15.99	0	2262
20	4	ACADEMY AMELIE	KIM DOUGLAS	17.99	0	9069
21	2	ACADEMY AMERICAN	JON BULLOCK	24.99	0	9351
22	11	ACADEMY AMISTAD	NICOLE GOODING	16.99	0	2323
23	10	ACADEMY ANACONDA	CHARLTON DENCH	24.99	0	7935
24	3	ACADEMY ANALYZE	AUDREY POITIER	28.99	0	5216
25	3	ACADEMY ANGELS	REESE DENCH	24.99	0	9675
26	11	ACADEMY ANNIE	BOB PRESLEY	11.99	0	783
27	2	ACADEMY ANONYMOUS	JESSICA DAFOE	26.99	0	7556
28	1	ACADEMY ANTHEM	ZERO CHASE	13.99	0	1255
29	16	ACADEMY ANTITRUST	SCARLETT BASINGER	10.99	0	9231
30	10	ACADEMY ANYTHING	CHRIS CRONYN	17.99	0	8197
31	6	ACADEMY APACHE	LAURA LANCASTER	18.99	0	997
32	9	ACADEMY APOCALYPSE	FRED PRESLEY	29.99	0	8777
33	12	ACADEMY APOLLO	ANDY MCGREGOR	24.99	0	9254
34	14	ACADEMY ARABIA	WILLEM SORVINO	24.99	0	9836
35	11	ACADEMY ARACHNOPHOBIA	CHRIS JOHANSSON	26.99	0	770
36	11	ACADEMY ARGONAUTS	LUCILLE DENIRO	13.99	0	3169
37	6	ACADEMY ARIZONA	AUDREY DEE	22.99	0	6512
38	9	ACADEMY ARK	FARRAH WINFREY	20.99	0	1133
39	8	ACADEMY ARMAGEDDON	UMA MALDEN	18.99	0	8477
40	7	ACADEMY ARMY	GREG AFFLECK	21.99	0	2339
41	11	ACADEMY ARSENIC	JOE HUSTON	15.99	0	1826
42	10	ACADEMY ARTIST	IAN BALL	23.99	0	6377
43	6	ACADEMY ATLANTIS	LIAM CRONYN	22.99	0	3284
44	12	ACADEMY ATTACKS	SYLVESTER DAFOE	23.99	0	2573
45	9	ACADEMY ATTRACTION	ELVIS BLANCHETT	27.99	0	938
46	2	ACADEMY AUTUMN	LAURA GARCIA	21.99	0	2888
47	13	ACADEMY BABY	GLENN DRIVER	12.99	0	36
48	14	ACADEMY BACKLASH	CUBA FONDA	18.99	0	9190
49	13	ACADEMY BADMAN	CARMEN OLIVIER	23.99	0	7743
50	16	ACADEMY BAKED	SALMA VOIGHT	13.99	0	5481
51	5	ACADEMY BALLOON	SPENCER TRACY	27.99	0	5762
52	3	ACADEMY BALLROOM	SALMA DIETRICH	19.99	0	8490
53	8	ACADEMY BANG	CLINT DUKAKIS	23.99	0	1391
54	10	ACADEMY BANGER	ROCK JACKMAN	24.99	0	2220
55	8	ACADEMY BARBARELLA	CATE BRODY	16.99	0	9319
56	15	ACADEMY BAREFOOT	ROCK MCDORMAND	26.99	0	3350
57	7	ACADEMY BASIC	LIAM MOORE	14.99	0	726
58	2	ACADEMY BEACH	GWYNETH MIRANDA	15.99	0	912
59	7	ACADEMY BEAR	LAUREN WASHINGTON	14.99	0	7618
60	8	ACADEMY BEAST	SHIRLEY CHASE	22.99	0	2079
61	9	ACADEMY BEAUTY	ROBERT HECHE	17.99	0	3261
62	12	ACADEMY BED	WILLIAM MCQUEEN	16.99	0	1361
63	7	ACADEMY BEDAZZLED	PENELOPE AKROYD	25.99	0	1147
64	14	ACADEMY BEETHOVEN	ANGELINA PESCI	18.99	0	7080
65	4	ACADEMY BEHAVIOR	SANDRA HUNT	10.99	0	3829
66	5	ACADEMY BENEATH	RICHARD MOORE	11.99	0	535
67	8	ACADEMY BERETS	MERYL RUSH	18.99	0	5897
68	10	ACADEMY BETRAYED	LENA KELLY	16.99	0	8888
69	8	ACADEMY BEVERLY	LIAM COOPER	20.99	0	5962
70	4	ACADEMY BIKINI	AUDREY SOBIESKI	11.99	0	1697
71	8	ACADEMY BILKO	ROBERT DEAN	15.99	0	8783
72	6	ACADEMY BILL	MARLON SILVERSTONE	9.99	0	7783
73	11	ACADEMY BINGO	GARY SPACEK	13.99	0	6125
74	2	ACADEMY BIRCH	PENELOPE NEWMAN	24.99	0	4012
75	6	ACADEMY BIRD	DREW HEPBURN	17.99	0	1548
76	9	ACADEMY BIRDCAGE	HELEN ALLEN	17.99	0	7375
77	5	ACADEMY BIRDS	KEVIN MIRANDA	28.99	0	8098
78	12	ACADEMY BLACKOUT	MARISA FIELD	9.99	0	8440
79	10	ACADEMY BLADE	JULIA MINELLI	17.99	0	7189
80	13	ACADEMY BLANKET	CHARLTON NICHOLSON	9.99	0	6858
81	4	ACADEMY BLINDNESS	MICHELLE MCCONAUGHEY	20.99	0	58
82	5	ACADEMY BLOOD	MARLON DIAZ	27.99	0	3414
83	11	ACADEMY BLUES	MARLENE TEMPLE	15.99	0	1863
84	3	ACADEMY BOILED	ROBERT JOLIE	23.99	0	1912
85	7	ACADEMY BONNIE	SANDRA PALTROW	20.99	0	9325
86	4	ACADEMY BOOGIE	KEVIN WALKEN	28.99	0	5526
87	16	ACADEMY BOONDOCK	RIP RYDER	21.99	0	9953
88	15	ACADEMY BORN	SCARLETT FINNEY	21.99	0	7594
89	13	ACADEMY BORROWERS	ELVIS RYAN	21.99	0	1670
90	13	ACADEMY BOULEVARD	SCARLETT TAUTOU	22.99	0	6120
91	10	ACADEMY BOUND	KATE MIRANDA	12.99	0	330
92	12	ACADEMY BOWFINGER	ROBIN KEATON	19.99	0	4899
93	9	ACADEMY BRANNIGAN	RIP BARRYMORE	17.99	0	4522
94	3	ACADEMY BRAVEHEART	EDWARD HAWKE	17.99	0	7176
95	10	ACADEMY BREAKFAST	LAUREN SILVERSTONE	18.99	0	9952
96	1	ACADEMY BREAKING	MARILYN BERGMAN	21.99	0	2198
97	11	ACADEMY BRIDE	NICK WAHLBERG	18.99	0	8506
98	16	ACADEMY BRIGHT	SISSY WEAVER	25.99	0	5368
99	4	ACADEMY BRINGING	VAL HURT	18.99	0	9673
100	3	ACADEMY BROOKLYN	PENELOPE HOPPER	25.99	0	2576
101	13	ACADEMY BROTHERHOOD	GOLDIE WILLIS	17.99	0	5545
102	10	ACADEMY BUBBLE	JODIE CRUISE	16.99	0	9166
103	4	ACADEMY BUCKET	SANDRA MARX	11.99	0	1991
104	11	ACADEMY BUGSY	MEG MALDEN	21.99	0	5609
105	10	ACADEMY BULL	ALAN DENCH	16.99	0	9237
106	10	ACADEMY BULWORTH	SIDNEY ROBBINS	28.99	0	4480
107	8	ACADEMY BUNCH	MAE RYDER	29.99	0	2929
108	15	ACADEMY BUTCH	SISSY GARLAND	24.99	0	2730
109	16	ACADEMY BUTTERFLY	SANDRA BRODY	22.99	0	9246
110	3	ACADEMY CABIN	CHRISTIAN DREYFUSS	13.99	0	1763
111	3	ACADEMY CADDYSHACK	VAL DEAN	9.99	0	1200
112	8	ACADEMY CALENDAR	SUSAN MIRANDA	11.99	0	706
113	7	ACADEMY CALIFORNIA	JANE JOHANSSON	15.99	0	9124
114	10	ACADEMY CAMELOT	ALICIA CRUISE	18.99	0	7534
115	6	ACADEMY CAMPUS	ANDY ZELLWEGER	19.99	0	6618
116	12	ACADEMY CANDIDATE	SIDNEY FISHER	22.99	0	502
117	13	ACADEMY CANDLES	MICHAEL SANDLER	23.99	0	3130
118	13	ACADEMY CANYON	RICHARD DUNST	12.99	0	535
119	2	ACADEMY CAPER	ED CHASE	11.99	0	581
120	15	ACADEMY CARIBBEAN	ANNE WEAVER	28.99	0	2570
121	10	ACADEMY CAROL	LAUREN COOPER	19.99	0	9261
122	9	ACADEMY CARRIE	NATALIE LOREN	13.99	0	6336
123	9	ACADEMY CASABLANCA	TIM ANISTON	16.99	0	5227
124	7	ACADEMY CASPER	MEG FAWCETT	22.99	0	2691
125	12	ACADEMY CASSIDY	DENNIS FONDA	24.99	0	6836
126	1	ACADEMY CASUALTIES	RUSSELL STREEP	21.99	0	6680
127	9	ACADEMY CAT	ELIZABETH STREEP	14.99	0	5144
128	15	ACADEMY CATCH	KARL MATTHAU	26.99	0	7368
129	6	ACADEMY CAUSE	ANGELA GARBO	9.99	0	4873
130	5	ACADEMY CELEBRITY	RIVER PALTROW	19.99	0	783
131	4	ACADEMY CENTER	SYLVESTER HUSTON	9.99	0	2449
132	12	ACADEMY CHAINSAW	BOB MATTHAU	29.99	0	1661
133	8	ACADEMY CHAMBER	PEARL PRESLEY	9.99	0	7365
134	12	ACADEMY CHAMPION	BRAD WAHLBERG	25.99	0	1015
135	5	ACADEMY CHANCE	RICHARD DEGENERES	10.99	0	2773
136	3	ACADEMY CHAPLIN	ORLANDO WATSON	11.99	0	8453
137	6	ACADEMY CHARADE	JEREMY ODONNELL	18.99	0	3240
138	10	ACADEMY CHARIOTS	BEN BULLOCK	16.99	0	6599
139	2	ACADEMY CHASING	LAUREN THERON	13.99	0	5289
140	5	ACADEMY CHEAPER	PARKER WAYNE	11.99	0	5150
141	7	ACADEMY CHICAGO	JENNIFER DAVIS	12.99	0	4338
142	1	ACADEMY CHICKEN	CARRIE MIRANDA	18.99	0	7803
143	13	ACADEMY CHILL	STEVE NOLTE	27.99	0	472
144	9	ACADEMY CHINATOWN	THORA CRAWFORD	11.99	0	5962
145	11	ACADEMY CHISUM	KATE PACINO	17.99	0	5777
146	15	ACADEMY CHITTY	RALPH DAY-LEWIS	16.99	0	975
147	13	ACADEMY CHOCOLAT	NICOLE GRANT	28.99	0	8315
148	12	ACADEMY CHOCOLATE	JULIA MCQUEEN	22.99	0	5789
149	11	ACADEMY CHRISTMAS	OPRAH BACALL	21.99	0	1440
150	4	ACADEMY CIDER	ROSIE ROBERTS	24.99	0	6668
151	6	ACADEMY CINCINATTI	SIDNEY BRANAGH	11.99	0	2704
152	4	ACADEMY CIRCUS	MARLON DRIVER	28.99	0	5070
153	13	ACADEMY CITIZEN	CHARLES WATSON	15.99	0	6446
154	14	ACADEMY CLASH	MATTHEW DEE	22.99	0	8130
155	13	ACADEMY CLEOPATRA	LEELEE BACALL	21.99	0	7745
156	5	ACADEMY CLERKS	SHIRLEY BERRY	12.99	0	3598
157	8	ACADEMY CLOCKWORK	MARISA GOLDBERG	11.99	0	8695
158	10	ACADEMY CLONES	RICHARD BOLGER	24.99	0	3668
159	7	ACADEMY CLOSER	LENA DIETRICH	10.99	0	4322
160	15	ACADEMY CLUB	JESSICA NEWMAN	18.99	0	2245
161	4	ACADEMY CLUE	FRED LOLLOBRIGIDA	11.99	0	4802
162	8	ACADEMY CLUELESS	SALLY CRUISE	11.99	0	1846
163	1	ACADEMY CLYDE	FAY TRACY	25.99	0	6876
164	3	ACADEMY COAST	WALTER BALL	25.99	0	8613
165	4	ACADEMY COLDBLOODED	KATE WRAY	23.99	0	8286
166	15	ACADEMY COLOR	HUMPHREY PECK	13.99	0	1548
167	11	ACADEMY COMA	GREGORY FINNEY	20.99	0	6404
168	12	ACADEMY COMANCHEROS	KATHARINE HORNE	9.99	0	1917
169	12	ACADEMY COMFORTS	DUSTIN HOFFMAN	22.99	0	3494
170	9	ACADEMY COMMAND	GREG HECHE	10.99	0	8094
171	15	ACADEMY COMMANDMENTS	JULIANNE WOOD	14.99	0	3593
172	8	ACADEMY CONEHEADS	MEL SUVARI	25.99	0	1404
173	7	ACADEMY CONFESSIONS	LEONARDO BOLGER	29.99	0	8691
174	3	ACADEMY CONFIDENTIAL	GENE SANDLER	17.99	0	5324
175	12	ACADEMY CONFUSED	WALTER WINFREY	10.99	0	531
176	15	ACADEMY CONGENIALITY	ANDY TORN	17.99	0	2199
177	13	ACADEMY CONNECTICUT	AUDREY MCDORMAND	18.99	0	4600
178	10	ACADEMY CONNECTION	KIRK SPACEK	13.99	0	6726
179	2	ACADEMY CONQUERER	JODIE WILLIS	17.99	0	9309
180	15	ACADEMY CONSPIRACY	SOPHIA BOLGER	27.99	0	9215
181	15	ACADEMY CONTACT	RIVER BLANCHETT	29.99	0	48
182	4	ACADEMY CONTROL	LUCILLE DRIVER	14.99	0	365
183	12	ACADEMY CONVERSATION	SCARLETT GABLE	14.99	0	6753
184	16	ACADEMY CORE	MAE MCDORMAND	18.99	0	9961
185	6	ACADEMY COWBOY	BRAD WALKEN	14.99	0	2911
186	3	ACADEMY CRAFT	HELEN PFEIFFER	9.99	0	8896
187	1	ACADEMY CRANES	CLARK THURMAN	22.99	0	9254
188	11	ACADEMY CRAZY	EWAN TAYLOR	20.99	0	8287
189	4	ACADEMY CREATURES	JENNIFER BRANDO	27.99	0	4613
190	14	ACADEMY CREEPERS	HENRY TURNER	29.99	0	1877
191	4	ACADEMY CROOKED	SUSAN GARCIA	22.99	0	6155
192	9	ACADEMY CROSSING	JUDE GOLDBERG	23.99	0	6501
193	10	ACADEMY CROSSROADS	JULIANNE ODONNELL	27.99	0	6754
194	12	ACADEMY CROW	RALPH HORNE	12.99	0	3341
195	11	ACADEMY CROWDS	ED CRONYN	9.99	0	4177
196	4	ACADEMY CRUELTY	PEARL GRANT	11.99	0	1450
197	12	ACADEMY CRUSADE	JULIANNE KIDMAN	14.99	0	5418
198	15	ACADEMY CRYSTAL	DUSTIN STALLONE	17.99	0	4769
199	2	ACADEMY CUPBOARD	UMA HORNE	27.99	0	2665
200	4	ACADEMY CURTAIN	JEFF DOUGLAS	18.99	0	5866
201	15	ACADEMY CYCLONE	WILL KAHN	22.99	0	9850
202	13	ACADEMY DADDY	JULIA GRANT	15.99	0	7402
203	14	ACADEMY DAISY	LAUREN KIDMAN	11.99	0	3238
204	10	ACADEMY DALMATIONS	RALPH BALL	19.99	0	4273
205	13	ACADEMY DANCES	MILLA CAINE	13.99	0	79
206	14	ACADEMY DANCING	JULIANNE HUNT	25.99	0	1673
207	13	ACADEMY DANGEROUS	KIM WALKEN	15.99	0	1936
208	1	ACADEMY DARES	NATALIE BRANDO	21.99	0	6782
209	16	ACADEMY DARKNESS	MORGAN RUSSELL	24.99	0	6457
210	3	ACADEMY DARKO	PENELOPE BLOOM	27.99	0	3817
211	14	ACADEMY DARLING	RUSSELL CAMPBELL	17.99	0	9815
212	9	ACADEMY DARN	SPENCER PALTROW	11.99	0	1550
213	5	ACADEMY DATE	EMILY BAILEY	9.99	0	4789
214	12	ACADEMY DAUGHTER	EMILY LUGOSI	18.99	0	5732
215	2	ACADEMY DAWN	MARY HUDSON	27.99	0	9860
216	4	ACADEMY DAY	CARRIE CRUISE	11.99	0	605
217	2	ACADEMY DAZED	PARKER CAMPBELL	29.99	0	7692
218	3	ACADEMY DECEIVER	RENEE LAW	17.99	0	4484
219	15	ACADEMY DEEP	ANDY FIELD	12.99	0	3496
220	12	ACADEMY DEER	RITA SOBIESKI	17.99	0	1454
221	7	ACADEMY DELIVERANCE	GREG WATSON	19.99	0	9254
222	10	ACADEMY DESERT	ANTHONY BRODY	16.99	0	3241
223	2	ACADEMY DESIRE	SIDNEY DERN	28.99	0	4877
224	6	ACADEMY DESPERATE	RENEE LANSBURY	17.99	0	5474
225	12	ACADEMY DESTINATION	HARRISON HOPE	20.99	0	675
226	12	ACADEMY DESTINY	ADRIEN DAY-LEWIS	9.99	0	466
227	16	ACADEMY DETAILS	CHRISTIAN DUNST	9.99	0	2814
228	6	ACADEMY DETECTIVE	KATE PINKETT	14.99	0	2063
229	12	ACADEMY DEVIL	ORLANDO AFFLECK	20.99	0	4812
230	2	ACADEMY DIARY	THORA CAGE	18.99	0	7689
231	9	ACADEMY DINOSAUR	WINONA HACKMAN	20.99	0	7178
232	10	ACADEMY DIRTY	AL HARRIS	24.99	0	6477
233	1	ACADEMY DISCIPLE	HENRY SARANDON	20.99	0	344
234	13	ACADEMY DISTURBING	ANDY RYAN	20.99	0	4297
235	1	ACADEMY DIVIDE	KIRK HAWKE	28.99	0	2550
236	12	ACADEMY DIVINE	MARLENE HACKMAN	23.99	0	895
237	7	ACADEMY DIVORCE	JON KAHN	18.99	0	9431
238	2	ACADEMY DOCTOR	NICOLE DUKAKIS	18.99	0	8047
239	9	ACADEMY DOGMA	LENA MCQUEEN	20.99	0	9263
240	16	ACADEMY DOLLS	GREG CRUZ	20.99	0	2132
241	13	ACADEMY DONNIE	LISA TANDY	18.99	0	5463
242	9	ACADEMY DOOM	ANNE WRAY	9.99	0	3211
243	16	ACADEMY DOORS	LISA KEATON	24.99	1	4739
244	9	ACADEMY DORADO	BURT JOLIE	11.99	0	2840
245	1	ACADEMY DOUBLE	JODIE ASTAIRE	17.99	0	6238
246	10	ACADEMY DOUBTFIRE	JOHN GABLE	13.99	0	543
247	13	ACADEMY DOWNHILL	ANGELINA FISHER	26.99	0	4802
248	3	ACADEMY DOZEN	ZERO FISHER	24.99	0	9924
249	4	ACADEMY DRACULA	JOHNNY LOLLOBRIGIDA	16.99	0	5402
250	10	ACADEMY DRAGON	KIRK POSEY	11.99	0	1196
251	12	ACADEMY DRAGONFLY	JOAN POITIER	13.99	0	2646
252	5	ACADEMY DREAM	LEELEE PFEIFFER	15.99	0	9469
253	13	ACADEMY DRIFTER	EWAN ODONNELL	25.99	0	3279
254	13	ACADEMY DRIVER	SPENCER NICHOLSON	14.99	0	6092
255	14	ACADEMY DRIVING	GWYNETH MCQUEEN	16.99	0	5054
256	9	ACADEMY DROP	ELIZABETH HUDSON	29.99	0	2151
257	4	ACADEMY DRUMLINE	UMA WAYNE	26.99	0	4885
258	13	ACADEMY DRUMS	CLARK BASINGER	10.99	0	6256
259	7	ACADEMY DUCK	FRED MCKELLEN	14.99	0	3180
260	15	ACADEMY DUDE	WALTER PFEIFFER	14.99	0	6978
261	13	ACADEMY DUFFEL	CHRISTIAN MARX	9.99	0	8439
262	4	ACADEMY DUMBO	RALPH SINATRA	12.99	0	469
263	11	ACADEMY DURHAM	BRAD HAWKE	26.99	0	9439
264	8	ACADEMY DWARFS	LANA SPACEK	25.99	0	4838
265	2	ACADEMY DYING	DENNIS ALLEN	9.99	0	3220
266	12	ACADEMY DYNAMITE	TIM BACALL	27.99	0	5114
267	12	ACADEMY EAGLES	GLENN DICAPRIO	20.99	0	9679
268	10	ACADEMY EARLY	HELEN BLOOM	23.99	0	8445
269	10	ACADEMY EARRING	MEL GRANT	13.99	0	8064
270	11	ACADEMY EARTH	RIVER DEE	27.99	0	904
271	4	ACADEMY EASY	CANDICE AFFLECK	12.99	0	1602
272	11	ACADEMY EDGE	JADA MIRANDA	29.99	0	8630
273	16	ACADEMY EFFECT	VIVIEN PRESLEY	16.99	0	8806
274	3	ACADEMY EGG	EMILY BENING	27.99	0	4175
275	11	ACADEMY EGYPT	MARISA WATSON	19.99	0	9163
276	10	ACADEMY ELEMENT	SUSAN BALL	23.99	0	8229
277	14	ACADEMY ELEPHANT	JOAN STREEP	15.99	0	6505
278	3	ACADEMY ELF	IAN RUSH	11.99	0	8480
279	16	ACADEMY ELIZABETH	SPENCER DUNST	14.99	0	1647
280	11	ACADEMY EMPIRE	BRUCE SOBIESKI	15.99	0	9311
281	4	ACADEMY ENCINO	WILLEM TORN	12.99	0	1659
282	16	ACADEMY ENCOUNTERS	AL HOPPER	18.99	0	8462
283	2	ACADEMY ENDING	MADELINE TOMEI	19.99	1	7486
284	6	ACADEMY ENEMY	ANGELA WITHERSPOON	14.99	0	2036
285	7	ACADEMY ENGLISH	ALICIA TRACY	20.99	0	3473
286	8	ACADEMY ENOUGH	ED HOPPER	18.99	0	8399
287	10	ACADEMY ENTRAPMENT	FRANK LUGOSI	21.99	0	380
288	8	ACADEMY ESCAPE	TIM CAGE	10.99	0	9278
289	14	ACADEMY EVE	SPENCER ZELLWEGER	27.99	0	1442
290	2	ACADEMY EVERYONE	ANGELINA NORTON	11.99	0	2715
291	8	ACADEMY EVOLUTION	NATALIE NICHOLSON	23.99	0	3398
292	9	ACADEMY EXCITEMENT	THORA PENN	26.99	0	9627
293	15	ACADEMY EXORCIST	BRAD RYAN	26.99	0	7354
294	12	ACADEMY EXPECATIONS	NEVE PFEIFFER	22.99	0	9902
295	13	ACADEMY EXPENDABLE	MEG PACINO	26.99	0	8951
296	2	ACADEMY EXPRESS	LANA DUKAKIS	26.99	0	6873
297	3	ACADEMY EXTRAORDINARY	HUME LANCASTER	11.99	0	7358
298	2	ACADEMY EYES	JULIETTE DRIVER	12.99	0	4168
299	15	ACADEMY FACTORY	CHARLES STALLONE	22.99	0	7583
300	11	ACADEMY FALCON	JESSICA DUKAKIS	15.99	0	2854
301	4	ACADEMY FAMILY	LAURA DERN	25.99	0	5792
302	8	ACADEMY FANTASIA	CARY DRIVER	27.99	0	5337
303	10	ACADEMY FANTASY	RITA HUNT	11.99	0	9190
304	9	ACADEMY FARGO	ORLANDO LANCASTER	23.99	0	2580
305	8	ACADEMY FATAL	KEVIN SINATRA	28.99	0	6886
306	4	ACADEMY FEATHERS	UMA FINNEY	25.99	0	444
307	6	ACADEMY FELLOWSHIP	GOLDIE LANCASTER	19.99	0	7295
308	1	ACADEMY FERRIS	DARYL ANISTON	26.99	0	8497
309	13	ACADEMY FEUD	HUME ODONNELL	19.99	0	5901
310	13	ACADEMY FEVER	HUMPHREY SORVINO	15.99	0	5268
311	1	ACADEMY FICTION	RUBY WATSON	29.99	0	9414
312	1	ACADEMY FIDDLER	JON BENING	16.99	0	9134
313	2	ACADEMY FIDELITY	TIM LEIGH	14.99	0	780
314	2	ACADEMY FIGHT	PAUL CLOSE	19.99	0	1553
315	2	ACADEMY FINDING	WINONA HOPPER	19.99	0	7322
316	1	ACADEMY FIRE	MATTHEW RYDER	27.99	0	3846
317	14	ACADEMY FIREBALL	JEFF REYNOLDS	15.99	0	9982
318	4	ACADEMY FIREHOUSE	KIRSTEN CHASE	12.99	0	9711
319	4	ACADEMY FISH	CARY KINNEAR	9.99	0	8122
320	3	ACADEMY FLAMINGOS	EMILY COSTNER	12.99	0	514
321	15	ACADEMY FLASH	RUBY PFEIFFER	20.99	0	6075
322	16	ACADEMY FLATLINERS	HALLE HOPE	17.99	0	4634
323	7	ACADEMY FLIGHT	LIZA AKROYD	29.99	0	476
324	15	ACADEMY FLINTSTONES	LEELEE HECHE	10.99	0	6526
325	15	ACADEMY FLOATS	RIVER MCDORMAND	12.99	0	5078
326	4	ACADEMY FLYING	DREW NICHOLSON	10.99	0	8490
327	11	ACADEMY FOOL	FRANCES CRUZ	9.99	0	646
328	8	ACADEMY FOREVER	AUDREY WRAY	11.99	0	2533
329	3	ACADEMY FORREST	MEL TOMEI	24.99	0	1261
330	7	ACADEMY FORRESTER	NICOLE STALLONE	13.99	0	5288
331	12	ACADEMY FORWARD	DEBBIE CROWE	29.99	0	4502
332	14	ACADEMY FRANKENSTEIN	MARISA TORN	11.99	0	2410
333	3	ACADEMY FREAKY	DREW HARRIS	14.99	0	1928
334	9	ACADEMY FREDDY	BETTE NICHOLSON	12.99	0	471
335	5	ACADEMY FREEDOM	SIDNEY SOBIESKI	10.99	0	8771
336	10	ACADEMY FRENCH	ANTHONY RUSH	25.99	0	3041
337	4	ACADEMY FRIDA	DANIEL LAW	27.99	0	1197
338	2	ACADEMY FRISCO	JULIETTE STREEP	16.99	0	486
339	9	ACADEMY FROGMEN	NATALIE MALDEN	22.99	0	1527
340	11	ACADEMY FRONTIER	WILLIAM BIRCH	21.99	0	322
341	8	ACADEMY FROST	RITA PENN	19.99	0	5657
342	14	ACADEMY FUGITIVE	CARY PITT	9.99	0	8035
343	3	ACADEMY FULL	MARLENE POSEY	23.99	0	7442
344	12	ACADEMY FURY	GRACE MOSTEL	18.99	0	1146
345	10	ACADEMY GABLES	DANIEL WITHERSPOON	21.99	0	3328
346	10	ACADEMY GALAXY	ANGELINA AKROYD	17.99	0	5549
347	16	ACADEMY GAMES	FRANK FOSTER	11.99	0	9238
348	15	ACADEMY GANDHI	MATTHEW JOHANSSON	21.99	0	7835
349	6	ACADEMY GANGS	JAYNE THERON	22.99	0	7431
350	13	ACADEMY GARDEN	NATALIE WAHLBERG	29.99	0	2829
351	5	ACADEMY GASLIGHT	FAY BOLGER	16.99	0	8108
352	15	ACADEMY GATHERING	CHARLTON KEATON	13.99	0	5131
353	3	ACADEMY GENTLEMEN	AL LANSBURY	25.99	0	1792
354	10	ACADEMY GHOST	ANNETTE HOPE	9.99	0	3873
355	13	ACADEMY GHOSTBUSTERS	GARY TAYLOR	19.99	0	8027
356	13	ACADEMY GIANT	SPENCER CAMPBELL	10.99	0	4315
357	15	ACADEMY GILBERT	VAL HACKMAN	9.99	0	5809
358	9	ACADEMY GILMORE	CATE PFEIFFER	20.99	0	2677
359	12	ACADEMY GLADIATOR	MINNIE BRANDO	25.99	0	8167
360	3	ACADEMY GLASS	MENA TYLER	19.99	0	5300
361	5	ACADEMY GLEAMING	MATTHEW CROWE	13.99	0	1615
362	11	ACADEMY GLORY	KIM CAMPBELL	21.99	0	1563
363	3	ACADEMY GO	SHIRLEY PENN	15.99	0	4077
364	10	ACADEMY GODFATHER	JULIA ANISTON	14.99	0	6566
365	2	ACADEMY GOLD	KIRSTEN AFFLECK	25.99	0	9753
366	6	ACADEMY GOLDFINGER	CHRIS RYAN	29.99	1	4240
367	3	ACADEMY GOLDMINE	KIRK MCGREGOR	23.99	0	7373
368	14	ACADEMY GONE	JEREMY GIBSON	24.99	0	7346
369	3	ACADEMY GOODFELLAS	OLYMPIA DEGENERES	23.99	0	5652
370	6	ACADEMY GORGEOUS	KIRSTEN MATTHAU	27.99	0	638
371	14	ACADEMY GOSFORD	SALLY PENN	9.99	0	8529
372	8	ACADEMY GRACELAND	JOE SWANK	9.99	0	6921
373	13	ACADEMY GRADUATE	ANNETTE HAYEK	13.99	0	7329
374	16	ACADEMY GRAFFITI	WHOOPI FINNEY	23.99	1	4867
375	5	ACADEMY GRAIL	BRUCE FIENNES	26.99	0	5034
376	15	ACADEMY GRAPES	DIANE BERRY	24.99	0	9287
377	10	ACADEMY GREASE	PENELOPE LEIGH	10.99	0	3460
378	13	ACADEMY GREATEST	PAUL FREEMAN	26.99	0	9398
379	10	ACADEMY GREEDY	ELVIS KAHN	20.99	0	2521
380	1	ACADEMY GREEK	KIRSTEN HURT	11.99	0	7805
381	11	ACADEMY GRINCH	SALLY DAMON	27.99	0	9721
382	13	ACADEMY GRIT	KATHARINE LAW	21.99	0	1320
383	15	ACADEMY GROOVE	JOE HEPBURN	23.99	0	448
384	11	ACADEMY GROSSE	KIM SUVARI	27.99	0	7714
385	3	ACADEMY GROUNDHOG	EDWARD HECHE	23.99	0	5593
386	8	ACADEMY GUMP	PARKER DAFOE	16.99	0	7239
387	6	ACADEMY GUN	FAY STREEP	27.99	0	9413
388	16	ACADEMY GUNFIGHT	HARRISON FORD	19.99	0	6508
389	9	ACADEMY GUNFIGHTER	JUDE MONROE	10.99	0	9009
390	14	ACADEMY GUYS	GOLDIE NOLTE	11.99	0	8940
391	11	ACADEMY HALF	BOB THURMAN	17.99	0	1534
392	3	ACADEMY HALL	ADAM LANSBURY	18.99	0	4192
393	7	ACADEMY HALLOWEEN	OPRAH HAYEK	24.99	0	7806
394	7	ACADEMY HAMLET	JAMES HAWN	28.99	0	9760
395	13	ACADEMY HANDICAP	MARLON GABLE	11.99	0	537
396	1	ACADEMY HANGING	TOM BRANDO	11.99	0	1755
397	5	ACADEMY HANKY	NEVE NORTON	14.99	0	1587
398	12	ACADEMY HANOVER	LAURA JOLIE	18.99	0	4764
399	4	ACADEMY HAPPINESS	SISSY MOSTEL	23.99	0	3961
400	11	ACADEMY HARDLY	NICOLE GOLDBERG	15.99	0	2009
401	6	ACADEMY HAROLD	GENE KUDROW	15.99	0	8527
402	8	ACADEMY HARPER	KATHARINE WILLIAMS	13.99	0	6659
403	6	ACADEMY HARRY	CHRISTOPHER WATSON	28.99	0	4280
404	7	ACADEMY HATE	BETTE MCGREGOR	15.99	0	6592
405	12	ACADEMY HAUNTED	ANDY WAYNE	18.99	0	5527
406	11	ACADEMY HAUNTING	BRUCE MARX	29.99	0	7774
407	14	ACADEMY HAWK	NEVE GOLDBERG	16.99	0	9699
408	1	ACADEMY HEAD	SPENCER WEST	13.99	0	2980
409	11	ACADEMY HEARTBREAKERS	THORA FINNEY	24.99	0	2235
410	7	ACADEMY HEAVEN	CHRISTIAN GABLE	17.99	0	4152
411	16	ACADEMY HEAVENLY	ALBERT HURT	10.99	0	9273
412	14	ACADEMY HEAVYWEIGHTS	GARY DREYFUSS	21.99	0	8921
413	9	ACADEMY HEDWIG	RUBY ODONNELL	18.99	0	7443
414	13	ACADEMY HELLFIGHTERS	ANTHONY KIDMAN	23.99	0	7040
415	15	ACADEMY HIGH	ANNE MCQUEEN	10.99	0	8719
416	8	ACADEMY HIGHBALL	GREGORY BACALL	19.99	0	8046
417	8	ACADEMY HILLS	BETTE WEST	24.99	0	7432
418	11	ACADEMY HOBBIT	JAMES BLOOM	19.99	0	3293
419	4	ACADEMY HOCUS	SALLY FIELD	15.99	1	1133
420	16	ACADEMY HOLES	OLYMPIA TRACY	10.99	0	8067
421	15	ACADEMY HOLIDAY	ROCK HUDSON	14.99	0	9379
422	2	ACADEMY HOLLOW	SIGOURNEY HAWN	12.99	0	4298
423	15	ACADEMY HOLLYWOOD	JULIANNE SANDLER	16.99	0	755
424	11	ACADEMY HOLOCAUST	HENRY JOVOVICH	20.99	0	3830
425	11	ACADEMY HOLY	FAY RYDER	17.99	0	2648
426	4	ACADEMY HOME	NEVE ROBBINS	9.99	0	7124
427	16	ACADEMY HOMEWARD	CARY BRODY	27.99	0	2950
428	5	ACADEMY HOMICIDE	BRAD DAFOE	26.99	0	3779
429	15	ACADEMY HONEY	SIDNEY DAY	14.99	0	6870
430	11	ACADEMY HOOK	JOE GUINESS	28.99	0	3303
431	4	ACADEMY HOOSIERS	BRUCE WRAY	28.99	0	1475
432	11	ACADEMY HOPE	ETHAN AKROYD	25.99	0	5620
433	2	ACADEMY HORN	ORLANDO COOPER	12.99	0	3076
434	9	ACADEMY HORROR	JULIANNE THERON	18.99	0	2744
435	3	ACADEMY HOTEL	MATT SOBIESKI	21.99	0	4597
436	16	ACADEMY HOURS	JENNIFER ZELLWEGER	10.99	0	4829
437	4	ACADEMY HOUSE	JOHN MARTIN	18.99	0	3617
438	1	ACADEMY HUMAN	KARL HUSTON	25.99	0	5199
439	2	ACADEMY HUNCHBACK	HUME DAY-LEWIS	22.99	0	5673
440	15	ACADEMY HUNGER	HUGH SANDLER	20.99	0	1757
441	1	ACADEMY HUNTER	CHRISTOPHER GARLAND	19.99	0	1144
442	16	ACADEMY HUNTING	MIRA MATTHAU	18.99	0	1141
443	14	ACADEMY HURRICANE	LENA BRANAGH	16.99	0	2610
444	14	ACADEMY HUSTLER	JOHN ZELLWEGER	14.99	0	1563
445	14	ACADEMY HYDE	WARREN KEITEL	13.99	0	3817
446	7	ACADEMY HYSTERICAL	NICOLE BRIDGES	21.99	0	1644
447	12	ACADEMY ICE	PEARL LANSBURY	17.99	0	8538
448	9	ACADEMY IDAHO	WARREN SMITH	11.99	0	8593
449	7	ACADEMY IDENTITY	SALLY BACALL	27.99	0	4792
450	1	ACADEMY IDOLS	ZERO CAGE	29.99	0	878
451	6	ACADEMY IGBY	DARYL RICKMAN	11.99	0	7983
452	5	ACADEMY ILLUSION	GROUCHO BAILEY	10.99	0	3648
453	15	ACADEMY IMAGE	CUBA WILSON	27.99	0	3526
454	12	ACADEMY IMPACT	HELEN HUDSON	21.99	0	6793
455	2	ACADEMY IMPOSSIBLE	RIP GARBO	10.99	0	1714
456	3	ACADEMY INCH	TOM PACINO	16.99	0	2818
457	3	ACADEMY INDEPENDENCE	GEOFFREY BLOOM	19.99	0	7597
458	14	ACADEMY INDIAN	NATALIE BEATTY	10.99	0	8132
459	7	ACADEMY INFORMER	FARRAH MONROE	25.99	0	6137
460	8	ACADEMY INNOCENT	WHOOPI DUNST	14.99	0	3075
461	8	ACADEMY INSECTS	AL KAHN	17.99	0	8273
462	11	ACADEMY INSIDER	SYLVESTER ANISTON	29.99	0	699
463	13	ACADEMY INSTINCT	CARRIE HANNAH	19.99	0	487
464	5	ACADEMY INTENTIONS	MICHAEL TAYLOR	21.99	0	9344
465	3	ACADEMY INTERVIEW	DREW CAMPBELL	12.99	0	5949
466	8	ACADEMY INTOLERABLE	BURT THERON	18.99	0	9749
467	5	ACADEMY INTRIGUE	WOODY WEST	13.99	0	5226
468	5	ACADEMY INVASION	SYLVESTER OLIVIER	17.99	0	3851
469	8	ACADEMY IRON	ELLEN HORNE	12.99	0	9266
470	2	ACADEMY ISHTAR	ANTHONY DAY-LEWIS	15.99	0	4954
471	15	ACADEMY ISLAND	HARVEY SPACEK	9.99	0	6538
472	1	ACADEMY ITALIAN	LIAM MARX	9.99	0	5493
473	9	ACADEMY JACKET	ED BRODY	18.99	0	4174
474	14	ACADEMY JADE	SHIRLEY AFFLECK	10.99	0	9174
475	1	ACADEMY JAPANESE	CATE DICAPRIO	10.99	0	5142
476	10	ACADEMY JASON	GRETA KELLY	29.99	0	6616
477	10	ACADEMY JAWBREAKER	ETHAN LEWIS	13.99	0	1026
478	13	ACADEMY JAWS	DORIS BOLGER	9.99	0	7650
479	7	ACADEMY JEDI	PARKER GRANT	15.99	0	9395
480	4	ACADEMY JEEPERS	DEBBIE JOLIE	16.99	0	8085
481	15	ACADEMY JEKYLL	GRACE COSTNER	13.99	0	8975
482	15	ACADEMY JEOPARDY	JIM POSEY	12.99	0	435
483	5	ACADEMY JERICHO	CHARLES POITIER	19.99	0	6966
484	5	ACADEMY JERK	BEN CRUISE	9.99	0	5645
485	16	ACADEMY JERSEY	ANTHONY PINKETT	12.99	0	6560
486	16	ACADEMY JET	ROBIN WRAY	15.99	0	9678
487	4	ACADEMY JINGLE	MORGAN BRODY	23.99	0	6950
488	12	ACADEMY JOON	JAYNE LAW	27.99	0	2004
489	10	ACADEMY JUGGLER	HILARY FINNEY	22.99	0	8995
490	4	ACADEMY JUMANJI	MAE FINNEY	15.99	0	7447
491	16	ACADEMY JUMPING	NICK IRONS	25.99	0	9630
492	12	ACADEMY JUNGLE	BETTE BACALL	18.99	0	3789
493	3	ACADEMY KANE	UMA HOPKINS	21.99	0	8
494	13	ACADEMY KARATE	GINA TRACY	12.99	0	6721
495	2	ACADEMY KENTUCKIAN	WOODY ROBERTS	24.99	0	4936
496	8	ACADEMY KICK	WILLIAM AKROYD	13.99	0	7899
497	3	ACADEMY KILL	RITA KEITEL	14.99	0	5376
498	11	ACADEMY KILLER	WINONA CAMPBELL	21.99	0	3144
499	10	ACADEMY KING	DENNIS KILMER	27.99	0	7714
500	10	ACADEMY KISS	KENNETH SINATRA	20.99	0	6145
501	1	ACADEMY KISSING	LIZA ALLEN	9.99	0	4035
502	14	ACADEMY KNOCK	THORA GUINESS	22.99	0	9102
503	3	ACADEMY KRAMER	ANJELICA DRIVER	12.99	0	7893
504	8	ACADEMY KWAI	GINA HOFFMAN	23.99	0	503
505	8	ACADEMY LABYRINTH	SANDRA TYLER	9.99	0	4080
506	11	ACADEMY LADY	JACK KILMER	14.99	0	6434
507	11	ACADEMY LADYBUGS	ANDY HARRIS	21.99	0	6852
508	8	ACADEMY LAMBS	WILL DENCH	20.99	0	8350
509	6	ACADEMY LANGUAGE	EWAN TRACY	22.99	0	6200
510	12	ACADEMY LAWLESS	KARL BERRY	21.99	0	134
511	16	ACADEMY LAWRENCE	KEVIN PINKETT	17.99	1	1287
512	1	ACADEMY LEAGUE	KARL MOSTEL	10.99	0	5896
513	13	ACADEMY LEATHERNECKS	ROBIN POSEY	24.99	0	2445
514	10	ACADEMY LEBOWSKI	CHARLIZE MINELLI	27.99	0	7513
515	8	ACADEMY LEGALLY	ROBERT ASTAIRE	9.99	0	9316
516	1	ACADEMY LEGEND	MATTHEW MALDEN	21.99	0	6708
517	12	ACADEMY LESSON	GOLDIE BASINGER	14.99	0	5863
518	14	ACADEMY LIAISONS	GRACE VOIGHT	22.99	0	6409
519	15	ACADEMY LIBERTY	FARRAH DENCH	10.99	0	5904
520	13	ACADEMY LICENSE	LISA LOLLOBRIGIDA	22.99	0	2144
521	10	ACADEMY LIES	RENEE MCCONAUGHEY	13.99	0	8058
522	15	ACADEMY LIFE	SALMA TORN	14.99	0	39
523	14	ACADEMY LIGHTS	SYLVESTER WILSON	12.99	0	5853
524	13	ACADEMY LION	ROBERT KIDMAN	10.99	0	9308
525	11	ACADEMY LOATHING	JUDY GRANT	15.99	0	1021
526	9	ACADEMY LOCK	MIRA LOREN	15.99	0	9127
527	2	ACADEMY LOLA	RIP PESCI	29.99	0	9510
528	16	ACADEMY LOLITA	SUSAN RUSSELL	27.99	0	5488
529	8	ACADEMY LONELY	BEN PRESLEY	15.99	0	6661
530	4	ACADEMY LORD	ANJELICA KEITEL	24.99	0	709
531	14	ACADEMY LOSE	MARLENE FIENNES	21.99	0	4695
532	8	ACADEMY LOSER	DAN PITT	15.99	0	1530
533	5	ACADEMY LOST	TOM OLIVIER	12.99	0	8908
534	12	ACADEMY LOUISIANA	MARISA BLANCHETT	25.99	0	4895
535	8	ACADEMY LOVE	AL MIRANDA	19.99	0	8231
536	10	ACADEMY LOVELY	CATE DIAZ	14.99	0	7664
537	12	ACADEMY LOVER	JUDI FONDA	28.99	0	2265
538	1	ACADEMY LOVERBOY	SYLVESTER THURMAN	29.99	0	5233
539	15	ACADEMY LUCK	LIAM RUSH	20.99	0	107
540	1	ACADEMY LUCKY	MARLON BEATTY	9.99	0	636
541	14	ACADEMY LUKE	GLENN COSTNER	29.99	0	1690
542	13	ACADEMY LUST	JUDE CAGE	14.99	0	1358
543	9	ACADEMY MADIGAN	ALBERT BOGART	17.99	0	843
544	16	ACADEMY MADISON	SANDRA WOOD	20.99	0	4533
545	10	ACADEMY MADNESS	JUDI KUDROW	13.99	0	873
546	5	ACADEMY MADRE	ELLEN HOPE	21.99	0	6748
547	13	ACADEMY MAGIC	RICHARD DAVIS	15.99	0	8447
548	7	ACADEMY MAGNIFICENT	UMA WOOD	18.99	0	396
549	9	ACADEMY MAGNOLIA	ALEC GARBO	17.99	0	5503
550	14	ACADEMY MAGUIRE	BRAD HUSTON	16.99	0	6854
551	8	ACADEMY MAIDEN	CARY AFFLECK	23.99	0	5759
552	7	ACADEMY MAJESTIC	RALPH HARRIS	12.99	0	2722
553	1	ACADEMY MAKER	ELLEN BRIDGES	29.99	0	6696
554	1	ACADEMY MALKOVICH	ALEC BLOOM	9.99	0	9458
555	10	ACADEMY MALLRATS	JAMES FOSTER	23.99	0	1417
556	7	ACADEMY MALTESE	CHARLES CHAPLIN	19.99	0	7617
557	2	ACADEMY MANCHURIAN	CHRISTIAN DEGENERES	27.99	0	8593
558	3	ACADEMY MANNEQUIN	WILL HOPPER	17.99	0	5375
559	2	ACADEMY MARRIED	MADELINE HOFFMAN	11.99	0	1221
560	1	ACADEMY MARS	JESSICA BERGMAN	18.99	0	1670
561	10	ACADEMY MASK	GEOFFREY CAINE	24.99	0	1732
562	9	ACADEMY MASKED	HUMPHREY PFEIFFER	23.99	0	8332
563	9	ACADEMY MASSACRE	FAY PINKETT	19.99	0	7176
564	1	ACADEMY MASSAGE	CHRIS DAMON	23.99	0	6434
565	13	ACADEMY MATRIX	MIRA FREEMAN	14.99	0	4809
566	8	ACADEMY MAUDE	LIZA HESTON	24.99	0	2656
567	15	ACADEMY MEET	WOODY PENN	16.99	0	5897
568	3	ACADEMY MEMENTO	GLENN WEST	18.99	0	4642
569	3	ACADEMY MENAGERIE	MATTHEW KIDMAN	16.99	0	9743
570	16	ACADEMY MERMAID	GINA BAILEY	23.99	0	1442
571	3	ACADEMY METAL	LAUREN POSEY	25.99	0	7789
572	2	ACADEMY METROPOLIS	JON HOFFMAN	10.99	0	9003
573	11	ACADEMY MICROCOSMOS	RUSSELL WILLIS	29.99	0	3232
574	8	ACADEMY MIDNIGHT	RUSSELL MATTHAU	11.99	0	745
575	2	ACADEMY MIDSUMMER	BURT WATSON	17.99	0	4145
576	9	ACADEMY MIGHTY	CHRISTIAN SMITH	11.99	0	6765
577	15	ACADEMY MILE	CARMEN OLIVIER	17.99	0	9082
578	5	ACADEMY MILLION	SCARLETT HAWKE	12.99	0	2997
579	8	ACADEMY MINDS	SPENCER SORVINO	16.99	0	8621
580	7	ACADEMY MINE	REESE BAILEY	19.99	0	4405
581	15	ACADEMY MINORITY	ELVIS ZELLWEGER	11.99	0	8922
582	13	ACADEMY MIRACLE	LAURENCE BARRYMORE	27.99	0	3479
583	13	ACADEMY MISSION	OPRAH RICKMAN	23.99	0	1486
584	16	ACADEMY MIXED	WILLIAM HAWN	27.99	0	9281
585	12	ACADEMY MOB	WARREN COOPER	20.99	0	4058
586	16	ACADEMY MOCKINGBIRD	HUME MCDORMAND	14.99	0	5366
587	3	ACADEMY MOD	LAUREN JOHANSSON	24.99	0	433
588	2	ACADEMY MODEL	RIP DAFOE	26.99	0	7444
589	16	ACADEMY MODERN	CHRIS SWANK	29.99	0	9167
590	15	ACADEMY MONEY	BETTE IRONS	27.99	0	7751
591	5	ACADEMY MONSOON	HUGH BACALL	23.99	0	1223
592	4	ACADEMY MONSTER	LIZA HAYEK	25.99	0	188
593	14	ACADEMY MONTEREY	DIANE DEGENERES	22.99	0	994
594	7	ACADEMY MONTEZUMA	VIVIEN BERGEN	20.99	0	6956
595	8	ACADEMY MOON	CLINT WATSON	20.99	0	2222
596	6	ACADEMY MOONSHINE	EDWARD BERGEN	24.99	0	5269
597	14	ACADEMY MOONWALKER	VIVIEN WAYNE	18.99	0	1089
598	8	ACADEMY MOSQUITO	GREGORY LEIGH	23.99	0	4288
599	13	ACADEMY MOTHER	JON MARX	25.99	0	5377
600	8	ACADEMY MOTIONS	JODIE MCGREGOR	22.99	0	2754
601	14	ACADEMY MOULIN	GREG KAHN	11.99	0	771
602	11	ACADEMY MOURNING	ALAN BLOOM	21.99	0	7524
603	12	ACADEMY MOVIE	GEOFFREY BEATTY	10.99	0	5343
604	8	ACADEMY MULAN	CHARLES LOLLOBRIGIDA	29.99	0	2983
605	9	ACADEMY MULHOLLAND	THORA SARANDON	29.99	0	1077
606	5	ACADEMY MUMMY	LIV FINNEY	21.99	0	8603
607	11	ACADEMY MUPPET	VIVIEN BIRCH	23.99	0	5159
608	8	ACADEMY MURDER	LANA GOLDBERG	25.99	0	3397
609	5	ACADEMY MUSCLE	SUSAN TYLER	18.99	0	2647
610	12	ACADEMY MUSIC	AUDREY HARRIS	23.99	0	5249
611	13	ACADEMY MUSKETEERS	RUBY MOSTEL	17.99	0	2849
612	5	ACADEMY MUSSOLINI	HALLE WILLIAMS	13.99	0	425
613	12	ACADEMY MYSTIC	JACK BRODY	15.99	0	8522
614	11	ACADEMY NAME	ORLANDO DAMON	20.99	0	6524
615	14	ACADEMY NASH	ANNE HARRIS	27.99	0	4545
616	7	ACADEMY NATIONAL	CANDICE TAUTOU	14.99	0	3915
617	9	ACADEMY NATURAL	GREGORY KIDMAN	28.99	0	129
618	16	ACADEMY NECKLACE	CARY HUNT	17.99	0	302
619	4	ACADEMY NEIGHBORS	DUSTIN HAWN	29.99	0	8979
620	11	ACADEMY NEMO	GARY SANDLER	23.99	0	3906
621	3	ACADEMY NETWORK	ELLEN BRIDGES	14.99	0	5254
622	11	ACADEMY NEWSIES	ANNE WAYNE	9.99	0	8011
623	1	ACADEMY NEWTON	EWAN SMITH	12.99	0	518
624	4	ACADEMY NIGHTMARE	JIM HOFFMAN	18.99	0	4461
625	6	ACADEMY NONE	EDWARD BLOOM	22.99	0	9467
626	1	ACADEMY NOON	ANTHONY WILLIS	15.99	0	4547
627	14	ACADEMY NORTH	HUGH VOIGHT	27.99	0	2559
628	11	ACADEMY NORTHWEST	BELA WINSLET	28.99	0	2834
629	16	ACADEMY NOTORIOUS	MORGAN FOSTER	18.99	0	1636
630	15	ACADEMY NOTTING	ELIZABETH BRIDGES	12.99	0	525
631	2	ACADEMY NOVOCAINE	AL RYAN	12.99	0	2574
632	11	ACADEMY NUTS	CHRISTOPHER TOMEI	9.99	0	1130
633	5	ACADEMY OCTOBER	BETTE HESTON	16.99	0	2319
634	11	ACADEMY ODDS	LANA GRANT	16.99	0	3548
635	9	ACADEMY OKLAHOMA	JOAN RICKMAN	25.99	0	2278
636	14	ACADEMY OLEANDER	ALAN BALL	26.99	0	975
637	2	ACADEMY OPEN	WOODY STREEP	14.99	0	7577
638	7	ACADEMY OPERATION	DANIEL CHASE	19.99	0	5812
639	12	ACADEMY OPPOSITE	WHOOPI CHASE	15.99	0	8205
640	11	ACADEMY OPUS	LAURENCE BEATTY	11.99	0	5199
641	6	ACADEMY ORANGE	KIRK NICHOLSON	16.99	0	7766
642	8	ACADEMY ORDER	LIZA MCQUEEN	18.99	0	4969
643	4	ACADEMY ORIENT	MARLENE FIENNES	17.99	0	1673
644	16	ACADEMY OSCAR	GLENN KEATON	28.99	0	8521
645	13	ACADEMY OTHERS	SPENCER HOPKINS	16.99	0	7516
646	15	ACADEMY OUTBREAK	JAMES TURNER	18.99	0	9624
647	4	ACADEMY OUTFIELD	LEONARDO PFEIFFER	26.99	0	5249
648	6	ACADEMY OUTLAW	ROSIE GRANT	29.99	0	6445
649	3	ACADEMY OZ	CHRIS ROBBINS	19.99	0	9686
650	6	ACADEMY PACIFIC	JACK JOHANSSON	14.99	0	9874
651	16	ACADEMY PACKER	SISSY PINKETT	17.99	0	1672
652	7	ACADEMY PAJAMA	SISSY GUINESS	29.99	0	738
653	9	ACADEMY PANIC	JEREMY LEWIS	16.99	0	2490
654	1	ACADEMY PANKY	ALBERT PENN	12.99	0	7472
655	3	ACADEMY PANTHER	ED KIDMAN	20.99	0	993
656	9	ACADEMY PAPI	ROCK ROBBINS	18.99	0	118
657	10	ACADEMY PARADISE	HUME LUGOSI	19.99	0	6386
658	10	ACADEMY PARIS	DEBBIE BLOOM	9.99	0	7694
659	5	ACADEMY PARK	JOHN HOPPER	15.99	0	6848
660	1	ACADEMY PARTY	DENZEL PRESLEY	15.99	0	9953
661	7	ACADEMY PAST	PARKER STREEP	13.99	0	9666
662	4	ACADEMY PATHS	KEVIN TOMEI	22.99	0	1332
663	5	ACADEMY PATIENT	DORIS WILSON	19.99	0	6817
664	5	ACADEMY PATRIOT	CATE DRIVER	24.99	0	7603
665	7	ACADEMY PATTON	JULIA MINELLI	22.99	0	8242
666	11	ACADEMY PAYCHECK	MATTHEW FORD	17.99	0	9619
667	7	ACADEMY PEACH	RUSSELL SARANDON	28.99	0	2488
668	2	ACADEMY PEAK	DENZEL PITT	15.99	0	2194
669	16	ACADEMY PEARL	JUDE JOLIE	11.99	0	962
670	15	ACADEMY PELICAN	NICOLAS NORTON	17.99	0	6807
671	4	ACADEMY PERDITION	ALAN WOOD	27.99	0	5825
672	14	ACADEMY PERFECT	HILARY RUSSELL	23.99	0	8474
673	16	ACADEMY PERSONAL	LAURENCE RYAN	12.99	0	8268
674	7	ACADEMY PET	GLENN BERGMAN	27.99	0	5809
675	16	ACADEMY PHANTOM	EMILY BERGEN	24.99	0	6089
676	7	ACADEMY PHILADELPHIA	LENA NOLTE	18.99	0	34
677	1	ACADEMY PIANIST	RAY HECHE	17.99	0	5161
678	5	ACADEMY PICKUP	GENE BLOOM	26.99	0	4035
679	11	ACADEMY PILOT	JODIE MOORE	29.99	0	6660
680	10	ACADEMY PINOCCHIO	NEVE LANCASTER	26.99	0	1972
681	8	ACADEMY PIRATES	SEAN PACINO	10.99	0	4497
682	1	ACADEMY PITTSBURGH	SEAN CARREY	26.99	0	100
683	6	ACADEMY PITY	BRUCE SARANDON	23.99	0	3681
684	2	ACADEMY PIZZA	ALEC FIENNES	20.99	0	5862
685	4	ACADEMY PLATOON	CATE TORN	29.99	0	4271
686	3	ACADEMY PLUTO	CARY CRUZ	9.99	0	2664
687	8	ACADEMY POCUS	INGRID FAWCETT	16.99	0	9718
688	6	ACADEMY POLISH	PENELOPE KEITEL	18.99	0	4310
689	14	ACADEMY POLLOCK	OLYMPIA DIETRICH	27.99	0	682
690	8	ACADEMY POND	WARREN BARRYMORE	21.99	0	7066
691	1	ACADEMY POSEIDON	SOPHIA CHAPLIN	12.99	0	1563
692	7	ACADEMY POTLUCK	JESSICA MOSTEL	26.99	0	6215
693	13	ACADEMY POTTER	CHARLES GOODING	21.99	0	3382
694	1	ACADEMY PREJUDICE	LISA NOLTE	24.99	0	4408
695	14	ACADEMY PRESIDENT	JOHN WRAY	25.99	0	4922
696	8	ACADEMY PRIDE	MARISA MALDEN	17.99	0	8314
697	9	ACADEMY PRIMARY	JOHNNY CHAPLIN	9.99	0	5125
698	11	ACADEMY PRINCESS	SIGOURNEY ROBERTS	25.99	0	7432
699	3	ACADEMY PRIVATE	JADA GARLAND	24.99	0	9708
700	3	ACADEMY PRIX	WARREN WILLIAMS	23.99	0	5442
701	3	ACADEMY PSYCHO	CATE DEPP	25.99	0	8787
702	11	ACADEMY PULP	ALEC DAY	11.99	0	86
703	11	ACADEMY PUNK	RALPH TOMEI	20.99	0	1446
704	5	ACADEMY PURE	JUDY SARANDON	23.99	0	6424
705	11	ACADEMY PURPLE	LEONARDO PFEIFFER	22.99	0	3532
706	4	ACADEMY QUEEN	LIAM LANSBURY	15.99	0	2617
707	4	ACADEMY QUEST	JODIE AKROYD	13.99	0	7220
708	4	ACADEMY QUILLS	LISA RYAN	9.99	0	2916
709	3	ACADEMY RACER	BRAD MCCONAUGHEY	23.99	0	6459
710	6	ACADEMY RAGE	HARRISON ALLEN	28.99	0	7714
711	5	ACADEMY RAGING	GOLDIE STREEP	27.99	0	6998
712	3	ACADEMY RAIDERS	MILLA GOODING	22.99	0	8529
713	6	ACADEMY RAINBOW	MARILYN TAUTOU	29.99	0	9781
714	5	ACADEMY RANDOM	LENA BERGMAN	16.99	0	9268
715	1	ACADEMY RANGE	TOM BOGART	16.99	0	5957
716	3	ACADEMY REAP	JAYNE FIENNES	19.99	0	6182
717	3	ACADEMY REAR	ADAM GARCIA	27.99	1	6208
718	12	ACADEMY REBEL	JOHN FREEMAN	17.99	0	3839
719	6	ACADEMY RECORDS	JEREMY LEWIS	29.99	0	2229
720	15	ACADEMY REDEMPTION	GEOFFREY WASHINGTON	26.99	0	3491
721	7	ACADEMY REDS	MATT HOPKINS	27.99	0	8729
722	8	ACADEMY REEF	DREW BRANAGH	19.99	1	2270
723	2	ACADEMY REIGN	LANA PINKETT	21.99	0	8879
724	16	ACADEMY REMEMBER	JEREMY HUSTON	18.99	0	3870
725	11	ACADEMY REQUIEM	GEOFFREY FISHER	29.99	0	6231
726	6	ACADEMY RESERVOIR	BELA LEWIS	29.99	0	80
727	14	ACADEMY RESURRECTION	CANDICE TYLER	10.99	0	1143
728	6	ACADEMY REUNION	RUSSELL JOHANSSON	27.99	0	9713
729	13	ACADEMY RIDER	JENNIFER BEATTY	14.99	0	8959
730	11	ACADEMY RIDGEMONT	DIANE CAMPBELL	28.99	0	3750
731	10	ACADEMY RIGHT	VAL HESTON	22.99	0	3803
732	11	ACADEMY RINGS	FRANCES DREYFUSS	25.99	0	6908
733	15	ACADEMY RIVER	CUBA OLIVIER	24.99	0	2759
734	12	ACADEMY ROAD	GOLDIE GOLDBERG	12.99	0	8245
735	1	ACADEMY ROBBERS	WHOOPI DENIRO	14.99	0	833
736	11	ACADEMY ROBBERY	JULIANNE REYNOLDS	21.99	0	9454
737	16	ACADEMY ROCK	DORIS BEATTY	14.99	0	6076
738	16	ACADEMY ROCKETEER	GARY PECK	12.99	0	8993
739	7	ACADEMY ROCKY	EWAN CHASE	25.99	0	8927
740	10	ACADEMY ROLLERCOASTER	CATE GIBSON	20.99	0	3308
741	11	ACADEMY ROMAN	BOB FAWCETT	12.99	0	4968
742	2	ACADEMY ROOF	KIM TOMEI	16.99	0	3844
743	16	ACADEMY ROOM	BRAD CAGE	14.99	0	5478
744	3	ACADEMY ROOTS	MICHELLE PESCI	17.99	0	210
745	6	ACADEMY ROSES	HILARY BIRCH	18.99	0	480
746	13	ACADEMY ROUGE	GROUCHO DREYFUSS	27.99	0	2661
747	7	ACADEMY ROXANNE	CHEVY LANCASTER	28.99	0	3250
748	6	ACADEMY RUGRATS	JEREMY SPACEK	17.99	0	7508
749	16	ACADEMY RULES	JOAN DENCH	22.99	0	9643
750	11	ACADEMY RUN	ANGELINA WITHERSPOON	10.99	0	6867
751	3	ACADEMY RUNAWAY	WHOOPI DEE	19.99	0	4156
752	13	ACADEMY RUNNER	WHOOPI IRONS	28.99	0	8624
753	4	ACADEMY RUSH	MICHELLE PHOENIX	23.99	0	7901
754	8	ACADEMY RUSHMORE	ALICIA BRANAGH	28.99	0	6970
755	15	ACADEMY SABRINA	MEL HORNE	28.99	0	1243
756	10	ACADEMY SADDLE	GRETA NEWMAN	21.99	0	4648
757	1	ACADEMY SAGEBRUSH	VIVIEN TURNER	29.99	0	3686
758	14	ACADEMY SAINTS	BRUCE BASINGER	20.99	0	2493
759	6	ACADEMY SALUTE	GROUCHO CROWE	16.99	0	1332
760	1	ACADEMY SAMURAI	LEELEE WRAY	24.99	0	1373
761	14	ACADEMY SANTA	RICHARD KIDMAN	13.99	0	9665
762	11	ACADEMY SASSY	SEAN BRIDGES	22.99	0	6931
763	16	ACADEMY SATISFACTION	NICOLAS WAHLBERG	11.99	0	4898
764	6	ACADEMY SATURDAY	MEG ROBERTS	23.99	0	7872
765	14	ACADEMY SATURN	PEARL CRONYN	18.99	0	6967
766	10	ACADEMY SAVANNAH	DREW ROBBINS	16.99	0	3501
767	6	ACADEMY SCALAWAG	JIM MOORE	13.99	0	5595
768	15	ACADEMY SCARFACE	JOE DREYFUSS	22.99	0	9378
769	3	ACADEMY SCHOOL	MIRA PFEIFFER	26.99	0	8488
770	10	ACADEMY SCISSORHANDS	ALICIA DIETRICH	17.99	0	9468
771	2	ACADEMY SCORPION	MIRA DIETRICH	15.99	0	7021
772	11	ACADEMY SEA	GWYNETH ZELLWEGER	11.99	0	6488
773	12	ACADEMY SEABISCUIT	TIM CAGE	12.99	0	3119
774	2	ACADEMY SEARCHERS	ANDY WAYNE	26.99	0	4715
775	11	ACADEMY SEATTLE	NICOLAS GOODING	24.99	0	4458
776	11	ACADEMY SECRET	MIRA TANDY	16.99	0	3731
777	2	ACADEMY SECRETARY	HARRISON SUVARI	18.99	1	5921
778	2	ACADEMY SECRETS	NATALIE ODONNELL	9.99	0	5189
779	6	ACADEMY SENSE	JEREMY WRAY	16.99	0	2287
780	14	ACADEMY SENSIBILITY	LISA KAHN	21.99	0	3881
781	1	ACADEMY SEVEN	ELIZABETH THURMAN	24.99	0	4375
782	3	ACADEMY SHAKESPEARE	FRANCES GABLE	19.99	0	2861
783	2	ACADEMY SHANE	WILLEM TOMEI	26.99	0	8532
784	6	ACADEMY SHANGHAI	RUBY DEPP	25.99	0	6741
785	1	ACADEMY SHAWSHANK	CUBA HURT	22.99	0	4136
786	1	ACADEMY SHEPHERD	FRED BOLGER	14.99	0	5739
787	12	ACADEMY SHINING	THORA WITHERSPOON	9.99	0	7256
788	5	ACADEMY SHIP	LIV LEWIS	14.99	0	5337
789	3	ACADEMY SHOCK	RALPH PFEIFFER	29.99	0	4158
790	11	ACADEMY SHOOTIST	SIGOURNEY LANCASTER	26.99	0	9571
791	4	ACADEMY SHOW	ANNE DAVIS	20.99	0	9125
792	2	ACADEMY SHREK	SISSY DAMON	10.99	0	3781
793	13	ACADEMY SHRUNK	VIVIEN KAHN	17.99	0	3454
794	15	ACADEMY SIDE	AUDREY TYLER	23.99	0	6012
795	3	ACADEMY SIEGE	CHARLTON KELLY	9.99	0	3423
796	16	ACADEMY SIERRA	KIM MARX	9.99	0	506
797	16	ACADEMY SILENCE	ELLEN DREYFUSS	26.99	0	4773
798	4	ACADEMY SILVERADO	WINONA BRANAGH	12.99	0	7732
799	9	ACADEMY SIMON	MEL HECHE	21.99	0	5672
800	4	ACADEMY SINNERS	BRAD DICAPRIO	16.99	0	4588
801	12	ACADEMY SISTER	ANTHONY DICAPRIO	14.99	0	2239
802	5	ACADEMY SKY	JUDE DEPP	20.99	0	8349
803	1	ACADEMY SLACKER	UMA FIENNES	9.99	0	4415
804	13	ACADEMY SLEEPING	SANDRA ALLEN	19.99	0	85
805	1	ACADEMY SLEEPLESS	EWAN SANDLER	12.99	0	5690
806	10	ACADEMY SLEEPY	ROCK SPACEK	23.99	0	1423
807	15	ACADEMY SLEUTH	HILARY GRANT	17.99	0	4903
808	4	ACADEMY SLING	RICHARD WINSLET	12.99	0	2987
809	10	ACADEMY SLIPPER	GARY SANDLER	19.99	0	9145
810	8	ACADEMY SLUMS	MINNIE FONDA	25.99	0	8638
811	6	ACADEMY SMILE	MICHELLE BERRY	12.99	0	7903
812	6	ACADEMY SMOKING	CLARK MINELLI	24.99	0	1196
813	4	ACADEMY SMOOCHY	BRAD DOUGLAS	9.99	0	1024
814	5	ACADEMY SNATCH	SOPHIA BERGEN	22.99	0	1852
815	9	ACADEMY SNATCHERS	JULIA BALL	14.99	0	9913
816	2	ACADEMY SNOWMAN	AUDREY CHASE	26.99	0	8209
817	10	ACADEMY SOLDIERS	JIM MONROE	25.99	0	5083
818	15	ACADEMY SOMETHING	PENELOPE LEWIS	9.99	0	2357
819	2	ACADEMY SONG	FRED TORN	9.99	0	8550
820	4	ACADEMY SONS	SISSY BASINGER	23.99	0	7154
821	12	ACADEMY SORORITY	SCARLETT HAWKE	25.99	0	2045
822	10	ACADEMY SOUP	SALLY SPACEK	10.99	0	2261
823	10	ACADEMY SOUTH	REESE KEITEL	16.99	0	3841
824	10	ACADEMY SPARTACUS	FARRAH MCGREGOR	27.99	0	7965
825	12	ACADEMY SPEAKEASY	RUBY SOBIESKI	22.99	0	1487
826	6	ACADEMY SPEED	KIRK DEE	13.99	0	7944
827	7	ACADEMY SPICE	MADELINE MALDEN	15.99	0	2533
828	9	ACADEMY SPIKING	PEARL DAVIS	15.99	0	3010
829	12	ACADEMY SPINAL	THORA CARREY	29.99	0	5639
830	13	ACADEMY SPIRIT	HILARY ROBBINS	22.99	0	9251
831	13	ACADEMY SPIRITED	CHEVY ROBBINS	16.99	0	1611
832	3	ACADEMY SPLASH	OLYMPIA HEPBURN	25.99	0	4032
833	1	ACADEMY SPLENDOR	LIV DENCH	25.99	0	1772
834	2	ACADEMY SPOILERS	GINA DERN	9.99	0	3548
835	10	ACADEMY SPY	CARRIE ALLEN	29.99	0	5452
836	15	ACADEMY SQUAD	GEOFFREY HARRIS	10.99	0	3190
837	4	ACADEMY STAGE	OLYMPIA TAYLOR	29.99	0	4760
838	7	ACADEMY STAGECOACH	MIRA MONROE	29.99	0	2720
839	3	ACADEMY STALLION	JULIETTE KILMER	19.99	0	7620
840	14	ACADEMY STAMPEDE	PAUL CAMPBELL	29.99	0	4076
841	9	ACADEMY STAR	RIP ASTAIRE	26.99	0	5578
842	3	ACADEMY STATE	JAMES EASTWOOD	28.99	0	661
843	7	ACADEMY STEEL	MIRA MOORE	11.99	0	1604
844	7	ACADEMY STEERS	MICHAEL SMITH	27.99	0	2555
845	11	ACADEMY STEPMOM	HUME COOPER	18.99	0	5214
846	14	ACADEMY STING	KATHARINE NEESON	22.99	0	6274
847	4	ACADEMY STOCK	TIM NEESON	22.99	0	2102
848	12	ACADEMY STONE	SANDRA WILSON	18.99	0	5194
849	10	ACADEMY STORM	GREG HOPE	15.99	0	6601
850	9	ACADEMY STORY	ROBERT ANISTON	28.99	0	9700
851	8	ACADEMY STRAIGHT	MAE EASTWOOD	9.99	0	1446
852	11	ACADEMY STRANGELOVE	RIP CRONYN	20.99	0	3921
853	13	ACADEMY STRANGER	GROUCHO KINNEAR	22.99	0	4322
854	3	ACADEMY STRANGERS	SHIRLEY LEIGH	19.99	0	2327
855	3	ACADEMY STREAK	ELIZABETH HANNAH	29.99	0	7057
856	16	ACADEMY STREETCAR	ADRIEN SILVERSTONE	21.99	0	9694
857	12	ACADEMY STRICTLY	CHARLIZE HORNE	20.99	0	9795
858	16	ACADEMY SUBMARINE	JULIANNE SILVERSTONE	15.99	0	5009
859	12	ACADEMY SUGAR	AUDREY MCDORMAND	22.99	0	9289
860	14	ACADEMY SUICIDES	GOLDIE EASTWOOD	11.99	0	6807
861	13	ACADEMY SUIT	JON DIAZ	26.99	0	3203
862	13	ACADEMY SUMMER	PENELOPE MARX	28.99	0	8153
863	15	ACADEMY SUN	LUCILLE BRIDGES	18.99	0	844
864	16	ACADEMY SUNDANCE	MILLA COSTNER	9.99	0	8414
865	16	ACADEMY SUNRISE	CHARLES MIRANDA	14.99	0	4397
866	16	ACADEMY SUNSET	MICHELLE LEIGH	18.99	0	5642
867	13	ACADEMY SUPER	CHRISTOPHER COSTNER	20.99	0	3409
868	6	ACADEMY SUPERFLY	JEREMY BACALL	29.99	0	8870
869	2	ACADEMY SUSPECTS	ANNE HAWKE	25.99	0	8515
870	11	ACADEMY SWARM	JUDE GARLAND	25.99	0	2566
871	4	ACADEMY SWEDEN	RIVER MALDEN	28.99	0	2094
872	8	ACADEMY SWEET	HELEN SILVERSTONE	22.99	0	4951
873	16	ACADEMY SWEETHEARTS	JULIANNE PHOENIX	18.99	0	9950
874	6	ACADEMY TADPOLE	HUMPHREY SARANDON	17.99	0	8334
875	4	ACADEMY TALENTED	DARYL DAY-LEWIS	24.99	1	8406
876	1	ACADEMY TARZAN	JANE DAMON	26.99	0	4794
877	1	ACADEMY TAXI	FRANCES MANSFIELD	17.99	0	6596
878	15	ACADEMY TEEN	HILARY DEGENERES	18.99	0	1231
879	7	ACADEMY TELEGRAPH	TIM ASTAIRE	26.99	0	5260
880	11	ACADEMY TELEMARK	NICOLE MOSTEL	27.99	0	7450
881	12	ACADEMY TEMPLE	VIVIEN HARRIS	12.99	0	703
882	11	ACADEMY TENENBAUMS	MATT DIETRICH	28.99	0	9105
883	10	ACADEMY TEQUILA	CHARLIZE MARX	29.99	0	8309
884	2	ACADEMY TERMINATOR	RUSSELL HURT	9.99	0	2672
885	9	ACADEMY TEXAS	THORA WRAY	15.99	0	3346
886	1	ACADEMY THEORY	NICOLAS LOREN	9.99	0	9808
887	2	ACADEMY THIEF	ELIZABETH GARCIA	24.99	0	9444
888	11	ACADEMY THIN	KENNETH TAUTOU	25.99	0	5939
889	11	ACADEMY TIES	AUDREY WAYNE	19.99	0	3898
890	12	ACADEMY TIGHTS	HELEN KIDMAN	23.99	0	2507
891	1	ACADEMY TIMBERLAND	ROBIN THURMAN	24.99	0	5674
892	12	ACADEMY TITANIC	TIM WILLIS	29.99	0	2173
893	15	ACADEMY TITANS	BETTE GABLE	19.99	0	9313
894	2	ACADEMY TOMATOES	SEAN ROBBINS	12.99	0	8514
895	9	ACADEMY TOMORROW	HELEN WRAY	28.99	0	2208
896	3	ACADEMY TOOTSIE	BURT NEWMAN	9.99	0	7
897	10	ACADEMY TORQUE	WARREN CHASE	19.99	0	6664
898	12	ACADEMY TOURIST	ALAN BERGMAN	25.99	0	1622
899	12	ACADEMY TOWERS	TIM MCDORMAND	21.99	0	1810
900	8	ACADEMY TOWN	CHRISTOPHER EASTWOOD	26.99	0	8392
901	2	ACADEMY TRACY	JUDY GRANT	12.99	0	9354
902	3	ACADEMY TRADING	BOB WILLIAMS	11.99	0	2324
903	13	ACADEMY TRAFFIC	FRED COSTNER	26.99	0	8528
904	16	ACADEMY TRAIN	JODIE PALTROW	28.99	0	2434
905	2	ACADEMY TRAINSPOTTING	KENNETH RUSH	14.99	0	7636
906	2	ACADEMY TRAMP	CHARLIZE NORTON	22.99	0	5370
907	9	ACADEMY TRANSLATION	JOHNNY BALE	22.99	0	9483
908	15	ACADEMY TRAP	CARMEN WOOD	12.99	0	952
909	1	ACADEMY TREASURE	RENEE RYAN	19.99	0	1229
910	13	ACADEMY TREATMENT	SOPHIA SARANDON	15.99	0	5277
911	2	ACADEMY TRIP	DENZEL CRUISE	13.99	0	818
912	13	ACADEMY TROJAN	CARMEN GOLDBERG	14.99	0	3005
913	4	ACADEMY TROOPERS	FAY TURNER	15.99	0	938
914	7	ACADEMY TROUBLE	SIDNEY CAGE	13.99	0	5981
915	6	ACADEMY TRUMAN	HUMPHREY HANNAH	14.99	0	4902
916	13	ACADEMY TURN	MEL RICKMAN	29.99	0	5020
917	2	ACADEMY TUXEDO	SEAN PINKETT	12.99	0	9042
918	8	ACADEMY TWISTED	RIP CRAWFORD	25.99	0	9060
919	14	ACADEMY TYCOON	ANDY TORN	24.99	0	6822
920	6	ACADEMY UNBREAKABLE	BEN HOPE	24.99	0	7883
921	4	ACADEMY UNCUT	KIM HOPKINS	28.99	0	5430
922	7	ACADEMY UNDEFEATED	FARRAH JOLIE	15.99	0	2621
923	4	ACADEMY UNFAITHFUL	JANE COSTNER	9.99	0	9262
924	15	ACADEMY UNFORGIVEN	RIVER SILVERSTONE	29.99	0	9343
925	11	ACADEMY UNITED	HELEN VOIGHT	24.99	0	651
926	9	ACADEMY UNTOUCHABLES	JULIA WALKEN	10.99	0	9510
927	11	ACADEMY UPRISING	JENNIFER DUNST	28.99	0	1382
928	3	ACADEMY UPTOWN	GENE SOBIESKI	21.99	0	2591
929	9	ACADEMY USUAL	AUDREY RYDER	16.99	0	6394
930	5	ACADEMY VACATION	KIM HECHE	23.99	0	2357
931	12	ACADEMY VALENTINE	CHRIS ODONNELL	14.99	0	243
932	4	ACADEMY VALLEY	GINA HARRIS	22.99	0	9324
933	13	ACADEMY VAMPIRE	ORLANDO JACKMAN	11.99	0	6211
934	6	ACADEMY VANILLA	INGRID MCKELLEN	18.99	1	1874
935	2	ACADEMY VANISHED	LISA DRIVER	22.99	0	7792
936	14	ACADEMY VANISHING	JOAN OLIVIER	9.99	0	2540
937	1	ACADEMY VARSITY	MARY CHASE	16.99	0	9831
938	5	ACADEMY VELVET	JOAN MARX	10.99	0	5732
939	12	ACADEMY VERTIGO	DEBBIE BIRCH	11.99	0	2008
940	5	ACADEMY VICTORY	JOHN MANSFIELD	28.99	0	4466
941	12	ACADEMY VIDEOTAPE	CHARLES BOLGER	12.99	0	968
942	7	ACADEMY VIETNAM	ELIZABETH CRUZ	10.99	0	691
943	2	ACADEMY VILLAIN	MEG THURMAN	20.99	0	3945
944	2	ACADEMY VIRGIN	JODIE MOORE	15.99	0	9972
945	9	ACADEMY VIRGINIAN	LENA BERGEN	9.99	0	8291
946	8	ACADEMY VIRTUAL	TIM NEWMAN	21.99	0	728
947	12	ACADEMY VISION	ETHAN DERN	28.99	0	8474
948	1	ACADEMY VOICE	NICK HANNAH	23.99	0	6995
949	2	ACADEMY VOLCANO	GROUCHO BEATTY	20.99	0	1261
950	10	ACADEMY VOLUME	DAN TORN	12.99	0	1754
951	16	ACADEMY VOYAGE	RUBY GARCIA	28.99	0	6850
952	16	ACADEMY WAGON	UMA MONROE	14.99	0	2798
953	2	ACADEMY WAIT	MEL MCDORMAND	26.99	0	6280
954	9	ACADEMY WAKE	MEL HAWKE	28.99	0	610
955	1	ACADEMY WALLS	WALTER KUDROW	13.99	0	8641
956	7	ACADEMY WANDA	DIANE OLIVIER	14.99	0	1832
957	15	ACADEMY WAR	ROCK MCDORMAND	27.99	0	4430
958	3	ACADEMY WARDROBE	ANTHONY AFFLECK	26.99	0	3892
959	8	ACADEMY WARLOCK	RENEE HANNAH	12.99	0	7858
960	4	ACADEMY WARS	GOLDIE FOSTER	12.99	0	439
961	1	ACADEMY WASH	NICOLAS WINFREY	14.99	0	3678
962	8	ACADEMY WASTELAND	WINONA CLOSE	14.99	0	8766
963	12	ACADEMY WATCH	SEAN CRUZ	25.99	0	7320
964	3	ACADEMY WATERFRONT	CATE JOLIE	29.99	0	4464
965	13	ACADEMY WATERSHIP	RAY TAYLOR	11.99	0	3624
966	3	ACADEMY WEDDING	GRACE BIRCH	27.99	0	5630
967	5	ACADEMY WEEKEND	MORGAN RUSSELL	14.99	0	7630
968	2	ACADEMY WEREWOLF	WALTER RYAN	9.99	0	9938
969	12	ACADEMY WEST	JON RICKMAN	27.99	0	1562
970	6	ACADEMY WESTWARD	ALEC KEITEL	11.99	0	727
971	8	ACADEMY WHALE	CHARLTON ROBBINS	25.99	0	4961
972	6	ACADEMY WHISPERER	FARRAH WALKEN	10.99	0	3502
973	14	ACADEMY WIFE	CHARLES DUNST	26.99	0	7282
974	13	ACADEMY WILD	JOHNNY BALE	15.99	0	2456
975	8	ACADEMY WILLOW	PARKER DEAN	19.99	0	3922
976	10	ACADEMY WIND	CHRISTIAN SARANDON	24.99	0	8317
977	4	ACADEMY WINDOW	OPRAH WITHERSPOON	19.99	0	9312
978	14	ACADEMY WISDOM	DREW WATSON	29.99	0	5327
979	12	ACADEMY WITCHES	LANA LAW	13.99	0	4804
980	8	ACADEMY WIZARD	MILLA FORD	13.99	0	426
981	10	ACADEMY WOLVES	RUBY GUINESS	25.99	0	4614
982	10	ACADEMY WOMEN	JEFF FISHER	16.99	0	5242
983	5	ACADEMY WON	JESSICA NEWMAN	20.99	0	2145
984	2	ACADEMY WONDERFUL	PEARL GOLDBERG	22.99	0	6483
985	2	ACADEMY WONDERLAND	WILLIAM BASINGER	26.99	0	8110
986	14	ACADEMY WONKA	DARYL TOMEI	24.99	0	3149
987	3	ACADEMY WORDS	MARILYN DUKAKIS	22.99	0	4649
988	3	ACADEMY WORKER	CATE WILSON	21.99	0	7971
989	14	ACADEMY WORKING	CLARK LEIGH	21.99	0	7701
990	4	ACADEMY WORLD	RIVER FINNEY	13.99	0	992
991	1	ACADEMY WORST	WOODY ANISTON	14.99	0	6724
992	9	ACADEMY WRATH	WHOOPI TYLER	13.99	0	6320
993	11	ACADEMY WRONG	LEONARDO NICHOLSON	25.99	0	1051
994	10	ACADEMY WYOMING	MATTHEW BRANDO	25.99	0	8821
995	9	ACADEMY YENTL	DEBBIE WILLIAMS	16.99	0	3570
996	8	ACADEMY YOUNG	HARRISON DEE	18.99	0	1085
997	3	ACADEMY YOUTH	ALAN BALE	11.99	0	5528
998	12	ACADEMY ZHIVAGO	DREW TRACY	16.99	0	5205
999	8	ACADEMY ZOOLANDER	MADELINE FAWCETT	11.99	0	3401
1000	16	ACADEMY ZORRO	FRANK MCGREGOR	13.99	1	4859
1001	9	ACE ACADEMY	MIRA HUDSON	28.99	0	1926
1002	1	ACE ACE	DORIS BENING	10.99	0	4673
1003	10	ACE ADAPTATION	HARRISON TOMEI	26.99	0	792
1004	6	ACE AFFAIR	HENRY MOSTEL	29.99	0	4683
1005	6	ACE AFRICAN	BRAD ROBBINS	22.99	0	949
1006	2	ACE AGENT	KIM KILMER	26.99	0	4865
1007	1	ACE AIRPLANE	KENNETH KAHN	14.99	0	7073
1008	12	ACE AIRPORT	LENA CROWE	11.99	0	8252
1009	3	ACE ALABAMA	JOHN HANNAH	20.99	0	2674
1010	1	ACE ALADDIN	ANGELA PITT	11.99	0	163
1011	4	ACE ALAMO	KEVIN JOHANSSON	25.99	0	204
1012	5	ACE ALASKA	KARL GARLAND	26.99	0	1058
1013	9	ACE ALI	FRANCES GABLE	11.99	0	3302
1014	16	ACE ALICE	NEVE MCKELLEN	18.99	0	1363
1015	12	ACE ALIEN	SEAN DEAN	24.99	0	2536
1016	13	ACE ALLEY	OLYMPIA LOREN	15.99	0	883
1017	6	ACE ALONE	JEREMY MCQUEEN	27.99	0	824
1018	16	ACE ALTER	JANE WINSLET	14.99	0	8895
1019	10	ACE AMADEUS	JULIANNE BASINGER	15.99	0	7162
1020	8	ACE AMELIE	UMA CRUZ	16.99	0	3001
1021	10	ACE AMERICAN	SHIRLEY PALTROW	16.99	0	2463
1022	8	ACE AMISTAD	SHIRLEY GABLE	27.99	0	3351
1023	16	ACE ANACONDA	GENE CRUISE	17.99	0	4149
1024	5	ACE ANALYZE	JIM BEATTY	26.99	0	9561
1025	9	ACE ANGELS	CHARLTON SUVARI	19.99	0	948
1026	13	ACE ANNIE	RENEE RYDER	22.99	0	8203
1027	15	ACE ANONYMOUS	CHRISTOPHER LOREN	25.99	0	3959
1028	3	ACE ANTHEM	LAURENCE HOPKINS	18.99	0	496
1029	14	ACE ANTITRUST	BURT CLOSE	15.99	0	4940
1030	5	ACE ANYTHING	GREGORY KEITEL	17.99	0	5471
1031	9	ACE APACHE	GREG RUSSELL	15.99	0	4885
1032	3	ACE APOCALYPSE	AUDREY GARBO	15.99	0	5476
1033	12	ACE APOLLO	ZERO DOUGLAS	15.99	0	8622
1034	6	ACE ARABIA	ALEC LEIGH	18.99	0	130
1035	16	ACE ARACHNOPHOBIA	KATE COOPER	15.99	0	5440
1036	14	ACE ARGONAUTS	GOLDIE BRIDGES	13.99	0	7828
1037	11	ACE ARIZONA	CHARLES LOREN	24.99	0	2933
1038	5	ACE ARK	KIRSTEN MCCONAUGHEY	15.99	0	2856
1039	3	ACE ARMAGEDDON	SALLY DIETRICH	12.99	0	7445
1040	4	ACE ARMY	SPENCER NORTON	24.99	0	5032
1041	5	ACE ARSENIC	LIV SPACEK	21.99	0	588
1042	7	ACE ARTIST	MARILYN PALTROW	20.99	0	5431
1043	14	ACE ATLANTIS	CHEVY PRESLEY	17.99	0	776
1044	11	ACE ATTACKS	GREGORY DAY	20.99	0	815
1045	5	ACE ATTRACTION	PARKER MARX	13.99	0	7538
1046	12	ACE AUTUMN	LAURENCE MCDORMAND	15.99	0	6182
1047	7	ACE BABY	GLENN MCKELLEN	9.99	0	7875
1048	10	ACE BACKLASH	KENNETH AKROYD	24.99	0	6057
1049	13	ACE BADMAN	RIVER BLOOM	12.99	0	2302
1050	4	ACE BAKED	ROCK WAHLBERG	29.99	0	1791
1051	13	ACE BALLOON	RENEE SMITH	16.99	0	422
1052	16	ACE BALLROOM	MEG KEATON	14.99	0	8498
1053	2	ACE BANG	RUSSELL BOGART	22.99	0	2616
1054	4	ACE BANGER	GROUCHO MCCONAUGHEY	10.99	0	9926
1055	5	ACE BARBARELLA	SUSAN ZELLWEGER	11.99	1	366
1056	5	ACE BAREFOOT	SALLY PITT	11.99	0	9959
1057	3	ACE BASIC	JUDY BALL	26.99	0	495
1058	11	ACE BEACH	CHARLIZE HANNAH	19.99	0	9691
1059	13	ACE BEAR	LAURENCE DENIRO	11.99	0	3556
1060	3	ACE BEAST	GRETA LOLLOBRIGIDA	10.99	0	3469
1061	2	ACE BEAUTY	BOB WOOD	28.99	0	1756
1062	16	ACE BED	DENZEL DEAN	18.99	0	5468
1063	8	ACE BEDAZZLED	VAL PECK	22.99	0	9691
1064	10	ACE BEETHOVEN	DENZEL ASTAIRE	13.99	0	5132
1065	9	ACE BEHAVIOR	BOB DUKAKIS	28.99	0	7842
1066	5	ACE BENEATH	PAUL HECHE	16.99	0	8609
1067	9	ACE BERETS	BOB FAWCETT	24.99	0	1372
1068	5	ACE BETRAYED	RUSSELL DERN	14.99	0	886
1069	4	ACE BEVERLY	BURT KEITEL	17.99	0	2697
1070	16	ACE BIKINI	KIRK DRIVER	9.99	0	9036
1071	14	ACE BILKO	GLENN HORNE	21.99	0	6982
1072	8	ACE BILL	ADAM FOSTER	20.99	0	7604
1073	11	ACE BINGO	ALAN GOODING	20.99	0	9215
1074	10	ACE BIRCH	JAYNE SPACEK	24.99	0	1721
1075	16	ACE BIRD	JESSICA DAFOE	20.99	0	6652
1076	8	ACE BIRDCAGE	CARY BALL	25.99	0	9473
1077	8	ACE BIRDS	FRANCES BERRY	19.99	0	3835
1078	5	ACE BLACKOUT	PARKER DUKAKIS	14.99	0	3932
1079	4	ACE BLADE	DORIS HEPBURN	22.99	0	4896
1080	13	ACE BLANKET	MENA CHAPLIN	14.99	0	9197
1081	15	ACE BLINDNESS	WARREN COOPER	10.99	0	5937
1082	1	ACE BLOOD	MATTHEW HOFFMAN	15.99	0	2873
1083	11	ACE BLUES	LAURA CROWE	18.99	0	3949
1084	14	ACE BOILED	ROBERT MIRANDA	10.99	0	9834
1085	10	ACE BONNIE	CARY BLANCHETT	14.99	0	8403
1086	3	ACE BOOGIE	ADRIEN DRIVER	11.99	0	9629
1087	12	ACE BOONDOCK	HUMPHREY GARCIA	17.99	0	3433
1088	12	ACE BORN	KARL FREEMAN	14.99	0	9891
1089	11	ACE BORROWERS	MAE MIRANDA	19.99	0	9184
1090	8	ACE BOULEVARD	ADRIEN DRIVER	21.99	0	3616
1091	8	ACE BOUND	MARISA PENN	18.99	0	11
1092	7	ACE BOWFINGER	GWYNETH LUGOSI	26.99	0	259
1093	3	ACE BRANNIGAN	HARRISON NICHOLSON	23.99	0	1777
1094	11	ACE BRAVEHEART	ROBERT MARX	15.99	0	5511
1095	4	ACE BREAKFAST	ROCK LEWIS	14.99	0	3830
1096	10	ACE BREAKING	BRUCE MCDORMAND	14.99	0	9548
1097	5	ACE BRIDE	KATHARINE JACKMAN	22.99	0	5286
1098	11	ACE BRIGHT	DEBBIE HUSTON	9.99	0	1525
1099	4	ACE BRINGING	ORLANDO TAUTOU	9.99	0	8587
1100	10	ACE BROOKLYN	JADA HESTON	17.99	0	6066
1101	13	ACE BROTHERHOOD	DREW DUKAKIS	27.99	0	3078
1102	14	ACE BUBBLE	RENEE SILVERSTONE	17.99	0	1183
1103	15	ACE BUCKET	LEONARDO BLANCHETT	11.99	0	7836
1104	5	ACE BUGSY	MARLENE FIELD	9.99	0	8462
1105	15	ACE BULL	FARRAH WAHLBERG	16.99	0	9658
1106	16	ACE BULWORTH	ELLEN CAMPBELL	12.99	0	8139
1107	8	ACE BUNCH	LUCILLE TRACY	14.99	0	672
1108	7	ACE BUTCH	CHARLTON DEAN	9.99	0	2659
1109	13	ACE BUTTERFLY	LAURA MIRANDA	18.99	0	9207
1110	5	ACE CABIN	ROSIE MANSFIELD	20.99	0	1830
1111	9	ACE CADDYSHACK	GLENN TAYLOR	25.99	0	3725
1112	10	ACE CALENDAR	EWAN KEITEL	13.99	0	5775
1113	5	ACE CALIFORNIA	RICHARD DAFOE	18.99	0	1663
1114	12	ACE CAMELOT	RIP WOOD	15.99	0	5055
1115	4	ACE CAMPUS	BRUCE PALTROW	10.99	0	355
1116	4	ACE CANDIDATE	SPENCER SANDLER	20.99	0	9534
1117	16	ACE CANDLES	JODIE CRUZ	13.99	0	2819
1118	13	ACE CANYON	JOHN PHOENIX	21.99	0	6891
1119	13	ACE CAPER	MEG TURNER	21.99	0	1019
1120	2	ACE CARIBBEAN	RICHARD HECHE	12.99	0	826
1121	4	ACE CAROL	SIDNEY PHOENIX	11.99	0	4795
1122	2	ACE CARRIE	MEG DENIRO	20.99	0	1081
1123	14	ACE CASABLANCA	ROCK DIAZ	15.99	0	247
1124	1	ACE CASPER	TIM MCQUEEN	23.99	0	1362
1125	13	ACE CASSIDY	KIRK EASTWOOD	21.99	0	492
1126	12	ACE CASUALTIES	PENELOPE PESCI	21.99	0	856
1127	1	ACE CAT	GOLDIE WAYNE	24.99	0	8004
1128	14	ACE CATCH	ANNETTE GABLE	23.99	0	9320
1129	12	ACE CAUSE	KIRSTEN PALTROW	22.99	0	7855
1130	13	ACE CELEBRITY	BETTE DAFOE	16.99	0	5846
1131	7	ACE CENTER	FRED JOVOVICH	12.99	0	1594
1132	5	ACE CHAINSAW	BRUCE CAMPBELL	21.99	0	6086
1133	7	ACE CHAMBER	WARREN PESCI	18.99	0	6485
1134	7	ACE CHAMPION	GROUCHO BRANAGH	28.99	0	7602
1135	12	ACE CHANCE	WARREN KEATON	26.99	0	7794
1136	7	ACE CHAPLIN	FAY DEGENERES	23.99	0	3711
1137	14	ACE CHARADE	JUDY MOORE	29.99	0	3910
1138	10	ACE CHARIOTS	CAMERON MCDORMAND	20.99	0	5133
1139	4	ACE CHASING	LIZA HOPPER	20.99	0	3677
1140	5	ACE CHEAPER	SIDNEY CAMPBELL	14.99	0	7409
1141	1	ACE CHICAGO	WILLEM GIBSON	16.99	0	3829
1142	12	ACE CHICKEN	ANDY WILLIS	13.99	0	2779
1143	10	ACE CHILL	SOPHIA KEITEL	24.99	0	9766
1144	4	ACE CHINATOWN	JAMES DIAZ	27.99	0	8379
1145	4	ACE CHISUM	WILLEM BRODY	11.99	0	9439
1146	14	ACE CHITTY	GEOFFREY HOPKINS	26.99	0	4081
1147	4	ACE CHOCOLAT	HARRISON JOLIE	14.99	0	3088
1148	9	ACE CHOCOLATE	ROBIN FOSTER	18.99	0	8980
1149	7	ACE CHRISTMAS	CHRIS FIELD	26.99	0	9723
1150	11	ACE CIDER	BOB HANNAH	22.99	0	4912
1151	10	ACE CINCINATTI	UMA GOLDBERG	28.99	0	7336
1152	6	ACE CIRCUS	DUSTIN HEPBURN	23.99	0	9637
1153	1	ACE CITIZEN	GARY DAY-LEWIS	26.99	0	3770
1154	12	ACE CLASH	MENA BERRY	27.99	0	8594
1155	14	ACE CLEOPATRA	ELVIS MARX	29.99	0	7795
1156	8	ACE CLERKS	CHEVY TAYLOR	17.99	0	3671
1157	3	ACE CLOCKWORK	REESE CAGE	16.99	0	4866
1158	6	ACE CLONES	MINNIE SUVARI	22.99	0	3713
1159	1	ACE CLOSER	JEFF HESTON	23.99	0	3681
1160	10	ACE CLUB	WILL DAVIS	26.99	0	2423
1161	10	ACE CLUE	CANDICE MCQUEEN	24.99	0	9171
1162	3	ACE CLUELESS	ANJELICA COSTNER	28.99	0	8881
1163	7	ACE CLYDE	NICK TEMPLE	11.99	0	4328
1164	8	ACE COAST	SANDRA KILMER	28.99	0	2046
1165	5	ACE COLDBLOODED	IAN SARANDON	14.99	0	5928
1166	9	ACE COLOR	DORIS DENCH	22.99	0	2683
1167	9	ACE COMA	JAYNE BULLOCK	21.99	0	9857
1168	8	ACE COMANCHEROS	SALMA HUDSON	13.99	0	3847
1169	11	ACE COMFORTS	SYLVESTER BIRCH	20.99	0	1673
1170	12	ACE COMMAND	WILLEM FONDA	12.99	0	6114
1171	12	ACE COMMANDMENTS	RUSSELL CAINE	29.99	0	8535
1172	4	ACE CONEHEADS	WILLIAM FORD	23.99	0	376
1173	11	ACE CONFESSIONS	JUDE HOPE	20.99	0	950
1174	15	ACE CONFIDENTIAL	CLARK GABLE	26.99	0	2028
1175	1	ACE CONFUSED	KATE MCGREGOR	29.99	0	1501
1176	10	ACE CONGENIALITY	FAY KIDMAN	18.99	0	705
1177	5	ACE CONNECTICUT	IAN PRESLEY	15.99	0	3588
1178	6	ACE CONNECTION	RENEE BRODY	26.99	0	4866
1179	15	ACE CONQUERER	ROCK LOREN	11.99	0	7243
1180	5	ACE CONSPIRACY	GRETA HOFFMAN	26.99	0	1364
1181	16	ACE CONTACT	MATT BAILEY	14.99	0	1802
1182	6	ACE CONTROL	TOM RYAN	25.99	0	3843
1183	2	ACE CONVERSATION	JUDE HARRIS	28.99	0	1631
1184	7	ACE CORE	NICOLAS COOPER	14.99	0	1727
1185	16	ACE COWBOY	LISA LOLLOBRIGIDA	15.99	0	453
1186	8	ACE CRAFT	BELA HAWN	11.99	0	5632
1187	6	ACE CRANES	GROUCHO BASINGER	14.99	0	4368
1188	11	ACE CRAZY	ROSIE WATSON	11.99	0	848
1189	5	ACE CREATURES	ELIZABETH DOUGLAS	9.99	0	5231
1190	4	ACE CREEPERS	BRUCE JOLIE	26.99	0	5265
1191	15	ACE CROOKED	UMA DUKAKIS	29.99	0	6432
1192	9	ACE CROSSING	MICHAEL PITT	27.99	1	5129
1193	5	ACE CROSSROADS	JENNIFER MCGREGOR	12.99	0	3171
1194	4	ACE CROW	LENA BERGEN	19.99	0	1256
1195	1	ACE CROWDS	LUCILLE FONDA	11.99	0	4611
1196	11	ACE CRUELTY	OPRAH BARRYMORE	21.99	0	1834
1197	4	ACE CRUSADE	SYLVESTER KEITEL	28.99	0	9141
1198	8	ACE CRYSTAL	KATE PECK	27.99	0	3048
1199	4	ACE CUPBOARD	HARRISON BRANDO	25.99	0	4869
1200	15	ACE CURTAIN	RIVER MCCONAUGHEY	20.99	0	9898
1201	1	ACE CYCLONE	ANDY GOODING	25.99	0	415
1202	16	ACE DADDY	KIRSTEN DAFOE	27.99	0	9654
1203	13	ACE DAISY	MEG LEWIS	16.99	0	5455
1204	11	ACE DALMATIONS	MARLON NEWMAN	9.99	0	2585
1205	9	ACE DANCES	SEAN HAWKE	15.99	0	6151
1206	6	ACE DANCING	ZERO WRAY	16.99	0	9700
1207	7	ACE DANGEROUS	CHRISTOPHER PHOENIX	29.99	0	3053
1208	15	ACE DARES	SEAN HAWN	21.99	0	3430
1209	3	ACE DARKNESS	ALAN HACKMAN	25.99	0	4979
1210	1	ACE DARKO	SPENCER TYLER	28.99	0	8815
1211	9	ACE DARLING	SEAN LANCASTER	20.99	0	6478
1212	9	ACE DARN	HELEN DUKAKIS	23.99	0	9989
1213	16	ACE DATE	INGRID COSTNER	27.99	0	1699
1214	4	ACE DAUGHTER	KIRSTEN VOIGHT	13.99	0	9803
1215	12	ACE DAWN	SISSY RUSH	22.99	0	1337
1216	9	ACE DAY	MENA DICAPRIO	17.99	0	5873
1217	1	ACE DAZED	SHIRLEY FORD	18.99	0	1326
1218	7	ACE DECEIVER	GARY BAILEY	26.99	0	816
1219	1	ACE DEEP	ADAM BULLOCK	21.99	0	7225
1220	9	ACE DEER	JUDE BOLGER	18.99	0	2203
1221	10	ACE DELIVERANCE	JOHN DIETRICH	14.99	0	3089
1222	14	ACE DESERT	MARISA PESCI	24.99	0	6813
1223	15	ACE DESIRE	MINNIE LOREN	12.99	0	6220
1224	5	ACE DESPERATE	OLYMPIA HESTON	14.99	0	1162
1225	16	ACE DESTINATION	DENZEL LOREN	19.99	0	9624
1226	12	ACE DESTINY	DREW MCKELLEN	13.99	0	9062
1227	9	ACE DETAILS	LUCILLE ROBBINS	12.99	0	7803
1228	14	ACE DETECTIVE	GWYNETH GUINESS	20.99	0	7873
1229	3	ACE DEVIL	DORIS STALLONE	28.99	0	2485
1230	1	ACE DIARY	ROBIN BOGART	14.99	0	8723
1231	4	ACE DINOSAUR	JUDE EASTWOOD	18.99	0	4110
1232	6	ACE DIRTY	CLINT ANISTON	29.99	0	6969
1233	13	ACE DISCIPLE	BETTE ANISTON	11.99	0	6653
1234	15	ACE DISTURBING	JUDI POITIER	12.99	0	6159
1235	7	ACE DIVIDE	MINNIE PECK	13.99	0	3049
1236	2	ACE DIVINE	LIAM CRUZ	21.99	0	1141
1237	1	ACE DIVORCE	CARY ALLEN	13.99	0	3069
1238	15	ACE DOCTOR	GINA RICKMAN	29.99	0	8940
1239	11	ACE DOGMA	MARILYN SINATRA	12.99	0	3122
1240	13	ACE DOLLS	ALEC GARBO	19.99	0	1
1241	13	ACE DONNIE	DANIEL NOLTE	17.99	0	8452
1242	9	ACE DOOM	SALLY DUKAKIS	22.99	0	8565
1243	16	ACE DOORS	LUCILLE GOLDBERG	14.99	0	5267
1244	3	ACE DORADO	GREGORY AFFLECK	25.99	0	3094
1245	2	ACE DOUBLE	MATT WALKEN	12.99	0	2504
1246	3	ACE DOUBTFIRE	TIM CRUISE	16.99	0	2138
1247	3	ACE DOWNHILL	JUDI BOGART	9.99	0	9974
1248	15	ACE DOZEN	HARVEY NORTON	19.99	0	7370
1249	1	ACE DRACULA	NICOLAS BRODY	17.99	0	8989
1250	12	ACE DRAGON	RIVER BALL	16.99	0	2310
1251	10	ACE DRAGONFLY	JADA FISHER	20.99	0	145
1252	13	ACE DREAM	CAMERON STREEP	14.99	0	8521
1253	5	ACE DRIFTER	KATE RUSSELL	22.99	0	4942
1254	7	ACE DRIVER	LISA GARBO	11.99	0	5399
1255	1	ACE DRIVING	LAUREN HOPPER	26.99	0	7664
1256	2	ACE DROP	BOB HOPE	19.99	1	7608
1257	9	ACE DRUMLINE	LISA RICKMAN	22.99	0	5005
1258	8	ACE DRUMS	FAY FIELD	9.99	0	5948
1259	9	ACE DUCK	VIVIEN FREEMAN	11.99	0	7037
1260	11	ACE DUDE	CHEVY JOLIE	14.99	0	9851
1261	1	ACE DUFFEL	JAMES HEPBURN	11.99	0	4316
1262	15	ACE DUMBO	DANIEL HORNE	19.99	0	2374
1263	16	ACE DURHAM	KENNETH LOREN	14.99	0	5112
1264	14	ACE DWARFS	SALLY BULLOCK	26.99	0	3344
1265	9	ACE DYING	ROCK WASHINGTON	23.99	0	1896
1266	11	ACE DYNAMITE	LIZA DAMON	11.99	0	5653
1267	9	ACE EAGLES	ALEC CRUZ	24.99	0	1242
1268	16	ACE EARLY	MILLA NEWMAN	19.99	0	3142
1269	1	ACE EARRING	JANE SILVERSTONE	27.99	0	6982
1270	4	ACE EARTH	LUCILLE CHASE	10.99	0	8157
1271	4	ACE EASY	ALBERT JOVOVICH	27.99	0	3448
1272	7	ACE EDGE	KATHARINE CAMPBELL	18.99	0	2280
1273	10	ACE EFFECT	SOPHIA SPACEK	15.99	0	8461
1274	10	ACE EGG	MARY GOLDBERG	10.99	0	2946
1275	12	ACE EGYPT	JENNIFER HUSTON	16.99	0	2944
1276	4	ACE ELEMENT	RENEE RUSSELL	13.99	0	4131
1277	9	ACE ELEPHANT	KEVIN BLOOM	11.99	0	4238
1278	6	ACE ELF	ELLEN CAMPBELL	13.99	0	6109
1279	2	ACE ELIZABETH	WINONA BALL	24.99	0	2527
1280	1	ACE EMPIRE	NICK SPACEK	19.99	0	2763
1281	13	ACE ENCINO	ANNETTE HARRIS	21.99	0	7189
1282	16	ACE ENCOUNTERS	RIP CRAWFORD	20.99	0	3654
1283	16	ACE ENDING	JUDI MARX	13.99	0	9429
1284	14	ACE ENEMY	WINONA VOIGHT	26.99	0	790
1285	2	ACE ENGLISH	SUSAN NOLTE	26.99	0	1309
1286	2	ACE ENOUGH	KATE WAYNE	12.99	0	1553
1287	15	ACE ENTRAPMENT	GOLDIE KEATON	23.99	0	6128
1288	1	ACE ESCAPE	DIANE BALE	20.99	0	613
1289	9	ACE EVE	WILLEM BRANDO	19.99	0	6275
1290	10	ACE EVERYONE	GARY BACALL	19.99	0	4742
1291	10	ACE EVOLUTION	INGRID WEAVER	12.99	0	9413
1292	5	ACE EXCITEMENT	JEREMY WITHERSPOON	22.99	0	5273
1293	5	ACE EXORCIST	KIRSTEN PFEIFFER	19.99	0	8384
1294	9	ACE EXPECATIONS	VIVIEN RYAN	19.99	0	8981
1295	3	ACE EXPENDABLE	THORA SUVARI	18.99	0	7779
1296	15	ACE EXPRESS	MORGAN WILLIAMS	16.99	0	8304
1297	5	ACE EXTRAORDINARY	RIP HAYEK	24.99	0	4866
1298	5	ACE EYES	DENNIS FIENNES	26.99	0	5006
1299	11	ACE FACTORY	FRANCES FONDA	22.99	0	5748
1300	9	ACE FALCON	JADA WRAY	18.99	0	7670
1301	4	ACE FAMILY	MORGAN GARLAND	29.99	0	8357
1302	13	ACE FANTASIA	ELLEN WRAY	21.99	0	3190
1303	2	ACE FANTASY	MAE AKROYD	15.99	0	4319
1304	13	ACE FARGO	PARKER KEITEL	10.99	0	6134
1305	11	ACE FATAL	LEONARDO NICHOLSON	11.99	0	451
1306	14	ACE FEATHERS	IAN GARCIA	21.99	0	1208
1307	7	ACE FELLOWSHIP	CAMERON BRANAGH	23.99	0	8492
1308	16	ACE FERRIS	SALLY RYDER	22.99	0	7000
1309	2	ACE FEUD	DIANE TORN	26.99	1	3689
1310	8	ACE FEVER	ANGELA MOORE	10.99	0	1739
1311	2	ACE FICTION	KATE MCCONAUGHEY	19.99	0	8548
1312	11	ACE FIDDLER	WARREN MCGREGOR	24.99	0	6681
1313	10	ACE FIDELITY	JESSICA EASTWOOD	18.99	0	5592
1314	3	ACE FIGHT	JEREMY AFFLECK	16.99	0	4473
1315	12	ACE FINDING	BURT DREYFUSS	25.99	0	8611
1316	16	ACE FIRE	JODIE HAYEK	19.99	0	6826
1317	6	ACE FIREBALL	GARY LANSBURY	15.99	0	6147
1318	16	ACE FIREHOUSE	SUSAN THERON	18.99	0	8553
1319	16	ACE FISH	SALLY HUNT	18.99	0	6950
1320	15	ACE FLAMINGOS	WILLEM LEWIS	9.99	0	3054
1321	14	ACE FLASH	NATALIE DUNST	16.99	0	6576
1322	1	ACE FLATLINERS	DENNIS BULLOCK	16.99	0	5075
1323	16	ACE FLIGHT	HILARY HANNAH	27.99	0	7189
1324	12	ACE FLINTSTONES	DAN SOBIESKI	21.99	0	282
1325	5	ACE FLOATS	LENA CRAWFORD	14.99	0	9466
1326	9	ACE FLYING	EDWARD BALL	15.99	0	329
1327	16	ACE FOOL	CHRIS HAWKE	12.99	0	5935
1328	11	ACE FOREVER	ZERO ODONNELL	10.99	0	8326
1329	13	ACE FORREST	MARY DREYFUSS	29.99	0	9417
1330	16	ACE FORRESTER	CANDICE CAMPBELL	21.99	0	2972
1331	9	ACE FORWARD	GREG WEAVER	25.99	0	7271
1332	14	ACE FRANKENSTEIN	CATE CRAWFORD	29.99	0	8845
1333	10	ACE FREAKY	LAURA ZELLWEGER	20.99	0	1410
1334	7	ACE FREDDY	JACK SOBIESKI	10.99	0	2891
1335	1	ACE FREEDOM	JADA RUSH	11.99	0	8225
1336	7	ACE FRENCH	PAUL TYLER	24.99	0	77
1337	8	ACE FRIDA	CUBA KAHN	22.99	0	5215
1338	9	ACE FRISCO	JULIA BENING	10.99	0	5730
1339	4	ACE FROGMEN	HUGH BAILEY	22.99	0	1906
1340	16	ACE FRONTIER	WILL BOGART	16.99	0	3496
1341	4	ACE FROST	ELVIS MCQUEEN	29.99	0	9592
1342	16	ACE FUGITIVE	JOAN THURMAN	12.99	0	9640
1343	11	ACE FULL	ALEC ASTAIRE	13.99	0	6584
1344	13	ACE FURY	MENA FOSTER	12.99	1	7835
1345	6	ACE GABLES	SHIRLEY WAYNE	16.99	0	1015
1346	12	ACE GALAXY	NICOLAS KAHN	29.99	0	1401
1347	15	ACE GAMES	ALEC HOPKINS	17.99	0	5387
1348	6	ACE GANDHI	KIRK EASTWOOD	16.99	0	6726
1349	1	ACE GANGS	AL DREYFUSS	24.99	0	116
1350	9	ACE GARDEN	VIVIEN SMITH	17.99	0	2668
1351	8	ACE GASLIGHT	PEARL SWANK	13.99	0	2561
1352	6	ACE GATHERING	MINNIE PESCI	17.99	0	3278
1353	15	ACE GENTLEMEN	LUCILLE HOPKINS	19.99	0	1332
1354	3	ACE GHOST	IAN TANDY	12.99	0	8720
1355	4	ACE GHOSTBUSTERS	MICHAEL BOGART	12.99	0	8615
1356	7	ACE GIANT	MIRA WINFREY	13.99	0	5267
1357	8	ACE GILBERT	EDWARD LOLLOBRIGIDA	12.99	0	3540
1358	8	ACE GILMORE	RICHARD TURNER	11.99	0	6387
1359	4	ACE GLADIATOR	JUDE LEWIS	22.99	0	912
1360	9	ACE GLASS	CUBA WEST	13.99	0	6704
1361	2	ACE GLEAMING	MARILYN KEATON	25.99	0	8489
1362	6	ACE GLORY	JACK CHASE	21.99	0	3972
1363	16	ACE GO	GARY SANDLER	24.99	0	7115
1364	7	ACE GODFATHER	FAY CLOSE	27.99	0	453
1365	16	ACE GOLD	ZERO GARCIA	12.99	0	1020
1366	14	ACE GOLDFINGER	LIV NOLTE	19.99	0	3272
1367	6	ACE GOLDMINE	JOE SOBIESKI	24.99	0	7982
1368	3	ACE GONE	LENA GABLE	18.99	0	5150
1369	3	ACE GOODFELLAS	MEG HUSTON	18.99	0	5048
1370	8	ACE GORGEOUS	SANDRA FREEMAN	19.99	0	4559
1371	10	ACE GOSFORD	CATE GABLE	13.99	0	6307
1372	9	ACE GRACELAND	JEREMY CHASE	9.99	0	8713
1373	14	ACE GRADUATE	DIANE BENING	17.99	0	3181
1374	16	ACE GRAFFITI	REESE NORTON	22.99	0	1691
1375	3	ACE GRAIL	JULIA MCQUEEN	29.99	0	319
1376	8	ACE GRAPES	HELEN PINKETT	21.99	0	2121
1377	4	ACE GREASE	HARRISON JOVOVICH	23.99	0	2835
1378	9	ACE GREATEST	GREGORY GARCIA	25.99	0	8651
1379	2	ACE GREEDY	KEVIN PHOENIX	27.99	0	6923
1380	1	ACE GREEK	GOLDIE HURT	21.99	0	4708
1381	10	ACE GRINCH	DENNIS VOIGHT	29.99	0	1694
1382	4	ACE GRIT	MEG PENN	20.99	0	2107
1383	14	ACE GROOVE	LANA WATSON	13.99	0	3656
1384	2	ACE GROSSE	BRAD RYAN	21.99	0	4532
1385	5	ACE GROUNDHOG	TIM PHOENIX	22.99	0	4039
1386	2	ACE GUMP	GINA TURNER	15.99	0	8237
1387	8	ACE GUN	KATHARINE BLANCHETT	12.99	0	9352
1388	7	ACE GUNFIGHT	SCARLETT KAHN	28.99	0	5808
1389	6	ACE GUNFIGHTER	HARRISON ROBBINS	17.99	0	499
1390	14	ACE GUYS	PENELOPE ODONNELL	25.99	0	840
1391	4	ACE HALF	WOODY HOFFMAN	20.99	0	8826
1392	6	ACE HALL	WILL DEPP	27.99	0	6307
1393	14	ACE HALLOWEEN	CHARLES RYAN	23.99	0	8502
1394	5	ACE HAMLET	LIZA BEATTY	22.99	0	98
1395	12	ACE HANDICAP	MICHELLE FOSTER	19.99	0	383
1396	10	ACE HANGING	JOE FREEMAN	20.99	0	2463
1397	8	ACE HANKY	JUDE DAY-LEWIS	17.99	0	9186
1398	1	ACE HANOVER	MINNIE WATSON	12.99	0	4562
1399	1	ACE HAPPINESS	JULIA WAHLBERG	22.99	0	9885
1400	11	ACE HARDLY	GLENN DOUGLAS	16.99	0	4703
1401	7	ACE HAROLD	RITA FONDA	27.99	0	6871
1402	3	ACE HARPER	SPENCER FONDA	22.99	0	192
1403	9	ACE HARRY	WALTER RYAN	14.99	0	5961
1404	12	ACE HATE	JULIA ALLEN	14.99	0	904
1405	4	ACE HAUNTED	HALLE FORD	20.99	0	1315
1406	1	ACE HAUNTING	JESSICA BRODY	26.99	0	3545
1407	9	ACE HAWK	MENA CHAPLIN	18.99	0	4343
1408	8	ACE HEAD	DORIS GABLE	17.99	0	2030
1409	1	ACE HEARTBREAKERS	DENZEL FREEMAN	20.99	0	8877
1410	10	ACE HEAVEN	DORIS SINATRA	29.99	0	9398
1411	2	ACE HEAVENLY	ANNETTE HARRIS	21.99	0	788
1412	15	ACE HEAVYWEIGHTS	DREW RUSSELL	22.99	0	279
1413	1	ACE HEDWIG	HARVEY NOLTE	14.99	0	16
1414	8	ACE HELLFIGHTERS	GREGORY BRANDO	23.99	0	9396
1415	10	ACE HIGH	OPRAH DERN	26.99	0	1379
1416	13	ACE HIGHBALL	KENNETH GARCIA	26.99	0	7989
1417	15	ACE HILLS	LAUREN THERON	11.99	0	8090
1418	3	ACE HOBBIT	JOHNNY LAW	20.99	0	5922
1419	9	ACE HOCUS	MICHELLE FONDA	27.99	0	3438
1420	14	ACE HOLES	LEONARDO MCGREGOR	21.99	0	8474
1421	12	ACE HOLIDAY	DENNIS DAFOE	14.99	0	1565
1422	2	ACE HOLLOW	ANDY WAHLBERG	22.99	0	5433
1423	8	ACE HOLLYWOOD	BURT DAVIS	29.99	0	9530
1424	9	ACE HOLOCAUST	FAY DUNST	14.99	0	3221
1425	10	ACE HOLY	VAL ANISTON	13.99	0	3924
1426	1	ACE HOME	LEELEE FORD	14.99	0	6161
1427	7	ACE HOMEWARD	KATE NORTON	18.99	0	5912
1428	16	ACE HOMICIDE	RICHARD SARANDON	11.99	0	5608
1429	1	ACE HONEY	SALLY FIENNES	16.99	0	462
1430	11	ACE HOOK	ANTHONY COSTNER	21.99	0	6765
1431	1	ACE HOOSIERS	ALAN HAWN	21.99	0	6283
1432	4	ACE HOPE	GENE BLOOM	24.99	0	6575
1433	6	ACE HORN	JIM KINNEAR	12.99	0	2348
1434	12	ACE HORROR	KEVIN PACINO	20.99	0	1268
1435	10	ACE HOTEL	FRANK PALTROW	23.99	0	6704
1436	6	ACE HOURS	BOB FINNEY	16.99	0	7687
1437	16	ACE HOUSE	SALMA CAINE	15.99	0	4093
1438	16	ACE HUMAN	VIVIEN DEE	18.99	0	5988
1439	11	ACE HUNCHBACK	FRED BLANCHETT	13.99	0	3440
1440	6	ACE HUNGER	ANJELICA DICAPRIO	22.99	0	3707
1441	6	ACE HUNTER	MERYL EASTWOOD	17.99	0	6170
1442	3	ACE HUNTING	OLYMPIA NEWMAN	9.99	0	6427
1443	8	ACE HURRICANE	SCARLETT WILLIAMS	17.99	0	2547
1444	1	ACE HUSTLER	GREG BERGEN	15.99	0	10
1445	11	ACE HYDE	ETHAN MIRANDA	23.99	0	2197
1446	2	ACE HYSTERICAL	JULIANNE MCCONAUGHEY	25.99	0	1997
1447	7	ACE ICE	SCARLETT DAMON	11.99	0	8620
1448	13	ACE IDAHO	RIVER PACINO	22.99	0	2168
1449	15	ACE IDENTITY	FAY BRANAGH	14.99	0	5794
1450	5	ACE IDOLS	DORIS BENING	19.99	0	5234
1451	12	ACE IGBY	CHARLES SOBIESKI	14.99	0	1716
1452	8	ACE ILLUSION	HELEN WINFREY	16.99	0	6330
1453	4	ACE IMAGE	GRACE THERON	9.99	0	4434
1454	4	ACE IMPACT	KEVIN HOFFMAN	20.99	0	9667
1455	2	ACE IMPOSSIBLE	ALEC WAYNE	15.99	0	7861
1456	14	ACE INCH	LISA DAMON	29.99	0	2060
1457	3	ACE INDEPENDENCE	CLARK WATSON	20.99	0	2854
1458	3	ACE INDIAN	CHRISTIAN HURT	19.99	0	7051
1459	16	ACE INFORMER	CHARLIZE PITT	19.99	0	8387
1460	8	ACE INNOCENT	PENELOPE GARLAND	19.99	0	2474
1461	5	ACE INSECTS	JENNIFER KUDROW	28.99	0	9273
1462	2	ACE INSIDER	SANDRA PECK	15.99	0	1439
1463	10	ACE INSTINCT	LIZA HESTON	24.99	0	1254
1464	8	ACE INTENTIONS	SANDRA TYLER	21.99	0	1307
1465	7	ACE INTERVIEW	JON TURNER	13.99	0	1960
1466	8	ACE INTOLERABLE	NICOLE PALTROW	28.99	0	2904
1467	14	ACE INTRIGUE	ADAM PFEIFFER	23.99	0	2586
1468	14	ACE INVASION	MICHAEL MALDEN	19.99	0	6509
1469	10	ACE IRON	KIRK RYAN	18.99	0	9922
1470	10	ACE ISHTAR	SISSY SOBIESKI	11.99	0	3131
1471	5	ACE ISLAND	ALAN KAHN	9.99	0	6333
1472	6	ACE ITALIAN	GROUCHO DOUGLAS	16.99	1	3777
1473	10	ACE JACKET	WILL SUVARI	15.99	0	3133
1474	16	ACE JADE	BURT WATSON	19.99	0	4960
1475	8	ACE JAPANESE	GINA ALLEN	17.99	0	3690
1476	12	ACE JASON	SHIRLEY HARRIS	24.99	0	3133
1477	6	ACE JAWBREAKER	LEELEE RUSSELL	24.99	0	5865
1478	2	ACE JAWS	JANE PECK	10.99	0	7680
1479	7	ACE JEDI	MICHELLE WAYNE	19.99	0	1140
1480	16	ACE JEEPERS	CARRIE WEAVER	15.99	0	2383
1481	11	ACE JEKYLL	MARISA BASINGER	20.99	0	1012
1482	14	ACE JEOPARDY	SIDNEY CAMPBELL	18.99	0	84
1483	1	ACE JERICHO	MORGAN WILSON	19.99	0	7251
1484	5	ACE JERK	MATT HAYEK	29.99	0	1171
1485	2	ACE JERSEY	ANNETTE TRACY	13.99	0	4058
1486	8	ACE JET	JEREMY TOMEI	10.99	0	2398
1487	4	ACE JINGLE	HELEN FINNEY	10.99	0	2504
1488	2	ACE JOON	DENZEL STALLONE	25.99	0	2552
1489	9	ACE JUGGLER	MEG MALDEN	13.99	0	5941
1490	6	ACE JUMANJI	JON MCKELLEN	16.99	0	7083
1491	13	ACE JUMPING	LENA DIETRICH	14.99	0	506
1492	8	ACE JUNGLE	HARVEY LANCASTER	27.99	0	1660
1493	2	ACE KANE	ADRIEN PECK	16.99	0	3433
1494	10	ACE KARATE	TIM BASINGER	14.99	0	4883
1495	14	ACE KENTUCKIAN	CANDICE LEWIS	16.99	0	9508
1496	2	ACE KICK	DIANE PINKETT	23.99	0	5838
1497	12	ACE KILL	CARY HUDSON	10.99	0	7609
1498	5	ACE KILLER	JOAN HOPKINS	14.99	0	9926
1499	10	ACE KING	ANGELA GOLDBERG	20.99	0	2966
1500	1	ACE KISS	SANDRA KAHN	12.99	0	8174
1501	2	ACE KISSING	KEVIN WAYNE	15.99	0	5367
1502	15	ACE KNOCK	ADAM FISHER	9.99	0	3380
1503	13	ACE KRAMER	RAY NICHOLSON	14.99	0	5804
1504	5	ACE KWAI	WALTER LANSBURY	15.99	0	6084
1505	10	ACE LABYRINTH	CARMEN CAINE	19.99	0	9929
1506	5	ACE LADY	TIM HACKMAN	26.99	0	5403
1507	7	ACE LADYBUGS	SANDRA MCKELLEN	17.99	0	2836
1508	12	ACE LAMBS	WARREN HUSTON	19.99	0	9062
1509	2	ACE LANGUAGE	JESSICA BAILEY	10.99	0	5676
1510	11	ACE LAWLESS	MILLA WILLIS	25.99	0	9976
1511	13	ACE LAWRENCE	HILARY PHOENIX	24.99	0	1158
1512	5	ACE LEAGUE	NICOLE WINFREY	11.99	0	4275
1513	7	ACE LEATHERNECKS	STEVE BLOOM	16.99	0	6735
1514	5	ACE LEBOWSKI	MILLA PECK	24.99	0	555
1515	5	ACE LEGALLY	ALAN HESTON	9.99	0	4551
1516	1	ACE LEGEND	DAN ALLEN	17.99	0	7756
1517	9	ACE LESSON	NICOLE WITHERSPOON	14.99	0	1117
1518	12	ACE LIAISONS	DARYL JOLIE	21.99	0	8149
1519	5	ACE LIBERTY	JULIETTE CAINE	29.99	0	2982
1520	1	ACE LICENSE	NICK CRAWFORD	10.99	0	9667
1521	9	ACE LIES	WILLEM CROWE	23.99	0	7027
1522	8	ACE LIFE	MEL BOLGER	13.99	0	7838
1523	6	ACE LIGHTS	FAY BEATTY	20.99	0	1576
1524	6	ACE LION	FRANK WASHINGTON	27.99	0	1716
1525	3	ACE LOATHING	GREGORY WEST	28.99	0	5316
1526	15	ACE LOCK	MORGAN KEATON	27.99	0	3091
1527	9	ACE LOLA	IAN ODONNELL	14.99	0	7776
1528	1	ACE LOLITA	ROBIN DENIRO	15.99	0	4939
1529	8	ACE LONELY	JADA CAINE	25.99	0	3459
1530	16	ACE LORD	FRED CRUZ	15.99	0	3097
1531	14	ACE LOSE	ROBERT WRAY	20.99	0	438
1532	14	ACE LOSER	NEVE HAWKE	14.99	0	6485
1533	1	ACE LOST	SISSY NORTON	27.99	0	6828
1534	6	ACE LOUISIANA	RIVER HURT	25.99	0	8394
1535	3	ACE LOVE	ALICIA CRUISE	18.99	0	1451
1536	13	ACE LOVELY	CATE FAWCETT	21.99	0	9890
1537	11	ACE LOVER	HUME PACINO	16.99	0	605
1538	1	ACE LOVERBOY	NICOLE ALLEN	28.99	0	7511
1539	10	ACE LUCK	DORIS DERN	17.99	0	4799
1540	4	ACE LUCKY	MATTHEW DAFOE	14.99	0	1587
1541	7	ACE LUKE	JIM HANNAH	20.99	0	3178
1542	9	ACE LUST	ALBERT MATTHAU	29.99	0	9906
1543	1	ACE MADIGAN	ADAM WITHERSPOON	25.99	0	8880
1544	9	ACE MADISON	CHARLIZE HURT	24.99	0	2013
1545	4	ACE MADNESS	HUME CAINE	27.99	0	488
1546	1	ACE MADRE	JENNIFER STREEP	20.99	0	4352
1547	14	ACE MAGIC	ANGELINA WINFREY	27.99	0	177
1548	14	ACE MAGNIFICENT	ZERO WEAVER	26.99	0	8861
1549	12	ACE MAGNOLIA	GWYNETH DEE	27.99	0	2486
1550	2	ACE MAGUIRE	HELEN DAFOE	19.99	0	8047
1551	9	ACE MAIDEN	MARLENE CLOSE	29.99	0	703
1552	7	ACE MAJESTIC	ANGELA KELLY	18.99	0	9721
1553	8	ACE MAKER	SYLVESTER DENIRO	19.99	0	6345
1554	7	ACE MALKOVICH	SANDRA STREEP	24.99	0	8422
1555	16	ACE MALLRATS	ANGELINA SOBIESKI	16.99	0	1479
1556	3	ACE MALTESE	GARY TANDY	26.99	0	9949
1557	15	ACE MANCHURIAN	JULIANNE DREYFUSS	28.99	0	9164
1558	15	ACE MANNEQUIN	CHRIS DENIRO	26.99	0	2690
1559	8	ACE MARRIED	CANDICE BRANDO	16.99	0	8555
1560	3	ACE MARS	MEL SPACEK	13.99	0	52
1561	6	ACE MASK	SANDRA GOODING	23.99	0	7228
1562	11	ACE MASKED	ADRIEN BRANDO	13.99	0	7606
1563	2	ACE MASSACRE	ADRIEN WILSON	14.99	0	7436
1564	9	ACE MASSAGE	SALLY DIETRICH	22.99	0	7064
1565	9	ACE MATRIX	KATHARINE RUSH	13.99	0	7516
1566	4	ACE MAUDE	CATE GIBSON	10.99	0	3488
1567	13	ACE MEET	JESSICA PFEIFFER	25.99	0	5179
1568	10	ACE MEMENTO	JOHN BALE	21.99	0	2919
1569	6	ACE MENAGERIE	KIRSTEN SWANK	12.99	0	1727
1570	15	ACE MERMAID	WALTER BALL	17.99	0	9621
1571	3	ACE METAL	GRACE HOPKINS	15.99	0	3902
1572	11	ACE METROPOLIS	CANDICE FISHER	11.99	0	392
1573	11	ACE MICROCOSMOS	AUDREY OLIVIER	11.99	0	3874
1574	7	ACE MIDNIGHT	EDWARD LOREN	29.99	0	7692
1575	3	ACE MIDSUMMER	RIP MCKELLEN	11.99	0	567
1576	2	ACE MIGHTY	JUDY DEAN	17.99	0	403
1577	13	ACE MILE	HALLE CRUISE	28.99	0	5017
1578	16	ACE MILLION	DANIEL WEAVER	9.99	0	4676
1579	7	ACE MINDS	ANJELICA IRONS	22.99	0	8068
1580	7	ACE MINE	JANE MCDORMAND	14.99	0	4931
1581	5	ACE MINORITY	MIRA SANDLER	26.99	0	2530
1582	14	ACE MIRACLE	JAYNE ALLEN	13.99	0	7526
1583	12	ACE MISSION	MICHAEL THERON	28.99	0	7685
1584	7	ACE MIXED	ELIZABETH FONDA	18.99	1	7215
1585	4	ACE MOB	GREG HECHE	23.99	0	732
1586	3	ACE MOCKINGBIRD	SEAN WINFREY	27.99	0	894
1587	3	ACE MOD	BRUCE MCKELLEN	21.99	0	299
1588	6	ACE MODEL	STEVE LEWIS	9.99	0	8265
1589	14	ACE MODERN	CHEVY THERON	10.99	0	1504
1590	13	ACE MONEY	LAURA LEIGH	11.99	0	2468
1591	4	ACE MONSOON	DENZEL HEPBURN	10.99	0	9987
1592	3	ACE MONSTER	MADELINE HUSTON	14.99	0	4834
1593	5	ACE MONTEREY	ANNE HAYEK	13.99	0	5517
1594	1	ACE MONTEZUMA	JAMES DREYFUSS	13.99	0	7561
1595	6	ACE MOON	GINA CAINE	28.99	0	5788
1596	3	ACE MOONSHINE	AL HUNT	17.99	0	3426
1597	7	ACE MOONWALKER	RIVER PFEIFFER	9.99	1	9001
1598	9	ACE MOSQUITO	GINA DUNST	20.99	0	7899
1599	2	ACE MOTHER	AUDREY LANSBURY	20.99	0	4197
1600	5	ACE MOTIONS	KIM BOLGER	22.99	0	8273
1601	4	ACE MOULIN	FRED DAFOE	13.99	0	8566
1602	9	ACE MOURNING	LAUREN WINSLET	17.99	1	5802
1603	5	ACE MOVIE	SEAN JOLIE	21.99	0	3951
1604	7	ACE MULAN	VIVIEN COSTNER	18.99	0	7068
1605	15	ACE MULHOLLAND	RIP ANISTON	18.99	0	8397
1606	5	ACE MUMMY	ANGELA SUVARI	21.99	0	6318
1607	7	ACE MUPPET	LISA MCGREGOR	9.99	0	6090
1608	10	ACE MURDER	BURT DUKAKIS	18.99	0	1705
1609	14	ACE MUSCLE	GREG DUNST	26.99	0	606
1610	9	ACE MUSIC	BEN MIRANDA	16.99	0	7260
1611	3	ACE MUSKETEERS	LAURA GARCIA	13.99	0	6442
1612	14	ACE MUSSOLINI	ETHAN GARLAND	18.99	0	2810
1613	2	ACE MYSTIC	LANA WILSON	12.99	0	4742
1614	6	ACE NAME	PARKER FAWCETT	23.99	0	5317
1615	13	ACE NASH	CLARK MIRANDA	26.99	0	2721
1616	9	ACE NATIONAL	MAE CLOSE	11.99	0	5715
1617	13	ACE NATURAL	TOM DAY-LEWIS	10.99	0	3132
1618	6	ACE NECKLACE	FARRAH POSEY	27.99	0	7210
1619	7	ACE NEIGHBORS	ALEC DOUGLAS	12.99	0	1518
1620	11	ACE NEMO	RENEE PENN	27.99	0	7864
1621	3	ACE NETWORK	VAL BOLGER	25.99	0	3229
1622	6	ACE NEWSIES	KENNETH ANISTON	14.99	0	2299
1623	10	ACE NEWTON	WILLIAM GUINESS	27.99	0	9079
1624	10	ACE NIGHTMARE	CLINT NICHOLSON	21.99	0	1492
1625	13	ACE NONE	SANDRA JOVOVICH	20.99	0	4138
1626	6	ACE NOON	JULIA JOHANSSON	15.99	0	7573
1627	11	ACE NORTH	PAUL MARTIN	12.99	0	8391
1628	7	ACE NORTHWEST	DREW HUDSON	17.99	0	5330
1629	5	ACE NOTORIOUS	DENNIS WALKEN	18.99	0	359
1630	10	ACE NOTTING	KATHARINE FIELD	19.99	0	9055
1631	15	ACE NOVOCAINE	HUME DEGENERES	17.99	0	6648
1632	3	ACE NUTS	EMILY COOPER	29.99	0	1434
1633	13	ACE OCTOBER	LIAM POITIER	9.99	0	9431
1634	9	ACE ODDS	SANDRA HAYEK	25.99	0	4110
1635	13	ACE OKLAHOMA	MORGAN KEATON	16.99	0	6058
1636	5	ACE OLEANDER	RUBY TYLER	22.99	0	3886
1637	6	ACE OPEN	KIM KAHN	21.99	0	9012
1638	12	ACE OPERATION	MARISA DERN	16.99	0	7775
1639	5	ACE OPPOSITE	DANIEL STALLONE	12.99	0	948
1640	9	ACE OPUS	LISA HAWN	14.99	0	6241
1641	15	ACE ORANGE	KATE ANISTON	24.99	0	8720
1642	2	ACE ORDER	HENRY WOOD	23.99	0	8534
1643	10	ACE ORIENT	CAMERON EASTWOOD	13.99	0	3982
1644	1	ACE OSCAR	ED VOIGHT	13.99	0	8567
1645	5	ACE OTHERS	EWAN MCDORMAND	28.99	0	417
1646	9	ACE OUTBREAK	ANNE RYAN	10.99	0	7300
1647	16	ACE OUTFIELD	MIRA MIRANDA	15.99	0	2925
1648	3	ACE OUTLAW	LEELEE TURNER	15.99	0	2317
1649	12	ACE OZ	CHARLIZE CAINE	28.99	0	2135
1650	13	ACE PACIFIC	ROCK MINELLI	10.99	0	7414
1651	2	ACE PACKER	KARL BLOOM	12.99	0	581
1652	15	ACE PAJAMA	MICHELLE BRIDGES	22.99	0	296
1653	15	ACE PANIC	TOM MCKELLEN	19.99	0	701
1654	12	ACE PANKY	DEBBIE MCKELLEN	27.99	0	5543
1655	2	ACE PANTHER	DANIEL GARLAND	28.99	0	7547
1656	11	ACE PAPI	RUBY LANCASTER	13.99	0	188
1657	5	ACE PARADISE	CARY MCGREGOR	29.99	0	5833
1658	1	ACE PARIS	DENZEL CLOSE	28.99	0	1512
1659	1	ACE PARK	PENELOPE HAWKE	13.99	0	3513
1660	13	ACE PARTY	MIRA HANNAH	29.99	0	1555
1661	12	ACE PAST	MILLA ASTAIRE	21.99	0	4327
1662	10	ACE PATHS	ANNETTE JOVOVICH	24.99	0	3105
1663	6	ACE PATIENT	JOAN IRONS	20.99	0	1472
1664	11	ACE PATRIOT	KIM HOFFMAN	18.99	0	8608
1665	14	ACE PATTON	ELVIS HESTON	20.99	0	6066
1666	12	ACE PAYCHECK	LUCILLE CAINE	17.99	0	8654
1667	14	ACE PEACH	HARRISON FIELD	27.99	0	8569
1668	4	ACE PEAK	GREGORY GARBO	23.99	0	7758
1669	14	ACE PEARL	DENZEL LEIGH	16.99	0	8790
1670	4	ACE PELICAN	GEOFFREY STREEP	19.99	0	7269
1671	2	ACE PERDITION	SANDRA BERGEN	24.99	0	5803
1672	10	ACE PERFECT	SIGOURNEY DUKAKIS	29.99	0	9328
1673	14	ACE PERSONAL	FAY GOODING	12.99	0	1746
1674	16	ACE PET	NICOLAS TEMPLE	12.99	0	7771
1675	1	ACE PHANTOM	LUCILLE JOHANSSON	16.99	0	66
1676	2	ACE PHILADELPHIA	BELA BRANDO	29.99	0	5399
1677	9	ACE PIANIST	ROBIN HORNE	18.99	0	139
1678	6	ACE PICKUP	HILARY DOUGLAS	22.99	0	4489
1679	14	ACE PILOT	GINA HAWN	21.99	0	5801
1680	6	ACE PINOCCHIO	BELA MIRANDA	29.99	0	798
1681	16	ACE PIRATES	DAN BRANDO	10.99	0	500
1682	10	ACE PITTSBURGH	JUDY MCCONAUGHEY	18.99	0	9539
1683	8	ACE PITY	DREW HAWN	26.99	0	6928
1684	5	ACE PIZZA	CAMERON TRACY	21.99	0	7051
1685	4	ACE PLATOON	GRETA SMITH	14.99	0	3700
1686	6	ACE PLUTO	JOE RUSH	20.99	0	5614
1687	10	ACE POCUS	CLINT HEPBURN	11.99	0	2329
1688	1	ACE POLISH	MARLENE FAWCETT	15.99	0	7246
1689	16	ACE POLLOCK	LUCILLE HEPBURN	10.99	0	1004
1690	13	ACE POND	SYLVESTER DEE	12.99	0	7229
1691	9	ACE POSEIDON	JUDE STREEP	9.99	0	3409
1692	10	ACE POTLUCK	PEARL WITHERSPOON	24.99	0	6395
1693	16	ACE POTTER	VAL CARREY	22.99	0	921
1694	6	ACE PREJUDICE	JULIANNE HAYEK	29.99	0	5668
1695	2	ACE PRESIDENT	RENEE FIELD	9.99	0	3027
1696	12	ACE PRIDE	CHARLTON WOOD	13.99	1	5446
1697	10	ACE PRIMARY	JULIETTE LAW	16.99	0	6174
1698	16	ACE PRINCESS	ORLANDO DUKAKIS	28.99	0	2010
1699	1	ACE PRIVATE	LIZA DREYFUSS	20.99	0	1357
1700	2	ACE PRIX	JEFF FREEMAN	28.99	0	9161
1701	4	ACE PSYCHO	SOPHIA BLANCHETT	16.99	0	8989
1702	15	ACE PULP	JESSICA TOMEI	18.99	0	7721
1703	2	ACE PUNK	ANNETTE DEE	26.99	0	9879
1704	1	ACE PURE	EMILY CRUZ	22.99	0	5338
1705	13	ACE PURPLE	SHIRLEY TAUTOU	13.99	0	2380
1706	3	ACE QUEEN	GINA ALLEN	10.99	0	6443
1707	16	ACE QUEST	KATE FAWCETT	17.99	0	7835
1708	4	ACE QUILLS	ALAN SINATRA	14.99	0	1878
1709	4	ACE RACER	HENRY NICHOLSON	19.99	0	1372
1710	1	ACE RAGE	ADRIEN BRIDGES	28.99	0	7966
1711	3	ACE RAGING	RICHARD JOVOVICH	19.99	0	1948
1712	3	ACE RAIDERS	JUDE KEITEL	23.99	0	2546
1713	8	ACE RAINBOW	AUDREY BULLOCK	18.99	0	7227
1714	11	ACE RANDOM	HUME MCDORMAND	9.99	0	7324
1715	3	ACE RANGE	RUBY CRAWFORD	13.99	0	2045
1716	16	ACE REAP	MINNIE DICAPRIO	25.99	0	2769
1717	16	ACE REAR	REESE THURMAN	19.99	0	7360
1718	12	ACE REBEL	SALMA ALLEN	26.99	0	2444
1719	9	ACE RECORDS	SANDRA CAMPBELL	28.99	0	9976
1720	11	ACE REDEMPTION	CHRISTOPHER GIBSON	20.99	0	2746
1721	12	ACE REDS	KATE LANCASTER	18.99	0	2930
1722	12	ACE REEF	CLARK FORD	19.99	0	7354
1723	5	ACE REIGN	NICOLE LEWIS	11.99	0	2305
1724	6	ACE REMEMBER	HARRISON WASHINGTON	13.99	0	5642
1725	4	ACE REQUIEM	TOM LANCASTER	17.99	0	5021
1726	11	ACE RESERVOIR	ANJELICA SILVERSTONE	13.99	0	4004
1727	9	ACE RESURRECTION	NICK WINFREY	23.99	0	5657
1728	7	ACE REUNION	CATE PITT	12.99	0	5320
1729	7	ACE RIDER	JIM DAY-LEWIS	25.99	0	3454
1730	6	ACE RIDGEMONT	SOPHIA NEWMAN	14.99	0	9810
1731	13	ACE RIGHT	RAY PITT	26.99	0	461
1732	4	ACE RINGS	ALAN HOPPER	29.99	0	5098
1733	9	ACE RIVER	ELIZABETH LAW	23.99	0	1133
1734	4	ACE ROAD	GOLDIE BRODY	23.99	0	7825
1735	1	ACE ROBBERS	JEREMY DEAN	28.99	0	5252
1736	15	ACE ROBBERY	EMILY DIETRICH	23.99	0	2217
1737	12	ACE ROCK	MEL FISHER	24.99	0	8229
1738	5	ACE ROCKETEER	HELEN SMITH	19.99	0	1100
1739	11	ACE ROCKY	DREW OLIVIER	29.99	0	1241
1740	12	ACE ROLLERCOASTER	GRETA GOLDBERG	13.99	0	8484
1741	12	ACE ROMAN	CARMEN CROWE	29.99	0	2200
1742	4	ACE ROOF	KENNETH MARX	27.99	0	8397
1743	12	ACE ROOM	MARY MCDORMAND	11.99	0	1566
1744	4	ACE ROOTS	RUSSELL RICKMAN	18.99	0	2160
1745	10	ACE ROSES	LEELEE HURT	28.99	0	8867
1746	13	ACE ROUGE	AUDREY HARRIS	27.99	0	9495
1747	2	ACE ROXANNE	KIM MATTHAU	22.99	0	9198
1748	8	ACE RUGRATS	KATHARINE DEAN	12.99	0	6840
1749	6	ACE RULES	JENNIFER KINNEAR	12.99	0	1855
1750	7	ACE RUN	MARY LANSBURY	29.99	0	3432
1751	14	ACE RUNAWAY	NICOLE DENCH	28.99	0	1476
1752	15	ACE RUNNER	ORLANDO DEGENERES	18.99	0	2720
1753	6	ACE RUSH	JUDE GOODING	28.99	0	8315
1754	10	ACE RUSHMORE	HARRISON SWANK	9.99	0	3619
1755	4	ACE SABRINA	SUSAN HANNAH	27.99	0	3914
1756	4	ACE SADDLE	MADELINE DENCH	29.99	0	7607
1757	3	ACE SAGEBRUSH	ZERO BENING	27.99	0	8866
1758	3	ACE SAINTS	ETHAN TAYLOR	23.99	0	8130
1759	8	ACE SALUTE	MATT GIBSON	27.99	0	6901
1760	4	ACE SAMURAI	BOB MIRANDA	12.99	0	4722
1761	9	ACE SANTA	MINNIE RUSH	12.99	0	8918
1762	15	ACE SASSY	WALTER TRACY	28.99	0	4649
1763	14	ACE SATISFACTION	GRACE WILLIS	10.99	0	1190
1764	15	ACE SATURDAY	JOHNNY CAGE	21.99	0	9106
1765	5	ACE SATURN	KIM DENCH	16.99	0	1028
1766	14	ACE SAVANNAH	SHIRLEY WATSON	20.99	0	6504
1767	7	ACE SCALAWAG	KEVIN BASINGER	17.99	0	3466
1768	14	ACE SCARFACE	GARY SARANDON	13.99	0	9411
1769	5	ACE SCHOOL	AUDREY SANDLER	25.99	0	761
1770	12	ACE SCISSORHANDS	GEOFFREY MCQUEEN	14.99	1	7097
1771	7	ACE SCORPION	MARISA SMITH	14.99	0	7619
1772	15	ACE SEA	RIP RYDER	18.99	0	7992
1773	13	ACE SEABISCUIT	LEONARDO BALL	11.99	0	5020
1774	1	ACE SEARCHERS	FRED KINNEAR	11.99	0	6774
1775	4	ACE SEATTLE	GENE BENING	19.99	0	3073
1776	4	ACE SECRET	CARRIE PECK	27.99	0	4913
1777	11	ACE SECRETARY	FAY THERON	18.99	0	4737
1778	5	ACE SECRETS	JUDY CARREY	27.99	0	7468
1779	6	ACE SENSE	FRANCES FINNEY	22.99	0	6379
1780	6	ACE SENSIBILITY	MICHAEL MOORE	22.99	0	335
1781	16	ACE SEVEN	NICOLAS HAWKE	10.99	0	7143
1782	10	ACE SHAKESPEARE	LEELEE WASHINGTON	27.99	0	9354
1783	6	ACE SHANE	BEN MINELLI	27.99	0	3489
1784	10	ACE SHANGHAI	MATTHEW TANDY	27.99	0	1254
1785	9	ACE SHAWSHANK	PENELOPE TAUTOU	13.99	0	9653
1786	5	ACE SHEPHERD	HARVEY IRONS	9.99	0	6703
1787	12	ACE SHINING	LEONARDO CHASE	15.99	0	9915
1788	5	ACE SHIP	MADELINE GIBSON	16.99	0	1342
1789	11	ACE SHOCK	ZERO SORVINO	16.99	0	5211
1790	8	ACE SHOOTIST	HENRY DIAZ	14.99	0	9100
1791	4	ACE SHOW	HILARY REYNOLDS	21.99	0	9712
1792	5	ACE SHREK	CARRIE JACKMAN	27.99	0	1583
1793	15	ACE SHRUNK	KARL BERGEN	19.99	0	7605
1794	11	ACE SIDE	LEELEE BLANCHETT	22.99	0	3248
1795	3	ACE SIEGE	LAURENCE WASHINGTON	20.99	0	825
1796	8	ACE SIERRA	ROSIE HEPBURN	26.99	0	6128
1797	14	ACE SILENCE	BURT FINNEY	29.99	0	9187
1798	2	ACE SILVERADO	WILLIAM BLANCHETT	22.99	0	3875
1799	7	ACE SIMON	JODIE DEGENERES	29.99	0	9240
1800	6	ACE SINNERS	RUSSELL BALE	28.99	0	536
1801	16	ACE SISTER	JOHN BARRYMORE	26.99	0	5283
1802	8	ACE SKY	RUSSELL PESCI	20.99	0	621
1803	8	ACE SLACKER	CHARLIZE RUSSELL	18.99	0	7434
1804	14	ACE SLEEPING	WILLIAM SORVINO	15.99	0	8617
1805	4	ACE SLEEPLESS	SOPHIA CHASE	11.99	0	4887
1806	3	ACE SLEEPY	KARL BEATTY	22.99	0	4333
1807	3	ACE SLEUTH	CHEVY FOSTER	9.99	0	8334
1808	2	ACE SLING	LIZA GIBSON	13.99	0	541
1809	16	ACE SLIPPER	SIDNEY NEWMAN	29.99	1	7216
1810	14	ACE SLUMS	SEAN DENCH	24.99	0	9430
1811	4	ACE SMILE	ADAM JOHANSSON	24.99	0	8956
1812	3	ACE SMOKING	DUSTIN EASTWOOD	15.99	0	1352
1813	3	ACE SMOOCHY	JUDI HARRIS	25.99	0	3343
1814	14	ACE SNATCH	ADRIEN MATTHAU	24.99	0	39
1815	8	ACE SNATCHERS	EDWARD GRANT	15.99	0	5877
1816	5	ACE SNOWMAN	BEN FIELD	14.99	0	2199
1817	3	ACE SOLDIERS	JULIANNE DEAN	17.99	0	8473
1818	9	ACE SOMETHING	ELIZABETH PFEIFFER	10.99	0	8905
1819	7	ACE SONG	JUDE GARBO	17.99	0	680
1820	7	ACE SONS	JENNIFER KILMER	22.99	0	5574
1821	4	ACE SORORITY	SANDRA CAINE	15.99	0	9239
1822	9	ACE SOUP	CHARLTON LOREN	10.99	0	7150
1823	15	ACE SOUTH	JAYNE KELLY	12.99	0	9555
1824	1	ACE SPARTACUS	GENE WILLIAMS	20.99	0	3969
1825	10	ACE SPEAKEASY	TIM PITT	10.99	0	8011
1826	11	ACE SPEED	TOM MATTHAU	19.99	0	3513
1827	7	ACE SPICE	TIM HOPKINS	21.99	0	9195
1828	5	ACE SPIKING	JEFF HARRIS	24.99	0	266
1829	11	ACE SPINAL	WINONA MATTHAU	29.99	0	3362
1830	7	ACE SPIRIT	BEN ROBBINS	15.99	0	4639
1831	3	ACE SPIRITED	AUDREY HUDSON	10.99	0	9969
1832	7	ACE SPLASH	JENNIFER GOLDBERG	16.99	0	9578
1833	5	ACE SPLENDOR	HALLE DEGENERES	24.99	0	9323
1834	12	ACE SPOILERS	KATHARINE MONROE	24.99	0	7010
1835	2	ACE SPY	JOAN BALE	12.99	0	3140
1836	10	ACE SQUAD	PEARL JACKMAN	23.99	0	7402
1837	11	ACE STAGE	CANDICE WINSLET	11.99	0	705
1838	2	ACE STAGECOACH	GARY MANSFIELD	18.99	0	2758
1839	7	ACE STALLION	THORA BENING	28.99	0	5730
1840	11	ACE STAMPEDE	LISA SWANK	11.99	0	9753
1841	7	ACE STAR	JIM MCCONAUGHEY	13.99	0	258
1842	16	ACE STATE	ADAM WOOD	10.99	0	3298
1843	3	ACE STEEL	THORA DAVIS	18.99	0	2417
1844	12	ACE STEERS	FRED BENING	22.99	1	941
1845	4	ACE STEPMOM	VIVIEN MCGREGOR	26.99	0	9609
1846	13	ACE STING	LAURA CHASE	14.99	0	8850
1847	5	ACE STOCK	SCARLETT EASTWOOD	15.99	0	9945
1848	11	ACE STONE	DEBBIE JACKMAN	20.99	0	8772
1849	13	ACE STORM	TOM MIRANDA	11.99	0	9321
1850	4	ACE STORY	KIRK JOVOVICH	12.99	0	2972
1851	2	ACE STRAIGHT	JEREMY CAINE	23.99	0	8154
1852	10	ACE STRANGELOVE	CANDICE OLIVIER	18.99	1	4791
1853	8	ACE STRANGER	WILL MCDORMAND	22.99	0	9062
1854	9	ACE STRANGERS	KIM WINFREY	18.99	0	8476
1855	7	ACE STREAK	GRETA DERN	28.99	0	6889
1856	4	ACE STREETCAR	RIVER JOVOVICH	23.99	0	2284
1857	9	ACE STRICTLY	THORA REYNOLDS	22.99	0	9225
1858	2	ACE SUBMARINE	KATHARINE MIRANDA	10.99	0	7207
1859	16	ACE SUGAR	MERYL SILVERSTONE	20.99	0	7588
1860	7	ACE SUICIDES	ALAN MOSTEL	24.99	0	4205
1861	8	ACE SUIT	THORA TANDY	14.99	0	1229
1862	8	ACE SUMMER	SIDNEY BLANCHETT	17.99	0	942
1863	6	ACE SUN	NICK STALLONE	27.99	0	288
1864	10	ACE SUNDANCE	ROCK WALKEN	15.99	0	1105
1865	1	ACE SUNRISE	PAUL TAYLOR	10.99	0	3869
1866	8	ACE SUNSET	ELIZABETH BERGEN	17.99	0	8191
1867	9	ACE SUPER	SPENCER SOBIESKI	18.99	0	6338
1868	9	ACE SUPERFLY	JODIE MALDEN	14.99	0	4065
1869	5	ACE SUSPECTS	GOLDIE BLOOM	11.99	0	8079
1870	4	ACE SWARM	MEL HOPKINS	9.99	0	3084
1871	7	ACE SWEDEN	HARVEY ASTAIRE	22.99	0	7111
1872	8	ACE SWEET	KATE ZELLWEGER	17.99	0	7896
1873	1	ACE SWEETHEARTS	HELEN WILLIS	19.99	0	8649
1874	15	ACE TADPOLE	WALTER KIDMAN	13.99	0	3476
1875	1	ACE TALENTED	REESE VOIGHT	24.99	0	3253
1876	1	ACE TARZAN	GREGORY FOSTER	17.99	0	7990
1877	2	ACE TAXI	REESE HURT	22.99	0	2315
1878	8	ACE TEEN	DANIEL THERON	26.99	0	4280
1879	12	ACE TELEGRAPH	WALTER DOUGLAS	22.99	0	6268
1880	16	ACE TELEMARK	KATHARINE LANCASTER	25.99	0	4803
1881	2	ACE TEMPLE	RIVER FAWCETT	18.99	0	8277
1882	5	ACE TENENBAUMS	GARY SORVINO	10.99	0	1723
1883	5	ACE TEQUILA	ANNE WATSON	19.99	0	4341
1884	15	ACE TERMINATOR	MINNIE HORNE	27.99	0	2254
1885	9	ACE TEXAS	PEARL BRIDGES	10.99	0	536
1886	9	ACE THEORY	GROUCHO BALE	16.99	0	733
1887	3	ACE THIEF	SPENCER ROBERTS	19.99	0	3960
1888	11	ACE THIN	GOLDIE CARREY	24.99	0	1037
1889	3	ACE TIES	KIRSTEN LAW	27.99	0	6853
1890	2	ACE TIGHTS	RENEE WEST	27.99	0	7141
1891	15	ACE TIMBERLAND	NICOLE KIDMAN	14.99	0	2573
1892	6	ACE TITANIC	ANDY BERGMAN	14.99	0	8817
1893	11	ACE TITANS	ALEC DEAN	29.99	0	6680
1894	2	ACE TOMATOES	DREW BOLGER	22.99	0	6756
1895	6	ACE TOMORROW	LUCILLE BENING	12.99	0	6313
1896	14	ACE TOOTSIE	CHRISTIAN SWANK	21.99	0	570
1897	14	ACE TORQUE	CARY JOHANSSON	28.99	0	6980
1898	13	ACE TOURIST	THORA HAWN	26.99	0	8770
1899	8	ACE TOWERS	WILLEM JOLIE	24.99	0	9494
1900	7	ACE TOWN	AL KEATON	9.99	0	9431
1901	11	ACE TRACY	REESE KILMER	26.99	0	9384
1902	14	ACE TRADING	JAMES ASTAIRE	9.99	0	1926
1903	12	ACE TRAFFIC	LIAM PENN	22.99	0	175
1904	9	ACE TRAIN	JULIANNE ASTAIRE	19.99	0	6921
1905	7	ACE TRAINSPOTTING	DENNIS BULLOCK	18.99	0	8826
1906	7	ACE TRAMP	INGRID RYDER	12.99	0	5691
1907	3	ACE TRANSLATION	LEELEE IRONS	20.99	0	5219
1908	13	ACE TRAP	ED CRUZ	16.99	0	7768
1909	7	ACE TREASURE	REESE FONDA	27.99	0	5328
1910	10	ACE TREATMENT	MARLON DERN	25.99	0	8063
1911	12	ACE TRIP	LEONARDO BOGART	11.99	0	2164
1912	11	ACE TROJAN	MICHELLE HAWN	14.99	0	1952
1913	13	ACE TROOPERS	HILARY PINKETT	9.99	0	2169
1914	13	ACE TROUBLE	KEVIN HUSTON	21.99	0	3734
1915	3	ACE TRUMAN	MADELINE WITHERSPOON	25.99	0	3400
1916	10	ACE TURN	JANE HURT	13.99	0	7272
1917	7	ACE TUXEDO	CHARLES DICAPRIO	11.99	0	1248
1918	6	ACE TWISTED	SALMA FISHER	23.99	0	9607
1919	15	ACE TYCOON	JAYNE COOPER	19.99	0	8280
1920	14	ACE UNBREAKABLE	RICHARD TYLER	19.99	0	5991
1921	14	ACE UNCUT	BELA FIENNES	14.99	0	6677
1922	16	ACE UNDEFEATED	TIM WEST	11.99	0	4706
1923	5	ACE UNFAITHFUL	REESE HANNAH	11.99	0	1588
1924	2	ACE UNFORGIVEN	GLENN BARRYMORE	20.99	0	1043
1925	6	ACE UNITED	ALAN GOODING	12.99	0	7329
1926	13	ACE UNTOUCHABLES	ANJELICA OLIVIER	26.99	0	5791
1927	9	ACE UPRISING	KARL WILLIAMS	18.99	0	6104
1928	15	ACE UPTOWN	AL GABLE	23.99	0	1282
1929	14	ACE USUAL	CHRISTOPHER LAW	13.99	0	7010
1930	5	ACE VACATION	BEN HOFFMAN	15.99	0	9521
1931	1	ACE VALENTINE	MARISA GARLAND	11.99	0	6110
1932	11	ACE VALLEY	KIRSTEN PENN	13.99	0	6590
1933	14	ACE VAMPIRE	AL BERGMAN	26.99	0	4916
1934	16	ACE VANILLA	ANJELICA MOORE	11.99	0	1397
1935	14	ACE VANISHED	LAUREN CHASE	28.99	0	1845
1936	15	ACE VANISHING	KEVIN KILMER	20.99	0	7591
1937	3	ACE VARSITY	JODIE FONDA	23.99	0	6364
1938	6	ACE VELVET	MINNIE GOLDBERG	16.99	0	4966
1939	14	ACE VERTIGO	CHARLTON CRONYN	28.99	0	100
1940	1	ACE VICTORY	CHRISTIAN COOPER	22.99	0	6523
1941	14	ACE VIDEOTAPE	DAN WINFREY	16.99	0	8356
1942	3	ACE VIETNAM	CHRISTIAN MCQUEEN	21.99	0	7161
1943	4	ACE VILLAIN	BOB PACINO	29.99	0	3086
1944	8	ACE VIRGIN	JOHNNY WEAVER	21.99	0	8197
1945	10	ACE VIRGINIAN	WINONA WALKEN	25.99	0	845
1946	8	ACE VIRTUAL	ANNE HACKMAN	22.99	0	5574
1947	8	ACE VISION	DAN TURNER	22.99	0	5354
1948	6	ACE VOICE	DUSTIN RICKMAN	18.99	0	3188
1949	13	ACE VOLCANO	EMILY CRAWFORD	14.99	0	1353
1950	2	ACE VOLUME	ANNETTE HARRIS	10.99	0	6341
1951	3	ACE VOYAGE	ALEC MCKELLEN	13.99	0	8005
1952	13	ACE WAGON	MILLA PHOENIX	28.99	0	2255
1953	8	ACE WAIT	WOODY PECK	24.99	0	7157
1954	1	ACE WAKE	SIGOURNEY TURNER	15.99	0	6821
1955	8	ACE WALLS	BETTE DAVIS	19.99	0	2815
1956	3	ACE WANDA	SUSAN HANNAH	12.99	0	1803
1957	16	ACE WAR	STEVE FREEMAN	23.99	0	2755
1958	15	ACE WARDROBE	WINONA ROBBINS	27.99	0	1446
1959	10	ACE WARLOCK	ANJELICA KIDMAN	19.99	0	1993
1960	3	ACE WARS	IAN DREYFUSS	14.99	0	6751
1961	9	ACE WASH	BELA WAHLBERG	18.99	0	6703
1962	11	ACE WASTELAND	ALAN BENING	20.99	0	3090
1963	14	ACE WATCH	BEN MINELLI	26.99	0	5774
1964	16	ACE WATERFRONT	CAMERON CAMPBELL	9.99	0	9503
1965	4	ACE WATERSHIP	DREW SORVINO	22.99	0	162
1966	5	ACE WEDDING	UMA MOORE	17.99	0	344
1967	1	ACE WEEKEND	BRAD ROBERTS	10.99	0	8351
1968	7	ACE WEREWOLF	JODIE CRAWFORD	18.99	0	81
1969	1	ACE WEST	CHARLIZE WINSLET	12.99	1	7952
1970	2	ACE WESTWARD	LUCILLE DAY	15.99	0	7300
1971	6	ACE WHALE	HENRY CHAPLIN	15.99	0	5179
1972	6	ACE WHISPERER	FRANK LUGOSI	17.99	0	6387
1973	5	ACE WIFE	RITA BAILEY	24.99	0	8213
1974	12	ACE WILD	REESE KIDMAN	27.99	0	7925
1975	11	ACE WILLOW	ADRIEN RUSH	15.99	0	8565
1976	1	ACE WIND	AL HOPPER	17.99	0	5465
1977	16	ACE WINDOW	CARY BERGEN	14.99	0	7913
1978	15	ACE WISDOM	ROBERT PINKETT	23.99	0	3209
1979	9	ACE WITCHES	RUSSELL DAFOE	15.99	0	5359
1980	2	ACE WIZARD	GEOFFREY RICKMAN	11.99	0	4279
1981	16	ACE WOLVES	SHIRLEY BRANDO	29.99	0	6285
1982	9	ACE WOMEN	MERYL HUSTON	22.99	0	1768
1983	8	ACE WON	STEVE MARTIN	14.99	0	3773
1984	10	ACE WONDERFUL	LAURA SINATRA	18.99	0	6641
1985	16	ACE WONDERLAND	JAMES DEGENERES	15.99	0	5063
1986	12	ACE WONKA	LIV FINNEY	22.99	0	1553
1987	4	ACE WORDS	MAE SORVINO	28.99	0	3581
1988	2	ACE WORKER	WALTER WEST	9.99	0	2574
1989	7	ACE WORKING	AUDREY SORVINO	29.99	0	2026
1990	11	ACE WORLD	JANE DOUGLAS	10.99	0	7900
1991	10	ACE WORST	CAMERON FINNEY	13.99	0	4181
1992	6	ACE WRATH	ELIZABETH CROWE	29.99	0	7483
1993	6	ACE WRONG	MICHAEL DEPP	15.99	0	9302
1994	10	ACE WYOMING	ORLANDO ODONNELL	22.99	0	484
1995	14	ACE YENTL	GLENN FISHER	15.99	0	9101
1996	2	ACE YOUNG	DREW ZELLWEGER	12.99	0	1704
1997	10	ACE YOUTH	GROUCHO LEIGH	27.99	0	4904
1998	10	ACE ZHIVAGO	NICOLAS WAHLBERG	15.99	0	225
1999	4	ACE ZOOLANDER	MINNIE SILVERSTONE	29.99	0	3917
2000	1	ACE ZORRO	MORGAN FAWCETT	16.99	0	1319
2001	5	ADAPTATION ACADEMY	CARY NEESON	19.99	0	3385
2002	11	ADAPTATION ACE	SPENCER HUDSON	9.99	0	4735
2003	9	ADAPTATION ADAPTATION	HUGH WATSON	14.99	0	6345
2004	5	ADAPTATION AFFAIR	JEFF HURT	9.99	0	9026
2005	7	ADAPTATION AFRICAN	DEBBIE KELLY	11.99	0	8005
2006	5	ADAPTATION AGENT	JIM CRONYN	17.99	0	3295
2007	12	ADAPTATION AIRPLANE	REESE GOLDBERG	22.99	0	1243
2008	2	ADAPTATION AIRPORT	ANNE WEST	19.99	0	3019
2009	3	ADAPTATION ALABAMA	PENELOPE KEITEL	21.99	0	2606
2010	8	ADAPTATION ALADDIN	RALPH WATSON	23.99	0	6866
2011	8	ADAPTATION ALAMO	SANDRA FIELD	29.99	0	5644
2012	5	ADAPTATION ALASKA	UMA HAWN	10.99	0	3651
2013	4	ADAPTATION ALI	GEOFFREY CHAPLIN	14.99	0	5482
2014	10	ADAPTATION ALICE	AUDREY RYAN	16.99	0	6064
2015	10	ADAPTATION ALIEN	KATHARINE SUVARI	17.99	0	5986
2016	2	ADAPTATION ALLEY	SPENCER BALE	29.99	1	6052
2017	9	ADAPTATION ALONE	ALEC DRIVER	18.99	0	758
2018	14	ADAPTATION ALTER	DREW LUGOSI	12.99	0	8860
2019	12	ADAPTATION AMADEUS	MEG HEPBURN	25.99	0	467
2020	7	ADAPTATION AMELIE	SOPHIA HANNAH	28.99	0	4447
2021	9	ADAPTATION AMERICAN	JOE TOMEI	17.99	0	4779
2022	1	ADAPTATION AMISTAD	PARKER GOLDBERG	10.99	0	1418
2023	3	ADAPTATION ANACONDA	NATALIE NEWMAN	16.99	0	5888
2024	4	ADAPTATION ANALYZE	ALBERT KEITEL	28.99	0	8088
2025	16	ADAPTATION ANGELS	DENNIS NEWMAN	27.99	0	175
2026	6	ADAPTATION ANNIE	STEVE BRANAGH	25.99	0	7652
2027	5	ADAPTATION ANONYMOUS	CHARLES LEIGH	9.99	0	9816
2028	3	ADAPTATION ANTHEM	MARLENE PRESLEY	28.99	0	4760
2029	9	ADAPTATION ANTITRUST	ZERO GARLAND	19.99	0	2899
2030	6	ADAPTATION ANYTHING	WARREN DICAPRIO	20.99	0	5497
2031	9	ADAPTATION APACHE	MARLON HOPPER	18.99	0	1909
2032	4	ADAPTATION APOCALYPSE	OPRAH KIDMAN	16.99	0	3803
2033	6	ADAPTATION APOLLO	CATE PRESLEY	9.99	0	2561
2034	8	ADAPTATION ARABIA	LUCILLE COOPER	19.99	0	9201
2035	13	ADAPTATION ARACHNOPHOBIA	CUBA ASTAIRE	24.99	0	3269
2036	5	ADAPTATION ARGONAUTS	PENELOPE BULLOCK	28.99	0	385
2037	3	ADAPTATION ARIZONA	KIRSTEN STALLONE	27.99	0	1408
2038	5	ADAPTATION ARK	SISSY LOREN	17.99	0	5644
2039	11	ADAPTATION ARMAGEDDON	NEVE BIRCH	15.99	0	4273
2040	4	ADAPTATION ARMY	JENNIFER FREEMAN	17.99	0	203
2041	12	ADAPTATION ARSENIC	CHARLIZE GIBSON	19.99	0	7523
2042	9	ADAPTATION ARTIST	LEELEE HOPKINS	11.99	0	8137
2043	5	ADAPTATION ATLANTIS	HILARY MCCONAUGHEY	12.99	0	9892
2044	12	ADAPTATION ATTACKS	AUDREY NORTON	18.99	0	6457
2045	15	ADAPTATION ATTRACTION	WOODY CROWE	15.99	0	809
2046	6	ADAPTATION AUTUMN	JENNIFER FAWCETT	19.99	0	7709
2047	5	ADAPTATION BABY	DIANE GARCIA	26.99	0	5655
2048	11	ADAPTATION BACKLASH	CLINT PHOENIX	10.99	0	2038
2049	1	ADAPTATION BADMAN	SIGOURNEY MANSFIELD	11.99	0	8691
2050	13	ADAPTATION BAKED	ANNE WALKEN	24.99	0	6404
2051	14	ADAPTATION BALLOON	VAL MARTIN	15.99	0	7638
2052	1	ADAPTATION BALLROOM	CARRIE GARBO	14.99	0	6011
2053	14	ADAPTATION BANG	GOLDIE SWANK	9.99	0	2153
2054	4	ADAPTATION BANGER	RIP WEST	11.99	0	8625
2055	16	ADAPTATION BARBARELLA	RALPH SORVINO	10.99	0	436
2056	12	ADAPTATION BAREFOOT	MARISA HAYEK	22.99	0	7522
2057	7	ADAPTATION BASIC	BURT ROBERTS	20.99	0	3077
2058	3	ADAPTATION BEACH	CHRISTIAN TYLER	18.99	0	781
2059	11	ADAPTATION BEAR	ALICIA CRAWFORD	19.99	0	1017
2060	6	ADAPTATION BEAST	TIM DUNST	11.99	0	5206
2061	3	ADAPTATION BEAUTY	VAL BALE	26.99	0	6614
2062	10	ADAPTATION BED	JANE BIRCH	23.99	0	5017
2063	1	ADAPTATION BEDAZZLED	IAN PINKETT	12.99	0	3564
2064	4	ADAPTATION BEETHOVEN	KARL TEMPLE	14.99	0	8351
2065	7	ADAPTATION BEHAVIOR	CARY PESCI	15.99	0	4794
2066	14	ADAPTATION BENEATH	JULIA BARRYMORE	25.99	0	1967
2067	8	ADAPTATION BERETS	EWAN HUDSON	27.99	0	8886
2068	7	ADAPTATION BETRAYED	LUCILLE CLOSE	25.99	0	8294
2069	3	ADAPTATION BEVERLY	MILLA LOLLOBRIGIDA	23.99	0	772
2070	9	ADAPTATION BIKINI	REESE DEE	22.99	0	6646
2071	3	ADAPTATION BILKO	MINNIE GOLDBERG	22.99	0	5982
2072	14	ADAPTATION BILL	ANTHONY MALDEN	11.99	0	2305
2073	1	ADAPTATION BINGO	HILARY SUVARI	22.99	0	7251
2074	8	ADAPTATION BIRCH	FRED RYDER	12.99	0	1549
2075	5	ADAPTATION BIRD	HENRY ZELLWEGER	10.99	0	9316
2076	12	ADAPTATION BIRDCAGE	GARY ROBERTS	18.99	0	4629
2077	1	ADAPTATION BIRDS	ANNE DICAPRIO	11.99	0	5287
2078	6	ADAPTATION BLACKOUT	HELEN HANNAH	24.99	0	272
2079	8	ADAPTATION BLADE	RIVER KAHN	24.99	0	3038
2080	15	ADAPTATION BLANKET	FRED WAYNE	15.99	1	9504
2081	4	ADAPTATION BLINDNESS	NATALIE PECK	20.99	0	1536
2082	16	ADAPTATION BLOOD	JACK CRAWFORD	10.99	0	8157
2083	10	ADAPTATION BLUES	DENZEL MARTIN	29.99	0	2623
2084	16	ADAPTATION BOILED	PAUL ROBBINS	26.99	0	4617
2085	2	ADAPTATION BONNIE	HUME HECHE	17.99	0	3977
2086	6	ADAPTATION BOOGIE	CAMERON WAYNE	10.99	0	2553
2087	4	ADAPTATION BOONDOCK	JAMES HUDSON	23.99	0	7047
2088	8	ADAPTATION BORN	GARY BOGART	23.99	0	6327
2089	16	ADAPTATION BORROWERS	HUMPHREY BALL	24.99	0	9286
2090	4	ADAPTATION BOULEVARD	GROUCHO WILSON	21.99	0	731
2091	1	ADAPTATION BOUND	AL POSEY	11.99	0	4857
2092	6	ADAPTATION BOWFINGER	VIVIEN BLOOM	25.99	0	4675
2093	9	ADAPTATION BRANNIGAN	KIRK DEPP	26.99	0	6174
2094	8	ADAPTATION BRAVEHEART	MARLON WALKEN	26.99	0	5120
2095	13	ADAPTATION BREAKFAST	JODIE TEMPLE	11.99	0	8631
2096	4	ADAPTATION BREAKING	LISA IRONS	13.99	0	4599
2097	12	ADAPTATION BRIDE	KEVIN WINSLET	22.99	0	3209
2098	3	ADAPTATION BRIGHT	LANA DREYFUSS	23.99	0	5354
2099	5	ADAPTATION BRINGING	JIM KINNEAR	29.99	0	1378
2100	8	ADAPTATION BROOKLYN	AL CRAWFORD	29.99	0	4992
2101	14	ADAPTATION BROTHERHOOD	WINONA KEITEL	18.99	0	5938
2102	15	ADAPTATION BUBBLE	KIRSTEN HOPKINS	18.99	0	3467
2103	13	ADAPTATION BUCKET	MADELINE DEGENERES	16.99	0	7272
2104	15	ADAPTATION BUGSY	ETHAN DEGENERES	16.99	0	6658
2105	8	ADAPTATION BULL	ROSIE NOLTE	19.99	0	1538
2106	16	ADAPTATION BULWORTH	MATTHEW HOPPER	29.99	0	4183
2107	10	ADAPTATION BUNCH	SCARLETT RUSSELL	12.99	0	9825
2108	8	ADAPTATION BUTCH	DIANE AFFLECK	11.99	0	1507
2109	14	ADAPTATION BUTTERFLY	HENRY DEAN	11.99	0	5892
2110	13	ADAPTATION CABIN	EMILY BEATTY	22.99	0	9079
2111	13	ADAPTATION CADDYSHACK	HALLE KUDROW	18.99	0	2592
2112	15	ADAPTATION CALENDAR	ANGELINA BRANDO	24.99	0	2817
2113	12	ADAPTATION CALIFORNIA	FAY POSEY	28.99	0	6355
2114	2	ADAPTATION CAMELOT	SALMA PHOENIX	19.99	0	4369
2115	2	ADAPTATION CAMPUS	JOHNNY MINELLI	16.99	0	444
2116	5	ADAPTATION CANDIDATE	LEELEE BEATTY	22.99	0	1265
2117	15	ADAPTATION CANDLES	DUSTIN GUINESS	28.99	0	4989
2118	4	ADAPTATION CANYON	ELIZABETH TAUTOU	19.99	0	1337
2119	3	ADAPTATION CAPER	SANDRA WAHLBERG	29.99	0	7197
2120	7	ADAPTATION CARIBBEAN	GWYNETH IRONS	28.99	0	6346
2121	16	ADAPTATION CAROL	MERYL BLOOM	20.99	0	2055
2122	11	ADAPTATION CARRIE	LENA MALDEN	28.99	0	7353
2123	7	ADAPTATION CASABLANCA	LEONARDO PFEIFFER	23.99	0	4226
2124	13	ADAPTATION CASPER	GREG GABLE	23.99	0	7533
2125	7	ADAPTATION CASSIDY	ED RUSH	24.99	0	755
2126	7	ADAPTATION CASUALTIES	CHRISTIAN NEWMAN	10.99	0	8779
2127	5	ADAPTATION CAT	JOAN WAHLBERG	27.99	0	9909
2128	10	ADAPTATION CATCH	MIRA DIETRICH	13.99	0	9437
2129	11	ADAPTATION CAUSE	FRANK REYNOLDS	29.99	0	6483
2130	12	ADAPTATION CELEBRITY	JADA SPACEK	29.99	0	1340
2131	1	ADAPTATION CENTER	RICHARD WRAY	13.99	0	400
2132	2	ADAPTATION CHAINSAW	WARREN GARLAND	21.99	0	8071
2133	10	ADAPTATION CHAMBER	BELA TAYLOR	14.99	0	282
2134	4	ADAPTATION CHAMPION	RAY POITIER	20.99	0	2301
2135	3	ADAPTATION CHANCE	ANTHONY HUSTON	21.99	0	6638
2136	12	ADAPTATION CHAPLIN	MARLENE KIDMAN	20.99	0	7297
2137	10	ADAPTATION CHARADE	BRAD TANDY	20.99	0	3476
2138	6	ADAPTATION CHARIOTS	DIANE AFFLECK	18.99	0	3222
2139	8	ADAPTATION CHASING	AUDREY KEATON	14.99	0	8097
2140	8	ADAPTATION CHEAPER	FRANCES DAY-LEWIS	20.99	0	7636
2141	4	ADAPTATION CHICAGO	FRANCES LEIGH	27.99	0	511
2142	10	ADAPTATION CHICKEN	STEVE OLIVIER	23.99	0	3492
2143	1	ADAPTATION CHILL	GRETA MANSFIELD	14.99	0	6401
2144	10	ADAPTATION CHINATOWN	CHEVY IRONS	22.99	0	2029
2145	8	ADAPTATION CHISUM	JACK DAY	24.99	0	2512
2146	9	ADAPTATION CHITTY	RITA WINSLET	26.99	0	9292
2147	14	ADAPTATION CHOCOLAT	LUCILLE HESTON	25.99	0	8708
2148	3	ADAPTATION CHOCOLATE	JIM CLOSE	19.99	0	4969
2149	2	ADAPTATION CHRISTMAS	WINONA AKROYD	14.99	0	7242
2150	8	ADAPTATION CIDER	UMA BRODY	27.99	0	7089
2151	3	ADAPTATION CINCINATTI	MENA HACKMAN	29.99	0	5280
2152	15	ADAPTATION CIRCUS	WHOOPI BERGMAN	20.99	0	924
2153	7	ADAPTATION CITIZEN	ELLEN WINSLET	27.99	0	6822
2154	6	ADAPTATION CLASH	MENA LEWIS	16.99	0	3481
2155	2	ADAPTATION CLEOPATRA	JIM FISHER	9.99	0	3457
2156	12	ADAPTATION CLERKS	NICOLAS GOODING	17.99	0	9512
2157	16	ADAPTATION CLOCKWORK	ALEC DERN	27.99	0	8761
2158	16	ADAPTATION CLONES	RUSSELL CRONYN	14.99	0	3084
2159	15	ADAPTATION CLOSER	SHIRLEY HARRIS	22.99	0	7305
2160	16	ADAPTATION CLUB	ANNE SOBIESKI	18.99	0	2877
2161	13	ADAPTATION CLUE	MATTHEW LEIGH	20.99	0	265
2162	8	ADAPTATION CLUELESS	FARRAH VOIGHT	19.99	0	644
2163	7	ADAPTATION CLYDE	ED SILVERSTONE	13.99	0	2911
2164	9	ADAPTATION COAST	MICHELLE AFFLECK	17.99	0	4575
2165	3	ADAPTATION COLDBLOODED	FAY MANSFIELD	13.99	0	1322
2166	8	ADAPTATION COLOR	MICHELLE SOBIESKI	12.99	0	6803
2167	4	ADAPTATION COMA	LENA SORVINO	19.99	0	4165
2168	9	ADAPTATION COMANCHEROS	DREW PENN	25.99	0	2988
2169	2	ADAPTATION COMFORTS	FRED JACKMAN	25.99	0	9273
2170	4	ADAPTATION COMMAND	JULIETTE BERGMAN	20.99	0	5643
2171	11	ADAPTATION COMMANDMENTS	HENRY RUSH	16.99	0	7434
2172	1	ADAPTATION CONEHEADS	LAURA CHAPLIN	22.99	0	9142
2173	1	ADAPTATION CONFESSIONS	MADELINE CRAWFORD	14.99	0	5845
2174	10	ADAPTATION CONFIDENTIAL	BELA BALL	27.99	0	9969
2175	13	ADAPTATION CONFUSED	ANTHONY BEATTY	16.99	0	3534
2176	15	ADAPTATION CONGENIALITY	CATE DENCH	15.99	0	920
2177	1	ADAPTATION CONNECTICUT	ED MCQUEEN	21.99	0	8760
2178	9	ADAPTATION CONNECTION	ANJELICA FINNEY	12.99	0	151
2179	12	ADAPTATION CONQUERER	ANNE CRONYN	26.99	0	8811
2180	14	ADAPTATION CONSPIRACY	UMA TEMPLE	27.99	0	5247
2181	4	ADAPTATION CONTACT	ORLANDO BRANAGH	16.99	0	3623
2182	8	ADAPTATION CONTROL	ZERO HECHE	23.99	0	2674
2183	10	ADAPTATION CONVERSATION	LAURENCE LAW	22.99	0	1917
2184	11	ADAPTATION CORE	HARVEY HOPPER	23.99	0	4426
2185	10	ADAPTATION COWBOY	GEOFFREY BLANCHETT	20.99	0	5289
2186	1	ADAPTATION CRAFT	MAE DAMON	26.99	0	362
2187	3	ADAPTATION CRANES	JIM BASINGER	12.99	0	5043
2188	8	ADAPTATION CRAZY	ANTHONY FREEMAN	9.99	0	7807
2189	4	ADAPTATION CREATURES	DUSTIN MCQUEEN	21.99	0	5088
2190	1	ADAPTATION CREEPERS	LENA WAYNE	16.99	0	5688
2191	15	ADAPTATION CROOKED	PEARL KIDMAN	20.99	0	3621
2192	10	ADAPTATION CROSSING	IAN KINNEAR	9.99	0	1737
2193	9	ADAPTATION CROSSROADS	JULIANNE COSTNER	21.99	0	5073
2194	7	ADAPTATION CROW	CHARLIZE HOFFMAN	22.99	0	4963
2195	3	ADAPTATION CROWDS	JANE BLOOM	24.99	0	9145
2196	5	ADAPTATION CRUELTY	JEFF GARBO	10.99	0	8039
2197	7	ADAPTATION CRUSADE	GREG HOPPER	26.99	0	676
2198	1	ADAPTATION CRYSTAL	ED BALE	20.99	0	4509
2199	1	ADAPTATION CUPBOARD	SIGOURNEY BACALL	13.99	0	9372
2200	12	ADAPTATION CURTAIN	ALICIA ROBERTS	11.99	0	4919
2201	1	ADAPTATION CYCLONE	RUBY SANDLER	19.99	0	7376
2202	5	ADAPTATION DADDY	DANIEL FIELD	22.99	0	6925
2203	12	ADAPTATION DAISY	NATALIE CRONYN	28.99	0	3684
2204	7	ADAPTATION DALMATIONS	HILARY ROBERTS	15.99	0	427
2205	4	ADAPTATION DANCES	RIVER NEESON	14.99	0	3261
2206	13	ADAPTATION DANCING	CARRIE STALLONE	21.99	0	23
2207	6	ADAPTATION DANGEROUS	GENE MCQUEEN	20.99	0	4731
2208	4	ADAPTATION DARES	MARLENE WOOD	29.99	0	3802
2209	6	ADAPTATION DARKNESS	CHEVY FOSTER	24.99	0	1293
2210	13	ADAPTATION DARKO	REESE TANDY	21.99	0	5935
2211	15	ADAPTATION DARLING	JANE TEMPLE	9.99	0	7763
2212	1	ADAPTATION DARN	IAN SILVERSTONE	16.99	0	6918
2213	14	ADAPTATION DATE	MEL LOLLOBRIGIDA	19.99	0	6202
2214	14	ADAPTATION DAUGHTER	WARREN SUVARI	9.99	0	5933
2215	3	ADAPTATION DAWN	JEREMY FONDA	28.99	0	5781
2216	9	ADAPTATION DAY	JENNIFER SMITH	29.99	0	9286
2217	12	ADAPTATION DAZED	NICOLAS TORN	12.99	0	903
2218	14	ADAPTATION DECEIVER	MATT BERGMAN	20.99	0	1971
2219	3	ADAPTATION DEEP	ANJELICA HARRIS	11.99	0	6248
2220	12	ADAPTATION DEER	WALTER LEIGH	12.99	0	8746
2221	12	ADAPTATION DELIVERANCE	MICHAEL BALE	13.99	0	5569
2222	2	ADAPTATION DESERT	JENNIFER PRESLEY	27.99	0	6997
2223	16	ADAPTATION DESIRE	PAUL RICKMAN	22.99	0	3191
2224	14	ADAPTATION DESPERATE	NATALIE HOPKINS	27.99	0	1492
2225	8	ADAPTATION DESTINATION	MIRA DIETRICH	18.99	0	2222
2226	6	ADAPTATION DESTINY	ELVIS COSTNER	9.99	0	2716
2227	10	ADAPTATION DETAILS	ALEC IRONS	9.99	0	9453
2228	12	ADAPTATION DETECTIVE	MINNIE EASTWOOD	19.99	0	136
2229	14	ADAPTATION DEVIL	JIM PINKETT	20.99	0	316
2230	12	ADAPTATION DIARY	FRED BOGART	17.99	0	7365
2231	11	ADAPTATION DINOSAUR	SPENCER TEMPLE	27.99	0	2747
2232	3	ADAPTATION DIRTY	ORLANDO HUSTON	13.99	0	1113
2233	3	ADAPTATION DISCIPLE	IAN DENIRO	26.99	0	3370
2234	14	ADAPTATION DISTURBING	BELA LOLLOBRIGIDA	16.99	0	6829
2235	6	ADAPTATION DIVIDE	PENELOPE SMITH	23.99	0	3337
2236	7	ADAPTATION DIVINE	DENNIS TEMPLE	15.99	0	1123
2237	10	ADAPTATION DIVORCE	LEELEE WAYNE	16.99	0	1111
2238	8	ADAPTATION DOCTOR	GWYNETH DRIVER	27.99	0	1146
2239	4	ADAPTATION DOGMA	MERYL ALLEN	15.99	0	8167
2240	16	ADAPTATION DOLLS	MARILYN PENN	24.99	0	8800
2241	2	ADAPTATION DONNIE	OPRAH RYDER	15.99	0	5293
2242	7	ADAPTATION DOOM	JOAN PALTROW	9.99	0	6148
2243	2	ADAPTATION DOORS	SOPHIA KEITEL	19.99	0	428
2244	10	ADAPTATION DORADO	ANNE MCCONAUGHEY	15.99	0	4050
2245	2	ADAPTATION DOUBLE	CARMEN THERON	24.99	0	5111
2246	10	ADAPTATION DOUBTFIRE	GARY PHOENIX	16.99	0	4213
2247	15	ADAPTATION DOWNHILL	CARRIE HOPE	17.99	0	1850
2248	16	ADAPTATION DOZEN	MILLA LEWIS	27.99	0	1093
2249	16	ADAPTATION DRACULA	NATALIE MIRANDA	29.99	0	6354
2250	7	ADAPTATION DRAGON	JULIA BALE	19.99	0	1590
2251	1	ADAPTATION DRAGONFLY	SIDNEY HANNAH	16.99	0	9224
2252	13	ADAPTATION DREAM	HALLE ODONNELL	27.99	0	8230
2253	2	ADAPTATION DRIFTER	HUGH BERGEN	25.99	0	4509
2254	15	ADAPTATION DRIVER	BRAD TRACY	21.99	0	344
2255	5	ADAPTATION DRIVING	AUDREY DUNST	25.99	0	8520
2256	15	ADAPTATION DROP	ELLEN SUVARI	26.99	0	385
2257	12	ADAPTATION DRUMLINE	NATALIE WEST	11.99	0	8010
2258	15	ADAPTATION DRUMS	SANDRA TYLER	15.99	0	8320
2259	13	ADAPTATION DUCK	NEVE LOREN	27.99	0	6311
2260	15	ADAPTATION DUDE	THORA HOPKINS	29.99	0	7449
2261	14	ADAPTATION DUFFEL	LENA CHAPLIN	10.99	0	7863
2262	3	ADAPTATION DUMBO	NICK PECK	27.99	0	5792
2263	11	ADAPTATION DURHAM	JOHNNY PRESLEY	20.99	0	1869
2264	6	ADAPTATION DWARFS	PAUL TAUTOU	11.99	0	9718
2265	12	ADAPTATION DYING	JACK MOSTEL	22.99	0	6472
2266	7	ADAPTATION DYNAMITE	REESE IRONS	29.99	0	7710
2267	13	ADAPTATION EAGLES	JOE PECK	19.99	0	3074
2268	2	ADAPTATION EARLY	ANNETTE DEGENERES	21.99	0	1497
2269	13	ADAPTATION EARRING	ALAN BULLOCK	20.99	0	7632
2270	9	ADAPTATION EARTH	JACK WEST	28.99	0	725
2271	10	ADAPTATION EASY	KIM AKROYD	17.99	0	1377
2272	3	ADAPTATION EDGE	RUBY RUSSELL	22.99	0	4224
2273	16	ADAPTATION EFFECT	MARLON HARRIS	9.99	1	4241
2274	3	ADAPTATION EGG	KEVIN ROBERTS	12.99	0	7791
2275	16	ADAPTATION EGYPT	NEVE SUVARI	16.99	0	3429
2276	8	ADAPTATION ELEMENT	GRETA GRANT	9.99	0	3579
2277	3	ADAPTATION ELEPHANT	CHARLES WEAVER	29.99	0	4524
2278	7	ADAPTATION ELF	SALLY KUDROW	10.99	0	8586
2279	8	ADAPTATION ELIZABETH	MAE PINKETT	9.99	0	9650
2280	14	ADAPTATION EMPIRE	RITA TAUTOU	20.99	0	6113
2281	15	ADAPTATION ENCINO	ADAM NORTON	14.99	0	7826
2282	10	ADAPTATION ENCOUNTERS	NATALIE SOBIESKI	24.99	0	3213
2283	4	ADAPTATION ENDING	SANDRA DEE	10.99	0	4366
2284	15	ADAPTATION ENEMY	CHRISTOPHER RYDER	20.99	0	920
2285	9	ADAPTATION ENGLISH	WALTER NEESON	16.99	0	2002
2286	16	ADAPTATION ENOUGH	SIDNEY CAGE	29.99	0	5740
2287	12	ADAPTATION ENTRAPMENT	HUME ZELLWEGER	18.99	0	2222
2288	13	ADAPTATION ESCAPE	JENNIFER WILSON	22.99	0	7554
2289	2	ADAPTATION EVE	KEVIN WILLIS	14.99	0	3944
2290	6	ADAPTATION EVERYONE	ANNETTE BEATTY	15.99	0	2928
2291	9	ADAPTATION EVOLUTION	JACK GARCIA	17.99	0	8108
2292	16	ADAPTATION EXCITEMENT	RIP BEATTY	16.99	0	5673
2293	10	ADAPTATION EXORCIST	KARL FIELD	10.99	0	5713
2294	13	ADAPTATION EXPECATIONS	KATE BENING	16.99	0	658
2295	13	ADAPTATION EXPENDABLE	CARRIE NORTON	26.99	0	5299
2296	2	ADAPTATION EXPRESS	SIGOURNEY KELLY	20.99	0	2077
2297	6	ADAPTATION EXTRAORDINARY	ELVIS TURNER	12.99	0	7880
2298	12	ADAPTATION EYES	BRUCE TOMEI	14.99	0	706
2299	14	ADAPTATION FACTORY	CATE REYNOLDS	16.99	0	4669
2300	7	ADAPTATION FALCON	CHEVY THERON	20.99	0	1646
2301	2	ADAPTATION FAMILY	MERYL SINATRA	29.99	0	6210
2302	3	ADAPTATION FANTASIA	JULIETTE PACINO	18.99	0	8177
2303	4	ADAPTATION FANTASY	MILLA MALDEN	16.99	0	6581
2304	7	ADAPTATION FARGO	INGRID NOLTE	20.99	0	5426
2305	1	ADAPTATION FATAL	JACK IRONS	12.99	0	1269
2306	6	ADAPTATION FEATHERS	UMA CAGE	9.99	0	2989
2307	11	ADAPTATION FELLOWSHIP	ADAM EASTWOOD	12.99	0	8667
2308	16	ADAPTATION FERRIS	JEREMY WRAY	23.99	0	3078
2309	6	ADAPTATION FEUD	WOODY PITT	25.99	0	427
2310	6	ADAPTATION FEVER	JULIETTE EASTWOOD	24.99	0	5735
2311	14	ADAPTATION FICTION	MILLA SANDLER	26.99	0	8218
2312	2	ADAPTATION FIDDLER	CARMEN HUNT	11.99	0	8761
2313	16	ADAPTATION FIDELITY	SANDRA MINELLI	18.99	0	2005
2314	12	ADAPTATION FIGHT	UMA PACINO	24.99	0	2309
2315	13	ADAPTATION FINDING	KARL SANDLER	15.99	0	17
2316	15	ADAPTATION FIRE	RICHARD HAWN	21.99	0	6339
2317	7	ADAPTATION FIREBALL	BURT FREEMAN	20.99	0	7561
2318	7	ADAPTATION FIREHOUSE	HUGH HOPE	14.99	0	7385
2319	8	ADAPTATION FISH	JAYNE MCQUEEN	17.99	0	9200
2320	11	ADAPTATION FLAMINGOS	MORGAN CHASE	12.99	0	2662
2321	4	ADAPTATION FLASH	MEL GABLE	29.99	0	9163
2322	11	ADAPTATION FLATLINERS	ELVIS GARBO	24.99	0	7279
2323	8	ADAPTATION FLIGHT	CLARK FAWCETT	27.99	0	657
2324	11	ADAPTATION FLINTSTONES	MICHELLE BERGMAN	10.99	0	808
2325	16	ADAPTATION FLOATS	ED CARREY	23.99	0	7101
2326	16	ADAPTATION FLYING	ANNETTE KEITEL	22.99	0	92
2327	10	ADAPTATION FOOL	HALLE CAMPBELL	26.99	0	2631
2328	10	ADAPTATION FOREVER	LANA GIBSON	24.99	0	1596
2329	13	ADAPTATION FORREST	DORIS THURMAN	19.99	0	7237
2330	10	ADAPTATION FORRESTER	SCARLETT WATSON	26.99	0	2083
2331	9	ADAPTATION FORWARD	NEVE MCCONAUGHEY	21.99	0	2496
2332	10	ADAPTATION FRANKENSTEIN	HILARY STREEP	29.99	0	2747
2333	4	ADAPTATION FREAKY	MARISA DENIRO	26.99	0	9053
2334	16	ADAPTATION FREDDY	RAY RYAN	13.99	0	7421
2335	15	ADAPTATION FREEDOM	MEG TOMEI	25.99	0	3244
2336	1	ADAPTATION FRENCH	UMA DIAZ	24.99	0	2161
2337	16	ADAPTATION FRIDA	ANNETTE HUSTON	17.99	0	7459
2338	11	ADAPTATION FRISCO	WOODY PALTROW	15.99	0	9800
2339	4	ADAPTATION FROGMEN	PAUL JOHANSSON	9.99	0	759
2340	12	ADAPTATION FRONTIER	WHOOPI MCGREGOR	17.99	0	6919
2341	12	ADAPTATION FROST	WALTER HESTON	23.99	0	8237
2342	15	ADAPTATION FUGITIVE	GARY COOPER	29.99	0	7677
2343	12	ADAPTATION FULL	JOAN DAVIS	23.99	0	9968
2344	11	ADAPTATION FURY	JOHNNY PFEIFFER	18.99	0	1948
2345	9	ADAPTATION GABLES	RIVER HUNT	19.99	0	2535
2346	4	ADAPTATION GALAXY	MERYL MIRANDA	12.99	0	8711
2347	16	ADAPTATION GAMES	ANGELA DENCH	14.99	0	5948
2348	1	ADAPTATION GANDHI	RICHARD WAHLBERG	19.99	0	3278
2349	9	ADAPTATION GANGS	ANNE FIENNES	9.99	0	7889
2350	4	ADAPTATION GARDEN	ELVIS FIELD	9.99	0	1611
2351	5	ADAPTATION GASLIGHT	RICHARD ALLEN	29.99	0	1410
2352	14	ADAPTATION GATHERING	HELEN CAMPBELL	27.99	0	5899
2353	8	ADAPTATION GENTLEMEN	JUDY HUNT	15.99	1	1427
2354	10	ADAPTATION GHOST	JEREMY KAHN	23.99	0	2364
2355	8	ADAPTATION GHOSTBUSTERS	KENNETH PINKETT	24.99	0	3667
2356	15	ADAPTATION GIANT	HELEN BASINGER	23.99	0	5466
2357	14	ADAPTATION GILBERT	MENA TEMPLE	13.99	0	1109
2358	13	ADAPTATION GILMORE	LAUREN DEPP	15.99	0	5760
2359	8	ADAPTATION GLADIATOR	BETTE CLOSE	28.99	0	6173
2360	3	ADAPTATION GLASS	GRETA FAWCETT	23.99	0	1201
2361	2	ADAPTATION GLEAMING	CHRISTOPHER WALKEN	18.99	0	2029
2362	1	ADAPTATION GLORY	BEN HORNE	23.99	0	8485
2363	13	ADAPTATION GO	BRAD JACKMAN	17.99	0	6424
2364	16	ADAPTATION GODFATHER	RICHARD DOUGLAS	10.99	0	6457
2365	11	ADAPTATION GOLD	VIVIEN GARCIA	9.99	0	9893
2366	3	ADAPTATION GOLDFINGER	SUSAN CARREY	15.99	0	5414
2367	9	ADAPTATION GOLDMINE	ADAM MARX	21.99	0	6859
2368	8	ADAPTATION GONE	CLARK BOLGER	20.99	0	9901
2369	4	ADAPTATION GOODFELLAS	EMILY HOPE	29.99	0	4695
2370	11	ADAPTATION GORGEOUS	ROBIN COOPER	21.99	0	9036
2371	10	ADAPTATION GOSFORD	ANJELICA FISHER	19.99	0	6568
2372	1	ADAPTATION GRACELAND	EMILY CHASE	9.99	0	5657
2373	12	ADAPTATION GRADUATE	MATT DAFOE	28.99	0	1565
2374	15	ADAPTATION GRAFFITI	LEONARDO WASHINGTON	12.99	0	1037
2375	11	ADAPTATION GRAIL	ETHAN LAW	18.99	0	4574
2376	6	ADAPTATION GRAPES	PENELOPE PINKETT	17.99	0	4259
2377	2	ADAPTATION GREASE	LAUREN DIETRICH	16.99	0	3374
2378	15	ADAPTATION GREATEST	KATE BALL	21.99	0	2832
2379	12	ADAPTATION GREEDY	DENZEL STALLONE	16.99	0	1420
2380	8	ADAPTATION GREEK	MILLA MCQUEEN	23.99	0	8615
2381	3	ADAPTATION GRINCH	LENA HUDSON	29.99	0	8295
2382	7	ADAPTATION GRIT	BRUCE WILLIS	29.99	0	4137
2383	5	ADAPTATION GROOVE	JEREMY DAVIS	26.99	0	4018
2384	2	ADAPTATION GROSSE	ED KEATON	16.99	0	2485
2385	8	ADAPTATION GROUNDHOG	SIDNEY DUNST	12.99	0	9870
2386	1	ADAPTATION GUMP	JEREMY CRAWFORD	22.99	0	3440
2387	8	ADAPTATION GUN	GARY JOVOVICH	21.99	0	6135
2388	16	ADAPTATION GUNFIGHT	ROBERT RICKMAN	18.99	0	6135
2389	14	ADAPTATION GUNFIGHTER	CARY PESCI	10.99	0	9898
2390	6	ADAPTATION GUYS	FAY KILMER	13.99	0	2942
2391	4	ADAPTATION HALF	JIM RICKMAN	22.99	0	5981
2392	1	ADAPTATION HALL	BURT THERON	15.99	0	5742
2393	15	ADAPTATION HALLOWEEN	GREG HOFFMAN	24.99	0	9465
2394	6	ADAPTATION HAMLET	MATTHEW PESCI	19.99	0	7311
2395	8	ADAPTATION HANDICAP	EMILY CARREY	25.99	0	9916
2396	2	ADAPTATION HANGING	OPRAH LEWIS	20.99	0	1696
2397	3	ADAPTATION HANKY	ANJELICA DENCH	14.99	0	5063
2398	14	ADAPTATION HANOVER	VAL IRONS	12.99	0	8283
2399	2	ADAPTATION HAPPINESS	KEVIN MATTHAU	25.99	0	3635
2400	9	ADAPTATION HARDLY	JUDI MARTIN	25.99	0	8756
2401	13	ADAPTATION HAROLD	JEFF HOPKINS	20.99	1	6868
2402	12	ADAPTATION HARPER	TIM CAGE	24.99	0	4914
2403	5	ADAPTATION HARRY	WILLIAM CRUZ	13.99	0	2234
2404	1	ADAPTATION HATE	ROBIN HORNE	21.99	0	9468
2405	16	ADAPTATION HAUNTED	KEVIN POSEY	18.99	0	9310
2406	6	ADAPTATION HAUNTING	HELEN DUNST	25.99	0	3775
2407	8	ADAPTATION HAWK	JUDY KELLY	17.99	0	8888
2408	15	ADAPTATION HEAD	BETTE KILMER	27.99	0	4430
2409	2	ADAPTATION HEARTBREAKERS	SPENCER ROBBINS	28.99	0	1502
2410	15	ADAPTATION HEAVEN	SOPHIA EASTWOOD	17.99	0	4318
2411	6	ADAPTATION HEAVENLY	NEVE BLOOM	24.99	0	5606
2412	2	ADAPTATION HEAVYWEIGHTS	BETTE FOSTER	22.99	0	3671
2413	9	ADAPTATION HEDWIG	SOPHIA MCKELLEN	21.99	0	6414
2414	1	ADAPTATION HELLFIGHTERS	IAN MARTIN	29.99	0	7670
2415	2	ADAPTATION HIGH	ANTHONY HARRIS	9.99	0	8298
2416	7	ADAPTATION HIGHBALL	SYLVESTER CRUISE	12.99	0	7965
2417	12	ADAPTATION HILLS	CATE BARRYMORE	26.99	0	8827
2418	3	ADAPTATION HOBBIT	JULIA CRUZ	10.99	0	234
2419	12	ADAPTATION HOCUS	LIZA STALLONE	11.99	0	1550
2420	15	ADAPTATION HOLES	KIRK TRACY	29.99	0	3948
2421	13	ADAPTATION HOLIDAY	LAURENCE FREEMAN	24.99	0	5161
2422	9	ADAPTATION HOLLOW	KIRSTEN DENCH	22.99	0	2434
2423	9	ADAPTATION HOLLYWOOD	JANE DENIRO	10.99	0	2380
2424	2	ADAPTATION HOLOCAUST	BEN BENING	23.99	0	8817
2425	14	ADAPTATION HOLY	PENELOPE BRANDO	18.99	0	6923
2426	14	ADAPTATION HOME	ANDY TORN	17.99	0	5522
2427	15	ADAPTATION HOMEWARD	REESE CHAPLIN	19.99	0	8579
2428	12	ADAPTATION HOMICIDE	BRUCE GARLAND	12.99	0	4392
2429	7	ADAPTATION HONEY	JUDE KEATON	19.99	0	7063
2430	7	ADAPTATION HOOK	RITA BOGART	12.99	0	9073
2431	14	ADAPTATION HOOSIERS	RENEE GABLE	27.99	0	4298
2432	8	ADAPTATION HOPE	LAUREN NORTON	13.99	0	3989
2433	2	ADAPTATION HORN	ORLANDO TYLER	13.99	0	1945
2434	11	ADAPTATION HORROR	MINNIE JOHANSSON	11.99	1	9454
2435	14	ADAPTATION HOTEL	ANGELINA GARLAND	22.99	0	5749
2436	10	ADAPTATION HOURS	THORA GOLDBERG	16.99	0	6925
2437	13	ADAPTATION HOUSE	HELEN PECK	17.99	0	5615
2438	13	ADAPTATION HUMAN	JODIE BARRYMORE	20.99	0	5624
2439	12	ADAPTATION HUNCHBACK	ANNETTE THURMAN	18.99	0	528
2440	7	ADAPTATION HUNGER	JACK TEMPLE	18.99	0	9486
2441	1	ADAPTATION HUNTER	GLENN BRANDO	29.99	0	5985
2442	11	ADAPTATION HUNTING	GENE DUNST	9.99	0	2601
2443	10	ADAPTATION HURRICANE	GARY HUNT	10.99	0	5517
2444	11	ADAPTATION HUSTLER	JANE ROBBINS	23.99	0	4649
2445	12	ADAPTATION HYDE	GREG MCQUEEN	12.99	0	8823
2446	2	ADAPTATION HYSTERICAL	ZERO BRANAGH	18.99	0	4894
2447	1	ADAPTATION ICE	RALPH PALTROW	16.99	0	4758
2448	10	ADAPTATION IDAHO	VIVIEN FISHER	28.99	0	9766
2449	8	ADAPTATION IDENTITY	NICOLE ANISTON	27.99	0	9791
2450	6	ADAPTATION IDOLS	LISA HOFFMAN	23.99	0	6995
2451	10	ADAPTATION IGBY	RICHARD PECK	21.99	0	8723
2452	2	ADAPTATION ILLUSION	LAUREN CROWE	27.99	0	3182
2453	6	ADAPTATION IMAGE	MARILYN CAMPBELL	15.99	0	341
2454	5	ADAPTATION IMPACT	ANJELICA KEATON	9.99	0	7549
2455	16	ADAPTATION IMPOSSIBLE	DANIEL RUSH	21.99	0	8036
2456	5	ADAPTATION INCH	JULIA BIRCH	11.99	0	6695
2457	16	ADAPTATION INDEPENDENCE	SALLY PITT	20.99	0	3924
2458	15	ADAPTATION INDIAN	KARL WEAVER	20.99	0	5873
2459	10	ADAPTATION INFORMER	BRUCE JOLIE	21.99	0	5237
2460	6	ADAPTATION INNOCENT	GARY KAHN	20.99	0	8004
2461	6	ADAPTATION INSECTS	SHIRLEY HECHE	27.99	0	5479
2462	9	ADAPTATION INSIDER	FRANCES KIDMAN	17.99	0	8966
2463	13	ADAPTATION INSTINCT	ROSIE WRAY	16.99	0	784
2464	15	ADAPTATION INTENTIONS	LAUREN BLOOM	9.99	0	984
2465	9	ADAPTATION INTERVIEW	LIAM BIRCH	27.99	0	7292
2466	11	ADAPTATION INTOLERABLE	CHEVY BACALL	20.99	0	7004
2467	2	ADAPTATION INTRIGUE	DREW HURT	17.99	0	3368
2468	5	ADAPTATION INVASION	GLENN PECK	11.99	0	8532
2469	4	ADAPTATION IRON	UMA WOOD	25.99	0	6526
2470	15	ADAPTATION ISHTAR	NEVE LUGOSI	19.99	0	3846
2471	4	ADAPTATION ISLAND	IAN BULLOCK	16.99	0	3290
2472	2	ADAPTATION ITALIAN	RICHARD ROBERTS	15.99	0	7077
2473	11	ADAPTATION JACKET	INGRID HOPE	29.99	0	4739
2474	14	ADAPTATION JADE	JESSICA RUSH	25.99	0	4875
2475	7	ADAPTATION JAPANESE	AUDREY HOPPER	12.99	0	5298
2476	9	ADAPTATION JASON	MARLON CRAWFORD	29.99	0	3323
2477	5	ADAPTATION JAWBREAKER	BURT MCQUEEN	11.99	0	2718
2478	13	ADAPTATION JAWS	MORGAN MARTIN	13.99	0	2990
2479	12	ADAPTATION JEDI	BEN HAWN	12.99	0	6537
2480	11	ADAPTATION JEEPERS	CAMERON MCDORMAND	24.99	0	617
2481	4	ADAPTATION JEKYLL	DUSTIN FONDA	27.99	0	7939
2482	4	ADAPTATION JEOPARDY	JAMES LOLLOBRIGIDA	16.99	0	3831
2483	10	ADAPTATION JERICHO	WINONA HURT	16.99	0	5689
2484	11	ADAPTATION JERK	WILLIAM GUINESS	24.99	0	1777
2485	6	ADAPTATION JERSEY	RENEE CRUZ	19.99	0	5858
2486	9	ADAPTATION JET	SUSAN CLOSE	25.99	0	2093
2487	10	ADAPTATION JINGLE	RALPH EASTWOOD	9.99	0	4604
2488	7	ADAPTATION JOON	TOM DIAZ	16.99	0	6353
2489	16	ADAPTATION JUGGLER	ALEC DEE	28.99	0	5795
2490	2	ADAPTATION JUMANJI	PAUL FISHER	28.99	0	6890
2491	8	ADAPTATION JUMPING	RUSSELL GABLE	17.99	0	9176
2492	10	ADAPTATION JUNGLE	DENZEL PALTROW	17.99	0	8661
2493	14	ADAPTATION KANE	CARRIE BOLGER	25.99	0	7263
2494	8	ADAPTATION KARATE	WARREN HAYEK	18.99	0	9140
2495	1	ADAPTATION KENTUCKIAN	DUSTIN HOPPER	26.99	0	471
2496	9	ADAPTATION KICK	HUGH SWANK	16.99	0	5318
2497	5	ADAPTATION KILL	DUSTIN TOMEI	19.99	0	9545
2498	6	ADAPTATION KILLER	ANNE COOPER	19.99	0	5382
2499	4	ADAPTATION KING	WARREN HAWKE	12.99	0	3153
2500	2	ADAPTATION KISS	PEARL WALKEN	16.99	0	1421
2501	7	ADAPTATION KISSING	ADAM DIAZ	25.99	0	2732
2502	6	ADAPTATION KNOCK	CHRIS TURNER	20.99	0	4643
2503	9	ADAPTATION KRAMER	MADELINE ROBERTS	20.99	0	6037
2504	2	ADAPTATION KWAI	ALAN JACKMAN	10.99	0	8971
2505	7	ADAPTATION LABYRINTH	ROBERT ROBBINS	12.99	0	5794
2506	5	ADAPTATION LADY	ROSIE IRONS	15.99	0	4729
2507	10	ADAPTATION LADYBUGS	HELEN LOREN	24.99	0	7930
2508	4	ADAPTATION LAMBS	LANA MINELLI	26.99	0	8427
2509	7	ADAPTATION LANGUAGE	GRACE FAWCETT	18.99	0	107
2510	6	ADAPTATION LAWLESS	PENELOPE PRESLEY	12.99	0	8867
2511	13	ADAPTATION LAWRENCE	HARRISON DAMON	21.99	0	6426
2512	2	ADAPTATION LEAGUE	DIANE BIRCH	18.99	0	3566
2513	4	ADAPTATION LEATHERNECKS	ZERO ASTAIRE	26.99	0	2022
2514	11	ADAPTATION LEBOWSKI	JUDY DUKAKIS	29.99	0	8855
2515	1	ADAPTATION LEGALLY	MARILYN BOGART	25.99	0	5520
2516	11	ADAPTATION LEGEND	ORLANDO BACALL	10.99	0	2698
2517	12	ADAPTATION LESSON	GRETA PACINO	28.99	0	1711
2518	5	ADAPTATION LIAISONS	DAN HARRIS	14.99	0	478
2519	8	ADAPTATION LIBERTY	GREG THURMAN	29.99	0	854
2520	14	ADAPTATION LICENSE	CLINT TOMEI	19.99	0	4532
2521	1	ADAPTATION LIES	JOE GARBO	26.99	0	1103
2522	2	ADAPTATION LIFE	RIP BOLGER	18.99	0	9698
2523	10	ADAPTATION LIGHTS	HARVEY DRIVER	25.99	0	6011
2524	14	ADAPTATION LION	JOHN BACALL	13.99	0	3723
2525	5	ADAPTATION LOATHING	ELVIS TEMPLE	18.99	0	9464
2526	15	ADAPTATION LOCK	FRED HOPE	17.99	0	7115
2527	9	ADAPTATION LOLA	RIP GARCIA	15.99	0	8278
2528	5	ADAPTATION LOLITA	CANDICE HAWN	22.99	0	6741
2529	5	ADAPTATION LONELY	MICHELLE BERRY	24.99	0	7144
2530	2	ADAPTATION LORD	LEELEE LANCASTER	17.99	0	9812
2531	6	ADAPTATION LOSE	JADA WALKEN	22.99	0	6988
2532	6	ADAPTATION LOSER	ANNE SOBIESKI	12.99	0	8629
2533	16	ADAPTATION LOST	EWAN HEPBURN	11.99	0	5037
2534	13	ADAPTATION LOUISIANA	LAUREN GARBO	19.99	0	8537
2535	4	ADAPTATION LOVE	HUMPHREY DEGENERES	25.99	0	4180
2536	13	ADAPTATION LOVELY	GREG WILLIAMS	13.99	0	6656
2537	15	ADAPTATION LOVER	JOHNNY WEAVER	29.99	0	6369
2538	14	ADAPTATION LOVERBOY	ANTHONY BOLGER	11.99	0	1637
2539	10	ADAPTATION LUCK	JULIANNE WOOD	12.99	0	6342
2540	1	ADAPTATION LUCKY	SANDRA NEWMAN	18.99	0	4943
2541	14	ADAPTATION LUKE	JENNIFER DEE	13.99	0	532
2542	14	ADAPTATION LUST	ADAM FORD	16.99	0	1153
2543	1	ADAPTATION MADIGAN	DENZEL BRIDGES	10.99	0	4263
2544	4	ADAPTATION MADISON	INGRID SOBIESKI	24.99	0	8878
2545	7	ADAPTATION MADNESS	KIM BEATTY	14.99	0	198
2546	13	ADAPTATION MADRE	ELIZABETH GARLAND	13.99	0	6893
2547	5	ADAPTATION MAGIC	ALEC HOPKINS	14.99	0	3208
2548	7	ADAPTATION MAGNIFICENT	JANE SMITH	21.99	0	6595
2549	1	ADAPTATION MAGNOLIA	JOHN BULLOCK	18.99	0	5006
2550	6	ADAPTATION MAGUIRE	KIM DREYFUSS	27.99	0	587
2551	15	ADAPTATION MAIDEN	JADA EASTWOOD	12.99	0	19
2552	14	ADAPTATION MAJESTIC	JENNIFER ROBERTS	27.99	0	2697
2553	4	ADAPTATION MAKER	BOB HECHE	22.99	0	9841
2554	5	ADAPTATION MALKOVICH	CAMERON BASINGER	25.99	0	20
2555	5	ADAPTATION MALLRATS	FARRAH SMITH	26.99	0	8278
2556	15	ADAPTATION MALTESE	CARRIE MCCONAUGHEY	15.99	0	6417
2557	6	ADAPTATION MANCHURIAN	INGRID MCKELLEN	25.99	0	4625
2558	1	ADAPTATION MANNEQUIN	SIDNEY PACINO	11.99	0	9159
2559	2	ADAPTATION MARRIED	WHOOPI MCKELLEN	13.99	0	4637
2560	4	ADAPTATION MARS	FAY ODONNELL	19.99	0	9994
2561	6	ADAPTATION MASK	LIV HECHE	19.99	0	3981
2562	2	ADAPTATION MASKED	ALEC BERGMAN	20.99	0	5335
2563	16	ADAPTATION MASSACRE	DREW TOMEI	27.99	0	5714
2564	13	ADAPTATION MASSAGE	DARYL CHAPLIN	25.99	0	6137
2565	4	ADAPTATION MATRIX	GARY MCDORMAND	20.99	0	8368
2566	9	ADAPTATION MAUDE	ELVIS IRONS	11.99	0	115
2567	9	ADAPTATION MEET	BEN BIRCH	20.99	0	9318
2568	2	ADAPTATION MEMENTO	ROBERT MCCONAUGHEY	16.99	0	8561
2569	15	ADAPTATION MENAGERIE	ADRIEN FAWCETT	11.99	0	3920
2570	12	ADAPTATION MERMAID	AL FIENNES	9.99	0	1533
2571	14	ADAPTATION METAL	MARILYN GARLAND	11.99	0	6050
2572	3	ADAPTATION METROPOLIS	MENA BARRYMORE	13.99	0	3056
2573	3	ADAPTATION MICROCOSMOS	SYLVESTER PENN	29.99	0	4282
2574	14	ADAPTATION MIDNIGHT	NICK WILLIS	26.99	0	8194
2575	4	ADAPTATION MIDSUMMER	CATE RYDER	14.99	0	9806
2576	7	ADAPTATION MIGHTY	GREGORY ODONNELL	9.99	0	8554
2577	11	ADAPTATION MILE	SOPHIA WILLIS	16.99	0	5201
2578	11	ADAPTATION MILLION	DUSTIN FREEMAN	20.99	0	2922
2579	16	ADAPTATION MINDS	ELIZABETH COOPER	24.99	0	3260
2580	9	ADAPTATION MINE	CARMEN DENIRO	23.99	0	9470
2581	11	ADAPTATION MINORITY	MAE TRACY	9.99	0	4618
2582	14	ADAPTATION MIRACLE	JADA MANSFIELD	25.99	0	6147
2583	5	ADAPTATION MISSION	WARREN LOLLOBRIGIDA	20.99	0	2885
2584	14	ADAPTATION MIXED	JEREMY CAGE	10.99	0	4673
2585	7	ADAPTATION MOB	MIRA HAWKE	20.99	0	2165
2586	8	ADAPTATION MOCKINGBIRD	CANDICE RICKMAN	11.99	0	673
2587	10	ADAPTATION MOD	MARY MONROE	29.99	0	5978
2588	10	ADAPTATION MODEL	CHRISTOPHER PESCI	21.99	0	3133
2589	14	ADAPTATION MODERN	JEFF BERRY	15.99	0	3097
2590	13	ADAPTATION MONEY	MORGAN LANSBURY	19.99	0	8227
2591	12	ADAPTATION MONSOON	LEELEE LANSBURY	26.99	0	3739
2592	15	ADAPTATION MONSTER	ALEC DENCH	20.99	0	4547
2593	3	ADAPTATION MONTEREY	CLARK SWANK	16.99	0	4296
2594	11	ADAPTATION MONTEZUMA	JUDI DUKAKIS	11.99	0	6628
2595	7	ADAPTATION MOON	DIANE HACKMAN	11.99	0	3079
2596	16	ADAPTATION MOONSHINE	SANDRA MCCONAUGHEY	20.99	0	5356
2597	15	ADAPTATION MOONWALKER	PEARL GARCIA	28.99	0	220
2598	7	ADAPTATION MOSQUITO	SEAN BOGART	21.99	0	3102
2599	1	ADAPTATION MOTHER	LEONARDO BLOOM	19.99	0	2161
2600	3	ADAPTATION MOTIONS	LISA MANSFIELD	17.99	0	5120
2601	12	ADAPTATION MOULIN	CARRIE NORTON	21.99	0	5841
2602	2	ADAPTATION MOURNING	UMA CHAPLIN	27.99	0	8738
2603	15	ADAPTATION MOVIE	WILL JOHANSSON	25.99	0	4073
2604	2	ADAPTATION MULAN	JON BIRCH	23.99	0	6880
2605	15	ADAPTATION MULHOLLAND	FAY ROBBINS	20.99	0	198
2606	1	ADAPTATION MUMMY	MILLA THERON	12.99	0	9386
2607	13	ADAPTATION MUPPET	BETTE LAW	23.99	0	1879
2608	10	ADAPTATION MURDER	MENA GARBO	20.99	0	7634
2609	16	ADAPTATION MUSCLE	RUBY DENCH	18.99	0	4439
2610	3	ADAPTATION MUSIC	DENZEL TAUTOU	17.99	0	3910
2611	8	ADAPTATION MUSKETEERS	ETHAN HOFFMAN	12.99	0	7240
2612	2	ADAPTATION MUSSOLINI	FAY GARLAND	12.99	0	7335
2613	6	ADAPTATION MYSTIC	BOB MINELLI	10.99	0	2370
2614	14	ADAPTATION NAME	JOE CAMPBELL	22.99	0	4277
2615	2	ADAPTATION NASH	FRANCES PHOENIX	15.99	0	6897
2616	12	ADAPTATION NATIONAL	CARY MARTIN	29.99	0	7430
2617	12	ADAPTATION NATURAL	CAMERON STALLONE	29.99	0	1828
2618	12	ADAPTATION NECKLACE	ROBERT GUINESS	26.99	0	176
2619	1	ADAPTATION NEIGHBORS	CHEVY DICAPRIO	20.99	0	7518
2620	16	ADAPTATION NEMO	JOE BALL	14.99	0	6376
2621	16	ADAPTATION NETWORK	DUSTIN BLANCHETT	10.99	0	9921
2622	14	ADAPTATION NEWSIES	ROCK RUSSELL	28.99	0	8604
2623	2	ADAPTATION NEWTON	ELIZABETH KEATON	28.99	0	7014
2624	16	ADAPTATION NIGHTMARE	WHOOPI HACKMAN	11.99	0	9007
2625	15	ADAPTATION NONE	UMA TURNER	16.99	0	3105
2626	16	ADAPTATION NOON	HUGH BRODY	13.99	0	4720
2627	4	ADAPTATION NORTH	ELVIS BACALL	10.99	0	462
2628	15	ADAPTATION NORTHWEST	KIRK BIRCH	12.99	0	9040
2629	15	ADAPTATION NOTORIOUS	FRED WRAY	26.99	0	2443
2630	12	ADAPTATION NOTTING	CHARLTON WRAY	23.99	0	3231
2631	16	ADAPTATION NOVOCAINE	JAYNE FOSTER	17.99	0	6461
2632	14	ADAPTATION NUTS	MATTHEW SANDLER	11.99	0	6343
2633	3	ADAPTATION OCTOBER	MIRA RUSSELL	24.99	0	7442
2634	11	ADAPTATION ODDS	NICK STALLONE	28.99	0	8535
2635	4	ADAPTATION OKLAHOMA	RUBY HEPBURN	16.99	0	1959
2636	11	ADAPTATION OLEANDER	KATHARINE BRIDGES	11.99	0	1196
2637	13	ADAPTATION OPEN	SYLVESTER GOLDBERG	17.99	0	7908
2638	1	ADAPTATION OPERATION	LAURA NICHOLSON	25.99	0	5436
2639	9	ADAPTATION OPPOSITE	HELEN BEATTY	14.99	0	704
2640	2	ADAPTATION OPUS	JUDE CRUISE	29.99	0	6214
2641	3	ADAPTATION ORANGE	NICK CRUZ	23.99	0	2516
2642	14	ADAPTATION ORDER	MADELINE BENING	24.99	0	1377
2643	9	ADAPTATION ORIENT	RITA KUDROW	11.99	0	2336
2644	11	ADAPTATION OSCAR	FRANCES STREEP	9.99	0	2925
2645	2	ADAPTATION OTHERS	JOE DAY	21.99	0	151
2646	4	ADAPTATION OUTBREAK	DENNIS FISHER	29.99	0	5181
2647	4	ADAPTATION OUTFIELD	LAURA SPACEK	26.99	0	670
2648	16	ADAPTATION OUTLAW	LIV BOLGER	25.99	0	9425
2649	1	ADAPTATION OZ	RALPH TANDY	15.99	0	8953
2650	10	ADAPTATION PACIFIC	CAMERON AFFLECK	11.99	0	2863
2651	2	ADAPTATION PACKER	LISA STALLONE	15.99	0	6352
2652	14	ADAPTATION PAJAMA	JOAN BAILEY	18.99	0	431
2653	8	ADAPTATION PANIC	CHARLES TAYLOR	11.99	0	3543
2654	1	ADAPTATION PANKY	DENZEL PENN	26.99	0	1133
2655	12	ADAPTATION PANTHER	CANDICE NEWMAN	26.99	0	7297
2656	3	ADAPTATION PAPI	LANA TORN	24.99	0	3825
2657	7	ADAPTATION PARADISE	IAN BIRCH	27.99	0	2960
2658	15	ADAPTATION PARIS	CHRISTIAN AKROYD	9.99	0	8452
2659	7	ADAPTATION PARK	KIRK CRAWFORD	21.99	0	6107
2660	12	ADAPTATION PARTY	FARRAH REYNOLDS	26.99	0	584
2661	10	ADAPTATION PAST	WALTER POSEY	12.99	0	1862
2662	9	ADAPTATION PATHS	EMILY TOMEI	28.99	0	7785
2663	4	ADAPTATION PATIENT	RALPH MONROE	17.99	0	9077
2664	5	ADAPTATION PATRIOT	BEN BOGART	26.99	0	1065
2665	7	ADAPTATION PATTON	SANDRA HOFFMAN	23.99	0	4849
2666	13	ADAPTATION PAYCHECK	DUSTIN TAUTOU	24.99	0	7466
2667	15	ADAPTATION PEACH	MARILYN KINNEAR	12.99	0	3944
2668	16	ADAPTATION PEAK	ANGELINA PFEIFFER	24.99	0	7478
2669	11	ADAPTATION PEARL	RUBY GOODING	24.99	0	5622
2670	14	ADAPTATION PELICAN	ADRIEN MCDORMAND	23.99	0	2960
2671	4	ADAPTATION PERDITION	CHRIS BOGART	18.99	0	1747
2672	3	ADAPTATION PERFECT	MIRA PFEIFFER	26.99	0	2038
2673	4	ADAPTATION PERSONAL	THORA SUVARI	14.99	0	618
2674	1	ADAPTATION PET	JEFF DEGENERES	27.99	0	6453
2675	7	ADAPTATION PHANTOM	EMILY SARANDON	17.99	0	6013
2676	12	ADAPTATION PHILADELPHIA	MICHAEL PALTROW	27.99	0	5162
2677	1	ADAPTATION PIANIST	ED FIENNES	25.99	0	1414
2678	16	ADAPTATION PICKUP	WOODY GABLE	28.99	0	5871
2679	16	ADAPTATION PILOT	ROBERT MCDORMAND	17.99	0	7985
2680	1	ADAPTATION PINOCCHIO	LIAM TRACY	15.99	0	1247
2681	15	ADAPTATION PIRATES	ROBIN BARRYMORE	22.99	0	9742
2682	3	ADAPTATION PITTSBURGH	FRANCES WOOD	17.99	0	4311
2683	9	ADAPTATION PITY	PENELOPE PITT	19.99	0	3982
2684	2	ADAPTATION PIZZA	ALBERT MCCONAUGHEY	28.99	0	5049
2685	12	ADAPTATION PLATOON	HUMPHREY BOGART	16.99	0	7327
2686	8	ADAPTATION PLUTO	PENELOPE GARBO	15.99	0	7112
2687	5	ADAPTATION POCUS	MICHAEL CAINE	20.99	0	4622
2688	1	ADAPTATION POLISH	DARYL BASINGER	25.99	0	8534
2689	3	ADAPTATION POLLOCK	JOAN NORTON	13.99	0	5077
2690	12	ADAPTATION POND	LEONARDO GARCIA	11.99	0	308
2691	14	ADAPTATION POSEIDON	HENRY COSTNER	22.99	0	3792
2692	6	ADAPTATION POTLUCK	JUDY POSEY	9.99	0	381
2693	9	ADAPTATION POTTER	BOB FINNEY	23.99	0	6666
2694	9	ADAPTATION PREJUDICE	GRETA DRIVER	9.99	0	9774
2695	9	ADAPTATION PRESIDENT	GRACE CRUZ	11.99	0	418
2696	3	ADAPTATION PRIDE	DENNIS CLOSE	20.99	0	6894
2697	16	ADAPTATION PRIMARY	JAYNE CAGE	18.99	0	7610
2698	8	ADAPTATION PRINCESS	BEN NEWMAN	21.99	0	1854
2699	5	ADAPTATION PRIVATE	JOAN WASHINGTON	21.99	0	9613
2700	10	ADAPTATION PRIX	CHRIS JOLIE	28.99	0	4760
2701	16	ADAPTATION PSYCHO	MAE SINATRA	12.99	0	4311
2702	14	ADAPTATION PULP	KIRK FINNEY	15.99	0	7335
2703	2	ADAPTATION PUNK	HUMPHREY DOUGLAS	12.99	0	7820
2704	6	ADAPTATION PURE	MIRA BRANDO	25.99	0	6826
2705	13	ADAPTATION PURPLE	CUBA DUNST	28.99	0	8329
2706	7	ADAPTATION QUEEN	MARLENE CRONYN	9.99	0	341
2707	8	ADAPTATION QUEST	GROUCHO DAY-LEWIS	9.99	0	1386
2708	13	ADAPTATION QUILLS	IAN MANSFIELD	12.99	0	2747
2709	16	ADAPTATION RACER	HENRY BERRY	23.99	0	1044
2710	6	ADAPTATION RAGE	HUME MIRANDA	20.99	0	6235
2711	7	ADAPTATION RAGING	RENEE WINSLET	9.99	0	1617
2712	1	ADAPTATION RAIDERS	HELEN JACKMAN	17.99	0	9130
2713	9	ADAPTATION RAINBOW	JUDI DUNST	29.99	0	2526
2714	4	ADAPTATION RANDOM	GOLDIE HECHE	22.99	0	2125
2715	12	ADAPTATION RANGE	SALMA HOPPER	11.99	1	4354
2716	13	ADAPTATION REAP	IAN GIBSON	20.99	0	4322
2717	12	ADAPTATION REAR	SYLVESTER HORNE	11.99	0	4522
2718	1	ADAPTATION REBEL	NICOLE HESTON	20.99	0	2203
2719	13	ADAPTATION RECORDS	MARISA MOORE	11.99	0	7484
2720	6	ADAPTATION REDEMPTION	DARYL BACALL	13.99	0	2035
2721	11	ADAPTATION REDS	LAURA WATSON	9.99	0	9789
2722	8	ADAPTATION REEF	JAYNE DEGENERES	17.99	0	3238
2723	14	ADAPTATION REIGN	ORLANDO GOODING	21.99	0	1755
2724	14	ADAPTATION REMEMBER	ROBIN PALTROW	18.99	0	1254
2725	4	ADAPTATION REQUIEM	CHARLTON CLOSE	17.99	0	3262
2726	10	ADAPTATION RESERVOIR	ELVIS WITHERSPOON	13.99	0	7690
2727	3	ADAPTATION RESURRECTION	ADRIEN JOHANSSON	22.99	0	3599
2728	16	ADAPTATION REUNION	NICOLAS PITT	23.99	0	6610
2729	15	ADAPTATION RIDER	HALLE CLOSE	24.99	0	1988
2730	14	ADAPTATION RIDGEMONT	GROUCHO STALLONE	29.99	0	7141
2731	6	ADAPTATION RIGHT	MICHAEL THURMAN	21.99	0	7200
2732	6	ADAPTATION RINGS	DENZEL DICAPRIO	16.99	0	1114
2733	12	ADAPTATION RIVER	SALLY SORVINO	18.99	0	1990
2734	3	ADAPTATION ROAD	GWYNETH HECHE	19.99	0	9908
2735	12	ADAPTATION ROBBERS	ROCK WOOD	10.99	0	1000
2736	13	ADAPTATION ROBBERY	WINONA FIELD	18.99	0	765
2737	3	ADAPTATION ROCK	GREG DEPP	17.99	0	2345
2738	9	ADAPTATION ROCKETEER	ANTHONY FORD	16.99	0	6126
2739	10	ADAPTATION ROCKY	ANGELA WALKEN	28.99	0	1859
2740	15	ADAPTATION ROLLERCOASTER	CHRISTOPHER BRIDGES	24.99	0	1616
2741	14	ADAPTATION ROMAN	JOAN WATSON	26.99	0	3712
2742	15	ADAPTATION ROOF	LUCILLE LUGOSI	14.99	0	2420
2743	8	ADAPTATION ROOM	LAUREN JOHANSSON	20.99	0	3840
2744	3	ADAPTATION ROOTS	GENE HEPBURN	13.99	0	7353
2745	7	ADAPTATION ROSES	RUSSELL DREYFUSS	21.99	0	224
2746	12	ADAPTATION ROUGE	WARREN THURMAN	13.99	0	3625
2747	10	ADAPTATION ROXANNE	VAL MONROE	13.99	0	9357
2748	8	ADAPTATION RUGRATS	JAMES HAWKE	9.99	0	3020
2749	7	ADAPTATION RULES	NICK CHASE	24.99	0	983
2750	8	ADAPTATION RUN	HARVEY RUSH	15.99	0	4153
2751	6	ADAPTATION RUNAWAY	GARY BOLGER	15.99	0	373
2752	11	ADAPTATION RUNNER	MENA TURNER	21.99	0	6018
2753	9	ADAPTATION RUSH	AL LEIGH	29.99	0	9918
2754	5	ADAPTATION RUSHMORE	CHARLIZE ASTAIRE	9.99	0	5272
2755	2	ADAPTATION SABRINA	GENE DAY	19.99	0	6735
2756	15	ADAPTATION SADDLE	PEARL TAYLOR	13.99	0	979
2757	5	ADAPTATION SAGEBRUSH	ADAM SPACEK	28.99	0	1196
2758	9	ADAPTATION SAINTS	MENA WRAY	20.99	0	2921
2759	9	ADAPTATION SALUTE	GENE DERN	23.99	0	642
2760	4	ADAPTATION SAMURAI	FARRAH HACKMAN	20.99	0	8139
2761	4	ADAPTATION SANTA	MENA SARANDON	29.99	0	8600
2762	2	ADAPTATION SASSY	MICHAEL DOUGLAS	10.99	0	1422
2763	4	ADAPTATION SATISFACTION	CATE RICKMAN	27.99	0	1105
2764	4	ADAPTATION SATURDAY	HALLE TAYLOR	19.99	0	6467
2765	10	ADAPTATION SATURN	ANGELA RYDER	26.99	0	9350
2766	11	ADAPTATION SAVANNAH	NICOLAS KINNEAR	16.99	0	7630
2767	4	ADAPTATION SCALAWAG	ANGELA MCCONAUGHEY	27.99	0	2613
2768	1	ADAPTATION SCARFACE	ALEC VOIGHT	12.99	0	3495
2769	5	ADAPTATION SCHOOL	DIANE AKROYD	22.99	0	7939
2770	5	ADAPTATION SCISSORHANDS	LEELEE BERRY	16.99	0	9268
2771	5	ADAPTATION SCORPION	JOAN LOREN	9.99	0	45
2772	13	ADAPTATION SEA	LIZA CAMPBELL	26.99	0	3324
2773	2	ADAPTATION SEABISCUIT	EDWARD BLANCHETT	11.99	0	652
2774	8	ADAPTATION SEARCHERS	AUDREY LAW	23.99	0	5783
2775	8	ADAPTATION SEATTLE	MARLENE KIDMAN	10.99	0	5758
2776	1	ADAPTATION SECRET	CHEVY COOPER	18.99	0	917
2777	8	ADAPTATION SECRETARY	DREW WINSLET	11.99	0	2760
2778	7	ADAPTATION SECRETS	HALLE TORN	23.99	0	6371
2779	12	ADAPTATION SENSE	DARYL HURT	26.99	0	4241
2780	7	ADAPTATION SENSIBILITY	WALTER MIRANDA	10.99	0	8360
2781	10	ADAPTATION SEVEN	ADAM PESCI	25.99	0	1914
2782	15	ADAPTATION SHAKESPEARE	CHRISTIAN NEESON	11.99	0	9754
2783	7	ADAPTATION SHANE	SCARLETT DAFOE	24.99	0	8833
2784	7	ADAPTATION SHANGHAI	GWYNETH MCGREGOR	21.99	0	5261
2785	1	ADAPTATION SHAWSHANK	CHRISTOPHER STALLONE	29.99	0	8927
2786	13	ADAPTATION SHEPHERD	LISA KEATON	25.99	0	8049
2787	16	ADAPTATION SHINING	JOAN CRAWFORD	12.99	0	2407
2788	3	ADAPTATION SHIP	JAYNE NEESON	9.99	0	3230
2789	15	ADAPTATION SHOCK	VIVIEN SANDLER	14.99	0	3994
2790	13	ADAPTATION SHOOTIST	ED HANNAH	29.99	0	1338
2791	14	ADAPTATION SHOW	MARLENE COOPER	18.99	0	9507
2792	5	ADAPTATION SHREK	CARRIE WILSON	24.99	0	4112
2793	16	ADAPTATION SHRUNK	BELA DIETRICH	17.99	0	4961
2794	12	ADAPTATION SIDE	FRANK COSTNER	23.99	0	6902
2795	2	ADAPTATION SIEGE	BOB DAMON	16.99	0	4587
2796	8	ADAPTATION SIERRA	LUCILLE AKROYD	11.99	0	6006
2797	2	ADAPTATION SILENCE	KIRSTEN PHOENIX	13.99	0	6991
2798	10	ADAPTATION SILVERADO	WHOOPI HOPE	23.99	0	2503
2799	3	ADAPTATION SIMON	JACK MARTIN	19.99	0	8541
2800	3	ADAPTATION SINNERS	ANNETTE GRANT	14.99	0	2270
2801	12	ADAPTATION SISTER	DUSTIN CRUISE	16.99	0	7040
2802	16	ADAPTATION SKY	JANE GOODING	19.99	0	9036
2803	4	ADAPTATION SLACKER	GREGORY CRONYN	12.99	0	2121
2804	7	ADAPTATION SLEEPING	RITA BASINGER	27.99	0	1134
2805	12	ADAPTATION SLEEPLESS	JUDE PALTROW	25.99	0	2276
2806	1	ADAPTATION SLEEPY	JACK ODONNELL	14.99	0	7315
2807	16	ADAPTATION SLEUTH	CAMERON WRAY	17.99	0	6882
2808	5	ADAPTATION SLING	SCARLETT PFEIFFER	22.99	0	7419
2809	14	ADAPTATION SLIPPER	RAY GABLE	22.99	0	3282
2810	13	ADAPTATION SLUMS	ALICIA WALKEN	14.99	0	39
2811	9	ADAPTATION SMILE	MICHAEL PENN	28.99	0	7373
2812	11	ADAPTATION SMOKING	NATALIE TURNER	25.99	0	2400
2813	8	ADAPTATION SMOOCHY	WHOOPI LEWIS	15.99	0	8825
2814	2	ADAPTATION SNATCH	DREW BEATTY	27.99	0	4479
2815	4	ADAPTATION SNATCHERS	HARVEY JACKMAN	13.99	0	867
2816	4	ADAPTATION SNOWMAN	RENEE DREYFUSS	28.99	0	7617
2817	11	ADAPTATION SOLDIERS	MATT TAUTOU	17.99	0	9552
2818	11	ADAPTATION SOMETHING	JULIETTE BOGART	21.99	0	7375
2819	8	ADAPTATION SONG	RAY JOHANSSON	24.99	0	5109
2820	3	ADAPTATION SONS	ADRIEN LANSBURY	20.99	0	7791
2821	11	ADAPTATION SORORITY	ANNE ANISTON	18.99	0	2679
2822	4	ADAPTATION SOUP	CARY MATTHAU	27.99	0	7716
2823	14	ADAPTATION SOUTH	SANDRA MINELLI	16.99	0	2931
2824	2	ADAPTATION SPARTACUS	RAY PFEIFFER	27.99	0	1557
2825	7	ADAPTATION SPEAKEASY	MINNIE MCCONAUGHEY	17.99	0	5019
2826	3	ADAPTATION SPEED	JULIANNE RYAN	13.99	0	4698
2827	8	ADAPTATION SPICE	BEN HAYEK	22.99	0	909
2828	7	ADAPTATION SPIKING	NEVE BOLGER	14.99	0	9783
2829	10	ADAPTATION SPINAL	MILLA KIDMAN	16.99	0	1571
2830	9	ADAPTATION SPIRIT	PAUL RYDER	13.99	0	9333
2831	12	ADAPTATION SPIRITED	MORGAN GARCIA	14.99	0	9497
2832	12	ADAPTATION SPLASH	HARRISON BLOOM	25.99	0	6537
2833	15	ADAPTATION SPLENDOR	OLYMPIA CAGE	22.99	0	2031
2834	10	ADAPTATION SPOILERS	NICK WINFREY	15.99	0	1448
2835	8	ADAPTATION SPY	UMA STALLONE	14.99	0	1319
2836	3	ADAPTATION SQUAD	JOHNNY RYDER	27.99	0	877
2837	14	ADAPTATION STAGE	CLINT RICKMAN	13.99	0	9090
2838	15	ADAPTATION STAGECOACH	ANGELA HUDSON	22.99	0	4492
2839	14	ADAPTATION STALLION	JACK PACINO	20.99	0	7513
2840	12	ADAPTATION STAMPEDE	LEELEE IRONS	22.99	0	6634
2841	13	ADAPTATION STAR	JESSICA TURNER	14.99	0	5113
2842	6	ADAPTATION STATE	FARRAH MOSTEL	20.99	0	8546
2843	8	ADAPTATION STEEL	GINA PRESLEY	19.99	0	4177
2844	16	ADAPTATION STEERS	CANDICE DAY-LEWIS	16.99	0	1347
2845	2	ADAPTATION STEPMOM	LIZA JOVOVICH	24.99	0	3520
2846	7	ADAPTATION STING	ELVIS WEAVER	26.99	0	699
2847	6	ADAPTATION STOCK	NEVE MANSFIELD	22.99	0	6146
2848	8	ADAPTATION STONE	HARRISON MARX	26.99	0	7626
2849	4	ADAPTATION STORM	WINONA BENING	16.99	0	7771
2850	8	ADAPTATION STORY	FARRAH LANSBURY	11.99	0	4438
2851	8	ADAPTATION STRAIGHT	HILARY MOORE	24.99	0	6224
2852	13	ADAPTATION STRANGELOVE	DIANE SUVARI	19.99	0	3703
2853	3	ADAPTATION STRANGER	WILLEM WINSLET	19.99	0	883
2854	5	ADAPTATION STRANGERS	CHARLIZE ANISTON	14.99	0	5822
2855	1	ADAPTATION STREAK	CATE SUVARI	15.99	0	4138
2856	13	ADAPTATION STREETCAR	ANTHONY HAWKE	12.99	0	5671
2857	13	ADAPTATION STRICTLY	INGRID TYLER	29.99	0	9064
2858	6	ADAPTATION SUBMARINE	SHIRLEY LEIGH	16.99	0	6724
2859	7	ADAPTATION SUGAR	MERYL FORD	21.99	0	583
2860	3	ADAPTATION SUICIDES	SPENCER MCDORMAND	15.99	0	8643
2861	12	ADAPTATION SUIT	EWAN ODONNELL	25.99	0	4045
2862	6	ADAPTATION SUMMER	GEOFFREY MATTHAU	25.99	0	7521
2863	11	ADAPTATION SUN	GEOFFREY WINFREY	20.99	0	3878
2864	4	ADAPTATION SUNDANCE	NATALIE PITT	28.99	0	3193
2865	16	ADAPTATION SUNRISE	UMA HUSTON	27.99	0	8789
2866	13	ADAPTATION SUNSET	LANA JOHANSSON	9.99	0	4151
2867	7	ADAPTATION SUPER	ALEC MCGREGOR	24.99	0	6371
2868	9	ADAPTATION SUPERFLY	LIAM BERGMAN	26.99	0	9196
2869	4	ADAPTATION SUSPECTS	MARY TANDY	28.99	0	9818
2870	5	ADAPTATION SWARM	JESSICA REYNOLDS	13.99	0	2446
2871	2	ADAPTATION SWEDEN	NICK HARRIS	22.99	0	179
2872	2	ADAPTATION SWEET	MARISA TAYLOR	10.99	0	429
2873	12	ADAPTATION SWEETHEARTS	CANDICE BULLOCK	16.99	0	7463
2874	5	ADAPTATION TADPOLE	LIAM CLOSE	28.99	0	3924
2875	15	ADAPTATION TALENTED	CHEVY GABLE	16.99	0	8103
2876	10	ADAPTATION TARZAN	DENZEL MCKELLEN	16.99	0	6537
2877	6	ADAPTATION TAXI	JULIANNE FREEMAN	9.99	0	1479
2878	1	ADAPTATION TEEN	EWAN COSTNER	12.99	0	2283
2879	15	ADAPTATION TELEGRAPH	HENRY RICKMAN	20.99	0	4881
2880	15	ADAPTATION TELEMARK	ROSIE MALDEN	10.99	0	3957
2881	15	ADAPTATION TEMPLE	ALEC LAW	11.99	0	3067
2882	13	ADAPTATION TENENBAUMS	MARLENE DREYFUSS	14.99	0	916
2883	7	ADAPTATION TEQUILA	ELVIS FREEMAN	23.99	0	7731
2884	15	ADAPTATION TERMINATOR	KATHARINE HESTON	15.99	0	2307
2885	13	ADAPTATION TEXAS	RIVER TEMPLE	22.99	0	7762
2886	1	ADAPTATION THEORY	GREG SPACEK	10.99	0	2540
2887	7	ADAPTATION THIEF	KARL OLIVIER	9.99	0	8274
2888	2	ADAPTATION THIN	CLARK HANNAH	17.99	0	6954
2889	3	ADAPTATION TIES	CARY BALL	23.99	0	935
2890	15	ADAPTATION TIGHTS	WILL COSTNER	24.99	0	9268
2891	9	ADAPTATION TIMBERLAND	PARKER TAYLOR	27.99	0	7056
2892	2	ADAPTATION TITANIC	HUME FONDA	22.99	0	3771
2893	8	ADAPTATION TITANS	PENELOPE IRONS	22.99	0	8879
2894	6	ADAPTATION TOMATOES	THORA BALE	19.99	0	2907
2895	10	ADAPTATION TOMORROW	JESSICA NEWMAN	20.99	0	2899
2896	8	ADAPTATION TOOTSIE	CHRIS WILLIAMS	14.99	0	1141
2897	16	ADAPTATION TORQUE	JEFF WEST	16.99	0	8097
2898	12	ADAPTATION TOURIST	FRANK BOGART	19.99	0	1761
2899	7	ADAPTATION TOWERS	DENNIS BRODY	15.99	0	9539
2900	10	ADAPTATION TOWN	LUCILLE CRUISE	10.99	0	550
2901	6	ADAPTATION TRACY	AL DEE	20.99	0	8422
2902	11	ADAPTATION TRADING	REESE HEPBURN	11.99	0	4096
2903	15	ADAPTATION TRAFFIC	JUDI KEATON	13.99	0	2717
2904	7	ADAPTATION TRAIN	HILARY HEPBURN	21.99	0	15
2905	9	ADAPTATION TRAINSPOTTING	DAN GOLDBERG	12.99	0	9430
2906	4	ADAPTATION TRAMP	CHRISTOPHER SORVINO	14.99	0	6538
2907	2	ADAPTATION TRANSLATION	BETTE ASTAIRE	27.99	0	8745
2908	5	ADAPTATION TRAP	HILARY ASTAIRE	25.99	0	4262
2909	2	ADAPTATION TREASURE	SALLY MARX	18.99	0	6183
2910	8	ADAPTATION TREATMENT	ZERO POSEY	22.99	0	4585
2911	10	ADAPTATION TRIP	FRANCES CHASE	25.99	0	6627
2912	7	ADAPTATION TROJAN	MEL IRONS	19.99	0	8015
2913	7	ADAPTATION TROOPERS	RIVER MOSTEL	25.99	0	527
2914	4	ADAPTATION TROUBLE	MARY KIDMAN	10.99	1	8648
2915	12	ADAPTATION TRUMAN	LIV HORNE	23.99	0	5437
2916	3	ADAPTATION TURN	MICHELLE PFEIFFER	18.99	0	1028
2917	2	ADAPTATION TUXEDO	LAURENCE WATSON	25.99	0	9590
2918	10	ADAPTATION TWISTED	LIV STREEP	17.99	0	812
2919	8	ADAPTATION TYCOON	LIV STALLONE	11.99	0	6137
2920	16	ADAPTATION UNBREAKABLE	BELA MARTIN	21.99	0	2018
2921	3	ADAPTATION UNCUT	THORA HEPBURN	26.99	0	4330
2922	16	ADAPTATION UNDEFEATED	HALLE WINFREY	20.99	0	8214
2923	9	ADAPTATION UNFAITHFUL	MATT FORD	11.99	0	2980
2924	4	ADAPTATION UNFORGIVEN	CHARLES DAVIS	26.99	0	567
2925	7	ADAPTATION UNITED	MARY FINNEY	19.99	0	9503
2926	12	ADAPTATION UNTOUCHABLES	HELEN BERRY	22.99	0	2561
2927	2	ADAPTATION UPRISING	DORIS TEMPLE	18.99	0	9808
2928	5	ADAPTATION UPTOWN	GEOFFREY WAHLBERG	28.99	0	681
2929	4	ADAPTATION USUAL	EWAN DENCH	16.99	0	6129
2930	7	ADAPTATION VACATION	TOM JACKMAN	10.99	0	8628
2931	1	ADAPTATION VALENTINE	TOM PECK	17.99	0	8639
2932	11	ADAPTATION VALLEY	NICOLAS HAYEK	27.99	0	1620
2933	15	ADAPTATION VAMPIRE	BEN BULLOCK	13.99	0	1264
2934	5	ADAPTATION VANILLA	HARRISON DREYFUSS	20.99	0	4336
2935	3	ADAPTATION VANISHED	THORA BERGMAN	11.99	0	9290
2936	16	ADAPTATION VANISHING	MARILYN CRUISE	27.99	0	9935
2937	13	ADAPTATION VARSITY	INGRID DUKAKIS	19.99	0	2822
2938	11	ADAPTATION VELVET	HUMPHREY BERRY	24.99	0	4632
2939	15	ADAPTATION VERTIGO	NICOLAS LANCASTER	14.99	0	3930
2940	11	ADAPTATION VICTORY	JIM DIAZ	21.99	0	6256
2941	9	ADAPTATION VIDEOTAPE	RITA FINNEY	12.99	0	4345
2942	3	ADAPTATION VIETNAM	NATALIE WOOD	21.99	0	9193
2943	14	ADAPTATION VILLAIN	ZERO CHASE	14.99	0	2775
2944	12	ADAPTATION VIRGIN	ROBERT RUSSELL	19.99	0	9316
2945	15	ADAPTATION VIRGINIAN	DANIEL PENN	16.99	0	5595
2946	16	ADAPTATION VIRTUAL	SHIRLEY TANDY	25.99	0	1074
2947	4	ADAPTATION VISION	BOB DAVIS	29.99	0	5865
2948	14	ADAPTATION VOICE	NICOLE NICHOLSON	27.99	0	6553
2949	3	ADAPTATION VOLCANO	JAYNE PACINO	29.99	0	4770
2950	15	ADAPTATION VOLUME	DAN BERGMAN	11.99	0	5190
2951	11	ADAPTATION VOYAGE	HELEN GUINESS	20.99	0	4238
2952	11	ADAPTATION WAGON	MAE HAWKE	24.99	0	4429
2953	6	ADAPTATION WAIT	CANDICE DEGENERES	10.99	0	771
2954	12	ADAPTATION WAKE	PEARL DEPP	12.99	0	9677
2955	11	ADAPTATION WALLS	ANDY CAGE	26.99	0	4552
2956	6	ADAPTATION WANDA	RUBY TORN	24.99	0	289
2957	3	ADAPTATION WAR	JANE BOGART	26.99	0	8028
2958	5	ADAPTATION WARDROBE	ANDY CRONYN	16.99	0	1420
2959	8	ADAPTATION WARLOCK	HILARY ZELLWEGER	13.99	0	6178
2960	4	ADAPTATION WARS	OLYMPIA SOBIESKI	13.99	0	9870
2961	12	ADAPTATION WASH	SIDNEY BALL	20.99	0	3320
2962	10	ADAPTATION WASTELAND	JAMES WILSON	9.99	0	2792
2963	13	ADAPTATION WATCH	JESSICA BAILEY	26.99	0	7239
2964	16	ADAPTATION WATERFRONT	MORGAN SUVARI	16.99	0	8967
2965	16	ADAPTATION WATERSHIP	NATALIE DOUGLAS	24.99	0	4037
2966	12	ADAPTATION WEDDING	JEFF DAFOE	22.99	0	2415
2967	16	ADAPTATION WEEKEND	DEBBIE EASTWOOD	17.99	0	9844
2968	11	ADAPTATION WEREWOLF	AL BRANDO	11.99	0	4189
2969	14	ADAPTATION WEST	ETHAN WAYNE	20.99	0	3560
2970	8	ADAPTATION WESTWARD	MAE FIENNES	13.99	0	1490
2971	10	ADAPTATION WHALE	GRETA RYDER	9.99	0	897
2972	5	ADAPTATION WHISPERER	HILARY GARLAND	19.99	0	6966
2973	8	ADAPTATION WIFE	RICHARD HAWKE	19.99	0	7631
2974	15	ADAPTATION WILD	MICHELLE GOODING	12.99	0	242
2975	9	ADAPTATION WILLOW	GRACE HAWN	12.99	0	4018
2976	6	ADAPTATION WIND	DANIEL DAMON	23.99	0	6127
2977	13	ADAPTATION WINDOW	WILLEM KILMER	12.99	0	7301
2978	14	ADAPTATION WISDOM	CHARLES JOVOVICH	22.99	1	6795
2979	7	ADAPTATION WITCHES	ANNETTE TURNER	11.99	0	174
2980	3	ADAPTATION WIZARD	JANE MCKELLEN	19.99	0	485
2981	15	ADAPTATION WOLVES	ELLEN CAGE	10.99	0	5071
2982	12	ADAPTATION WOMEN	ANGELA LOLLOBRIGIDA	23.99	0	731
2983	7	ADAPTATION WON	LAURA LUGOSI	20.99	0	5786
2984	4	ADAPTATION WONDERFUL	JOHN NEWMAN	15.99	0	5825
2985	6	ADAPTATION WONDERLAND	DENZEL WILLIAMS	24.99	0	259
2986	13	ADAPTATION WONKA	CHEVY FOSTER	10.99	0	9696
2987	10	ADAPTATION WORDS	KENNETH CAINE	21.99	0	2784
2988	11	ADAPTATION WORKER	SANDRA DEGENERES	14.99	0	1134
2989	14	ADAPTATION WORKING	RALPH BAILEY	15.99	0	5880
2990	15	ADAPTATION WORLD	KATHARINE MIRANDA	11.99	0	9909
2991	3	ADAPTATION WORST	GOLDIE DAMON	15.99	0	7680
2992	5	ADAPTATION WRATH	SPENCER SORVINO	26.99	0	7304
2993	2	ADAPTATION WRONG	WHOOPI BRODY	29.99	0	7628
2994	2	ADAPTATION WYOMING	RAY DEAN	27.99	0	1257
2995	8	ADAPTATION YENTL	PAUL HUDSON	9.99	0	1788
2996	16	ADAPTATION YOUNG	HENRY POITIER	15.99	0	6513
2997	2	ADAPTATION YOUTH	JOE FREEMAN	9.99	0	9240
2998	12	ADAPTATION ZHIVAGO	ANGELINA DREYFUSS	23.99	0	4335
2999	8	ADAPTATION ZOOLANDER	MARY FORD	14.99	0	2160
3000	7	ADAPTATION ZORRO	MEL NEESON	12.99	0	2791
3001	6	AFFAIR ACADEMY	ALEC MOSTEL	24.99	1	919
3002	6	AFFAIR ACE	JANE BLANCHETT	26.99	0	6132
3003	13	AFFAIR ADAPTATION	SIGOURNEY SINATRA	26.99	0	1487
3004	5	AFFAIR AFFAIR	JOHN WITHERSPOON	28.99	0	6980
3005	3	AFFAIR AFRICAN	HALLE MCDORMAND	26.99	0	395
3006	2	AFFAIR AGENT	MICHELLE BRANDO	11.99	0	6959
3007	4	AFFAIR AIRPLANE	PENELOPE DAMON	22.99	0	8692
3008	5	AFFAIR AIRPORT	MENA STREEP	12.99	0	2076
3009	6	AFFAIR ALABAMA	CUBA WASHINGTON	25.99	0	4282
3010	9	AFFAIR ALADDIN	ANGELINA WRAY	27.99	0	8281
3011	15	AFFAIR ALAMO	UMA TYLER	21.99	0	7795
3012	5	AFFAIR ALASKA	WINONA DERN	10.99	0	548
3013	16	AFFAIR ALI	SOPHIA CROWE	22.99	0	5729
3014	14	AFFAIR ALICE	JUDI NEESON	9.99	0	3608
3015	8	AFFAIR ALIEN	GRETA WINFREY	19.99	0	1632
3016	6	AFFAIR ALLEY	AUDREY POITIER	15.99	0	1121
3017	2	AFFAIR ALONE	HALLE MOSTEL	10.99	0	2859
3018	2	AFFAIR ALTER	JOAN PECK	9.99	0	8257
3019	10	AFFAIR AMADEUS	JOHNNY DAVIS	11.99	0	9631
3020	8	AFFAIR AMELIE	TIM PFEIFFER	25.99	0	7712
3021	16	AFFAIR AMERICAN	JULIA MARTIN	9.99	0	8734
3022	3	AFFAIR AMISTAD	KATE WILSON	20.99	0	2917
3023	14	AFFAIR ANACONDA	ADAM CAMPBELL	14.99	0	3633
3024	2	AFFAIR ANALYZE	LAURA POITIER	21.99	0	8345
3025	10	AFFAIR ANGELS	KIRK DUNST	19.99	0	8154
3026	5	AFFAIR ANNIE	INGRID BERRY	25.99	0	3093
3027	11	AFFAIR ANONYMOUS	ETHAN DOUGLAS	13.99	0	3004
3028	8	AFFAIR ANTHEM	JAYNE MCCONAUGHEY	19.99	0	6002
3029	14	AFFAIR ANTITRUST	GREGORY ALLEN	18.99	0	1889
3030	5	AFFAIR ANYTHING	JOHN CROWE	26.99	0	5929
3031	11	AFFAIR APACHE	MATT WILLIAMS	10.99	0	7916
3032	6	AFFAIR APOCALYPSE	AUDREY HARRIS	22.99	0	8753
3033	16	AFFAIR APOLLO	JOHNNY BOGART	17.99	0	3962
3034	16	AFFAIR ARABIA	IAN HOPE	16.99	0	281
3035	9	AFFAIR ARACHNOPHOBIA	DENNIS CHAPLIN	9.99	0	8987
3036	10	AFFAIR ARGONAUTS	SALLY MCKELLEN	14.99	0	6003
3037	2	AFFAIR ARIZONA	ADRIEN BERGMAN	11.99	0	6110
3038	1	AFFAIR ARK	MILLA NEESON	19.99	0	2965
3039	15	AFFAIR ARMAGEDDON	NICOLAS BASINGER	15.99	0	6270
3040	6	AFFAIR ARMY	PEARL VOIGHT	20.99	0	7639
3041	8	AFFAIR ARSENIC	HUGH KILMER	15.99	0	963
3042	15	AFFAIR ARTIST	CHRISTIAN THERON	28.99	0	8899
3043	9	AFFAIR ATLANTIS	KIM BAILEY	13.99	0	6201
3044	9	AFFAIR ATTACKS	MATTHEW HESTON	14.99	0	610
3045	15	AFFAIR ATTRACTION	WILLEM BLOOM	23.99	0	9071
3046	8	AFFAIR AUTUMN	JAYNE BOGART	26.99	0	2559
3047	15	AFFAIR BABY	CATE FIENNES	11.99	0	1544
3048	16	AFFAIR BACKLASH	CUBA PRESLEY	20.99	0	7230
3049	3	AFFAIR BADMAN	CHRIS KEATON	26.99	0	9150
3050	15	AFFAIR BAKED	ADRIEN NORTON	27.99	0	6545
3051	13	AFFAIR BALLOON	OLYMPIA SARANDON	13.99	0	1606
3052	8	AFFAIR BALLROOM	JODIE LOREN	22.99	0	7056
3053	13	AFFAIR BANG	JESSICA NOLTE	29.99	0	4474
3054	12	AFFAIR BANGER	WARREN HAWKE	26.99	0	7501
3055	13	AFFAIR BARBARELLA	JANE CLOSE	25.99	0	8031
3056	7	AFFAIR BAREFOOT	LISA SPACEK	12.99	0	2586
3057	6	AFFAIR BASIC	ROSIE LAW	26.99	0	5308
3058	9	AFFAIR BEACH	DENNIS WINFREY	29.99	0	4516
3059	7	AFFAIR BEAR	SALMA MCGREGOR	17.99	0	1209
3060	3	AFFAIR BEAST	FAY DENIRO	21.99	0	3336
3061	7	AFFAIR BEAUTY	CHRISTOPHER HOPKINS	29.99	0	2467
3062	5	AFFAIR BED	RIP WINSLET	11.99	0	11
3063	11	AFFAIR BEDAZZLED	WILL FIENNES	26.99	0	9099
3064	5	AFFAIR BEETHOVEN	KATE PINKETT	12.99	0	158
3065	5	AFFAIR BEHAVIOR	ELVIS DOUGLAS	20.99	0	2826
3066	15	AFFAIR BENEATH	NEVE DENIRO	10.99	0	3655
3067	6	AFFAIR BERETS	GREG JOHANSSON	11.99	0	1366
3068	3	AFFAIR BETRAYED	JEREMY DAY-LEWIS	11.99	0	7615
3069	1	AFFAIR BEVERLY	JON GARBO	20.99	0	6320
3070	9	AFFAIR BIKINI	SPENCER RYAN	26.99	0	7704
3071	2	AFFAIR BILKO	ALAN DEPP	26.99	0	2591
3072	4	AFFAIR BILL	OPRAH MCQUEEN	20.99	0	3521
3073	11	AFFAIR BINGO	LAURA TOMEI	11.99	1	6408
3074	15	AFFAIR BIRCH	ZERO AFFLECK	17.99	0	5160
3075	1	AFFAIR BIRD	GARY BRANDO	28.99	0	6665
3076	12	AFFAIR BIRDCAGE	SUSAN BALL	24.99	0	2422
3077	16	AFFAIR BIRDS	SHIRLEY BLANCHETT	24.99	0	6464
3078	2	AFFAIR BLACKOUT	KATE FIENNES	23.99	0	5333
3079	6	AFFAIR BLADE	KATE GARBO	15.99	0	869
3080	14	AFFAIR BLANKET	DANIEL RUSSELL	11.99	0	1364
3081	13	AFFAIR BLINDNESS	CLARK HOFFMAN	24.99	0	630
3082	16	AFFAIR BLOOD	CHARLTON CHASE	26.99	0	7846
3083	8	AFFAIR BLUES	BRUCE ZELLWEGER	9.99	0	5573
3084	10	AFFAIR BOILED	STEVE WITHERSPOON	11.99	0	6703
3085	4	AFFAIR BONNIE	JEREMY BRODY	17.99	0	1883
3086	9	AFFAIR BOOGIE	MADELINE BERGEN	23.99	0	8006
3087	13	AFFAIR BOONDOCK	WALTER PRESLEY	28.99	0	8610
3088	12	AFFAIR BORN	SALLY BOGART	25.99	0	5304
3089	6	AFFAIR BORROWERS	JUDY OLIVIER	14.99	0	8090
3090	16	AFFAIR BOULEVARD	TIM WRAY	17.99	0	1951
3091	10	AFFAIR BOUND	ELVIS TURNER	13.99	0	527
3092	1	AFFAIR BOWFINGER	RICHARD GOODING	29.99	0	4141
3093	14	AFFAIR BRANNIGAN	JUDY AFFLECK	23.99	0	6430
3094	4	AFFAIR BRAVEHEART	GREG COSTNER	24.99	0	1412
3095	9	AFFAIR BREAKFAST	CARY HACKMAN	19.99	0	5121
3096	11	AFFAIR BREAKING	INGRID GUINESS	28.99	0	305
3097	16	AFFAIR BRIDE	IAN MINELLI	25.99	0	7121
3098	4	AFFAIR BRIGHT	MIRA HUDSON	24.99	0	5270
3099	7	AFFAIR BRINGING	MICHAEL HARRIS	24.99	0	1493
3100	14	AFFAIR BROOKLYN	KENNETH PALTROW	29.99	0	3468
3101	9	AFFAIR BROTHERHOOD	NICOLAS THERON	28.99	0	3601
3102	16	AFFAIR BUBBLE	ADAM SOBIESKI	16.99	0	6282
3103	2	AFFAIR BUCKET	BRAD SWANK	25.99	0	2696
3104	6	AFFAIR BUGSY	MEG WILSON	9.99	0	8291
3105	3	AFFAIR BULL	KATE KUDROW	23.99	0	7371
3106	1	AFFAIR BULWORTH	LIV BALE	25.99	0	4484
3107	3	AFFAIR BUNCH	EWAN TYLER	12.99	0	9107
3108	13	AFFAIR BUTCH	PARKER FREEMAN	27.99	0	3603
3109	3	AFFAIR BUTTERFLY	GLENN HOPPER	26.99	0	161
3110	11	AFFAIR CABIN	KIRK MIRANDA	13.99	0	979
3111	16	AFFAIR CADDYSHACK	CATE HAWN	20.99	0	969
3112	1	AFFAIR CALENDAR	ADRIEN GOODING	14.99	0	2826
3113	4	AFFAIR CALIFORNIA	MADELINE FORD	29.99	0	7726
3114	6	AFFAIR CAMELOT	DREW GRANT	22.99	0	7096
3115	11	AFFAIR CAMPUS	GRETA THERON	13.99	0	7130
3116	6	AFFAIR CANDIDATE	CARY BACALL	18.99	0	3499
3117	9	AFFAIR CANDLES	NEVE MALDEN	20.99	0	2751
3118	14	AFFAIR CANYON	LISA BERGEN	19.99	0	8384
3119	5	AFFAIR CAPER	DIANE GABLE	19.99	0	4439
3120	4	AFFAIR CARIBBEAN	GLENN NEESON	20.99	0	4137
3121	5	AFFAIR CAROL	JANE DEAN	17.99	0	233
3122	12	AFFAIR CARRIE	LISA DENIRO	18.99	0	4891
3123	13	AFFAIR CASABLANCA	KIM NEESON	16.99	0	5861
3124	4	AFFAIR CASPER	TOM HARRIS	17.99	0	9399
3125	14	AFFAIR CASSIDY	LIAM BLOOM	13.99	0	5082
3126	10	AFFAIR CASUALTIES	NEVE TURNER	10.99	0	4223
3127	2	AFFAIR CAT	MATTHEW BASINGER	23.99	0	4894
3128	3	AFFAIR CATCH	CHEVY DOUGLAS	24.99	0	3109
3129	6	AFFAIR CAUSE	MIRA STALLONE	14.99	0	6144
3130	4	AFFAIR CELEBRITY	MILLA CAINE	25.99	0	3518
3131	6	AFFAIR CENTER	ELVIS WAYNE	9.99	1	5666
3132	8	AFFAIR CHAINSAW	LIV BENING	11.99	0	1438
3133	11	AFFAIR CHAMBER	JACK WALKEN	25.99	0	615
3134	2	AFFAIR CHAMPION	SOPHIA WINSLET	26.99	0	1694
3135	7	AFFAIR CHANCE	FRED HEPBURN	11.99	0	6361
3136	8	AFFAIR CHAPLIN	LAURA KUDROW	24.99	0	5683
3137	6	AFFAIR CHARADE	MADELINE BERGEN	28.99	0	3808
3138	2	AFFAIR CHARIOTS	GARY SPACEK	19.99	0	9653
3139	10	AFFAIR CHASING	UMA PFEIFFER	18.99	0	1769
3140	11	AFFAIR CHEAPER	LIAM WINSLET	28.99	0	8430
3141	10	AFFAIR CHICAGO	HILARY MATTHAU	12.99	0	9904
3142	12	AFFAIR CHICKEN	ANNE NORTON	16.99	0	2656
3143	12	AFFAIR CHILL	BRUCE PACINO	9.99	0	7321
3144	1	AFFAIR CHINATOWN	JEREMY RICKMAN	28.99	0	66
3145	3	AFFAIR CHISUM	WINONA TAYLOR	24.99	0	1068
3146	10	AFFAIR CHITTY	MIRA GRANT	29.99	0	847
3147	16	AFFAIR CHOCOLAT	PAUL DIAZ	9.99	0	3929
3148	5	AFFAIR CHOCOLATE	BRAD GABLE	17.99	0	3018
3149	2	AFFAIR CHRISTMAS	AUDREY HACKMAN	21.99	0	3059
3150	10	AFFAIR CIDER	CLARK HUNT	20.99	0	9881
3151	11	AFFAIR CINCINATTI	HARVEY ROBERTS	17.99	0	9173
3152	8	AFFAIR CIRCUS	CLINT PALTROW	14.99	0	7982
3153	11	AFFAIR CITIZEN	CHARLIZE AFFLECK	24.99	0	5406
3154	1	AFFAIR CLASH	TOM JOVOVICH	11.99	0	2838
3155	7	AFFAIR CLEOPATRA	OPRAH NEWMAN	21.99	0	9592
3156	10	AFFAIR CLERKS	NICK WAHLBERG	29.99	0	4865
3157	15	AFFAIR CLOCKWORK	DAN RYDER	10.99	0	9160
3158	14	AFFAIR CLONES	SYLVESTER OLIVIER	9.99	0	3112
3159	9	AFFAIR CLOSER	RITA HURT	19.99	0	9067
3160	13	AFFAIR CLUB	LAURA ALLEN	19.99	0	8206
3161	8	AFFAIR CLUE	NICOLAS CRUISE	13.99	0	583
3162	12	AFFAIR CLUELESS	SALLY BACALL	27.99	0	9079
3163	14	AFFAIR CLYDE	LEONARDO WAYNE	24.99	0	394
3164	1	AFFAIR COAST	JULIA JACKMAN	27.99	0	1104
3165	13	AFFAIR COLDBLOODED	CARMEN PITT	16.99	0	7285
3166	3	AFFAIR COLOR	SUSAN POITIER	28.99	0	703
3167	16	AFFAIR COMA	BRAD NICHOLSON	26.99	0	1837
3168	12	AFFAIR COMANCHEROS	CARRIE GUINESS	16.99	0	730
3169	7	AFFAIR COMFORTS	KIRSTEN CRAWFORD	27.99	0	5433
3170	1	AFFAIR COMMAND	FAY SINATRA	11.99	0	5552
3171	14	AFFAIR COMMANDMENTS	FRED FOSTER	25.99	0	2736
3172	14	AFFAIR CONEHEADS	VAL DEAN	28.99	0	5259
3173	3	AFFAIR CONFESSIONS	SUSAN RYAN	14.99	0	465
3174	6	AFFAIR CONFIDENTIAL	DIANE KAHN	27.99	0	2663
3175	7	AFFAIR CONFUSED	BEN HAWN	24.99	0	2538
3176	5	AFFAIR CONGENIALITY	LENA HARRIS	21.99	0	8523
3177	14	AFFAIR CONNECTICUT	BEN BAILEY	25.99	0	1371
3178	6	AFFAIR CONNECTION	TIM BOLGER	14.99	0	644
3179	5	AFFAIR CONQUERER	LAURA NORTON	19.99	0	9878
3180	13	AFFAIR CONSPIRACY	HUMPHREY ANISTON	27.99	0	9538
3181	2	AFFAIR CONTACT	GROUCHO ASTAIRE	24.99	0	5421
3182	10	AFFAIR CONTROL	LANA HORNE	22.99	0	5480
3183	13	AFFAIR CONVERSATION	MARLENE MARX	24.99	0	121
3184	13	AFFAIR CORE	MICHAEL CHAPLIN	16.99	0	2799
3185	6	AFFAIR COWBOY	FRANK HORNE	24.99	0	407
3186	12	AFFAIR CRAFT	ANNETTE HOPPER	10.99	0	6706
3187	10	AFFAIR CRANES	CATE POSEY	12.99	0	4077
3188	12	AFFAIR CRAZY	AL CRUISE	17.99	0	8702
3189	7	AFFAIR CREATURES	ALBERT OLIVIER	11.99	0	7000
3190	7	AFFAIR CREEPERS	CHRIS HAWKE	23.99	0	4942
3191	12	AFFAIR CROOKED	VIVIEN TEMPLE	25.99	0	1282
3192	8	AFFAIR CROSSING	SEAN LANSBURY	21.99	0	2815
3193	16	AFFAIR CROSSROADS	JOAN HUNT	9.99	0	3886
3194	14	AFFAIR CROW	BETTE DEPP	27.99	0	1493
3195	10	AFFAIR CROWDS	KIRK PFEIFFER	24.99	0	7293
3196	5	AFFAIR CRUELTY	LIAM BRANDO	13.99	0	5551
3197	6	AFFAIR CRUSADE	CAMERON FORD	13.99	0	8566
3198	8	AFFAIR CRYSTAL	GOLDIE TYLER	29.99	0	1892
3199	6	AFFAIR CUPBOARD	JAYNE RUSSELL	18.99	0	7942
3200	10	AFFAIR CURTAIN	JULIA DRIVER	12.99	0	9183
3201	15	AFFAIR CYCLONE	ALICIA EASTWOOD	19.99	0	9199
3202	1	AFFAIR DADDY	ELLEN STALLONE	12.99	0	1773
3203	1	AFFAIR DAISY	BETTE KUDROW	16.99	0	34
3204	9	AFFAIR DALMATIONS	RAY TAYLOR	29.99	0	4811
3205	13	AFFAIR DANCES	PARKER TYLER	15.99	0	8165
3206	4	AFFAIR DANCING	CANDICE WEST	14.99	0	6279
3207	3	AFFAIR DANGEROUS	JOAN IRONS	17.99	0	5249
3208	10	AFFAIR DARES	AUDREY NEESON	23.99	0	5894
3209	12	AFFAIR DARKNESS	JESSICA LANCASTER	19.99	0	7802
3210	16	AFFAIR DARKO	MERYL FAWCETT	24.99	0	7578
3211	9	AFFAIR DARLING	MILLA SILVERSTONE	23.99	0	1502
3212	5	AFFAIR DARN	MAE DAY-LEWIS	25.99	0	2881
3213	5	AFFAIR DATE	VIVIEN DEGENERES	16.99	0	9688
3214	16	AFFAIR DAUGHTER	JULIA MATTHAU	17.99	0	520
3215	4	AFFAIR DAWN	GROUCHO BEATTY	27.99	0	9610
3216	11	AFFAIR DAY	PEARL FORD	16.99	0	8343
3217	9	AFFAIR DAZED	ANNE EASTWOOD	11.99	0	6982
3218	7	AFFAIR DECEIVER	TOM GARBO	17.99	0	8632
3219	6	AFFAIR DEEP	JODIE NEWMAN	27.99	0	5740
3220	15	AFFAIR DEER	MADELINE DREYFUSS	14.99	0	4236
3221	4	AFFAIR DELIVERANCE	ORLANDO SILVERSTONE	9.99	0	7670
3222	14	AFFAIR DESERT	ANTHONY NEESON	28.99	0	1328
3223	10	AFFAIR DESIRE	JOHN DEGENERES	20.99	0	2073
3224	7	AFFAIR DESPERATE	SEAN WINSLET	27.99	0	9651
3225	8	AFFAIR DESTINATION	EDWARD ROBBINS	10.99	0	4152
3226	9	AFFAIR DESTINY	DORIS EASTWOOD	14.99	0	3937
3227	1	AFFAIR DETAILS	ANNETTE CRAWFORD	11.99	0	8723
3228	4	AFFAIR DETECTIVE	CAMERON OLIVIER	24.99	0	7360
3229	16	AFFAIR DEVIL	MINNIE MOORE	26.99	0	5629
3230	13	AFFAIR DIARY	GRACE AKROYD	9.99	0	3965
3231	8	AFFAIR DINOSAUR	MICHELLE MCCONAUGHEY	23.99	0	247
3232	2	AFFAIR DIRTY	DARYL WEAVER	11.99	0	2950
3233	1	AFFAIR DISCIPLE	WOODY FAWCETT	11.99	0	2417
3234	14	AFFAIR DISTURBING	SISSY WOOD	20.99	0	4433
3235	3	AFFAIR DIVIDE	JEFF MALDEN	18.99	0	5506
3236	14	AFFAIR DIVINE	CHRISTIAN BERGMAN	20.99	0	693
3237	10	AFFAIR DIVORCE	ALAN SMITH	25.99	0	760
3238	2	AFFAIR DOCTOR	HELEN WILLIAMS	10.99	0	4261
3239	6	AFFAIR DOGMA	IAN WAHLBERG	13.99	0	2182
3240	11	AFFAIR DOLLS	RIP MCCONAUGHEY	11.99	0	4372
3241	11	AFFAIR DONNIE	JUDY WEAVER	26.99	0	2618
3242	15	AFFAIR DOOM	BEN BOGART	28.99	0	343
3243	16	AFFAIR DOORS	WOODY WINFREY	16.99	0	636
3244	13	AFFAIR DORADO	WINONA GOLDBERG	13.99	0	4788
3245	7	AFFAIR DOUBLE	BRAD DIAZ	14.99	0	1812
3246	11	AFFAIR DOUBTFIRE	CARRIE BALL	13.99	0	6361
3247	8	AFFAIR DOWNHILL	NEVE ROBERTS	20.99	0	6188
3248	10	AFFAIR DOZEN	LEELEE ODONNELL	20.99	0	6461
3249	11	AFFAIR DRACULA	ALBERT TEMPLE	21.99	0	6209
3250	2	AFFAIR DRAGON	SHIRLEY KELLY	13.99	0	2597
3251	6	AFFAIR DRAGONFLY	FRED HOPKINS	19.99	0	1760
3252	3	AFFAIR DREAM	WALTER BOLGER	27.99	0	6536
3253	8	AFFAIR DRIFTER	GREGORY DAVIS	10.99	0	4191
3254	12	AFFAIR DRIVER	FRANK HANNAH	24.99	0	3880
3255	6	AFFAIR DRIVING	STEVE BRANAGH	14.99	0	6863
3256	9	AFFAIR DROP	CHARLES NEWMAN	26.99	0	7883
3257	16	AFFAIR DRUMLINE	SIGOURNEY FAWCETT	28.99	0	5323
3258	10	AFFAIR DRUMS	NICOLAS MOORE	28.99	0	5197
3259	6	AFFAIR DUCK	SYLVESTER HOPPER	22.99	0	9365
3260	1	AFFAIR DUDE	ANGELINA LEWIS	29.99	0	3456
3261	11	AFFAIR DUFFEL	ALAN FONDA	25.99	0	1878
3262	10	AFFAIR DUMBO	JOHNNY CAGE	18.99	0	6664
3263	16	AFFAIR DURHAM	GINA NEESON	24.99	0	611
3264	5	AFFAIR DWARFS	JULIANNE WINFREY	12.99	0	7276
3265	2	AFFAIR DYING	FRED NICHOLSON	12.99	0	1260
3266	9	AFFAIR DYNAMITE	JESSICA DREYFUSS	20.99	0	6064
3267	12	AFFAIR EAGLES	NICK MINELLI	13.99	0	8132
3268	15	AFFAIR EARLY	JOE BRANAGH	13.99	0	951
3269	5	AFFAIR EARRING	ANTHONY BRANDO	25.99	0	6994
3270	9	AFFAIR EARTH	HARRISON HAWKE	26.99	0	101
3271	16	AFFAIR EASY	FRANCES BLOOM	17.99	0	3580
3272	1	AFFAIR EDGE	ZERO FORD	24.99	0	1070
3273	9	AFFAIR EFFECT	DENNIS HAYEK	9.99	0	619
3274	3	AFFAIR EGG	CHRISTOPHER THERON	13.99	0	4686
3275	15	AFFAIR EGYPT	SHIRLEY CRAWFORD	14.99	0	4639
3276	5	AFFAIR ELEMENT	KIM WALKEN	21.99	0	1751
3277	15	AFFAIR ELEPHANT	JUDY FISHER	28.99	0	556
3278	1	AFFAIR ELF	JODIE MCGREGOR	14.99	0	977
3279	6	AFFAIR ELIZABETH	WILLIAM SANDLER	19.99	0	6467
3280	16	AFFAIR EMPIRE	RIVER TURNER	26.99	0	8106
3281	5	AFFAIR ENCINO	NICK HUNT	27.99	0	598
3282	1	AFFAIR ENCOUNTERS	HENRY WOOD	20.99	0	4604
3283	10	AFFAIR ENDING	BETTE WILSON	10.99	0	7575
3284	3	AFFAIR ENEMY	KIRK KILMER	12.99	0	5662
3285	13	AFFAIR ENGLISH	JOAN WOOD	22.99	0	6605
3286	8	AFFAIR ENOUGH	CARY CAINE	12.99	0	1857
3287	4	AFFAIR ENTRAPMENT	CHRISTOPHER BALE	22.99	0	978
3288	2	AFFAIR ESCAPE	ANNETTE CROWE	12.99	0	2866
3289	15	AFFAIR EVE	ROBERT HOFFMAN	19.99	0	8563
3290	1	AFFAIR EVERYONE	RUBY HARRIS	20.99	0	6782
3291	4	AFFAIR EVOLUTION	RITA HUNT	15.99	0	8178
3292	9	AFFAIR EXCITEMENT	SALLY TEMPLE	23.99	0	4406
3293	13	AFFAIR EXORCIST	LUCILLE LOREN	26.99	0	8961
3294	3	AFFAIR EXPECATIONS	GREG NOLTE	29.99	0	9421
3295	14	AFFAIR EXPENDABLE	GREGORY DAY-LEWIS	22.99	0	3813
3296	6	AFFAIR EXPRESS	RUSSELL WAYNE	12.99	0	4961
3297	16	AFFAIR EXTRAORDINARY	HARRISON ROBERTS	26.99	0	8724
3298	5	AFFAIR EYES	JENNIFER DENCH	27.99	0	2050
3299	13	AFFAIR FACTORY	SIDNEY DAY	11.99	0	543
3300	2	AFFAIR FALCON	EWAN WRAY	17.99	0	315
3301	13	AFFAIR FAMILY	WILL WOOD	22.99	0	2417
3302	3	AFFAIR FANTASIA	ALAN BRIDGES	20.99	0	4778
3303	7	AFFAIR FANTASY	MIRA DAVIS	26.99	0	8046
3304	1	AFFAIR FARGO	ALBERT TRACY	28.99	0	1986
3305	16	AFFAIR FATAL	CUBA BRANDO	14.99	0	8391
3306	5	AFFAIR FEATHERS	ROBERT FOSTER	14.99	0	9712
3307	9	AFFAIR FELLOWSHIP	BETTE CHAPLIN	20.99	0	326
3308	1	AFFAIR FERRIS	EDWARD BERRY	24.99	0	3574
3309	9	AFFAIR FEUD	ELVIS WOOD	20.99	0	3006
3310	13	AFFAIR FEVER	IAN WALKEN	28.99	0	9532
3311	13	AFFAIR FICTION	FRANK JOVOVICH	21.99	0	2970
3312	10	AFFAIR FIDDLER	JENNIFER FIELD	23.99	0	1307
3313	12	AFFAIR FIDELITY	DEBBIE TAUTOU	29.99	0	1406
3314	6	AFFAIR FIGHT	CARRIE CARREY	21.99	0	584
3315	15	AFFAIR FINDING	WILLIAM HUNT	15.99	0	1859
3316	4	AFFAIR FIRE	MERYL DAVIS	20.99	0	4807
3317	14	AFFAIR FIREBALL	RAY HAYEK	15.99	0	6417
3318	7	AFFAIR FIREHOUSE	JUDY SARANDON	22.99	0	1161
3319	13	AFFAIR FISH	ELVIS BERGMAN	27.99	0	9732
3320	16	AFFAIR FLAMINGOS	JEFF KEITEL	28.99	0	8697
3321	3	AFFAIR FLASH	BEN BEATTY	26.99	0	9151
3322	5	AFFAIR FLATLINERS	GRACE HEPBURN	10.99	0	4318
3323	12	AFFAIR FLIGHT	DUSTIN CAINE	14.99	0	9980
3324	6	AFFAIR FLINTSTONES	AUDREY KIDMAN	22.99	0	7192
3325	10	AFFAIR FLOATS	ED GRANT	9.99	0	557
3326	15	AFFAIR FLYING	CAMERON HOPKINS	29.99	0	7084
3327	15	AFFAIR FOOL	CHARLES LEIGH	14.99	0	8618
3328	11	AFFAIR FOREVER	ADAM GRANT	28.99	0	7659
3329	15	AFFAIR FORREST	FRANK WOOD	29.99	0	7302
3330	12	AFFAIR FORRESTER	CANDICE DAFOE	28.99	0	4404
3331	16	AFFAIR FORWARD	SIGOURNEY CHAPLIN	11.99	0	1597
3332	14	AFFAIR FRANKENSTEIN	NATALIE BEATTY	29.99	0	3855
3333	14	AFFAIR FREAKY	PAUL WINFREY	26.99	0	4066
3334	10	AFFAIR FREDDY	HUGH RYDER	27.99	0	71
3335	10	AFFAIR FREEDOM	DENNIS HURT	24.99	0	4567
3336	3	AFFAIR FRENCH	LISA HAYEK	10.99	0	7588
3337	4	AFFAIR FRIDA	RIP GABLE	28.99	0	1140
3338	6	AFFAIR FRISCO	BETTE CAGE	11.99	0	9753
3339	9	AFFAIR FROGMEN	PAUL KUDROW	28.99	0	5514
3340	15	AFFAIR FRONTIER	ALICIA BASINGER	11.99	0	4540
3341	10	AFFAIR FROST	SEAN WILLIAMS	13.99	0	4082
3342	16	AFFAIR FUGITIVE	OPRAH DENIRO	25.99	0	724
3343	15	AFFAIR FULL	DEBBIE KILMER	29.99	0	1644
3344	16	AFFAIR FURY	MILLA COOPER	24.99	0	1436
3345	5	AFFAIR GABLES	DANIEL AKROYD	15.99	0	9811
3346	13	AFFAIR GALAXY	UMA PHOENIX	22.99	0	9652
3347	1	AFFAIR GAMES	DENNIS TORN	25.99	0	4151
3348	15	AFFAIR GANDHI	VIVIEN LAW	10.99	0	6044
3349	4	AFFAIR GANGS	PAUL JACKMAN	29.99	0	8597
3350	2	AFFAIR GARDEN	SANDRA JACKMAN	15.99	0	99
3351	5	AFFAIR GASLIGHT	NICOLAS LAW	13.99	0	6785
3352	3	AFFAIR GATHERING	LANA DENIRO	17.99	0	2462
3353	14	AFFAIR GENTLEMEN	RICHARD WALKEN	25.99	0	3459
3354	6	AFFAIR GHOST	ROCK DIAZ	12.99	0	548
3355	1	AFFAIR GHOSTBUSTERS	KENNETH FISHER	27.99	0	3507
3356	15	AFFAIR GIANT	STEVE TRACY	22.99	0	1155
3357	5	AFFAIR GILBERT	GWYNETH FAWCETT	27.99	0	4144
3358	3	AFFAIR GILMORE	GREG KEITEL	28.99	0	3591
3359	5	AFFAIR GLADIATOR	LIZA MOSTEL	11.99	0	8464
3360	3	AFFAIR GLASS	CHRISTOPHER SILVERSTONE	24.99	0	7964
3361	2	AFFAIR GLEAMING	MICHAEL LEIGH	29.99	0	8229
3362	2	AFFAIR GLORY	CARY JOLIE	18.99	0	8383
3363	15	AFFAIR GO	GROUCHO JOVOVICH	13.99	0	6482
3364	10	AFFAIR GODFATHER	GARY PENN	13.99	0	1154
3365	1	AFFAIR GOLD	THORA AFFLECK	13.99	0	6140
3366	1	AFFAIR GOLDFINGER	CLINT RYAN	24.99	0	3787
3367	9	AFFAIR GOLDMINE	SEAN TEMPLE	23.99	0	2586
3368	9	AFFAIR GONE	ORLANDO DAVIS	27.99	0	2013
3369	9	AFFAIR GOODFELLAS	SUSAN ALLEN	26.99	0	7492
3370	16	AFFAIR GORGEOUS	OLYMPIA DICAPRIO	27.99	0	4738
3371	8	AFFAIR GOSFORD	EMILY JOVOVICH	22.99	0	421
3372	1	AFFAIR GRACELAND	SUSAN REYNOLDS	28.99	0	2567
3373	3	AFFAIR GRADUATE	JOAN WAYNE	28.99	0	9067
3374	3	AFFAIR GRAFFITI	SYLVESTER FONDA	10.99	0	1393
3375	14	AFFAIR GRAIL	HUMPHREY BOGART	20.99	0	8938
3376	1	AFFAIR GRAPES	HUGH HOPE	15.99	0	6223
3377	6	AFFAIR GREASE	HENRY CHASE	14.99	0	8199
3378	9	AFFAIR GREATEST	ORLANDO DICAPRIO	29.99	0	5768
3379	15	AFFAIR GREEDY	SPENCER GARBO	26.99	0	626
3380	16	AFFAIR GREEK	CHEVY DEGENERES	16.99	0	1254
3381	5	AFFAIR GRINCH	LANA STALLONE	22.99	0	6892
3382	5	AFFAIR GRIT	RUBY JACKMAN	23.99	0	9322
3383	8	AFFAIR GROOVE	DANIEL DOUGLAS	14.99	0	4093
3384	14	AFFAIR GROSSE	PARKER COSTNER	24.99	1	1908
3385	13	AFFAIR GROUNDHOG	JADA WILLIAMS	29.99	0	2293
3386	2	AFFAIR GUMP	AUDREY LOREN	22.99	0	2161
3387	6	AFFAIR GUN	MILLA KEITEL	13.99	0	4667
3388	3	AFFAIR GUNFIGHT	NICOLE NICHOLSON	15.99	0	198
3389	12	AFFAIR GUNFIGHTER	DAN PRESLEY	19.99	0	1879
3390	12	AFFAIR GUYS	CHARLES DRIVER	11.99	0	4659
3391	6	AFFAIR HALF	ANGELINA FISHER	17.99	0	2914
3392	11	AFFAIR HALL	RITA FONDA	16.99	0	80
3393	13	AFFAIR HALLOWEEN	MENA MONROE	20.99	0	6176
3394	10	AFFAIR HAMLET	HARVEY PALTROW	25.99	0	8684
3395	16	AFFAIR HANDICAP	CHEVY TRACY	11.99	0	4050
3396	10	AFFAIR HANGING	NEVE GARLAND	21.99	0	7186
3397	15	AFFAIR HANKY	ANGELINA HAYEK	24.99	0	5737
3398	12	AFFAIR HANOVER	DIANE LOLLOBRIGIDA	17.99	0	2001
3399	1	AFFAIR HAPPINESS	SPENCER PALTROW	17.99	0	1187
3400	5	AFFAIR HARDLY	ALBERT HESTON	18.99	0	415
3401	14	AFFAIR HAROLD	IAN BOLGER	21.99	0	1991
3402	5	AFFAIR HARPER	LIZA MCDORMAND	16.99	0	3882
3403	15	AFFAIR HARRY	WARREN BERRY	11.99	0	972
3404	6	AFFAIR HATE	RICHARD KELLY	14.99	0	2846
3405	6	AFFAIR HAUNTED	MIRA DAY	17.99	0	2558
3406	7	AFFAIR HAUNTING	GROUCHO JOHANSSON	26.99	0	753
3407	1	AFFAIR HAWK	MICHAEL GARLAND	22.99	0	449
3408	1	AFFAIR HEAD	CARMEN MCGREGOR	9.99	0	6149
3409	2	AFFAIR HEARTBREAKERS	CHARLES BRANDO	28.99	0	830
3410	4	AFFAIR HEAVEN	FRED PHOENIX	28.99	0	9571
3411	3	AFFAIR HEAVENLY	JEREMY LANCASTER	20.99	0	5289
3412	10	AFFAIR HEAVYWEIGHTS	SISSY HESTON	15.99	0	6085
3413	6	AFFAIR HEDWIG	DUSTIN CARREY	19.99	0	71
3414	2	AFFAIR HELLFIGHTERS	CANDICE DOUGLAS	13.99	0	4814
3415	6	AFFAIR HIGH	DENNIS HANNAH	22.99	0	3341
3416	10	AFFAIR HIGHBALL	SIDNEY JOLIE	9.99	0	2805
3417	9	AFFAIR HILLS	MIRA MONROE	18.99	0	8140
3418	2	AFFAIR HOBBIT	WARREN FIENNES	15.99	0	1285
3419	5	AFFAIR HOCUS	HUMPHREY THURMAN	18.99	0	6028
3420	15	AFFAIR HOLES	ADAM HOFFMAN	11.99	0	3264
3421	8	AFFAIR HOLIDAY	ROBERT MCQUEEN	16.99	0	8685
3422	10	AFFAIR HOLLOW	JULIANNE DEE	16.99	0	4834
3423	3	AFFAIR HOLLYWOOD	RENEE PRESLEY	11.99	0	5988
3424	4	AFFAIR HOLOCAUST	JOHN GIBSON	22.99	0	6113
3425	5	AFFAIR HOLY	ANJELICA PECK	14.99	0	1167
3426	10	AFFAIR HOME	OPRAH DUKAKIS	17.99	0	4284
3427	5	AFFAIR HOMEWARD	MARY DERN	25.99	0	3520
3428	5	AFFAIR HOMICIDE	BURT POSEY	10.99	0	1693
3429	11	AFFAIR HONEY	KATE BRIDGES	12.99	0	3395
3430	13	AFFAIR HOOK	ANGELINA ASTAIRE	26.99	0	8835
3431	16	AFFAIR HOOSIERS	CHRISTOPHER TANDY	23.99	0	8097
3432	3	AFFAIR HOPE	ANTHONY LANSBURY	25.99	0	6681
3433	3	AFFAIR HORN	JACK MINELLI	14.99	0	2915
3434	7	AFFAIR HORROR	HUMPHREY HAWN	29.99	0	1755
3435	5	AFFAIR HOTEL	DANIEL GIBSON	16.99	0	4778
3436	4	AFFAIR HOURS	GREG COOPER	17.99	0	6179
3437	4	AFFAIR HOUSE	CLARK ANISTON	15.99	0	5343
3438	16	AFFAIR HUMAN	CLARK WINFREY	17.99	0	9089
3439	11	AFFAIR HUNCHBACK	GLENN NEESON	10.99	0	9160
3440	5	AFFAIR HUNGER	FRANCES WEAVER	18.99	0	5033
3441	15	AFFAIR HUNTER	MATTHEW LANCASTER	14.99	0	5501
3442	15	AFFAIR HUNTING	KIRSTEN CRUZ	10.99	0	3885
3443	10	AFFAIR HURRICANE	GWYNETH HOPPER	25.99	0	5954
3444	12	AFFAIR HUSTLER	ELVIS KEITEL	9.99	0	8972
3445	15	AFFAIR HYDE	ROSIE TANDY	13.99	0	1504
3446	12	AFFAIR HYSTERICAL	MICHELLE DERN	17.99	0	6685
3447	16	AFFAIR ICE	SALMA HEPBURN	19.99	0	3569
3448	15	AFFAIR IDAHO	RIP BRANAGH	14.99	0	6572
3449	14	AFFAIR IDENTITY	CLARK LOLLOBRIGIDA	11.99	0	7823
3450	1	AFFAIR IDOLS	MARISA KIDMAN	27.99	0	9701
3451	1	AFFAIR IGBY	DORIS HUSTON	23.99	0	7646
3452	7	AFFAIR ILLUSION	DANIEL SOBIESKI	14.99	0	6968
3453	10	AFFAIR IMAGE	RENEE DENIRO	17.99	0	6910
3454	2	AFFAIR IMPACT	ETHAN GOLDBERG	14.99	0	8678
3455	1	AFFAIR IMPOSSIBLE	HUGH KEATON	23.99	0	1522
3456	11	AFFAIR INCH	MADELINE HACKMAN	27.99	0	5126
3457	11	AFFAIR INDEPENDENCE	GRACE JACKMAN	26.99	0	6840
3458	9	AFFAIR INDIAN	TIM FOSTER	16.99	0	4490
3459	1	AFFAIR INFORMER	ROBERT SPACEK	15.99	0	3258
3460	3	AFFAIR INNOCENT	ROSIE BRODY	20.99	0	2273
3461	12	AFFAIR INSECTS	LIZA HOPPER	16.99	0	7333
3462	14	AFFAIR INSIDER	DORIS WITHERSPOON	13.99	0	9653
3463	15	AFFAIR INSTINCT	GARY GARCIA	26.99	0	696
3464	5	AFFAIR INTENTIONS	SPENCER PHOENIX	11.99	0	9943
3465	7	AFFAIR INTERVIEW	CANDICE DAFOE	14.99	0	9229
3466	8	AFFAIR INTOLERABLE	HELEN JACKMAN	11.99	0	7180
3467	14	AFFAIR INTRIGUE	MICHELLE PALTROW	10.99	0	5251
3468	1	AFFAIR INVASION	SIDNEY SANDLER	16.99	0	5881
3469	7	AFFAIR IRON	GINA TORN	15.99	1	3550
3470	6	AFFAIR ISHTAR	KIM HAYEK	18.99	0	3302
3471	6	AFFAIR ISLAND	RIVER CRONYN	24.99	0	6655
3472	8	AFFAIR ITALIAN	HARVEY CHASE	12.99	0	2903
3473	11	AFFAIR JACKET	BOB DOUGLAS	21.99	0	7216
3474	3	AFFAIR JADE	LIZA BASINGER	19.99	0	6166
3475	14	AFFAIR JAPANESE	ANDY OLIVIER	17.99	0	7252
3476	12	AFFAIR JASON	SPENCER JOHANSSON	20.99	0	2129
3477	4	AFFAIR JAWBREAKER	HALLE PACINO	21.99	0	6022
3478	15	AFFAIR JAWS	SEAN KUDROW	29.99	0	5082
3479	12	AFFAIR JEDI	KIM DOUGLAS	15.99	0	9356
3480	15	AFFAIR JEEPERS	MADELINE MANSFIELD	29.99	1	7711
3481	12	AFFAIR JEKYLL	EMILY PENN	21.99	0	5105
3482	14	AFFAIR JEOPARDY	DENNIS HUNT	12.99	0	717
3483	13	AFFAIR JERICHO	LIV WATSON	22.99	0	7378
3484	3	AFFAIR JERK	ALAN MARTIN	24.99	0	7782
3485	11	AFFAIR JERSEY	HARRISON STREEP	15.99	0	3666
3486	2	AFFAIR JET	BEN JOLIE	16.99	0	3455
3487	14	AFFAIR JINGLE	RITA VOIGHT	10.99	0	8804
3488	3	AFFAIR JOON	RITA THURMAN	24.99	0	7273
3489	8	AFFAIR JUGGLER	GLENN PESCI	19.99	0	2454
3490	5	AFFAIR JUMANJI	BOB BRIDGES	22.99	0	9030
3491	1	AFFAIR JUMPING	HUMPHREY IRONS	11.99	0	5117
3492	8	AFFAIR JUNGLE	JAMES NOLTE	14.99	0	5321
3493	3	AFFAIR KANE	INGRID TEMPLE	29.99	0	9681
3494	12	AFFAIR KARATE	MERYL BRIDGES	9.99	0	1427
3495	5	AFFAIR KENTUCKIAN	ELVIS TYLER	16.99	0	6793
3496	5	AFFAIR KICK	CHRISTIAN MANSFIELD	23.99	0	9983
3497	4	AFFAIR KILL	MEG COOPER	21.99	0	4227
3498	3	AFFAIR KILLER	FRANK MANSFIELD	20.99	0	9287
3499	9	AFFAIR KING	ANGELINA DIETRICH	13.99	0	6742
3500	6	AFFAIR KISS	LAURENCE LOLLOBRIGIDA	22.99	0	1590
3501	5	AFFAIR KISSING	OPRAH DAVIS	19.99	0	4685
3502	8	AFFAIR KNOCK	MADELINE BERRY	12.99	0	743
3503	10	AFFAIR KRAMER	MATTHEW STREEP	27.99	0	2394
3504	13	AFFAIR KWAI	JUDI WEST	26.99	0	8099
3505	9	AFFAIR LABYRINTH	HENRY KUDROW	11.99	0	3291
3506	5	AFFAIR LADY	KATHARINE IRONS	9.99	0	4302
3507	9	AFFAIR LADYBUGS	JUDI HOFFMAN	11.99	0	2017
3508	4	AFFAIR LAMBS	ANGELINA CRAWFORD	27.99	0	4609
3509	2	AFFAIR LANGUAGE	IAN SWANK	22.99	0	5885
3510	8	AFFAIR LAWLESS	CARY DENCH	26.99	0	3118
3511	3	AFFAIR LAWRENCE	REESE MCKELLEN	23.99	0	7630
3512	2	AFFAIR LEAGUE	DARYL CLOSE	22.99	0	8007
3513	14	AFFAIR LEATHERNECKS	WILLEM JOVOVICH	27.99	0	293
3514	6	AFFAIR LEBOWSKI	SIDNEY JOLIE	24.99	0	6035
3515	6	AFFAIR LEGALLY	RUBY LEIGH	18.99	0	2036
3516	13	AFFAIR LEGEND	ROBIN KUDROW	21.99	0	4976
3517	6	AFFAIR LESSON	MARY GARCIA	20.99	1	9599
3518	6	AFFAIR LIAISONS	JIM SOBIESKI	15.99	0	8533
3519	6	AFFAIR LIBERTY	GROUCHO BARRYMORE	14.99	0	4896
3520	14	AFFAIR LICENSE	ANNE CAINE	23.99	0	4522
3521	15	AFFAIR LIES	ZERO HANNAH	24.99	0	2378
3522	4	AFFAIR LIFE	LEONARDO FONDA	27.99	0	5970
3523	14	AFFAIR LIGHTS	JACK DEGENERES	15.99	0	1319
3524	3	AFFAIR LION	CLARK WALKEN	20.99	0	9788
3525	1	AFFAIR LOATHING	CANDICE ASTAIRE	10.99	0	7325
3526	9	AFFAIR LOCK	CARY MCCONAUGHEY	20.99	0	1197
3527	13	AFFAIR LOLA	JENNIFER LUGOSI	16.99	0	3399
3528	16	AFFAIR LOLITA	LAURA FONDA	17.99	0	1458
3529	9	AFFAIR LONELY	AUDREY SOBIESKI	23.99	0	2431
3530	11	AFFAIR LORD	EMILY GOODING	25.99	0	9854
3531	9	AFFAIR LOSE	LIAM WRAY	22.99	0	9597
3532	13	AFFAIR LOSER	KENNETH DUKAKIS	14.99	0	269
3533	10	AFFAIR LOST	GWYNETH MCGREGOR	12.99	0	154
3534	5	AFFAIR LOUISIANA	ROSIE KINNEAR	16.99	0	2039
3535	10	AFFAIR LOVE	LAUREN WALKEN	27.99	0	461
3536	14	AFFAIR LOVELY	ANDY DERN	18.99	0	5630
3537	7	AFFAIR LOVER	RUSSELL PALTROW	29.99	0	5154
3538	1	AFFAIR LOVERBOY	CHARLES KELLY	16.99	0	1619
3539	7	AFFAIR LUCK	MICHELLE WOOD	13.99	0	9483
3540	7	AFFAIR LUCKY	SCARLETT WINSLET	9.99	0	5994
3541	1	AFFAIR LUKE	SALLY PFEIFFER	11.99	0	7794
3542	11	AFFAIR LUST	JOHN MCKELLEN	19.99	0	4342
3543	1	AFFAIR MADIGAN	WALTER MCCONAUGHEY	12.99	0	6429
3544	6	AFFAIR MADISON	LUCILLE GARLAND	9.99	0	9888
3545	16	AFFAIR MADNESS	WHOOPI ASTAIRE	27.99	0	8250
3546	8	AFFAIR MADRE	KEVIN BOLGER	15.99	0	7534
3547	2	AFFAIR MAGIC	HENRY TANDY	21.99	0	4
3548	1	AFFAIR MAGNIFICENT	LIV HAWKE	29.99	0	6062
3549	10	AFFAIR MAGNOLIA	WILL WALKEN	14.99	0	5696
3550	4	AFFAIR MAGUIRE	LEELEE WILLIAMS	13.99	0	6335
3551	1	AFFAIR MAIDEN	NEVE DREYFUSS	21.99	0	9338
3552	6	AFFAIR MAJESTIC	REESE PACINO	24.99	0	1777
3553	12	AFFAIR MAKER	LEELEE FAWCETT	16.99	0	1796
3554	16	AFFAIR MALKOVICH	BURT TURNER	28.99	0	729
3555	8	AFFAIR MALLRATS	ALEC HANNAH	10.99	0	8495
3556	12	AFFAIR MALTESE	CARY MCQUEEN	18.99	0	7341
3557	7	AFFAIR MANCHURIAN	JAMES LANSBURY	12.99	0	7211
3558	6	AFFAIR MANNEQUIN	ALEC AFFLECK	29.99	0	3134
3559	3	AFFAIR MARRIED	DIANE DUNST	14.99	0	3820
3560	6	AFFAIR MARS	PENELOPE PENN	16.99	0	3879
3561	4	AFFAIR MASK	ALBERT KELLY	15.99	0	2438
3562	1	AFFAIR MASKED	REESE GIBSON	19.99	0	796
3563	4	AFFAIR MASSACRE	BEN WAHLBERG	14.99	0	4311
3564	9	AFFAIR MASSAGE	NATALIE ALLEN	25.99	0	9512
3565	3	AFFAIR MATRIX	MATT LAW	28.99	0	4732
3566	6	AFFAIR MAUDE	ADAM BOGART	16.99	0	9828
3567	10	AFFAIR MEET	GRETA HURT	17.99	0	9128
3568	8	AFFAIR MEMENTO	ROBIN CROWE	20.99	0	7117
3569	16	AFFAIR MENAGERIE	MORGAN WITHERSPOON	24.99	0	9737
3570	11	AFFAIR MERMAID	KATE TYLER	16.99	0	4434
3571	13	AFFAIR METAL	KATHARINE CRONYN	26.99	0	9624
3572	13	AFFAIR METROPOLIS	JAYNE CAGE	12.99	0	4134
3573	1	AFFAIR MICROCOSMOS	LENA AFFLECK	27.99	0	249
3574	10	AFFAIR MIDNIGHT	ADRIEN LANCASTER	15.99	0	7617
3575	5	AFFAIR MIDSUMMER	MEG WAYNE	26.99	0	5312
3576	5	AFFAIR MIGHTY	MINNIE BLANCHETT	26.99	0	2493
3577	13	AFFAIR MILE	HELEN ODONNELL	13.99	0	9079
3578	11	AFFAIR MILLION	STEVE TRACY	14.99	0	4725
3579	5	AFFAIR MINDS	ALBERT HARRIS	14.99	0	2947
3580	1	AFFAIR MINE	DREW BALL	23.99	0	5130
3581	4	AFFAIR MINORITY	LEONARDO COOPER	29.99	1	5018
3582	4	AFFAIR MIRACLE	DANIEL RUSH	21.99	0	379
3583	8	AFFAIR MISSION	UMA MONROE	17.99	0	7408
3584	15	AFFAIR MIXED	CHARLIZE CLOSE	27.99	0	8852
3585	4	AFFAIR MOB	THORA HUDSON	18.99	0	8095
3586	16	AFFAIR MOCKINGBIRD	WILLEM HAWN	20.99	0	9703
3587	1	AFFAIR MOD	OLYMPIA LOLLOBRIGIDA	14.99	0	7623
3588	5	AFFAIR MODEL	INGRID MONROE	13.99	0	3116
3589	16	AFFAIR MODERN	JOAN WASHINGTON	11.99	0	9074
3590	16	AFFAIR MONEY	HARRISON BACALL	28.99	0	5514
3591	12	AFFAIR MONSOON	WHOOPI HACKMAN	23.99	0	3415
3592	11	AFFAIR MONSTER	SUSAN WOOD	18.99	0	792
3593	4	AFFAIR MONTEREY	NEVE JOVOVICH	21.99	0	7895
3594	15	AFFAIR MONTEZUMA	MORGAN ODONNELL	17.99	0	5540
3595	5	AFFAIR MOON	LAUREN RYAN	23.99	0	367
3596	4	AFFAIR MOONSHINE	JANE HOFFMAN	13.99	0	3775
3597	9	AFFAIR MOONWALKER	HALLE SOBIESKI	18.99	0	5954
3598	9	AFFAIR MOSQUITO	BRUCE HOPE	14.99	0	8333
3599	1	AFFAIR MOTHER	JULIANNE WINFREY	25.99	0	3229
3600	6	AFFAIR MOTIONS	CANDICE NEESON	28.99	0	8303
3601	16	AFFAIR MOULIN	ETHAN LEIGH	17.99	0	4261
3602	13	AFFAIR MOURNING	ELIZABETH DUNST	11.99	0	5126
3603	12	AFFAIR MOVIE	WARREN DREYFUSS	26.99	0	174
3604	11	AFFAIR MULAN	WOODY MARTIN	12.99	0	3591
3605	9	AFFAIR MULHOLLAND	ALEC PECK	22.99	0	3665
3606	8	AFFAIR MUMMY	TIM LEWIS	24.99	0	6930
3607	3	AFFAIR MUPPET	WINONA PECK	17.99	0	7395
3608	15	AFFAIR MURDER	ALBERT LAW	27.99	0	5714
3609	15	AFFAIR MUSCLE	CLARK BARRYMORE	27.99	0	5563
3610	4	AFFAIR MUSIC	EMILY PINKETT	14.99	0	8913
3611	11	AFFAIR MUSKETEERS	JESSICA SARANDON	21.99	0	4168
3612	5	AFFAIR MUSSOLINI	CARY NORTON	14.99	0	9730
3613	16	AFFAIR MYSTIC	KATE ALLEN	9.99	0	9244
3614	10	AFFAIR NAME	WILL RYAN	25.99	0	2021
3615	6	AFFAIR NASH	TOM WASHINGTON	21.99	0	2947
3616	8	AFFAIR NATIONAL	BRUCE SUVARI	28.99	0	6389
3617	6	AFFAIR NATURAL	GLENN ODONNELL	19.99	0	4217
3618	8	AFFAIR NECKLACE	JANE WEAVER	9.99	0	3326
3619	15	AFFAIR NEIGHBORS	CARRIE LANCASTER	27.99	0	8121
3620	2	AFFAIR NEMO	NICOLE MINELLI	9.99	0	9564
3621	6	AFFAIR NETWORK	RICHARD PECK	18.99	0	2336
3622	2	AFFAIR NEWSIES	THORA ALLEN	17.99	0	8759
3623	14	AFFAIR NEWTON	RIVER WILSON	14.99	0	7850
3624	10	AFFAIR NIGHTMARE	GRACE TOMEI	24.99	0	6573
3625	9	AFFAIR NONE	FRANK TOMEI	14.99	0	5274
3626	4	AFFAIR NOON	DUSTIN DERN	9.99	0	8917
3627	5	AFFAIR NORTH	SPENCER REYNOLDS	13.99	0	4107
3628	2	AFFAIR NORTHWEST	HELEN WOOD	27.99	0	3508
3629	11	AFFAIR NOTORIOUS	EDWARD SORVINO	9.99	0	372
3630	11	AFFAIR NOTTING	THORA BIRCH	29.99	0	8538
3631	9	AFFAIR NOVOCAINE	CAMERON LUGOSI	24.99	0	8025
3632	11	AFFAIR NUTS	KIRSTEN TRACY	20.99	0	7316
3633	16	AFFAIR OCTOBER	MIRA CRAWFORD	15.99	0	9610
3634	11	AFFAIR ODDS	RAY PRESLEY	28.99	0	3464
3635	16	AFFAIR OKLAHOMA	JADA HOPPER	27.99	0	7841
3636	12	AFFAIR OLEANDER	HARRISON WATSON	26.99	0	27
3637	11	AFFAIR OPEN	SPENCER FAWCETT	13.99	0	91
3638	16	AFFAIR OPERATION	CUBA RYDER	23.99	0	2647
3639	11	AFFAIR OPPOSITE	ALBERT SANDLER	18.99	0	8025
3640	13	AFFAIR OPUS	ELLEN ODONNELL	13.99	0	6923
3641	16	AFFAIR ORANGE	LUCILLE FISHER	16.99	0	3042
3642	6	AFFAIR ORDER	LISA SPACEK	14.99	0	4597
3643	5	AFFAIR ORIENT	ELIZABETH ANISTON	18.99	0	3790
3644	12	AFFAIR OSCAR	CLINT FINNEY	24.99	0	9125
3645	9	AFFAIR OTHERS	LEONARDO KELLY	26.99	0	1868
3646	9	AFFAIR OUTBREAK	JUDY PENN	11.99	0	6933
3647	8	AFFAIR OUTFIELD	KARL HOFFMAN	10.99	0	5927
3648	9	AFFAIR OUTLAW	LISA WOOD	25.99	0	3009
3649	3	AFFAIR OZ	LUCILLE CRONYN	15.99	0	3793
3650	4	AFFAIR PACIFIC	SPENCER JACKMAN	26.99	0	6400
3651	1	AFFAIR PACKER	GROUCHO SINATRA	20.99	0	4362
3652	4	AFFAIR PAJAMA	SEAN GUINESS	25.99	0	5859
3653	6	AFFAIR PANIC	LANA WILLIAMS	29.99	0	244
3654	5	AFFAIR PANKY	DEBBIE TAYLOR	27.99	0	1430
3655	5	AFFAIR PANTHER	MAE HOFFMAN	12.99	0	9430
3656	14	AFFAIR PAPI	OPRAH FIENNES	12.99	0	7102
3657	10	AFFAIR PARADISE	BRUCE BOLGER	19.99	0	5457
3658	2	AFFAIR PARIS	JUDE DEGENERES	22.99	0	2263
3659	11	AFFAIR PARK	BRAD HUSTON	27.99	0	2955
3660	1	AFFAIR PARTY	NICK MOORE	22.99	0	227
3661	10	AFFAIR PAST	GREG NEWMAN	16.99	0	2074
3662	2	AFFAIR PATHS	GENE HURT	12.99	0	1846
3663	12	AFFAIR PATIENT	JACK BEATTY	13.99	0	6284
3664	8	AFFAIR PATRIOT	BURT GUINESS	20.99	0	4904
3665	14	AFFAIR PATTON	CHARLIZE FIELD	21.99	0	9945
3666	10	AFFAIR PAYCHECK	MATT LOREN	28.99	0	5228
3667	3	AFFAIR PEACH	ZERO BACALL	18.99	0	9749
3668	11	AFFAIR PEAK	ALICIA WASHINGTON	10.99	0	7473
3669	12	AFFAIR PEARL	CHARLES MATTHAU	25.99	0	4229
3670	5	AFFAIR PELICAN	NEVE AKROYD	18.99	0	7108
3671	8	AFFAIR PERDITION	FRANK CROWE	11.99	0	2472
3672	11	AFFAIR PERFECT	EWAN DRIVER	22.99	0	4836
3673	10	AFFAIR PERSONAL	INGRID HANNAH	22.99	0	5741
3674	7	AFFAIR PET	CUBA COOPER	20.99	0	3466
3675	16	AFFAIR PHANTOM	GRETA DIETRICH	23.99	0	9385
3676	7	AFFAIR PHILADELPHIA	CARRIE CHASE	23.99	0	2636
3677	15	AFFAIR PIANIST	KEVIN TORN	13.99	0	3043
3678	12	AFFAIR PICKUP	MILLA CAGE	11.99	0	1754
3679	11	AFFAIR PILOT	GREG CHASE	27.99	0	3174
3680	4	AFFAIR PINOCCHIO	LAURENCE MCKELLEN	20.99	0	3084
3681	9	AFFAIR PIRATES	JIM PECK	22.99	0	7356
3682	15	AFFAIR PITTSBURGH	MADELINE FORD	18.99	0	1606
3683	13	AFFAIR PITY	FRANCES DENIRO	18.99	0	634
3684	11	AFFAIR PIZZA	DENZEL BARRYMORE	29.99	0	9016
3685	5	AFFAIR PLATOON	KARL CAINE	27.99	0	8494
3686	4	AFFAIR PLUTO	KIM DAY	22.99	0	9596
3687	7	AFFAIR POCUS	FRANK POSEY	9.99	0	8472
3688	4	AFFAIR POLISH	BOB WILLIS	19.99	0	4536
3689	9	AFFAIR POLLOCK	JON BENING	25.99	0	4170
3690	11	AFFAIR POND	KEVIN FOSTER	13.99	0	2605
3691	1	AFFAIR POSEIDON	JODIE HECHE	21.99	0	3308
3692	10	AFFAIR POTLUCK	BETTE IRONS	27.99	0	2932
3693	12	AFFAIR POTTER	ELLEN PENN	26.99	0	6848
3694	5	AFFAIR PREJUDICE	NICOLE POSEY	25.99	0	7947
3695	3	AFFAIR PRESIDENT	CATE CROWE	24.99	0	3681
3696	16	AFFAIR PRIDE	RAY HOPE	18.99	0	8843
3697	13	AFFAIR PRIMARY	HARRISON MCGREGOR	27.99	0	8960
3698	3	AFFAIR PRINCESS	LISA DAVIS	18.99	0	8124
3699	2	AFFAIR PRIVATE	KIRK DRIVER	27.99	0	819
3700	11	AFFAIR PRIX	ETHAN DEE	25.99	0	6632
3701	3	AFFAIR PSYCHO	BURT WILLIAMS	29.99	0	1661
3702	14	AFFAIR PULP	REESE DEAN	13.99	0	2940
3703	2	AFFAIR PUNK	JUDI DUNST	24.99	0	5320
3704	9	AFFAIR PURE	RITA SWANK	11.99	0	8699
3705	4	AFFAIR PURPLE	BRAD GUINESS	18.99	0	633
3706	2	AFFAIR QUEEN	ALBERT GIBSON	13.99	0	4476
3707	7	AFFAIR QUEST	MEG CROWE	13.99	0	7918
3708	8	AFFAIR QUILLS	BETTE KIDMAN	29.99	0	8207
3709	9	AFFAIR RACER	MEG SILVERSTONE	16.99	0	4047
3710	4	AFFAIR RAGE	REESE BRANAGH	15.99	0	9983
3711	7	AFFAIR RAGING	HALLE NORTON	17.99	0	7078
3712	14	AFFAIR RAIDERS	SISSY FIENNES	19.99	0	3102
3713	6	AFFAIR RAINBOW	ROSIE ZELLWEGER	17.99	1	1104
3714	4	AFFAIR RANDOM	SYLVESTER KEATON	27.99	0	8379
3715	5	AFFAIR RANGE	UMA BERRY	11.99	0	5097
3716	2	AFFAIR REAP	DANIEL ROBERTS	18.99	0	1177
3717	3	AFFAIR REAR	JAMES ASTAIRE	10.99	0	9441
3718	7	AFFAIR REBEL	UMA SWANK	13.99	0	9316
3719	6	AFFAIR RECORDS	JEFF HUSTON	14.99	0	3133
3720	2	AFFAIR REDEMPTION	HILARY NORTON	9.99	0	7891
3721	9	AFFAIR REDS	KIRK TOMEI	24.99	0	7387
3722	14	AFFAIR REEF	OPRAH KINNEAR	15.99	0	3043
3723	4	AFFAIR REIGN	CHRIS AFFLECK	12.99	0	4246
3724	2	AFFAIR REMEMBER	SPENCER LOLLOBRIGIDA	20.99	0	2920
3725	15	AFFAIR REQUIEM	WILLEM WATSON	14.99	0	7702
3726	2	AFFAIR RESERVOIR	MARY KIDMAN	22.99	0	263
3727	6	AFFAIR RESURRECTION	KIRSTEN CHAPLIN	11.99	0	1875
3728	7	AFFAIR REUNION	DAN PACINO	21.99	0	4263
3729	1	AFFAIR RIDER	ADAM AKROYD	28.99	0	8379
3730	4	AFFAIR RIDGEMONT	PAUL HOPPER	13.99	0	7520
3731	16	AFFAIR RIGHT	FARRAH RYAN	22.99	0	5656
3732	11	AFFAIR RINGS	MIRA RUSSELL	13.99	0	1697
3733	7	AFFAIR RIVER	SCARLETT FOSTER	21.99	0	7578
3734	1	AFFAIR ROAD	ORLANDO WILLIAMS	9.99	0	3388
3735	14	AFFAIR ROBBERS	RAY BOLGER	22.99	0	5251
3736	7	AFFAIR ROBBERY	GEOFFREY DICAPRIO	23.99	0	7405
3737	4	AFFAIR ROCK	JULIETTE LANSBURY	29.99	0	4423
3738	3	AFFAIR ROCKETEER	RALPH CRUZ	9.99	0	7250
3739	13	AFFAIR ROCKY	MEL SORVINO	19.99	0	5654
3740	14	AFFAIR ROLLERCOASTER	MATT PINKETT	22.99	0	9688
3741	3	AFFAIR ROMAN	DUSTIN ROBERTS	19.99	0	1377
3742	4	AFFAIR ROOF	MERYL PACINO	25.99	0	4774
3743	4	AFFAIR ROOM	MATTHEW RYAN	29.99	0	4751
3744	12	AFFAIR ROOTS	GARY LANCASTER	17.99	0	1738
3745	16	AFFAIR ROSES	STEVE WATSON	22.99	0	2913
3746	10	AFFAIR ROUGE	ANTHONY ROBERTS	26.99	0	5250
3747	16	AFFAIR ROXANNE	DORIS KEATON	23.99	0	8895
3748	3	AFFAIR RUGRATS	MEL JOHANSSON	26.99	0	4778
3749	5	AFFAIR RULES	ALICIA DAY	21.99	0	1075
3750	13	AFFAIR RUN	ANGELINA MALDEN	23.99	0	6399
3751	16	AFFAIR RUNAWAY	INGRID SPACEK	10.99	0	6922
3752	10	AFFAIR RUNNER	DEBBIE MOSTEL	25.99	0	4957
3753	12	AFFAIR RUSH	WOODY JACKMAN	16.99	0	4888
3754	14	AFFAIR RUSHMORE	MILLA MCGREGOR	27.99	0	3304
3755	16	AFFAIR SABRINA	SYLVESTER ASTAIRE	9.99	0	1547
3756	11	AFFAIR SADDLE	WOODY PACINO	11.99	0	6746
3757	13	AFFAIR SAGEBRUSH	GRACE FONDA	29.99	0	6798
3758	8	AFFAIR SAINTS	CHRISTOPHER SPACEK	19.99	0	4971
3759	16	AFFAIR SALUTE	CARMEN BERGMAN	23.99	0	3579
3760	1	AFFAIR SAMURAI	HARVEY WEST	28.99	1	930
3761	2	AFFAIR SANTA	RAY NEWMAN	10.99	0	5495
3762	13	AFFAIR SASSY	SHIRLEY LANSBURY	11.99	0	255
3763	13	AFFAIR SATISFACTION	SALMA BARRYMORE	28.99	0	772
3764	8	AFFAIR SATURDAY	CHARLIZE KAHN	20.99	0	1077
3765	15	AFFAIR SATURN	ANNETTE DAMON	15.99	0	557
3766	7	AFFAIR SAVANNAH	NEVE DEE	13.99	0	5005
3767	12	AFFAIR SCALAWAG	ANNE BERGMAN	22.99	0	6150
3768	11	AFFAIR SCARFACE	MARY WEAVER	19.99	0	1994
3769	10	AFFAIR SCHOOL	MILLA FREEMAN	24.99	0	9027
3770	14	AFFAIR SCISSORHANDS	BURT STALLONE	28.99	0	2503
3771	16	AFFAIR SCORPION	JOE LANCASTER	23.99	0	7992
3772	4	AFFAIR SEA	SCARLETT IRONS	14.99	0	437
3773	14	AFFAIR SEABISCUIT	WOODY RICKMAN	20.99	0	8890
3774	12	AFFAIR SEARCHERS	DUSTIN TAYLOR	18.99	0	1519
3775	6	AFFAIR SEATTLE	ZERO HORNE	18.99	0	1476
3776	12	AFFAIR SECRET	MICHAEL FONDA	12.99	0	4409
3777	16	AFFAIR SECRETARY	THORA DEAN	27.99	0	395
3778	15	AFFAIR SECRETS	RENEE GABLE	27.99	0	848
3779	13	AFFAIR SENSE	WALTER MCCONAUGHEY	9.99	0	5686
3780	3	AFFAIR SENSIBILITY	ALEC HARRIS	12.99	0	3984
3781	6	AFFAIR SEVEN	NEVE LAW	9.99	0	7634
3782	8	AFFAIR SHAKESPEARE	WINONA PINKETT	16.99	0	4699
3783	7	AFFAIR SHANE	RIVER JOHANSSON	13.99	0	7041
3784	5	AFFAIR SHANGHAI	GINA COSTNER	14.99	0	3807
3785	14	AFFAIR SHAWSHANK	RALPH GARCIA	27.99	0	6450
3786	5	AFFAIR SHEPHERD	DEBBIE STALLONE	29.99	0	9583
3787	13	AFFAIR SHINING	MERYL FAWCETT	24.99	0	2904
3788	4	AFFAIR SHIP	RALPH BOLGER	9.99	0	1811
3789	12	AFFAIR SHOCK	GROUCHO MCKELLEN	10.99	0	5483
3790	8	AFFAIR SHOOTIST	STEVE PHOENIX	13.99	0	4388
3791	14	AFFAIR SHOW	FARRAH SUVARI	10.99	0	1341
3792	1	AFFAIR SHREK	JANE MARTIN	24.99	0	1239
3793	1	AFFAIR SHRUNK	DORIS LAW	26.99	0	5517
3794	16	AFFAIR SIDE	CLINT FORD	16.99	0	824
3795	15	AFFAIR SIEGE	RIP SPACEK	25.99	0	4044
3796	4	AFFAIR SIERRA	ELLEN WATSON	20.99	0	1003
3797	11	AFFAIR SILENCE	MICHELLE BASINGER	11.99	0	471
3798	4	AFFAIR SILVERADO	LIAM SILVERSTONE	18.99	0	2052
3799	1	AFFAIR SIMON	KATHARINE MCCONAUGHEY	12.99	0	9380
3800	5	AFFAIR SINNERS	PEARL TANDY	10.99	0	8401
3801	8	AFFAIR SISTER	PEARL VOIGHT	24.99	0	7925
3802	14	AFFAIR SKY	RUBY BOLGER	20.99	0	6340
3803	10	AFFAIR SLACKER	JAYNE HECHE	13.99	0	667
3804	7	AFFAIR SLEEPING	MEL THERON	28.99	0	6468
3805	15	AFFAIR SLEEPLESS	JUDI FORD	22.99	0	1776
3806	8	AFFAIR SLEEPY	BOB TURNER	14.99	0	5355
3807	2	AFFAIR SLEUTH	MAE JACKMAN	28.99	0	8432
3808	9	AFFAIR SLING	ETHAN MCGREGOR	29.99	0	1512
3809	1	AFFAIR SLIPPER	ALICIA DEE	24.99	0	1019
3810	7	AFFAIR SLUMS	JAYNE BEATTY	27.99	0	8617
3811	2	AFFAIR SMILE	PARKER DAY	12.99	0	4198
3812	12	AFFAIR SMOKING	STEVE LAW	16.99	0	9496
3813	3	AFFAIR SMOOCHY	LAURA BACALL	18.99	0	4034
3814	10	AFFAIR SNATCH	MADELINE BERRY	22.99	0	8105
3815	12	AFFAIR SNATCHERS	SCARLETT DAMON	12.99	0	5896
3816	1	AFFAIR SNOWMAN	RICHARD CRAWFORD	26.99	0	3016
3817	4	AFFAIR SOLDIERS	SALMA BASINGER	12.99	0	3397
3818	2	AFFAIR SOMETHING	GWYNETH LOLLOBRIGIDA	23.99	0	3829
3819	2	AFFAIR SONG	JESSICA MINELLI	23.99	0	2802
3820	9	AFFAIR SONS	JOHN ASTAIRE	17.99	0	5936
3821	16	AFFAIR SORORITY	PAUL DEPP	25.99	0	1204
3822	2	AFFAIR SOUP	CHRISTOPHER EASTWOOD	29.99	0	5623
3823	5	AFFAIR SOUTH	CATE KINNEAR	22.99	0	1726
3824	1	AFFAIR SPARTACUS	RIP DUKAKIS	19.99	0	960
3825	13	AFFAIR SPEAKEASY	CARMEN KELLY	14.99	0	3286
3826	14	AFFAIR SPEED	LAUREN TORN	22.99	0	6486
3827	13	AFFAIR SPICE	VAL ROBERTS	28.99	0	3981
3828	8	AFFAIR SPIKING	UMA BACALL	22.99	0	1607
3829	13	AFFAIR SPINAL	JEREMY PFEIFFER	21.99	0	4610
3830	12	AFFAIR SPIRIT	WINONA ALLEN	26.99	0	9063
3831	3	AFFAIR SPIRITED	RICHARD CAMPBELL	24.99	0	4951
3832	7	AFFAIR SPLASH	ETHAN KILMER	16.99	0	84
3833	12	AFFAIR SPLENDOR	ANDY WILLIAMS	23.99	0	7215
3834	14	AFFAIR SPOILERS	JEFF GRANT	15.99	0	6773
3835	13	AFFAIR SPY	MENA PENN	24.99	0	9691
3836	11	AFFAIR SQUAD	CAMERON PALTROW	18.99	0	8961
3837	16	AFFAIR STAGE	JANE STALLONE	13.99	0	9030
3838	4	AFFAIR STAGECOACH	SALMA VOIGHT	14.99	0	4474
3839	16	AFFAIR STALLION	ROCK HOFFMAN	18.99	0	8400
3840	2	AFFAIR STAMPEDE	KIM JOHANSSON	25.99	0	1035
3841	13	AFFAIR STAR	RIP TORN	27.99	0	2625
3842	13	AFFAIR STATE	BRUCE FAWCETT	13.99	0	2849
3843	2	AFFAIR STEEL	DARYL ROBBINS	29.99	0	8055
3844	7	AFFAIR STEERS	EDWARD BALE	14.99	0	9877
3845	2	AFFAIR STEPMOM	JOHN MANSFIELD	22.99	0	7291
3846	13	AFFAIR STING	LIZA CRONYN	21.99	0	9786
3847	14	AFFAIR STOCK	FAY SWANK	28.99	0	8200
3848	4	AFFAIR STONE	LEELEE DAFOE	18.99	0	6335
3849	4	AFFAIR STORM	MATT MCDORMAND	19.99	0	1476
3850	8	AFFAIR STORY	NICOLAS ZELLWEGER	29.99	0	1491
3851	12	AFFAIR STRAIGHT	GLENN HEPBURN	15.99	0	4007
3852	5	AFFAIR STRANGELOVE	ELLEN SUVARI	21.99	0	3372
3853	7	AFFAIR STRANGER	KATHARINE BACALL	29.99	0	7309
3854	10	AFFAIR STRANGERS	GRETA PACINO	15.99	0	2442
3855	8	AFFAIR STREAK	ED NEESON	12.99	0	9073
3856	6	AFFAIR STREETCAR	GRACE FINNEY	22.99	0	3495
3857	2	AFFAIR STRICTLY	DARYL WASHINGTON	15.99	0	13
3858	11	AFFAIR SUBMARINE	ALICIA TYLER	13.99	0	4949
3859	15	AFFAIR SUGAR	DANIEL KEITEL	14.99	0	3933
3860	9	AFFAIR SUICIDES	ANNETTE DERN	25.99	0	6942
3861	11	AFFAIR SUIT	ALAN ROBERTS	9.99	0	6536
3862	6	AFFAIR SUMMER	LAURENCE JOLIE	20.99	0	959
3863	10	AFFAIR SUN	ADRIEN IRONS	21.99	0	9060
3864	2	AFFAIR SUNDANCE	JADA MCCONAUGHEY	15.99	0	2456
3865	12	AFFAIR SUNRISE	JUDE HEPBURN	24.99	0	9440
3866	8	AFFAIR SUNSET	MIRA THURMAN	18.99	0	1596
3867	2	AFFAIR SUPER	MARY DIETRICH	23.99	0	4906
3868	13	AFFAIR SUPERFLY	WILLEM HAWKE	25.99	0	6646
3869	12	AFFAIR SUSPECTS	FARRAH BRANDO	11.99	0	1883
3870	7	AFFAIR SWARM	LIZA BOLGER	27.99	0	8281
3871	14	AFFAIR SWEDEN	MINNIE EASTWOOD	20.99	0	6191
3872	12	AFFAIR SWEET	SIGOURNEY TEMPLE	16.99	0	7348
3873	14	AFFAIR SWEETHEARTS	CHARLIZE GOLDBERG	26.99	0	1666
3874	9	AFFAIR TADPOLE	FARRAH TOMEI	25.99	0	6911
3875	16	AFFAIR TALENTED	RAY HAWKE	21.99	0	6450
3876	7	AFFAIR TARZAN	VAL CAGE	11.99	0	7085
3877	13	AFFAIR TAXI	LAURENCE GUINESS	22.99	0	1698
3878	7	AFFAIR TEEN	KENNETH MCGREGOR	20.99	0	7314
3879	12	AFFAIR TELEGRAPH	LIZA WINSLET	29.99	0	6541
3880	11	AFFAIR TELEMARK	ANTHONY PITT	18.99	0	3705
3881	2	AFFAIR TEMPLE	JUDE ROBBINS	10.99	0	1845
3882	13	AFFAIR TENENBAUMS	LAURA NEWMAN	16.99	0	3417
3883	9	AFFAIR TEQUILA	WILL PECK	10.99	0	4418
3884	13	AFFAIR TERMINATOR	INGRID WEST	17.99	0	1839
3885	2	AFFAIR TEXAS	THORA MATTHAU	12.99	0	2706
3886	9	AFFAIR THEORY	ANGELA CRUISE	9.99	0	9541
3887	4	AFFAIR THIEF	LUCILLE ALLEN	25.99	0	9540
3888	2	AFFAIR THIN	MATT THURMAN	11.99	0	9181
3889	9	AFFAIR TIES	SCARLETT REYNOLDS	29.99	0	8099
3890	3	AFFAIR TIGHTS	JACK DIETRICH	10.99	0	5019
3891	6	AFFAIR TIMBERLAND	MERYL WAYNE	16.99	0	9399
3892	6	AFFAIR TITANIC	VIVIEN COOPER	29.99	0	3179
3893	15	AFFAIR TITANS	DEBBIE BERRY	21.99	0	1673
3894	8	AFFAIR TOMATOES	TIM PECK	16.99	0	1215
3895	3	AFFAIR TOMORROW	HILARY SARANDON	21.99	0	8128
3896	2	AFFAIR TOOTSIE	OLYMPIA DAVIS	25.99	0	7161
3897	12	AFFAIR TORQUE	SIDNEY WAHLBERG	23.99	0	8386
3898	1	AFFAIR TOURIST	SUSAN RYDER	13.99	0	896
3899	7	AFFAIR TOWERS	RENEE TEMPLE	15.99	0	4671
3900	7	AFFAIR TOWN	ETHAN HEPBURN	26.99	0	1458
3901	11	AFFAIR TRACY	GROUCHO CAMPBELL	17.99	0	9449
3902	2	AFFAIR TRADING	SANDRA NOLTE	29.99	0	7489
3903	14	AFFAIR TRAFFIC	KENNETH GOODING	24.99	0	9238
3904	14	AFFAIR TRAIN	RENEE WINSLET	22.99	0	525
3905	2	AFFAIR TRAINSPOTTING	JOE PFEIFFER	16.99	0	5213
3906	9	AFFAIR TRAMP	MARY CRUZ	27.99	0	6063
3907	14	AFFAIR TRANSLATION	FAY OLIVIER	23.99	0	6585
3908	8	AFFAIR TRAP	ANDY KELLY	29.99	0	6347
3909	15	AFFAIR TREASURE	LISA BRIDGES	23.99	0	9057
3910	13	AFFAIR TREATMENT	MADELINE TAUTOU	14.99	0	1890
3911	13	AFFAIR TRIP	HELEN ROBBINS	18.99	0	9745
3912	1	AFFAIR TROJAN	MATTHEW HUSTON	15.99	0	3684
3913	16	AFFAIR TROOPERS	SISSY MCCONAUGHEY	9.99	0	1760
3914	11	AFFAIR TROUBLE	FRANCES KEATON	14.99	0	537
3915	3	AFFAIR TRUMAN	SYLVESTER ZELLWEGER	26.99	0	1668
3916	1	AFFAIR TURN	TOM ANISTON	17.99	0	5948
3917	6	AFFAIR TUXEDO	BELA JOHANSSON	9.99	0	2523
3918	7	AFFAIR TWISTED	SCARLETT SINATRA	15.99	0	4758
3919	8	AFFAIR TYCOON	WOODY JOLIE	25.99	0	2237
3920	14	AFFAIR UNBREAKABLE	DIANE WILLIAMS	24.99	0	4681
3921	15	AFFAIR UNCUT	JOHN ROBBINS	26.99	0	9433
3922	8	AFFAIR UNDEFEATED	JAYNE KEITEL	19.99	0	2694
3923	13	AFFAIR UNFAITHFUL	BEN WILLIS	22.99	0	9273
3924	2	AFFAIR UNFORGIVEN	JAMES PITT	11.99	0	2090
3925	6	AFFAIR UNITED	CHRISTIAN FORD	20.99	0	9389
3926	1	AFFAIR UNTOUCHABLES	MINNIE ZELLWEGER	19.99	0	8749
3927	8	AFFAIR UPRISING	HUGH DUKAKIS	27.99	0	9577
3928	3	AFFAIR UPTOWN	SYLVESTER MALDEN	14.99	0	1852
3929	3	AFFAIR USUAL	THORA GARBO	21.99	0	4393
3930	14	AFFAIR VACATION	PEARL SILVERSTONE	29.99	0	8607
3931	15	AFFAIR VALENTINE	SALLY GUINESS	22.99	0	7030
3932	9	AFFAIR VALLEY	ZERO GARLAND	28.99	0	8129
3933	14	AFFAIR VAMPIRE	HUME HEPBURN	25.99	0	6420
3934	16	AFFAIR VANILLA	ADAM TAUTOU	27.99	0	4730
3935	6	AFFAIR VANISHED	FARRAH DUNST	11.99	0	6518
3936	16	AFFAIR VANISHING	ANGELINA DAMON	26.99	0	9553
3937	9	AFFAIR VARSITY	GINA GARCIA	20.99	0	5853
3938	6	AFFAIR VELVET	ALAN CAMPBELL	24.99	0	7027
3939	7	AFFAIR VERTIGO	KIRSTEN TYLER	17.99	0	441
3940	14	AFFAIR VICTORY	GREG CHAPLIN	12.99	0	6231
3941	13	AFFAIR VIDEOTAPE	ROBIN DEPP	26.99	0	6798
3942	13	AFFAIR VIETNAM	ANGELA MCGREGOR	11.99	0	3150
3943	12	AFFAIR VILLAIN	JEREMY JOVOVICH	24.99	0	3928
3944	7	AFFAIR VIRGIN	FRED MOORE	29.99	0	1156
3945	1	AFFAIR VIRGINIAN	EMILY VOIGHT	17.99	0	5430
3946	1	AFFAIR VIRTUAL	REESE TAYLOR	26.99	0	8840
3947	9	AFFAIR VISION	JUDY KEITEL	20.99	0	6722
3948	14	AFFAIR VOICE	CLINT GARBO	15.99	0	4427
3949	12	AFFAIR VOLCANO	BRAD KEATON	9.99	0	1486
3950	3	AFFAIR VOLUME	ANTHONY LANSBURY	17.99	0	1347
3951	16	AFFAIR VOYAGE	ADRIEN WEAVER	24.99	0	7253
3952	11	AFFAIR WAGON	EDWARD EASTWOOD	12.99	0	8985
3953	14	AFFAIR WAIT	ELLEN PHOENIX	29.99	0	3454
3954	8	AFFAIR WAKE	SALMA RUSSELL	20.99	0	3795
3955	12	AFFAIR WALLS	TOM WILLIAMS	24.99	0	8789
3956	15	AFFAIR WANDA	ROBERT FISHER	27.99	0	6090
3957	10	AFFAIR WAR	SPENCER PECK	27.99	0	7690
3958	13	AFFAIR WARDROBE	JUDE NICHOLSON	9.99	0	5656
3959	6	AFFAIR WARLOCK	GRETA BRODY	13.99	0	1704
3960	10	AFFAIR WARS	CARRIE GABLE	20.99	0	5016
3961	7	AFFAIR WASH	ROBERT ZELLWEGER	14.99	0	9083
3962	14	AFFAIR WASTELAND	LIZA KAHN	25.99	0	4834
3963	9	AFFAIR WATCH	CHRIS CARREY	9.99	0	8407
3964	10	AFFAIR WATERFRONT	WARREN KUDROW	29.99	0	6226
3965	3	AFFAIR WATERSHIP	WILL HACKMAN	14.99	0	785
3966	13	AFFAIR WEDDING	AUDREY GOLDBERG	21.99	0	9647
3967	9	AFFAIR WEEKEND	JODIE JOLIE	11.99	0	8573
3968	10	AFFAIR WEREWOLF	ADRIEN SMITH	25.99	0	1826
3969	10	AFFAIR WEST	NATALIE HURT	21.99	0	5121
3970	4	AFFAIR WESTWARD	SPENCER LOLLOBRIGIDA	12.99	0	8572
3971	4	AFFAIR WHALE	DUSTIN MARX	15.99	0	8730
3972	5	AFFAIR WHISPERER	HARRISON PALTROW	25.99	0	6505
3973	10	AFFAIR WIFE	JOAN HOPE	22.99	0	3366
3974	13	AFFAIR WILD	RIP SORVINO	20.99	0	2555
3975	1	AFFAIR WILLOW	ROBIN MARTIN	29.99	0	6760
3976	14	AFFAIR WIND	FAY ASTAIRE	10.99	0	4910
3977	15	AFFAIR WINDOW	DARYL MCGREGOR	15.99	0	370
3978	16	AFFAIR WISDOM	JOE ALLEN	17.99	0	7027
3979	13	AFFAIR WITCHES	KARL HOPE	21.99	0	9411
3980	14	AFFAIR WIZARD	KATHARINE BALE	22.99	1	3171
3981	6	AFFAIR WOLVES	GRACE SILVERSTONE	22.99	0	6810
3982	2	AFFAIR WOMEN	GENE RYAN	15.99	0	7027
3983	6	AFFAIR WON	MINNIE BARRYMORE	26.99	0	3532
3984	9	AFFAIR WONDERFUL	RENEE DEAN	10.99	0	7877
3985	1	AFFAIR WONDERLAND	ROBERT MCGREGOR	20.99	0	8229
3986	14	AFFAIR WONKA	MAE MCDORMAND	13.99	0	5046
3987	15	AFFAIR WORDS	FRANK GARBO	13.99	0	3936
3988	15	AFFAIR WORKER	JANE ASTAIRE	22.99	0	9077
3989	16	AFFAIR WORKING	CARY GUINESS	25.99	0	9327
3990	9	AFFAIR WORLD	KIM HURT	17.99	0	8450
3991	4	AFFAIR WORST	JIM TURNER	26.99	0	7126
3992	6	AFFAIR WRATH	AUDREY AKROYD	22.99	0	7412
3993	1	AFFAIR WRONG	ORLANDO BRIDGES	19.99	0	6177
3994	7	AFFAIR WYOMING	ADRIEN PECK	20.99	0	4726
3995	8	AFFAIR YENTL	VAL BARRYMORE	9.99	0	9801
3996	14	AFFAIR YOUNG	SIDNEY MIRANDA	15.99	0	30
3997	1	AFFAIR YOUTH	AL STREEP	11.99	0	2259
3998	14	AFFAIR ZHIVAGO	GREG KINNEAR	21.99	0	837
3999	4	AFFAIR ZOOLANDER	REESE HAWN	14.99	0	2832
4000	12	AFFAIR ZORRO	GOLDIE HACKMAN	22.99	0	7688
4001	11	AFRICAN ACADEMY	INGRID DOUGLAS	20.99	0	9099
4002	9	AFRICAN ACE	OPRAH MIRANDA	20.99	0	2524
4003	13	AFRICAN ADAPTATION	RAY MATTHAU	11.99	0	8172
4004	4	AFRICAN AFFAIR	DREW HORNE	29.99	0	1739
4005	5	AFRICAN AFRICAN	LANA HAYEK	21.99	0	9890
4006	7	AFRICAN AGENT	EMILY PFEIFFER	25.99	0	8734
4007	12	AFRICAN AIRPLANE	JULIANNE RUSSELL	18.99	0	2830
4008	12	AFRICAN AIRPORT	SISSY BRANAGH	19.99	0	1268
4009	6	AFRICAN ALABAMA	LAURENCE HAWN	20.99	0	2960
4010	12	AFRICAN ALADDIN	MIRA ODONNELL	15.99	0	8024
4011	5	AFRICAN ALAMO	KARL NOLTE	20.99	0	7883
4012	7	AFRICAN ALASKA	LAURA CRONYN	29.99	0	9124
4013	4	AFRICAN ALI	ALAN GARBO	11.99	0	2381
4014	5	AFRICAN ALICE	MARLON CROWE	26.99	0	724
4015	3	AFRICAN ALIEN	PARKER HUNT	27.99	0	692
4016	11	AFRICAN ALLEY	OLYMPIA BERGEN	13.99	0	2301
4017	16	AFRICAN ALONE	IAN BASINGER	20.99	0	565
4018	8	AFRICAN ALTER	IAN DENCH	19.99	0	2755
4019	12	AFRICAN AMADEUS	JESSICA MCQUEEN	17.99	0	2024
4020	8	AFRICAN AMELIE	MATTHEW MCKELLEN	13.99	0	4469
4021	5	AFRICAN AMERICAN	JUDY CLOSE	9.99	0	1351
4022	5	AFRICAN AMISTAD	CUBA FOSTER	23.99	0	1975
4023	12	AFRICAN ANACONDA	JAYNE GOODING	12.99	0	8195
4024	7	AFRICAN ANALYZE	JEREMY MARX	27.99	1	9457
4025	2	AFRICAN ANGELS	LAURA HOPKINS	25.99	0	777
4026	4	AFRICAN ANNIE	ED WINFREY	24.99	0	6014
4027	14	AFRICAN ANONYMOUS	VAL DUNST	10.99	0	8538
4028	5	AFRICAN ANTHEM	DUSTIN PINKETT	23.99	0	1111
4029	9	AFRICAN ANTITRUST	MIRA FONDA	29.99	0	7100
4030	15	AFRICAN ANYTHING	CHRIS FISHER	19.99	0	8438
4031	10	AFRICAN APACHE	RITA FIELD	26.99	0	8407
4032	7	AFRICAN APOCALYPSE	CATE TYLER	16.99	0	1295
4033	4	AFRICAN APOLLO	SANDRA DAY	18.99	0	7611
4034	10	AFRICAN ARABIA	BOB HECHE	14.99	0	3184
4035	16	AFRICAN ARACHNOPHOBIA	MARILYN FIELD	12.99	0	7400
4036	16	AFRICAN ARGONAUTS	ANJELICA GOODING	26.99	0	1003
4037	11	AFRICAN ARIZONA	AL MCCONAUGHEY	25.99	0	9766
4038	15	AFRICAN ARK	DAN CRUISE	25.99	0	1063
4039	9	AFRICAN ARMAGEDDON	KARL DAVIS	22.99	0	9278
4040	16	AFRICAN ARMY	ED HUSTON	21.99	0	496
4041	6	AFRICAN ARSENIC	JAMES MCQUEEN	17.99	0	6312
4042	9	AFRICAN ARTIST	EDWARD BRANAGH	19.99	0	2246
4043	8	AFRICAN ATLANTIS	INGRID SORVINO	23.99	0	676
4044	13	AFRICAN ATTACKS	EWAN CRAWFORD	15.99	0	7721
4045	4	AFRICAN ATTRACTION	ELLEN RUSSELL	19.99	0	8924
4046	9	AFRICAN AUTUMN	JULIETTE PITT	29.99	0	9797
4047	10	AFRICAN BABY	BETTE MINELLI	26.99	0	9959
4048	2	AFRICAN BACKLASH	ROBERT MIRANDA	19.99	0	4552
4049	9	AFRICAN BADMAN	MADELINE BRIDGES	26.99	0	4580
4050	10	AFRICAN BAKED	EDWARD ODONNELL	27.99	0	6389
4051	13	AFRICAN BALLOON	HARVEY PENN	15.99	0	5214
4052	5	AFRICAN BALLROOM	CHRISTIAN DUKAKIS	16.99	0	3219
4053	6	AFRICAN BANG	WHOOPI DAY	12.99	0	2976
4054	11	AFRICAN BANGER	INGRID DIETRICH	14.99	0	8583
4055	12	AFRICAN BARBARELLA	KENNETH PESCI	29.99	0	7286
4056	10	AFRICAN BAREFOOT	JEFF GABLE	29.99	0	1385
4057	9	AFRICAN BASIC	JAMES TURNER	23.99	0	5755
4058	1	AFRICAN BEACH	RAY MCCONAUGHEY	29.99	0	5030
4059	5	AFRICAN BEAR	PAUL HEPBURN	23.99	0	8866
4060	9	AFRICAN BEAST	LISA HEPBURN	10.99	0	2037
4061	14	AFRICAN BEAUTY	KIM ASTAIRE	14.99	0	1961
4062	7	AFRICAN BED	BRUCE KELLY	26.99	0	3669
4063	7	AFRICAN BEDAZZLED	WILLIAM DAFOE	13.99	0	7800
4064	12	AFRICAN BEETHOVEN	DENNIS HESTON	19.99	0	9189
4065	6	AFRICAN BEHAVIOR	GRETA MOSTEL	29.99	0	7602
4066	3	AFRICAN BENEATH	PENELOPE LEWIS	24.99	0	7932
4067	15	AFRICAN BERETS	GEOFFREY DENCH	9.99	0	5236
4068	7	AFRICAN BETRAYED	NATALIE IRONS	17.99	0	9015
4069	3	AFRICAN BEVERLY	GREG HANNAH	17.99	0	4620
4070	5	AFRICAN BIKINI	CARMEN DEPP	22.99	0	8774
4071	7	AFRICAN BILKO	JEFF HAWN	13.99	0	2850
4072	16	AFRICAN BILL	JULIETTE BLOOM	15.99	0	6039
4073	14	AFRICAN BINGO	BOB KILMER	20.99	0	7881
4074	8	AFRICAN BIRCH	CUBA BLOOM	25.99	0	738
4075	5	AFRICAN BIRD	GLENN ROBBINS	17.99	0	5584
4076	5	AFRICAN BIRDCAGE	WILL STALLONE	23.99	0	1295
4077	16	AFRICAN BIRDS	DIANE ASTAIRE	19.99	0	3502
4078	3	AFRICAN BLACKOUT	SIDNEY CLOSE	13.99	0	8092
4079	1	AFRICAN BLADE	SOPHIA CRAWFORD	13.99	0	3751
4080	5	AFRICAN BLANKET	CHARLIZE DENCH	21.99	0	5785
4081	3	AFRICAN BLINDNESS	JACK TOMEI	11.99	0	4574
4082	5	AFRICAN BLOOD	JOE MARTIN	19.99	0	8119
4083	14	AFRICAN BLUES	WILL DEPP	24.99	0	6913
4084	9	AFRICAN BOILED	SANDRA HUSTON	17.99	0	8489
4085	13	AFRICAN BONNIE	BETTE WILLIAMS	28.99	0	7178
4086	9	AFRICAN BOOGIE	LIAM PECK	28.99	0	2147
4087	7	AFRICAN BOONDOCK	RITA BOLGER	27.99	0	9424
4088	12	AFRICAN BORN	DANIEL HAWN	23.99	0	6692
4089	6	AFRICAN BORROWERS	CHARLTON MOSTEL	13.99	0	8344
4090	2	AFRICAN BOULEVARD	RALPH TOMEI	12.99	0	3436
4091	15	AFRICAN BOUND	ANNE GIBSON	19.99	0	8983
4092	12	AFRICAN BOWFINGER	ADAM PHOENIX	20.99	0	5881
4093	8	AFRICAN BRANNIGAN	ADRIEN FISHER	23.99	0	1396
4094	6	AFRICAN BRAVEHEART	RENEE GARLAND	19.99	0	8881
4095	6	AFRICAN BREAKFAST	PEARL NORTON	11.99	0	6209
4096	8	AFRICAN BREAKING	WOODY POSEY	19.99	0	3191
4097	7	AFRICAN BRIDE	ANJELICA WINFREY	17.99	0	6767
4098	1	AFRICAN BRIGHT	ADAM WINSLET	9.99	0	29
4099	3	AFRICAN BRINGING	HALLE WRAY	28.99	0	9700
4100	14	AFRICAN BROOKLYN	MARLON SARANDON	21.99	0	5155
4101	4	AFRICAN BROTHERHOOD	EMILY GOODING	13.99	0	5209
4102	9	AFRICAN BUBBLE	JOHNNY FIELD	21.99	0	9947
4103	5	AFRICAN BUCKET	WILL PHOENIX	14.99	0	6238
4104	5	AFRICAN BUGSY	LISA THURMAN	22.99	0	964
4105	10	AFRICAN BULL	SPENCER NEWMAN	14.99	0	8307
4106	13	AFRICAN BULWORTH	DENZEL KEITEL	10.99	0	1153
4107	10	AFRICAN BUNCH	JADA EASTWOOD	10.99	0	1559
4108	2	AFRICAN BUTCH	SIDNEY CRONYN	9.99	0	6274
4109	11	AFRICAN BUTTERFLY	JULIA POITIER	14.99	0	3525
4110	6	AFRICAN CABIN	ALEC ASTAIRE	14.99	0	3136
4111	2	AFRICAN CADDYSHACK	ROCK BLOOM	15.99	0	5903
4112	8	AFRICAN CALENDAR	SIGOURNEY PHOENIX	27.99	0	7958
4113	1	AFRICAN CALIFORNIA	WILLEM TAYLOR	28.99	0	4398
4114	9	AFRICAN CAMELOT	CUBA LOLLOBRIGIDA	10.99	0	5838
4115	7	AFRICAN CAMPUS	LEONARDO DEE	18.99	0	9024
4116	12	AFRICAN CANDIDATE	WOODY MCDORMAND	21.99	0	1461
4117	3	AFRICAN CANDLES	SEAN GUINESS	10.99	0	6859
4118	14	AFRICAN CANYON	KIM DRIVER	26.99	0	4736
4119	5	AFRICAN CAPER	ANJELICA PITT	18.99	0	9103
4120	1	AFRICAN CARIBBEAN	CHARLES DAMON	22.99	0	6558
4121	9	AFRICAN CAROL	EWAN GRANT	20.99	0	2303
4122	12	AFRICAN CARRIE	LIZA CARREY	21.99	0	8854
4123	5	AFRICAN CASABLANCA	CHRISTOPHER BERRY	26.99	0	3749
4124	5	AFRICAN CASPER	CANDICE CRUZ	16.99	0	9147
4125	5	AFRICAN CASSIDY	CARMEN PECK	17.99	0	7621
4126	1	AFRICAN CASUALTIES	CHARLTON WAHLBERG	16.99	0	1240
4127	10	AFRICAN CAT	ETHAN COOPER	12.99	0	4878
4128	2	AFRICAN CATCH	KIRSTEN AKROYD	14.99	0	4852
4129	10	AFRICAN CAUSE	MEL BRODY	24.99	0	3488
4130	11	AFRICAN CELEBRITY	ANNETTE PESCI	25.99	0	4304
4131	9	AFRICAN CENTER	GRETA CRAWFORD	23.99	0	8269
4132	13	AFRICAN CHAINSAW	ZERO BIRCH	10.99	0	7402
4133	10	AFRICAN CHAMBER	NICOLE FOSTER	11.99	0	5719
4134	10	AFRICAN CHAMPION	MERYL DAVIS	15.99	0	1592
4135	11	AFRICAN CHANCE	SHIRLEY MARTIN	24.99	0	69
4136	3	AFRICAN CHAPLIN	CUBA VOIGHT	19.99	0	7009
4137	6	AFRICAN CHARADE	PENELOPE HAWKE	15.99	0	497
4138	2	AFRICAN CHARIOTS	HILARY BERGEN	26.99	0	9816
4139	7	AFRICAN CHASING	DAN SOBIESKI	10.99	0	1439
4140	4	AFRICAN CHEAPER	NICOLE RYAN	11.99	0	1264
4141	2	AFRICAN CHICAGO	ANGELA MOORE	15.99	0	6439
4142	1	AFRICAN CHICKEN	ANNE IRONS	25.99	0	5546
4143	14	AFRICAN CHILL	LIZA TEMPLE	13.99	0	8287
4144	4	AFRICAN CHINATOWN	MARLON BERGMAN	17.99	0	7923
4145	9	AFRICAN CHISUM	LAUREN GOODING	15.99	0	919
4146	7	AFRICAN CHITTY	NICOLE MCDORMAND	18.99	0	9097
4147	2	AFRICAN CHOCOLAT	HUGH WEAVER	12.99	0	2135
4148	12	AFRICAN CHOCOLATE	BOB LOLLOBRIGIDA	16.99	0	7836
4149	3	AFRICAN CHRISTMAS	SALLY BACALL	26.99	0	52
4150	10	AFRICAN CIDER	HENRY WOOD	13.99	0	8871
4151	5	AFRICAN CINCINATTI	JUDY PENN	10.99	0	4446
4152	16	AFRICAN CIRCUS	HENRY DUNST	16.99	0	1269
4153	10	AFRICAN CITIZEN	MILLA CRUISE	22.99	0	5187
4154	8	AFRICAN CLASH	KENNETH PECK	15.99	0	9838
4155	5	AFRICAN CLEOPATRA	WILL COSTNER	23.99	0	2632
4156	10	AFRICAN CLERKS	WILLEM NICHOLSON	11.99	0	1647
4157	9	AFRICAN CLOCKWORK	JESSICA NORTON	28.99	0	9280
4158	1	AFRICAN CLONES	CANDICE MATTHAU	25.99	0	6561
4159	5	AFRICAN CLOSER	HALLE PFEIFFER	26.99	0	9149
4160	13	AFRICAN CLUB	BETTE FOSTER	25.99	0	4636
4161	1	AFRICAN CLUE	CHARLES MCDORMAND	9.99	0	8686
4162	4	AFRICAN CLUELESS	KEVIN DERN	22.99	0	5982
4163	10	AFRICAN CLYDE	DENNIS DENCH	23.99	0	4924
4164	6	AFRICAN COAST	DENZEL DRIVER	24.99	0	2514
4165	11	AFRICAN COLDBLOODED	LEELEE WALKEN	24.99	0	6326
4166	4	AFRICAN COLOR	ELLEN PRESLEY	15.99	0	9758
4167	4	AFRICAN COMA	DREW WINSLET	24.99	0	4232
4168	6	AFRICAN COMANCHEROS	MATT DAVIS	20.99	0	6743
4169	1	AFRICAN COMFORTS	WARREN DIETRICH	14.99	1	765
4170	9	AFRICAN COMMAND	ADAM MCQUEEN	11.99	0	7137
4171	13	AFRICAN COMMANDMENTS	JOAN LANCASTER	9.99	0	2586
4172	16	AFRICAN CONEHEADS	DUSTIN BIRCH	13.99	0	8695
4173	11	AFRICAN CONFESSIONS	BEN CROWE	15.99	0	9980
4174	16	AFRICAN CONFIDENTIAL	EMILY SARANDON	28.99	0	2647
4175	1	AFRICAN CONFUSED	SOPHIA MATTHAU	9.99	0	2627
4176	12	AFRICAN CONGENIALITY	RIP IRONS	13.99	0	6951
4177	8	AFRICAN CONNECTICUT	PEARL HUSTON	23.99	0	6099
4178	10	AFRICAN CONNECTION	REESE FREEMAN	22.99	0	5465
4179	11	AFRICAN CONQUERER	GRETA MINELLI	28.99	0	4384
4180	4	AFRICAN CONSPIRACY	ANJELICA MATTHAU	10.99	0	7835
4181	6	AFRICAN CONTACT	ETHAN GOODING	12.99	0	7667
4182	14	AFRICAN CONTROL	EDWARD BENING	22.99	0	9520
4183	4	AFRICAN CONVERSATION	FRANK FREEMAN	9.99	0	9563
4184	10	AFRICAN CORE	LENA NEESON	28.99	0	1903
4185	7	AFRICAN COWBOY	RENEE RUSSELL	18.99	0	4448
4186	4	AFRICAN CRAFT	ROBERT DEGENERES	19.99	0	4178
4187	5	AFRICAN CRANES	JOE DICAPRIO	19.99	0	2524
4188	8	AFRICAN CRAZY	LEONARDO CHASE	24.99	0	6102
4189	12	AFRICAN CREATURES	EWAN RYDER	15.99	0	8735
4190	9	AFRICAN CREEPERS	MARY BULLOCK	15.99	0	5410
4191	12	AFRICAN CROOKED	PEARL ROBERTS	21.99	0	1815
4192	16	AFRICAN CROSSING	JENNIFER KEITEL	18.99	0	3592
4193	12	AFRICAN CROSSROADS	JULIA HUSTON	15.99	0	7217
4194	15	AFRICAN CROW	JULIA WEAVER	13.99	0	2595
4195	2	AFRICAN CROWDS	HENRY PRESLEY	24.99	0	9467
4196	5	AFRICAN CRUELTY	NATALIE SILVERSTONE	10.99	0	9931
4197	4	AFRICAN CRUSADE	JULIA GOLDBERG	23.99	0	5411
4198	1	AFRICAN CRYSTAL	ALBERT LOLLOBRIGIDA	21.99	0	2583
4199	5	AFRICAN CUPBOARD	DARYL STALLONE	26.99	0	4606
4200	2	AFRICAN CURTAIN	DENZEL CAMPBELL	18.99	0	2781
4201	7	AFRICAN CYCLONE	BETTE CRONYN	11.99	0	4735
4202	2	AFRICAN DADDY	RUSSELL JOHANSSON	22.99	0	7014
4203	3	AFRICAN DAISY	EWAN DEPP	13.99	0	1812
4204	8	AFRICAN DALMATIONS	ALBERT BULLOCK	22.99	0	762
4205	3	AFRICAN DANCES	DENZEL ALLEN	16.99	0	1121
4206	10	AFRICAN DANCING	FRANCES TEMPLE	23.99	0	5437
4207	3	AFRICAN DANGEROUS	ANGELA CAINE	9.99	0	2365
4208	12	AFRICAN DARES	JOHN WILLIAMS	9.99	0	3181
4209	4	AFRICAN DARKNESS	JAYNE MCDORMAND	13.99	0	3832
4210	5	AFRICAN DARKO	HUGH HAWN	19.99	0	8697
4211	10	AFRICAN DARLING	NICOLE GOODING	28.99	0	7599
4212	8	AFRICAN DARN	SISSY DOUGLAS	19.99	0	6721
4213	12	AFRICAN DATE	LUCILLE BARRYMORE	13.99	0	7909
4214	9	AFRICAN DAUGHTER	IAN DERN	29.99	0	7041
4215	6	AFRICAN DAWN	CARMEN RICKMAN	25.99	0	8818
4216	11	AFRICAN DAY	ELVIS TRACY	17.99	0	3580
4217	3	AFRICAN DAZED	MAE DREYFUSS	9.99	0	9473
4218	12	AFRICAN DECEIVER	ZERO KEITEL	16.99	0	573
4219	3	AFRICAN DEEP	GENE EASTWOOD	20.99	0	7877
4220	5	AFRICAN DEER	KEVIN NEESON	16.99	0	8315
4221	5	AFRICAN DELIVERANCE	NEVE BERRY	19.99	0	5540
4222	15	AFRICAN DESERT	ROCK MATTHAU	19.99	0	6222
4223	8	AFRICAN DESIRE	CHARLIZE GIBSON	18.99	0	9011
4224	9	AFRICAN DESPERATE	DARYL SWANK	26.99	0	4935
4225	10	AFRICAN DESTINATION	CHEVY MOSTEL	12.99	0	5938
4226	1	AFRICAN DESTINY	MATT DUNST	24.99	0	1327
4227	5	AFRICAN DETAILS	NICOLE OLIVIER	11.99	0	4018
4228	12	AFRICAN DETECTIVE	PAUL NICHOLSON	27.99	0	4942
4229	13	AFRICAN DEVIL	GRETA MONROE	29.99	0	7571
4230	8	AFRICAN DIARY	INGRID BOGART	22.99	0	4569
4231	4	AFRICAN DINOSAUR	OLYMPIA DIETRICH	28.99	0	5704
4232	1	AFRICAN DIRTY	EMILY DUNST	25.99	0	4823
4233	4	AFRICAN DISCIPLE	CHEVY COOPER	29.99	0	2938
4234	8	AFRICAN DISTURBING	UMA TANDY	26.99	0	4240
4235	10	AFRICAN DIVIDE	JULIANNE GABLE	29.99	0	7891
4236	8	AFRICAN DIVINE	ANNE DENIRO	13.99	0	649
4237	13	AFRICAN DIVORCE	GWYNETH DAMON	9.99	1	7815
4238	9	AFRICAN DOCTOR	VIVIEN CROWE	23.99	0	162
4239	16	AFRICAN DOGMA	SEAN MCCONAUGHEY	28.99	0	7380
4240	6	AFRICAN DOLLS	BOB ZELLWEGER	27.99	0	933
4241	11	AFRICAN DONNIE	GREG HEPBURN	23.99	0	5009
4242	13	AFRICAN DOOM	MILLA HACKMAN	11.99	0	7043
4243	15	AFRICAN DOORS	SIGOURNEY WEST	27.99	0	515
4244	15	AFRICAN DORADO	MATTHEW MANSFIELD	24.99	0	1015
4245	8	AFRICAN DOUBLE	BRUCE SUVARI	21.99	0	889
4246	11	AFRICAN DOUBTFIRE	JULIANNE GARCIA	9.99	0	1506
4247	9	AFRICAN DOWNHILL	KENNETH STALLONE	13.99	0	9804
4248	15	AFRICAN DOZEN	TIM THURMAN	26.99	0	5594
4249	15	AFRICAN DRACULA	CHEVY MCQUEEN	20.99	0	6721
4250	11	AFRICAN DRAGON	JULIANNE TOMEI	24.99	0	2369
4251	14	AFRICAN DRAGONFLY	LENA CLOSE	16.99	0	6672
4252	9	AFRICAN DREAM	JUDI PACINO	10.99	0	4840
4253	1	AFRICAN DRIFTER	HARRISON TAUTOU	29.99	0	1279
4254	9	AFRICAN DRIVER	ORLANDO LEWIS	23.99	0	1597
4255	6	AFRICAN DRIVING	ANJELICA ROBBINS	27.99	0	5330
4256	2	AFRICAN DROP	MERYL GARLAND	24.99	0	8770
4257	7	AFRICAN DRUMLINE	LAUREN DENCH	27.99	0	5156
4258	7	AFRICAN DRUMS	HELEN FOSTER	24.99	0	777
4259	15	AFRICAN DUCK	MARLENE STALLONE	22.99	0	7742
4260	13	AFRICAN DUDE	KENNETH TORN	27.99	0	739
4261	7	AFRICAN DUFFEL	JAYNE TRACY	10.99	0	1697
4262	16	AFRICAN DUMBO	IAN ALLEN	20.99	0	7128
4263	1	AFRICAN DURHAM	ANJELICA DUKAKIS	18.99	0	3685
4264	9	AFRICAN DWARFS	DENNIS WALKEN	12.99	0	7474
4265	16	AFRICAN DYING	MARILYN GOLDBERG	19.99	0	4244
4266	10	AFRICAN DYNAMITE	GLENN MCGREGOR	9.99	0	9538
4267	3	AFRICAN EAGLES	WHOOPI NICHOLSON	21.99	0	8768
4268	5	AFRICAN EARLY	CHRISTIAN DREYFUSS	16.99	0	2131
4269	12	AFRICAN EARRING	CHARLES DENCH	28.99	0	7142
4270	11	AFRICAN EARTH	BOB GARCIA	15.99	0	3318
4271	13	AFRICAN EASY	WARREN HAYEK	10.99	0	6762
4272	1	AFRICAN EDGE	GRETA MARX	9.99	0	5759
4273	15	AFRICAN EFFECT	SALLY JOHANSSON	9.99	0	5818
4274	5	AFRICAN EGG	ROBERT LOREN	17.99	0	2423
4275	2	AFRICAN EGYPT	LEONARDO DAFOE	13.99	0	4591
4276	9	AFRICAN ELEMENT	SHIRLEY DRIVER	19.99	0	3129
4277	3	AFRICAN ELEPHANT	SYLVESTER HANNAH	20.99	0	1197
4278	2	AFRICAN ELF	LIV DREYFUSS	29.99	0	4758
4279	9	AFRICAN ELIZABETH	ANNE LUGOSI	16.99	0	5765
4280	10	AFRICAN EMPIRE	PENELOPE BOLGER	13.99	0	3148
4281	11	AFRICAN ENCINO	LEONARDO SUVARI	20.99	0	9685
4282	14	AFRICAN ENCOUNTERS	HARRISON KELLY	25.99	0	7759
4283	15	AFRICAN ENDING	ANNE COOPER	20.99	0	3892
4284	1	AFRICAN ENEMY	WILLEM NICHOLSON	10.99	0	9682
4285	11	AFRICAN ENGLISH	AUDREY MOSTEL	17.99	0	3838
4286	12	AFRICAN ENOUGH	DUSTIN LANSBURY	16.99	0	5875
4287	5	AFRICAN ENTRAPMENT	CANDICE WRAY	23.99	0	1768
4288	8	AFRICAN ESCAPE	GREG OLIVIER	19.99	0	4748
4289	15	AFRICAN EVE	CHARLTON DEGENERES	27.99	0	2016
4290	14	AFRICAN EVERYONE	SANDRA WEAVER	28.99	0	7482
4291	5	AFRICAN EVOLUTION	GARY BRANAGH	20.99	0	4272
4292	3	AFRICAN EXCITEMENT	INGRID PRESLEY	14.99	0	2031
4293	7	AFRICAN EXORCIST	SOPHIA THURMAN	25.99	0	1324
4294	4	AFRICAN EXPECATIONS	HARRISON FAWCETT	17.99	0	6775
4295	10	AFRICAN EXPENDABLE	LIZA BALE	18.99	0	9959
4296	4	AFRICAN EXPRESS	BURT DIAZ	19.99	0	5532
4297	16	AFRICAN EXTRAORDINARY	GARY WASHINGTON	16.99	0	7432
4298	10	AFRICAN EYES	MADELINE MANSFIELD	18.99	0	345
4299	10	AFRICAN FACTORY	GRACE MARTIN	29.99	1	5270
4300	11	AFRICAN FALCON	KIRK LUGOSI	14.99	0	5223
4301	5	AFRICAN FAMILY	RALPH DEPP	16.99	0	5907
4302	15	AFRICAN FANTASIA	JULIANNE PECK	13.99	0	7004
4303	16	AFRICAN FANTASY	FRANK MCQUEEN	21.99	0	6627
4304	11	AFRICAN FARGO	EMILY OLIVIER	29.99	0	2617
4305	9	AFRICAN FATAL	RUSSELL FIENNES	10.99	0	8982
4306	10	AFRICAN FEATHERS	CHARLTON SWANK	17.99	0	9234
4307	16	AFRICAN FELLOWSHIP	MAE CHAPLIN	19.99	0	7094
4308	4	AFRICAN FERRIS	GREGORY GARLAND	19.99	0	4484
4309	3	AFRICAN FEUD	CHARLIZE MCDORMAND	17.99	0	8167
4310	11	AFRICAN FEVER	CARY BRIDGES	20.99	0	7202
4311	7	AFRICAN FICTION	LAURA RUSSELL	21.99	0	8038
4312	9	AFRICAN FIDDLER	WALTER CARREY	12.99	0	3471
4313	14	AFRICAN FIDELITY	MINNIE STALLONE	13.99	0	6909
4314	11	AFRICAN FIGHT	GENE JOHANSSON	25.99	0	9176
4315	10	AFRICAN FINDING	ALICIA MARX	24.99	0	2260
4316	8	AFRICAN FIRE	AL LOREN	9.99	0	1873
4317	14	AFRICAN FIREBALL	GOLDIE NOLTE	25.99	0	9768
4318	3	AFRICAN FIREHOUSE	RITA NORTON	27.99	0	1547
4319	9	AFRICAN FISH	MARLENE KINNEAR	27.99	0	5726
4320	13	AFRICAN FLAMINGOS	CLINT WILLIS	26.99	0	3272
4321	1	AFRICAN FLASH	SPENCER CRAWFORD	10.99	0	792
4322	5	AFRICAN FLATLINERS	ORLANDO BERGMAN	21.99	0	5925
4323	9	AFRICAN FLIGHT	FARRAH BAILEY	16.99	0	1729
4324	9	AFRICAN FLINTSTONES	MIRA HOPPER	12.99	0	616
4325	13	AFRICAN FLOATS	ALBERT BRIDGES	28.99	0	7326
4326	5	AFRICAN FLYING	STEVE WOOD	12.99	0	1357
4327	5	AFRICAN FOOL	DEBBIE EASTWOOD	9.99	0	870
4328	10	AFRICAN FOREVER	CANDICE HOPE	27.99	0	195
4329	1	AFRICAN FORREST	JODIE GARBO	25.99	0	8068
4330	14	AFRICAN FORRESTER	SYLVESTER DUNST	27.99	0	8628
4331	10	AFRICAN FORWARD	RUSSELL JOHANSSON	19.99	0	9006
4332	11	AFRICAN FRANKENSTEIN	DARYL WAHLBERG	26.99	0	860
4333	15	AFRICAN FREAKY	KARL KINNEAR	10.99	0	3543
4334	2	AFRICAN FREDDY	MINNIE JACKMAN	20.99	0	2495
4335	6	AFRICAN FREEDOM	KATHARINE BRANAGH	14.99	0	7779
4336	3	AFRICAN FRENCH	EWAN LAW	29.99	0	9455
4337	15	AFRICAN FRIDA	SANDRA PALTROW	11.99	0	8051
4338	3	AFRICAN FRISCO	GREGORY JACKMAN	24.99	0	7790
4339	2	AFRICAN FROGMEN	EMILY MCGREGOR	25.99	0	5373
4340	1	AFRICAN FRONTIER	MARILYN KILMER	21.99	0	6118
4341	6	AFRICAN FROST	CHRISTOPHER WILSON	22.99	0	2412
4342	10	AFRICAN FUGITIVE	VIVIEN TANDY	18.99	0	5084
4343	4	AFRICAN FULL	ADAM CAMPBELL	21.99	0	5534
4344	6	AFRICAN FURY	CLARK WALKEN	22.99	0	3578
4345	3	AFRICAN GABLES	SISSY PINKETT	26.99	0	7188
4346	7	AFRICAN GALAXY	MENA MOSTEL	21.99	0	6525
4347	14	AFRICAN GAMES	JUDY TANDY	25.99	0	4750
4348	5	AFRICAN GANDHI	LIV KUDROW	15.99	0	4798
4349	14	AFRICAN GANGS	HUMPHREY KEATON	9.99	0	1188
4350	7	AFRICAN GARDEN	SALLY FORD	15.99	0	1697
4351	1	AFRICAN GASLIGHT	ROBIN MANSFIELD	23.99	0	1254
4352	6	AFRICAN GATHERING	WINONA BEATTY	27.99	0	2933
4353	6	AFRICAN GENTLEMEN	ROSIE COOPER	29.99	0	9873
4354	8	AFRICAN GHOST	JUDE FOSTER	26.99	0	6637
4355	16	AFRICAN GHOSTBUSTERS	ADAM RUSSELL	26.99	0	1658
4356	1	AFRICAN GIANT	ORLANDO BOLGER	26.99	0	9714
4357	16	AFRICAN GILBERT	ALEC CLOSE	28.99	0	8866
4358	4	AFRICAN GILMORE	ANJELICA GOODING	10.99	0	5305
4359	2	AFRICAN GLADIATOR	SCARLETT RYAN	21.99	0	2592
4360	4	AFRICAN GLASS	ANGELINA MCDORMAND	14.99	0	1330
4361	7	AFRICAN GLEAMING	DUSTIN HOPKINS	12.99	0	429
4362	3	AFRICAN GLORY	DEBBIE DENIRO	12.99	0	2417
4363	1	AFRICAN GO	LIZA HESTON	11.99	0	9703
4364	11	AFRICAN GODFATHER	ORLANDO MANSFIELD	19.99	0	4110
4365	13	AFRICAN GOLD	ALICIA HAWKE	26.99	0	4855
4366	16	AFRICAN GOLDFINGER	TOM BERGEN	13.99	0	2267
4367	4	AFRICAN GOLDMINE	JOAN GOODING	18.99	0	6714
4368	11	AFRICAN GONE	CAMERON MCCONAUGHEY	15.99	0	6348
4369	5	AFRICAN GOODFELLAS	DREW GIBSON	9.99	0	4057
4370	8	AFRICAN GORGEOUS	RITA NEESON	19.99	0	4777
4371	16	AFRICAN GOSFORD	KATHARINE HOFFMAN	28.99	0	7845
4372	3	AFRICAN GRACELAND	CHRISTIAN TAUTOU	21.99	0	7271
4373	5	AFRICAN GRADUATE	GREGORY WRAY	17.99	0	762
4374	1	AFRICAN GRAFFITI	JENNIFER LEWIS	14.99	0	3408
4375	11	AFRICAN GRAIL	ADRIEN BEATTY	19.99	0	4943
4376	16	AFRICAN GRAPES	TOM JOVOVICH	19.99	0	5713
4377	5	AFRICAN GREASE	JANE KUDROW	18.99	0	7471
4378	3	AFRICAN GREATEST	NICK HEPBURN	20.99	0	324
4379	10	AFRICAN GREEDY	LEONARDO STREEP	10.99	0	2118
4380	7	AFRICAN GREEK	EMILY REYNOLDS	17.99	0	8102
4381	15	AFRICAN GRINCH	GEOFFREY DAFOE	26.99	0	7317
4382	7	AFRICAN GRIT	EWAN WRAY	26.99	0	4323
4383	10	AFRICAN GROOVE	SALMA MCKELLEN	15.99	0	6868
4384	6	AFRICAN GROSSE	KARL RICKMAN	29.99	0	6333
4385	3	AFRICAN GROUNDHOG	HUGH DAY	18.99	0	6386
4386	5	AFRICAN GUMP	ROSIE KEATON	21.99	0	5454
4387	5	AFRICAN GUN	KATE PRESLEY	21.99	0	9870
4388	1	AFRICAN GUNFIGHT	LIV CRUISE	27.99	0	7812
4389	10	AFRICAN GUNFIGHTER	KENNETH TEMPLE	11.99	0	3696
4390	12	AFRICAN GUYS	LAURENCE ANISTON	11.99	0	2079
4391	13	AFRICAN HALF	MORGAN PENN	21.99	0	756
4392	3	AFRICAN HALL	ROBIN MANSFIELD	23.99	0	4314
4393	11	AFRICAN HALLOWEEN	LIZA CRUISE	15.99	0	1414
4394	2	AFRICAN HAMLET	ALBERT MINELLI	22.99	0	8639
4395	16	AFRICAN HANDICAP	SHIRLEY HUNT	21.99	0	3450
4396	13	AFRICAN HANGING	ANNETTE GARLAND	19.99	0	3545
4397	10	AFRICAN HANKY	VIVIEN BRODY	17.99	0	1290
4398	14	AFRICAN HANOVER	GINA JACKMAN	18.99	0	3967
4399	10	AFRICAN HAPPINESS	ANDY TAUTOU	22.99	0	7769
4400	9	AFRICAN HARDLY	EDWARD IRONS	17.99	0	8483
4401	12	AFRICAN HAROLD	DENNIS SWANK	25.99	0	1867
4402	3	AFRICAN HARPER	GENE WILLIS	11.99	0	1261
4403	4	AFRICAN HARRY	LIV DEGENERES	20.99	0	4059
4404	16	AFRICAN HATE	ETHAN FONDA	29.99	0	7629
4405	13	AFRICAN HAUNTED	EDWARD HUNT	9.99	0	3175
4406	14	AFRICAN HAUNTING	CLARK LOREN	10.99	0	5498
4407	5	AFRICAN HAWK	JUDY KEITEL	20.99	0	9001
4408	12	AFRICAN HEAD	CATE STALLONE	15.99	0	8550
4409	12	AFRICAN HEARTBREAKERS	CUBA FORD	29.99	0	1576
4410	13	AFRICAN HEAVEN	LUCILLE BERRY	9.99	0	4852
4411	6	AFRICAN HEAVENLY	ANTHONY WAYNE	19.99	0	4453
4412	1	AFRICAN HEAVYWEIGHTS	WHOOPI DICAPRIO	20.99	0	5861
4413	8	AFRICAN HEDWIG	JAMES KIDMAN	21.99	0	8225
4414	8	AFRICAN HELLFIGHTERS	CHEVY LANSBURY	22.99	0	4790
4415	13	AFRICAN HIGH	KIM EASTWOOD	17.99	0	6428
4416	15	AFRICAN HIGHBALL	LAUREN MCDORMAND	29.99	0	5957
4417	7	AFRICAN HILLS	SALMA CHASE	17.99	0	6999
4418	16	AFRICAN HOBBIT	DREW CRAWFORD	17.99	0	722
4419	4	AFRICAN HOCUS	MADELINE DEAN	17.99	0	1805
4420	14	AFRICAN HOLES	JOE MOSTEL	18.99	0	7832
4421	2	AFRICAN HOLIDAY	HUME AFFLECK	22.99	0	5185
4422	5	AFRICAN HOLLOW	MEG HAWKE	11.99	0	3954
4423	14	AFRICAN HOLLYWOOD	LANA RUSSELL	9.99	0	3452
4424	2	AFRICAN HOLOCAUST	LANA HEPBURN	24.99	0	4392
4425	15	AFRICAN HOLY	BRUCE OLIVIER	17.99	0	1965
4426	4	AFRICAN HOME	DARYL CRUZ	21.99	0	1878
4427	2	AFRICAN HOMEWARD	LEONARDO BOLGER	25.99	0	4096
4428	4	AFRICAN HOMICIDE	DANIEL BAILEY	24.99	0	3974
4429	2	AFRICAN HONEY	ROBERT CRUZ	23.99	0	6547
4430	2	AFRICAN HOOK	GRETA TAYLOR	13.99	0	4768
4431	7	AFRICAN HOOSIERS	MATTHEW HURT	21.99	0	5260
4432	13	AFRICAN HOPE	LUCILLE CRUISE	17.99	0	8485
4433	14	AFRICAN HORN	SHIRLEY COSTNER	9.99	0	9611
4434	7	AFRICAN HORROR	CHEVY BALE	14.99	0	1020
4435	15	AFRICAN HOTEL	WILLEM SORVINO	14.99	0	2607
4436	12	AFRICAN HOURS	NICK HUDSON	17.99	0	8142
4437	15	AFRICAN HOUSE	ADAM TOMEI	20.99	0	9890
4438	7	AFRICAN HUMAN	CHRIS BRIDGES	14.99	0	943
4439	4	AFRICAN HUNCHBACK	CARY KINNEAR	17.99	0	8468
4440	9	AFRICAN HUNGER	MEG NOLTE	19.99	0	7295
4441	12	AFRICAN HUNTER	DANIEL MONROE	19.99	0	2845
4442	5	AFRICAN HUNTING	CLARK WINSLET	15.99	0	4764
4443	5	AFRICAN HURRICANE	LEELEE WASHINGTON	18.99	0	7239
4444	9	AFRICAN HUSTLER	EMILY HORNE	23.99	0	530
4445	9	AFRICAN HYDE	NICK GIBSON	13.99	0	6653
4446	15	AFRICAN HYSTERICAL	GINA MALDEN	11.99	0	3735
4447	7	AFRICAN ICE	GRETA GARLAND	21.99	0	8823
4448	2	AFRICAN IDAHO	RITA WILLIAMS	22.99	0	347
4449	7	AFRICAN IDENTITY	JON WEST	22.99	0	3661
4450	12	AFRICAN IDOLS	NICK CHAPLIN	18.99	0	5911
4451	2	AFRICAN IGBY	CUBA DREYFUSS	17.99	0	2607
4452	13	AFRICAN ILLUSION	MADELINE SMITH	12.99	0	2995
4453	1	AFRICAN IMAGE	ELLEN HURT	26.99	0	6650
4454	15	AFRICAN IMPACT	LIV KEATON	16.99	0	2459
4455	12	AFRICAN IMPOSSIBLE	HUGH TAYLOR	19.99	0	7502
4456	2	AFRICAN INCH	ALICIA HAWKE	14.99	0	4445
4457	9	AFRICAN INDEPENDENCE	EMILY MCKELLEN	12.99	0	6820
4458	8	AFRICAN INDIAN	CHRIS SILVERSTONE	23.99	0	2989
4459	6	AFRICAN INFORMER	RITA KILMER	29.99	0	9884
4460	4	AFRICAN INNOCENT	SALMA MOSTEL	22.99	0	1708
4461	7	AFRICAN INSECTS	LAUREN DAY-LEWIS	17.99	0	4202
4462	14	AFRICAN INSIDER	ANJELICA AFFLECK	11.99	0	8336
4463	13	AFRICAN INSTINCT	MARILYN MARTIN	29.99	0	3001
4464	5	AFRICAN INTENTIONS	ROCK NOLTE	10.99	0	7530
4465	2	AFRICAN INTERVIEW	IAN TURNER	28.99	0	5602
4466	2	AFRICAN INTOLERABLE	PENELOPE WALKEN	23.99	0	2609
4467	2	AFRICAN INTRIGUE	ELVIS DAFOE	12.99	0	4152
4468	1	AFRICAN INVASION	ALAN CAMPBELL	22.99	0	3296
4469	16	AFRICAN IRON	AL GRANT	25.99	0	6867
4470	9	AFRICAN ISHTAR	LENA LANSBURY	28.99	0	1379
4471	9	AFRICAN ISLAND	ANNETTE MARTIN	15.99	0	4051
4472	9	AFRICAN ITALIAN	LIAM HAWKE	26.99	0	9397
4473	4	AFRICAN JACKET	BEN LOLLOBRIGIDA	14.99	0	1988
4474	10	AFRICAN JADE	LAURENCE COOPER	21.99	0	632
4475	5	AFRICAN JAPANESE	LIV HUSTON	27.99	0	1140
4476	1	AFRICAN JASON	MIRA WAYNE	10.99	0	176
4477	8	AFRICAN JAWBREAKER	JAMES RUSH	10.99	0	95
4478	1	AFRICAN JAWS	LAURENCE SMITH	11.99	0	8138
4479	5	AFRICAN JEDI	WILLIAM MINELLI	27.99	0	9324
4480	16	AFRICAN JEEPERS	INGRID JOVOVICH	21.99	0	8493
4481	12	AFRICAN JEKYLL	RAY GRANT	17.99	0	225
4482	7	AFRICAN JEOPARDY	RENEE WATSON	26.99	0	3982
4483	14	AFRICAN JERICHO	DIANE BARRYMORE	18.99	0	2885
4484	5	AFRICAN JERK	TIM HORNE	14.99	0	1657
4485	3	AFRICAN JERSEY	MATTHEW FIELD	21.99	0	542
4486	8	AFRICAN JET	JAYNE LEWIS	14.99	0	9045
4487	5	AFRICAN JINGLE	ROSIE HARRIS	10.99	0	8672
4488	8	AFRICAN JOON	SUSAN BRODY	23.99	0	725
4489	16	AFRICAN JUGGLER	KATE STREEP	28.99	0	8908
4490	2	AFRICAN JUMANJI	DARYL DOUGLAS	24.99	0	870
4491	13	AFRICAN JUMPING	MARY FISHER	14.99	0	6415
4492	3	AFRICAN JUNGLE	ANGELINA SOBIESKI	29.99	0	3076
4493	14	AFRICAN KANE	JAMES GARBO	25.99	0	108
4494	14	AFRICAN KARATE	SALLY ALLEN	17.99	0	9527
4495	5	AFRICAN KENTUCKIAN	DREW WOOD	18.99	0	1084
4496	9	AFRICAN KICK	JAMES KIDMAN	13.99	0	9986
4497	14	AFRICAN KILL	ROBERT WAHLBERG	28.99	0	7173
4498	4	AFRICAN KILLER	AUDREY RICKMAN	22.99	0	1134
4499	11	AFRICAN KING	CARRIE GRANT	19.99	0	439
4500	8	AFRICAN KISS	ALICIA BALL	23.99	0	7662
4501	13	AFRICAN KISSING	FRANK BERRY	14.99	0	747
4502	4	AFRICAN KNOCK	ZERO CHASE	10.99	0	9097
4503	13	AFRICAN KRAMER	MEG DRIVER	26.99	0	2226
4504	16	AFRICAN KWAI	LISA MANSFIELD	11.99	0	3814
4505	3	AFRICAN LABYRINTH	JACK LOREN	12.99	0	9385
4506	16	AFRICAN LADY	AL BLOOM	14.99	0	3111
4507	6	AFRICAN LADYBUGS	JOAN LOLLOBRIGIDA	15.99	0	5392
4508	4	AFRICAN LAMBS	ROBERT HECHE	27.99	0	7608
4509	2	AFRICAN LANGUAGE	GROUCHO DEPP	24.99	0	4692
4510	2	AFRICAN LAWLESS	ANJELICA JACKMAN	20.99	0	3343
4511	8	AFRICAN LAWRENCE	JADA MARTIN	19.99	0	7610
4512	13	AFRICAN LEAGUE	GRACE CHAPLIN	14.99	0	9799
4513	13	AFRICAN LEATHERNECKS	HUMPHREY NOLTE	22.99	0	6897
4514	7	AFRICAN LEBOWSKI	UMA PACINO	24.99	0	2936
4515	4	AFRICAN LEGALLY	PENELOPE KUDROW	14.99	0	4472
4516	10	AFRICAN LEGEND	ANGELINA LAW	9.99	0	8894
4517	13	AFRICAN LESSON	ANGELA SUVARI	11.99	0	5052
4518	2	AFRICAN LIAISONS	CUBA WATSON	19.99	0	7687
4519	4	AFRICAN LIBERTY	JOAN WILSON	12.99	0	9072
4520	8	AFRICAN LICENSE	JEREMY WAYNE	13.99	0	5445
4521	11	AFRICAN LIES	BURT SOBIESKI	24.99	0	1608
4522	10	AFRICAN LIFE	ALAN MONROE	22.99	0	1410
4523	3	AFRICAN LIGHTS	BELA TORN	16.99	0	6497
4524	2	AFRICAN LION	LIV MCGREGOR	21.99	0	3406
4525	8	AFRICAN LOATHING	FARRAH DAY-LEWIS	29.99	0	5029
4526	8	AFRICAN LOCK	GLENN BULLOCK	21.99	0	1887
4527	13	AFRICAN LOLA	ROSIE HUDSON	25.99	0	6307
4528	15	AFRICAN LOLITA	JULIETTE DRIVER	9.99	0	9472
4529	11	AFRICAN LONELY	LANA POSEY	14.99	0	3494
4530	10	AFRICAN LORD	LANA SPACEK	27.99	0	219
4531	7	AFRICAN LOSE	CHARLIZE DUKAKIS	24.99	0	8
4532	15	AFRICAN LOSER	JIM MOSTEL	24.99	0	5913
4533	7	AFRICAN LOST	SEAN GARLAND	28.99	0	5123
4534	14	AFRICAN LOUISIANA	EMILY ANISTON	18.99	0	6084
4535	13	AFRICAN LOVE	JEFF TOMEI	16.99	0	2411
4536	7	AFRICAN LOVELY	KARL CRONYN	20.99	0	4297
4537	9	AFRICAN LOVER	BOB SMITH	29.99	0	5388
4538	10	AFRICAN LOVERBOY	SPENCER WILSON	18.99	0	2748
4539	16	AFRICAN LUCK	FRANCES POSEY	14.99	0	5783
4540	14	AFRICAN LUCKY	JOAN WINSLET	15.99	0	2609
4541	9	AFRICAN LUKE	JEFF PECK	10.99	0	3549
4542	9	AFRICAN LUST	CLARK ROBBINS	21.99	0	7587
4543	3	AFRICAN MADIGAN	NATALIE GARBO	9.99	0	6132
4544	6	AFRICAN MADISON	GWYNETH RYDER	21.99	0	5527
4545	3	AFRICAN MADNESS	JULIETTE TOMEI	22.99	0	8613
4546	15	AFRICAN MADRE	LANA PHOENIX	16.99	0	8160
4547	12	AFRICAN MAGIC	LAURENCE FAWCETT	27.99	0	3543
4548	11	AFRICAN MAGNIFICENT	MILLA BAILEY	17.99	0	5302
4549	16	AFRICAN MAGNOLIA	GLENN GUINESS	16.99	1	3684
4550	15	AFRICAN MAGUIRE	ELLEN CROWE	18.99	0	4504
4551	5	AFRICAN MAIDEN	CLINT RICKMAN	27.99	0	9837
4552	12	AFRICAN MAJESTIC	FAY SUVARI	14.99	0	1893
4553	11	AFRICAN MAKER	DIANE HARRIS	16.99	0	2997
4554	14	AFRICAN MALKOVICH	MERYL RUSSELL	13.99	0	6905
4555	10	AFRICAN MALLRATS	SEAN BENING	26.99	0	7212
4556	5	AFRICAN MALTESE	JOHN SARANDON	18.99	0	6166
4557	8	AFRICAN MANCHURIAN	JIM GOLDBERG	24.99	0	2161
4558	15	AFRICAN MANNEQUIN	LIZA DUKAKIS	12.99	0	4115
4559	8	AFRICAN MARRIED	DANIEL KAHN	11.99	0	3465
4560	14	AFRICAN MARS	HUMPHREY DREYFUSS	23.99	0	9125
4561	7	AFRICAN MASK	MIRA HACKMAN	28.99	0	4044
4562	9	AFRICAN MASKED	PENELOPE EASTWOOD	29.99	0	4411
4563	4	AFRICAN MASSACRE	NEVE WILLIS	26.99	0	3715
4564	4	AFRICAN MASSAGE	SHIRLEY LANSBURY	18.99	0	5974
4565	13	AFRICAN MATRIX	SHIRLEY KEITEL	13.99	0	9977
4566	2	AFRICAN MAUDE	HILARY MONROE	26.99	0	2523
4567	4	AFRICAN MEET	KIM BLOOM	9.99	0	5935
4568	8	AFRICAN MEMENTO	KEVIN EASTWOOD	13.99	0	6632
4569	10	AFRICAN MENAGERIE	DENZEL GOLDBERG	18.99	0	9126
4570	1	AFRICAN MERMAID	JAMES MATTHAU	28.99	0	6617
4571	15	AFRICAN METAL	GENE WAHLBERG	15.99	0	8792
4572	10	AFRICAN METROPOLIS	WILL WOOD	11.99	0	614
4573	12	AFRICAN MICROCOSMOS	GWYNETH HORNE	14.99	0	4962
4574	15	AFRICAN MIDNIGHT	SEAN DAY	12.99	0	6978
4575	2	AFRICAN MIDSUMMER	GARY PALTROW	19.99	0	1200
4576	3	AFRICAN MIGHTY	ANGELA LANSBURY	19.99	0	7921
4577	6	AFRICAN MILE	PEARL HOPE	15.99	0	7810
4578	7	AFRICAN MILLION	ED DUKAKIS	24.99	0	8961
4579	5	AFRICAN MINDS	CAMERON JOVOVICH	11.99	0	7783
4580	14	AFRICAN MINE	JOHN PHOENIX	11.99	0	1229
4581	5	AFRICAN MINORITY	MEL HANNAH	15.99	0	5610
4582	2	AFRICAN MIRACLE	ADRIEN DEGENERES	27.99	0	5847
4583	11	AFRICAN MISSION	SEAN WILLIS	27.99	0	4486
4584	13	AFRICAN MIXED	WALTER WILSON	27.99	0	6179
4585	11	AFRICAN MOB	GREGORY VOIGHT	12.99	0	5846
4586	5	AFRICAN MOCKINGBIRD	WILLIAM EASTWOOD	29.99	0	8648
4587	9	AFRICAN MOD	BRUCE NOLTE	20.99	0	6732
4588	2	AFRICAN MODEL	MAE CRUISE	9.99	0	3523
4589	8	AFRICAN MODERN	GEOFFREY TANDY	17.99	0	4134
4590	1	AFRICAN MONEY	GOLDIE HESTON	16.99	0	3814
4591	16	AFRICAN MONSOON	MENA THURMAN	28.99	0	2841
4592	13	AFRICAN MONSTER	WHOOPI GOODING	28.99	0	5179
4593	10	AFRICAN MONTEREY	MINNIE BALL	13.99	0	7934
4594	10	AFRICAN MONTEZUMA	MARLON JOHANSSON	27.99	0	4202
4595	5	AFRICAN MOON	SALLY WALKEN	22.99	0	4571
4596	1	AFRICAN MOONSHINE	GREG DIAZ	23.99	0	1954
4597	16	AFRICAN MOONWALKER	LAURA ALLEN	29.99	0	4985
4598	8	AFRICAN MOSQUITO	KATHARINE JOVOVICH	12.99	0	5897
4599	16	AFRICAN MOTHER	BETTE DUNST	22.99	0	9925
4600	1	AFRICAN MOTIONS	SYLVESTER JOHANSSON	28.99	0	2237
4601	6	AFRICAN MOULIN	JOE CARREY	23.99	0	6879
4602	15	AFRICAN MOURNING	MICHAEL SPACEK	19.99	0	6217
4603	16	AFRICAN MOVIE	CARRIE DICAPRIO	20.99	0	8549
4604	2	AFRICAN MULAN	CHARLTON HEPBURN	13.99	0	3437
4605	4	AFRICAN MULHOLLAND	ROCK BULLOCK	11.99	0	9706
4606	6	AFRICAN MUMMY	CANDICE HAWKE	26.99	0	9705
4607	9	AFRICAN MUPPET	RICHARD BAILEY	13.99	0	6027
4608	14	AFRICAN MURDER	SCARLETT JOVOVICH	29.99	0	3231
4609	14	AFRICAN MUSCLE	OLYMPIA CHAPLIN	29.99	0	8235
4610	6	AFRICAN MUSIC	VAL LANCASTER	12.99	0	9895
4611	3	AFRICAN MUSKETEERS	HUME ANISTON	14.99	0	5269
4612	4	AFRICAN MUSSOLINI	KIRK GARBO	9.99	0	828
4613	11	AFRICAN MYSTIC	LAURENCE HARRIS	19.99	0	6229
4614	14	AFRICAN NAME	PAUL CROWE	21.99	0	1306
4615	7	AFRICAN NASH	MEL HURT	16.99	0	3576
4616	6	AFRICAN NATIONAL	HARRISON PRESLEY	24.99	0	2151
4617	5	AFRICAN NATURAL	LANA DAY	26.99	0	1424
4618	15	AFRICAN NECKLACE	KENNETH TANDY	19.99	0	9182
4619	2	AFRICAN NEIGHBORS	BURT CRONYN	27.99	0	2672
4620	1	AFRICAN NEMO	NICOLAS CHAPLIN	23.99	0	3741
4621	2	AFRICAN NETWORK	CARY SPACEK	18.99	0	1309
4622	11	AFRICAN NEWSIES	GREGORY SPACEK	13.99	0	5851
4623	6	AFRICAN NEWTON	JENNIFER LEWIS	28.99	0	8113
4624	14	AFRICAN NIGHTMARE	WOODY CROWE	28.99	0	7465
4625	4	AFRICAN NONE	SISSY BRANAGH	29.99	0	3976
4626	6	AFRICAN NOON	DREW THURMAN	18.99	0	8052
4627	10	AFRICAN NORTH	MARILYN WITHERSPOON	28.99	0	3050
4628	9	AFRICAN NORTHWEST	SEAN LOLLOBRIGIDA	29.99	0	9455
4629	13	AFRICAN NOTORIOUS	CARY FONDA	25.99	0	2190
4630	9	AFRICAN NOTTING	GLENN HUSTON	17.99	0	1468
4631	14	AFRICAN NOVOCAINE	ALICIA REYNOLDS	10.99	0	3591
4632	14	AFRICAN NUTS	GREG SARANDON	19.99	0	5495
4633	13	AFRICAN OCTOBER	CARRIE DIAZ	23.99	0	6238
4634	10	AFRICAN ODDS	WALTER ALLEN	24.99	0	2303
4635	16	AFRICAN OKLAHOMA	MINNIE EASTWOOD	15.99	0	1520
4636	8	AFRICAN OLEANDER	SUSAN KILMER	19.99	0	1379
4637	14	AFRICAN OPEN	VAL HESTON	12.99	0	6916
4638	12	AFRICAN OPERATION	VIVIEN PHOENIX	27.99	0	1878
4639	8	AFRICAN OPPOSITE	DARYL BAILEY	18.99	0	9870
4640	11	AFRICAN OPUS	FRANCES REYNOLDS	17.99	0	140
4641	9	AFRICAN ORANGE	KEVIN KEATON	18.99	1	1362
4642	10	AFRICAN ORDER	LANA STALLONE	20.99	0	5066
4643	4	AFRICAN ORIENT	DUSTIN PRESLEY	12.99	0	6476
4644	6	AFRICAN OSCAR	MEG BOGART	21.99	0	4646
4645	9	AFRICAN OTHERS	DORIS DAMON	26.99	0	2924
4646	14	AFRICAN OUTBREAK	RICHARD BULLOCK	17.99	0	8071
4647	9	AFRICAN OUTFIELD	MARISA COSTNER	11.99	0	6715
4648	11	AFRICAN OUTLAW	JADA WATSON	27.99	0	430
4649	9	AFRICAN OZ	CHARLES JACKMAN	13.99	0	6811
4650	11	AFRICAN PACIFIC	SIDNEY MCGREGOR	27.99	0	4822
4651	3	AFRICAN PACKER	LISA FREEMAN	29.99	0	1923
4652	13	AFRICAN PAJAMA	GWYNETH FIELD	18.99	0	731
4653	2	AFRICAN PANIC	AL BERRY	20.99	0	1343
4654	10	AFRICAN PANKY	LUCILLE HUDSON	24.99	0	6966
4655	7	AFRICAN PANTHER	GINA FISHER	15.99	0	8039
4656	13	AFRICAN PAPI	CHARLIZE HACKMAN	17.99	0	9110
4657	10	AFRICAN PARADISE	DORIS CROWE	28.99	0	6678
4658	1	AFRICAN PARIS	NICOLAS POITIER	9.99	0	6913
4659	3	AFRICAN PARK	CHEVY TEMPLE	25.99	0	8254
4660	8	AFRICAN PARTY	CHARLTON ALLEN	26.99	0	3716
4661	10	AFRICAN PAST	PAUL BOGART	25.99	0	1599
4662	11	AFRICAN PATHS	GREGORY BERGMAN	28.99	0	9762
4663	10	AFRICAN PATIENT	MORGAN BALL	15.99	0	129
4664	1	AFRICAN PATRIOT	SIDNEY DENCH	12.99	0	4943
4665	16	AFRICAN PATTON	JUDI KIDMAN	12.99	0	8233
4666	9	AFRICAN PAYCHECK	SUSAN WILSON	15.99	0	4066
4667	8	AFRICAN PEACH	JODIE HAWN	25.99	0	5002
4668	13	AFRICAN PEAK	KATHARINE TRACY	19.99	0	6181
4669	9	AFRICAN PEARL	SALMA DEAN	17.99	0	8993
4670	15	AFRICAN PELICAN	JAMES GRANT	17.99	0	7790
4671	4	AFRICAN PERDITION	NICOLE BEATTY	11.99	0	4872
4672	9	AFRICAN PERFECT	SPENCER RYDER	9.99	0	2334
4673	9	AFRICAN PERSONAL	CARY GARCIA	10.99	0	3528
4674	12	AFRICAN PET	LAUREN GARCIA	20.99	0	9759
4675	8	AFRICAN PHANTOM	HALLE MIRANDA	27.99	0	9020
4676	11	AFRICAN PHILADELPHIA	WALTER DIETRICH	17.99	0	3033
4677	15	AFRICAN PIANIST	BRAD WILLIS	25.99	0	6888
4678	1	AFRICAN PICKUP	ANJELICA KEATON	12.99	0	9065
4679	9	AFRICAN PILOT	EMILY DOUGLAS	11.99	0	288
4680	2	AFRICAN PINOCCHIO	MEG DIETRICH	18.99	0	7282
4681	6	AFRICAN PIRATES	ADAM SARANDON	15.99	0	4149
4682	10	AFRICAN PITTSBURGH	HARVEY BRANAGH	23.99	0	3671
4683	7	AFRICAN PITY	SHIRLEY WATSON	18.99	0	4719
4684	6	AFRICAN PIZZA	NICOLE MCGREGOR	21.99	0	5717
4685	11	AFRICAN PLATOON	ROSIE SANDLER	15.99	0	9947
4686	1	AFRICAN PLUTO	RENEE LUGOSI	10.99	0	169
4687	8	AFRICAN POCUS	CARMEN JACKMAN	26.99	0	300
4688	4	AFRICAN POLISH	WHOOPI LUGOSI	11.99	0	766
4689	10	AFRICAN POLLOCK	MICHELLE GOLDBERG	15.99	1	4312
4690	15	AFRICAN POND	DREW MIRANDA	24.99	0	4803
4691	12	AFRICAN POSEIDON	ANTHONY ASTAIRE	20.99	0	9590
4692	9	AFRICAN POTLUCK	JENNIFER KUDROW	23.99	0	6508
4693	12	AFRICAN POTTER	DUSTIN MARX	23.99	0	2712
4694	12	AFRICAN PREJUDICE	MARLENE DOUGLAS	18.99	0	6492
4695	15	AFRICAN PRESIDENT	FRANCES HUSTON	11.99	0	2650
4696	10	AFRICAN PRIDE	FAY WAYNE	22.99	0	3686
4697	10	AFRICAN PRIMARY	SUSAN ASTAIRE	10.99	0	3122
4698	12	AFRICAN PRINCESS	SYLVESTER GUINESS	29.99	0	6281
4699	4	AFRICAN PRIVATE	SPENCER SILVERSTONE	27.99	0	4995
4700	9	AFRICAN PRIX	WILLIAM CAMPBELL	26.99	0	1992
4701	2	AFRICAN PSYCHO	CHARLES SWANK	17.99	0	6173
4702	13	AFRICAN PULP	MAE CARREY	23.99	0	3313
4703	16	AFRICAN PUNK	MORGAN WILLIAMS	28.99	0	7882
4704	9	AFRICAN PURE	LENA CLOSE	18.99	0	8598
4705	16	AFRICAN PURPLE	ADAM MANSFIELD	28.99	0	2622
4706	2	AFRICAN QUEEN	CANDICE KIDMAN	14.99	0	6416
4707	15	AFRICAN QUEST	RALPH NICHOLSON	19.99	0	154
4708	14	AFRICAN QUILLS	WILL FORD	21.99	0	8951
4709	6	AFRICAN RACER	ANNE RUSH	29.99	0	1155
4710	14	AFRICAN RAGE	MINNIE CLOSE	26.99	0	1424
4711	2	AFRICAN RAGING	MATTHEW DAMON	13.99	0	5922
4712	14	AFRICAN RAIDERS	EMILY GARBO	22.99	0	6211
4713	11	AFRICAN RAINBOW	WALTER PHOENIX	22.99	0	2060
4714	9	AFRICAN RANDOM	WINONA NEWMAN	21.99	0	2111
4715	12	AFRICAN RANGE	HARRISON HORNE	17.99	0	4607
4716	9	AFRICAN REAP	MATT GOLDBERG	13.99	0	1436
4717	14	AFRICAN REAR	JUDE HEPBURN	10.99	0	3785
4718	12	AFRICAN REBEL	BURT PESCI	22.99	0	4174
4719	14	AFRICAN RECORDS	BOB TAUTOU	26.99	0	7280
4720	2	AFRICAN REDEMPTION	CUBA CAINE	18.99	0	4760
4721	15	AFRICAN REDS	RUSSELL BLOOM	21.99	0	4343
4722	12	AFRICAN REEF	SANDRA BULLOCK	13.99	0	9353
4723	10	AFRICAN REIGN	MARLON TYLER	23.99	0	52
4724	2	AFRICAN REMEMBER	SCARLETT HOFFMAN	13.99	0	3162
4725	16	AFRICAN REQUIEM	JEREMY GARLAND	11.99	0	10000
4726	10	AFRICAN RESERVOIR	BOB PECK	18.99	0	4065
4727	15	AFRICAN RESURRECTION	KARL AFFLECK	24.99	0	7419
4728	12	AFRICAN REUNION	MARLENE SILVERSTONE	16.99	0	2289
4729	6	AFRICAN RIDER	MATTHEW MCQUEEN	13.99	0	9734
4730	9	AFRICAN RIDGEMONT	GREG RYAN	29.99	0	1531
4731	16	AFRICAN RIGHT	SANDRA KEITEL	10.99	0	1535
4732	8	AFRICAN RINGS	CHEVY TAYLOR	9.99	0	3743
4733	13	AFRICAN RIVER	CUBA FIENNES	17.99	0	7046
4734	11	AFRICAN ROAD	GREG ASTAIRE	15.99	0	1933
4735	5	AFRICAN ROBBERS	WILLIAM RYAN	22.99	0	9023
4736	13	AFRICAN ROBBERY	JADA RUSSELL	22.99	0	4056
4737	14	AFRICAN ROCK	EWAN GIBSON	29.99	0	9022
4738	6	AFRICAN ROCKETEER	DENZEL COSTNER	20.99	0	8875
4739	4	AFRICAN ROCKY	SPENCER DEPP	21.99	0	1583
4740	13	AFRICAN ROLLERCOASTER	VAL TEMPLE	24.99	0	7368
4741	11	AFRICAN ROMAN	JULIANNE FIENNES	10.99	0	3972
4742	8	AFRICAN ROOF	PARKER RYAN	25.99	0	1701
4743	11	AFRICAN ROOM	GREG BRANDO	27.99	0	9407
4744	13	AFRICAN ROOTS	DAN THERON	23.99	0	7717
4745	14	AFRICAN ROSES	MARLENE DEGENERES	25.99	1	1717
4746	9	AFRICAN ROUGE	JOHN MONROE	10.99	0	4666
4747	8	AFRICAN ROXANNE	ELVIS DEAN	13.99	1	265
4748	7	AFRICAN RUGRATS	CATE MOSTEL	24.99	0	7824
4749	11	AFRICAN RULES	MARY FISHER	27.99	0	1273
4750	11	AFRICAN RUN	GWYNETH TANDY	15.99	0	3579
4751	8	AFRICAN RUNAWAY	AL CRONYN	28.99	0	7501
4752	7	AFRICAN RUNNER	WILLEM NOLTE	23.99	0	9760
4753	12	AFRICAN RUSH	MARILYN DRIVER	26.99	0	1946
4754	10	AFRICAN RUSHMORE	JULIANNE ODONNELL	14.99	0	5402
4755	7	AFRICAN SABRINA	HUME CRUISE	25.99	0	535
4756	3	AFRICAN SADDLE	DUSTIN WATSON	12.99	0	4719
4757	15	AFRICAN SAGEBRUSH	CHEVY DUKAKIS	27.99	0	582
4758	14	AFRICAN SAINTS	GREGORY NEESON	19.99	0	3686
4759	11	AFRICAN SALUTE	ANNETTE BRODY	13.99	0	6161
4760	13	AFRICAN SAMURAI	RICHARD SMITH	12.99	0	2851
4761	4	AFRICAN SANTA	DIANE PFEIFFER	18.99	0	1020
4762	15	AFRICAN SASSY	HUGH RICKMAN	10.99	0	3627
4763	3	AFRICAN SATISFACTION	ALEC JACKMAN	18.99	0	5334
4764	14	AFRICAN SATURDAY	MARLON NEWMAN	27.99	0	659
4765	9	AFRICAN SATURN	SIDNEY MCKELLEN	15.99	0	4816
4766	10	AFRICAN SAVANNAH	DENNIS WITHERSPOON	26.99	0	845
4767	15	AFRICAN SCALAWAG	RUSSELL FORD	15.99	0	4959
4768	12	AFRICAN SCARFACE	WINONA KIDMAN	24.99	0	9735
4769	5	AFRICAN SCHOOL	MARILYN SUVARI	28.99	0	5238
4770	16	AFRICAN SCISSORHANDS	CHARLTON DIETRICH	27.99	0	9346
4771	6	AFRICAN SCORPION	SUSAN DAVIS	20.99	0	3441
4772	11	AFRICAN SEA	MEL WITHERSPOON	19.99	0	876
4773	16	AFRICAN SEABISCUIT	LIZA AFFLECK	29.99	0	6277
4774	16	AFRICAN SEARCHERS	JODIE WITHERSPOON	21.99	0	2330
4775	2	AFRICAN SEATTLE	JUDI TAYLOR	14.99	0	1084
4776	4	AFRICAN SECRET	GINA BIRCH	11.99	0	3678
4777	8	AFRICAN SECRETARY	GREGORY DREYFUSS	12.99	0	6591
4778	4	AFRICAN SECRETS	MARY RICKMAN	27.99	0	3885
4779	8	AFRICAN SENSE	HALLE OLIVIER	29.99	0	2638
4780	4	AFRICAN SENSIBILITY	CATE HAWKE	23.99	0	8740
4781	14	AFRICAN SEVEN	WALTER TORN	11.99	0	5979
4782	9	AFRICAN SHAKESPEARE	SEAN JACKMAN	26.99	0	6554
4783	9	AFRICAN SHANE	JACK THURMAN	12.99	0	1663
4784	10	AFRICAN SHANGHAI	SALMA DEGENERES	28.99	0	1575
4785	4	AFRICAN SHAWSHANK	LANA HANNAH	15.99	0	2585
4786	4	AFRICAN SHEPHERD	CHARLTON WALKEN	12.99	0	1774
4787	13	AFRICAN SHINING	MATTHEW LEIGH	22.99	0	3194
4788	5	AFRICAN SHIP	DEBBIE WASHINGTON	24.99	0	9555
4789	15	AFRICAN SHOCK	DAN NEWMAN	24.99	0	3957
4790	15	AFRICAN SHOOTIST	REESE SANDLER	19.99	0	9091
4791	12	AFRICAN SHOW	ROBIN FOSTER	27.99	0	8973
4792	2	AFRICAN SHREK	JESSICA DICAPRIO	24.99	0	8854
4793	1	AFRICAN SHRUNK	RITA DAMON	14.99	0	9259
4794	4	AFRICAN SIDE	LENA SILVERSTONE	17.99	0	2014
4795	13	AFRICAN SIEGE	ADAM HUDSON	21.99	0	1368
4796	9	AFRICAN SIERRA	JODIE NOLTE	16.99	0	9846
4797	4	AFRICAN SILENCE	ELIZABETH MCQUEEN	23.99	0	1643
4798	10	AFRICAN SILVERADO	HARRISON HESTON	17.99	0	3001
4799	6	AFRICAN SIMON	CAMERON WAHLBERG	28.99	0	6734
4800	3	AFRICAN SINNERS	CHARLES CAMPBELL	12.99	0	853
4801	5	AFRICAN SISTER	PARKER DICAPRIO	24.99	0	3357
4802	12	AFRICAN SKY	WILL TAUTOU	29.99	0	3498
4803	3	AFRICAN SLACKER	PENELOPE CRONYN	20.99	0	4858
4804	14	AFRICAN SLEEPING	HUMPHREY WAYNE	28.99	0	7431
4805	10	AFRICAN SLEEPLESS	SIDNEY ASTAIRE	24.99	0	6392
4806	14	AFRICAN SLEEPY	SPENCER HOPE	21.99	0	5282
4807	16	AFRICAN SLEUTH	HUGH WEAVER	28.99	0	9799
4808	5	AFRICAN SLING	CHRIS BRANAGH	10.99	0	7598
4809	9	AFRICAN SLIPPER	MICHELLE HUNT	28.99	0	5826
4810	12	AFRICAN SLUMS	LIAM BALE	21.99	0	7717
4811	4	AFRICAN SMILE	DENZEL MINELLI	11.99	0	4240
4812	11	AFRICAN SMOKING	HARRISON CRUZ	10.99	0	3179
4813	1	AFRICAN SMOOCHY	JACK GRANT	13.99	0	634
4814	16	AFRICAN SNATCH	KATE WITHERSPOON	22.99	0	9552
4815	4	AFRICAN SNATCHERS	WOODY MCCONAUGHEY	26.99	0	7909
4816	10	AFRICAN SNOWMAN	JAMES HAWKE	26.99	0	6869
4817	5	AFRICAN SOLDIERS	SIDNEY CROWE	22.99	0	46
4818	16	AFRICAN SOMETHING	HILARY DICAPRIO	16.99	0	8328
4819	7	AFRICAN SONG	RIP HAWKE	29.99	0	7411
4820	15	AFRICAN SONS	GROUCHO DUNST	28.99	0	5549
4821	12	AFRICAN SORORITY	WHOOPI POITIER	11.99	0	5043
4822	14	AFRICAN SOUP	MERYL SORVINO	23.99	0	9340
4823	12	AFRICAN SOUTH	DARYL HANNAH	11.99	0	6647
4824	16	AFRICAN SPARTACUS	BELA DAFOE	24.99	0	1403
4825	8	AFRICAN SPEAKEASY	JANE BLOOM	26.99	0	5765
4826	7	AFRICAN SPEED	GLENN PENN	16.99	0	9048
4827	15	AFRICAN SPICE	NICK NOLTE	21.99	0	1966
4828	9	AFRICAN SPIKING	LENA BRANDO	23.99	0	3711
4829	7	AFRICAN SPINAL	LANA COOPER	18.99	0	7439
4830	10	AFRICAN SPIRIT	ROCK HAYEK	9.99	0	8460
4831	10	AFRICAN SPIRITED	KIRK NORTON	28.99	0	4178
4832	14	AFRICAN SPLASH	BRUCE WEAVER	21.99	0	4982
4833	13	AFRICAN SPLENDOR	LISA BALE	16.99	0	8380
4834	12	AFRICAN SPOILERS	ADRIEN BULLOCK	15.99	0	9290
4835	2	AFRICAN SPY	GREGORY CRAWFORD	27.99	0	6260
4836	12	AFRICAN SQUAD	GENE SMITH	15.99	0	3793
4837	12	AFRICAN STAGE	GLENN MARTIN	26.99	0	8520
4838	6	AFRICAN STAGECOACH	SIDNEY WEST	28.99	0	6362
4839	13	AFRICAN STALLION	ORLANDO BERRY	25.99	0	3476
4840	12	AFRICAN STAMPEDE	JULIETTE HOPPER	10.99	0	7395
4841	11	AFRICAN STAR	KIRK BOLGER	29.99	0	3226
4842	7	AFRICAN STATE	SYLVESTER CAINE	23.99	0	1026
4843	9	AFRICAN STEEL	ANNE DUKAKIS	18.99	0	3862
4844	2	AFRICAN STEERS	JESSICA AFFLECK	26.99	0	8561
4845	4	AFRICAN STEPMOM	GENE JOHANSSON	24.99	0	6725
4846	8	AFRICAN STING	PEARL DENCH	9.99	0	1897
4847	6	AFRICAN STOCK	GLENN MCDORMAND	14.99	0	2930
4848	6	AFRICAN STONE	LAUREN THURMAN	17.99	0	8116
4849	14	AFRICAN STORM	RITA HAWKE	14.99	0	6023
4850	3	AFRICAN STORY	BRAD HOPE	18.99	0	6558
4851	2	AFRICAN STRAIGHT	SISSY MCGREGOR	27.99	0	1408
4852	2	AFRICAN STRANGELOVE	ORLANDO WRAY	17.99	0	890
4853	12	AFRICAN STRANGER	WILL MCKELLEN	15.99	0	3043
4854	2	AFRICAN STRANGERS	MIRA TAYLOR	28.99	0	9719
4855	9	AFRICAN STREAK	JACK DOUGLAS	21.99	0	5898
4856	5	AFRICAN STREETCAR	DENZEL SPACEK	12.99	0	8662
4857	5	AFRICAN STRICTLY	SALLY SINATRA	10.99	0	1204
4858	3	AFRICAN SUBMARINE	OLYMPIA WASHINGTON	11.99	0	8095
4859	8	AFRICAN SUGAR	MEL FINNEY	12.99	0	8270
4860	3	AFRICAN SUICIDES	BRUCE POSEY	20.99	0	8252
4861	3	AFRICAN SUIT	MARY MINELLI	16.99	0	3968
4862	4	AFRICAN SUMMER	DENNIS BULLOCK	10.99	0	4423
4863	4	AFRICAN SUN	HARVEY GARCIA	29.99	0	5970
4864	13	AFRICAN SUNDANCE	SUSAN WATSON	18.99	0	1536
4865	5	AFRICAN SUNRISE	SPENCER DAY-LEWIS	16.99	0	2778
4866	4	AFRICAN SUNSET	SYLVESTER TYLER	27.99	0	7344
4867	5	AFRICAN SUPER	SALLY JACKMAN	18.99	0	590
4868	15	AFRICAN SUPERFLY	JACK ROBBINS	15.99	0	9187
4869	15	AFRICAN SUSPECTS	SALLY JACKMAN	25.99	0	9532
4870	16	AFRICAN SWARM	CLARK DAFOE	27.99	0	9500
4871	3	AFRICAN SWEDEN	SALMA ROBERTS	10.99	0	1303
4872	13	AFRICAN SWEET	LIZA TRACY	22.99	0	1932
4873	12	AFRICAN SWEETHEARTS	WHOOPI DUKAKIS	11.99	0	6951
4874	1	AFRICAN TADPOLE	CUBA HUNT	28.99	0	1197
4875	14	AFRICAN TALENTED	GINA DEGENERES	9.99	0	9037
4876	16	AFRICAN TARZAN	MEL DENIRO	26.99	0	3241
4877	16	AFRICAN TAXI	DORIS BRANDO	21.99	0	6011
4878	13	AFRICAN TEEN	SIGOURNEY JACKMAN	25.99	0	4747
4879	8	AFRICAN TELEGRAPH	VAL NORTON	22.99	0	2225
4880	13	AFRICAN TELEMARK	JEREMY HUNT	10.99	0	5621
4881	16	AFRICAN TEMPLE	RICHARD KAHN	23.99	0	1228
4882	1	AFRICAN TENENBAUMS	DUSTIN GABLE	13.99	0	72
4883	14	AFRICAN TEQUILA	JON REYNOLDS	24.99	0	1266
4884	4	AFRICAN TERMINATOR	RIP ZELLWEGER	11.99	0	4148
4885	6	AFRICAN TEXAS	SHIRLEY HAWN	26.99	0	4002
4886	7	AFRICAN THEORY	STEVE JOVOVICH	13.99	0	2781
4887	6	AFRICAN THIEF	MADELINE CROWE	20.99	0	5962
4888	9	AFRICAN THIN	GWYNETH DENIRO	10.99	0	8943
4889	3	AFRICAN TIES	SIGOURNEY COOPER	29.99	0	5383
4890	7	AFRICAN TIGHTS	VIVIEN NICHOLSON	15.99	0	4636
4891	12	AFRICAN TIMBERLAND	WILL THURMAN	21.99	0	1565
4892	15	AFRICAN TITANIC	GREGORY HANNAH	19.99	0	7658
4893	2	AFRICAN TITANS	ALAN KEATON	19.99	0	9880
4894	6	AFRICAN TOMATOES	CHEVY REYNOLDS	14.99	0	4700
4895	13	AFRICAN TOMORROW	CHARLIZE COSTNER	24.99	0	6492
4896	4	AFRICAN TOOTSIE	KATE COOPER	12.99	0	6205
4897	6	AFRICAN TORQUE	ALBERT MOSTEL	23.99	0	9787
4898	8	AFRICAN TOURIST	JON DUNST	18.99	0	715
4899	8	AFRICAN TOWERS	ROBIN CAMPBELL	21.99	0	5911
4900	2	AFRICAN TOWN	ORLANDO DAMON	13.99	0	2325
4901	15	AFRICAN TRACY	HUGH CRAWFORD	17.99	0	1758
4902	1	AFRICAN TRADING	ROCK PECK	10.99	0	197
4903	1	AFRICAN TRAFFIC	GEOFFREY TANDY	20.99	0	905
4904	10	AFRICAN TRAIN	DREW RYAN	18.99	0	6410
4905	1	AFRICAN TRAINSPOTTING	RUBY JOHANSSON	25.99	0	8092
4906	1	AFRICAN TRAMP	WINONA MCCONAUGHEY	18.99	0	3564
4907	10	AFRICAN TRANSLATION	ANTHONY BIRCH	18.99	0	4727
4908	8	AFRICAN TRAP	GOLDIE CRUISE	25.99	0	6664
4909	14	AFRICAN TREASURE	JEREMY FOSTER	11.99	0	8713
4910	12	AFRICAN TREATMENT	HARRISON SINATRA	21.99	0	1053
4911	7	AFRICAN TRIP	MORGAN MINELLI	17.99	0	7655
4912	12	AFRICAN TROJAN	RUBY NICHOLSON	26.99	0	9957
4913	5	AFRICAN TROOPERS	CUBA LOREN	22.99	0	9160
4914	5	AFRICAN TROUBLE	ELLEN DEAN	24.99	0	390
4915	10	AFRICAN TRUMAN	SALLY BERRY	29.99	0	4685
4916	2	AFRICAN TURN	CAMERON BERGMAN	26.99	0	1814
4917	10	AFRICAN TUXEDO	SALLY DAVIS	18.99	0	9753
4918	7	AFRICAN TWISTED	KIM FIENNES	21.99	0	9159
4919	9	AFRICAN TYCOON	CHARLIZE DEAN	25.99	0	4796
4920	14	AFRICAN UNBREAKABLE	KIM MALDEN	23.99	0	2310
4921	3	AFRICAN UNCUT	GARY NICHOLSON	14.99	0	7702
4922	8	AFRICAN UNDEFEATED	WILLIAM BIRCH	15.99	0	101
4923	5	AFRICAN UNFAITHFUL	GLENN WEAVER	26.99	0	2650
4924	12	AFRICAN UNFORGIVEN	JOHNNY BLOOM	27.99	0	4662
4925	6	AFRICAN UNITED	ANNETTE PALTROW	28.99	0	6441
4926	3	AFRICAN UNTOUCHABLES	GINA KILMER	18.99	0	8220
4927	4	AFRICAN UPRISING	SPENCER DENCH	13.99	0	4233
4928	4	AFRICAN UPTOWN	HALLE SINATRA	20.99	0	9314
4929	14	AFRICAN USUAL	ALBERT GUINESS	15.99	0	9048
4930	13	AFRICAN VACATION	LISA MOORE	26.99	0	4
4931	8	AFRICAN VALENTINE	KATE POITIER	25.99	0	3394
4932	11	AFRICAN VALLEY	LAUREN HOPE	20.99	0	1231
4933	16	AFRICAN VAMPIRE	TOM TORN	15.99	0	5851
4934	5	AFRICAN VANILLA	WILLEM DIETRICH	14.99	0	2618
4935	3	AFRICAN VANISHED	SUSAN GARCIA	25.99	0	5031
4936	13	AFRICAN VANISHING	EDWARD NOLTE	16.99	0	4633
4937	11	AFRICAN VARSITY	STEVE BRIDGES	14.99	0	5820
4938	7	AFRICAN VELVET	JODIE MARX	15.99	0	9326
4939	15	AFRICAN VERTIGO	DEBBIE CRUISE	27.99	0	7910
4940	3	AFRICAN VICTORY	CHARLTON MOORE	10.99	0	3557
4941	10	AFRICAN VIDEOTAPE	ANDY DERN	26.99	0	5287
4942	5	AFRICAN VIETNAM	MARISA DIETRICH	13.99	0	2952
4943	13	AFRICAN VILLAIN	SOPHIA TYLER	14.99	0	8341
4944	3	AFRICAN VIRGIN	ALBERT CAINE	17.99	0	4962
4945	3	AFRICAN VIRGINIAN	CHARLTON COOPER	16.99	0	6115
4946	12	AFRICAN VIRTUAL	SANDRA RYDER	24.99	0	4602
4947	5	AFRICAN VISION	NEVE TOMEI	28.99	0	2607
4948	4	AFRICAN VOICE	CHRISTOPHER SWANK	11.99	0	4053
4949	15	AFRICAN VOLCANO	KATHARINE DUNST	29.99	0	5667
4950	8	AFRICAN VOLUME	NEVE TAYLOR	21.99	0	9648
4951	4	AFRICAN VOYAGE	ORLANDO TRACY	10.99	0	3723
4952	9	AFRICAN WAGON	ELVIS TOMEI	14.99	0	3451
4953	9	AFRICAN WAIT	DARYL AFFLECK	23.99	0	3115
4954	2	AFRICAN WAKE	LIAM BALE	22.99	0	2953
4955	4	AFRICAN WALLS	CHRISTIAN HOPPER	29.99	0	3738
4956	15	AFRICAN WANDA	ETHAN DUKAKIS	23.99	0	9068
4957	1	AFRICAN WAR	RENEE WASHINGTON	15.99	0	5994
4958	11	AFRICAN WARDROBE	LENA POSEY	27.99	0	7025
4959	3	AFRICAN WARLOCK	NICOLAS LUGOSI	25.99	0	7425
4960	2	AFRICAN WARS	DANIEL HUSTON	14.99	0	2689
4961	11	AFRICAN WASH	KIRK GOLDBERG	27.99	0	9430
4962	13	AFRICAN WASTELAND	SEAN BULLOCK	21.99	0	881
4963	4	AFRICAN WATCH	ROSIE BRODY	25.99	1	3114
4964	9	AFRICAN WATERFRONT	SISSY CRAWFORD	14.99	0	1511
4965	16	AFRICAN WATERSHIP	MADELINE BASINGER	13.99	0	793
4966	8	AFRICAN WEDDING	JEREMY WALKEN	9.99	0	5210
4967	16	AFRICAN WEEKEND	MARISA MCQUEEN	26.99	0	1023
4968	15	AFRICAN WEREWOLF	DORIS HOPE	25.99	0	2198
4969	2	AFRICAN WEST	HUGH REYNOLDS	29.99	0	3646
4970	3	AFRICAN WESTWARD	INGRID AFFLECK	25.99	0	7222
4971	14	AFRICAN WHALE	MARLENE MOORE	15.99	0	4815
4972	14	AFRICAN WHISPERER	CANDICE MINELLI	18.99	0	3592
4973	10	AFRICAN WIFE	RICHARD HAWKE	25.99	0	601
4974	1	AFRICAN WILD	RIVER DIAZ	17.99	0	8317
4975	13	AFRICAN WILLOW	ROBIN GOLDBERG	13.99	0	298
4976	15	AFRICAN WIND	MENA WOOD	20.99	0	3635
4977	1	AFRICAN WINDOW	ADRIEN BRANAGH	12.99	0	4885
4978	9	AFRICAN WISDOM	SISSY CARREY	16.99	0	799
4979	7	AFRICAN WITCHES	GREG WILLIS	13.99	0	5874
4980	1	AFRICAN WIZARD	WARREN CHASE	27.99	0	1069
4981	15	AFRICAN WOLVES	BOB DIETRICH	21.99	0	3810
4982	16	AFRICAN WOMEN	JOHN TOMEI	29.99	0	663
4983	8	AFRICAN WON	DENZEL MALDEN	16.99	0	1633
4984	7	AFRICAN WONDERFUL	CARRIE FINNEY	25.99	0	5065
4985	6	AFRICAN WONDERLAND	MARY LUGOSI	15.99	0	177
4986	7	AFRICAN WONKA	FAY GOODING	20.99	0	1325
4987	15	AFRICAN WORDS	ALEC WAYNE	17.99	0	906
4988	8	AFRICAN WORKER	MEL GARCIA	23.99	0	6093
4989	14	AFRICAN WORKING	TIM CHAPLIN	29.99	0	4697
4990	8	AFRICAN WORLD	ANNE DUKAKIS	12.99	0	5246
4991	3	AFRICAN WORST	SPENCER BEATTY	18.99	0	8845
4992	10	AFRICAN WRATH	RIVER JOLIE	21.99	0	7325
4993	12	AFRICAN WRONG	BRAD GARLAND	17.99	0	8143
4994	16	AFRICAN WYOMING	WHOOPI TOMEI	28.99	0	8970
4995	7	AFRICAN YENTL	DAN FOSTER	18.99	0	8153
4996	16	AFRICAN YOUNG	SCARLETT MIRANDA	27.99	0	4645
4997	13	AFRICAN YOUTH	WARREN NOLTE	21.99	0	8649
4998	6	AFRICAN ZHIVAGO	DREW WRAY	17.99	0	2779
4999	4	AFRICAN ZOOLANDER	CHRISTOPHER GARLAND	13.99	0	357
5000	2	AFRICAN ZORRO	HELEN NOLTE	15.99	0	8681
5001	2	AGENT ACADEMY	JULIA BRANAGH	29.99	0	6160
5002	8	AGENT ACE	FRANK POSEY	17.99	0	5906
5003	5	AGENT ADAPTATION	LAUREN MOORE	19.99	0	9595
5004	13	AGENT AFFAIR	GLENN FAWCETT	28.99	0	6193
5005	16	AGENT AFRICAN	FRED MARTIN	16.99	0	4383
5006	4	AGENT AGENT	KENNETH WOOD	24.99	0	5327
5007	6	AGENT AIRPLANE	FARRAH HARRIS	22.99	0	6220
5008	5	AGENT AIRPORT	FARRAH BIRCH	26.99	0	3586
5009	13	AGENT ALABAMA	MATT GARLAND	11.99	0	1726
5010	12	AGENT ALADDIN	PAUL EASTWOOD	10.99	0	6613
5011	8	AGENT ALAMO	MARLENE TORN	9.99	0	6170
5012	10	AGENT ALASKA	ALBERT ANISTON	26.99	0	8383
5013	8	AGENT ALI	SYLVESTER WASHINGTON	24.99	0	5093
5014	2	AGENT ALICE	SCARLETT LEWIS	25.99	0	1898
5015	16	AGENT ALIEN	JOHNNY HOFFMAN	24.99	0	1560
5016	7	AGENT ALLEY	ANNE WINSLET	9.99	0	7048
5017	11	AGENT ALONE	MORGAN LEWIS	23.99	0	4003
5018	9	AGENT ALTER	GOLDIE TOMEI	18.99	0	1079
5019	16	AGENT AMADEUS	MEG PRESLEY	26.99	0	3743
5020	1	AGENT AMELIE	RIP HUSTON	19.99	0	3037
5021	11	AGENT AMERICAN	EWAN MALDEN	23.99	0	2889
5022	7	AGENT AMISTAD	SALMA DOUGLAS	11.99	0	2869
5023	9	AGENT ANACONDA	CLINT HUNT	27.99	0	8270
5024	16	AGENT ANALYZE	LAUREN SWANK	22.99	0	1186
5025	1	AGENT ANGELS	LEONARDO ODONNELL	26.99	0	8105
5026	3	AGENT ANNIE	HUME SUVARI	18.99	0	303
5027	12	AGENT ANONYMOUS	GENE WITHERSPOON	21.99	0	2669
5028	14	AGENT ANTHEM	NICK MOORE	10.99	0	6487
5029	15	AGENT ANTITRUST	JUDI KAHN	18.99	0	1854
5030	10	AGENT ANYTHING	SEAN DAMON	12.99	0	697
5031	16	AGENT APACHE	SYLVESTER DAMON	17.99	0	4847
5032	7	AGENT APOCALYPSE	JIM GARCIA	24.99	0	5868
5033	1	AGENT APOLLO	EDWARD SINATRA	24.99	0	7779
5034	7	AGENT ARABIA	FRANCES POITIER	27.99	0	4649
5035	2	AGENT ARACHNOPHOBIA	MATTHEW RYAN	29.99	0	7284
5036	1	AGENT ARGONAUTS	TOM WINFREY	28.99	0	5771
5037	7	AGENT ARIZONA	TOM RYDER	27.99	0	8841
5038	8	AGENT ARK	MICHELLE KILMER	24.99	0	5700
5039	9	AGENT ARMAGEDDON	GEOFFREY NEWMAN	25.99	0	5286
5040	5	AGENT ARMY	GINA MOORE	28.99	0	2975
5041	11	AGENT ARSENIC	EMILY MINELLI	21.99	0	6374
5042	3	AGENT ARTIST	JAMES BACALL	11.99	0	9678
5043	1	AGENT ATLANTIS	JUDI HAWN	23.99	0	7887
5044	5	AGENT ATTACKS	JESSICA MOSTEL	21.99	0	348
5045	2	AGENT ATTRACTION	MERYL PHOENIX	18.99	0	3054
5046	12	AGENT AUTUMN	VIVIEN FOSTER	9.99	0	5450
5047	11	AGENT BABY	LANA CAGE	10.99	0	5055
5048	1	AGENT BACKLASH	SYLVESTER DERN	20.99	0	774
5049	6	AGENT BADMAN	NICOLAS DEGENERES	25.99	0	2089
5050	14	AGENT BAKED	UMA WEST	20.99	0	6190
5051	14	AGENT BALLOON	WARREN CAINE	25.99	0	9115
5052	6	AGENT BALLROOM	ANGELA RYAN	28.99	0	2942
5053	7	AGENT BANG	KEVIN VOIGHT	16.99	0	5125
5054	7	AGENT BANGER	OLYMPIA SINATRA	12.99	0	5812
5055	6	AGENT BARBARELLA	KARL HORNE	15.99	1	9300
5056	15	AGENT BAREFOOT	ANTHONY SOBIESKI	27.99	0	2112
5057	13	AGENT BASIC	ADAM WAYNE	26.99	0	8738
5058	3	AGENT BEACH	RAY DERN	23.99	0	2655
5059	4	AGENT BEAR	BEN AKROYD	28.99	0	7020
5060	9	AGENT BEAST	CHRIS KELLY	10.99	0	1545
5061	16	AGENT BEAUTY	WILLIAM PRESLEY	10.99	0	5946
5062	5	AGENT BED	KATE HOPE	14.99	0	3871
5063	3	AGENT BEDAZZLED	MARISA HECHE	28.99	0	2418
5064	4	AGENT BEETHOVEN	EDWARD FIELD	15.99	0	4115
5065	16	AGENT BEHAVIOR	TOM RYAN	12.99	0	7692
5066	5	AGENT BENEATH	JULIETTE SUVARI	15.99	0	1748
5067	15	AGENT BERETS	LIZA CROWE	17.99	0	9119
5068	13	AGENT BETRAYED	GRACE MARX	18.99	0	4522
5069	12	AGENT BEVERLY	PARKER PRESLEY	28.99	0	286
5070	6	AGENT BIKINI	RIVER BAILEY	15.99	0	6814
5071	2	AGENT BILKO	KATE JACKMAN	21.99	0	4499
5072	13	AGENT BILL	MAE MOSTEL	17.99	0	979
5073	5	AGENT BINGO	MILLA TOMEI	22.99	0	2578
5074	2	AGENT BIRCH	AL BALL	26.99	0	585
5075	15	AGENT BIRD	BOB FREEMAN	23.99	0	2770
5076	7	AGENT BIRDCAGE	PARKER PACINO	28.99	0	5494
5077	6	AGENT BIRDS	DENNIS BENING	9.99	0	2967
5078	2	AGENT BLACKOUT	CUBA POITIER	26.99	0	5360
5079	2	AGENT BLADE	LAURA HUNT	10.99	0	5689
5080	3	AGENT BLANKET	SUSAN DAVIS	13.99	0	5564
5081	9	AGENT BLINDNESS	ELVIS FAWCETT	14.99	0	5550
5082	14	AGENT BLOOD	LIV MARTIN	9.99	0	628
5083	6	AGENT BLUES	RICHARD PESCI	20.99	0	1948
5084	2	AGENT BOILED	MATT MARX	22.99	0	9997
5085	4	AGENT BONNIE	DENNIS SPACEK	11.99	0	1342
5086	11	AGENT BOOGIE	JAYNE LUGOSI	28.99	0	6737
5087	9	AGENT BOONDOCK	EWAN PACINO	11.99	0	8910
5088	3	AGENT BORN	LISA BLOOM	29.99	0	1465
5089	3	AGENT BORROWERS	OLYMPIA NORTON	26.99	0	4478
5090	14	AGENT BOULEVARD	FAY KUDROW	10.99	0	3630
5091	4	AGENT BOUND	VIVIEN GARCIA	22.99	0	8250
5092	6	AGENT BOWFINGER	JULIETTE SILVERSTONE	21.99	0	2786
5093	8	AGENT BRANNIGAN	HALLE BRANAGH	11.99	0	9898
5094	4	AGENT BRAVEHEART	MEG DREYFUSS	29.99	0	91
5095	8	AGENT BREAKFAST	KIM WOOD	24.99	0	2328
5096	2	AGENT BREAKING	LENA DEPP	9.99	0	9057
5097	14	AGENT BRIDE	MIRA DAVIS	17.99	0	6449
5098	11	AGENT BRIGHT	OLYMPIA DUKAKIS	10.99	0	8487
5099	1	AGENT BRINGING	CARRIE MCQUEEN	24.99	0	2631
5100	12	AGENT BROOKLYN	ELIZABETH BERRY	14.99	0	3041
5101	9	AGENT BROTHERHOOD	KIM TRACY	11.99	0	4569
5102	1	AGENT BUBBLE	MATTHEW SMITH	24.99	0	4812
5103	7	AGENT BUCKET	PEARL TURNER	11.99	0	1681
5104	16	AGENT BUGSY	RENEE WRAY	11.99	0	4359
5105	6	AGENT BULL	JUDY HESTON	22.99	0	3225
5106	15	AGENT BULWORTH	DORIS DEAN	19.99	0	1780
5107	16	AGENT BUNCH	ADAM GABLE	21.99	0	2276
5108	2	AGENT BUTCH	CARY HORNE	27.99	0	895
5109	1	AGENT BUTTERFLY	BEN LEIGH	26.99	0	7950
5110	5	AGENT CABIN	DREW BARRYMORE	25.99	0	9467
5111	2	AGENT CADDYSHACK	CLARK MALDEN	16.99	0	5153
5112	9	AGENT CALENDAR	SANDRA ALLEN	19.99	0	9555
5113	12	AGENT CALIFORNIA	INGRID PENN	27.99	0	105
5114	16	AGENT CAMELOT	LAUREN MCDORMAND	10.99	0	2564
5115	14	AGENT CAMPUS	FRED PINKETT	10.99	0	9686
5116	1	AGENT CANDIDATE	KIM MCQUEEN	13.99	0	6317
5117	12	AGENT CANDLES	MARILYN JACKMAN	21.99	0	2686
5118	9	AGENT CANYON	WINONA PRESLEY	29.99	0	5709
5119	16	AGENT CAPER	DAN MARTIN	20.99	0	6558
5120	13	AGENT CARIBBEAN	HILARY JOVOVICH	11.99	0	9222
5121	2	AGENT CAROL	KIRK MARX	22.99	0	5394
5122	5	AGENT CARRIE	ALICIA KELLY	28.99	0	445
5123	3	AGENT CASABLANCA	RENEE MONROE	12.99	0	4374
5124	12	AGENT CASPER	ANGELA LOREN	28.99	0	6995
5125	10	AGENT CASSIDY	DARYL WATSON	29.99	0	7884
5126	15	AGENT CASUALTIES	HUGH BRODY	18.99	0	2063
5127	1	AGENT CAT	NEVE BACALL	9.99	0	8437
5128	2	AGENT CATCH	JON BRODY	27.99	0	1083
5129	6	AGENT CAUSE	MERYL ASTAIRE	16.99	0	8222
5130	1	AGENT CELEBRITY	ORLANDO KILMER	14.99	0	8074
5131	1	AGENT CENTER	TIM HAYEK	18.99	0	6918
5132	11	AGENT CHAINSAW	MIRA THURMAN	17.99	0	6590
5133	4	AGENT CHAMBER	PEARL AFFLECK	24.99	0	648
5134	14	AGENT CHAMPION	BETTE DAFOE	20.99	0	397
5135	6	AGENT CHANCE	LAURA MCGREGOR	11.99	0	955
5136	15	AGENT CHAPLIN	JULIA WEAVER	26.99	0	3995
5137	9	AGENT CHARADE	FAY BASINGER	14.99	0	2096
5138	15	AGENT CHARIOTS	DENNIS NICHOLSON	23.99	0	988
5139	13	AGENT CHASING	FRED DENCH	26.99	0	8700
5140	15	AGENT CHEAPER	JON BRIDGES	18.99	0	3897
5141	10	AGENT CHICAGO	GRACE CARREY	10.99	1	7336
5142	8	AGENT CHICKEN	RALPH KILMER	25.99	0	2315
5143	16	AGENT CHILL	SPENCER PENN	12.99	0	3130
5144	5	AGENT CHINATOWN	KIM CRAWFORD	21.99	0	3250
5145	8	AGENT CHISUM	JAYNE TYLER	29.99	0	6733
5146	6	AGENT CHITTY	RITA WAYNE	23.99	0	8152
5147	7	AGENT CHOCOLAT	GRETA JOHANSSON	13.99	0	1474
5148	7	AGENT CHOCOLATE	SALMA DEGENERES	16.99	0	2752
5149	11	AGENT CHRISTMAS	JENNIFER PALTROW	13.99	0	4759
5150	9	AGENT CIDER	HILARY PRESLEY	29.99	0	7724
5151	11	AGENT CINCINATTI	MIRA BEATTY	18.99	0	7390
5152	5	AGENT CIRCUS	DUSTIN CHASE	22.99	0	5024
5153	13	AGENT CITIZEN	NICK RYAN	22.99	0	1628
5154	15	AGENT CLASH	SCARLETT RYAN	16.99	0	1696
5155	14	AGENT CLEOPATRA	THORA KILMER	14.99	0	6395
5156	1	AGENT CLERKS	MICHAEL COSTNER	24.99	0	4382
5157	8	AGENT CLOCKWORK	LEELEE WASHINGTON	23.99	0	9528
5158	4	AGENT CLONES	NICOLE GARBO	28.99	0	8829
5159	2	AGENT CLOSER	MATTHEW WALKEN	29.99	0	6774
5160	3	AGENT CLUB	DENZEL CHAPLIN	10.99	0	7337
5161	12	AGENT CLUE	SOPHIA HARRIS	17.99	0	5483
5162	14	AGENT CLUELESS	JODIE MARX	18.99	0	501
5163	7	AGENT CLYDE	HUMPHREY KEITEL	12.99	0	4122
5164	1	AGENT COAST	GREG LUGOSI	23.99	0	6447
5165	7	AGENT COLDBLOODED	REESE PESCI	21.99	0	1928
5166	6	AGENT COLOR	LEONARDO KEITEL	13.99	0	7382
5167	13	AGENT COMA	GREG RYAN	14.99	0	6588
5168	6	AGENT COMANCHEROS	CLINT MINELLI	24.99	0	6559
5169	3	AGENT COMFORTS	ED SMITH	18.99	0	8098
5170	2	AGENT COMMAND	KARL TYLER	28.99	0	3336
5171	2	AGENT COMMANDMENTS	RUSSELL STALLONE	23.99	0	7927
5172	8	AGENT CONEHEADS	LAURENCE TAUTOU	25.99	0	8282
5173	8	AGENT CONFESSIONS	JOAN HOFFMAN	22.99	0	2643
5174	5	AGENT CONFIDENTIAL	BETTE EASTWOOD	20.99	0	6166
5175	6	AGENT CONFUSED	JULIETTE TORN	27.99	0	396
5176	4	AGENT CONGENIALITY	SHIRLEY WAHLBERG	10.99	0	9629
5177	14	AGENT CONNECTICUT	ROBERT BLANCHETT	18.99	0	9581
5178	5	AGENT CONNECTION	HUME FONDA	24.99	0	5696
5179	1	AGENT CONQUERER	SCARLETT DERN	10.99	0	6457
5180	12	AGENT CONSPIRACY	KATHARINE CAINE	14.99	0	3544
5181	5	AGENT CONTACT	EWAN DAY	12.99	0	9141
5182	2	AGENT CONTROL	ZERO CAGE	28.99	0	8786
5183	15	AGENT CONVERSATION	DENNIS STALLONE	15.99	0	1791
5184	15	AGENT CORE	JANE MALDEN	24.99	0	2315
5185	7	AGENT COWBOY	HALLE GUINESS	28.99	0	3758
5186	5	AGENT CRAFT	LEELEE TURNER	21.99	0	8727
5187	8	AGENT CRANES	ADRIEN CRUISE	19.99	0	5831
5188	6	AGENT CRAZY	JADA BASINGER	21.99	0	137
5189	13	AGENT CREATURES	LEONARDO DENIRO	13.99	0	2892
5190	7	AGENT CREEPERS	MEL HACKMAN	25.99	0	3150
5191	3	AGENT CROOKED	DIANE MCGREGOR	24.99	0	2949
5192	11	AGENT CROSSING	JOHN NORTON	22.99	0	6335
5193	4	AGENT CROSSROADS	MENA KIDMAN	22.99	0	546
5194	11	AGENT CROW	FRED TANDY	14.99	0	3038
5195	9	AGENT CROWDS	MICHELLE HURT	14.99	0	389
5196	9	AGENT CRUELTY	MATT HEPBURN	25.99	0	8699
5197	2	AGENT CRUSADE	KIM SMITH	20.99	0	7280
5198	4	AGENT CRYSTAL	ELVIS NOLTE	27.99	0	3712
5199	16	AGENT CUPBOARD	DREW WRAY	14.99	0	2867
5200	9	AGENT CURTAIN	ORLANDO SINATRA	14.99	0	307
5201	5	AGENT CYCLONE	JESSICA MATTHAU	29.99	0	6541
5202	14	AGENT DADDY	JODIE HUDSON	17.99	0	9369
5203	2	AGENT DAISY	LIV DEAN	16.99	0	9507
5204	12	AGENT DALMATIONS	VAL BASINGER	29.99	0	2076
5205	5	AGENT DANCES	ALEC SPACEK	9.99	0	865
5206	1	AGENT DANCING	MICHELLE GIBSON	19.99	0	949
5207	3	AGENT DANGEROUS	KIRK CHAPLIN	22.99	0	5945
5208	10	AGENT DARES	RIVER MINELLI	13.99	0	9341
5209	3	AGENT DARKNESS	WILLIAM PRESLEY	11.99	0	2769
5210	5	AGENT DARKO	CAMERON ZELLWEGER	16.99	0	2002
5211	7	AGENT DARLING	LANA BERRY	11.99	0	8985
5212	4	AGENT DARN	ANGELINA ROBBINS	25.99	0	5827
5213	7	AGENT DATE	DIANE ALLEN	13.99	0	2390
5214	3	AGENT DAUGHTER	ZERO GIBSON	11.99	0	7295
5215	7	AGENT DAWN	NATALIE RUSSELL	19.99	0	7479
5216	12	AGENT DAY	ROBERT KUDROW	14.99	0	4269
5217	3	AGENT DAZED	DARYL THURMAN	13.99	0	6245
5218	13	AGENT DECEIVER	MAE BARRYMORE	9.99	0	8533
5219	5	AGENT DEEP	DORIS GOLDBERG	14.99	0	7047
5220	1	AGENT DEER	JOHNNY TOMEI	24.99	0	6145
5221	8	AGENT DELIVERANCE	CHRIS BRANAGH	15.99	0	8315
5222	12	AGENT DESERT	MORGAN LEIGH	28.99	0	3923
5223	9	AGENT DESIRE	JAYNE MATTHAU	12.99	0	6871
5224	1	AGENT DESPERATE	ANTHONY WAHLBERG	14.99	0	5634
5225	16	AGENT DESTINATION	JENNIFER CRUISE	18.99	0	8545
5226	2	AGENT DESTINY	WARREN HACKMAN	14.99	0	3537
5227	2	AGENT DETAILS	SYLVESTER HECHE	25.99	0	7215
5228	3	AGENT DETECTIVE	GOLDIE TURNER	22.99	0	9785
5229	6	AGENT DEVIL	SOPHIA CAMPBELL	16.99	0	945
5230	16	AGENT DIARY	FAY GRANT	17.99	0	2108
5231	5	AGENT DINOSAUR	LIAM WASHINGTON	13.99	0	3044
5232	10	AGENT DIRTY	NEVE DENIRO	19.99	0	859
5233	4	AGENT DISCIPLE	WOODY DEAN	20.99	0	926
5234	9	AGENT DISTURBING	DREW COOPER	17.99	0	6437
5235	9	AGENT DIVIDE	ALEC IRONS	25.99	0	8811
5236	1	AGENT DIVINE	RIP CAINE	22.99	0	9872
5237	15	AGENT DIVORCE	DREW WAHLBERG	22.99	0	2740
5238	12	AGENT DOCTOR	JUDE MCGREGOR	24.99	0	3523
5239	14	AGENT DOGMA	JULIA OLIVIER	10.99	0	629
5240	12	AGENT DOLLS	KEVIN MINELLI	24.99	0	4367
5241	10	AGENT DONNIE	LANA HUDSON	18.99	0	9276
5242	7	AGENT DOOM	RUSSELL BACALL	22.99	0	2651
5243	15	AGENT DOORS	SIGOURNEY HEPBURN	18.99	0	680
5244	13	AGENT DORADO	PARKER AKROYD	15.99	0	8890
5245	6	AGENT DOUBLE	KARL RUSH	28.99	0	9811
5246	6	AGENT DOUBTFIRE	JENNIFER CAMPBELL	28.99	0	5456
5247	14	AGENT DOWNHILL	LANA ZELLWEGER	23.99	0	2564
5248	16	AGENT DOZEN	MENA LOREN	27.99	0	8616
5249	15	AGENT DRACULA	SANDRA RYAN	23.99	0	9413
5250	10	AGENT DRAGON	MORGAN HOPKINS	11.99	0	2472
5251	2	AGENT DRAGONFLY	HILARY PECK	20.99	0	9675
5252	2	AGENT DREAM	WHOOPI IRONS	22.99	0	6185
5253	15	AGENT DRIFTER	DANIEL CHASE	21.99	0	2102
5254	8	AGENT DRIVER	ADAM WAYNE	16.99	0	912
5255	5	AGENT DRIVING	KATHARINE DAY-LEWIS	9.99	0	9066
5256	4	AGENT DROP	LIV HEPBURN	22.99	0	2569
5257	10	AGENT DRUMLINE	NICOLAS BERGEN	21.99	0	9345
5258	4	AGENT DRUMS	BOB MIRANDA	17.99	0	1064
5259	10	AGENT DUCK	ANJELICA PESCI	21.99	0	6886
5260	12	AGENT DUDE	SPENCER FONDA	13.99	0	2451
5261	3	AGENT DUFFEL	MEG LUGOSI	25.99	0	6512
5262	1	AGENT DUMBO	MIRA SORVINO	25.99	0	4464
5263	12	AGENT DURHAM	BOB MANSFIELD	25.99	0	3456
5264	15	AGENT DWARFS	ANTHONY LUGOSI	28.99	0	1234
5265	11	AGENT DYING	JEREMY THERON	20.99	0	7940
5266	13	AGENT DYNAMITE	HARVEY DIAZ	18.99	0	6043
5267	2	AGENT EAGLES	JANE BALL	26.99	0	8407
5268	5	AGENT EARLY	JANE JOVOVICH	16.99	0	4226
5269	12	AGENT EARRING	ADRIEN CRUISE	25.99	0	1998
5270	15	AGENT EARTH	BEN ROBBINS	16.99	0	2023
5271	3	AGENT EASY	JESSICA BOLGER	20.99	0	4886
5272	3	AGENT EDGE	KARL NOLTE	21.99	0	3402
5273	7	AGENT EFFECT	RUBY RYDER	26.99	0	1424
5274	5	AGENT EGG	GOLDIE THURMAN	15.99	0	4701
5275	8	AGENT EGYPT	ED LOLLOBRIGIDA	20.99	0	5557
5276	13	AGENT ELEMENT	MARLON BOLGER	13.99	0	2277
5277	12	AGENT ELEPHANT	STEVE RUSSELL	14.99	0	4283
5278	10	AGENT ELF	DIANE RUSH	18.99	0	3941
5279	10	AGENT ELIZABETH	FARRAH VOIGHT	28.99	0	9527
5280	7	AGENT EMPIRE	KARL OLIVIER	22.99	0	4765
5281	3	AGENT ENCINO	LAUREN BALL	26.99	0	2229
5282	2	AGENT ENCOUNTERS	ADRIEN AFFLECK	29.99	0	3732
5283	7	AGENT ENDING	CHEVY TANDY	22.99	0	7983
5284	1	AGENT ENEMY	MIRA TOMEI	15.99	0	9249
5285	5	AGENT ENGLISH	LIZA DAMON	25.99	0	8876
5286	5	AGENT ENOUGH	THORA ASTAIRE	26.99	0	2060
5287	2	AGENT ENTRAPMENT	DENNIS WEAVER	10.99	0	4724
5288	8	AGENT ESCAPE	GOLDIE FREEMAN	21.99	0	6391
5289	7	AGENT EVE	KARL ANISTON	11.99	0	3469
5290	1	AGENT EVERYONE	KEVIN MANSFIELD	23.99	0	3892
5291	10	AGENT EVOLUTION	IAN NEWMAN	19.99	0	2849
5292	12	AGENT EXCITEMENT	DREW MARX	28.99	0	1623
5293	7	AGENT EXORCIST	JUDI CHAPLIN	24.99	0	4929
5294	6	AGENT EXPECATIONS	JUDY CROWE	27.99	0	8430
5295	4	AGENT EXPENDABLE	JAYNE GOLDBERG	25.99	0	8403
5296	3	AGENT EXPRESS	JUDY MCGREGOR	21.99	0	426
5297	14	AGENT EXTRAORDINARY	MARLENE SINATRA	11.99	0	3446
5298	5	AGENT EYES	JON BRANDO	25.99	0	2715
5299	5	AGENT FACTORY	JEREMY CRONYN	25.99	0	7815
5300	10	AGENT FALCON	CHRIS FAWCETT	10.99	0	2201
5301	15	AGENT FAMILY	RUBY DICAPRIO	17.99	0	9645
5302	8	AGENT FANTASIA	PENELOPE PFEIFFER	11.99	0	5144
5303	8	AGENT FANTASY	LUCILLE BOLGER	29.99	0	4560
5304	4	AGENT FARGO	MAE CAMPBELL	23.99	0	7105
5305	8	AGENT FATAL	ALAN KINNEAR	22.99	0	1070
5306	14	AGENT FEATHERS	HARRISON JOVOVICH	23.99	0	2298
5307	11	AGENT FELLOWSHIP	WALTER GRANT	18.99	0	7936
5308	16	AGENT FERRIS	SIGOURNEY WEST	21.99	0	7701
5309	1	AGENT FEUD	STEVE CAGE	23.99	0	8347
5310	7	AGENT FEVER	HARVEY DREYFUSS	17.99	0	9836
5311	9	AGENT FICTION	JOHNNY PRESLEY	27.99	0	4208
5312	2	AGENT FIDDLER	RICHARD BRANAGH	10.99	0	3051
5313	14	AGENT FIDELITY	ELLEN JOVOVICH	25.99	0	1622
5314	9	AGENT FIGHT	FRANCES BULLOCK	18.99	0	1082
5315	5	AGENT FINDING	HILARY CRUZ	22.99	0	2998
5316	11	AGENT FIRE	ANNE BRANDO	11.99	1	5076
5317	9	AGENT FIREBALL	LIV BRANDO	16.99	0	1645
5318	11	AGENT FIREHOUSE	MATT BASINGER	28.99	0	7580
5319	2	AGENT FISH	SIDNEY GABLE	16.99	0	6914
5320	8	AGENT FLAMINGOS	SIDNEY BERRY	27.99	0	4862
5321	3	AGENT FLASH	LENA GOLDBERG	13.99	0	5944
5322	12	AGENT FLATLINERS	MILLA BERGEN	16.99	0	8930
5323	9	AGENT FLIGHT	VAL BOGART	13.99	0	7654
5324	16	AGENT FLINTSTONES	CANDICE BRANDO	26.99	0	9118
5325	9	AGENT FLOATS	WINONA WINSLET	17.99	0	7233
5326	15	AGENT FLYING	BRAD BALE	19.99	0	6107
5327	2	AGENT FOOL	MEG ALLEN	25.99	0	1079
5328	12	AGENT FOREVER	DEBBIE TOMEI	22.99	0	2311
5329	7	AGENT FORREST	GREG BALE	19.99	0	8344
5330	7	AGENT FORRESTER	RIP HACKMAN	17.99	0	6723
5331	3	AGENT FORWARD	MILLA PALTROW	14.99	0	9795
5332	14	AGENT FRANKENSTEIN	WOODY DUNST	20.99	0	3650
5333	11	AGENT FREAKY	ELLEN RUSH	26.99	0	3447
5334	2	AGENT FREDDY	HELEN SOBIESKI	17.99	0	2510
5335	5	AGENT FREEDOM	MARISA ROBERTS	10.99	0	4580
5336	12	AGENT FRENCH	CHRISTIAN FORD	18.99	0	3727
5337	7	AGENT FRIDA	MATT HEPBURN	17.99	0	7629
5338	13	AGENT FRISCO	KENNETH MANSFIELD	9.99	0	9690
5339	7	AGENT FROGMEN	RAY KEITEL	25.99	0	1390
5340	1	AGENT FRONTIER	STEVE CRUISE	23.99	0	1088
5341	3	AGENT FROST	JEFF ZELLWEGER	15.99	0	251
5342	11	AGENT FUGITIVE	JEREMY TAYLOR	16.99	0	4186
5343	2	AGENT FULL	ALAN BERRY	22.99	0	4628
5344	10	AGENT FURY	WILLIAM JOVOVICH	17.99	0	9216
5345	9	AGENT GABLES	CAMERON DUNST	18.99	0	3714
5346	10	AGENT GALAXY	HALLE BLOOM	9.99	0	8135
5347	1	AGENT GAMES	MENA BARRYMORE	19.99	0	9766
5348	15	AGENT GANDHI	ANJELICA HUSTON	28.99	0	1736
5349	7	AGENT GANGS	MEL PINKETT	16.99	0	9604
5350	5	AGENT GARDEN	ELLEN ODONNELL	17.99	0	2233
5351	13	AGENT GASLIGHT	GENE PESCI	12.99	0	6980
5352	16	AGENT GATHERING	NICOLE ROBERTS	22.99	0	1307
5353	11	AGENT GENTLEMEN	LISA CRUISE	23.99	0	7367
5354	14	AGENT GHOST	JOAN KEITEL	20.99	0	6209
5355	8	AGENT GHOSTBUSTERS	GENE DAFOE	24.99	0	4667
5356	16	AGENT GIANT	CUBA HANNAH	15.99	0	9280
5357	16	AGENT GILBERT	MILLA KELLY	24.99	0	9830
5358	14	AGENT GILMORE	CHRISTOPHER SARANDON	19.99	0	3010
5359	4	AGENT GLADIATOR	RIVER FREEMAN	23.99	0	7267
5360	6	AGENT GLASS	TIM GRANT	22.99	0	5494
5361	2	AGENT GLEAMING	VIVIEN BRODY	14.99	0	5122
5362	4	AGENT GLORY	ANDY HARRIS	28.99	0	2183
5363	15	AGENT GO	ALEC ANISTON	10.99	0	5190
5364	7	AGENT GODFATHER	SANDRA PENN	13.99	0	7535
5365	15	AGENT GOLD	CATE PFEIFFER	27.99	0	2818
5366	7	AGENT GOLDFINGER	HUME HOPE	16.99	0	8218
5367	14	AGENT GOLDMINE	DREW WAYNE	28.99	0	3805
5368	3	AGENT GONE	HUGH REYNOLDS	12.99	0	9006
5369	11	AGENT GOODFELLAS	LIV DAY	20.99	0	323
5370	5	AGENT GORGEOUS	OPRAH FOSTER	18.99	0	1124
5371	12	AGENT GOSFORD	KIRK MARX	11.99	0	2913
5372	16	AGENT GRACELAND	DREW STALLONE	12.99	0	950
5373	9	AGENT GRADUATE	SALLY THURMAN	29.99	0	6953
5374	14	AGENT GRAFFITI	STEVE PESCI	18.99	0	3263
5375	9	AGENT GRAIL	MATT LAW	14.99	1	8715
5376	7	AGENT GRAPES	JOE PECK	28.99	0	4515
5377	4	AGENT GREASE	FRANK RUSH	18.99	0	514
5378	9	AGENT GREATEST	TOM KAHN	17.99	0	9817
5379	2	AGENT GREEDY	MICHELLE FINNEY	9.99	0	9658
5380	6	AGENT GREEK	JULIETTE FAWCETT	9.99	0	5227
5381	15	AGENT GRINCH	DUSTIN WEST	16.99	0	731
5382	14	AGENT GRIT	RUSSELL BRODY	11.99	0	8090
5383	3	AGENT GROOVE	GINA CARREY	11.99	0	7874
5384	2	AGENT GROSSE	CAMERON NEWMAN	25.99	0	9092
5385	13	AGENT GROUNDHOG	DENZEL BALL	14.99	0	7896
5386	13	AGENT GUMP	NICOLAS WEST	9.99	0	6336
5387	2	AGENT GUN	OPRAH CAMPBELL	29.99	0	3417
5388	13	AGENT GUNFIGHT	JOHN HECHE	11.99	0	491
5389	15	AGENT GUNFIGHTER	MORGAN MCDORMAND	29.99	0	4183
5390	15	AGENT GUYS	JESSICA COOPER	11.99	0	5239
5391	15	AGENT HALF	JODIE DERN	22.99	0	7968
5392	5	AGENT HALL	UMA HAWKE	9.99	0	2008
5393	7	AGENT HALLOWEEN	LUCILLE CHASE	27.99	0	1652
5394	15	AGENT HAMLET	RALPH CAINE	22.99	0	2018
5395	1	AGENT HANDICAP	HARRISON BALE	19.99	0	8220
5396	1	AGENT HANGING	BELA BERGEN	19.99	0	3753
5397	6	AGENT HANKY	RALPH AFFLECK	14.99	0	1670
5398	8	AGENT HANOVER	GINA HECHE	10.99	0	5773
5399	5	AGENT HAPPINESS	MIRA DAVIS	9.99	0	8490
5400	4	AGENT HARDLY	SIDNEY TYLER	21.99	0	437
5401	7	AGENT HAROLD	CAMERON HUSTON	19.99	0	8291
5402	15	AGENT HARPER	ROBIN FIENNES	23.99	0	8768
5403	14	AGENT HARRY	FRED BAILEY	12.99	0	5989
5404	12	AGENT HATE	RIP GIBSON	18.99	0	6685
5405	5	AGENT HAUNTED	LAUREN MOORE	13.99	0	193
5406	4	AGENT HAUNTING	JUDE PALTROW	16.99	0	5022
5407	3	AGENT HAWK	RIVER BRANDO	9.99	0	3966
5408	15	AGENT HEAD	JAMES MCKELLEN	13.99	0	5520
5409	13	AGENT HEARTBREAKERS	THORA KINNEAR	21.99	0	3425
5410	5	AGENT HEAVEN	ADAM FIELD	26.99	0	2749
5411	14	AGENT HEAVENLY	WILLIAM POITIER	16.99	0	2074
5412	15	AGENT HEAVYWEIGHTS	GEOFFREY DIETRICH	23.99	0	1087
5413	2	AGENT HEDWIG	NICOLAS COSTNER	20.99	0	5401
5414	2	AGENT HELLFIGHTERS	BEN CHAPLIN	9.99	0	861
5415	6	AGENT HIGH	HUGH BACALL	16.99	0	9041
5416	10	AGENT HIGHBALL	MARISA POSEY	21.99	0	7437
5417	14	AGENT HILLS	ALAN AKROYD	11.99	0	3001
5418	4	AGENT HOBBIT	JOAN RYDER	29.99	0	8337
5419	9	AGENT HOCUS	WINONA HACKMAN	21.99	0	7405
5420	12	AGENT HOLES	PARKER PITT	10.99	0	6470
5421	16	AGENT HOLIDAY	HUME PECK	22.99	0	5299
5422	7	AGENT HOLLOW	KARL BULLOCK	17.99	0	2371
5423	12	AGENT HOLLYWOOD	ALICIA JOLIE	12.99	0	3533
5424	1	AGENT HOLOCAUST	NICOLE AKROYD	29.99	0	1483
5425	12	AGENT HOLY	SIGOURNEY EASTWOOD	19.99	0	9819
5426	3	AGENT HOME	MERYL GRANT	20.99	0	101
5427	2	AGENT HOMEWARD	CATE HAWKE	21.99	0	4017
5428	14	AGENT HOMICIDE	SOPHIA KEATON	27.99	0	3904
5429	4	AGENT HONEY	HUGH PACINO	29.99	0	109
5430	3	AGENT HOOK	GEOFFREY HECHE	9.99	0	7086
5431	1	AGENT HOOSIERS	BRAD BERRY	23.99	0	1239
5432	12	AGENT HOPE	KATE PACINO	26.99	0	3560
5433	5	AGENT HORN	SEAN COOPER	12.99	0	5694
5434	9	AGENT HORROR	ETHAN DRIVER	28.99	0	9653
5435	16	AGENT HOTEL	HILARY HARRIS	14.99	0	3220
5436	16	AGENT HOURS	HUGH HESTON	10.99	0	217
5437	4	AGENT HOUSE	MORGAN SUVARI	24.99	0	394
5438	2	AGENT HUMAN	DARYL WILLIAMS	29.99	0	2537
5439	9	AGENT HUNCHBACK	KATE MOSTEL	26.99	0	8102
5440	13	AGENT HUNGER	DENZEL LAW	12.99	0	6472
5441	8	AGENT HUNTER	BETTE SINATRA	27.99	0	2274
5442	15	AGENT HUNTING	BELA BLOOM	22.99	0	7822
5443	11	AGENT HURRICANE	NICK WAHLBERG	27.99	0	8504
5444	3	AGENT HUSTLER	JUDY HEPBURN	23.99	0	1179
5445	8	AGENT HYDE	MEL ANISTON	23.99	0	5167
5446	6	AGENT HYSTERICAL	GOLDIE NICHOLSON	18.99	0	2242
5447	11	AGENT ICE	GEOFFREY HUNT	24.99	0	1443
5448	9	AGENT IDAHO	ANTHONY RUSH	14.99	0	9606
5449	2	AGENT IDENTITY	HILARY RUSSELL	21.99	0	6347
5450	12	AGENT IDOLS	MARLENE WAYNE	17.99	0	8372
5451	15	AGENT IGBY	JUDY WITHERSPOON	14.99	0	771
5452	8	AGENT ILLUSION	KEVIN BERGEN	25.99	0	6582
5453	16	AGENT IMAGE	JANE FINNEY	9.99	0	969
5454	16	AGENT IMPACT	SIDNEY NORTON	16.99	0	3471
5455	1	AGENT IMPOSSIBLE	FAY BALL	22.99	0	9255
5456	8	AGENT INCH	SPENCER GUINESS	9.99	0	3172
5457	2	AGENT INDEPENDENCE	HENRY CARREY	22.99	0	1909
5458	5	AGENT INDIAN	JUDY TRACY	24.99	0	956
5459	14	AGENT INFORMER	PENELOPE TRACY	24.99	0	884
5460	1	AGENT INNOCENT	CARRIE DOUGLAS	16.99	0	5880
5461	5	AGENT INSECTS	WILLIAM HECHE	12.99	0	6387
5462	8	AGENT INSIDER	RALPH KEATON	27.99	0	7424
5463	2	AGENT INSTINCT	MARISA HOPE	21.99	0	5690
5464	11	AGENT INTENTIONS	JIM AKROYD	18.99	0	7397
5465	9	AGENT INTERVIEW	ALAN RUSH	23.99	0	9484
5466	5	AGENT INTOLERABLE	HARVEY HARRIS	14.99	0	8090
5467	15	AGENT INTRIGUE	GLENN BLOOM	23.99	0	4800
5468	7	AGENT INVASION	THORA BASINGER	10.99	0	1036
5469	11	AGENT IRON	BURT FISHER	11.99	0	8306
5470	14	AGENT ISHTAR	LISA GABLE	27.99	0	7474
5471	13	AGENT ISLAND	CHEVY FIENNES	12.99	0	7479
5472	16	AGENT ITALIAN	ROCK HORNE	15.99	0	8133
5473	13	AGENT JACKET	SALMA LEIGH	24.99	0	5052
5474	14	AGENT JADE	ROBIN DOUGLAS	28.99	0	6288
5475	13	AGENT JAPANESE	WILLIAM DEGENERES	17.99	0	233
5476	3	AGENT JASON	GRACE TYLER	15.99	0	9096
5477	1	AGENT JAWBREAKER	HARRISON BLOOM	27.99	0	5196
5478	12	AGENT JAWS	BETTE DAY-LEWIS	20.99	0	7285
5479	1	AGENT JEDI	ADRIEN RUSH	27.99	0	3955
5480	9	AGENT JEEPERS	MADELINE JOHANSSON	19.99	0	7312
5481	9	AGENT JEKYLL	MARILYN ANISTON	27.99	0	7417
5482	13	AGENT JEOPARDY	ROCK FREEMAN	12.99	0	2548
5483	11	AGENT JERICHO	JODIE TYLER	24.99	0	4264
5484	8	AGENT JERK	DEBBIE KELLY	19.99	0	9349
5485	15	AGENT JERSEY	JAMES WATSON	19.99	0	3179
5486	5	AGENT JET	GRACE WILSON	27.99	0	6462
5487	11	AGENT JINGLE	WOODY MARX	18.99	0	2188
5488	12	AGENT JOON	CARY HAYEK	13.99	0	6019
5489	11	AGENT JUGGLER	CARRIE MOSTEL	26.99	0	5481
5490	13	AGENT JUMANJI	JOHN BALL	13.99	0	9288
5491	9	AGENT JUMPING	SISSY SILVERSTONE	27.99	0	7287
5492	9	AGENT JUNGLE	GRACE FOSTER	19.99	0	904
5493	12	AGENT KANE	JUDY KINNEAR	26.99	0	6924
5494	8	AGENT KARATE	GROUCHO GIBSON	21.99	0	5133
5495	3	AGENT KENTUCKIAN	KIM WITHERSPOON	22.99	0	1224
5496	9	AGENT KICK	TOM PECK	18.99	0	6456
5497	3	AGENT KILL	WINONA BIRCH	19.99	0	8040
5498	10	AGENT KILLER	GREGORY EASTWOOD	11.99	0	891
5499	13	AGENT KING	JESSICA MATTHAU	12.99	0	6723
5500	11	AGENT KISS	MARLON FISHER	13.99	0	8463
5501	6	AGENT KISSING	KIRK JACKMAN	15.99	0	1355
5502	15	AGENT KNOCK	DENZEL BRANDO	28.99	0	8001
5503	12	AGENT KRAMER	BRUCE DAY	10.99	0	2581
5504	3	AGENT KWAI	SANDRA CAGE	22.99	0	626
5505	5	AGENT LABYRINTH	HENRY WILSON	29.99	0	3347
5506	13	AGENT LADY	ROBERT LANCASTER	16.99	0	7658
5507	8	AGENT LADYBUGS	SEAN RUSH	23.99	0	4949
5508	9	AGENT LAMBS	MINNIE HESTON	21.99	0	405
5509	14	AGENT LANGUAGE	CHRISTOPHER NICHOLSON	24.99	0	4660
5510	13	AGENT LAWLESS	JAMES MANSFIELD	13.99	0	6311
5511	9	AGENT LAWRENCE	CLINT GABLE	16.99	0	277
5512	2	AGENT LEAGUE	RICHARD DAVIS	29.99	0	5156
5513	8	AGENT LEATHERNECKS	VIVIEN HESTON	13.99	0	4641
5514	4	AGENT LEBOWSKI	CATE WALKEN	17.99	0	4416
5515	15	AGENT LEGALLY	ANGELA HURT	15.99	0	5947
5516	16	AGENT LEGEND	VAL CRUZ	11.99	0	6631
5517	3	AGENT LESSON	SCARLETT NICHOLSON	29.99	0	7981
5518	8	AGENT LIAISONS	DUSTIN COOPER	18.99	0	2899
5519	15	AGENT LIBERTY	DENZEL MCDORMAND	9.99	0	8885
5520	8	AGENT LICENSE	GWYNETH WAHLBERG	19.99	0	335
5521	2	AGENT LIES	DREW CRUISE	10.99	0	7862
5522	12	AGENT LIFE	JESSICA HUSTON	21.99	0	1395
5523	7	AGENT LIGHTS	GARY WATSON	22.99	0	6842
5524	15	AGENT LION	GARY DIETRICH	12.99	0	3453
5525	1	AGENT LOATHING	ETHAN RYAN	17.99	0	5125
5526	7	AGENT LOCK	MICHELLE HESTON	22.99	0	264
5527	8	AGENT LOLA	JUDI DEE	28.99	0	9606
5528	1	AGENT LOLITA	SISSY DEE	16.99	0	2679
5529	1	AGENT LONELY	KATHARINE RYDER	16.99	0	8526
5530	12	AGENT LORD	MARISA WINSLET	29.99	0	9648
5531	8	AGENT LOSE	HUGH SANDLER	12.99	0	9014
5532	4	AGENT LOSER	CARY VOIGHT	24.99	0	9655
5533	11	AGENT LOST	DARYL TEMPLE	21.99	0	717
5534	14	AGENT LOUISIANA	SCARLETT DREYFUSS	16.99	0	8137
5535	4	AGENT LOVE	RAY FISHER	27.99	0	1646
5536	14	AGENT LOVELY	WHOOPI ROBBINS	14.99	0	4365
5537	3	AGENT LOVER	GRETA CHASE	14.99	0	1793
5538	4	AGENT LOVERBOY	ANNE LANCASTER	18.99	0	2966
5539	9	AGENT LUCK	LAURA WILSON	17.99	0	2127
5540	4	AGENT LUCKY	KATHARINE LOLLOBRIGIDA	29.99	0	8331
5541	3	AGENT LUKE	LEONARDO FAWCETT	11.99	0	5541
5542	9	AGENT LUST	MINNIE OLIVIER	28.99	0	5866
5543	2	AGENT MADIGAN	CATE DAY	12.99	0	2622
5544	8	AGENT MADISON	DORIS CRAWFORD	9.99	0	5732
5545	4	AGENT MADNESS	CHARLTON REYNOLDS	25.99	0	6126
5546	10	AGENT MADRE	SUSAN TURNER	13.99	0	4682
5547	13	AGENT MAGIC	CHRISTIAN MALDEN	19.99	0	1406
5548	2	AGENT MAGNIFICENT	GROUCHO MANSFIELD	13.99	0	233
5549	8	AGENT MAGNOLIA	DARYL CRUISE	23.99	0	7672
5550	5	AGENT MAGUIRE	KARL HOPPER	17.99	0	2859
5551	1	AGENT MAIDEN	DAN STREEP	28.99	0	2274
5552	7	AGENT MAJESTIC	RIVER SORVINO	21.99	0	3257
5553	12	AGENT MAKER	SYLVESTER GOLDBERG	10.99	0	6686
5554	2	AGENT MALKOVICH	SALMA BASINGER	15.99	0	782
5555	2	AGENT MALLRATS	KARL ALLEN	21.99	0	7688
5556	15	AGENT MALTESE	LIV HUDSON	10.99	0	6764
5557	6	AGENT MANCHURIAN	JUDI SPACEK	11.99	0	8180
5558	8	AGENT MANNEQUIN	DANIEL CARREY	17.99	0	7816
5559	1	AGENT MARRIED	ROBIN FORD	28.99	0	5805
5560	16	AGENT MARS	LENA PFEIFFER	20.99	0	307
5561	5	AGENT MASK	JON DEE	28.99	0	9187
5562	10	AGENT MASKED	OPRAH MCQUEEN	10.99	0	1796
5563	15	AGENT MASSACRE	GLENN DEGENERES	11.99	0	5588
5564	15	AGENT MASSAGE	SISSY NICHOLSON	24.99	0	5488
5565	5	AGENT MATRIX	EWAN LOREN	27.99	0	6129
5566	15	AGENT MAUDE	ROSIE HANNAH	18.99	0	1651
5567	6	AGENT MEET	RENEE TRACY	11.99	1	5772
5568	5	AGENT MEMENTO	RIP TURNER	21.99	0	4371
5569	3	AGENT MENAGERIE	CAMERON TRACY	10.99	0	7039
5570	10	AGENT MERMAID	FAY WASHINGTON	27.99	0	3964
5571	9	AGENT METAL	RENEE REYNOLDS	16.99	0	1162
5572	9	AGENT METROPOLIS	ALAN KILMER	15.99	0	130
5573	15	AGENT MICROCOSMOS	SUSAN WALKEN	23.99	0	9338
5574	3	AGENT MIDNIGHT	ROCK PALTROW	14.99	0	4659
5575	16	AGENT MIDSUMMER	HUGH GUINESS	14.99	0	2281
5576	11	AGENT MIGHTY	WINONA RYAN	18.99	0	1778
5577	10	AGENT MILE	MINNIE MOORE	21.99	0	3561
5578	10	AGENT MILLION	FARRAH TAYLOR	19.99	0	8182
5579	8	AGENT MINDS	JULIANNE PFEIFFER	15.99	0	2986
5580	13	AGENT MINE	MENA WEST	12.99	0	9746
5581	7	AGENT MINORITY	PARKER STREEP	16.99	0	9069
5582	9	AGENT MIRACLE	KIRK TANDY	14.99	0	5387
5583	10	AGENT MISSION	HUMPHREY BALE	27.99	0	9886
5584	12	AGENT MIXED	MINNIE AFFLECK	14.99	0	7015
5585	9	AGENT MOB	MARLENE BALE	13.99	0	8529
5586	4	AGENT MOCKINGBIRD	MICHELLE LEIGH	29.99	0	9975
5587	14	AGENT MOD	SALLY HURT	18.99	0	3016
5588	16	AGENT MODEL	GRACE FREEMAN	17.99	0	8929
5589	6	AGENT MODERN	SIGOURNEY WILLIS	10.99	0	1815
5590	13	AGENT MONEY	DIANE PINKETT	18.99	0	4107
5591	5	AGENT MONSOON	WILLEM CLOSE	29.99	0	9110
5592	16	AGENT MONSTER	HENRY AKROYD	26.99	0	1235
5593	3	AGENT MONTEREY	JOAN HAYEK	19.99	0	7196
5594	7	AGENT MONTEZUMA	MEL CRAWFORD	14.99	0	8791
5595	8	AGENT MOON	LIV BEATTY	23.99	0	5787
5596	2	AGENT MOONSHINE	NICOLAS RYDER	10.99	0	8758
5597	16	AGENT MOONWALKER	SHIRLEY RUSH	16.99	0	3257
5598	8	AGENT MOSQUITO	NICOLE RUSSELL	29.99	0	5516
5599	11	AGENT MOTHER	NEVE NEESON	16.99	0	9991
5600	4	AGENT MOTIONS	ANNE HAWKE	27.99	0	5576
5601	8	AGENT MOULIN	GRETA CROWE	12.99	0	1437
5602	1	AGENT MOURNING	THORA DEGENERES	28.99	0	5640
5603	5	AGENT MOVIE	GRETA BOLGER	9.99	0	6357
5604	10	AGENT MULAN	FRED PRESLEY	15.99	0	2528
5605	5	AGENT MULHOLLAND	MARY GARLAND	16.99	0	7559
5606	15	AGENT MUMMY	UMA NEESON	14.99	0	1996
5607	7	AGENT MUPPET	JANE TYLER	15.99	0	485
5608	15	AGENT MURDER	CHARLTON BRIDGES	14.99	0	2216
5609	15	AGENT MUSCLE	WILLEM OLIVIER	12.99	1	1014
5610	8	AGENT MUSIC	JOAN DREYFUSS	11.99	0	7000
5611	14	AGENT MUSKETEERS	HALLE KINNEAR	25.99	0	2222
5612	1	AGENT MUSSOLINI	CARY DAVIS	18.99	0	9865
5613	8	AGENT MYSTIC	BURT HOFFMAN	22.99	0	2370
5614	14	AGENT NAME	TIM LOLLOBRIGIDA	26.99	0	9229
5615	16	AGENT NASH	DEBBIE DAVIS	17.99	0	8430
5616	2	AGENT NATIONAL	HENRY CRAWFORD	19.99	0	1935
5617	12	AGENT NATURAL	HUME WOOD	26.99	0	9491
5618	14	AGENT NECKLACE	HILARY VOIGHT	28.99	0	821
5619	3	AGENT NEIGHBORS	MARLON HAYEK	11.99	0	4272
5620	1	AGENT NEMO	MAE DAMON	13.99	0	9537
5621	2	AGENT NETWORK	CARY PINKETT	18.99	0	1134
5622	11	AGENT NEWSIES	BRAD WAHLBERG	10.99	0	5261
5623	1	AGENT NEWTON	JAYNE LUGOSI	17.99	0	47
5624	8	AGENT NIGHTMARE	JADA NORTON	11.99	0	6948
5625	10	AGENT NONE	SOPHIA SARANDON	13.99	0	5264
5626	3	AGENT NOON	ELVIS BRANDO	15.99	0	4806
5627	7	AGENT NORTH	HUME DEAN	19.99	0	1660
5628	1	AGENT NORTHWEST	OLYMPIA DUKAKIS	18.99	0	2711
5629	8	AGENT NOTORIOUS	WALTER COSTNER	28.99	0	7420
5630	10	AGENT NOTTING	KEVIN TEMPLE	19.99	0	5890
5631	1	AGENT NOVOCAINE	MICHELLE DEGENERES	15.99	0	2729
5632	13	AGENT NUTS	JON WASHINGTON	12.99	0	7839
5633	6	AGENT OCTOBER	BELA HORNE	11.99	0	7671
5634	6	AGENT ODDS	TOM HARRIS	15.99	0	2483
5635	2	AGENT OKLAHOMA	CARRIE TYLER	21.99	0	2071
5636	4	AGENT OLEANDER	JEFF HOPE	28.99	0	9758
5637	3	AGENT OPEN	SPENCER KAHN	23.99	0	3415
5638	8	AGENT OPERATION	RENEE BAILEY	20.99	0	7357
5639	5	AGENT OPPOSITE	CHARLIZE JOHANSSON	14.99	0	4597
5640	8	AGENT OPUS	HARRISON THERON	21.99	0	7926
5641	14	AGENT ORANGE	ED PACINO	14.99	0	9819
5642	4	AGENT ORDER	JON RUSSELL	12.99	0	1859
5643	8	AGENT ORIENT	DENZEL WALKEN	15.99	0	3479
5644	1	AGENT OSCAR	ROSIE RICKMAN	12.99	0	6626
5645	11	AGENT OTHERS	KENNETH JOLIE	9.99	0	473
5646	13	AGENT OUTBREAK	OLYMPIA WATSON	9.99	0	3623
5647	1	AGENT OUTFIELD	CHARLTON HOPKINS	19.99	0	6160
5648	12	AGENT OUTLAW	KATHARINE BOLGER	28.99	0	60
5649	5	AGENT OZ	PAUL HEPBURN	11.99	0	7842
5650	13	AGENT PACIFIC	FARRAH DENIRO	15.99	0	4012
5651	7	AGENT PACKER	GREG BENING	11.99	0	5495
5652	8	AGENT PAJAMA	ADAM CAGE	22.99	0	6107
5653	5	AGENT PANIC	MINNIE GARLAND	25.99	0	1112
5654	13	AGENT PANKY	KATHARINE LEIGH	21.99	0	1521
5655	6	AGENT PANTHER	HUGH HUDSON	22.99	0	6574
5656	1	AGENT PAPI	MIRA COSTNER	17.99	0	8278
5657	16	AGENT PARADISE	WARREN RYAN	28.99	0	6202
5658	9	AGENT PARIS	WINONA NORTON	14.99	0	2795
5659	7	AGENT PARK	RUBY DUKAKIS	28.99	0	5354
5660	2	AGENT PARTY	ADAM DEE	18.99	0	8011
5661	3	AGENT PAST	WILL WALKEN	26.99	0	2740
5662	11	AGENT PATHS	ANNETTE DERN	22.99	0	4948
5663	5	AGENT PATIENT	CLINT POSEY	14.99	0	6672
5664	9	AGENT PATRIOT	WALTER GUINESS	16.99	0	8257
5665	15	AGENT PATTON	ANNE GOODING	28.99	0	9355
5666	12	AGENT PAYCHECK	SALMA WINSLET	23.99	0	1794
5667	16	AGENT PEACH	JAMES JOLIE	9.99	0	6317
5668	9	AGENT PEAK	HELEN HACKMAN	23.99	0	3970
5669	6	AGENT PEARL	RALPH CLOSE	15.99	0	991
5670	3	AGENT PELICAN	JOE HOFFMAN	13.99	0	3326
5671	3	AGENT PERDITION	GENE BERGEN	9.99	0	1380
5672	3	AGENT PERFECT	MAE PECK	21.99	0	7784
5673	5	AGENT PERSONAL	CLARK DEPP	22.99	0	8163
5674	1	AGENT PET	WILLIAM FINNEY	26.99	0	5166
5675	15	AGENT PHANTOM	WALTER RYAN	17.99	0	3133
5676	12	AGENT PHILADELPHIA	HARVEY CAMPBELL	9.99	0	1307
5677	3	AGENT PIANIST	ROSIE FONDA	26.99	0	5766
5678	10	AGENT PICKUP	ROBERT DAFOE	25.99	0	7831
5679	10	AGENT PILOT	BRUCE TANDY	20.99	0	7483
5680	2	AGENT PINOCCHIO	KATHARINE MANSFIELD	9.99	1	5446
5681	6	AGENT PIRATES	MENA PFEIFFER	24.99	0	8374
5682	14	AGENT PITTSBURGH	CHRISTOPHER WEAVER	23.99	0	1231
5683	5	AGENT PITY	GLENN GARCIA	11.99	0	1609
5684	15	AGENT PIZZA	ALEC PFEIFFER	9.99	0	7072
5685	13	AGENT PLATOON	GARY GOODING	15.99	0	3021
5686	14	AGENT PLUTO	ALEC RUSSELL	20.99	0	7965
5687	6	AGENT POCUS	NICOLAS GUINESS	20.99	0	5111
5688	11	AGENT POLISH	SEAN GRANT	29.99	0	121
5689	3	AGENT POLLOCK	NICK HARRIS	12.99	0	334
5690	15	AGENT POND	IAN CLOSE	12.99	0	8421
5691	8	AGENT POSEIDON	LUCILLE DUKAKIS	19.99	0	1523
5692	5	AGENT POTLUCK	KATHARINE CROWE	10.99	0	6479
5693	10	AGENT POTTER	ANDY GOLDBERG	18.99	0	5441
5694	8	AGENT PREJUDICE	VIVIEN JOVOVICH	13.99	0	3592
5695	4	AGENT PRESIDENT	JULIA LANSBURY	22.99	0	9744
5696	8	AGENT PRIDE	EMILY DAY-LEWIS	11.99	0	890
5697	5	AGENT PRIMARY	ETHAN BARRYMORE	25.99	0	9955
5698	8	AGENT PRINCESS	HARRISON NEESON	19.99	0	7385
5699	1	AGENT PRIVATE	EDWARD LAW	29.99	0	9260
5700	6	AGENT PRIX	JOE WINSLET	27.99	0	2218
5701	14	AGENT PSYCHO	JEFF BOGART	11.99	0	1851
5702	4	AGENT PULP	DREW HUDSON	18.99	0	3371
5703	8	AGENT PUNK	ADRIEN PFEIFFER	26.99	0	1152
5704	10	AGENT PURE	MEG DEPP	26.99	0	4299
5705	13	AGENT PURPLE	HUMPHREY LOREN	13.99	0	217
5706	8	AGENT QUEEN	CANDICE DRIVER	27.99	0	3231
5707	2	AGENT QUEST	RALPH MALDEN	15.99	0	622
5708	11	AGENT QUILLS	RALPH KELLY	22.99	0	71
5709	13	AGENT RACER	ELVIS WEAVER	18.99	0	5008
5710	15	AGENT RAGE	BETTE KEITEL	15.99	0	5345
5711	6	AGENT RAGING	RIVER DAVIS	18.99	0	2171
5712	13	AGENT RAIDERS	RICHARD DAMON	20.99	0	8682
5713	10	AGENT RAINBOW	HILARY CROWE	17.99	0	7615
5714	7	AGENT RANDOM	MILLA MCGREGOR	22.99	0	4797
5715	3	AGENT RANGE	ADAM WINFREY	14.99	0	7627
5716	13	AGENT REAP	WILLEM LOREN	21.99	0	951
5717	14	AGENT REAR	FRED RICKMAN	22.99	0	8272
5718	8	AGENT REBEL	AL WAHLBERG	27.99	0	8627
5719	11	AGENT RECORDS	JOHNNY PENN	16.99	0	5785
5720	14	AGENT REDEMPTION	KEVIN KUDROW	26.99	0	8171
5721	10	AGENT REDS	HUGH LOREN	21.99	0	4102
5722	11	AGENT REEF	CLARK ALLEN	29.99	0	4916
5723	13	AGENT REIGN	IAN CARREY	26.99	0	7283
5724	11	AGENT REMEMBER	JEFF OLIVIER	12.99	0	8310
5725	13	AGENT REQUIEM	HARVEY TRACY	15.99	0	1775
5726	2	AGENT RESERVOIR	ORLANDO GARBO	19.99	0	9503
5727	15	AGENT RESURRECTION	WARREN MCGREGOR	11.99	0	6098
5728	10	AGENT REUNION	OPRAH HAWN	9.99	0	7946
5729	12	AGENT RIDER	JOHN WAHLBERG	12.99	0	5481
5730	1	AGENT RIDGEMONT	JEFF SWANK	17.99	0	1973
5731	10	AGENT RIGHT	KEVIN DRIVER	16.99	0	4990
5732	5	AGENT RINGS	CARRIE PINKETT	14.99	0	7337
5733	14	AGENT RIVER	CHARLTON HOPE	21.99	0	3913
5734	7	AGENT ROAD	GEOFFREY DAFOE	27.99	0	4168
5735	8	AGENT ROBBERS	ETHAN HAWKE	27.99	0	4359
5736	2	AGENT ROBBERY	MORGAN GRANT	22.99	0	5297
5737	3	AGENT ROCK	EMILY ALLEN	14.99	0	1162
5738	1	AGENT ROCKETEER	KIRSTEN BRODY	12.99	0	269
5739	9	AGENT ROCKY	DORIS CARREY	27.99	0	6218
5740	5	AGENT ROLLERCOASTER	ALICIA JOHANSSON	20.99	0	8438
5741	16	AGENT ROMAN	DREW JACKMAN	23.99	0	9540
5742	4	AGENT ROOF	WARREN DRIVER	19.99	0	2261
5743	11	AGENT ROOM	GREGORY LEIGH	13.99	0	875
5744	4	AGENT ROOTS	DUSTIN DOUGLAS	18.99	0	2864
5745	2	AGENT ROSES	PENELOPE HECHE	11.99	0	1797
5746	16	AGENT ROUGE	MATT WINFREY	12.99	0	8097
5747	3	AGENT ROXANNE	BRAD WALKEN	11.99	0	6596
5748	6	AGENT RUGRATS	DORIS BERGEN	23.99	0	9563
5749	13	AGENT RULES	DREW HUSTON	29.99	0	3772
5750	5	AGENT RUN	RENEE AFFLECK	10.99	0	7839
5751	4	AGENT RUNAWAY	OPRAH BASINGER	28.99	0	4422
5752	12	AGENT RUNNER	HARRISON GARLAND	26.99	0	8122
5753	8	AGENT RUSH	SHIRLEY RUSSELL	23.99	0	1416
5754	11	AGENT RUSHMORE	LIZA DAY	27.99	0	5525
5755	5	AGENT SABRINA	KEVIN JOHANSSON	10.99	0	6597
5756	14	AGENT SADDLE	MINNIE SARANDON	22.99	0	9465
5757	2	AGENT SAGEBRUSH	GENE HOPKINS	18.99	0	7746
5758	4	AGENT SAINTS	KIRK PRESLEY	11.99	0	181
5759	5	AGENT SALUTE	DUSTIN CAINE	27.99	0	4485
5760	8	AGENT SAMURAI	UMA FIENNES	29.99	0	5065
5761	11	AGENT SANTA	GEOFFREY DICAPRIO	16.99	0	399
5762	6	AGENT SASSY	JOHNNY WEST	22.99	0	7650
5763	7	AGENT SATISFACTION	JULIANNE MCQUEEN	29.99	0	9924
5764	16	AGENT SATURDAY	CARY BALE	13.99	0	1702
5765	11	AGENT SATURN	JOHN GIBSON	21.99	0	8906
5766	2	AGENT SAVANNAH	CHEVY BACALL	18.99	0	472
5767	8	AGENT SCALAWAG	ADAM PESCI	29.99	0	3905
5768	12	AGENT SCARFACE	ALEC PRESLEY	14.99	0	7940
5769	4	AGENT SCHOOL	ROBERT PACINO	16.99	0	7584
5770	9	AGENT SCISSORHANDS	CARY LUGOSI	9.99	0	5033
5771	15	AGENT SCORPION	KARL FIENNES	10.99	0	9349
5772	3	AGENT SEA	MARLENE DAY-LEWIS	11.99	0	52
5773	9	AGENT SEABISCUIT	ORLANDO TYLER	20.99	0	4806
5774	6	AGENT SEARCHERS	CLINT HARRIS	12.99	0	1061
5775	15	AGENT SEATTLE	MERYL FINNEY	10.99	0	8949
5776	10	AGENT SECRET	DENNIS DOUGLAS	11.99	0	9623
5777	1	AGENT SECRETARY	CLINT IRONS	23.99	0	3700
5778	12	AGENT SECRETS	FARRAH CAINE	18.99	0	4473
5779	15	AGENT SENSE	RUSSELL BACALL	11.99	0	6348
5780	4	AGENT SENSIBILITY	WALTER BULLOCK	28.99	0	3151
5781	14	AGENT SEVEN	LEELEE POSEY	9.99	0	9558
5782	16	AGENT SHAKESPEARE	JAYNE THERON	12.99	0	631
5783	9	AGENT SHANE	DARYL DIAZ	26.99	0	8861
5784	5	AGENT SHANGHAI	STEVE MONROE	11.99	0	1108
5785	13	AGENT SHAWSHANK	DUSTIN WRAY	24.99	0	4276
5786	1	AGENT SHEPHERD	CLINT PESCI	22.99	0	328
5787	10	AGENT SHINING	SUSAN PINKETT	9.99	0	4886
5788	2	AGENT SHIP	OLYMPIA HOPKINS	15.99	0	4699
5789	3	AGENT SHOCK	CARMEN LANCASTER	10.99	0	8882
5790	4	AGENT SHOOTIST	SEAN HOFFMAN	18.99	0	7894
5791	14	AGENT SHOW	JUDY CRUZ	10.99	0	2616
5792	2	AGENT SHREK	ZERO HAWKE	9.99	0	9079
5793	8	AGENT SHRUNK	GROUCHO KILMER	14.99	0	6377
5794	12	AGENT SIDE	CUBA ALLEN	26.99	0	8667
5795	12	AGENT SIEGE	GARY FIELD	21.99	0	4680
5796	7	AGENT SIERRA	MARY MCGREGOR	27.99	0	4919
5797	3	AGENT SILENCE	SPENCER REYNOLDS	12.99	0	3499
5798	2	AGENT SILVERADO	SIDNEY DEPP	18.99	0	7220
5799	2	AGENT SIMON	NICK DAMON	14.99	0	8446
5800	2	AGENT SINNERS	CHEVY REYNOLDS	18.99	0	9125
5801	15	AGENT SISTER	KATE POSEY	20.99	0	2156
5802	1	AGENT SKY	WILLEM SINATRA	29.99	0	7407
5803	5	AGENT SLACKER	WOODY BASINGER	13.99	0	4898
5804	15	AGENT SLEEPING	MICHAEL LANCASTER	22.99	0	7398
5805	9	AGENT SLEEPLESS	JUDE WALKEN	22.99	0	8651
5806	10	AGENT SLEEPY	LIV DERN	11.99	0	2732
5807	6	AGENT SLEUTH	BOB TAYLOR	15.99	0	743
5808	1	AGENT SLING	CARRIE CAMPBELL	9.99	0	6087
5809	9	AGENT SLIPPER	CHEVY DIAZ	13.99	0	9655
5810	16	AGENT SLUMS	SISSY HAYEK	18.99	0	2548
5811	6	AGENT SMILE	JUDY MIRANDA	28.99	0	3329
5812	4	AGENT SMOKING	DEBBIE BIRCH	15.99	0	425
5813	7	AGENT SMOOCHY	CUBA HECHE	19.99	0	5293
5814	2	AGENT SNATCH	RAY WOOD	14.99	0	7111
5815	4	AGENT SNATCHERS	CARY CRAWFORD	12.99	0	2100
5816	7	AGENT SNOWMAN	SALLY WINSLET	28.99	0	6173
5817	4	AGENT SOLDIERS	MICHAEL CARREY	18.99	0	838
5818	8	AGENT SOMETHING	JUDY SUVARI	23.99	0	9734
5819	4	AGENT SONG	WARREN JACKMAN	9.99	0	1760
5820	12	AGENT SONS	GRETA ASTAIRE	26.99	0	9976
5821	1	AGENT SORORITY	WILL LAW	28.99	0	8975
5822	9	AGENT SOUP	ANGELA PENN	13.99	0	5065
5823	6	AGENT SOUTH	GROUCHO MOSTEL	26.99	0	7241
5824	13	AGENT SPARTACUS	DENNIS LANCASTER	24.99	0	9882
5825	15	AGENT SPEAKEASY	ADRIEN DICAPRIO	15.99	0	1752
5826	5	AGENT SPEED	NICK CLOSE	14.99	0	2127
5827	3	AGENT SPICE	TIM MARX	13.99	0	990
5828	12	AGENT SPIKING	ORLANDO CHAPLIN	10.99	0	1041
5829	13	AGENT SPINAL	MARLON ROBBINS	9.99	0	2108
5830	16	AGENT SPIRIT	JODIE HUDSON	9.99	0	5883
5831	3	AGENT SPIRITED	OLYMPIA BARRYMORE	28.99	0	8312
5832	3	AGENT SPLASH	JANE HORNE	10.99	0	2781
5833	3	AGENT SPLENDOR	JAMES GIBSON	28.99	0	4068
5834	1	AGENT SPOILERS	CLINT DEAN	23.99	0	7147
5835	15	AGENT SPY	CLINT DEAN	16.99	0	9441
5836	16	AGENT SQUAD	WOODY HARRIS	23.99	0	2970
5837	9	AGENT STAGE	ORLANDO HOPKINS	29.99	0	4262
5838	5	AGENT STAGECOACH	REESE NEESON	23.99	0	2391
5839	2	AGENT STALLION	JIM MATTHAU	14.99	0	7018
5840	16	AGENT STAMPEDE	THORA CRONYN	12.99	0	1562
5841	2	AGENT STAR	KIRK JOVOVICH	11.99	0	8846
5842	7	AGENT STATE	GRACE PRESLEY	12.99	0	8462
5843	10	AGENT STEEL	JUDY ZELLWEGER	17.99	0	1024
5844	11	AGENT STEERS	MINNIE RUSH	11.99	0	49
5845	13	AGENT STEPMOM	CUBA BARRYMORE	24.99	0	7373
5846	15	AGENT STING	ED FOSTER	18.99	0	4604
5847	6	AGENT STOCK	DENZEL SWANK	23.99	0	9554
5848	9	AGENT STONE	VIVIEN MCDORMAND	9.99	0	6366
5849	3	AGENT STORM	INGRID MIRANDA	26.99	0	4740
5850	14	AGENT STORY	JULIANNE LANCASTER	9.99	0	7449
5851	13	AGENT STRAIGHT	BETTE COOPER	9.99	0	5403
5852	8	AGENT STRANGELOVE	HUME WEST	23.99	0	4279
5853	11	AGENT STRANGER	ANGELINA CAGE	21.99	0	645
5854	4	AGENT STRANGERS	MINNIE DUNST	22.99	0	4612
5855	3	AGENT STREAK	AL WRAY	22.99	0	2945
5856	7	AGENT STREETCAR	JESSICA SARANDON	19.99	0	800
5857	1	AGENT STRICTLY	ALICIA EASTWOOD	17.99	0	6501
5858	14	AGENT SUBMARINE	PENELOPE MONROE	27.99	0	9496
5859	16	AGENT SUGAR	EDWARD JOHANSSON	23.99	0	3892
5860	3	AGENT SUICIDES	HELEN DRIVER	12.99	0	4137
5861	8	AGENT SUIT	DENZEL FORD	28.99	0	443
5862	16	AGENT SUMMER	GREGORY STREEP	9.99	0	3489
5863	11	AGENT SUN	ADAM BULLOCK	18.99	0	2584
5864	7	AGENT SUNDANCE	OPRAH ZELLWEGER	22.99	0	9093
5865	1	AGENT SUNRISE	DAN SINATRA	17.99	0	1329
5866	14	AGENT SUNSET	JIM HAWN	10.99	0	2902
5867	2	AGENT SUPER	CATE FIENNES	18.99	0	4095
5868	13	AGENT SUPERFLY	KATE ALLEN	25.99	0	5644
5869	1	AGENT SUSPECTS	KIRK TAYLOR	26.99	0	2367
5870	12	AGENT SWARM	ANJELICA LEIGH	28.99	1	239
5871	1	AGENT SWEDEN	JAYNE SOBIESKI	19.99	0	7711
5872	13	AGENT SWEET	BOB WOOD	28.99	0	4312
5873	6	AGENT SWEETHEARTS	JAYNE DEE	27.99	0	9104
5874	8	AGENT TADPOLE	PENELOPE BLOOM	9.99	0	3085
5875	5	AGENT TALENTED	SCARLETT MCGREGOR	15.99	0	8648
5876	6	AGENT TARZAN	MERYL MANSFIELD	25.99	0	5768
5877	9	AGENT TAXI	KIRK WAHLBERG	22.99	0	9977
5878	2	AGENT TEEN	DREW DEAN	19.99	0	2645
5879	7	AGENT TELEGRAPH	GROUCHO LEWIS	13.99	0	2619
5880	9	AGENT TELEMARK	SIDNEY STALLONE	17.99	0	4355
5881	4	AGENT TEMPLE	ALICIA HURT	28.99	0	1458
5882	9	AGENT TENENBAUMS	ANTHONY RYAN	10.99	0	9400
5883	2	AGENT TEQUILA	CHRISTIAN JACKMAN	15.99	0	2830
5884	10	AGENT TERMINATOR	SALLY HAWN	28.99	0	4447
5885	4	AGENT TEXAS	FAY BULLOCK	10.99	0	4348
5886	9	AGENT THEORY	STEVE REYNOLDS	20.99	0	1639
5887	12	AGENT THIEF	WALTER DAY-LEWIS	25.99	0	3857
5888	12	AGENT THIN	SEAN GOODING	27.99	0	8791
5889	3	AGENT TIES	FRANK DICAPRIO	9.99	0	9177
5890	8	AGENT TIGHTS	ANGELINA GRANT	24.99	0	5619
5891	3	AGENT TIMBERLAND	GLENN WOOD	10.99	0	308
5892	5	AGENT TITANIC	ELIZABETH DEE	13.99	1	5587
5893	10	AGENT TITANS	UMA OLIVIER	18.99	0	6336
5894	6	AGENT TOMATOES	SISSY PESCI	22.99	0	960
5895	10	AGENT TOMORROW	JOE CRONYN	21.99	0	9548
5896	3	AGENT TOOTSIE	UMA BOGART	19.99	0	4789
5897	9	AGENT TORQUE	MILLA HESTON	25.99	0	7040
5898	6	AGENT TOURIST	HUME DEGENERES	15.99	0	9705
5899	15	AGENT TOWERS	MERYL BERGEN	26.99	0	4207
5900	15	AGENT TOWN	LEONARDO DREYFUSS	17.99	0	5252
5901	6	AGENT TRACY	LIZA BERGMAN	15.99	0	8056
5902	13	AGENT TRADING	ED BRANDO	19.99	0	8853
5903	4	AGENT TRAFFIC	CARMEN DENCH	21.99	0	8374
5904	10	AGENT TRAIN	SOPHIA HOPKINS	14.99	0	6177
5905	11	AGENT TRAINSPOTTING	SOPHIA CROWE	14.99	0	7986
5906	13	AGENT TRAMP	SCARLETT WEAVER	17.99	0	4509
5907	4	AGENT TRANSLATION	KIRK ASTAIRE	18.99	0	4592
5908	6	AGENT TRAP	MICHELLE OLIVIER	19.99	0	2343
5909	6	AGENT TREASURE	MENA SUVARI	13.99	0	9592
5910	14	AGENT TREATMENT	CHARLIZE RUSH	24.99	0	7381
5911	9	AGENT TRIP	MEL TANDY	17.99	0	9266
5912	14	AGENT TROJAN	VAL KEATON	17.99	0	4529
5913	15	AGENT TROOPERS	CHARLIZE FREEMAN	21.99	0	4381
5914	14	AGENT TROUBLE	FAY CARREY	19.99	0	3960
5915	8	AGENT TRUMAN	CLARK DAMON	21.99	0	2363
5916	6	AGENT TURN	BRAD HUSTON	9.99	0	3864
5917	16	AGENT TUXEDO	SOPHIA PRESLEY	28.99	0	8936
5918	6	AGENT TWISTED	DUSTIN BENING	19.99	0	665
5919	16	AGENT TYCOON	DENNIS HUDSON	13.99	0	5788
5920	11	AGENT UNBREAKABLE	PENELOPE HESTON	26.99	0	7289
5921	1	AGENT UNCUT	DENNIS HANNAH	12.99	0	1054
5922	9	AGENT UNDEFEATED	SALMA HANNAH	18.99	0	411
5923	6	AGENT UNFAITHFUL	BRUCE NEESON	20.99	0	7512
5924	11	AGENT UNFORGIVEN	DENZEL BULLOCK	26.99	0	1928
5925	7	AGENT UNITED	MADELINE AFFLECK	13.99	0	6852
5926	16	AGENT UNTOUCHABLES	BETTE SWANK	12.99	0	5293
5927	5	AGENT UPRISING	TIM KILMER	11.99	0	2394
5928	3	AGENT UPTOWN	SPENCER EASTWOOD	14.99	0	893
5929	1	AGENT USUAL	DENZEL JOVOVICH	13.99	0	5835
5930	7	AGENT VACATION	LAUREN RUSH	10.99	1	3945
5931	12	AGENT VALENTINE	ELIZABETH WATSON	26.99	0	2569
5932	6	AGENT VALLEY	RAY FOSTER	15.99	0	7670
5933	9	AGENT VAMPIRE	AUDREY MCDORMAND	18.99	0	9443
5934	9	AGENT VANILLA	JENNIFER TORN	24.99	0	8119
5935	6	AGENT VANISHED	LENA LANCASTER	28.99	0	5926
5936	5	AGENT VANISHING	JULIETTE GABLE	20.99	0	6152
5937	14	AGENT VARSITY	WALTER KUDROW	21.99	0	4202
5938	7	AGENT VELVET	ANGELA GARLAND	18.99	0	9238
5939	7	AGENT VERTIGO	RIVER FORD	26.99	0	9491
5940	11	AGENT VICTORY	JUDE HAWN	14.99	0	1143
5941	14	AGENT VIDEOTAPE	JIM MCQUEEN	16.99	0	6537
5942	16	AGENT VIETNAM	DARYL ANISTON	28.99	0	397
5943	6	AGENT VILLAIN	HUMPHREY AKROYD	17.99	0	2196
5944	6	AGENT VIRGIN	KIM STREEP	12.99	0	6455
5945	2	AGENT VIRGINIAN	ANNETTE GABLE	21.99	0	3927
5946	12	AGENT VIRTUAL	ALICIA HOPPER	12.99	0	2310
5947	14	AGENT VISION	EDWARD SOBIESKI	9.99	0	8767
5948	2	AGENT VOICE	SHIRLEY CARREY	19.99	0	3389
5949	12	AGENT VOLCANO	CUBA TOMEI	14.99	0	8833
5950	15	AGENT VOLUME	DUSTIN CHAPLIN	29.99	0	8480
5951	6	AGENT VOYAGE	GARY HUSTON	17.99	0	1408
5952	11	AGENT WAGON	WHOOPI KAHN	27.99	0	7431
5953	13	AGENT WAIT	SIDNEY MINELLI	22.99	0	4474
5954	16	AGENT WAKE	GRACE STREEP	12.99	0	3877
5955	1	AGENT WALLS	KATE BAILEY	15.99	0	2986
5956	3	AGENT WANDA	PEARL GOODING	18.99	0	4492
5957	10	AGENT WAR	WARREN HAYEK	20.99	0	5191
5958	5	AGENT WARDROBE	CHEVY BENING	12.99	0	2929
5959	11	AGENT WARLOCK	CATE NORTON	29.99	0	2560
5960	6	AGENT WARS	FRANCES TURNER	27.99	0	3036
5961	4	AGENT WASH	MENA FONDA	29.99	0	4767
5962	7	AGENT WASTELAND	SISSY GARCIA	17.99	0	2031
5963	15	AGENT WATCH	EMILY DAMON	10.99	0	9719
5964	6	AGENT WATERFRONT	MARLON BACALL	19.99	1	5137
5965	13	AGENT WATERSHIP	JACK GARBO	9.99	0	6178
5966	6	AGENT WEDDING	VIVIEN HOPKINS	9.99	0	7311
5967	9	AGENT WEEKEND	BOB SUVARI	17.99	0	92
5968	10	AGENT WEREWOLF	DENZEL CARREY	27.99	0	6126
5969	14	AGENT WEST	MAE LOLLOBRIGIDA	19.99	0	6353
5970	1	AGENT WESTWARD	WOODY SOBIESKI	18.99	0	2470
5971	2	AGENT WHALE	MICHAEL DAY	9.99	0	1286
5972	12	AGENT WHISPERER	WILLIAM RICKMAN	26.99	0	2260
5973	14	AGENT WIFE	HARVEY RYAN	10.99	0	5918
5974	11	AGENT WILD	CHRISTIAN KELLY	15.99	0	2405
5975	16	AGENT WILLOW	ANTHONY BERGEN	28.99	0	9390
5976	4	AGENT WIND	CHEVY LEWIS	27.99	0	4136
5977	1	AGENT WINDOW	CLINT FORD	9.99	0	3623
5978	4	AGENT WISDOM	CHEVY BACALL	21.99	0	8333
5979	4	AGENT WITCHES	GWYNETH RUSH	16.99	0	4027
5980	10	AGENT WIZARD	JIM BEATTY	23.99	0	9794
5981	10	AGENT WOLVES	KEVIN CRUZ	25.99	0	1451
5982	3	AGENT WOMEN	JOE BRANDO	16.99	0	6622
5983	12	AGENT WON	MERYL FREEMAN	27.99	0	7909
5984	12	AGENT WONDERFUL	LANA CHAPLIN	10.99	0	6723
5985	8	AGENT WONDERLAND	NATALIE BRODY	28.99	0	7308
5986	15	AGENT WONKA	THORA HAWKE	19.99	0	171
5987	11	AGENT WORDS	CARRIE GARLAND	11.99	0	2453
5988	13	AGENT WORKER	LEELEE HORNE	18.99	0	5471
5989	5	AGENT WORKING	MICHAEL BERGEN	26.99	0	2180
5990	9	AGENT WORLD	GREG MCKELLEN	13.99	0	1401
5991	16	AGENT WORST	KEVIN KAHN	27.99	0	7318
5992	15	AGENT WRATH	BRAD MCKELLEN	9.99	0	8294
5993	5	AGENT WRONG	FRANCES KEATON	27.99	0	6366
5994	7	AGENT WYOMING	MICHELLE DENIRO	11.99	0	8493
5995	6	AGENT YENTL	JOE LOLLOBRIGIDA	23.99	0	636
5996	14	AGENT YOUNG	LAURA RICKMAN	16.99	0	5783
5997	2	AGENT YOUTH	DEBBIE LAW	13.99	0	9532
5998	1	AGENT ZHIVAGO	JOAN TAYLOR	15.99	0	4603
5999	16	AGENT ZOOLANDER	MILLA CLOSE	22.99	0	7811
6000	9	AGENT ZORRO	GROUCHO MCCONAUGHEY	29.99	0	1659
6001	1	AIRPLANE ACADEMY	TIM BRIDGES	22.99	0	5905
6002	4	AIRPLANE ACE	CHARLTON LUGOSI	17.99	0	7472
6003	6	AIRPLANE ADAPTATION	LIZA SILVERSTONE	26.99	0	3674
6004	5	AIRPLANE AFFAIR	KARL BIRCH	9.99	0	8156
6005	13	AIRPLANE AFRICAN	JANE DENIRO	12.99	0	7337
6006	5	AIRPLANE AGENT	RUSSELL DREYFUSS	14.99	0	3365
6007	14	AIRPLANE AIRPLANE	SYLVESTER BRIDGES	29.99	0	7082
6008	12	AIRPLANE AIRPORT	JULIANNE TORN	16.99	0	6507
6009	12	AIRPLANE ALABAMA	NEVE BALE	14.99	0	4753
6010	2	AIRPLANE ALADDIN	MORGAN SORVINO	19.99	0	9532
6011	4	AIRPLANE ALAMO	DREW DUKAKIS	10.99	0	1438
6012	7	AIRPLANE ALASKA	ELLEN GOLDBERG	16.99	0	7887
6013	1	AIRPLANE ALI	MENA BOLGER	21.99	0	4251
6014	4	AIRPLANE ALICE	JESSICA CRONYN	29.99	0	5114
6015	8	AIRPLANE ALIEN	GREGORY KAHN	12.99	0	3265
6016	2	AIRPLANE ALLEY	LIV DERN	16.99	0	1585
6017	8	AIRPLANE ALONE	KARL ROBERTS	24.99	0	8988
6018	9	AIRPLANE ALTER	ZERO CROWE	13.99	0	4561
6019	11	AIRPLANE AMADEUS	MAE AFFLECK	11.99	0	761
6020	11	AIRPLANE AMELIE	LAURENCE HARRIS	29.99	0	6050
6021	5	AIRPLANE AMERICAN	SALMA NOLTE	28.99	0	2155
6022	2	AIRPLANE AMISTAD	WOODY KELLY	21.99	0	1252
6023	9	AIRPLANE ANACONDA	GEOFFREY SMITH	19.99	0	853
6024	16	AIRPLANE ANALYZE	BETTE PACINO	21.99	0	526
6025	11	AIRPLANE ANGELS	JEREMY HOPE	14.99	0	290
6026	14	AIRPLANE ANNIE	MINNIE PESCI	24.99	0	7476
6027	16	AIRPLANE ANONYMOUS	EWAN PESCI	28.99	0	5555
6028	2	AIRPLANE ANTHEM	HARVEY STREEP	17.99	0	4254
6029	8	AIRPLANE ANTITRUST	CARRIE FINNEY	20.99	0	9451
6030	10	AIRPLANE ANYTHING	HILARY MARX	10.99	0	8140
6031	2	AIRPLANE APACHE	KATE POITIER	26.99	0	1790
6032	9	AIRPLANE APOCALYPSE	SOPHIA HEPBURN	26.99	0	2343
6033	7	AIRPLANE APOLLO	BEN HOPKINS	25.99	0	4366
6034	4	AIRPLANE ARABIA	OPRAH FIELD	15.99	0	6867
6035	5	AIRPLANE ARACHNOPHOBIA	FRANCES HURT	22.99	0	1688
6036	8	AIRPLANE ARGONAUTS	SUSAN MIRANDA	9.99	0	3983
6037	3	AIRPLANE ARIZONA	ROBIN ASTAIRE	10.99	0	2142
6038	6	AIRPLANE ARK	MATT DENIRO	17.99	0	5063
6039	14	AIRPLANE ARMAGEDDON	RITA DAVIS	21.99	0	6871
6040	5	AIRPLANE ARMY	CHRISTIAN RYAN	21.99	0	7173
6041	12	AIRPLANE ARSENIC	HALLE WAHLBERG	22.99	0	8292
6042	1	AIRPLANE ARTIST	RUSSELL BRIDGES	27.99	0	7100
6043	2	AIRPLANE ATLANTIS	WALTER KEITEL	25.99	0	9762
6044	5	AIRPLANE ATTACKS	CUBA REYNOLDS	11.99	0	7160
6045	13	AIRPLANE ATTRACTION	JUDY MINELLI	28.99	0	9619
6046	11	AIRPLANE AUTUMN	SHIRLEY WILLIS	9.99	0	8139
6047	14	AIRPLANE BABY	THORA NORTON	24.99	0	1320
6048	7	AIRPLANE BACKLASH	MARLENE NORTON	17.99	0	5783
6049	6	AIRPLANE BADMAN	GRACE PINKETT	20.99	0	6967
6050	5	AIRPLANE BAKED	GRACE MCDORMAND	25.99	0	5559
6051	12	AIRPLANE BALLOON	JULIANNE DENCH	22.99	0	1463
6052	7	AIRPLANE BALLROOM	ROBIN CAMPBELL	16.99	0	4105
6053	8	AIRPLANE BANG	BRAD DRIVER	12.99	0	5549
6054	12	AIRPLANE BANGER	FRANCES BAILEY	10.99	0	1308
6055	13	AIRPLANE BARBARELLA	OLYMPIA STREEP	11.99	0	3254
6056	11	AIRPLANE BAREFOOT	KIRSTEN GARBO	12.99	0	8450
6057	6	AIRPLANE BASIC	WINONA HAWKE	12.99	0	8469
6058	10	AIRPLANE BEACH	CARY DIETRICH	22.99	0	8045
6059	4	AIRPLANE BEAR	ROCK CHAPLIN	19.99	0	4203
6060	11	AIRPLANE BEAST	EMILY WOOD	17.99	0	8876
6061	12	AIRPLANE BEAUTY	EDWARD POITIER	15.99	0	2233
6062	3	AIRPLANE BED	MAE DEPP	11.99	0	4133
6063	16	AIRPLANE BEDAZZLED	MENA WINSLET	11.99	0	1111
6064	15	AIRPLANE BEETHOVEN	ELVIS SWANK	24.99	0	4867
6065	3	AIRPLANE BEHAVIOR	JOAN ALLEN	18.99	0	5634
6066	6	AIRPLANE BENEATH	GENE BULLOCK	20.99	0	2380
6067	13	AIRPLANE BERETS	JOHN KUDROW	17.99	0	8982
6068	14	AIRPLANE BETRAYED	SCARLETT MCKELLEN	19.99	0	5131
6069	11	AIRPLANE BEVERLY	HALLE MCQUEEN	27.99	0	7389
6070	7	AIRPLANE BIKINI	OLYMPIA KINNEAR	26.99	0	1569
6071	7	AIRPLANE BILKO	FARRAH DRIVER	24.99	0	6977
6072	16	AIRPLANE BILL	ED MCKELLEN	18.99	0	9109
6073	6	AIRPLANE BINGO	KATHARINE THURMAN	13.99	0	2776
6074	12	AIRPLANE BIRCH	STEVE BALL	11.99	0	2942
6075	14	AIRPLANE BIRD	ROCK FINNEY	21.99	0	8069
6076	13	AIRPLANE BIRDCAGE	BOB MANSFIELD	9.99	0	9432
6077	12	AIRPLANE BIRDS	LAURA EASTWOOD	29.99	0	6317
6078	15	AIRPLANE BLACKOUT	JULIANNE BRIDGES	18.99	0	9306
6079	12	AIRPLANE BLADE	WILL BLOOM	22.99	0	9111
6080	15	AIRPLANE BLANKET	DREW BENING	25.99	0	4120
6081	10	AIRPLANE BLINDNESS	AL HECHE	22.99	0	3423
6082	10	AIRPLANE BLOOD	MARILYN DAVIS	12.99	0	4029
6083	14	AIRPLANE BLUES	JULIANNE BLOOM	16.99	0	8689
6084	5	AIRPLANE BOILED	WARREN DEPP	14.99	0	1696
6085	3	AIRPLANE BONNIE	DREW SILVERSTONE	17.99	0	8952
6086	13	AIRPLANE BOOGIE	GINA CARREY	25.99	0	7898
6087	3	AIRPLANE BOONDOCK	ADAM HAYEK	25.99	0	1978
6088	4	AIRPLANE BORN	FRANCES HAYEK	24.99	0	8262
6089	10	AIRPLANE BORROWERS	BELA BACALL	20.99	0	9666
6090	12	AIRPLANE BOULEVARD	PENELOPE HAWN	28.99	0	3592
6091	14	AIRPLANE BOUND	JUDI MANSFIELD	12.99	0	3212
6092	16	AIRPLANE BOWFINGER	NICOLAS LANCASTER	28.99	0	3484
6093	3	AIRPLANE BRANNIGAN	PAUL KINNEAR	18.99	0	5304
6094	5	AIRPLANE BRAVEHEART	KIM STALLONE	16.99	0	8245
6095	6	AIRPLANE BREAKFAST	ED BOLGER	10.99	0	443
6096	8	AIRPLANE BREAKING	MARILYN THURMAN	29.99	0	466
6097	5	AIRPLANE BRIDE	LEONARDO AFFLECK	9.99	0	9468
6098	6	AIRPLANE BRIGHT	JOHN BOLGER	12.99	0	7445
6099	11	AIRPLANE BRINGING	LAUREN SILVERSTONE	13.99	0	9712
6100	1	AIRPLANE BROOKLYN	AUDREY HUNT	15.99	0	1209
6101	6	AIRPLANE BROTHERHOOD	ADRIEN ASTAIRE	29.99	0	604
6102	1	AIRPLANE BUBBLE	ANNETTE DICAPRIO	22.99	0	164
6103	10	AIRPLANE BUCKET	CARMEN MOSTEL	10.99	0	6656
6104	13	AIRPLANE BUGSY	JODIE HUSTON	17.99	0	6379
6105	6	AIRPLANE BULL	CAMERON ROBBINS	18.99	0	6793
6106	9	AIRPLANE BULWORTH	MICHELLE HAWKE	20.99	0	6849
6107	11	AIRPLANE BUNCH	VIVIEN HEPBURN	23.99	0	2427
6108	12	AIRPLANE BUTCH	SPENCER MINELLI	26.99	0	7168
6109	8	AIRPLANE BUTTERFLY	DARYL KEATON	29.99	0	9168
6110	10	AIRPLANE CABIN	MENA DREYFUSS	24.99	0	7606
6111	7	AIRPLANE CADDYSHACK	CLARK DREYFUSS	11.99	0	5746
6112	13	AIRPLANE CALENDAR	ADRIEN IRONS	24.99	0	686
6113	16	AIRPLANE CALIFORNIA	MINNIE THURMAN	27.99	0	4191
6114	10	AIRPLANE CAMELOT	TOM DAY	25.99	0	8548
6115	12	AIRPLANE CAMPUS	CATE SANDLER	17.99	0	8610
6116	3	AIRPLANE CANDIDATE	CHARLIZE WALKEN	16.99	0	3
6117	15	AIRPLANE CANDLES	JOHN SINATRA	28.99	0	6661
6118	16	AIRPLANE CANYON	KIM KILMER	23.99	0	2753
6119	3	AIRPLANE CAPER	JOHNNY BALE	10.99	0	6800
6120	15	AIRPLANE CARIBBEAN	JOE LEIGH	10.99	0	50
6121	15	AIRPLANE CAROL	TIM CHAPLIN	10.99	0	9608
6122	2	AIRPLANE CARRIE	PEARL HECHE	20.99	0	3361
6123	4	AIRPLANE CASABLANCA	SEAN GABLE	25.99	0	3047
6124	1	AIRPLANE CASPER	GREG CROWE	20.99	0	1831
6125	4	AIRPLANE CASSIDY	NICOLE COSTNER	23.99	0	7294
6126	12	AIRPLANE CASUALTIES	SHIRLEY CHAPLIN	22.99	0	3848
6127	10	AIRPLANE CAT	RIP DOUGLAS	16.99	0	1644
6128	12	AIRPLANE CATCH	JULIA BARRYMORE	21.99	0	5754
6129	15	AIRPLANE CAUSE	ORLANDO TAUTOU	13.99	0	140
6130	7	AIRPLANE CELEBRITY	CUBA MCGREGOR	12.99	0	4176
6131	15	AIRPLANE CENTER	KIRSTEN BACALL	25.99	0	7826
6132	3	AIRPLANE CHAINSAW	ANNETTE DIAZ	29.99	0	8927
6133	3	AIRPLANE CHAMBER	UMA FREEMAN	22.99	0	7608
6134	4	AIRPLANE CHAMPION	LUCILLE SOBIESKI	29.99	0	361
6135	1	AIRPLANE CHANCE	MARY HUNT	12.99	0	9865
6136	10	AIRPLANE CHAPLIN	ALAN KELLY	12.99	0	6811
6137	16	AIRPLANE CHARADE	UMA HUDSON	9.99	0	5791
6138	15	AIRPLANE CHARIOTS	THORA LEWIS	26.99	0	8607
6139	10	AIRPLANE CHASING	MENA HOPKINS	14.99	0	7430
6140	5	AIRPLANE CHEAPER	DENNIS HOFFMAN	28.99	0	8505
6141	15	AIRPLANE CHICAGO	HARVEY DEGENERES	28.99	0	6860
6142	10	AIRPLANE CHICKEN	CHARLTON GIBSON	20.99	0	5915
6143	3	AIRPLANE CHILL	CHRISTIAN EASTWOOD	10.99	0	3912
6144	15	AIRPLANE CHINATOWN	ROSIE RICKMAN	21.99	0	2850
6145	6	AIRPLANE CHISUM	NATALIE DRIVER	21.99	0	3618
6146	7	AIRPLANE CHITTY	LEONARDO CHAPLIN	25.99	0	159
6147	8	AIRPLANE CHOCOLAT	HENRY PENN	22.99	0	7777
6148	4	AIRPLANE CHOCOLATE	BELA HECHE	17.99	0	2343
6149	13	AIRPLANE CHRISTMAS	ADAM HEPBURN	22.99	0	112
6150	15	AIRPLANE CIDER	FRANK HAWKE	22.99	0	5259
6151	1	AIRPLANE CINCINATTI	MEG HAWKE	21.99	0	7744
6152	11	AIRPLANE CIRCUS	JOHNNY PALTROW	9.99	0	7769
6153	13	AIRPLANE CITIZEN	DEBBIE MALDEN	27.99	1	7056
6154	2	AIRPLANE CLASH	CATE RUSSELL	11.99	0	1875
6155	2	AIRPLANE CLEOPATRA	LENA FOSTER	17.99	1	5846
6156	16	AIRPLANE CLERKS	ZERO AKROYD	22.99	0	2149
6157	7	AIRPLANE CLOCKWORK	SYLVESTER DENIRO	27.99	0	2795
6158	11	AIRPLANE CLONES	SCARLETT BENING	27.99	0	8635
6159	10	AIRPLANE CLOSER	MARISA BALL	24.99	0	720
6160	15	AIRPLANE CLUB	INGRID DIETRICH	19.99	0	4108
6161	2	AIRPLANE CLUE	INGRID MINELLI	10.99	0	379
6162	5	AIRPLANE CLUELESS	FAY MOSTEL	13.99	0	5545
6163	9	AIRPLANE CLYDE	LIV DEAN	16.99	0	5504
6164	4	AIRPLANE COAST	LEELEE NOLTE	27.99	0	7474
6165	16	AIRPLANE COLDBLOODED	ALBERT EASTWOOD	16.99	0	7169
6166	13	AIRPLANE COLOR	GROUCHO TOMEI	13.99	0	6229
6167	4	AIRPLANE COMA	FAY DOUGLAS	20.99	0	8449
6168	2	AIRPLANE COMANCHEROS	AUDREY AKROYD	23.99	0	1714
6169	4	AIRPLANE COMFORTS	RUSSELL MCCONAUGHEY	26.99	0	2501
6170	10	AIRPLANE COMMAND	KEVIN HORNE	21.99	0	3600
6171	6	AIRPLANE COMMANDMENTS	ELIZABETH MCDORMAND	23.99	0	2340
6172	5	AIRPLANE CONEHEADS	JUDY BERGEN	21.99	0	160
6173	8	AIRPLANE CONFESSIONS	ALBERT NOLTE	19.99	0	4036
6174	11	AIRPLANE CONFIDENTIAL	ALBERT MCGREGOR	20.99	0	5274
6175	13	AIRPLANE CONFUSED	WOODY BENING	16.99	0	8307
6176	12	AIRPLANE CONGENIALITY	JEREMY AFFLECK	29.99	0	2839
6177	4	AIRPLANE CONNECTICUT	GRETA ZELLWEGER	23.99	0	9514
6178	12	AIRPLANE CONNECTION	MADELINE BALE	24.99	0	134
6179	3	AIRPLANE CONQUERER	MARILYN DEGENERES	12.99	0	1151
6180	12	AIRPLANE CONSPIRACY	CLARK LANSBURY	23.99	0	8521
6181	9	AIRPLANE CONTACT	SALLY MANSFIELD	29.99	0	5459
6182	5	AIRPLANE CONTROL	KENNETH PINKETT	21.99	0	1417
6183	9	AIRPLANE CONVERSATION	CLINT CHASE	13.99	0	7312
6184	4	AIRPLANE CORE	WHOOPI BALE	26.99	0	7374
6185	16	AIRPLANE COWBOY	FRANCES TOMEI	11.99	0	1911
6186	16	AIRPLANE CRAFT	RALPH BLOOM	26.99	0	3370
6187	7	AIRPLANE CRANES	AUDREY FIENNES	28.99	0	5134
6188	2	AIRPLANE CRAZY	MATT HUSTON	14.99	0	5630
6189	16	AIRPLANE CREATURES	LEONARDO TEMPLE	29.99	0	8023
6190	12	AIRPLANE CREEPERS	MICHAEL NORTON	29.99	0	2745
6191	3	AIRPLANE CROOKED	HALLE SINATRA	29.99	0	4289
6192	5	AIRPLANE CROSSING	NICOLAS BENING	16.99	1	6678
6193	15	AIRPLANE CROSSROADS	CHARLIZE BERRY	20.99	0	8214
6194	2	AIRPLANE CROW	MICHAEL FONDA	24.99	0	4231
6195	9	AIRPLANE CROWDS	CAMERON WITHERSPOON	13.99	0	9372
6196	8	AIRPLANE CRUELTY	OPRAH CHASE	27.99	0	4229
6197	5	AIRPLANE CRUSADE	JOE HECHE	9.99	0	4822
6198	12	AIRPLANE CRYSTAL	KIRK PACINO	26.99	0	9016
6199	11	AIRPLANE CUPBOARD	DREW GRANT	16.99	0	5225
6200	13	AIRPLANE CURTAIN	JUDI MCQUEEN	28.99	0	4815
6201	14	AIRPLANE CYCLONE	MAE GARCIA	21.99	0	7600
6202	1	AIRPLANE DADDY	CUBA KEATON	19.99	0	9959
6203	16	AIRPLANE DAISY	MICHAEL DIAZ	20.99	0	9596
6204	8	AIRPLANE DALMATIONS	GREGORY RYAN	23.99	0	4591
6205	4	AIRPLANE DANCES	BRAD WILSON	24.99	0	9613
6206	4	AIRPLANE DANCING	GINA PENN	26.99	0	5478
6207	10	AIRPLANE DANGEROUS	ANTHONY FREEMAN	25.99	0	6243
6208	13	AIRPLANE DARES	SIDNEY STALLONE	18.99	0	59
6209	7	AIRPLANE DARKNESS	RENEE STREEP	25.99	0	9695
6210	4	AIRPLANE DARKO	TOM PINKETT	16.99	0	8114
6211	5	AIRPLANE DARLING	KARL MONROE	22.99	0	8525
6212	3	AIRPLANE DARN	DANIEL BERRY	13.99	0	502
6213	14	AIRPLANE DATE	SIGOURNEY MCQUEEN	24.99	0	2847
6214	13	AIRPLANE DAUGHTER	CARY KINNEAR	20.99	0	6611
6215	9	AIRPLANE DAWN	HUME LAW	18.99	0	8542
6216	5	AIRPLANE DAY	JUDE CRUZ	25.99	0	9886
6217	11	AIRPLANE DAZED	ANTHONY WOOD	26.99	0	9234
6218	15	AIRPLANE DECEIVER	KIM BIRCH	25.99	0	6674
6219	2	AIRPLANE DEEP	DEBBIE LUGOSI	13.99	0	5326
6220	14	AIRPLANE DEER	BOB MOSTEL	14.99	0	9948
6221	2	AIRPLANE DELIVERANCE	DAN GUINESS	22.99	0	140
6222	10	AIRPLANE DESERT	ADAM SUVARI	23.99	0	2279
6223	10	AIRPLANE DESIRE	GENE MARX	12.99	0	1453
6224	14	AIRPLANE DESPERATE	NEVE HURT	9.99	0	8710
6225	10	AIRPLANE DESTINATION	KARL LANSBURY	23.99	0	6562
6226	11	AIRPLANE DESTINY	ANGELINA WEST	27.99	0	2450
6227	14	AIRPLANE DETAILS	BRAD CRUZ	27.99	0	7978
6228	2	AIRPLANE DETECTIVE	HUME IRONS	17.99	0	8023
6229	9	AIRPLANE DEVIL	FARRAH IRONS	15.99	0	9686
6230	3	AIRPLANE DIARY	JULIETTE BOLGER	23.99	0	3546
6231	6	AIRPLANE DINOSAUR	GARY HEPBURN	17.99	0	8887
6232	11	AIRPLANE DIRTY	BETTE CLOSE	24.99	0	9703
6233	9	AIRPLANE DISCIPLE	JEREMY CAMPBELL	28.99	0	1126
6234	12	AIRPLANE DISTURBING	LENA BRIDGES	9.99	0	1257
6235	16	AIRPLANE DIVIDE	DORIS LEWIS	19.99	0	9985
6236	15	AIRPLANE DIVINE	JAMES MCDORMAND	12.99	0	7257
6237	2	AIRPLANE DIVORCE	SIDNEY NEWMAN	12.99	0	9285
6238	3	AIRPLANE DOCTOR	ANTHONY WEST	21.99	0	6264
6239	12	AIRPLANE DOGMA	NICOLAS MCQUEEN	15.99	0	1526
6240	7	AIRPLANE DOLLS	MORGAN MOSTEL	22.99	0	9925
6241	11	AIRPLANE DONNIE	LISA BEATTY	10.99	0	6363
6242	13	AIRPLANE DOOM	GARY FAWCETT	23.99	0	7185
6243	11	AIRPLANE DOORS	MATTHEW MANSFIELD	23.99	0	5655
6244	6	AIRPLANE DORADO	DEBBIE THURMAN	10.99	0	8709
6245	4	AIRPLANE DOUBLE	KARL MATTHAU	28.99	0	7120
6246	15	AIRPLANE DOUBTFIRE	PARKER TYLER	20.99	1	70
6247	3	AIRPLANE DOWNHILL	GEOFFREY SARANDON	19.99	0	7856
6248	4	AIRPLANE DOZEN	HELEN CAGE	27.99	0	5698
6249	8	AIRPLANE DRACULA	JEREMY CHAPLIN	22.99	0	6427
6250	9	AIRPLANE DRAGON	ELIZABETH HOFFMAN	10.99	0	5160
6251	13	AIRPLANE DRAGONFLY	JADA FINNEY	20.99	0	4263
6252	9	AIRPLANE DREAM	DREW BEATTY	27.99	0	7383
6253	11	AIRPLANE DRIFTER	SCARLETT REYNOLDS	9.99	0	7021
6254	10	AIRPLANE DRIVER	SALLY BLOOM	10.99	0	781
6255	12	AIRPLANE DRIVING	JULIA DICAPRIO	28.99	0	9053
6256	8	AIRPLANE DROP	DORIS BLANCHETT	27.99	0	998
6257	6	AIRPLANE DRUMLINE	CHEVY CLOSE	20.99	0	7090
6258	5	AIRPLANE DRUMS	JOAN MOSTEL	12.99	0	1140
6259	14	AIRPLANE DUCK	DARYL DRIVER	24.99	0	9466
6260	13	AIRPLANE DUDE	DENNIS BAILEY	15.99	0	5315
6261	4	AIRPLANE DUFFEL	LIV HOPE	18.99	0	2365
6262	9	AIRPLANE DUMBO	HUGH MOSTEL	23.99	0	4156
6263	7	AIRPLANE DURHAM	BELA JOVOVICH	27.99	0	7661
6264	1	AIRPLANE DWARFS	ANJELICA KILMER	13.99	0	3900
6265	3	AIRPLANE DYING	JACK BEATTY	16.99	0	4089
6266	15	AIRPLANE DYNAMITE	SALLY MARTIN	19.99	0	2023
6267	13	AIRPLANE EAGLES	SANDRA MARX	12.99	0	851
6268	10	AIRPLANE EARLY	LEELEE PHOENIX	22.99	0	2676
6269	7	AIRPLANE EARRING	RICHARD MCGREGOR	18.99	0	650
6270	14	AIRPLANE EARTH	CARMEN WOOD	14.99	0	5020
6271	11	AIRPLANE EASY	BRUCE DEPP	20.99	0	1588
6272	12	AIRPLANE EDGE	ORLANDO KEATON	21.99	0	805
6273	12	AIRPLANE EFFECT	RITA DEE	15.99	0	4392
6274	9	AIRPLANE EGG	ANTHONY DOUGLAS	16.99	0	9018
6275	7	AIRPLANE EGYPT	SIGOURNEY LOREN	20.99	0	2467
6276	1	AIRPLANE ELEMENT	JON KILMER	12.99	0	2675
6277	6	AIRPLANE ELEPHANT	RALPH SMITH	10.99	0	4526
6278	3	AIRPLANE ELF	MEL BULLOCK	29.99	0	5540
6279	7	AIRPLANE ELIZABETH	ROBIN WINFREY	19.99	0	5687
6280	7	AIRPLANE EMPIRE	CHARLTON REYNOLDS	14.99	0	113
6281	9	AIRPLANE ENCINO	KEVIN GARLAND	9.99	0	6312
6282	5	AIRPLANE ENCOUNTERS	JENNIFER STALLONE	10.99	0	8858
6283	9	AIRPLANE ENDING	AL BIRCH	13.99	0	4280
6284	13	AIRPLANE ENEMY	HUME HURT	21.99	0	7356
6285	3	AIRPLANE ENGLISH	JON FOSTER	15.99	0	8115
6286	6	AIRPLANE ENOUGH	CLARK CAINE	27.99	0	7027
6287	9	AIRPLANE ENTRAPMENT	KATHARINE HOPE	29.99	0	4655
6288	14	AIRPLANE ESCAPE	KENNETH BASINGER	27.99	0	6090
6289	5	AIRPLANE EVE	BEN BACALL	23.99	0	430
6290	7	AIRPLANE EVERYONE	HENRY RUSSELL	28.99	0	28
6291	12	AIRPLANE EVOLUTION	CHARLES HESTON	28.99	0	3031
6292	10	AIRPLANE EXCITEMENT	OLYMPIA SOBIESKI	12.99	0	2780
6293	11	AIRPLANE EXORCIST	GOLDIE MIRANDA	12.99	0	5934
6294	13	AIRPLANE EXPECATIONS	LIZA SANDLER	27.99	0	2442
6295	15	AIRPLANE EXPENDABLE	ALICIA WAHLBERG	15.99	0	1401
6296	5	AIRPLANE EXPRESS	LAURA LOREN	18.99	0	8947
6297	12	AIRPLANE EXTRAORDINARY	MORGAN BRIDGES	19.99	0	5195
6298	13	AIRPLANE EYES	CHRISTIAN TURNER	11.99	0	6760
6299	12	AIRPLANE FACTORY	JODIE TAUTOU	15.99	0	9713
6300	10	AIRPLANE FALCON	SIGOURNEY MIRANDA	21.99	0	7397
6301	12	AIRPLANE FAMILY	GINA DENIRO	15.99	0	8228
6302	4	AIRPLANE FANTASIA	TOM HEPBURN	28.99	0	2183
6303	8	AIRPLANE FANTASY	CARMEN PALTROW	22.99	0	2045
6304	5	AIRPLANE FARGO	AUDREY KEATON	25.99	0	8052
6305	12	AIRPLANE FATAL	JENNIFER HANNAH	22.99	0	3980
6306	7	AIRPLANE FEATHERS	MARILYN PINKETT	23.99	0	3324
6307	9	AIRPLANE FELLOWSHIP	PARKER DIAZ	18.99	0	6998
6308	11	AIRPLANE FERRIS	HUMPHREY MONROE	25.99	0	2265
6309	1	AIRPLANE FEUD	NICOLAS LEIGH	10.99	0	5825
6310	15	AIRPLANE FEVER	WINONA BIRCH	16.99	0	9880
6311	12	AIRPLANE FICTION	NATALIE BOGART	16.99	0	7829
6312	12	AIRPLANE FIDDLER	ANGELINA FINNEY	19.99	0	2463
6313	3	AIRPLANE FIDELITY	SISSY HORNE	21.99	0	1701
6314	14	AIRPLANE FIGHT	NICK DOUGLAS	20.99	0	770
6315	3	AIRPLANE FINDING	CHRIS DENCH	11.99	0	8823
6316	2	AIRPLANE FIRE	WILLEM FIELD	26.99	0	7778
6317	10	AIRPLANE FIREBALL	BRAD HANNAH	23.99	0	8820
6318	15	AIRPLANE FIREHOUSE	GREGORY BEATTY	26.99	0	6155
6319	16	AIRPLANE FISH	SIGOURNEY HOPPER	24.99	0	2503
6320	13	AIRPLANE FLAMINGOS	JOHNNY CHAPLIN	29.99	0	689
6321	14	AIRPLANE FLASH	HELEN GUINESS	26.99	0	722
6322	10	AIRPLANE FLATLINERS	JOAN SWANK	23.99	0	3536
6323	10	AIRPLANE FLIGHT	IAN HOPE	28.99	0	539
6324	9	AIRPLANE FLINTSTONES	JUDY DEPP	18.99	0	5244
6325	12	AIRPLANE FLOATS	MEG ROBERTS	12.99	0	9569
6326	4	AIRPLANE FLYING	GREGORY LOREN	22.99	0	5842
6327	12	AIRPLANE FOOL	JAYNE ALLEN	12.99	0	9743
6328	9	AIRPLANE FOREVER	JACK DUKAKIS	28.99	0	6902
6329	16	AIRPLANE FORREST	UMA RICKMAN	19.99	0	9206
6330	1	AIRPLANE FORRESTER	MICHAEL TOMEI	23.99	0	4386
6331	11	AIRPLANE FORWARD	ALBERT FIENNES	9.99	0	4312
6332	10	AIRPLANE FRANKENSTEIN	JAYNE MIRANDA	9.99	0	1521
6333	1	AIRPLANE FREAKY	JEFF GABLE	18.99	0	6669
6334	3	AIRPLANE FREDDY	JAMES DRIVER	10.99	0	6367
6335	16	AIRPLANE FREEDOM	JULIETTE SINATRA	23.99	0	5991
6336	3	AIRPLANE FRENCH	SUSAN CROWE	12.99	0	8655
6337	10	AIRPLANE FRIDA	JUDY RYDER	9.99	0	3392
6338	3	AIRPLANE FRISCO	MERYL STREEP	22.99	0	9856
6339	5	AIRPLANE FROGMEN	ETHAN HAWN	24.99	0	614
6340	6	AIRPLANE FRONTIER	SEAN HURT	27.99	0	4032
6341	8	AIRPLANE FROST	LAURENCE DUNST	17.99	0	7888
6342	5	AIRPLANE FUGITIVE	LAUREN BAILEY	25.99	0	4202
6343	2	AIRPLANE FULL	EMILY DEE	26.99	0	5576
6344	13	AIRPLANE FURY	WILL CAMPBELL	10.99	0	4605
6345	3	AIRPLANE GABLES	TOM DAY-LEWIS	9.99	0	1091
6346	7	AIRPLANE GALAXY	HUMPHREY MANSFIELD	9.99	1	8583
6347	13	AIRPLANE GAMES	SIGOURNEY DICAPRIO	16.99	0	9499
6348	13	AIRPLANE GANDHI	CLINT COSTNER	10.99	0	409
6349	11	AIRPLANE GANGS	CUBA RUSSELL	21.99	0	519
6350	1	AIRPLANE GARDEN	EWAN WRAY	29.99	0	3870
6351	2	AIRPLANE GASLIGHT	WILLIAM HAYEK	19.99	0	9827
6352	6	AIRPLANE GATHERING	ELIZABETH DAY-LEWIS	14.99	0	3018
6353	4	AIRPLANE GENTLEMEN	JODIE HANNAH	17.99	0	4635
6354	8	AIRPLANE GHOST	ELIZABETH BOGART	22.99	0	1134
6355	11	AIRPLANE GHOSTBUSTERS	BURT PRESLEY	29.99	0	1154
6356	6	AIRPLANE GIANT	KATE TAUTOU	15.99	0	9678
6357	5	AIRPLANE GILBERT	DAN PRESLEY	20.99	0	7938
6358	14	AIRPLANE GILMORE	DANIEL DENCH	16.99	0	6662
6359	13	AIRPLANE GLADIATOR	ORLANDO BIRCH	10.99	0	4612
6360	3	AIRPLANE GLASS	DENZEL GUINESS	14.99	0	9769
6361	7	AIRPLANE GLEAMING	ROSIE NORTON	28.99	0	2270
6362	15	AIRPLANE GLORY	WINONA FINNEY	10.99	0	103
6363	15	AIRPLANE GO	ELIZABETH PITT	10.99	0	8944
6364	12	AIRPLANE GODFATHER	WILLEM TEMPLE	19.99	0	6911
6365	16	AIRPLANE GOLD	BEN BOGART	12.99	0	4299
6366	3	AIRPLANE GOLDFINGER	CANDICE PRESLEY	9.99	0	1354
6367	4	AIRPLANE GOLDMINE	JEREMY LOLLOBRIGIDA	13.99	0	3430
6368	4	AIRPLANE GONE	BETTE KUDROW	19.99	0	1672
6369	6	AIRPLANE GOODFELLAS	ANGELINA GARCIA	16.99	0	9778
6370	1	AIRPLANE GORGEOUS	AUDREY SORVINO	11.99	0	4431
6371	9	AIRPLANE GOSFORD	DARYL CRONYN	23.99	0	8851
6372	13	AIRPLANE GRACELAND	JESSICA HAWN	14.99	0	1300
6373	10	AIRPLANE GRADUATE	MEG TANDY	23.99	0	2959
6374	14	AIRPLANE GRAFFITI	MARLON PENN	28.99	0	5245
6375	15	AIRPLANE GRAIL	GROUCHO BRANDO	29.99	0	3754
6376	7	AIRPLANE GRAPES	KIM RYDER	21.99	0	7411
6377	8	AIRPLANE GREASE	CHEVY DRIVER	29.99	0	7951
6378	2	AIRPLANE GREATEST	MARLON COSTNER	25.99	0	25
6379	1	AIRPLANE GREEDY	MORGAN PITT	24.99	0	7908
6380	4	AIRPLANE GREEK	SPENCER KUDROW	21.99	0	1470
6381	16	AIRPLANE GRINCH	UMA WAHLBERG	20.99	0	4191
6382	5	AIRPLANE GRIT	MICHELLE BACALL	18.99	0	2615
6383	4	AIRPLANE GROOVE	JAMES BERRY	27.99	0	3040
6384	15	AIRPLANE GROSSE	ANGELA TRACY	21.99	0	6990
6385	7	AIRPLANE GROUNDHOG	EDWARD TAUTOU	15.99	0	7607
6386	8	AIRPLANE GUMP	MEL HOFFMAN	17.99	0	2182
6387	14	AIRPLANE GUN	EDWARD DENCH	19.99	0	2357
6388	13	AIRPLANE GUNFIGHT	GENE TRACY	13.99	0	1570
6389	9	AIRPLANE GUNFIGHTER	ANNETTE NEWMAN	20.99	0	6832
6390	5	AIRPLANE GUYS	KENNETH NICHOLSON	19.99	0	133
6391	5	AIRPLANE HALF	JENNIFER HEPBURN	28.99	0	4251
6392	3	AIRPLANE HALL	MATT MIRANDA	17.99	0	3428
6393	11	AIRPLANE HALLOWEEN	ED WEAVER	29.99	0	289
6394	2	AIRPLANE HAMLET	MICHELLE NICHOLSON	12.99	0	9832
6395	14	AIRPLANE HANDICAP	MARY JOHANSSON	17.99	0	6462
6396	7	AIRPLANE HANGING	BEN DIETRICH	27.99	0	9112
6397	5	AIRPLANE HANKY	KIM GUINESS	29.99	0	7219
6398	6	AIRPLANE HANOVER	MATT HORNE	20.99	0	8279
6399	10	AIRPLANE HAPPINESS	JUDE LANCASTER	15.99	0	7431
6400	5	AIRPLANE HARDLY	ED MARTIN	28.99	0	2466
6401	10	AIRPLANE HAROLD	JULIA HOPE	22.99	0	7429
6402	10	AIRPLANE HARPER	CATE MCQUEEN	11.99	0	9472
6403	14	AIRPLANE HARRY	IAN WASHINGTON	19.99	0	8395
6404	6	AIRPLANE HATE	HILARY BIRCH	26.99	0	1288
6405	10	AIRPLANE HAUNTED	NEVE MONROE	26.99	0	7521
6406	2	AIRPLANE HAUNTING	DARYL CRAWFORD	21.99	0	5305
6407	6	AIRPLANE HAWK	CHRISTIAN HAWN	19.99	0	7817
6408	7	AIRPLANE HEAD	MINNIE HARRIS	26.99	0	2073
6409	11	AIRPLANE HEARTBREAKERS	FRANCES DREYFUSS	10.99	0	6687
6410	4	AIRPLANE HEAVEN	GINA PINKETT	28.99	0	9133
6411	11	AIRPLANE HEAVENLY	BETTE MOSTEL	27.99	0	9313
6412	7	AIRPLANE HEAVYWEIGHTS	GREGORY MCCONAUGHEY	21.99	0	9015
6413	6	AIRPLANE HEDWIG	GARY KIDMAN	10.99	0	2385
6414	5	AIRPLANE HELLFIGHTERS	JULIA BEATTY	21.99	0	6569
6415	4	AIRPLANE HIGH	HILARY FORD	20.99	0	9692
6416	8	AIRPLANE HIGHBALL	MADELINE WILLIAMS	21.99	0	9011
6417	9	AIRPLANE HILLS	JULIA DIAZ	26.99	0	6211
6418	13	AIRPLANE HOBBIT	CHEVY DAY	10.99	0	5332
6419	5	AIRPLANE HOCUS	LEELEE LUGOSI	26.99	0	7254
6420	8	AIRPLANE HOLES	ANNETTE HAWN	27.99	0	3318
6421	14	AIRPLANE HOLIDAY	FAY HUNT	18.99	0	1357
6422	6	AIRPLANE HOLLOW	HUGH KUDROW	27.99	0	2488
6423	9	AIRPLANE HOLLYWOOD	JIM CHASE	23.99	0	7646
6424	4	AIRPLANE HOLOCAUST	GRETA KEITEL	25.99	0	5188
6425	9	AIRPLANE HOLY	TIM SMITH	21.99	0	9214
6426	15	AIRPLANE HOME	HILARY KILMER	13.99	0	4353
6427	6	AIRPLANE HOMEWARD	WILLIAM GRANT	24.99	0	3855
6428	16	AIRPLANE HOMICIDE	KATHARINE RYAN	18.99	0	7649
6429	4	AIRPLANE HONEY	FAY MOSTEL	20.99	0	6350
6430	2	AIRPLANE HOOK	JEREMY WITHERSPOON	9.99	0	1567
6431	16	AIRPLANE HOOSIERS	MERYL HURT	16.99	0	7055
6432	13	AIRPLANE HOPE	BOB ANISTON	24.99	0	3691
6433	3	AIRPLANE HORN	CHRIS PITT	23.99	0	6227
6434	8	AIRPLANE HORROR	FAY HAWKE	24.99	0	7469
6435	6	AIRPLANE HOTEL	NATALIE BERGEN	26.99	0	2889
6436	16	AIRPLANE HOURS	ORLANDO BALE	23.99	0	4422
6437	7	AIRPLANE HOUSE	JEREMY CAMPBELL	19.99	0	2150
6438	14	AIRPLANE HUMAN	WALTER BALE	9.99	0	1528
6439	11	AIRPLANE HUNCHBACK	KIRSTEN COOPER	28.99	0	5477
6440	11	AIRPLANE HUNGER	LIV DOUGLAS	17.99	0	7101
6441	11	AIRPLANE HUNTER	NICOLE BOGART	18.99	0	1189
6442	15	AIRPLANE HUNTING	ELVIS COOPER	16.99	0	1595
6443	9	AIRPLANE HURRICANE	DANIEL JACKMAN	19.99	0	9167
6444	11	AIRPLANE HUSTLER	BEN CAGE	13.99	0	9890
6445	13	AIRPLANE HYDE	ELVIS PENN	17.99	0	3723
6446	2	AIRPLANE HYSTERICAL	JIM RYAN	27.99	0	2458
6447	16	AIRPLANE ICE	IAN BULLOCK	14.99	0	569
6448	7	AIRPLANE IDAHO	KENNETH BAILEY	21.99	0	517
6449	9	AIRPLANE IDENTITY	CUBA DEAN	21.99	0	2375
6450	10	AIRPLANE IDOLS	WALTER DENIRO	26.99	0	663
6451	4	AIRPLANE IGBY	SALLY RICKMAN	23.99	0	966
6452	15	AIRPLANE ILLUSION	DIANE MARTIN	16.99	0	6949
6453	7	AIRPLANE IMAGE	NATALIE DENCH	29.99	0	2840
6454	1	AIRPLANE IMPACT	JUDY GABLE	13.99	0	9743
6455	7	AIRPLANE IMPOSSIBLE	DIANE KILMER	17.99	0	8762
6456	8	AIRPLANE INCH	MARILYN MATTHAU	15.99	0	2665
6457	7	AIRPLANE INDEPENDENCE	SANDRA DENCH	22.99	0	7137
6458	6	AIRPLANE INDIAN	WALTER ZELLWEGER	10.99	0	7980
6459	6	AIRPLANE INFORMER	CHARLTON WILLIS	26.99	0	1033
6460	14	AIRPLANE INNOCENT	MARILYN LOREN	9.99	0	315
6461	15	AIRPLANE INSECTS	MARISA HAYEK	20.99	0	9509
6462	14	AIRPLANE INSIDER	DAN CAINE	23.99	0	7863
6463	7	AIRPLANE INSTINCT	PENELOPE BLOOM	16.99	0	7393
6464	3	AIRPLANE INTENTIONS	MICHELLE HUSTON	15.99	0	8562
6465	7	AIRPLANE INTERVIEW	JAYNE CHAPLIN	10.99	0	4117
6466	2	AIRPLANE INTOLERABLE	ROBIN BRODY	24.99	0	5668
6467	12	AIRPLANE INTRIGUE	MILLA KAHN	27.99	0	4751
6468	11	AIRPLANE INVASION	KIRSTEN MCGREGOR	18.99	1	7142
6469	4	AIRPLANE IRON	DANIEL COOPER	27.99	0	5298
6470	13	AIRPLANE ISHTAR	MEL TYLER	13.99	0	8831
6471	10	AIRPLANE ISLAND	ADAM BERGMAN	18.99	0	6893
6472	1	AIRPLANE ITALIAN	DARYL JOVOVICH	24.99	0	4181
6473	4	AIRPLANE JACKET	ANGELINA BERGEN	24.99	0	440
6474	8	AIRPLANE JADE	DENNIS PESCI	23.99	0	6989
6475	4	AIRPLANE JAPANESE	LISA GOLDBERG	27.99	0	5872
6476	13	AIRPLANE JASON	MARY CRONYN	25.99	0	4764
6477	8	AIRPLANE JAWBREAKER	WILLIAM MCKELLEN	22.99	0	3805
6478	2	AIRPLANE JAWS	JEFF KILMER	11.99	0	9759
6479	3	AIRPLANE JEDI	MICHAEL REYNOLDS	17.99	0	3223
6480	2	AIRPLANE JEEPERS	MICHAEL MCKELLEN	23.99	0	2727
6481	5	AIRPLANE JEKYLL	JENNIFER DREYFUSS	28.99	0	759
6482	7	AIRPLANE JEOPARDY	MILLA KAHN	17.99	0	523
6483	13	AIRPLANE JERICHO	LAURENCE DERN	13.99	0	8808
6484	4	AIRPLANE JERK	MARISA LANSBURY	28.99	0	801
6485	4	AIRPLANE JERSEY	MINNIE ASTAIRE	28.99	0	2313
6486	4	AIRPLANE JET	JUDY WRAY	22.99	0	5683
6487	12	AIRPLANE JINGLE	BEN FREEMAN	18.99	0	2592
6488	8	AIRPLANE JOON	JULIA KELLY	10.99	0	9046
6489	16	AIRPLANE JUGGLER	JESSICA WILSON	21.99	0	4025
6490	11	AIRPLANE JUMANJI	JACK BOLGER	17.99	0	1372
6491	11	AIRPLANE JUMPING	CARRIE DEAN	11.99	0	612
6492	12	AIRPLANE JUNGLE	HUMPHREY MATTHAU	25.99	0	1575
6493	1	AIRPLANE KANE	MENA KILMER	20.99	0	4478
6494	8	AIRPLANE KARATE	IAN LEWIS	28.99	0	2874
6495	6	AIRPLANE KENTUCKIAN	HENRY SWANK	25.99	0	4175
6496	15	AIRPLANE KICK	MARISA THERON	9.99	0	5299
6497	2	AIRPLANE KILL	CHARLES PHOENIX	19.99	0	1919
6498	11	AIRPLANE KILLER	NATALIE LOLLOBRIGIDA	16.99	0	3437
6499	13	AIRPLANE KING	STEVE MCDORMAND	13.99	0	882
6500	8	AIRPLANE KISS	UMA TORN	27.99	0	1970
6501	5	AIRPLANE KISSING	BELA LAW	28.99	0	1008
6502	8	AIRPLANE KNOCK	ROBIN NOLTE	21.99	0	3605
6503	13	AIRPLANE KRAMER	TOM SPACEK	20.99	0	856
6504	15	AIRPLANE KWAI	MILLA WINFREY	25.99	0	2658
6505	15	AIRPLANE LABYRINTH	CHRIS NEWMAN	26.99	0	8238
6506	1	AIRPLANE LADY	HELEN SWANK	11.99	0	9747
6507	4	AIRPLANE LADYBUGS	MARLON DOUGLAS	9.99	0	8360
6508	7	AIRPLANE LAMBS	MATTHEW PALTROW	16.99	0	8551
6509	7	AIRPLANE LANGUAGE	ROBERT CAGE	11.99	0	89
6510	7	AIRPLANE LAWLESS	MEL SINATRA	20.99	0	2393
6511	7	AIRPLANE LAWRENCE	BRAD NICHOLSON	25.99	0	8982
6512	12	AIRPLANE LEAGUE	CLARK WOOD	17.99	0	750
6513	4	AIRPLANE LEATHERNECKS	PENELOPE HEPBURN	28.99	0	327
6514	13	AIRPLANE LEBOWSKI	CHRISTIAN CRUISE	21.99	0	972
6515	10	AIRPLANE LEGALLY	SUSAN PESCI	14.99	0	5647
6516	9	AIRPLANE LEGEND	ED NEESON	22.99	0	243
6517	9	AIRPLANE LESSON	AL CRONYN	23.99	0	421
6518	13	AIRPLANE LIAISONS	JOAN SINATRA	20.99	0	2415
6519	10	AIRPLANE LIBERTY	JANE JACKMAN	24.99	0	7612
6520	14	AIRPLANE LICENSE	JOE NOLTE	25.99	0	7693
6521	6	AIRPLANE LIES	JANE JACKMAN	20.99	0	8773
6522	10	AIRPLANE LIFE	ANNE MCGREGOR	21.99	0	6418
6523	11	AIRPLANE LIGHTS	JEREMY BLOOM	11.99	0	1854
6524	6	AIRPLANE LION	MEG DEE	25.99	0	7581
6525	9	AIRPLANE LOATHING	JAYNE SOBIESKI	9.99	0	4108
6526	14	AIRPLANE LOCK	SOPHIA WAHLBERG	14.99	0	142
6527	3	AIRPLANE LOLA	MARILYN BLANCHETT	12.99	0	9656
6528	14	AIRPLANE LOLITA	ANNE FOSTER	15.99	0	7028
6529	8	AIRPLANE LONELY	TIM SOBIESKI	12.99	0	9150
6530	15	AIRPLANE LORD	NICOLAS CROWE	16.99	0	3388
6531	13	AIRPLANE LOSE	ELVIS BALL	22.99	0	7537
6532	11	AIRPLANE LOSER	ROSIE HECHE	15.99	0	5351
6533	5	AIRPLANE LOST	SEAN HOPE	16.99	0	3443
6534	1	AIRPLANE LOUISIANA	CHRISTOPHER DAVIS	29.99	0	8000
6535	15	AIRPLANE LOVE	WINONA DIETRICH	22.99	0	2174
6536	16	AIRPLANE LOVELY	ELVIS GRANT	14.99	0	5582
6537	16	AIRPLANE LOVER	WILLIAM PFEIFFER	26.99	0	5992
6538	6	AIRPLANE LOVERBOY	ANGELINA FORD	14.99	0	7816
6539	10	AIRPLANE LUCK	WOODY PHOENIX	25.99	0	3562
6540	10	AIRPLANE LUCKY	LUCILLE MARX	20.99	0	2511
6541	13	AIRPLANE LUKE	MAE DEAN	9.99	0	6860
6542	10	AIRPLANE LUST	IAN HORNE	21.99	0	4656
6543	3	AIRPLANE MADIGAN	RENEE NEESON	13.99	0	4867
6544	16	AIRPLANE MADISON	DENZEL JOVOVICH	29.99	0	9293
6545	6	AIRPLANE MADNESS	KATE STALLONE	29.99	0	7857
6546	4	AIRPLANE MADRE	AL CLOSE	27.99	0	4826
6547	9	AIRPLANE MAGIC	VAL RUSH	29.99	0	2435
6548	7	AIRPLANE MAGNIFICENT	STEVE KIDMAN	13.99	0	8279
6549	12	AIRPLANE MAGNOLIA	GRACE POITIER	28.99	0	6127
6550	14	AIRPLANE MAGUIRE	JENNIFER BLANCHETT	17.99	0	8472
6551	4	AIRPLANE MAIDEN	AL DUKAKIS	13.99	0	2047
6552	11	AIRPLANE MAJESTIC	WINONA PALTROW	22.99	0	3463
6553	15	AIRPLANE MAKER	SEAN BOLGER	25.99	0	6248
6554	10	AIRPLANE MALKOVICH	HARRISON BENING	28.99	1	1128
6555	10	AIRPLANE MALLRATS	DARYL TAUTOU	9.99	0	2688
6556	14	AIRPLANE MALTESE	KIRK HORNE	27.99	0	7223
6557	2	AIRPLANE MANCHURIAN	JAMES GABLE	10.99	0	1056
6558	7	AIRPLANE MANNEQUIN	DENNIS TANDY	15.99	0	5496
6559	15	AIRPLANE MARRIED	LIAM DIAZ	15.99	0	6081
6560	7	AIRPLANE MARS	JOAN ROBERTS	21.99	0	7451
6561	14	AIRPLANE MASK	DEBBIE MOSTEL	18.99	0	8716
6562	3	AIRPLANE MASKED	DIANE MCCONAUGHEY	21.99	0	2081
6563	12	AIRPLANE MASSACRE	ANTHONY BOLGER	28.99	0	7155
6564	8	AIRPLANE MASSAGE	WILLEM FIELD	10.99	0	1917
6565	11	AIRPLANE MATRIX	WILL AFFLECK	12.99	0	7684
6566	15	AIRPLANE MAUDE	JAMES HUSTON	11.99	0	9710
6567	16	AIRPLANE MEET	LEELEE BERRY	13.99	0	2797
6568	7	AIRPLANE MEMENTO	HELEN GARCIA	18.99	0	7803
6569	3	AIRPLANE MENAGERIE	BOB PESCI	12.99	0	6953
6570	6	AIRPLANE MERMAID	MICHAEL HOPPER	15.99	0	3070
6571	2	AIRPLANE METAL	RALPH JOHANSSON	20.99	0	7046
6572	8	AIRPLANE METROPOLIS	PENELOPE LEIGH	10.99	0	4453
6573	6	AIRPLANE MICROCOSMOS	RICHARD CLOSE	24.99	0	722
6574	9	AIRPLANE MIDNIGHT	RAY SINATRA	22.99	0	5804
6575	6	AIRPLANE MIDSUMMER	ANDY FORD	9.99	0	6468
6576	6	AIRPLANE MIGHTY	CHARLIZE POSEY	11.99	0	7434
6577	14	AIRPLANE MILE	GENE ROBERTS	21.99	0	722
6578	1	AIRPLANE MILLION	DUSTIN DEE	26.99	0	8682
6579	15	AIRPLANE MINDS	MENA KAHN	24.99	0	6678
6580	5	AIRPLANE MINE	ADAM HOPPER	16.99	0	6647
6581	16	AIRPLANE MINORITY	INGRID RYDER	11.99	0	6997
6582	14	AIRPLANE MIRACLE	JODIE PFEIFFER	12.99	0	3397
6583	5	AIRPLANE MISSION	KIRSTEN GARLAND	19.99	0	5507
6584	6	AIRPLANE MIXED	ANNETTE CAINE	9.99	0	1981
6585	12	AIRPLANE MOB	MARLENE CARREY	24.99	0	1269
6586	7	AIRPLANE MOCKINGBIRD	THORA HUDSON	25.99	0	8377
6587	8	AIRPLANE MOD	KIRSTEN HORNE	29.99	0	8941
6588	6	AIRPLANE MODEL	ELVIS TORN	27.99	0	4823
6589	7	AIRPLANE MODERN	LIZA POITIER	19.99	0	4755
6590	12	AIRPLANE MONEY	LIZA JOLIE	16.99	0	1082
6591	8	AIRPLANE MONSOON	LANA MANSFIELD	17.99	0	1667
6592	4	AIRPLANE MONSTER	MADELINE TOMEI	25.99	0	2764
6593	12	AIRPLANE MONTEREY	CLARK CRONYN	29.99	0	5650
6594	8	AIRPLANE MONTEZUMA	GENE JOLIE	10.99	0	1009
6595	9	AIRPLANE MOON	LEONARDO OLIVIER	12.99	0	8186
6596	5	AIRPLANE MOONSHINE	IAN KEITEL	26.99	0	8099
6597	1	AIRPLANE MOONWALKER	MICHELLE CLOSE	22.99	0	5730
6598	15	AIRPLANE MOSQUITO	OPRAH NEESON	11.99	0	8253
6599	11	AIRPLANE MOTHER	GLENN BERRY	29.99	0	3300
6600	2	AIRPLANE MOTIONS	ALEC NORTON	23.99	0	721
6601	8	AIRPLANE MOULIN	LEELEE CAGE	28.99	0	5156
6602	12	AIRPLANE MOURNING	MEG ZELLWEGER	17.99	0	6447
6603	16	AIRPLANE MOVIE	GENE LEIGH	24.99	0	9439
6604	10	AIRPLANE MULAN	ALBERT FISHER	28.99	0	1674
6605	4	AIRPLANE MULHOLLAND	SALLY GOODING	14.99	0	7126
6606	6	AIRPLANE MUMMY	ROSIE LANSBURY	28.99	0	8259
6607	8	AIRPLANE MUPPET	RIVER CROWE	11.99	0	4668
6608	13	AIRPLANE MURDER	ALICIA MATTHAU	10.99	0	6992
6609	1	AIRPLANE MUSCLE	ALEC WEAVER	9.99	0	3336
6610	4	AIRPLANE MUSIC	MINNIE BLOOM	10.99	0	7729
6611	13	AIRPLANE MUSKETEERS	GLENN OLIVIER	22.99	0	7949
6612	8	AIRPLANE MUSSOLINI	WILLIAM BERGMAN	14.99	0	5952
6613	12	AIRPLANE MYSTIC	DEBBIE WILLIS	25.99	0	5711
6614	8	AIRPLANE NAME	JULIA BERGEN	19.99	0	3706
6615	14	AIRPLANE NASH	JESSICA FISHER	20.99	0	8224
6616	6	AIRPLANE NATIONAL	JULIA CRAWFORD	22.99	0	1457
6617	8	AIRPLANE NATURAL	DENZEL DERN	18.99	0	4159
6618	1	AIRPLANE NECKLACE	HELEN DOUGLAS	13.99	0	4259
6619	13	AIRPLANE NEIGHBORS	JON KELLY	15.99	0	6103
6620	12	AIRPLANE NEMO	TOM TAUTOU	12.99	0	3362
6621	16	AIRPLANE NETWORK	JULIA PITT	19.99	0	3214
6622	11	AIRPLANE NEWSIES	LAURA SPACEK	27.99	0	1126
6623	5	AIRPLANE NEWTON	HENRY DUKAKIS	22.99	0	4383
6624	2	AIRPLANE NIGHTMARE	WARREN FISHER	21.99	0	9919
6625	3	AIRPLANE NONE	SALLY FONDA	11.99	0	2737
6626	8	AIRPLANE NOON	AL HOPPER	29.99	0	4062
6627	5	AIRPLANE NORTH	EDWARD LUGOSI	27.99	0	5141
6628	16	AIRPLANE NORTHWEST	RICHARD PENN	16.99	0	3311
6629	14	AIRPLANE NOTORIOUS	MARLON HOPKINS	25.99	0	2988
6630	13	AIRPLANE NOTTING	LUCILLE DAVIS	22.99	0	1128
6631	15	AIRPLANE NOVOCAINE	LANA RYDER	28.99	0	5203
6632	6	AIRPLANE NUTS	BURT BERGMAN	20.99	0	5556
6633	2	AIRPLANE OCTOBER	EWAN WATSON	27.99	0	6497
6634	4	AIRPLANE ODDS	BRUCE BULLOCK	27.99	0	1333
6635	3	AIRPLANE OKLAHOMA	GREGORY NICHOLSON	25.99	0	6871
6636	15	AIRPLANE OLEANDER	JOHN DAFOE	19.99	0	2611
6637	1	AIRPLANE OPEN	GOLDIE HOFFMAN	11.99	0	2815
6638	11	AIRPLANE OPERATION	DENZEL BLANCHETT	28.99	0	5328
6639	10	AIRPLANE OPPOSITE	MARY CRUISE	23.99	0	5684
6640	14	AIRPLANE OPUS	EDWARD DENCH	12.99	0	5494
6641	14	AIRPLANE ORANGE	OLYMPIA WILLIS	16.99	0	8739
6642	10	AIRPLANE ORDER	GENE HOPKINS	28.99	0	3210
6643	4	AIRPLANE ORIENT	HUMPHREY DEGENERES	18.99	0	3823
6644	16	AIRPLANE OSCAR	LAURA RUSH	22.99	0	6430
6645	4	AIRPLANE OTHERS	SHIRLEY FIELD	18.99	0	9283
6646	1	AIRPLANE OUTBREAK	SIDNEY GARCIA	24.99	0	3346
6647	11	AIRPLANE OUTFIELD	RALPH FONDA	28.99	0	3545
6648	5	AIRPLANE OUTLAW	LEELEE JOVOVICH	23.99	0	7774
6649	1	AIRPLANE OZ	KIM WATSON	22.99	0	377
6650	5	AIRPLANE PACIFIC	GRETA RYAN	12.99	0	8443
6651	2	AIRPLANE PACKER	DEBBIE DEPP	29.99	0	9220
6652	6	AIRPLANE PAJAMA	ELIZABETH MIRANDA	11.99	0	5324
6653	8	AIRPLANE PANIC	ANGELA TAUTOU	9.99	0	9990
6654	14	AIRPLANE PANKY	TOM MARTIN	17.99	0	5195
6655	7	AIRPLANE PANTHER	GENE KAHN	25.99	0	5613
6656	10	AIRPLANE PAPI	RITA REYNOLDS	26.99	0	8306
6657	12	AIRPLANE PARADISE	JODIE BEATTY	29.99	0	753
6658	9	AIRPLANE PARIS	UMA MARX	20.99	0	4827
6659	10	AIRPLANE PARK	BEN HURT	19.99	0	3194
6660	1	AIRPLANE PARTY	ROBIN DREYFUSS	16.99	0	5066
6661	15	AIRPLANE PAST	ETHAN NEESON	24.99	0	130
6662	9	AIRPLANE PATHS	ANTHONY DEAN	9.99	0	2226
6663	2	AIRPLANE PATIENT	ROBIN POSEY	9.99	0	4870
6664	9	AIRPLANE PATRIOT	WHOOPI THURMAN	21.99	0	8286
6665	15	AIRPLANE PATTON	BURT HAWN	24.99	0	1615
6666	5	AIRPLANE PAYCHECK	ROBERT MOORE	20.99	0	3137
6667	9	AIRPLANE PEACH	KATHARINE VOIGHT	21.99	0	7664
6668	14	AIRPLANE PEAK	JULIA BALE	23.99	0	8386
6669	3	AIRPLANE PEARL	NATALIE MARTIN	11.99	0	1216
6670	16	AIRPLANE PELICAN	KATHARINE CAGE	10.99	0	2983
6671	4	AIRPLANE PERDITION	VIVIEN CHASE	10.99	0	3246
6672	6	AIRPLANE PERFECT	ED DEGENERES	28.99	0	1802
6673	11	AIRPLANE PERSONAL	DENZEL ODONNELL	13.99	0	2985
6674	1	AIRPLANE PET	SOPHIA KEITEL	24.99	0	1080
6675	15	AIRPLANE PHANTOM	ED MANSFIELD	17.99	0	1332
6676	12	AIRPLANE PHILADELPHIA	FAY THERON	23.99	0	9805
6677	16	AIRPLANE PIANIST	DENZEL DUNST	13.99	0	751
6678	7	AIRPLANE PICKUP	PARKER TEMPLE	22.99	0	1326
6679	15	AIRPLANE PILOT	MARLENE BOGART	26.99	0	2972
6680	16	AIRPLANE PINOCCHIO	SIGOURNEY PINKETT	12.99	0	5520
6681	6	AIRPLANE PIRATES	JAMES TAYLOR	21.99	0	3671
6682	10	AIRPLANE PITTSBURGH	MARY KINNEAR	25.99	0	8695
6683	15	AIRPLANE PITY	NICOLE CRUZ	22.99	0	8170
6684	13	AIRPLANE PIZZA	SUSAN RICKMAN	18.99	0	7729
6685	12	AIRPLANE PLATOON	JUDI KUDROW	22.99	0	6629
6686	3	AIRPLANE PLUTO	KATE BARRYMORE	21.99	0	807
6687	16	AIRPLANE POCUS	LIZA DENCH	22.99	0	4010
6688	9	AIRPLANE POLISH	LENA WASHINGTON	14.99	0	4289
6689	2	AIRPLANE POLLOCK	DANIEL GARLAND	29.99	0	7983
6690	13	AIRPLANE POND	GREG KILMER	14.99	0	732
6691	16	AIRPLANE POSEIDON	CARMEN FOSTER	18.99	0	7751
6692	9	AIRPLANE POTLUCK	ALAN WATSON	12.99	0	659
6693	10	AIRPLANE POTTER	ZERO BOGART	12.99	0	5791
6694	10	AIRPLANE PREJUDICE	UMA HESTON	25.99	0	7472
6695	10	AIRPLANE PRESIDENT	FARRAH DAFOE	28.99	0	4471
6696	1	AIRPLANE PRIDE	RAY HAWN	11.99	0	7465
6697	15	AIRPLANE PRIMARY	MEL HOPE	28.99	0	2652
6698	16	AIRPLANE PRINCESS	GWYNETH DAFOE	29.99	0	7201
6699	10	AIRPLANE PRIVATE	CHEVY WITHERSPOON	19.99	0	5906
6700	5	AIRPLANE PRIX	RAY GOODING	20.99	0	2691
6701	16	AIRPLANE PSYCHO	MENA FORD	25.99	0	5766
6702	9	AIRPLANE PULP	ALBERT GOODING	13.99	0	6473
6703	8	AIRPLANE PUNK	RUSSELL FAWCETT	26.99	0	2282
6704	9	AIRPLANE PURE	DENNIS TAUTOU	24.99	0	9929
6705	5	AIRPLANE PURPLE	HARRISON MINELLI	11.99	0	6969
6706	6	AIRPLANE QUEEN	ALICIA CRAWFORD	10.99	0	5089
6707	11	AIRPLANE QUEST	SIGOURNEY IRONS	22.99	0	2062
6708	5	AIRPLANE QUILLS	JUDY CRAWFORD	12.99	0	8090
6709	7	AIRPLANE RACER	MEG LEWIS	21.99	0	556
6710	10	AIRPLANE RAGE	MICHAEL MANSFIELD	29.99	0	8839
6711	11	AIRPLANE RAGING	ANNETTE BENING	23.99	0	227
6712	4	AIRPLANE RAIDERS	JUDY PITT	10.99	0	2122
6713	5	AIRPLANE RAINBOW	HENRY OLIVIER	25.99	0	4056
6714	10	AIRPLANE RANDOM	WILLIAM DAY-LEWIS	15.99	0	2706
6715	6	AIRPLANE RANGE	SANDRA GUINESS	9.99	0	5631
6716	15	AIRPLANE REAP	LUCILLE ZELLWEGER	29.99	0	7412
6717	1	AIRPLANE REAR	JOHN TEMPLE	20.99	0	8826
6718	12	AIRPLANE REBEL	LAURA DIAZ	11.99	0	4244
6719	9	AIRPLANE RECORDS	MARISA NORTON	19.99	0	4586
6720	13	AIRPLANE REDEMPTION	RUSSELL FISHER	22.99	0	1967
6721	4	AIRPLANE REDS	DAN DUNST	26.99	0	8790
6722	10	AIRPLANE REEF	OPRAH EASTWOOD	10.99	0	7272
6723	16	AIRPLANE REIGN	WOODY LAW	20.99	0	620
6724	16	AIRPLANE REMEMBER	NICOLE DAY-LEWIS	21.99	0	7285
6725	1	AIRPLANE REQUIEM	ANJELICA KEATON	28.99	0	4250
6726	2	AIRPLANE RESERVOIR	MORGAN GOODING	15.99	0	129
6727	3	AIRPLANE RESURRECTION	GEOFFREY SANDLER	28.99	0	1428
6728	11	AIRPLANE REUNION	MILLA SINATRA	22.99	0	3981
6729	12	AIRPLANE RIDER	LIZA DUNST	18.99	0	3566
6730	4	AIRPLANE RIDGEMONT	SCARLETT WEST	14.99	0	436
6731	11	AIRPLANE RIGHT	JADA WILSON	17.99	0	6476
6732	7	AIRPLANE RINGS	JEFF HOPE	24.99	0	3183
6733	14	AIRPLANE RIVER	CATE BARRYMORE	21.99	0	4806
6734	16	AIRPLANE ROAD	PEARL HAWN	21.99	0	6737
6735	16	AIRPLANE ROBBERS	LUCILLE BIRCH	26.99	0	4906
6736	14	AIRPLANE ROBBERY	JEREMY AFFLECK	15.99	0	7253
6737	16	AIRPLANE ROCK	CHRISTOPHER SILVERSTONE	17.99	0	5536
6738	12	AIRPLANE ROCKETEER	LEONARDO HARRIS	26.99	0	3026
6739	6	AIRPLANE ROCKY	MORGAN WILLIAMS	11.99	0	6075
6740	13	AIRPLANE ROLLERCOASTER	MENA JOVOVICH	17.99	0	187
6741	15	AIRPLANE ROMAN	ALBERT DAFOE	16.99	0	4266
6742	2	AIRPLANE ROOF	ED HOFFMAN	14.99	0	7811
6743	13	AIRPLANE ROOM	DAN KUDROW	17.99	0	1764
6744	12	AIRPLANE ROOTS	CATE PESCI	18.99	0	6918
6745	1	AIRPLANE ROSES	DANIEL MARX	24.99	0	5333
6746	12	AIRPLANE ROUGE	NICK TYLER	25.99	0	2383
6747	4	AIRPLANE ROXANNE	MEL FREEMAN	18.99	0	5199
6748	4	AIRPLANE RUGRATS	ANTHONY HANNAH	17.99	0	4651
6749	10	AIRPLANE RULES	CUBA KEATON	24.99	0	180
6750	7	AIRPLANE RUN	LUCILLE WITHERSPOON	21.99	0	6401
6751	3	AIRPLANE RUNAWAY	KEVIN HOPKINS	27.99	0	8188
6752	2	AIRPLANE RUNNER	CHRISTIAN HAWN	25.99	0	7657
6753	6	AIRPLANE RUSH	CHRISTIAN BERGEN	17.99	0	9796
6754	14	AIRPLANE RUSHMORE	JON BEATTY	9.99	0	4447
6755	1	AIRPLANE SABRINA	JADA CRONYN	23.99	0	1391
6756	6	AIRPLANE SADDLE	LEELEE WATSON	27.99	0	8145
6757	12	AIRPLANE SAGEBRUSH	DREW WATSON	27.99	0	806
6758	11	AIRPLANE SAINTS	CHARLIZE BENING	25.99	0	6193
6759	13	AIRPLANE SALUTE	MATTHEW FAWCETT	14.99	0	4487
6760	12	AIRPLANE SAMURAI	MADELINE HAWKE	12.99	0	4284
6761	5	AIRPLANE SANTA	HALLE HECHE	27.99	0	1848
6762	12	AIRPLANE SASSY	CARMEN AFFLECK	28.99	0	8613
6763	1	AIRPLANE SATISFACTION	SYLVESTER JOHANSSON	12.99	0	3716
6764	13	AIRPLANE SATURDAY	MEG BERRY	18.99	0	262
6765	15	AIRPLANE SATURN	JANE BERRY	20.99	0	5364
6766	16	AIRPLANE SAVANNAH	WARREN KEATON	15.99	0	2690
6767	9	AIRPLANE SCALAWAG	ETHAN BOGART	22.99	0	1419
6768	8	AIRPLANE SCARFACE	MARILYN BAILEY	17.99	0	9399
6769	13	AIRPLANE SCHOOL	ALAN WILLIS	18.99	0	3740
6770	8	AIRPLANE SCISSORHANDS	JENNIFER FAWCETT	28.99	0	6786
6771	8	AIRPLANE SCORPION	DANIEL RYDER	17.99	0	5960
6772	12	AIRPLANE SEA	MERYL MCKELLEN	29.99	0	7178
6773	2	AIRPLANE SEABISCUIT	OLYMPIA PRESLEY	24.99	0	9373
6774	12	AIRPLANE SEARCHERS	SISSY WILLIAMS	23.99	0	3072
6775	2	AIRPLANE SEATTLE	LISA TURNER	20.99	0	4499
6776	4	AIRPLANE SECRET	EDWARD DUNST	17.99	0	3660
6777	1	AIRPLANE SECRETARY	ZERO HAWN	23.99	0	2586
6778	7	AIRPLANE SECRETS	AL JACKMAN	12.99	0	1843
6779	2	AIRPLANE SENSE	CHARLES WATSON	9.99	0	5594
6780	5	AIRPLANE SENSIBILITY	JIM PFEIFFER	28.99	0	3017
6781	6	AIRPLANE SEVEN	LENA HUNT	21.99	0	3216
6782	16	AIRPLANE SHAKESPEARE	NICK THERON	29.99	0	1240
6783	4	AIRPLANE SHANE	LIV ZELLWEGER	14.99	0	8633
6784	7	AIRPLANE SHANGHAI	REESE DIAZ	21.99	0	4420
6785	3	AIRPLANE SHAWSHANK	CHRISTIAN LEWIS	21.99	0	4285
6786	15	AIRPLANE SHEPHERD	SOPHIA TANDY	19.99	0	7810
6787	14	AIRPLANE SHINING	MATT HORNE	20.99	0	2467
6788	11	AIRPLANE SHIP	ED NICHOLSON	15.99	0	4046
6789	3	AIRPLANE SHOCK	MATT GARCIA	29.99	0	9330
6790	7	AIRPLANE SHOOTIST	JUDE BERGMAN	21.99	0	9977
6791	1	AIRPLANE SHOW	SALMA LOLLOBRIGIDA	28.99	0	3406
6792	12	AIRPLANE SHREK	RENEE TURNER	16.99	0	2418
6793	10	AIRPLANE SHRUNK	SUSAN CHASE	26.99	0	8460
6794	4	AIRPLANE SIDE	DEBBIE MCKELLEN	28.99	0	1468
6795	14	AIRPLANE SIEGE	DENZEL AKROYD	16.99	0	8952
6796	6	AIRPLANE SIERRA	JOAN MALDEN	13.99	0	5563
6797	9	AIRPLANE SILENCE	JESSICA CRONYN	16.99	0	9315
6798	10	AIRPLANE SILVERADO	BETTE CAINE	19.99	0	5496
6799	6	AIRPLANE SIMON	CLINT DEAN	20.99	0	7779
6800	12	AIRPLANE SINNERS	PENELOPE WRAY	28.99	0	3691
6801	14	AIRPLANE SISTER	WALTER ODONNELL	15.99	0	4565
6802	14	AIRPLANE SKY	MARILYN HOPPER	15.99	0	1787
6803	5	AIRPLANE SLACKER	GEOFFREY HAWKE	16.99	0	2952
6804	15	AIRPLANE SLEEPING	JULIANNE DRIVER	10.99	0	6637
6805	14	AIRPLANE SLEEPLESS	MARLENE LEWIS	22.99	0	9981
6806	1	AIRPLANE SLEEPY	MERYL FORD	29.99	0	6001
6807	7	AIRPLANE SLEUTH	ANNE JOVOVICH	10.99	0	8741
6808	4	AIRPLANE SLING	FARRAH BLANCHETT	20.99	0	2106
6809	14	AIRPLANE SLIPPER	JON FINNEY	16.99	0	3530
6810	1	AIRPLANE SLUMS	SYLVESTER DENIRO	23.99	0	4330
6811	12	AIRPLANE SMILE	PAUL THERON	17.99	0	4167
6812	16	AIRPLANE SMOKING	SYLVESTER DICAPRIO	9.99	0	7533
6813	15	AIRPLANE SMOOCHY	ROCK LEWIS	13.99	0	2677
6814	7	AIRPLANE SNATCH	LAURENCE WINSLET	28.99	0	9835
6815	5	AIRPLANE SNATCHERS	DORIS GRANT	12.99	0	1091
6816	10	AIRPLANE SNOWMAN	WOODY REYNOLDS	17.99	0	8429
6817	13	AIRPLANE SOLDIERS	CAMERON BULLOCK	24.99	0	4426
6818	8	AIRPLANE SOMETHING	AL BIRCH	15.99	0	1396
6819	10	AIRPLANE SONG	CANDICE ODONNELL	12.99	0	4664
6820	3	AIRPLANE SONS	RUSSELL TANDY	17.99	0	9279
6821	9	AIRPLANE SORORITY	MERYL NEESON	19.99	0	8378
6822	6	AIRPLANE SOUP	WARREN TANDY	18.99	0	1329
6823	15	AIRPLANE SOUTH	DENZEL BERRY	28.99	0	4995
6824	1	AIRPLANE SPARTACUS	DAN WOOD	12.99	0	7951
6825	11	AIRPLANE SPEAKEASY	MARLON FONDA	19.99	0	7052
6826	7	AIRPLANE SPEED	HARRISON DAY-LEWIS	11.99	0	4283
6827	15	AIRPLANE SPICE	FRANCES BASINGER	27.99	0	8867
6828	1	AIRPLANE SPIKING	WARREN HACKMAN	14.99	0	3644
6829	13	AIRPLANE SPINAL	GRETA FOSTER	28.99	0	5234
6830	12	AIRPLANE SPIRIT	SALLY CAGE	17.99	0	5782
6831	2	AIRPLANE SPIRITED	RENEE ANISTON	18.99	0	5189
6832	15	AIRPLANE SPLASH	LANA BEATTY	13.99	0	769
6833	2	AIRPLANE SPLENDOR	JOAN WRAY	9.99	0	7721
6834	7	AIRPLANE SPOILERS	CANDICE WRAY	25.99	0	6218
6835	5	AIRPLANE SPY	OLYMPIA NICHOLSON	11.99	0	3667
6836	12	AIRPLANE SQUAD	HENRY COSTNER	19.99	0	5046
6837	1	AIRPLANE STAGE	KIRK KUDROW	21.99	0	5177
6838	12	AIRPLANE STAGECOACH	JUDI SINATRA	12.99	0	7525
6839	15	AIRPLANE STALLION	NICOLE DIETRICH	10.99	0	6818
6840	11	AIRPLANE STAMPEDE	GROUCHO FIENNES	17.99	0	4279
6841	13	AIRPLANE STAR	LENA CRONYN	12.99	0	2444
6842	11	AIRPLANE STATE	RALPH PITT	14.99	0	5280
6843	13	AIRPLANE STEEL	GREGORY BALL	14.99	0	2085
6844	1	AIRPLANE STEERS	JODIE CAINE	25.99	0	5124
6845	8	AIRPLANE STEPMOM	ROBIN TANDY	25.99	0	2924
6846	4	AIRPLANE STING	JOAN BIRCH	26.99	0	1732
6847	2	AIRPLANE STOCK	STEVE WAYNE	27.99	0	2667
6848	7	AIRPLANE STONE	GARY WEAVER	24.99	0	5144
6849	16	AIRPLANE STORM	MARLENE DENIRO	18.99	0	8421
6850	16	AIRPLANE STORY	MICHELLE HUDSON	25.99	0	9910
6851	2	AIRPLANE STRAIGHT	AUDREY JOVOVICH	20.99	0	3324
6852	12	AIRPLANE STRANGELOVE	EWAN HAYEK	22.99	0	4647
6853	15	AIRPLANE STRANGER	IAN ODONNELL	13.99	0	6360
6854	12	AIRPLANE STRANGERS	SHIRLEY GRANT	16.99	0	8957
6855	4	AIRPLANE STREAK	GWYNETH REYNOLDS	28.99	0	6344
6856	15	AIRPLANE STREETCAR	CHARLES MARTIN	29.99	0	4877
6857	5	AIRPLANE STRICTLY	STEVE SWANK	21.99	0	2055
6858	1	AIRPLANE SUBMARINE	SISSY GOLDBERG	18.99	0	3308
6859	2	AIRPLANE SUGAR	MIRA DUNST	29.99	0	5344
6860	15	AIRPLANE SUICIDES	FRANCES TEMPLE	14.99	0	8307
6861	14	AIRPLANE SUIT	JAMES OLIVIER	9.99	0	5770
6862	9	AIRPLANE SUMMER	JAMES WOOD	17.99	0	9155
6863	10	AIRPLANE SUN	FRANCES MCGREGOR	19.99	0	8694
6864	14	AIRPLANE SUNDANCE	CHRIS CRUISE	20.99	0	8300
6865	2	AIRPLANE SUNRISE	MILLA BEATTY	17.99	0	5000
6866	4	AIRPLANE SUNSET	DANIEL COSTNER	22.99	0	8759
6867	4	AIRPLANE SUPER	SALMA OLIVIER	23.99	0	4381
6868	10	AIRPLANE SUPERFLY	ANNETTE PHOENIX	27.99	0	1570
6869	12	AIRPLANE SUSPECTS	GRETA BOLGER	28.99	0	5302
6870	12	AIRPLANE SWARM	LAURENCE ROBBINS	18.99	0	8850
6871	16	AIRPLANE SWEDEN	ANNE GUINESS	12.99	0	2467
6872	1	AIRPLANE SWEET	UMA DUKAKIS	27.99	0	539
6873	6	AIRPLANE SWEETHEARTS	RALPH KUDROW	17.99	0	424
6874	9	AIRPLANE TADPOLE	CHARLIZE COSTNER	27.99	0	8162
6875	7	AIRPLANE TALENTED	LAURENCE SMITH	9.99	0	7552
6876	15	AIRPLANE TARZAN	CHARLIZE DAY-LEWIS	29.99	0	2042
6877	4	AIRPLANE TAXI	JON GUINESS	12.99	0	4593
6878	4	AIRPLANE TEEN	ADRIEN MARTIN	29.99	1	4337
6879	1	AIRPLANE TELEGRAPH	LIAM KILMER	12.99	0	6893
6880	16	AIRPLANE TELEMARK	JUDY TANDY	21.99	0	7866
6881	6	AIRPLANE TEMPLE	ADRIEN ROBERTS	19.99	0	3761
6882	12	AIRPLANE TENENBAUMS	PARKER WATSON	12.99	0	451
6883	11	AIRPLANE TEQUILA	MARISA DREYFUSS	22.99	0	6378
6884	2	AIRPLANE TERMINATOR	CHRISTOPHER DUNST	23.99	0	6078
6885	7	AIRPLANE TEXAS	JIM HUDSON	27.99	0	3453
6886	11	AIRPLANE THEORY	CARMEN GOODING	23.99	0	8549
6887	2	AIRPLANE THIEF	RAY LANCASTER	26.99	0	8738
6888	15	AIRPLANE THIN	CHARLTON GOODING	20.99	0	4234
6889	3	AIRPLANE TIES	MORGAN BRODY	16.99	0	1965
6890	16	AIRPLANE TIGHTS	MARY CRUISE	17.99	0	7093
6891	13	AIRPLANE TIMBERLAND	BOB RICKMAN	27.99	0	9556
6892	12	AIRPLANE TITANIC	JUDI KEITEL	20.99	0	2475
6893	7	AIRPLANE TITANS	LUCILLE DEE	20.99	0	6643
6894	16	AIRPLANE TOMATOES	PENELOPE VOIGHT	23.99	0	5959
6895	15	AIRPLANE TOMORROW	RALPH CRUZ	20.99	0	8751
6896	5	AIRPLANE TOOTSIE	MARILYN GARLAND	16.99	0	996
6897	6	AIRPLANE TORQUE	LIZA WITHERSPOON	26.99	0	9747
6898	2	AIRPLANE TOURIST	DEBBIE TURNER	23.99	0	9609
6899	6	AIRPLANE TOWERS	SEAN HOFFMAN	12.99	0	1316
6900	12	AIRPLANE TOWN	GLENN BALE	20.99	0	9388
6901	7	AIRPLANE TRACY	GARY TAUTOU	10.99	0	5548
6902	3	AIRPLANE TRADING	KATE KINNEAR	25.99	0	459
6903	12	AIRPLANE TRAFFIC	VIVIEN HESTON	29.99	0	4183
6904	15	AIRPLANE TRAIN	SALMA JOLIE	25.99	0	20
6905	15	AIRPLANE TRAINSPOTTING	ANGELA HACKMAN	14.99	0	6385
6906	4	AIRPLANE TRAMP	JUDI FOSTER	19.99	0	7313
6907	1	AIRPLANE TRANSLATION	ETHAN KINNEAR	21.99	0	6365
6908	11	AIRPLANE TRAP	AUDREY BENING	21.99	0	2090
6909	1	AIRPLANE TREASURE	MINNIE WALKEN	27.99	0	3633
6910	14	AIRPLANE TREATMENT	ORLANDO MINELLI	28.99	0	6922
6911	9	AIRPLANE TRIP	ALICIA BIRCH	10.99	0	4242
6912	13	AIRPLANE TROJAN	WHOOPI MCKELLEN	10.99	0	2831
6913	12	AIRPLANE TROOPERS	GREGORY SWANK	25.99	0	3605
6914	16	AIRPLANE TROUBLE	FAY HOPPER	23.99	0	86
6915	1	AIRPLANE TRUMAN	MARLENE CRUISE	26.99	0	5456
6916	9	AIRPLANE TURN	MADELINE MONROE	20.99	0	2126
6917	16	AIRPLANE TUXEDO	RUBY JACKMAN	28.99	0	702
6918	4	AIRPLANE TWISTED	THORA DENCH	20.99	0	3772
6919	15	AIRPLANE TYCOON	ROBIN WOOD	13.99	0	1583
6920	4	AIRPLANE UNBREAKABLE	GRETA PESCI	27.99	0	4580
6921	7	AIRPLANE UNCUT	CAMERON BAILEY	9.99	0	8199
6922	5	AIRPLANE UNDEFEATED	GENE KELLY	11.99	0	8643
6923	3	AIRPLANE UNFAITHFUL	BURT MOSTEL	11.99	0	1196
6924	8	AIRPLANE UNFORGIVEN	BURT CAGE	15.99	0	7768
6925	8	AIRPLANE UNITED	JON KUDROW	26.99	0	294
6926	5	AIRPLANE UNTOUCHABLES	ANNETTE SMITH	17.99	0	6318
6927	4	AIRPLANE UPRISING	CHEVY BRANDO	19.99	0	6130
6928	7	AIRPLANE UPTOWN	EWAN GOODING	19.99	0	4939
6929	10	AIRPLANE USUAL	LUCILLE WILLIAMS	24.99	0	9643
6930	8	AIRPLANE VACATION	JUDY PHOENIX	29.99	0	9275
6931	1	AIRPLANE VALENTINE	OLYMPIA SOBIESKI	10.99	0	6127
6932	12	AIRPLANE VALLEY	NATALIE HECHE	27.99	0	9412
6933	8	AIRPLANE VAMPIRE	GINA FORD	25.99	0	8048
6934	5	AIRPLANE VANILLA	ORLANDO HOPKINS	27.99	0	255
6935	14	AIRPLANE VANISHED	OPRAH NEESON	16.99	0	3092
6936	5	AIRPLANE VANISHING	CATE NORTON	9.99	0	3582
6937	11	AIRPLANE VARSITY	RALPH JOHANSSON	17.99	0	7390
6938	6	AIRPLANE VELVET	BELA TAUTOU	22.99	0	9132
6939	8	AIRPLANE VERTIGO	GWYNETH TORN	13.99	0	5357
6940	4	AIRPLANE VICTORY	DARYL MCQUEEN	29.99	0	8695
6941	5	AIRPLANE VIDEOTAPE	KIM EASTWOOD	18.99	0	3364
6942	13	AIRPLANE VIETNAM	ROBIN AFFLECK	21.99	0	2099
6943	6	AIRPLANE VILLAIN	BELA PECK	17.99	0	7139
6944	6	AIRPLANE VIRGIN	LISA SINATRA	23.99	0	3980
6945	4	AIRPLANE VIRGINIAN	ANDY DIETRICH	17.99	0	435
6946	5	AIRPLANE VIRTUAL	GREG LOLLOBRIGIDA	26.99	0	6889
6947	4	AIRPLANE VISION	MERYL SOBIESKI	9.99	0	777
6948	4	AIRPLANE VOICE	RAY POITIER	15.99	0	1522
6949	1	AIRPLANE VOLCANO	WHOOPI HURT	22.99	0	4
6950	1	AIRPLANE VOLUME	ETHAN GOODING	10.99	0	5432
6951	2	AIRPLANE VOYAGE	CARMEN BRANAGH	18.99	0	1441
6952	3	AIRPLANE WAGON	WILL CHAPLIN	26.99	0	3904
6953	15	AIRPLANE WAIT	CATE HARRIS	23.99	0	2965
6954	14	AIRPLANE WAKE	PAUL POITIER	26.99	0	9388
6955	14	AIRPLANE WALLS	GINA HAWN	11.99	0	1344
6956	11	AIRPLANE WANDA	ED MARX	25.99	0	2006
6957	15	AIRPLANE WAR	GRETA DAY	27.99	0	5262
6958	5	AIRPLANE WARDROBE	TOM WINFREY	17.99	0	6560
6959	12	AIRPLANE WARLOCK	HUME KILMER	19.99	0	7864
6960	7	AIRPLANE WARS	DEBBIE CRUZ	24.99	0	6969
6961	15	AIRPLANE WASH	FRED WAYNE	11.99	0	3715
6962	6	AIRPLANE WASTELAND	LAURENCE MCCONAUGHEY	23.99	0	6426
6963	4	AIRPLANE WATCH	LIV RICKMAN	11.99	0	2951
6964	13	AIRPLANE WATERFRONT	ROBIN THERON	12.99	0	2017
6965	16	AIRPLANE WATERSHIP	HUGH RUSH	12.99	0	6945
6966	15	AIRPLANE WEDDING	MAE HARRIS	12.99	0	3422
6967	9	AIRPLANE WEEKEND	WALTER STALLONE	11.99	0	4531
6968	13	AIRPLANE WEREWOLF	DENZEL PECK	17.99	0	3962
6969	12	AIRPLANE WEST	EWAN MCKELLEN	20.99	0	6440
6970	12	AIRPLANE WESTWARD	JADA RYDER	11.99	0	9578
6971	14	AIRPLANE WHALE	GWYNETH SWANK	18.99	0	8904
6972	13	AIRPLANE WHISPERER	NEVE MALDEN	24.99	0	2498
6973	4	AIRPLANE WIFE	WARREN KEATON	18.99	0	8039
6974	14	AIRPLANE WILD	JAMES MATTHAU	11.99	0	2542
6975	12	AIRPLANE WILLOW	ANJELICA TAYLOR	12.99	1	287
6976	3	AIRPLANE WIND	SIDNEY SMITH	19.99	0	9249
6977	7	AIRPLANE WINDOW	JULIA BERRY	11.99	0	2538
6978	7	AIRPLANE WISDOM	PAUL BARRYMORE	16.99	0	6914
6979	3	AIRPLANE WITCHES	FRED EASTWOOD	21.99	0	4450
6980	14	AIRPLANE WIZARD	GEOFFREY CHASE	27.99	0	3150
6981	15	AIRPLANE WOLVES	CATE HUNT	25.99	0	4147
6982	12	AIRPLANE WOMEN	JOHNNY GARCIA	13.99	0	3297
6983	8	AIRPLANE WON	HARVEY TAUTOU	14.99	0	8530
6984	16	AIRPLANE WONDERFUL	CHEVY FOSTER	14.99	0	5637
6985	12	AIRPLANE WONDERLAND	MORGAN POITIER	9.99	0	569
6986	6	AIRPLANE WONKA	JULIETTE KIDMAN	18.99	0	5012
6987	15	AIRPLANE WORDS	SALMA BARRYMORE	16.99	0	3548
6988	12	AIRPLANE WORKER	DIANE ROBBINS	10.99	0	4231
6989	16	AIRPLANE WORKING	PARKER WRAY	10.99	0	6842
6990	11	AIRPLANE WORLD	JAMES WEST	16.99	0	572
6991	7	AIRPLANE WORST	LEELEE FAWCETT	29.99	0	9193
6992	8	AIRPLANE WRATH	WHOOPI NEESON	15.99	0	2484
6993	11	AIRPLANE WRONG	ALBERT POSEY	28.99	0	591
6994	6	AIRPLANE WYOMING	ANJELICA ROBERTS	10.99	0	3021
6995	13	AIRPLANE YENTL	ELLEN KELLY	13.99	0	2315
6996	5	AIRPLANE YOUNG	KATHARINE FOSTER	27.99	0	3219
6997	13	AIRPLANE YOUTH	WINONA RICKMAN	24.99	0	329
6998	16	AIRPLANE ZHIVAGO	RALPH RUSH	9.99	0	6249
6999	2	AIRPLANE ZOOLANDER	HUME ANISTON	11.99	0	2709
7000	7	AIRPLANE ZORRO	REESE THURMAN	23.99	0	7027
7001	15	AIRPORT ACADEMY	ANGELA GARCIA	18.99	0	3464
7002	13	AIRPORT ACE	CAMERON ZELLWEGER	25.99	0	2131
7003	13	AIRPORT ADAPTATION	ZERO PHOENIX	21.99	0	6837
7004	4	AIRPORT AFFAIR	MICHAEL SINATRA	21.99	0	8097
7005	15	AIRPORT AFRICAN	MICHAEL GARLAND	23.99	0	7962
7006	7	AIRPORT AGENT	CHRIS WILLIS	17.99	0	3829
7007	13	AIRPORT AIRPLANE	HELEN CRUISE	27.99	0	1248
7008	2	AIRPORT AIRPORT	SALLY POSEY	10.99	0	6040
7009	13	AIRPORT ALABAMA	JACK KINNEAR	18.99	0	3627
7010	5	AIRPORT ALADDIN	NATALIE BAILEY	29.99	0	7757
7011	13	AIRPORT ALAMO	NICK BLOOM	28.99	0	1511
7012	6	AIRPORT ALASKA	GREG DREYFUSS	23.99	0	2973
7013	14	AIRPORT ALI	ANGELINA DIAZ	23.99	0	3848
7014	5	AIRPORT ALICE	THORA CAGE	24.99	0	811
7015	2	AIRPORT ALIEN	CAMERON TORN	25.99	0	8246
7016	10	AIRPORT ALLEY	SUSAN MOSTEL	15.99	0	4295
7017	8	AIRPORT ALONE	MINNIE WAHLBERG	26.99	0	8802
7018	2	AIRPORT ALTER	CHARLES HORNE	12.99	0	5025
7019	9	AIRPORT AMADEUS	MAE HOFFMAN	18.99	0	2473
7020	9	AIRPORT AMELIE	CHARLES DEE	22.99	0	240
7021	8	AIRPORT AMERICAN	MEL MCDORMAND	17.99	0	2858
7022	14	AIRPORT AMISTAD	DENNIS HARRIS	20.99	0	8413
7023	7	AIRPORT ANACONDA	FRED FINNEY	21.99	0	4527
7024	2	AIRPORT ANALYZE	SISSY ASTAIRE	23.99	0	524
7025	16	AIRPORT ANGELS	FAY BALL	11.99	0	3259
7026	3	AIRPORT ANNIE	VAL CRUZ	26.99	0	8839
7027	2	AIRPORT ANONYMOUS	FAY HESTON	15.99	0	5053
7028	3	AIRPORT ANTHEM	ROBERT HAWKE	18.99	0	3088
7029	15	AIRPORT ANTITRUST	GOLDIE BEATTY	25.99	0	8223
7030	14	AIRPORT ANYTHING	SANDRA PFEIFFER	11.99	0	5729
7031	8	AIRPORT APACHE	PAUL WILLIAMS	17.99	0	3726
7032	5	AIRPORT APOCALYPSE	RICHARD TANDY	21.99	0	7939
7033	2	AIRPORT APOLLO	DEBBIE FIENNES	28.99	0	1894
7034	4	AIRPORT ARABIA	EDWARD NEWMAN	20.99	0	176
7035	7	AIRPORT ARACHNOPHOBIA	NICOLE FINNEY	14.99	0	5764
7036	14	AIRPORT ARGONAUTS	KARL WALKEN	21.99	0	3003
7037	16	AIRPORT ARIZONA	CHRIS MCGREGOR	25.99	0	3348
7038	9	AIRPORT ARK	MARLENE EASTWOOD	25.99	0	4239
7039	16	AIRPORT ARMAGEDDON	BRAD HOFFMAN	13.99	1	5702
7040	4	AIRPORT ARMY	SIGOURNEY GOLDBERG	29.99	0	3558
7041	9	AIRPORT ARSENIC	FARRAH HESTON	10.99	0	6162
7042	7	AIRPORT ARTIST	EDWARD WITHERSPOON	20.99	0	4575
7043	15	AIRPORT ATLANTIS	OPRAH FIELD	20.99	0	9759
7044	16	AIRPORT ATTACKS	INGRID BALL	10.99	0	4191
7045	10	AIRPORT ATTRACTION	REESE HUDSON	19.99	0	4191
7046	14	AIRPORT AUTUMN	SALLY WITHERSPOON	12.99	0	8820
7047	13	AIRPORT BABY	SANDRA HESTON	9.99	0	6183
7048	8	AIRPORT BACKLASH	TIM SWANK	13.99	0	162
7049	4	AIRPORT BADMAN	ANNE FOSTER	22.99	0	3021
7050	1	AIRPORT BAKED	PAUL ANISTON	26.99	0	2076
7051	5	AIRPORT BALLOON	CUBA HARRIS	11.99	0	2500
7052	1	AIRPORT BALLROOM	MENA FONDA	27.99	0	6692
7053	8	AIRPORT BANG	JULIETTE SINATRA	17.99	0	9155
7054	7	AIRPORT BANGER	ELLEN DEPP	19.99	0	6545
7055	13	AIRPORT BARBARELLA	MATTHEW WAHLBERG	20.99	0	2076
7056	13	AIRPORT BAREFOOT	LISA BACALL	29.99	0	1753
7057	4	AIRPORT BASIC	JUDI CAMPBELL	27.99	0	8502
7058	10	AIRPORT BEACH	MATT JACKMAN	10.99	0	7144
7059	1	AIRPORT BEAR	WHOOPI FREEMAN	14.99	0	8467
7060	15	AIRPORT BEAST	PARKER MCGREGOR	21.99	0	5352
7061	13	AIRPORT BEAUTY	KIRK WILLIS	17.99	0	7053
7062	10	AIRPORT BED	RUBY BULLOCK	11.99	0	8598
7063	16	AIRPORT BEDAZZLED	GRETA MANSFIELD	21.99	0	2658
7064	6	AIRPORT BEETHOVEN	LISA OLIVIER	15.99	0	4463
7065	3	AIRPORT BEHAVIOR	AUDREY TOMEI	28.99	0	2636
7066	8	AIRPORT BENEATH	DIANE DRIVER	9.99	0	1438
7067	12	AIRPORT BERETS	ETHAN EASTWOOD	20.99	0	3017
7068	7	AIRPORT BETRAYED	SISSY FREEMAN	25.99	0	5870
7069	1	AIRPORT BEVERLY	FAY DUKAKIS	22.99	0	2545
7070	2	AIRPORT BIKINI	CHARLIZE PINKETT	12.99	0	6322
7071	8	AIRPORT BILKO	SYLVESTER BOGART	22.99	0	6296
7072	13	AIRPORT BILL	TIM SOBIESKI	10.99	0	3294
7073	7	AIRPORT BINGO	MEG SINATRA	14.99	0	6403
7074	14	AIRPORT BIRCH	TIM MCQUEEN	12.99	0	5247
7075	7	AIRPORT BIRD	ELVIS HACKMAN	20.99	0	9099
7076	3	AIRPORT BIRDCAGE	ADRIEN ALLEN	11.99	0	1188
7077	12	AIRPORT BIRDS	UMA HUSTON	22.99	0	3353
7078	16	AIRPORT BLACKOUT	CHARLTON WAYNE	23.99	0	7465
7079	6	AIRPORT BLADE	HENRY BLANCHETT	14.99	0	6822
7080	13	AIRPORT BLANKET	BELA MIRANDA	9.99	0	6533
7081	16	AIRPORT BLINDNESS	MATT GOODING	28.99	0	3412
7082	2	AIRPORT BLOOD	RIVER DEAN	9.99	0	3852
7083	6	AIRPORT BLUES	GLENN THURMAN	19.99	0	5518
7084	4	AIRPORT BOILED	MARILYN TAYLOR	22.99	0	8813
7085	6	AIRPORT BONNIE	JULIETTE THURMAN	17.99	0	7288
7086	1	AIRPORT BOOGIE	CAMERON TANDY	23.99	0	6033
7087	1	AIRPORT BOONDOCK	ROBERT TEMPLE	27.99	0	7215
7088	5	AIRPORT BORN	LIAM DEGENERES	21.99	0	1684
7089	3	AIRPORT BORROWERS	ANGELA WITHERSPOON	25.99	0	1587
7090	11	AIRPORT BOULEVARD	ANGELINA WASHINGTON	13.99	0	9672
7091	15	AIRPORT BOUND	ROBERT GIBSON	9.99	0	6374
7092	11	AIRPORT BOWFINGER	JULIA CAINE	18.99	0	4067
7093	4	AIRPORT BRANNIGAN	MARISA DOUGLAS	25.99	0	3840
7094	16	AIRPORT BRAVEHEART	HALLE ALLEN	9.99	0	9839
7095	3	AIRPORT BREAKFAST	STEVE HORNE	13.99	0	2384
7096	3	AIRPORT BREAKING	LISA LOLLOBRIGIDA	9.99	0	6949
7097	11	AIRPORT BRIDE	ROBIN DEPP	12.99	0	8501
7098	10	AIRPORT BRIGHT	CARRIE TURNER	13.99	0	9990
7099	10	AIRPORT BRINGING	AL NEWMAN	29.99	0	8096
7100	16	AIRPORT BROOKLYN	ETHAN STREEP	27.99	0	9273
7101	2	AIRPORT BROTHERHOOD	JUDI DENCH	23.99	0	1194
7102	7	AIRPORT BUBBLE	HARRISON TOMEI	14.99	0	922
7103	2	AIRPORT BUCKET	ADAM MCDORMAND	13.99	0	7103
7104	4	AIRPORT BUGSY	HELEN HEPBURN	13.99	0	666
7105	1	AIRPORT BULL	STEVE FREEMAN	15.99	0	9740
7106	4	AIRPORT BULWORTH	DENNIS FAWCETT	24.99	0	4627
7107	14	AIRPORT BUNCH	GROUCHO HECHE	13.99	0	4101
7108	6	AIRPORT BUTCH	ALICIA PRESLEY	15.99	0	8662
7109	1	AIRPORT BUTTERFLY	FRANK CRUISE	17.99	0	6945
7110	8	AIRPORT CABIN	ANDY HORNE	17.99	0	2483
7111	7	AIRPORT CADDYSHACK	KIM ALLEN	21.99	0	5790
7112	1	AIRPORT CALENDAR	ADRIEN MCDORMAND	17.99	0	6733
7113	14	AIRPORT CALIFORNIA	JAMES CRONYN	26.99	0	4065
7114	12	AIRPORT CAMELOT	LEONARDO LANCASTER	9.99	0	242
7115	12	AIRPORT CAMPUS	JOHN HUDSON	24.99	0	2629
7116	1	AIRPORT CANDIDATE	EWAN DEPP	20.99	0	340
7117	3	AIRPORT CANDLES	MARLON TRACY	12.99	0	5112
7118	14	AIRPORT CANYON	MERYL CAGE	14.99	0	2077
7119	11	AIRPORT CAPER	ORLANDO PALTROW	14.99	0	7374
7120	5	AIRPORT CARIBBEAN	DEBBIE HESTON	25.99	0	786
7121	1	AIRPORT CAROL	GOLDIE CROWE	15.99	0	1750
7122	6	AIRPORT CARRIE	BELA THERON	29.99	0	3877
7123	9	AIRPORT CASABLANCA	JULIANNE STALLONE	13.99	0	5089
7124	7	AIRPORT CASPER	DENZEL PITT	12.99	1	9397
7125	15	AIRPORT CASSIDY	HARVEY DIETRICH	11.99	0	5632
7126	4	AIRPORT CASUALTIES	OLYMPIA BERGEN	19.99	0	4965
7127	12	AIRPORT CAT	HARVEY PECK	25.99	0	4047
7128	3	AIRPORT CATCH	EDWARD DAMON	23.99	0	3356
7129	4	AIRPORT CAUSE	BELA SINATRA	17.99	0	732
7130	6	AIRPORT CELEBRITY	GREGORY THURMAN	24.99	1	3849
7131	5	AIRPORT CENTER	JENNIFER CROWE	9.99	0	8233
7132	9	AIRPORT CHAINSAW	KARL HANNAH	28.99	0	2376
7133	6	AIRPORT CHAMBER	JEFF FISHER	20.99	0	8549
7134	15	AIRPORT CHAMPION	MATTHEW CRUISE	29.99	0	6537
7135	1	AIRPORT CHANCE	KATHARINE WAYNE	17.99	0	5398
7136	13	AIRPORT CHAPLIN	NATALIE WAYNE	13.99	0	4332
7137	1	AIRPORT CHARADE	ROBIN JOLIE	21.99	0	35
7138	14	AIRPORT CHARIOTS	GOLDIE PESCI	14.99	0	3368
7139	2	AIRPORT CHASING	KARL CRAWFORD	25.99	0	1281
7140	8	AIRPORT CHEAPER	ANTHONY CRUZ	29.99	0	7276
7141	9	AIRPORT CHICAGO	MATT GARLAND	14.99	0	6422
7142	12	AIRPORT CHICKEN	CHARLES MIRANDA	19.99	0	5556
7143	9	AIRPORT CHILL	EWAN BASINGER	27.99	0	5621
7144	4	AIRPORT CHINATOWN	NICOLAS HOPE	24.99	0	8909
7145	14	AIRPORT CHISUM	BETTE ODONNELL	28.99	0	6763
7146	11	AIRPORT CHITTY	ANGELA DAVIS	15.99	0	6364
7147	16	AIRPORT CHOCOLAT	FARRAH CHASE	11.99	0	5146
7148	11	AIRPORT CHOCOLATE	KIRSTEN DAMON	28.99	0	8937
7149	9	AIRPORT CHRISTMAS	GREG DERN	14.99	0	5859
7150	3	AIRPORT CIDER	EWAN SPACEK	13.99	0	9600
7151	15	AIRPORT CINCINATTI	CHRISTOPHER HARRIS	28.99	0	6402
7152	10	AIRPORT CIRCUS	REESE NOLTE	26.99	0	4799
7153	6	AIRPORT CITIZEN	MENA HOPE	28.99	0	7535
7154	14	AIRPORT CLASH	AL THURMAN	12.99	0	9972
7155	13	AIRPORT CLEOPATRA	ROBIN DERN	9.99	0	5921
7156	1	AIRPORT CLERKS	ZERO GIBSON	12.99	0	7229
7157	13	AIRPORT CLOCKWORK	HUMPHREY THURMAN	21.99	0	1939
7158	2	AIRPORT CLONES	MARILYN BRANDO	25.99	0	274
7159	9	AIRPORT CLOSER	STEVE THURMAN	20.99	0	424
7160	9	AIRPORT CLUB	FRED SOBIESKI	16.99	0	7813
7161	16	AIRPORT CLUE	CHEVY TAUTOU	29.99	0	4679
7162	12	AIRPORT CLUELESS	GRETA SUVARI	11.99	0	964
7163	5	AIRPORT CLYDE	DEBBIE LANCASTER	28.99	0	2642
7164	16	AIRPORT COAST	CHARLTON TANDY	27.99	0	2170
7165	15	AIRPORT COLDBLOODED	ANGELA WEAVER	13.99	0	9108
7166	16	AIRPORT COLOR	PEARL DUKAKIS	12.99	0	8166
7167	10	AIRPORT COMA	MATT WEAVER	29.99	0	1287
7168	2	AIRPORT COMANCHEROS	MEL FONDA	14.99	0	98
7169	9	AIRPORT COMFORTS	SCARLETT DAY-LEWIS	23.99	0	2775
7170	15	AIRPORT COMMAND	DORIS ALLEN	29.99	0	5497
7171	14	AIRPORT COMMANDMENTS	ROSIE DEAN	22.99	0	1006
7172	8	AIRPORT CONEHEADS	ANGELINA AFFLECK	11.99	0	934
7173	5	AIRPORT CONFESSIONS	JADA BASINGER	28.99	0	6925
7174	16	AIRPORT CONFIDENTIAL	SUSAN THERON	26.99	0	120
7175	2	AIRPORT CONFUSED	ALBERT JOHANSSON	15.99	0	2517
7176	14	AIRPORT CONGENIALITY	JODIE FISHER	24.99	0	8603
7177	14	AIRPORT CONNECTICUT	SALMA HESTON	27.99	0	8440
7178	16	AIRPORT CONNECTION	SISSY SORVINO	17.99	0	2312
7179	2	AIRPORT CONQUERER	CAMERON PESCI	29.99	0	6929
7180	1	AIRPORT CONSPIRACY	CUBA MINELLI	9.99	0	6449
7181	5	AIRPORT CONTACT	WILL STALLONE	24.99	0	9455
7182	10	AIRPORT CONTROL	HELEN GOLDBERG	19.99	0	9559
7183	6	AIRPORT CONVERSATION	RALPH DAFOE	13.99	0	5608
7184	8	AIRPORT CORE	FARRAH NEESON	20.99	0	8293
7185	5	AIRPORT COWBOY	JOAN NEESON	18.99	0	4428
7186	2	AIRPORT CRAFT	FAY WINSLET	10.99	0	8461
7187	1	AIRPORT CRANES	DIANE GARBO	17.99	0	4642
7188	6	AIRPORT CRAZY	MARY COSTNER	11.99	0	2520
7189	12	AIRPORT CREATURES	SUSAN SUVARI	29.99	0	5784
7190	14	AIRPORT CREEPERS	EDWARD NOLTE	15.99	0	9426
7191	12	AIRPORT CROOKED	SYLVESTER DEAN	9.99	0	6599
7192	14	AIRPORT CROSSING	ALAN FAWCETT	10.99	0	8631
7193	9	AIRPORT CROSSROADS	ANDY BEATTY	13.99	0	4324
7194	8	AIRPORT CROW	FAY TORN	17.99	0	7069
7195	16	AIRPORT CROWDS	HENRY OLIVIER	13.99	0	5228
7196	3	AIRPORT CRUELTY	OLYMPIA PECK	10.99	0	461
7197	12	AIRPORT CRUSADE	GRETA MALDEN	24.99	0	560
7198	10	AIRPORT CRYSTAL	CAMERON DEAN	22.99	0	3074
7199	2	AIRPORT CUPBOARD	DARYL TYLER	16.99	0	860
7200	2	AIRPORT CURTAIN	PENELOPE DERN	18.99	0	7662
7201	16	AIRPORT CYCLONE	JOE MCCONAUGHEY	24.99	0	2126
7202	13	AIRPORT DADDY	RICHARD HAWN	11.99	0	4877
7203	4	AIRPORT DAISY	MIRA RUSH	15.99	0	1619
7204	10	AIRPORT DALMATIONS	AUDREY KAHN	26.99	0	3678
7205	15	AIRPORT DANCES	LUCILLE WILLIAMS	23.99	0	913
7206	8	AIRPORT DANCING	MILLA HANNAH	28.99	0	3957
7207	3	AIRPORT DANGEROUS	RITA WAHLBERG	28.99	0	9854
7208	7	AIRPORT DARES	PARKER DEPP	12.99	0	2026
7209	6	AIRPORT DARKNESS	MIRA COOPER	17.99	0	5986
7210	13	AIRPORT DARKO	KEVIN THERON	17.99	0	9719
7211	8	AIRPORT DARLING	HARVEY ALLEN	12.99	0	5177
7212	10	AIRPORT DARN	JAYNE BLANCHETT	17.99	0	5028
7213	7	AIRPORT DATE	OPRAH HUNT	12.99	0	3110
7214	6	AIRPORT DAUGHTER	JODIE WAYNE	10.99	0	4587
7215	11	AIRPORT DAWN	GREG BLOOM	13.99	0	9053
7216	4	AIRPORT DAY	SUSAN WEAVER	20.99	0	8622
7217	2	AIRPORT DAZED	VAL PALTROW	20.99	0	9832
7218	1	AIRPORT DECEIVER	JEREMY HURT	25.99	0	836
7219	2	AIRPORT DEEP	ALEC WINFREY	21.99	0	3616
7220	1	AIRPORT DEER	JENNIFER PALTROW	16.99	0	9261
7221	5	AIRPORT DELIVERANCE	SCARLETT BRANDO	13.99	0	26
7222	1	AIRPORT DESERT	MILLA RICKMAN	9.99	0	8074
7223	16	AIRPORT DESIRE	FARRAH FINNEY	18.99	0	9071
7224	9	AIRPORT DESPERATE	SHIRLEY DAFOE	20.99	0	9199
7225	15	AIRPORT DESTINATION	LIZA SARANDON	16.99	0	5488
7226	5	AIRPORT DESTINY	MARY HOPPER	12.99	0	3449
7227	3	AIRPORT DETAILS	CAMERON PECK	27.99	0	4038
7228	12	AIRPORT DETECTIVE	NATALIE PALTROW	29.99	0	8333
7229	15	AIRPORT DEVIL	ANDY NOLTE	24.99	0	8122
7230	11	AIRPORT DIARY	LIV CHASE	15.99	0	8000
7231	14	AIRPORT DINOSAUR	ELLEN SMITH	19.99	1	9116
7232	14	AIRPORT DIRTY	LIZA COOPER	29.99	0	3426
7233	7	AIRPORT DISCIPLE	ANJELICA PINKETT	11.99	0	2037
7234	15	AIRPORT DISTURBING	SIDNEY MALDEN	29.99	0	1242
7235	13	AIRPORT DIVIDE	FARRAH BACALL	17.99	0	8085
7236	4	AIRPORT DIVINE	MADELINE CROWE	18.99	0	6271
7237	6	AIRPORT DIVORCE	RAY LEIGH	29.99	0	8434
7238	6	AIRPORT DOCTOR	LAUREN TYLER	17.99	0	2923
7239	10	AIRPORT DOGMA	SHIRLEY WEST	19.99	0	2332
7240	10	AIRPORT DOLLS	ELVIS PALTROW	27.99	0	5976
7241	12	AIRPORT DONNIE	RALPH FIENNES	15.99	0	4893
7242	16	AIRPORT DOOM	ANJELICA CARREY	24.99	0	5928
7243	10	AIRPORT DOORS	JUDI IRONS	12.99	0	5234
7244	8	AIRPORT DORADO	JODIE HUDSON	16.99	0	3993
7245	10	AIRPORT DOUBLE	BURT LANCASTER	26.99	0	2182
7246	8	AIRPORT DOUBTFIRE	KARL BULLOCK	13.99	0	3096
7247	12	AIRPORT DOWNHILL	JEREMY HANNAH	25.99	0	6047
7248	6	AIRPORT DOZEN	BETTE PITT	27.99	0	9649
7249	7	AIRPORT DRACULA	JAMES GOLDBERG	27.99	0	3808
7250	5	AIRPORT DRAGON	TIM EASTWOOD	16.99	0	3660
7251	10	AIRPORT DRAGONFLY	JOHNNY LUGOSI	11.99	0	9455
7252	7	AIRPORT DREAM	GREGORY KELLY	27.99	0	5009
7253	8	AIRPORT DRIFTER	ED MOORE	21.99	0	1540
7254	9	AIRPORT DRIVER	JULIETTE VOIGHT	29.99	0	2525
7255	6	AIRPORT DRIVING	KEVIN BASINGER	15.99	0	6997
7256	11	AIRPORT DROP	FARRAH ASTAIRE	12.99	0	957
7257	2	AIRPORT DRUMLINE	LIZA LOREN	18.99	0	9162
7258	16	AIRPORT DRUMS	LANA WINFREY	13.99	0	1003
7259	6	AIRPORT DUCK	ALAN BRIDGES	27.99	0	8068
7260	3	AIRPORT DUDE	SALMA HUDSON	23.99	0	2899
7261	7	AIRPORT DUFFEL	GENE HEPBURN	23.99	0	4573
7262	13	AIRPORT DUMBO	ANDY ODONNELL	17.99	0	5144
7263	5	AIRPORT DURHAM	JOHN BOLGER	27.99	0	508
7264	16	AIRPORT DWARFS	CHRISTIAN MIRANDA	29.99	0	2689
7265	13	AIRPORT DYING	NICK MOORE	22.99	0	5066
7266	16	AIRPORT DYNAMITE	TOM PHOENIX	14.99	0	5299
7267	12	AIRPORT EAGLES	DIANE COOPER	25.99	0	3703
7268	5	AIRPORT EARLY	JOAN TANDY	25.99	0	7669
7269	14	AIRPORT EARRING	IAN PENN	29.99	0	9377
7270	5	AIRPORT EARTH	LEELEE KEATON	29.99	0	9385
7271	8	AIRPORT EASY	MATT CAINE	18.99	0	697
7272	16	AIRPORT EDGE	DUSTIN BULLOCK	12.99	0	7938
7273	9	AIRPORT EFFECT	MARLENE COOPER	9.99	0	3917
7274	13	AIRPORT EGG	BURT POITIER	13.99	0	8206
7275	3	AIRPORT EGYPT	GRACE WITHERSPOON	24.99	0	5205
7276	11	AIRPORT ELEMENT	MARLON HUDSON	16.99	0	623
7277	7	AIRPORT ELEPHANT	CUBA TAUTOU	22.99	0	792
7278	8	AIRPORT ELF	EDWARD MATTHAU	11.99	0	1764
7279	8	AIRPORT ELIZABETH	SYLVESTER HESTON	21.99	0	6521
7280	7	AIRPORT EMPIRE	MADELINE RYDER	24.99	0	6016
7281	5	AIRPORT ENCINO	ANTHONY DAY	28.99	0	9677
7282	1	AIRPORT ENCOUNTERS	ROBIN WITHERSPOON	13.99	0	8880
7283	5	AIRPORT ENDING	JUDE BLANCHETT	19.99	0	1442
7284	12	AIRPORT ENEMY	LAUREN NORTON	21.99	0	2322
7285	5	AIRPORT ENGLISH	ALEC PECK	27.99	0	5639
7286	9	AIRPORT ENOUGH	PENELOPE POSEY	20.99	0	3450
7287	9	AIRPORT ENTRAPMENT	GLENN OLIVIER	16.99	0	9663
7288	5	AIRPORT ESCAPE	ANJELICA CHASE	24.99	0	2456
7289	15	AIRPORT EVE	TIM GARLAND	19.99	0	2205
7290	12	AIRPORT EVERYONE	TIM DENIRO	24.99	0	4047
7291	5	AIRPORT EVOLUTION	CHEVY MIRANDA	10.99	0	8520
7292	7	AIRPORT EXCITEMENT	KENNETH POSEY	25.99	0	4342
7293	12	AIRPORT EXORCIST	LEELEE GOLDBERG	25.99	0	2650
7294	1	AIRPORT EXPECATIONS	MADELINE BALE	29.99	0	6113
7295	3	AIRPORT EXPENDABLE	SALLY DENCH	11.99	0	71
7296	9	AIRPORT EXPRESS	MARLON DUNST	23.99	0	8724
7297	9	AIRPORT EXTRAORDINARY	LIZA SMITH	10.99	0	7461
7298	9	AIRPORT EYES	CARMEN FIELD	11.99	0	2613
7299	6	AIRPORT FACTORY	FRED BULLOCK	29.99	0	8260
7300	10	AIRPORT FALCON	ANTHONY DICAPRIO	18.99	0	593
7301	8	AIRPORT FAMILY	GROUCHO TORN	11.99	0	7469
7302	1	AIRPORT FANTASIA	LANA BOLGER	22.99	0	1559
7303	6	AIRPORT FANTASY	JOAN NOLTE	19.99	0	5675
7304	13	AIRPORT FARGO	MERYL CHAPLIN	10.99	0	7790
7305	15	AIRPORT FATAL	ANGELINA POSEY	29.99	0	4244
7306	1	AIRPORT FEATHERS	GINA ODONNELL	16.99	0	8932
7307	2	AIRPORT FELLOWSHIP	WOODY SOBIESKI	23.99	0	1683
7308	14	AIRPORT FERRIS	RUSSELL SMITH	15.99	0	6375
7309	15	AIRPORT FEUD	RALPH BERRY	21.99	0	9350
7310	6	AIRPORT FEVER	MENA ASTAIRE	17.99	0	9098
7311	14	AIRPORT FICTION	LEONARDO WRAY	12.99	0	4283
7312	1	AIRPORT FIDDLER	ELIZABETH HUSTON	9.99	0	7063
7313	4	AIRPORT FIDELITY	KARL ANISTON	10.99	0	8525
7314	12	AIRPORT FIGHT	TIM DAVIS	19.99	0	706
7315	7	AIRPORT FINDING	BOB CAMPBELL	11.99	0	712
7316	1	AIRPORT FIRE	ANNETTE GARLAND	21.99	0	4254
7317	1	AIRPORT FIREBALL	SPENCER KUDROW	15.99	0	775
7318	1	AIRPORT FIREHOUSE	BOB RUSH	20.99	0	4228
7319	7	AIRPORT FISH	MAE KEITEL	15.99	1	4235
7320	7	AIRPORT FLAMINGOS	KIRSTEN HAWKE	19.99	0	1085
7321	9	AIRPORT FLASH	JODIE KEITEL	21.99	0	9867
7322	1	AIRPORT FLATLINERS	KATE CRONYN	28.99	0	1175
7323	1	AIRPORT FLIGHT	SISSY IRONS	11.99	0	7304
7324	9	AIRPORT FLINTSTONES	ELIZABETH HARRIS	12.99	0	2518
7325	10	AIRPORT FLOATS	MARY BRIDGES	12.99	0	1771
7326	5	AIRPORT FLYING	MICHELLE CHASE	24.99	0	8420
7327	12	AIRPORT FOOL	ALEC SINATRA	14.99	0	5078
7328	7	AIRPORT FOREVER	WOODY RYAN	15.99	0	145
7329	1	AIRPORT FORREST	JACK HOPKINS	14.99	0	1504
7330	9	AIRPORT FORRESTER	EMILY DEE	12.99	0	8696
7331	6	AIRPORT FORWARD	ALEC NICHOLSON	10.99	0	7991
7332	15	AIRPORT FRANKENSTEIN	LISA CLOSE	28.99	0	3797
7333	8	AIRPORT FREAKY	CHRISTOPHER SOBIESKI	18.99	0	830
7334	8	AIRPORT FREDDY	KATE CAINE	27.99	0	1682
7335	1	AIRPORT FREEDOM	HUME WASHINGTON	15.99	0	8006
7336	3	AIRPORT FRENCH	JODIE HUSTON	12.99	0	9023
7337	16	AIRPORT FRIDA	ANTHONY HOPPER	21.99	0	5035
7338	16	AIRPORT FRISCO	GOLDIE SORVINO	12.99	0	4503
7339	4	AIRPORT FROGMEN	LAURENCE PESCI	25.99	0	9975
7340	16	AIRPORT FRONTIER	TIM MCCONAUGHEY	16.99	0	511
7341	3	AIRPORT FROST	KATE BERGEN	21.99	0	869
7342	9	AIRPORT FUGITIVE	KENNETH DEGENERES	21.99	0	9391
7343	2	AIRPORT FULL	PAUL SINATRA	17.99	0	442
7344	14	AIRPORT FURY	ORLANDO DAFOE	18.99	0	3566
7345	8	AIRPORT GABLES	WILL TYLER	17.99	0	8778
7346	8	AIRPORT GALAXY	UMA GUINESS	29.99	0	1970
7347	1	AIRPORT GAMES	JAMES KELLY	21.99	0	2728
7348	9	AIRPORT GANDHI	BOB CRUZ	15.99	0	588
7349	6	AIRPORT GANGS	ELVIS JACKMAN	11.99	0	2349
7350	8	AIRPORT GARDEN	CHARLIZE HANNAH	18.99	0	3994
7351	6	AIRPORT GASLIGHT	RAY DEAN	14.99	0	8003
7352	8	AIRPORT GATHERING	GLENN DIAZ	28.99	0	4391
7353	3	AIRPORT GENTLEMEN	MAE HAWKE	14.99	0	2585
7354	6	AIRPORT GHOST	NICOLE BOGART	21.99	0	6975
7355	14	AIRPORT GHOSTBUSTERS	BRUCE PALTROW	29.99	0	8931
7356	6	AIRPORT GIANT	CARMEN JOHANSSON	12.99	0	3236
7357	16	AIRPORT GILBERT	LAURENCE DENIRO	15.99	0	4545
7358	12	AIRPORT GILMORE	SANDRA FOSTER	16.99	0	6014
7359	11	AIRPORT GLADIATOR	MICHAEL WAYNE	16.99	0	9216
7360	2	AIRPORT GLASS	LUCILLE GARCIA	12.99	0	7929
7361	2	AIRPORT GLEAMING	FAY PECK	13.99	0	641
7362	9	AIRPORT GLORY	GENE STALLONE	11.99	0	4711
7363	9	AIRPORT GO	RIP TAUTOU	17.99	0	4242
7364	1	AIRPORT GODFATHER	HALLE TAYLOR	24.99	0	9045
7365	11	AIRPORT GOLD	EMILY FINNEY	14.99	0	6069
7366	2	AIRPORT GOLDFINGER	GEOFFREY LEWIS	16.99	0	1975
7367	7	AIRPORT GOLDMINE	ANGELA DREYFUSS	24.99	0	1790
7368	4	AIRPORT GONE	ANGELINA WATSON	9.99	0	2895
7369	8	AIRPORT GOODFELLAS	CHEVY GRANT	25.99	0	4083
7370	12	AIRPORT GORGEOUS	NEVE PRESLEY	29.99	0	2341
7371	10	AIRPORT GOSFORD	RICHARD BOGART	28.99	0	5712
7372	2	AIRPORT GRACELAND	RUSSELL TEMPLE	12.99	0	2336
7373	6	AIRPORT GRADUATE	CHRISTOPHER SILVERSTONE	16.99	0	5342
7374	11	AIRPORT GRAFFITI	SYLVESTER DIETRICH	26.99	0	338
7375	4	AIRPORT GRAIL	RAY RYAN	29.99	0	8208
7376	4	AIRPORT GRAPES	SUSAN GARCIA	9.99	0	3732
7377	10	AIRPORT GREASE	EDWARD GIBSON	17.99	0	8579
7378	11	AIRPORT GREATEST	MATTHEW STALLONE	26.99	0	5021
7379	6	AIRPORT GREEDY	PAUL THERON	15.99	0	8516
7380	6	AIRPORT GREEK	MARILYN WATSON	11.99	0	4159
7381	15	AIRPORT GRINCH	PEARL BOGART	26.99	0	443
7382	4	AIRPORT GRIT	INGRID NICHOLSON	18.99	0	9356
7383	6	AIRPORT GROOVE	PEARL REYNOLDS	9.99	0	9974
7384	9	AIRPORT GROSSE	SEAN WILLIS	14.99	0	5828
7385	3	AIRPORT GROUNDHOG	JULIA LEWIS	25.99	0	4174
7386	4	AIRPORT GUMP	JUDY MCCONAUGHEY	29.99	0	6150
7387	1	AIRPORT GUN	FRANCES ODONNELL	17.99	0	3942
7388	6	AIRPORT GUNFIGHT	CHEVY JOHANSSON	11.99	0	7532
7389	3	AIRPORT GUNFIGHTER	MINNIE AKROYD	9.99	0	9651
7390	10	AIRPORT GUYS	KATE HAWKE	11.99	0	2220
7391	9	AIRPORT HALF	ROCK GOLDBERG	10.99	0	3090
7392	11	AIRPORT HALL	ADAM FREEMAN	29.99	0	1709
7393	6	AIRPORT HALLOWEEN	MATT CAINE	19.99	0	1720
7394	5	AIRPORT HAMLET	CLARK HAWKE	29.99	0	4642
7395	16	AIRPORT HANDICAP	SEAN BAILEY	19.99	0	653
7396	12	AIRPORT HANGING	JAYNE NOLTE	20.99	0	7802
7397	14	AIRPORT HANKY	CARRIE HACKMAN	26.99	0	9035
7398	1	AIRPORT HANOVER	ANDY PACINO	23.99	0	3159
7399	14	AIRPORT HAPPINESS	NEVE HUDSON	9.99	0	1622
7400	9	AIRPORT HARDLY	DAN GOODING	17.99	0	3418
7401	8	AIRPORT HAROLD	ALEC LAW	27.99	0	7581
7402	11	AIRPORT HARPER	CHARLTON WEAVER	25.99	0	5069
7403	12	AIRPORT HARRY	DEBBIE SMITH	24.99	0	4166
7404	1	AIRPORT HATE	SIDNEY GOLDBERG	25.99	0	3286
7405	16	AIRPORT HAUNTED	MINNIE WALKEN	12.99	0	5729
7406	8	AIRPORT HAUNTING	CARY REYNOLDS	19.99	0	2322
7407	5	AIRPORT HAWK	CLARK FINNEY	17.99	0	9776
7408	15	AIRPORT HEAD	REESE SOBIESKI	11.99	0	3098
7409	9	AIRPORT HEARTBREAKERS	MENA MCGREGOR	18.99	0	1041
7410	13	AIRPORT HEAVEN	ALEC GARLAND	19.99	0	3409
7411	1	AIRPORT HEAVENLY	BRUCE ZELLWEGER	12.99	0	7558
7412	7	AIRPORT HEAVYWEIGHTS	BELA RUSH	21.99	0	2042
7413	10	AIRPORT HEDWIG	ALICIA CAINE	16.99	0	6022
7414	11	AIRPORT HELLFIGHTERS	DREW SORVINO	16.99	0	6489
7415	8	AIRPORT HIGH	ALAN BALL	19.99	0	5317
7416	14	AIRPORT HIGHBALL	KARL LOLLOBRIGIDA	28.99	0	422
7417	12	AIRPORT HILLS	RIVER CRONYN	25.99	0	275
7418	16	AIRPORT HOBBIT	CHRIS GARCIA	9.99	0	4389
7419	10	AIRPORT HOCUS	ETHAN HAWN	26.99	0	5426
7420	9	AIRPORT HOLES	LAUREN DIAZ	19.99	0	1078
7421	1	AIRPORT HOLIDAY	MENA MARX	21.99	0	4507
7422	10	AIRPORT HOLLOW	MAE DERN	18.99	0	4189
7423	8	AIRPORT HOLLYWOOD	PEARL BACALL	22.99	0	5131
7424	2	AIRPORT HOLOCAUST	TIM NEESON	16.99	0	7193
7425	15	AIRPORT HOLY	WILLIAM ANISTON	18.99	0	7454
7426	10	AIRPORT HOME	GRETA LUGOSI	14.99	0	9102
7427	12	AIRPORT HOMEWARD	CHRISTIAN RYAN	16.99	0	2101
7428	13	AIRPORT HOMICIDE	DUSTIN PECK	20.99	0	2850
7429	2	AIRPORT HONEY	VIVIEN HECHE	29.99	0	4719
7430	12	AIRPORT HOOK	JOHNNY MOSTEL	23.99	0	305
7431	8	AIRPORT HOOSIERS	LIV PENN	25.99	0	7900
7432	12	AIRPORT HOPE	LAUREN OLIVIER	27.99	0	8245
7433	2	AIRPORT HORN	KATE SMITH	15.99	0	8898
7434	10	AIRPORT HORROR	GEOFFREY HESTON	20.99	0	905
7435	1	AIRPORT HOTEL	OLYMPIA CAMPBELL	19.99	0	8879
7436	9	AIRPORT HOURS	LEONARDO DOUGLAS	12.99	0	5868
7437	16	AIRPORT HOUSE	FAY ROBERTS	20.99	0	3387
7438	6	AIRPORT HUMAN	CHRIS PHOENIX	28.99	0	5356
7439	13	AIRPORT HUNCHBACK	WILL MOSTEL	11.99	0	4035
7440	4	AIRPORT HUNGER	KENNETH DENIRO	29.99	0	3879
7441	14	AIRPORT HUNTER	MATT FINNEY	18.99	0	7402
7442	1	AIRPORT HUNTING	JULIA HOPPER	15.99	0	1678
7443	11	AIRPORT HURRICANE	SOPHIA GOLDBERG	26.99	0	9550
7444	6	AIRPORT HUSTLER	LIV BIRCH	15.99	0	8339
7445	12	AIRPORT HYDE	BEN HARRIS	14.99	0	8546
7446	11	AIRPORT HYSTERICAL	CLARK DAVIS	16.99	0	6752
7447	2	AIRPORT ICE	CARY OLIVIER	21.99	0	1383
7448	13	AIRPORT IDAHO	JUDY NORTON	22.99	0	7982
7449	10	AIRPORT IDENTITY	SHIRLEY TAYLOR	13.99	0	811
7450	2	AIRPORT IDOLS	JOHN WAYNE	12.99	0	8517
7451	1	AIRPORT IGBY	ANNETTE TORN	12.99	0	7257
7452	14	AIRPORT ILLUSION	JADA FIENNES	29.99	0	4497
7453	3	AIRPORT IMAGE	CATE NICHOLSON	22.99	0	6483
7454	8	AIRPORT IMPACT	JULIANNE WILSON	15.99	0	7255
7455	7	AIRPORT IMPOSSIBLE	MATT DIETRICH	27.99	0	8923
7456	12	AIRPORT INCH	RAY HEPBURN	25.99	0	279
7457	9	AIRPORT INDEPENDENCE	GREG HURT	29.99	0	2590
7458	7	AIRPORT INDIAN	TOM MARTIN	20.99	0	2826
7459	4	AIRPORT INFORMER	EDWARD OLIVIER	24.99	0	4490
7460	8	AIRPORT INNOCENT	MIRA HECHE	11.99	0	1428
7461	16	AIRPORT INSECTS	LANA BERGEN	25.99	0	1896
7462	14	AIRPORT INSIDER	MATT HAWKE	12.99	0	1389
7463	7	AIRPORT INSTINCT	NICOLAS RUSH	16.99	0	9951
7464	11	AIRPORT INTENTIONS	MERYL KEITEL	27.99	0	7132
7465	6	AIRPORT INTERVIEW	CHARLES NICHOLSON	10.99	0	4659
7466	4	AIRPORT INTOLERABLE	KARL RUSSELL	25.99	0	4128
7467	16	AIRPORT INTRIGUE	ROBERT GUINESS	22.99	0	1977
7468	13	AIRPORT INVASION	WILLEM WINSLET	19.99	0	3086
7469	9	AIRPORT IRON	ROBIN WINSLET	13.99	0	701
7470	15	AIRPORT ISHTAR	NICOLE DAMON	10.99	0	5351
7471	9	AIRPORT ISLAND	GINA HUDSON	10.99	0	8961
7472	8	AIRPORT ITALIAN	FAY DAFOE	15.99	0	8447
7473	8	AIRPORT JACKET	RIVER MARTIN	18.99	0	1580
7474	13	AIRPORT JADE	CATE MCGREGOR	21.99	0	44
7475	11	AIRPORT JAPANESE	DENNIS PINKETT	18.99	0	4764
7476	16	AIRPORT JASON	UMA FIELD	15.99	0	1831
7477	3	AIRPORT JAWBREAKER	HENRY SPACEK	18.99	0	2220
7478	6	AIRPORT JAWS	ROBERT MCDORMAND	11.99	0	9436
7479	5	AIRPORT JEDI	KIRSTEN TAYLOR	18.99	0	3938
7480	7	AIRPORT JEEPERS	CARY CLOSE	22.99	0	9228
7481	2	AIRPORT JEKYLL	DUSTIN LANSBURY	10.99	0	6034
7482	4	AIRPORT JEOPARDY	JANE BACALL	22.99	0	5695
7483	14	AIRPORT JERICHO	DAN SILVERSTONE	23.99	0	2821
7484	11	AIRPORT JERK	CHARLTON DENIRO	13.99	0	6360
7485	10	AIRPORT JERSEY	REESE BRANDO	24.99	0	3937
7486	11	AIRPORT JET	VIVIEN THERON	27.99	0	7978
7487	8	AIRPORT JINGLE	RIVER CRUZ	28.99	0	3225
7488	8	AIRPORT JOON	CATE ODONNELL	23.99	0	864
7489	16	AIRPORT JUGGLER	GOLDIE AFFLECK	11.99	0	92
7490	13	AIRPORT JUMANJI	CARMEN RYAN	20.99	0	8819
7491	16	AIRPORT JUMPING	ORLANDO CHASE	27.99	0	7141
7492	12	AIRPORT JUNGLE	STEVE KEITEL	19.99	0	7465
7493	14	AIRPORT KANE	JANE WATSON	29.99	0	8158
7494	2	AIRPORT KARATE	RIVER LOREN	17.99	0	223
7495	7	AIRPORT KENTUCKIAN	RIP HOPPER	20.99	0	3289
7496	7	AIRPORT KICK	JOHN WILLIAMS	12.99	0	5259
7497	15	AIRPORT KILL	ANGELINA LANCASTER	25.99	0	4916
7498	9	AIRPORT KILLER	JADA WAHLBERG	29.99	0	472
7499	13	AIRPORT KING	MADELINE WILSON	22.99	0	3324
7500	11	AIRPORT KISS	RALPH ROBERTS	18.99	0	7969
7501	13	AIRPORT KISSING	OLYMPIA PENN	14.99	0	6093
7502	13	AIRPORT KNOCK	CHRIS RUSSELL	26.99	0	2395
7503	6	AIRPORT KRAMER	CHRIS CAMPBELL	25.99	0	627
7504	14	AIRPORT KWAI	ALICIA WASHINGTON	18.99	0	4000
7505	13	AIRPORT LABYRINTH	CLARK DAMON	20.99	0	4835
7506	6	AIRPORT LADY	DARYL HOPPER	11.99	0	989
7507	12	AIRPORT LADYBUGS	SIDNEY KINNEAR	27.99	0	4771
7508	3	AIRPORT LAMBS	LIV PINKETT	15.99	0	7472
7509	6	AIRPORT LANGUAGE	MEL FINNEY	17.99	0	2398
7510	13	AIRPORT LAWLESS	JEFF LANCASTER	29.99	0	1136
7511	8	AIRPORT LAWRENCE	LANA IRONS	22.99	0	3091
7512	12	AIRPORT LEAGUE	RUSSELL FORD	22.99	0	2425
7513	2	AIRPORT LEATHERNECKS	WILLEM GARBO	24.99	0	4841
7514	8	AIRPORT LEBOWSKI	RICHARD AFFLECK	12.99	0	5818
7515	7	AIRPORT LEGALLY	CATE CRAWFORD	26.99	0	2599
7516	16	AIRPORT LEGEND	NICOLE LOREN	20.99	0	3577
7517	14	AIRPORT LESSON	MERYL WINSLET	23.99	0	9222
7518	15	AIRPORT LIAISONS	FARRAH PESCI	28.99	0	9311
7519	7	AIRPORT LIBERTY	TOM WALKEN	13.99	0	3254
7520	13	AIRPORT LICENSE	JUDE HURT	28.99	0	6392
7521	3	AIRPORT LIES	DIANE DOUGLAS	28.99	0	4552
7522	5	AIRPORT LIFE	JAMES MINELLI	29.99	0	474
7523	15	AIRPORT LIGHTS	PAUL DERN	12.99	0	2225
7524	2	AIRPORT LION	CHARLIZE LANCASTER	10.99	0	2331
7525	6	AIRPORT LOATHING	MINNIE KILMER	27.99	0	341
7526	9	AIRPORT LOCK	GENE MCKELLEN	24.99	0	1153
7527	4	AIRPORT LOLA	OPRAH STALLONE	22.99	0	840
7528	11	AIRPORT LOLITA	GREG PESCI	18.99	0	5046
7529	11	AIRPORT LONELY	ANNE ALLEN	26.99	0	8133
7530	1	AIRPORT LORD	GREGORY HESTON	24.99	0	8013
7531	13	AIRPORT LOSE	JAMES SMITH	11.99	0	9879
7532	4	AIRPORT LOSER	ROBERT POSEY	29.99	0	6481
7533	1	AIRPORT LOST	HALLE BASINGER	17.99	0	2697
7534	15	AIRPORT LOUISIANA	FARRAH CLOSE	29.99	0	3457
7535	13	AIRPORT LOVE	PENELOPE BACALL	11.99	0	899
7536	15	AIRPORT LOVELY	STEVE LOREN	16.99	0	4717
7537	6	AIRPORT LOVER	DIANE TYLER	12.99	0	5990
7538	14	AIRPORT LOVERBOY	MARISA WEST	13.99	0	1436
7539	8	AIRPORT LUCK	FRED DIAZ	24.99	0	2818
7540	2	AIRPORT LUCKY	GARY AKROYD	27.99	0	963
7541	16	AIRPORT LUKE	MEL BERGEN	27.99	0	3709
7542	6	AIRPORT LUST	FARRAH ROBERTS	20.99	0	1740
7543	3	AIRPORT MADIGAN	CARRIE ROBERTS	26.99	0	4820
7544	16	AIRPORT MADISON	NICOLAS HESTON	14.99	0	9738
7545	9	AIRPORT MADNESS	WILLIAM DOUGLAS	26.99	0	1201
7546	16	AIRPORT MADRE	CUBA BRANDO	22.99	0	6148
7547	1	AIRPORT MAGIC	HILARY FORD	15.99	0	3454
7548	8	AIRPORT MAGNIFICENT	CARMEN BERGMAN	21.99	0	982
7549	2	AIRPORT MAGNOLIA	KARL SUVARI	26.99	0	7183
7550	13	AIRPORT MAGUIRE	WOODY NEESON	25.99	0	1442
7551	15	AIRPORT MAIDEN	ELLEN HUNT	10.99	0	2457
7552	12	AIRPORT MAJESTIC	LAUREN BRANDO	10.99	0	4875
7553	7	AIRPORT MAKER	KIRK SWANK	20.99	0	4541
7554	11	AIRPORT MALKOVICH	GARY KAHN	12.99	0	4271
7555	15	AIRPORT MALLRATS	BOB BRANDO	27.99	0	6169
7556	1	AIRPORT MALTESE	BOB ROBBINS	15.99	0	1990
7557	9	AIRPORT MANCHURIAN	GARY KINNEAR	11.99	0	7064
7558	10	AIRPORT MANNEQUIN	KIRK BASINGER	12.99	0	84
7559	11	AIRPORT MARRIED	JULIANNE DERN	28.99	0	8489
7560	6	AIRPORT MARS	WARREN FREEMAN	18.99	0	8475
7561	2	AIRPORT MASK	LIZA DUKAKIS	12.99	0	4731
7562	6	AIRPORT MASKED	ALAN CAINE	23.99	0	6419
7563	7	AIRPORT MASSACRE	MICHAEL TEMPLE	28.99	0	3034
7564	16	AIRPORT MASSAGE	KIRK NOLTE	19.99	0	66
7565	6	AIRPORT MATRIX	GROUCHO WOOD	15.99	0	6026
7566	3	AIRPORT MAUDE	SIGOURNEY KEITEL	24.99	0	4825
7567	4	AIRPORT MEET	LIV BEATTY	14.99	0	8799
7568	15	AIRPORT MEMENTO	OPRAH BRIDGES	21.99	0	8100
7569	15	AIRPORT MENAGERIE	JOHNNY ANISTON	18.99	0	1157
7570	8	AIRPORT MERMAID	BRUCE SMITH	26.99	0	5491
7571	7	AIRPORT METAL	AUDREY DENIRO	15.99	0	7619
7572	13	AIRPORT METROPOLIS	RITA DEE	17.99	0	5528
7573	5	AIRPORT MICROCOSMOS	MATT GIBSON	9.99	0	7319
7574	14	AIRPORT MIDNIGHT	NICOLE STALLONE	16.99	0	2439
7575	8	AIRPORT MIDSUMMER	ANNETTE POSEY	20.99	0	1730
7576	2	AIRPORT MIGHTY	INGRID WINSLET	12.99	0	4216
7577	16	AIRPORT MILE	MARLON BERGMAN	25.99	0	1378
7578	6	AIRPORT MILLION	JUDI RICKMAN	29.99	0	4636
7579	12	AIRPORT MINDS	GARY MOSTEL	18.99	0	6007
7580	12	AIRPORT MINE	GRETA HUNT	25.99	0	9129
7581	16	AIRPORT MINORITY	SIDNEY CHASE	16.99	0	1728
7582	13	AIRPORT MIRACLE	EDWARD DRIVER	18.99	0	7259
7583	10	AIRPORT MISSION	JOHNNY GOLDBERG	10.99	0	3039
7584	9	AIRPORT MIXED	WHOOPI BLANCHETT	27.99	0	9802
7585	8	AIRPORT MOB	JENNIFER DIETRICH	26.99	0	4954
7586	12	AIRPORT MOCKINGBIRD	MARLENE AFFLECK	21.99	0	9917
7587	13	AIRPORT MOD	FARRAH CLOSE	9.99	0	3374
7588	13	AIRPORT MODEL	MINNIE CRUISE	14.99	0	796
7589	9	AIRPORT MODERN	CHRISTIAN STALLONE	20.99	0	7231
7590	9	AIRPORT MONEY	WOODY COSTNER	29.99	0	438
7591	8	AIRPORT MONSOON	ANGELA PECK	11.99	0	4146
7592	2	AIRPORT MONSTER	LAURA BRODY	16.99	0	1840
7593	12	AIRPORT MONTEREY	HARVEY WAHLBERG	18.99	0	6633
7594	9	AIRPORT MONTEZUMA	JUDI PHOENIX	23.99	0	2131
7595	7	AIRPORT MOON	HELEN RICKMAN	17.99	0	3709
7596	8	AIRPORT MOONSHINE	BETTE CROWE	19.99	0	4181
7597	15	AIRPORT MOONWALKER	KATHARINE GUINESS	18.99	0	6994
7598	11	AIRPORT MOSQUITO	LIV JACKMAN	9.99	0	7951
7599	12	AIRPORT MOTHER	JULIETTE HESTON	13.99	0	7900
7600	7	AIRPORT MOTIONS	KIM KAHN	25.99	0	2883
7601	3	AIRPORT MOULIN	JODIE FREEMAN	14.99	0	7714
7602	11	AIRPORT MOURNING	CHRISTIAN PFEIFFER	13.99	0	9415
7603	15	AIRPORT MOVIE	JAMES SWANK	20.99	0	3591
7604	6	AIRPORT MULAN	RAY LUGOSI	27.99	0	9080
7605	11	AIRPORT MULHOLLAND	JACK DAMON	13.99	0	3291
7606	8	AIRPORT MUMMY	MEG CRAWFORD	29.99	0	5039
7607	12	AIRPORT MUPPET	DORIS BRANDO	28.99	0	4291
7608	14	AIRPORT MURDER	FAY DENCH	14.99	0	1751
7609	11	AIRPORT MUSCLE	ORLANDO BRANAGH	18.99	0	5529
7610	6	AIRPORT MUSIC	ORLANDO MCCONAUGHEY	25.99	0	7683
7611	2	AIRPORT MUSKETEERS	VAL FINNEY	25.99	0	3853
7612	5	AIRPORT MUSSOLINI	JON BAILEY	19.99	0	8268
7613	15	AIRPORT MYSTIC	AUDREY RYAN	13.99	0	8504
7614	7	AIRPORT NAME	WARREN PESCI	12.99	0	9291
7615	12	AIRPORT NASH	KENNETH JOVOVICH	18.99	0	3723
7616	4	AIRPORT NATIONAL	MERYL GIBSON	12.99	0	9848
7617	10	AIRPORT NATURAL	ALAN HAYEK	10.99	0	9624
7618	15	AIRPORT NECKLACE	OPRAH TANDY	29.99	0	8342
7619	14	AIRPORT NEIGHBORS	KIM HURT	25.99	0	7173
7620	12	AIRPORT NEMO	DIANE FOSTER	14.99	0	5003
7621	11	AIRPORT NETWORK	SCARLETT BASINGER	15.99	0	168
7622	5	AIRPORT NEWSIES	JANE SILVERSTONE	15.99	0	3628
7623	5	AIRPORT NEWTON	DIANE ROBERTS	9.99	0	3046
7624	15	AIRPORT NIGHTMARE	PENELOPE LAW	18.99	0	4137
7625	3	AIRPORT NONE	OPRAH BARRYMORE	16.99	0	5706
7626	14	AIRPORT NOON	LIZA WALKEN	24.99	0	8610
7627	13	AIRPORT NORTH	MATTHEW KUDROW	13.99	0	5509
7628	10	AIRPORT NORTHWEST	GLENN CHASE	25.99	0	702
7629	2	AIRPORT NOTORIOUS	MADELINE BERGMAN	27.99	0	9697
7630	5	AIRPORT NOTTING	AL MONROE	9.99	0	3142
7631	10	AIRPORT NOVOCAINE	DUSTIN TRACY	13.99	0	4838
7632	2	AIRPORT NUTS	ALICIA HARRIS	25.99	0	9027
7633	6	AIRPORT OCTOBER	ANNE COSTNER	22.99	0	2559
7634	12	AIRPORT ODDS	GLENN BASINGER	16.99	0	8322
7635	6	AIRPORT OKLAHOMA	JOE DAMON	15.99	0	5115
7636	11	AIRPORT OLEANDER	IAN TANDY	27.99	0	587
7637	6	AIRPORT OPEN	JIM CRUISE	17.99	0	787
7638	5	AIRPORT OPERATION	ELIZABETH DOUGLAS	16.99	0	2107
7639	10	AIRPORT OPPOSITE	ELVIS MCQUEEN	28.99	0	1826
7640	13	AIRPORT OPUS	HENRY EASTWOOD	14.99	0	6384
7641	13	AIRPORT ORANGE	JON DOUGLAS	12.99	0	5968
7642	4	AIRPORT ORDER	RALPH KELLY	23.99	0	7501
7643	13	AIRPORT ORIENT	ALEC DEE	9.99	0	9520
7644	5	AIRPORT OSCAR	LEELEE DAMON	19.99	0	5751
7645	12	AIRPORT OTHERS	SEAN WASHINGTON	10.99	0	5065
7646	12	AIRPORT OUTBREAK	PENELOPE WILSON	13.99	0	9425
7647	14	AIRPORT OUTFIELD	JOAN HACKMAN	21.99	0	3989
7648	6	AIRPORT OUTLAW	LUCILLE TRACY	17.99	0	2217
7649	6	AIRPORT OZ	JAMES DAFOE	28.99	0	5856
7650	9	AIRPORT PACIFIC	JULIA HAWKE	17.99	0	7125
7651	15	AIRPORT PACKER	MEL DAY-LEWIS	23.99	0	8355
7652	10	AIRPORT PAJAMA	DREW DIETRICH	10.99	0	3463
7653	8	AIRPORT PANIC	ELIZABETH DENCH	11.99	0	1973
7654	6	AIRPORT PANKY	HUGH WINSLET	25.99	0	1143
7655	6	AIRPORT PANTHER	JULIETTE HAWN	27.99	0	275
7656	10	AIRPORT PAPI	ELIZABETH NORTON	14.99	0	7023
7657	2	AIRPORT PARADISE	WILL WINFREY	15.99	0	8569
7658	11	AIRPORT PARIS	BRUCE KINNEAR	28.99	0	7362
7659	3	AIRPORT PARK	MINNIE WRAY	20.99	0	6219
7660	11	AIRPORT PARTY	ANDY BRANAGH	12.99	0	8381
7661	4	AIRPORT PAST	JULIETTE LAW	18.99	0	8878
7662	3	AIRPORT PATHS	SALMA WAHLBERG	11.99	0	9225
7663	16	AIRPORT PATIENT	JIM WASHINGTON	10.99	0	1230
7664	14	AIRPORT PATRIOT	CAMERON WOOD	20.99	0	8727
7665	3	AIRPORT PATTON	WILLIAM CHAPLIN	12.99	0	9605
7666	1	AIRPORT PAYCHECK	JULIANNE KAHN	20.99	0	3439
7667	8	AIRPORT PEACH	EMILY BOLGER	15.99	0	5189
7668	4	AIRPORT PEAK	JENNIFER DAMON	23.99	0	3125
7669	14	AIRPORT PEARL	FRANK BOLGER	28.99	0	8114
7670	13	AIRPORT PELICAN	WARREN RUSH	25.99	0	2782
7671	12	AIRPORT PERDITION	RALPH ZELLWEGER	14.99	0	7445
7672	10	AIRPORT PERFECT	RUBY ZELLWEGER	27.99	0	753
7673	7	AIRPORT PERSONAL	FARRAH KIDMAN	26.99	0	5664
7674	3	AIRPORT PET	MATT BALL	18.99	0	3002
7675	5	AIRPORT PHANTOM	BEN ROBERTS	13.99	0	551
7676	9	AIRPORT PHILADELPHIA	ANJELICA FAWCETT	15.99	0	6097
7677	1	AIRPORT PIANIST	LIAM CROWE	27.99	0	9093
7678	16	AIRPORT PICKUP	JANE HOPPER	14.99	0	6631
7679	14	AIRPORT PILOT	MICHELLE HORNE	19.99	0	6753
7680	13	AIRPORT PINOCCHIO	JENNIFER CRUISE	27.99	0	133
7681	15	AIRPORT PIRATES	GINA WASHINGTON	29.99	0	8979
7682	10	AIRPORT PITTSBURGH	BEN DIETRICH	13.99	0	1484
7683	2	AIRPORT PITY	LIAM CAGE	20.99	0	9117
7684	4	AIRPORT PIZZA	HARVEY CRUISE	28.99	0	2974
7685	10	AIRPORT PLATOON	JOHN HOPPER	9.99	0	9128
7686	1	AIRPORT PLUTO	RUBY DEGENERES	16.99	0	768
7687	5	AIRPORT POCUS	GRETA RYDER	16.99	1	5146
7688	8	AIRPORT POLISH	MARISA BLOOM	11.99	0	232
7689	1	AIRPORT POLLOCK	DENNIS SORVINO	17.99	0	8872
7690	12	AIRPORT POND	GREG FINNEY	12.99	0	6620
7691	2	AIRPORT POSEIDON	SOPHIA HACKMAN	28.99	0	1161
7692	1	AIRPORT POTLUCK	STEVE BAILEY	16.99	0	9050
7693	15	AIRPORT POTTER	ZERO THERON	20.99	0	6257
7694	9	AIRPORT PREJUDICE	JEREMY AKROYD	25.99	0	1975
7695	11	AIRPORT PRESIDENT	JULIA BLANCHETT	29.99	0	8707
7696	11	AIRPORT PRIDE	EMILY GARCIA	20.99	0	359
7697	11	AIRPORT PRIMARY	ANTHONY FIELD	21.99	0	4509
7698	8	AIRPORT PRINCESS	GOLDIE LANSBURY	19.99	0	3205
7699	2	AIRPORT PRIVATE	GLENN MCKELLEN	20.99	0	7238
7700	13	AIRPORT PRIX	RIP BALL	14.99	0	799
7701	3	AIRPORT PSYCHO	JANE NORTON	17.99	0	7381
7702	8	AIRPORT PULP	ANJELICA TYLER	20.99	0	7289
7703	16	AIRPORT PUNK	FAY WOOD	15.99	0	3684
7704	11	AIRPORT PURE	ZERO LUGOSI	29.99	0	3907
7705	11	AIRPORT PURPLE	JAMES WALKEN	19.99	0	4651
7706	10	AIRPORT QUEEN	CHARLTON GARLAND	9.99	0	3927
7707	13	AIRPORT QUEST	GARY DERN	25.99	0	8034
7708	9	AIRPORT QUILLS	RAY RICKMAN	26.99	0	2683
7709	3	AIRPORT RACER	SALLY PECK	12.99	0	140
7710	10	AIRPORT RAGE	TOM GABLE	9.99	0	1516
7711	8	AIRPORT RAGING	JULIA HAYEK	22.99	0	3130
7712	1	AIRPORT RAIDERS	KIRSTEN CRUISE	15.99	1	3527
7713	3	AIRPORT RAINBOW	CANDICE KELLY	28.99	0	1961
7714	3	AIRPORT RANDOM	SPENCER KILMER	9.99	0	5791
7715	1	AIRPORT RANGE	TIM DUNST	29.99	0	7826
7716	3	AIRPORT REAP	DEBBIE ROBERTS	23.99	0	6462
7717	16	AIRPORT REAR	ROCK HAYEK	20.99	0	8345
7718	15	AIRPORT REBEL	GWYNETH TAYLOR	9.99	0	7114
7719	4	AIRPORT RECORDS	EDWARD WINSLET	11.99	0	9675
7720	12	AIRPORT REDEMPTION	ELVIS BERRY	22.99	0	5705
7721	7	AIRPORT REDS	GREGORY DAY-LEWIS	22.99	0	7540
7722	5	AIRPORT REEF	CLARK TAUTOU	11.99	0	9203
7723	16	AIRPORT REIGN	RAY FIENNES	15.99	0	5799
7724	1	AIRPORT REMEMBER	KIM LANCASTER	14.99	0	5747
7725	4	AIRPORT REQUIEM	MARLENE GOLDBERG	19.99	0	7222
7726	2	AIRPORT RESERVOIR	UMA HECHE	17.99	0	8301
7727	3	AIRPORT RESURRECTION	MICHAEL FISHER	16.99	0	1151
7728	5	AIRPORT REUNION	JAMES GOLDBERG	10.99	0	7702
7729	11	AIRPORT RIDER	GINA PACINO	13.99	0	9972
7730	13	AIRPORT RIDGEMONT	HARRISON DAFOE	17.99	0	3860
7731	3	AIRPORT RIGHT	RITA RICKMAN	10.99	0	8702
7732	15	AIRPORT RINGS	DANIEL GABLE	21.99	0	6296
7733	12	AIRPORT RIVER	ADRIEN WILSON	12.99	0	6921
7734	15	AIRPORT ROAD	HUGH MOSTEL	14.99	0	3632
7735	4	AIRPORT ROBBERS	KIRK MCGREGOR	22.99	0	2613
7736	1	AIRPORT ROBBERY	ALEC CROWE	26.99	0	2091
7737	12	AIRPORT ROCK	KIRK CRONYN	27.99	0	2637
7738	9	AIRPORT ROCKETEER	DREW KEITEL	20.99	0	2581
7739	4	AIRPORT ROCKY	SYLVESTER MATTHAU	21.99	0	7805
7740	16	AIRPORT ROLLERCOASTER	HUMPHREY BRANDO	20.99	0	4527
7741	13	AIRPORT ROMAN	MAE PITT	26.99	0	9087
7742	1	AIRPORT ROOF	BOB DIAZ	21.99	0	8860
7743	14	AIRPORT ROOM	HUMPHREY NEWMAN	11.99	0	875
7744	6	AIRPORT ROOTS	MICHAEL HAWN	14.99	0	5600
7745	1	AIRPORT ROSES	MATTHEW ALLEN	18.99	0	4054
7746	15	AIRPORT ROUGE	CHARLIZE GABLE	20.99	0	7165
7747	8	AIRPORT ROXANNE	WILLEM DAY	20.99	0	1324
7748	8	AIRPORT RUGRATS	RICHARD NOLTE	26.99	0	49
7749	15	AIRPORT RULES	JACK CAGE	22.99	0	4565
7750	4	AIRPORT RUN	JIM HUDSON	27.99	0	178
7751	5	AIRPORT RUNAWAY	HARRISON STREEP	17.99	0	5530
7752	3	AIRPORT RUNNER	PAUL TAUTOU	11.99	0	5931
7753	4	AIRPORT RUSH	EWAN TAUTOU	10.99	0	584
7754	1	AIRPORT RUSHMORE	DAN MONROE	19.99	0	6044
7755	15	AIRPORT SABRINA	AUDREY HUSTON	17.99	0	46
7756	7	AIRPORT SADDLE	RUSSELL MCCONAUGHEY	25.99	0	2581
7757	6	AIRPORT SAGEBRUSH	CARRIE COSTNER	11.99	0	5522
7758	12	AIRPORT SAINTS	INGRID KIDMAN	29.99	0	1350
7759	1	AIRPORT SALUTE	RALPH MINELLI	14.99	0	732
7760	14	AIRPORT SAMURAI	KEVIN BENING	28.99	0	8990
7761	15	AIRPORT SANTA	JULIA THURMAN	25.99	0	5504
7762	1	AIRPORT SASSY	MORGAN ASTAIRE	12.99	0	73
7763	12	AIRPORT SATISFACTION	KATHARINE SUVARI	11.99	0	1260
7764	5	AIRPORT SATURDAY	PARKER TOMEI	10.99	0	8921
7765	3	AIRPORT SATURN	VIVIEN WINSLET	23.99	0	4174
7766	10	AIRPORT SAVANNAH	FRED SINATRA	10.99	0	9824
7767	11	AIRPORT SCALAWAG	ADRIEN MCDORMAND	16.99	0	1496
7768	6	AIRPORT SCARFACE	ADAM JOHANSSON	28.99	0	8473
7769	1	AIRPORT SCHOOL	NICK TORN	25.99	0	8697
7770	12	AIRPORT SCISSORHANDS	RUBY BERRY	22.99	0	7401
7771	2	AIRPORT SCORPION	KIM FORD	16.99	0	1471
7772	6	AIRPORT SEA	PAUL BERRY	16.99	0	5571
7773	9	AIRPORT SEABISCUIT	ANNE SINATRA	19.99	0	6850
7774	6	AIRPORT SEARCHERS	LAUREN RICKMAN	11.99	0	5322
7775	16	AIRPORT SEATTLE	LIAM DOUGLAS	26.99	0	3674
7776	9	AIRPORT SECRET	MICHELLE AFFLECK	11.99	0	1358
7777	5	AIRPORT SECRETARY	DENNIS PHOENIX	9.99	0	6538
7778	10	AIRPORT SECRETS	JIM MARX	22.99	0	1978
7779	6	AIRPORT SENSE	WHOOPI IRONS	28.99	0	5430
7780	8	AIRPORT SENSIBILITY	RIVER LAW	10.99	0	7503
7781	7	AIRPORT SEVEN	OLYMPIA WATSON	11.99	0	1255
7782	5	AIRPORT SHAKESPEARE	SALLY FAWCETT	18.99	0	9505
7783	3	AIRPORT SHANE	KIM WASHINGTON	21.99	0	6805
7784	13	AIRPORT SHANGHAI	CHRISTIAN TURNER	24.99	0	7564
7785	5	AIRPORT SHAWSHANK	GEOFFREY DERN	11.99	0	6948
7786	14	AIRPORT SHEPHERD	MADELINE PHOENIX	22.99	0	6795
7787	12	AIRPORT SHINING	WINONA BRIDGES	21.99	0	3312
7788	9	AIRPORT SHIP	ELVIS PECK	11.99	0	8382
7789	13	AIRPORT SHOCK	NICOLAS BOLGER	29.99	0	5596
7790	12	AIRPORT SHOOTIST	RITA CLOSE	9.99	0	1314
7791	12	AIRPORT SHOW	SALMA CHASE	16.99	0	7207
7792	1	AIRPORT SHREK	ROCK KELLY	9.99	0	4270
7793	6	AIRPORT SHRUNK	CHARLES NORTON	22.99	0	4515
7794	8	AIRPORT SIDE	KEVIN MALDEN	13.99	0	4138
7795	13	AIRPORT SIEGE	LAURA DICAPRIO	21.99	0	8593
7796	12	AIRPORT SIERRA	AL BACALL	21.99	0	7929
7797	5	AIRPORT SILENCE	GEOFFREY HECHE	11.99	0	4503
7798	9	AIRPORT SILVERADO	CATE SILVERSTONE	23.99	0	9348
7799	3	AIRPORT SIMON	JULIETTE TOMEI	23.99	0	776
7800	2	AIRPORT SINNERS	GREGORY SUVARI	23.99	0	6474
7801	9	AIRPORT SISTER	MEG CARREY	20.99	0	655
7802	6	AIRPORT SKY	JOHNNY ANISTON	23.99	0	9450
7803	3	AIRPORT SLACKER	OPRAH PECK	14.99	0	1885
7804	4	AIRPORT SLEEPING	BELA LEWIS	24.99	0	1722
7805	13	AIRPORT SLEEPLESS	ALEC HANNAH	12.99	0	4621
7806	13	AIRPORT SLEEPY	LIAM MOORE	19.99	0	3325
7807	9	AIRPORT SLEUTH	GRETA MALDEN	9.99	0	5056
7808	16	AIRPORT SLING	DIANE HARRIS	24.99	0	6380
7809	15	AIRPORT SLIPPER	DENNIS THERON	9.99	0	4902
7810	3	AIRPORT SLUMS	SIGOURNEY HAYEK	13.99	0	9904
7811	11	AIRPORT SMILE	MARISA GOLDBERG	14.99	0	8722
7812	10	AIRPORT SMOKING	JESSICA HACKMAN	29.99	0	7367
7813	8	AIRPORT SMOOCHY	CHARLES HAWKE	23.99	0	8212
7814	6	AIRPORT SNATCH	MICHELLE BERRY	20.99	0	3155
7815	1	AIRPORT SNATCHERS	NICK DERN	28.99	0	3107
7816	15	AIRPORT SNOWMAN	MENA BULLOCK	20.99	0	5408
7817	7	AIRPORT SOLDIERS	TOM AKROYD	27.99	0	3725
7818	10	AIRPORT SOMETHING	RALPH HEPBURN	25.99	0	9376
7819	10	AIRPORT SONG	AL HOFFMAN	15.99	0	949
7820	10	AIRPORT SONS	GRETA ZELLWEGER	16.99	0	8140
7821	11	AIRPORT SORORITY	UMA SINATRA	16.99	0	3427
7822	15	AIRPORT SOUP	GRETA RYAN	26.99	0	3204
7823	4	AIRPORT SOUTH	OLYMPIA EASTWOOD	29.99	0	8721
7824	15	AIRPORT SPARTACUS	GENE MOORE	28.99	0	2881
7825	1	AIRPORT SPEAKEASY	FAY LANCASTER	16.99	0	1991
7826	4	AIRPORT SPEED	ALAN KUDROW	11.99	0	3868
7827	8	AIRPORT SPICE	CLARK RICKMAN	26.99	0	8581
7828	3	AIRPORT SPIKING	CHEVY ROBERTS	27.99	0	2272
7829	13	AIRPORT SPINAL	SHIRLEY NEWMAN	10.99	0	8292
7830	6	AIRPORT SPIRIT	HELEN MCGREGOR	22.99	0	2769
7831	14	AIRPORT SPIRITED	RIVER CRUISE	27.99	0	7121
7832	5	AIRPORT SPLASH	JODIE RYDER	18.99	0	658
7833	5	AIRPORT SPLENDOR	ROSIE ROBBINS	18.99	0	5992
7834	11	AIRPORT SPOILERS	ETHAN HOPE	20.99	0	8713
7835	7	AIRPORT SPY	JON TURNER	25.99	0	4988
7836	1	AIRPORT SQUAD	MERYL HAYEK	27.99	0	170
7837	10	AIRPORT STAGE	RITA LAW	10.99	0	4423
7838	3	AIRPORT STAGECOACH	DENNIS FAWCETT	29.99	0	8879
7839	10	AIRPORT STALLION	GOLDIE HOPKINS	26.99	0	8649
7840	12	AIRPORT STAMPEDE	PAUL HAYEK	13.99	0	3354
7841	12	AIRPORT STAR	OPRAH DIAZ	17.99	0	600
7842	7	AIRPORT STATE	LIZA PINKETT	14.99	0	6296
7843	11	AIRPORT STEEL	TOM WEST	27.99	0	7025
7844	13	AIRPORT STEERS	CHEVY KEATON	11.99	0	1789
7845	16	AIRPORT STEPMOM	LEONARDO BLOOM	24.99	0	8034
7846	2	AIRPORT STING	ANNETTE BAILEY	26.99	0	2061
7847	15	AIRPORT STOCK	UMA TAYLOR	20.99	0	7537
7848	3	AIRPORT STONE	MICHELLE SANDLER	11.99	0	6372
7849	13	AIRPORT STORM	CHARLTON JACKMAN	29.99	0	5207
7850	3	AIRPORT STORY	LISA MARTIN	24.99	0	9250
7851	9	AIRPORT STRAIGHT	WALTER HOPKINS	21.99	0	3988
7852	13	AIRPORT STRANGELOVE	EMILY DAY	24.99	0	3840
7853	9	AIRPORT STRANGER	CUBA WAHLBERG	13.99	0	8886
7854	14	AIRPORT STRANGERS	HELEN SOBIESKI	9.99	0	9965
7855	9	AIRPORT STREAK	LENA WALKEN	11.99	0	9604
7856	1	AIRPORT STREETCAR	IAN DAMON	9.99	0	7211
7857	7	AIRPORT STRICTLY	UMA MCGREGOR	23.99	0	6960
7858	2	AIRPORT SUBMARINE	LIV TOMEI	14.99	0	6400
7859	3	AIRPORT SUGAR	JIM WEST	20.99	0	2542
7860	9	AIRPORT SUICIDES	CLINT HUSTON	11.99	0	8456
7861	2	AIRPORT SUIT	ANJELICA NICHOLSON	19.99	0	8687
7862	4	AIRPORT SUMMER	JON BRANDO	12.99	0	8788
7863	14	AIRPORT SUN	PAUL TANDY	18.99	0	8752
7864	2	AIRPORT SUNDANCE	ROBERT DIAZ	21.99	0	7870
7865	14	AIRPORT SUNRISE	EMILY FAWCETT	9.99	0	8836
7866	14	AIRPORT SUNSET	KIRK JOVOVICH	28.99	0	2547
7867	13	AIRPORT SUPER	GWYNETH DAY	14.99	0	1602
7868	3	AIRPORT SUPERFLY	ALBERT DEAN	28.99	0	1436
7869	13	AIRPORT SUSPECTS	HUMPHREY SANDLER	22.99	0	1917
7870	7	AIRPORT SWARM	JON DAVIS	23.99	0	9249
7871	10	AIRPORT SWEDEN	JAMES BERRY	11.99	0	4334
7872	7	AIRPORT SWEET	MARLENE REYNOLDS	24.99	0	243
7873	15	AIRPORT SWEETHEARTS	ELIZABETH CRUISE	28.99	0	9450
7874	2	AIRPORT TADPOLE	NICOLE TYLER	19.99	0	1291
7875	11	AIRPORT TALENTED	GRACE WILLIAMS	12.99	0	5601
7876	2	AIRPORT TARZAN	MAE DAMON	20.99	0	6227
7877	16	AIRPORT TAXI	HENRY PENN	21.99	0	4262
7878	11	AIRPORT TEEN	LIV GARLAND	27.99	0	7338
7879	14	AIRPORT TELEGRAPH	MARISA GIBSON	21.99	0	1906
7880	12	AIRPORT TELEMARK	CHARLIZE KELLY	9.99	0	7895
7881	10	AIRPORT TEMPLE	ZERO RYAN	14.99	0	3302
7882	14	AIRPORT TENENBAUMS	ANGELINA DOUGLAS	14.99	0	5066
7883	11	AIRPORT TEQUILA	SCARLETT KEITEL	15.99	0	1729
7884	1	AIRPORT TERMINATOR	KENNETH DEGENERES	23.99	0	3993
7885	14	AIRPORT TEXAS	SYLVESTER KEITEL	9.99	0	6195
7886	13	AIRPORT THEORY	HUMPHREY CRAWFORD	25.99	0	7263
7887	3	AIRPORT THIEF	ADAM DRIVER	12.99	0	8905
7888	11	AIRPORT THIN	IAN DAY-LEWIS	20.99	0	8204
7889	12	AIRPORT TIES	ANNE LANCASTER	14.99	0	8739
7890	11	AIRPORT TIGHTS	HUGH BOLGER	21.99	0	9694
7891	4	AIRPORT TIMBERLAND	CHARLIZE WASHINGTON	22.99	0	5711
7892	6	AIRPORT TITANIC	SALMA TAYLOR	16.99	0	4038
7893	5	AIRPORT TITANS	LUCILLE PINKETT	22.99	0	1486
7894	8	AIRPORT TOMATOES	MICHELLE BAILEY	20.99	0	9352
7895	7	AIRPORT TOMORROW	ANDY WRAY	26.99	0	1614
7896	13	AIRPORT TOOTSIE	BOB SINATRA	28.99	0	8284
7897	9	AIRPORT TORQUE	MICHAEL SARANDON	16.99	0	7505
7898	13	AIRPORT TOURIST	JOHN HAYEK	17.99	0	7871
7899	9	AIRPORT TOWERS	RITA LEWIS	14.99	0	1319
7900	3	AIRPORT TOWN	CARMEN KIDMAN	13.99	0	7181
7901	7	AIRPORT TRACY	KATE CAGE	18.99	0	9857
7902	5	AIRPORT TRADING	RAY LEIGH	9.99	0	9645
7903	13	AIRPORT TRAFFIC	HENRY OLIVIER	14.99	0	4742
7904	1	AIRPORT TRAIN	ANGELINA MCQUEEN	26.99	0	1626
7905	16	AIRPORT TRAINSPOTTING	MICHAEL BENING	11.99	0	424
7906	14	AIRPORT TRAMP	CHRISTOPHER MOSTEL	16.99	0	2378
7907	6	AIRPORT TRANSLATION	RICHARD HESTON	11.99	0	7366
7908	2	AIRPORT TRAP	JANE CROWE	19.99	0	5295
7909	16	AIRPORT TREASURE	CHRISTIAN HOPKINS	9.99	0	491
7910	3	AIRPORT TREATMENT	CAMERON DOUGLAS	27.99	0	3938
7911	15	AIRPORT TRIP	ANNE CRUZ	10.99	0	1913
7912	6	AIRPORT TROJAN	LUCILLE TOMEI	11.99	0	646
7913	14	AIRPORT TROOPERS	ELIZABETH BRODY	15.99	0	6795
7914	14	AIRPORT TROUBLE	CARY LEIGH	29.99	0	4316
7915	1	AIRPORT TRUMAN	MILLA POITIER	12.99	0	858
7916	9	AIRPORT TURN	FARRAH KEATON	21.99	0	8332
7917	13	AIRPORT TUXEDO	MORGAN VOIGHT	17.99	0	7500
7918	8	AIRPORT TWISTED	SCARLETT TORN	24.99	0	4845
7919	7	AIRPORT TYCOON	ANJELICA ANISTON	20.99	0	6309
7920	16	AIRPORT UNBREAKABLE	HARVEY BASINGER	23.99	0	9866
7921	13	AIRPORT UNCUT	JUDE POITIER	10.99	0	1000
7922	15	AIRPORT UNDEFEATED	ALAN CAMPBELL	21.99	0	535
7923	6	AIRPORT UNFAITHFUL	VIVIEN BASINGER	14.99	0	1455
7924	12	AIRPORT UNFORGIVEN	CHRIS DAMON	25.99	0	1742
7925	7	AIRPORT UNITED	DIANE PINKETT	25.99	0	4278
7926	13	AIRPORT UNTOUCHABLES	CLARK DAFOE	14.99	0	5277
7927	7	AIRPORT UPRISING	MATTHEW CHAPLIN	17.99	0	2374
7928	8	AIRPORT UPTOWN	FAY CAGE	17.99	0	770
7929	9	AIRPORT USUAL	FARRAH BLOOM	23.99	0	390
7930	15	AIRPORT VACATION	PEARL DREYFUSS	11.99	0	2037
7931	9	AIRPORT VALENTINE	HUMPHREY SPACEK	23.99	0	6663
7932	4	AIRPORT VALLEY	RITA JACKMAN	28.99	0	5830
7933	3	AIRPORT VAMPIRE	MINNIE FINNEY	18.99	0	843
7934	9	AIRPORT VANILLA	CLARK DIAZ	25.99	0	513
7935	14	AIRPORT VANISHED	GOLDIE STREEP	21.99	0	4007
7936	14	AIRPORT VANISHING	ED HUSTON	13.99	0	3559
7937	15	AIRPORT VARSITY	RUBY HECHE	23.99	0	7271
7938	5	AIRPORT VELVET	ANJELICA HURT	29.99	0	7716
7939	2	AIRPORT VERTIGO	ALICIA HAYEK	14.99	0	9985
7940	6	AIRPORT VICTORY	ROSIE BARRYMORE	22.99	0	7927
7941	1	AIRPORT VIDEOTAPE	ETHAN HUDSON	15.99	0	4626
7942	11	AIRPORT VIETNAM	SIDNEY LEWIS	19.99	0	2208
7943	4	AIRPORT VILLAIN	MICHAEL LAW	14.99	0	6114
7944	1	AIRPORT VIRGIN	ALICIA MINELLI	10.99	0	2498
7945	2	AIRPORT VIRGINIAN	FRANK DAY	28.99	0	9554
7946	12	AIRPORT VIRTUAL	JADA TYLER	29.99	0	1137
7947	8	AIRPORT VISION	MENA STALLONE	15.99	0	9630
7948	9	AIRPORT VOICE	JULIANNE KUDROW	14.99	0	833
7949	14	AIRPORT VOLCANO	NATALIE SWANK	27.99	0	6306
7950	3	AIRPORT VOLUME	RUBY ZELLWEGER	18.99	0	7117
7951	7	AIRPORT VOYAGE	LIZA MCCONAUGHEY	26.99	0	8199
7952	16	AIRPORT WAGON	MARY BALL	22.99	0	9913
7953	10	AIRPORT WAIT	KATE WAHLBERG	11.99	0	3536
7954	4	AIRPORT WAKE	DEBBIE BALE	28.99	0	1360
7955	9	AIRPORT WALLS	CARY BERRY	17.99	0	466
7956	2	AIRPORT WANDA	MATT WAHLBERG	24.99	0	2658
7957	9	AIRPORT WAR	GARY NOLTE	13.99	0	6819
7958	4	AIRPORT WARDROBE	LIAM TORN	24.99	0	7817
7959	2	AIRPORT WARLOCK	RITA DAFOE	15.99	0	7522
7960	8	AIRPORT WARS	ROBIN NICHOLSON	21.99	0	3535
7961	10	AIRPORT WASH	ETHAN CROWE	15.99	0	207
7962	9	AIRPORT WASTELAND	MICHELLE HUNT	27.99	0	127
7963	9	AIRPORT WATCH	SPENCER TOMEI	12.99	0	9177
7964	15	AIRPORT WATERFRONT	CARMEN PHOENIX	24.99	0	2457
7965	9	AIRPORT WATERSHIP	SYLVESTER HUSTON	16.99	0	9976
7966	12	AIRPORT WEDDING	CLINT NICHOLSON	29.99	0	1050
7967	16	AIRPORT WEEKEND	LAURA KEITEL	23.99	0	2659
7968	12	AIRPORT WEREWOLF	CHEVY WALKEN	21.99	0	7946
7969	9	AIRPORT WEST	JULIETTE ALLEN	22.99	0	5667
7970	15	AIRPORT WESTWARD	ANGELINA DICAPRIO	26.99	0	1037
7971	14	AIRPORT WHALE	PENELOPE DRIVER	29.99	0	7493
7972	2	AIRPORT WHISPERER	ETHAN DEGENERES	23.99	0	6537
7973	16	AIRPORT WIFE	LAUREN MCDORMAND	11.99	0	6602
7974	15	AIRPORT WILD	MATTHEW REYNOLDS	17.99	0	4341
7975	16	AIRPORT WILLOW	MICHELLE EASTWOOD	9.99	0	3012
7976	3	AIRPORT WIND	LAURENCE WASHINGTON	28.99	0	8418
7977	11	AIRPORT WINDOW	BELA BAILEY	28.99	0	2
7978	10	AIRPORT WISDOM	LIZA MOSTEL	12.99	0	8566
7979	14	AIRPORT WITCHES	LIV NEESON	19.99	0	259
7980	16	AIRPORT WIZARD	GLENN BLOOM	22.99	0	4481
7981	16	AIRPORT WOLVES	HELEN DOUGLAS	20.99	0	3115
7982	7	AIRPORT WOMEN	GREGORY THERON	18.99	0	604
7983	8	AIRPORT WON	MORGAN HEPBURN	10.99	0	4909
7984	16	AIRPORT WONDERFUL	CHEVY HOPPER	20.99	0	2552
7985	10	AIRPORT WONDERLAND	GREGORY VOIGHT	28.99	0	4787
7986	6	AIRPORT WONKA	OPRAH KEATON	24.99	0	9630
7987	1	AIRPORT WORDS	RUBY HESTON	17.99	0	6770
7988	8	AIRPORT WORKER	BURT GABLE	12.99	0	7225
7989	11	AIRPORT WORKING	CLARK GIBSON	26.99	0	1494
7990	2	AIRPORT WORLD	ANTHONY JOVOVICH	18.99	0	6343
7991	15	AIRPORT WORST	CHARLTON ROBERTS	22.99	0	2057
7992	11	AIRPORT WRATH	MARILYN LEIGH	18.99	0	5369
7993	3	AIRPORT WRONG	SIDNEY HAWN	14.99	0	3247
7994	16	AIRPORT WYOMING	MICHAEL DICAPRIO	12.99	0	6263
7995	5	AIRPORT YENTL	CATE CRAWFORD	16.99	0	5557
7996	1	AIRPORT YOUNG	GOLDIE KEATON	12.99	0	8503
7997	6	AIRPORT YOUTH	INGRID SILVERSTONE	9.99	0	3799
7998	9	AIRPORT ZHIVAGO	REESE HESTON	18.99	0	3953
7999	13	AIRPORT ZOOLANDER	MARY NICHOLSON	18.99	0	7571
8000	2	AIRPORT ZORRO	TOM CHAPLIN	13.99	0	5447
8001	13	ALABAMA ACADEMY	ANNETTE KINNEAR	11.99	0	2439
8002	16	ALABAMA ACE	ANJELICA BERGMAN	16.99	0	3390
8003	13	ALABAMA ADAPTATION	PEARL MCKELLEN	20.99	0	4714
8004	16	ALABAMA AFFAIR	CHARLTON SORVINO	21.99	0	9902
8005	6	ALABAMA AFRICAN	CHARLES GOLDBERG	15.99	0	6705
8006	14	ALABAMA AGENT	DENNIS GOLDBERG	28.99	0	9181
8007	3	ALABAMA AIRPLANE	WOODY HOPKINS	13.99	0	768
8008	9	ALABAMA AIRPORT	MILLA LUGOSI	15.99	0	7788
8009	13	ALABAMA ALABAMA	LISA BOGART	28.99	0	9022
8010	15	ALABAMA ALADDIN	EWAN BIRCH	10.99	0	8797
8011	12	ALABAMA ALAMO	ELLEN DENCH	29.99	0	7460
8012	15	ALABAMA ALASKA	DANIEL FIELD	27.99	0	256
8013	16	ALABAMA ALI	LISA BERGMAN	22.99	0	7584
8014	7	ALABAMA ALICE	SALLY CRUZ	9.99	0	5662
8015	16	ALABAMA ALIEN	MARISA BERRY	13.99	0	372
8016	2	ALABAMA ALLEY	EWAN TURNER	16.99	0	4320
8017	2	ALABAMA ALONE	NICOLAS POITIER	15.99	0	2658
8018	6	ALABAMA ALTER	GRACE LEIGH	28.99	0	7370
8019	12	ALABAMA AMADEUS	TIM MOORE	20.99	0	743
8020	3	ALABAMA AMELIE	CHARLTON MONROE	25.99	0	3104
8021	13	ALABAMA AMERICAN	DENZEL WOOD	10.99	0	828
8022	9	ALABAMA AMISTAD	ROBERT HUDSON	14.99	0	4465
8023	9	ALABAMA ANACONDA	AL BRANAGH	27.99	0	2348
8024	10	ALABAMA ANALYZE	SIGOURNEY PRESLEY	20.99	0	5982
8025	10	ALABAMA ANGELS	ELIZABETH HOPE	25.99	0	1334
8026	2	ALABAMA ANNIE	CARMEN BAILEY	15.99	0	4784
8027	6	ALABAMA ANONYMOUS	UMA MINELLI	13.99	0	7189
8028	11	ALABAMA ANTHEM	ROBERT HESTON	22.99	0	8801
8029	15	ALABAMA ANTITRUST	MAE TYLER	25.99	0	9583
8030	7	ALABAMA ANYTHING	HUME BENING	22.99	0	6244
8031	13	ALABAMA APACHE	MARLON TURNER	27.99	0	7783
8032	6	ALABAMA APOCALYPSE	JACK LEWIS	15.99	0	3297
8033	1	ALABAMA APOLLO	PARKER HECHE	27.99	0	761
8034	12	ALABAMA ARABIA	WINONA WOOD	17.99	0	4419
8035	6	ALABAMA ARACHNOPHOBIA	JUDI CLOSE	24.99	0	3365
8036	6	ALABAMA ARGONAUTS	ED LOLLOBRIGIDA	9.99	0	4410
8037	13	ALABAMA ARIZONA	AL STREEP	13.99	0	7906
8038	9	ALABAMA ARK	DENZEL DAMON	15.99	0	3062
8039	7	ALABAMA ARMAGEDDON	FRANCES SILVERSTONE	17.99	0	677
8040	14	ALABAMA ARMY	DREW KILMER	16.99	0	356
8041	11	ALABAMA ARSENIC	LISA MOORE	28.99	0	859
8042	6	ALABAMA ARTIST	TIM IRONS	16.99	0	1015
8043	3	ALABAMA ATLANTIS	GARY DICAPRIO	16.99	0	3773
8044	11	ALABAMA ATTACKS	DAN WRAY	29.99	0	3896
8045	1	ALABAMA ATTRACTION	THORA DAY	14.99	0	2141
8046	6	ALABAMA AUTUMN	SANDRA DEAN	28.99	0	5508
8047	1	ALABAMA BABY	ANDY JOLIE	28.99	0	7496
8048	1	ALABAMA BACKLASH	ALAN BALE	16.99	0	6108
8049	12	ALABAMA BADMAN	LEONARDO BOLGER	28.99	0	9870
8050	6	ALABAMA BAKED	DARYL BULLOCK	14.99	0	7552
8051	8	ALABAMA BALLOON	WILLIAM PENN	15.99	0	1283
8052	15	ALABAMA BALLROOM	MADELINE MOORE	28.99	0	5077
8053	11	ALABAMA BANG	KENNETH MIRANDA	23.99	0	9651
8054	5	ALABAMA BANGER	AUDREY PHOENIX	27.99	0	1531
8055	15	ALABAMA BARBARELLA	FARRAH WILSON	10.99	0	6882
8056	14	ALABAMA BAREFOOT	HUMPHREY NEESON	26.99	1	525
8057	16	ALABAMA BASIC	MILLA TAUTOU	21.99	0	3106
8058	2	ALABAMA BEACH	WALTER HOFFMAN	22.99	0	9620
8059	10	ALABAMA BEAR	MICHAEL HAWKE	23.99	0	3531
8060	14	ALABAMA BEAST	GINA CROWE	11.99	0	5339
8061	13	ALABAMA BEAUTY	DARYL BRANDO	13.99	0	1924
8062	5	ALABAMA BED	ANNE THERON	29.99	0	8393
8063	5	ALABAMA BEDAZZLED	FARRAH LANCASTER	13.99	0	4030
8064	4	ALABAMA BEETHOVEN	RITA RYAN	27.99	0	1231
8065	4	ALABAMA BEHAVIOR	GENE DRIVER	20.99	0	5845
8066	2	ALABAMA BENEATH	MICHAEL CRONYN	15.99	0	6286
8067	8	ALABAMA BERETS	JUDY MINELLI	20.99	0	9759
8068	7	ALABAMA BETRAYED	JULIETTE TEMPLE	23.99	0	7196
8069	2	ALABAMA BEVERLY	JUDI EASTWOOD	27.99	0	9713
8070	1	ALABAMA BIKINI	ELLEN HESTON	15.99	0	6473
8071	15	ALABAMA BILKO	ROBIN BOLGER	21.99	0	2183
8072	4	ALABAMA BILL	SALLY TORN	24.99	0	4612
8073	12	ALABAMA BINGO	GRACE STALLONE	14.99	0	4456
8074	16	ALABAMA BIRCH	NICOLE LUGOSI	19.99	0	9416
8075	8	ALABAMA BIRD	HARVEY JACKMAN	23.99	0	3805
8076	6	ALABAMA BIRDCAGE	JOE PHOENIX	12.99	0	8859
8077	7	ALABAMA BIRDS	PENELOPE LEWIS	14.99	0	2302
8078	12	ALABAMA BLACKOUT	AUDREY BALL	10.99	0	5832
8079	9	ALABAMA BLADE	CHRISTOPHER DICAPRIO	14.99	0	6516
8080	4	ALABAMA BLANKET	CHARLIZE CRUZ	21.99	0	9663
8081	16	ALABAMA BLINDNESS	MICHAEL DICAPRIO	18.99	0	355
8082	6	ALABAMA BLOOD	LIAM TANDY	11.99	0	9276
8083	6	ALABAMA BLUES	WHOOPI SUVARI	17.99	0	2627
8084	16	ALABAMA BOILED	JULIETTE HAYEK	12.99	0	2749
8085	14	ALABAMA BONNIE	JOAN THERON	29.99	0	3838
8086	15	ALABAMA BOOGIE	MARISA HAWKE	22.99	0	1032
8087	11	ALABAMA BOONDOCK	WARREN CRONYN	14.99	0	897
8088	4	ALABAMA BORN	UMA MCGREGOR	12.99	0	8571
8089	7	ALABAMA BORROWERS	FARRAH BACALL	29.99	0	9628
8090	4	ALABAMA BOULEVARD	ROSIE AFFLECK	23.99	0	3001
8091	2	ALABAMA BOUND	MINNIE TOMEI	24.99	0	5686
8092	14	ALABAMA BOWFINGER	NICOLE COSTNER	25.99	0	367
8093	15	ALABAMA BRANNIGAN	MARY MCQUEEN	26.99	0	6963
8094	12	ALABAMA BRAVEHEART	MORGAN DEAN	29.99	0	9100
8095	15	ALABAMA BREAKFAST	STEVE HAWN	25.99	0	8763
8096	2	ALABAMA BREAKING	PARKER DAMON	25.99	0	2807
8097	6	ALABAMA BRIDE	JENNIFER RUSSELL	11.99	0	8968
8098	3	ALABAMA BRIGHT	KARL IRONS	26.99	0	3370
8099	9	ALABAMA BRINGING	KIRSTEN ANISTON	13.99	1	7520
8100	3	ALABAMA BROOKLYN	CHRISTIAN WALKEN	10.99	0	2878
8101	15	ALABAMA BROTHERHOOD	JON RUSSELL	23.99	0	4438
8102	16	ALABAMA BUBBLE	DREW WEAVER	18.99	0	8244
8103	6	ALABAMA BUCKET	GENE DAMON	27.99	0	6350
8104	4	ALABAMA BUGSY	MARLENE KELLY	25.99	0	6425
8105	9	ALABAMA BULL	LANA TOMEI	23.99	0	2794
8106	16	ALABAMA BULWORTH	ANTHONY TAYLOR	18.99	0	6520
8107	15	ALABAMA BUNCH	LENA KINNEAR	12.99	0	6575
8108	16	ALABAMA BUTCH	SALMA DUNST	14.99	0	8829
8109	15	ALABAMA BUTTERFLY	HUMPHREY GARBO	20.99	0	1623
8110	4	ALABAMA CABIN	ANNE MCQUEEN	25.99	0	9996
8111	1	ALABAMA CADDYSHACK	SCARLETT DUKAKIS	11.99	0	4385
8112	13	ALABAMA CALENDAR	WILLEM NEWMAN	16.99	0	9506
8113	1	ALABAMA CALIFORNIA	EDWARD RUSH	27.99	0	4053
8114	13	ALABAMA CAMELOT	ORLANDO WINSLET	13.99	0	8802
8115	6	ALABAMA CAMPUS	JULIA POSEY	17.99	0	8359
8116	7	ALABAMA CANDIDATE	CARRIE LUGOSI	14.99	0	8869
8117	12	ALABAMA CANDLES	KIM JOHANSSON	23.99	0	3742
8118	11	ALABAMA CANYON	CHEVY TURNER	27.99	0	2210
8119	5	ALABAMA CAPER	DANIEL MALDEN	10.99	0	7425
8120	16	ALABAMA CARIBBEAN	JOHNNY CAGE	18.99	0	260
8121	5	ALABAMA CAROL	LIV WEAVER	17.99	0	3324
8122	5	ALABAMA CARRIE	ROBERT WEAVER	27.99	0	7010
8123	4	ALABAMA CASABLANCA	LIAM DUKAKIS	17.99	0	4168
8124	10	ALABAMA CASPER	ADRIEN JACKMAN	26.99	0	7880
8125	9	ALABAMA CASSIDY	SYLVESTER JACKMAN	10.99	0	4640
8126	2	ALABAMA CASUALTIES	IAN DENIRO	23.99	0	6430
8127	1	ALABAMA CAT	LEELEE WINFREY	26.99	0	2354
8128	9	ALABAMA CATCH	JULIETTE BIRCH	12.99	0	7182
8129	10	ALABAMA CAUSE	DEBBIE BOGART	21.99	0	7609
8130	7	ALABAMA CELEBRITY	ELIZABETH HURT	15.99	0	2067
8131	13	ALABAMA CENTER	JENNIFER MATTHAU	12.99	0	1186
8132	14	ALABAMA CHAINSAW	BOB FORD	17.99	0	9331
8133	11	ALABAMA CHAMBER	AL POSEY	12.99	0	4931
8134	15	ALABAMA CHAMPION	LEELEE JOLIE	11.99	0	5074
8135	14	ALABAMA CHANCE	WILLIAM HUNT	11.99	0	5149
8136	6	ALABAMA CHAPLIN	CARRIE KIDMAN	25.99	0	4354
8137	15	ALABAMA CHARADE	PAUL KIDMAN	29.99	0	9669
8138	15	ALABAMA CHARIOTS	MIRA MALDEN	28.99	0	6368
8139	7	ALABAMA CHASING	CATE MOSTEL	9.99	0	2304
8140	9	ALABAMA CHEAPER	MICHELLE MCGREGOR	19.99	0	4715
8141	1	ALABAMA CHICAGO	ADRIEN BERGEN	12.99	0	7193
8142	10	ALABAMA CHICKEN	ELIZABETH PITT	16.99	0	1983
8143	6	ALABAMA CHILL	RAY MONROE	9.99	0	5574
8144	11	ALABAMA CHINATOWN	DENZEL ALLEN	26.99	0	9815
8145	1	ALABAMA CHISUM	LIAM LANSBURY	24.99	0	3525
8146	4	ALABAMA CHITTY	JACK BLOOM	13.99	0	2674
8147	16	ALABAMA CHOCOLAT	ADRIEN SORVINO	13.99	0	7377
8148	7	ALABAMA CHOCOLATE	HENRY KEITEL	13.99	0	9727
8149	12	ALABAMA CHRISTMAS	WINONA DENIRO	29.99	0	181
8150	16	ALABAMA CIDER	LAURA BRODY	20.99	0	6465
8151	15	ALABAMA CINCINATTI	NICOLAS BOGART	15.99	0	9879
8152	10	ALABAMA CIRCUS	RIVER DOUGLAS	21.99	0	169
8153	6	ALABAMA CITIZEN	KATE TEMPLE	24.99	0	1061
8154	12	ALABAMA CLASH	GROUCHO SINATRA	23.99	0	4267
8155	12	ALABAMA CLEOPATRA	KENNETH PHOENIX	14.99	0	4227
8156	15	ALABAMA CLERKS	JULIA CRUISE	23.99	0	8471
8157	11	ALABAMA CLOCKWORK	CARMEN BRODY	19.99	0	6013
8158	8	ALABAMA CLONES	JODIE BERGEN	9.99	0	5490
8159	3	ALABAMA CLOSER	HALLE JOLIE	19.99	0	1492
8160	15	ALABAMA CLUB	SEAN TORN	18.99	0	1662
8161	15	ALABAMA CLUE	GWYNETH BRANDO	17.99	0	8841
8162	5	ALABAMA CLUELESS	ADAM HOFFMAN	17.99	0	7305
8163	16	ALABAMA CLYDE	REESE HAYEK	18.99	0	5991
8164	1	ALABAMA COAST	BRUCE MARTIN	17.99	0	2941
8165	9	ALABAMA COLDBLOODED	DAN BACALL	17.99	0	3763
8166	10	ALABAMA COLOR	JOHN HANNAH	28.99	0	2751
8167	14	ALABAMA COMA	MIRA BIRCH	26.99	0	6458
8168	9	ALABAMA COMANCHEROS	AUDREY HOPPER	16.99	0	5321
8169	16	ALABAMA COMFORTS	CATE WAYNE	10.99	0	2408
8170	6	ALABAMA COMMAND	ETHAN SWANK	20.99	0	7745
8171	15	ALABAMA COMMANDMENTS	CLARK STREEP	17.99	0	9937
8172	11	ALABAMA CONEHEADS	BELA MATTHAU	17.99	0	5451
8173	1	ALABAMA CONFESSIONS	ADAM ZELLWEGER	11.99	0	9284
8174	11	ALABAMA CONFIDENTIAL	SCARLETT FAWCETT	25.99	0	1975
8175	1	ALABAMA CONFUSED	ANNE PENN	15.99	0	3267
8176	2	ALABAMA CONGENIALITY	CLARK CROWE	14.99	0	9635
8177	4	ALABAMA CONNECTICUT	LANA DREYFUSS	15.99	0	115
8178	14	ALABAMA CONNECTION	ADRIEN PITT	27.99	0	3592
8179	13	ALABAMA CONQUERER	MATT KEATON	23.99	0	345
8180	14	ALABAMA CONSPIRACY	OLYMPIA FOSTER	28.99	0	179
8181	4	ALABAMA CONTACT	DARYL PESCI	17.99	0	8018
8182	7	ALABAMA CONTROL	BETTE DAY	29.99	0	7767
8183	16	ALABAMA CONVERSATION	JULIA HARRIS	29.99	0	3839
8184	6	ALABAMA CORE	SOPHIA BERRY	9.99	0	2131
8185	1	ALABAMA COWBOY	KIM MATTHAU	25.99	0	1995
8186	14	ALABAMA CRAFT	SYLVESTER RUSH	9.99	0	8939
8187	14	ALABAMA CRANES	CAMERON MANSFIELD	27.99	0	6546
8188	11	ALABAMA CRAZY	ANNETTE KIDMAN	13.99	0	3401
8189	10	ALABAMA CREATURES	INGRID SUVARI	19.99	0	1594
8190	12	ALABAMA CREEPERS	PARKER TORN	14.99	0	3031
8191	8	ALABAMA CROOKED	BETTE JOVOVICH	16.99	0	2926
8192	5	ALABAMA CROSSING	SIDNEY FOSTER	17.99	0	4455
8193	1	ALABAMA CROSSROADS	WILLEM WALKEN	11.99	0	4879
8194	8	ALABAMA CROW	GRACE PECK	26.99	0	1964
8195	1	ALABAMA CROWDS	BRAD TRACY	25.99	0	7900
8196	2	ALABAMA CRUELTY	FRANK MATTHAU	12.99	0	8209
8197	8	ALABAMA CRUSADE	CHRIS DEPP	16.99	0	4105
8198	13	ALABAMA CRYSTAL	GRACE NEWMAN	25.99	0	4676
8199	5	ALABAMA CUPBOARD	CLINT DAVIS	21.99	0	3808
8200	13	ALABAMA CURTAIN	FARRAH BIRCH	27.99	0	4368
8201	11	ALABAMA CYCLONE	ANGELINA WEST	29.99	0	328
8202	13	ALABAMA DADDY	FAY MALDEN	29.99	0	9245
8203	6	ALABAMA DAISY	LENA PITT	23.99	0	3723
8204	3	ALABAMA DALMATIONS	LAURENCE RUSH	16.99	0	6537
8205	12	ALABAMA DANCES	NICK CRONYN	9.99	0	6025
8206	8	ALABAMA DANCING	KIM PRESLEY	19.99	0	6827
8207	9	ALABAMA DANGEROUS	ETHAN KILMER	26.99	0	2189
8208	13	ALABAMA DARES	WARREN TEMPLE	16.99	0	4804
8209	12	ALABAMA DARKNESS	ELVIS ROBBINS	15.99	0	6444
8210	16	ALABAMA DARKO	RIVER TEMPLE	23.99	0	8989
8211	5	ALABAMA DARLING	MARLON GARCIA	26.99	0	3937
8212	9	ALABAMA DARN	TIM HARRIS	26.99	0	4355
8213	1	ALABAMA DATE	GENE WOOD	29.99	0	9055
8214	8	ALABAMA DAUGHTER	MEG BENING	24.99	0	8134
8215	7	ALABAMA DAWN	MERYL FONDA	13.99	0	5921
8216	2	ALABAMA DAY	VIVIEN FONDA	24.99	0	8228
8217	3	ALABAMA DAZED	DREW PFEIFFER	10.99	0	4692
8218	9	ALABAMA DECEIVER	JEREMY LEWIS	26.99	0	7983
8219	12	ALABAMA DEEP	SALMA BALL	17.99	0	2323
8220	4	ALABAMA DEER	KIRSTEN CLOSE	28.99	0	5967
8221	9	ALABAMA DELIVERANCE	THORA HUNT	18.99	0	1169
8222	5	ALABAMA DESERT	ROSIE GRANT	20.99	0	3861
8223	16	ALABAMA DESIRE	WALTER WRAY	18.99	0	5282
8224	5	ALABAMA DESPERATE	LANA LEWIS	11.99	1	3508
8225	6	ALABAMA DESTINATION	JUDY DAY-LEWIS	28.99	0	8774
8226	9	ALABAMA DESTINY	GREGORY MOSTEL	18.99	0	5795
8227	9	ALABAMA DETAILS	WHOOPI HECHE	17.99	0	4375
8228	13	ALABAMA DETECTIVE	JAMES WAYNE	24.99	0	2618
8229	5	ALABAMA DEVIL	ROBIN MINELLI	26.99	0	8235
8230	4	ALABAMA DIARY	ANGELINA BOGART	23.99	0	1945
8231	10	ALABAMA DINOSAUR	SALLY KAHN	28.99	0	9907
8232	9	ALABAMA DIRTY	INGRID JOHANSSON	18.99	0	3653
8233	15	ALABAMA DISCIPLE	GARY NEWMAN	16.99	0	7033
8234	10	ALABAMA DISTURBING	GREGORY NOLTE	18.99	0	1042
8235	5	ALABAMA DIVIDE	DARYL PENN	15.99	0	2115
8236	9	ALABAMA DIVINE	MORGAN ZELLWEGER	16.99	0	6721
8237	6	ALABAMA DIVORCE	CHRISTIAN HEPBURN	25.99	0	629
8238	3	ALABAMA DOCTOR	NICK SINATRA	18.99	0	1526
8239	3	ALABAMA DOGMA	ROCK REYNOLDS	19.99	0	3630
8240	10	ALABAMA DOLLS	BELA HOPPER	25.99	0	4993
8241	1	ALABAMA DONNIE	JON DICAPRIO	24.99	0	4258
8242	7	ALABAMA DOOM	SALMA WINSLET	21.99	0	7675
8243	11	ALABAMA DOORS	LAUREN TAYLOR	16.99	0	7433
8244	9	ALABAMA DORADO	JUDI HOPKINS	16.99	0	7043
8245	12	ALABAMA DOUBLE	CHRIS KILMER	25.99	0	9282
8246	5	ALABAMA DOUBTFIRE	DAN FREEMAN	25.99	0	8210
8247	4	ALABAMA DOWNHILL	REESE IRONS	10.99	0	5384
8248	14	ALABAMA DOZEN	IAN PACINO	18.99	0	7227
8249	4	ALABAMA DRACULA	CLARK MARX	23.99	0	1218
8250	7	ALABAMA DRAGON	MARY PALTROW	20.99	0	9993
8251	8	ALABAMA DRAGONFLY	GREGORY SMITH	23.99	0	4290
8252	9	ALABAMA DREAM	SUSAN TANDY	15.99	0	9829
8253	14	ALABAMA DRIFTER	MENA SINATRA	14.99	0	7681
8254	16	ALABAMA DRIVER	HARVEY HOPE	12.99	0	3539
8255	5	ALABAMA DRIVING	ANNE KINNEAR	28.99	0	5737
8256	15	ALABAMA DROP	HUGH MALDEN	14.99	0	263
8257	12	ALABAMA DRUMLINE	SIDNEY ROBERTS	22.99	0	8440
8258	10	ALABAMA DRUMS	MARLON WAHLBERG	15.99	0	9205
8259	2	ALABAMA DUCK	HALLE CAMPBELL	18.99	0	5120
8260	13	ALABAMA DUDE	ANJELICA LEIGH	26.99	0	1541
8261	7	ALABAMA DUFFEL	NICOLAS HEPBURN	26.99	0	187
8262	14	ALABAMA DUMBO	REESE HAYEK	24.99	0	8783
8263	10	ALABAMA DURHAM	REESE MOORE	14.99	0	9703
8264	3	ALABAMA DWARFS	CANDICE ANISTON	20.99	0	4104
8265	1	ALABAMA DYING	WILLEM DERN	11.99	0	4784
8266	5	ALABAMA DYNAMITE	STEVE KILMER	29.99	0	6245
8267	1	ALABAMA EAGLES	ANGELINA DAY	26.99	0	931
8268	12	ALABAMA EARLY	NICOLE KINNEAR	19.99	0	7022
8269	8	ALABAMA EARRING	MIRA WEAVER	21.99	0	1788
8270	16	ALABAMA EARTH	JAMES KELLY	29.99	0	5451
8271	8	ALABAMA EASY	BEN TEMPLE	16.99	0	4498
8272	16	ALABAMA EDGE	MATT TOMEI	9.99	0	6236
8273	2	ALABAMA EFFECT	CHRIS HACKMAN	27.99	0	9503
8274	10	ALABAMA EGG	SISSY FREEMAN	15.99	0	3834
8275	8	ALABAMA EGYPT	STEVE TURNER	27.99	0	5397
8276	8	ALABAMA ELEMENT	INGRID FIELD	20.99	0	2956
8277	16	ALABAMA ELEPHANT	CUBA MIRANDA	22.99	0	8923
8278	5	ALABAMA ELF	FAY RUSSELL	18.99	0	1750
8279	7	ALABAMA ELIZABETH	JULIANNE DAY	14.99	0	4439
8280	11	ALABAMA EMPIRE	GRETA WINFREY	21.99	0	2238
8281	2	ALABAMA ENCINO	KATE FINNEY	20.99	0	2046
8282	14	ALABAMA ENCOUNTERS	RUBY SORVINO	9.99	0	5188
8283	15	ALABAMA ENDING	FRED POITIER	13.99	0	9560
8284	7	ALABAMA ENEMY	CLARK LEIGH	27.99	0	6836
8285	6	ALABAMA ENGLISH	MARLON KEITEL	23.99	0	5322
8286	15	ALABAMA ENOUGH	RUSSELL DAY-LEWIS	18.99	0	7033
8287	11	ALABAMA ENTRAPMENT	KARL MANSFIELD	19.99	0	116
8288	1	ALABAMA ESCAPE	OPRAH KILMER	16.99	0	9424
8289	5	ALABAMA EVE	JUDY BRODY	18.99	0	3643
8290	3	ALABAMA EVERYONE	SIDNEY GARCIA	25.99	0	9902
8291	6	ALABAMA EVOLUTION	DENNIS WITHERSPOON	13.99	0	9786
8292	15	ALABAMA EXCITEMENT	LAURA BOGART	18.99	0	2010
8293	8	ALABAMA EXORCIST	NICK MINELLI	13.99	0	4804
8294	3	ALABAMA EXPECATIONS	LEONARDO DICAPRIO	22.99	0	6213
8295	1	ALABAMA EXPENDABLE	WINONA THERON	27.99	0	469
8296	15	ALABAMA EXPRESS	ALEC BAILEY	11.99	0	4657
8297	2	ALABAMA EXTRAORDINARY	KIRSTEN BRIDGES	22.99	0	1769
8298	14	ALABAMA EYES	RITA WOOD	21.99	0	7949
8299	2	ALABAMA FACTORY	ANNETTE FONDA	23.99	0	7953
8300	5	ALABAMA FALCON	MEG AFFLECK	15.99	0	3701
8301	6	ALABAMA FAMILY	HUME SANDLER	16.99	0	6245
8302	14	ALABAMA FANTASIA	NICOLAS AFFLECK	17.99	0	2921
8303	10	ALABAMA FANTASY	FARRAH KIDMAN	17.99	0	4723
8304	4	ALABAMA FARGO	RICHARD DAY-LEWIS	14.99	0	7925
8305	1	ALABAMA FATAL	REESE DAY	24.99	0	7065
8306	2	ALABAMA FEATHERS	JUDY SUVARI	19.99	0	4231
8307	2	ALABAMA FELLOWSHIP	JACK BASINGER	27.99	0	891
8308	3	ALABAMA FERRIS	LIZA BACALL	18.99	0	7595
8309	15	ALABAMA FEUD	WILLIAM MATTHAU	24.99	0	8931
8310	9	ALABAMA FEVER	CAMERON TURNER	15.99	0	6219
8311	1	ALABAMA FICTION	JOAN PFEIFFER	19.99	0	6933
8312	16	ALABAMA FIDDLER	NICOLE FREEMAN	16.99	0	1989
8313	8	ALABAMA FIDELITY	DORIS GARLAND	10.99	0	6496
8314	14	ALABAMA FIGHT	ELVIS PECK	26.99	0	1240
8315	12	ALABAMA FINDING	ALICIA WATSON	26.99	0	6669
8316	8	ALABAMA FIRE	HUGH DERN	28.99	0	6214
8317	10	ALABAMA FIREBALL	WHOOPI PESCI	16.99	0	1779
8318	9	ALABAMA FIREHOUSE	KATHARINE KUDROW	25.99	0	3488
8319	7	ALABAMA FISH	ANNETTE HUDSON	23.99	0	4938
8320	14	ALABAMA FLAMINGOS	JAMES AFFLECK	26.99	0	6765
8321	9	ALABAMA FLASH	TIM DOUGLAS	28.99	0	7109
8322	9	ALABAMA FLATLINERS	JAMES SARANDON	19.99	0	5266
8323	11	ALABAMA FLIGHT	BELA PFEIFFER	13.99	0	7048
8324	10	ALABAMA FLINTSTONES	CHRISTOPHER WEST	22.99	0	4606
8325	3	ALABAMA FLOATS	JESSICA HUDSON	20.99	0	2921
8326	4	ALABAMA FLYING	KIRSTEN STALLONE	12.99	0	7636
8327	15	ALABAMA FOOL	LANA DUNST	15.99	0	7439
8328	14	ALABAMA FOREVER	JOAN IRONS	28.99	0	9891
8329	11	ALABAMA FORREST	UMA DUKAKIS	25.99	0	5891
8330	5	ALABAMA FORRESTER	ANNE BENING	24.99	0	3816
8331	1	ALABAMA FORWARD	DORIS TAYLOR	21.99	0	9855
8332	6	ALABAMA FRANKENSTEIN	FARRAH WASHINGTON	28.99	0	874
8333	11	ALABAMA FREAKY	LANA BOGART	11.99	0	2891
8334	3	ALABAMA FREDDY	LAUREN MIRANDA	10.99	0	5107
8335	11	ALABAMA FREEDOM	LANA PALTROW	24.99	0	2045
8336	2	ALABAMA FRENCH	BELA HOPE	15.99	0	1233
8337	5	ALABAMA FRIDA	ANNE GOLDBERG	21.99	0	3086
8338	11	ALABAMA FRISCO	HUMPHREY WILLIS	14.99	0	4302
8339	9	ALABAMA FROGMEN	BELA DEAN	11.99	0	5288
8340	11	ALABAMA FRONTIER	DUSTIN WEAVER	13.99	0	6700
8341	7	ALABAMA FROST	CANDICE PRESLEY	19.99	0	1492
8342	10	ALABAMA FUGITIVE	JULIETTE GRANT	22.99	0	8253
8343	16	ALABAMA FULL	RALPH MOORE	17.99	0	8871
8344	14	ALABAMA FURY	CAMERON HOPE	27.99	0	4063
8345	7	ALABAMA GABLES	GROUCHO DAFOE	22.99	0	191
8346	6	ALABAMA GALAXY	PEARL SINATRA	18.99	0	8593
8347	10	ALABAMA GAMES	EDWARD VOIGHT	11.99	0	2243
8348	16	ALABAMA GANDHI	SEAN LANSBURY	24.99	0	7871
8349	10	ALABAMA GANGS	DUSTIN POSEY	24.99	0	8055
8350	3	ALABAMA GARDEN	ADRIEN BERGEN	19.99	0	4154
8351	9	ALABAMA GASLIGHT	DREW BEATTY	15.99	0	5407
8352	3	ALABAMA GATHERING	JEREMY BOGART	17.99	0	409
8353	11	ALABAMA GENTLEMEN	LENA COSTNER	19.99	0	5402
8354	5	ALABAMA GHOST	FRANCES KIDMAN	20.99	0	9412
8355	6	ALABAMA GHOSTBUSTERS	ADRIEN HARRIS	16.99	0	7367
8356	13	ALABAMA GIANT	RAY HAYEK	29.99	0	2963
8357	9	ALABAMA GILBERT	HUGH TAYLOR	29.99	0	6185
8358	1	ALABAMA GILMORE	RALPH TORN	22.99	0	6968
8359	3	ALABAMA GLADIATOR	DORIS OLIVIER	18.99	0	4929
8360	7	ALABAMA GLASS	SOPHIA LANSBURY	17.99	0	8069
8361	3	ALABAMA GLEAMING	DORIS MONROE	28.99	0	9467
8362	4	ALABAMA GLORY	RITA COSTNER	22.99	0	917
8363	5	ALABAMA GO	WINONA CROWE	9.99	0	3931
8364	12	ALABAMA GODFATHER	BETTE WITHERSPOON	29.99	0	3106
8365	8	ALABAMA GOLD	SANDRA SUVARI	16.99	0	7619
8366	3	ALABAMA GOLDFINGER	IAN HAWKE	17.99	0	542
8367	6	ALABAMA GOLDMINE	DORIS MALDEN	12.99	0	3855
8368	5	ALABAMA GONE	LANA HUSTON	14.99	0	3907
8369	11	ALABAMA GOODFELLAS	HARVEY DIAZ	24.99	0	8228
8370	1	ALABAMA GORGEOUS	MATTHEW NORTON	27.99	0	9374
8371	11	ALABAMA GOSFORD	GRETA DAY	10.99	0	7069
8372	3	ALABAMA GRACELAND	FRED WEST	16.99	0	5310
8373	12	ALABAMA GRADUATE	AL GARLAND	15.99	0	5378
8374	12	ALABAMA GRAFFITI	RENEE DENIRO	10.99	0	317
8375	15	ALABAMA GRAIL	MORGAN AKROYD	21.99	0	7695
8376	9	ALABAMA GRAPES	WINONA LEIGH	27.99	0	5966
8377	10	ALABAMA GREASE	KEVIN ROBBINS	27.99	0	6661
8378	7	ALABAMA GREATEST	ALICIA TAUTOU	17.99	0	6455
8379	16	ALABAMA GREEDY	SIGOURNEY TOMEI	24.99	0	8633
8380	13	ALABAMA GREEK	SANDRA TAYLOR	19.99	0	7746
8381	5	ALABAMA GRINCH	GREG WILSON	14.99	0	9870
8382	14	ALABAMA GRIT	ORLANDO HANNAH	17.99	0	8897
8383	2	ALABAMA GROOVE	OPRAH NOLTE	11.99	0	9443
8384	13	ALABAMA GROSSE	ROBIN BEATTY	22.99	0	8057
8385	9	ALABAMA GROUNDHOG	MEL MARTIN	17.99	0	1329
8386	3	ALABAMA GUMP	BRAD GUINESS	19.99	0	9324
8387	8	ALABAMA GUN	GRACE KEATON	14.99	0	6161
8388	3	ALABAMA GUNFIGHT	FRANK AKROYD	27.99	0	4018
8389	14	ALABAMA GUNFIGHTER	JEREMY TEMPLE	23.99	0	2747
8390	8	ALABAMA GUYS	SEAN BALL	12.99	0	9934
8391	5	ALABAMA HALF	HENRY LOLLOBRIGIDA	17.99	0	446
8392	6	ALABAMA HALL	KIRK LAW	22.99	0	4933
8393	5	ALABAMA HALLOWEEN	JUDE WEAVER	21.99	0	6208
8394	16	ALABAMA HAMLET	JON NORTON	18.99	0	251
8395	12	ALABAMA HANDICAP	ANTHONY STALLONE	21.99	0	4876
8396	10	ALABAMA HANGING	ANTHONY DUNST	29.99	0	1444
8397	1	ALABAMA HANKY	MILLA ANISTON	21.99	0	5205
8398	2	ALABAMA HANOVER	JIM WILLIS	21.99	0	3135
8399	4	ALABAMA HAPPINESS	ZERO KEITEL	23.99	0	3590
8400	12	ALABAMA HARDLY	DANIEL NICHOLSON	25.99	0	2023
8401	5	ALABAMA HAROLD	JON SWANK	16.99	0	1895
8402	8	ALABAMA HARPER	DEBBIE SUVARI	13.99	0	8871
8403	12	ALABAMA HARRY	RUBY KAHN	12.99	0	3868
8404	8	ALABAMA HATE	SPENCER DREYFUSS	19.99	0	8691
8405	14	ALABAMA HAUNTED	KENNETH PACINO	10.99	0	8173
8406	5	ALABAMA HAUNTING	MEG PRESLEY	24.99	0	5102
8407	16	ALABAMA HAWK	GWYNETH LOREN	12.99	0	7985
8408	1	ALABAMA HEAD	GARY IRONS	27.99	0	3970
8409	5	ALABAMA HEARTBREAKERS	MEL COOPER	12.99	0	6623
8410	1	ALABAMA HEAVEN	GWYNETH KAHN	21.99	0	8495
8411	7	ALABAMA HEAVENLY	LIAM SMITH	10.99	0	7090
8412	10	ALABAMA HEAVYWEIGHTS	FRANCES KEITEL	29.99	0	688
8413	13	ALABAMA HEDWIG	KIM PALTROW	10.99	0	2301
8414	8	ALABAMA HELLFIGHTERS	HUGH TANDY	12.99	0	589
8415	13	ALABAMA HIGH	LANA BLANCHETT	12.99	0	1412
8416	1	ALABAMA HIGHBALL	WARREN BLOOM	22.99	0	5411
8417	6	ALABAMA HILLS	ANNETTE ROBERTS	22.99	0	7317
8418	12	ALABAMA HOBBIT	JANE JACKMAN	14.99	0	300
8419	8	ALABAMA HOCUS	SIGOURNEY BACALL	27.99	0	9324
8420	16	ALABAMA HOLES	ALBERT WITHERSPOON	19.99	0	7013
8421	11	ALABAMA HOLIDAY	RAY CRAWFORD	22.99	0	9716
8422	3	ALABAMA HOLLOW	NICOLE CARREY	13.99	0	4831
8423	16	ALABAMA HOLLYWOOD	WILLEM HUSTON	17.99	0	5399
8424	7	ALABAMA HOLOCAUST	KIRSTEN DEAN	15.99	0	7414
8425	5	ALABAMA HOLY	MORGAN BENING	14.99	0	8802
8426	16	ALABAMA HOME	ANNE DEGENERES	25.99	0	8648
8427	12	ALABAMA HOMEWARD	AL BACALL	19.99	0	7919
8428	16	ALABAMA HOMICIDE	ETHAN DAVIS	28.99	0	123
8429	8	ALABAMA HONEY	ED BALE	10.99	0	3570
8430	13	ALABAMA HOOK	INGRID MARX	19.99	0	9980
8431	7	ALABAMA HOOSIERS	DUSTIN SUVARI	18.99	0	1020
8432	6	ALABAMA HOPE	CARY GABLE	15.99	0	3866
8433	2	ALABAMA HORN	LEONARDO SANDLER	17.99	0	2108
8434	7	ALABAMA HORROR	EDWARD DEE	22.99	0	6044
8435	1	ALABAMA HOTEL	DENNIS BERRY	17.99	0	906
8436	7	ALABAMA HOURS	UMA WRAY	22.99	0	5586
8437	13	ALABAMA HOUSE	STEVE RICKMAN	27.99	0	7500
8438	5	ALABAMA HUMAN	KEVIN DAY-LEWIS	27.99	0	3042
8439	2	ALABAMA HUNCHBACK	KATE BACALL	16.99	0	8232
8440	16	ALABAMA HUNGER	SOPHIA NOLTE	12.99	0	4970
8441	4	ALABAMA HUNTER	JOHNNY KIDMAN	12.99	0	9386
8442	12	ALABAMA HUNTING	MILLA WEST	22.99	0	8057
8443	7	ALABAMA HURRICANE	ALEC BULLOCK	29.99	0	6481
8444	5	ALABAMA HUSTLER	MEG BOGART	25.99	0	3527
8445	11	ALABAMA HYDE	ANDY GOODING	20.99	0	1445
8446	1	ALABAMA HYSTERICAL	MEG RUSH	19.99	0	8663
8447	8	ALABAMA ICE	RITA PENN	12.99	0	6668
8448	16	ALABAMA IDAHO	RAY RUSH	29.99	0	8011
8449	11	ALABAMA IDENTITY	SISSY ALLEN	15.99	0	3365
8450	11	ALABAMA IDOLS	MIRA HOPE	23.99	0	2531
8451	14	ALABAMA IGBY	ALICIA AFFLECK	20.99	0	45
8452	7	ALABAMA ILLUSION	MORGAN WINFREY	13.99	0	943
8453	15	ALABAMA IMAGE	SEAN BOLGER	23.99	0	6223
8454	8	ALABAMA IMPACT	MADELINE PITT	16.99	0	4528
8455	12	ALABAMA IMPOSSIBLE	SISSY PINKETT	17.99	0	8746
8456	11	ALABAMA INCH	SEAN DUNST	24.99	0	3960
8457	12	ALABAMA INDEPENDENCE	HARRISON DAY-LEWIS	18.99	0	5068
8458	9	ALABAMA INDIAN	LISA FIENNES	17.99	1	7103
8459	1	ALABAMA INFORMER	JENNIFER HUDSON	23.99	0	5182
8460	2	ALABAMA INNOCENT	ELIZABETH LANCASTER	9.99	0	6995
8461	15	ALABAMA INSECTS	ZERO MOSTEL	25.99	0	8239
8462	3	ALABAMA INSIDER	ANGELA BOLGER	20.99	0	4796
8463	1	ALABAMA INSTINCT	REESE BERRY	22.99	0	7862
8464	6	ALABAMA INTENTIONS	ELIZABETH KEITEL	26.99	0	943
8465	6	ALABAMA INTERVIEW	MARISA FIELD	21.99	0	6288
8466	5	ALABAMA INTOLERABLE	FRANCES DEE	15.99	0	6715
8467	2	ALABAMA INTRIGUE	PAUL COSTNER	12.99	0	3135
8468	11	ALABAMA INVASION	HILARY POSEY	18.99	0	8793
8469	4	ALABAMA IRON	HUME ROBERTS	18.99	0	5949
8470	10	ALABAMA ISHTAR	SPENCER WATSON	13.99	0	2443
8471	14	ALABAMA ISLAND	JOAN SMITH	11.99	0	4775
8472	13	ALABAMA ITALIAN	MARISA DAY-LEWIS	21.99	0	3579
8473	15	ALABAMA JACKET	CAMERON ASTAIRE	14.99	0	5236
8474	3	ALABAMA JADE	FRED NEWMAN	20.99	0	8974
8475	3	ALABAMA JAPANESE	ROBIN PECK	10.99	0	3613
8476	5	ALABAMA JASON	CLINT RICKMAN	25.99	0	2923
8477	5	ALABAMA JAWBREAKER	JULIA PALTROW	28.99	0	8990
8478	5	ALABAMA JAWS	SUSAN CRAWFORD	17.99	0	3729
8479	15	ALABAMA JEDI	ANGELINA MCCONAUGHEY	13.99	0	1913
8480	2	ALABAMA JEEPERS	SOPHIA FORD	28.99	0	8283
8481	5	ALABAMA JEKYLL	LENA PENN	19.99	0	4977
8482	13	ALABAMA JEOPARDY	DARYL RICKMAN	15.99	0	4898
8483	3	ALABAMA JERICHO	MATT WEAVER	11.99	0	1223
8484	8	ALABAMA JERK	NICK DEGENERES	20.99	0	9199
8485	12	ALABAMA JERSEY	ELLEN KUDROW	22.99	0	6633
8486	8	ALABAMA JET	HARVEY ROBERTS	9.99	0	8824
8487	9	ALABAMA JINGLE	MARISA BAILEY	24.99	0	3265
8488	4	ALABAMA JOON	ETHAN JOVOVICH	27.99	0	6041
8489	1	ALABAMA JUGGLER	ROCK BLOOM	25.99	0	2820
8490	11	ALABAMA JUMANJI	ROBERT FONDA	28.99	0	3096
8491	10	ALABAMA JUMPING	BETTE HANNAH	29.99	0	3484
8492	14	ALABAMA JUNGLE	HARVEY WOOD	19.99	0	6984
8493	14	ALABAMA KANE	DARYL WILSON	11.99	0	8172
8494	12	ALABAMA KARATE	SPENCER TOMEI	20.99	0	5262
8495	14	ALABAMA KENTUCKIAN	SALLY FORD	23.99	0	8130
8496	16	ALABAMA KICK	DENNIS THERON	10.99	0	6579
8497	7	ALABAMA KILL	MARILYN PHOENIX	25.99	0	3743
8498	8	ALABAMA KILLER	GREG BLANCHETT	23.99	0	2092
8499	9	ALABAMA KING	BRUCE WAHLBERG	17.99	0	7547
8500	16	ALABAMA KISS	BOB FINNEY	26.99	1	3694
8501	10	ALABAMA KISSING	ELIZABETH WINFREY	26.99	0	1171
8502	8	ALABAMA KNOCK	RUBY HOPKINS	11.99	0	962
8503	9	ALABAMA KRAMER	CLINT PITT	26.99	0	3882
8504	1	ALABAMA KWAI	GENE WILLIAMS	12.99	0	7942
8505	15	ALABAMA LABYRINTH	CANDICE FONDA	9.99	0	1111
8506	7	ALABAMA LADY	BEN REYNOLDS	22.99	0	1214
8507	12	ALABAMA LADYBUGS	LAURA BOGART	21.99	0	8265
8508	12	ALABAMA LAMBS	LANA POITIER	27.99	0	117
8509	5	ALABAMA LANGUAGE	WHOOPI MOSTEL	21.99	0	3495
8510	6	ALABAMA LAWLESS	MEL PITT	19.99	0	8225
8511	10	ALABAMA LAWRENCE	LAURENCE BULLOCK	23.99	0	1890
8512	13	ALABAMA LEAGUE	FAY JOVOVICH	16.99	0	5195
8513	4	ALABAMA LEATHERNECKS	EMILY RYAN	25.99	0	8648
8514	13	ALABAMA LEBOWSKI	JULIETTE WASHINGTON	24.99	0	3507
8515	2	ALABAMA LEGALLY	BOB TEMPLE	25.99	0	8432
8516	10	ALABAMA LEGEND	WILL WILSON	13.99	0	7307
8517	7	ALABAMA LESSON	DUSTIN HOPKINS	23.99	0	3366
8518	4	ALABAMA LIAISONS	CARRIE BALE	18.99	0	7982
8519	6	ALABAMA LIBERTY	NEVE MANSFIELD	26.99	0	2409
8520	4	ALABAMA LICENSE	CARMEN HOPPER	15.99	0	4878
8521	3	ALABAMA LIES	JENNIFER SUVARI	11.99	0	1027
8522	14	ALABAMA LIFE	KEVIN HESTON	10.99	0	3840
8523	7	ALABAMA LIGHTS	INGRID DUNST	20.99	0	2313
8524	6	ALABAMA LION	ROBIN BERGMAN	10.99	0	1846
8525	5	ALABAMA LOATHING	MARILYN BRANDO	17.99	0	8904
8526	15	ALABAMA LOCK	NICOLE KILMER	16.99	0	7956
8527	8	ALABAMA LOLA	DREW HURT	9.99	0	3370
8528	7	ALABAMA LOLITA	MADELINE WEST	26.99	0	3834
8529	1	ALABAMA LONELY	JENNIFER SOBIESKI	27.99	0	3713
8530	2	ALABAMA LORD	JOHN DAFOE	24.99	0	8891
8531	10	ALABAMA LOSE	JADA KINNEAR	16.99	0	661
8532	3	ALABAMA LOSER	KATHARINE GOODING	17.99	0	895
8533	12	ALABAMA LOST	ANGELA SMITH	16.99	0	5360
8534	12	ALABAMA LOUISIANA	GWYNETH PECK	12.99	0	2554
8535	9	ALABAMA LOVE	JEREMY NICHOLSON	9.99	0	833
8536	15	ALABAMA LOVELY	LUCILLE AKROYD	16.99	0	5388
8537	7	ALABAMA LOVER	SYLVESTER KAHN	29.99	0	3345
8538	1	ALABAMA LOVERBOY	CHEVY MCCONAUGHEY	11.99	0	8056
8539	11	ALABAMA LUCK	JULIA PACINO	9.99	0	1194
8540	5	ALABAMA LUCKY	REESE HOPKINS	23.99	0	1952
8541	13	ALABAMA LUKE	DARYL HEPBURN	17.99	0	5671
8542	16	ALABAMA LUST	BEN DAY	27.99	0	9784
8543	4	ALABAMA MADIGAN	LEELEE DENCH	16.99	0	5615
8544	3	ALABAMA MADISON	ELVIS WITHERSPOON	23.99	0	1551
8545	14	ALABAMA MADNESS	LIAM DENCH	21.99	0	1043
8546	13	ALABAMA MADRE	KATE POITIER	9.99	0	3290
8547	10	ALABAMA MAGIC	KENNETH BULLOCK	22.99	0	7342
8548	11	ALABAMA MAGNIFICENT	WILLEM DEAN	13.99	0	3251
8549	13	ALABAMA MAGNOLIA	GARY ROBERTS	10.99	0	2945
8550	4	ALABAMA MAGUIRE	KARL DRIVER	26.99	0	4869
8551	15	ALABAMA MAIDEN	DREW PALTROW	18.99	0	4000
8552	13	ALABAMA MAJESTIC	JULIETTE DUKAKIS	16.99	0	5357
8553	2	ALABAMA MAKER	ORLANDO MALDEN	10.99	0	3622
8554	6	ALABAMA MALKOVICH	CHARLES MATTHAU	23.99	0	6132
8555	16	ALABAMA MALLRATS	SOPHIA THERON	19.99	0	8003
8556	16	ALABAMA MALTESE	JUDI MCDORMAND	13.99	0	2232
8557	11	ALABAMA MANCHURIAN	JULIA TAYLOR	12.99	0	4701
8558	12	ALABAMA MANNEQUIN	ANNETTE DOUGLAS	18.99	0	8822
8559	14	ALABAMA MARRIED	JON OLIVIER	29.99	0	1682
8560	10	ALABAMA MARS	ANJELICA GARBO	18.99	0	7525
8561	5	ALABAMA MASK	HARVEY TAUTOU	25.99	0	4596
8562	1	ALABAMA MASKED	GOLDIE PHOENIX	19.99	0	5376
8563	16	ALABAMA MASSACRE	RIP LUGOSI	10.99	0	1388
8564	15	ALABAMA MASSAGE	ROCK TANDY	18.99	0	2174
8565	10	ALABAMA MATRIX	LAURA GUINESS	22.99	0	4454
8566	7	ALABAMA MAUDE	GENE CAINE	25.99	0	4156
8567	4	ALABAMA MEET	CHARLIZE VOIGHT	20.99	0	400
8568	2	ALABAMA MEMENTO	LUCILLE HECHE	28.99	0	6668
8569	1	ALABAMA MENAGERIE	JULIETTE HARRIS	27.99	0	3455
8570	2	ALABAMA MERMAID	NICK HEPBURN	23.99	0	5985
8571	3	ALABAMA METAL	NEVE HUSTON	18.99	0	6484
8572	14	ALABAMA METROPOLIS	KIRSTEN JOHANSSON	9.99	0	16
8573	1	ALABAMA MICROCOSMOS	JADA COOPER	23.99	0	9028
8574	6	ALABAMA MIDNIGHT	GENE CAMPBELL	27.99	0	1465
8575	4	ALABAMA MIDSUMMER	LAURA CARREY	28.99	0	6611
8576	9	ALABAMA MIGHTY	CHARLES WILSON	14.99	0	4021
8577	15	ALABAMA MILE	SISSY DOUGLAS	19.99	0	9603
8578	8	ALABAMA MILLION	CARRIE FORD	28.99	0	2144
8579	14	ALABAMA MINDS	GROUCHO GARBO	11.99	0	3968
8580	5	ALABAMA MINE	KENNETH HOFFMAN	27.99	0	3837
8581	9	ALABAMA MINORITY	GRETA WAYNE	23.99	0	7689
8582	2	ALABAMA MIRACLE	ANGELINA CHASE	29.99	0	3362
8583	15	ALABAMA MISSION	MEG CHAPLIN	10.99	0	6921
8584	5	ALABAMA MIXED	ANJELICA TRACY	22.99	0	2787
8585	1	ALABAMA MOB	MORGAN FISHER	21.99	0	1152
8586	16	ALABAMA MOCKINGBIRD	ANNE PENN	15.99	0	2834
8587	2	ALABAMA MOD	JAYNE HOPPER	11.99	0	937
8588	8	ALABAMA MODEL	EDWARD GABLE	11.99	0	3219
8589	14	ALABAMA MODERN	DORIS NICHOLSON	27.99	0	2696
8590	3	ALABAMA MONEY	LENA FONDA	27.99	0	7889
8591	16	ALABAMA MONSOON	JUDI TANDY	10.99	0	8916
8592	6	ALABAMA MONSTER	GREGORY DENIRO	25.99	0	7714
8593	14	ALABAMA MONTEREY	CARMEN SORVINO	11.99	0	5316
8594	7	ALABAMA MONTEZUMA	DENNIS SANDLER	22.99	0	5176
8595	15	ALABAMA MOON	RUSSELL SPACEK	20.99	0	7564
8596	6	ALABAMA MOONSHINE	LIV PECK	26.99	0	7889
8597	12	ALABAMA MOONWALKER	ANDY BOLGER	10.99	0	4110
8598	14	ALABAMA MOSQUITO	EDWARD POSEY	29.99	0	2171
8599	8	ALABAMA MOTHER	ALAN EASTWOOD	23.99	0	6983
8600	4	ALABAMA MOTIONS	KATE TRACY	10.99	0	2559
8601	14	ALABAMA MOULIN	WHOOPI POITIER	18.99	0	7369
8602	4	ALABAMA MOURNING	ROSIE DUKAKIS	14.99	0	7200
8603	11	ALABAMA MOVIE	JOAN CRUISE	28.99	0	3355
8604	3	ALABAMA MULAN	MAE MINELLI	12.99	0	6049
8605	14	ALABAMA MULHOLLAND	JUDE LAW	17.99	0	9356
8606	11	ALABAMA MUMMY	MENA HOPPER	22.99	0	2605
8607	6	ALABAMA MUPPET	KEVIN CAGE	13.99	0	9087
8608	15	ALABAMA MURDER	BRUCE BIRCH	17.99	0	2516
8609	12	ALABAMA MUSCLE	SIGOURNEY CHAPLIN	16.99	0	2359
8610	16	ALABAMA MUSIC	REESE COSTNER	18.99	0	4268
8611	7	ALABAMA MUSKETEERS	SHIRLEY DAY-LEWIS	10.99	0	7814
8612	6	ALABAMA MUSSOLINI	STEVE DAFOE	28.99	0	3143
8613	14	ALABAMA MYSTIC	HUGH FIENNES	28.99	0	4049
8614	3	ALABAMA NAME	KIM HEPBURN	10.99	0	8692
8615	5	ALABAMA NASH	ANGELA REYNOLDS	10.99	0	6091
8616	9	ALABAMA NATIONAL	ROBERT MINELLI	17.99	0	6718
8617	3	ALABAMA NATURAL	SCARLETT BLOOM	11.99	1	2732
8618	7	ALABAMA NECKLACE	LEELEE SILVERSTONE	25.99	0	3005
8619	4	ALABAMA NEIGHBORS	NEVE TOMEI	25.99	0	5281
8620	11	ALABAMA NEMO	FRANCES DEPP	23.99	0	5260
8621	5	ALABAMA NETWORK	CHRISTIAN TANDY	11.99	0	9057
8622	13	ALABAMA NEWSIES	ZERO HOPE	22.99	0	9928
8623	15	ALABAMA NEWTON	RENEE WILLIAMS	20.99	0	5316
8624	14	ALABAMA NIGHTMARE	JADA WINFREY	20.99	0	3805
8625	2	ALABAMA NONE	MADELINE GOODING	16.99	0	9751
8626	15	ALABAMA NOON	ROCK FREEMAN	10.99	0	1040
8627	16	ALABAMA NORTH	KEVIN DEPP	29.99	0	981
8628	16	ALABAMA NORTHWEST	ANJELICA STREEP	25.99	0	8166
8629	5	ALABAMA NOTORIOUS	RAY DAFOE	24.99	0	5341
8630	2	ALABAMA NOTTING	STEVE SUVARI	24.99	0	9730
8631	12	ALABAMA NOVOCAINE	GEOFFREY CAINE	20.99	0	7821
8632	11	ALABAMA NUTS	ALICIA CROWE	13.99	0	9467
8633	5	ALABAMA OCTOBER	RAY CAGE	16.99	0	1693
8634	3	ALABAMA ODDS	HARRISON DAVIS	29.99	0	1344
8635	9	ALABAMA OKLAHOMA	WINONA BASINGER	17.99	0	2161
8636	7	ALABAMA OLEANDER	GRETA KAHN	23.99	0	5619
8637	8	ALABAMA OPEN	OLYMPIA PFEIFFER	20.99	0	9177
8638	8	ALABAMA OPERATION	ANJELICA DEPP	14.99	0	9598
8639	8	ALABAMA OPPOSITE	CHRISTOPHER RYDER	26.99	0	1147
8640	16	ALABAMA OPUS	CHRISTIAN DIETRICH	28.99	0	9639
8641	3	ALABAMA ORANGE	JODIE BLANCHETT	19.99	0	5451
8642	1	ALABAMA ORDER	ETHAN DUKAKIS	26.99	0	2135
8643	12	ALABAMA ORIENT	JESSICA DUNST	25.99	0	793
8644	12	ALABAMA OSCAR	SEAN AFFLECK	28.99	0	6430
8645	1	ALABAMA OTHERS	SUSAN PRESLEY	13.99	0	6111
8646	3	ALABAMA OUTBREAK	MICHAEL SORVINO	22.99	0	4985
8647	3	ALABAMA OUTFIELD	RAY GUINESS	18.99	0	6151
8648	11	ALABAMA OUTLAW	STEVE WASHINGTON	11.99	0	4779
8649	4	ALABAMA OZ	JOE HOPKINS	10.99	0	2962
8650	12	ALABAMA PACIFIC	ANJELICA GUINESS	22.99	0	7426
8651	5	ALABAMA PACKER	LAURA POITIER	29.99	0	9084
8652	8	ALABAMA PAJAMA	FRANK LEIGH	14.99	0	5020
8653	14	ALABAMA PANIC	JAMES NORTON	25.99	0	1455
8654	5	ALABAMA PANKY	LENA BAILEY	24.99	0	9644
8655	1	ALABAMA PANTHER	GROUCHO STREEP	10.99	0	9467
8656	14	ALABAMA PAPI	MICHAEL POITIER	17.99	0	800
8657	5	ALABAMA PARADISE	MARISA CHASE	21.99	0	6661
8658	2	ALABAMA PARIS	GRETA DICAPRIO	20.99	0	1737
8659	12	ALABAMA PARK	DARYL DUKAKIS	15.99	0	3215
8660	5	ALABAMA PARTY	CHRISTIAN BASINGER	21.99	0	6598
8661	9	ALABAMA PAST	HUMPHREY WILLIS	14.99	0	1132
8662	6	ALABAMA PATHS	ETHAN NICHOLSON	29.99	0	6764
8663	11	ALABAMA PATIENT	UMA HANNAH	29.99	0	9827
8664	3	ALABAMA PATRIOT	ETHAN MCQUEEN	16.99	0	2982
8665	12	ALABAMA PATTON	GRETA CRONYN	27.99	0	4897
8666	9	ALABAMA PAYCHECK	JENNIFER GABLE	28.99	0	8210
8667	1	ALABAMA PEACH	JON WAYNE	15.99	0	7889
8668	16	ALABAMA PEAK	DAN LEIGH	28.99	0	1393
8669	15	ALABAMA PEARL	PEARL PINKETT	13.99	0	7088
8670	8	ALABAMA PELICAN	SIGOURNEY SINATRA	26.99	0	6886
8671	6	ALABAMA PERDITION	ANGELA DAMON	25.99	0	6511
8672	10	ALABAMA PERFECT	LEELEE CRUISE	11.99	0	5143
8673	15	ALABAMA PERSONAL	BEN JOVOVICH	10.99	0	6477
8674	4	ALABAMA PET	HENRY GARLAND	9.99	0	5046
8675	12	ALABAMA PHANTOM	GINA BEATTY	21.99	0	42
8676	5	ALABAMA PHILADELPHIA	DENNIS DEGENERES	16.99	0	3586
8677	16	ALABAMA PIANIST	KEVIN MCQUEEN	21.99	0	648
8678	2	ALABAMA PICKUP	LANA MINELLI	12.99	0	218
8679	14	ALABAMA PILOT	HILARY WILLIS	13.99	0	9559
8680	12	ALABAMA PINOCCHIO	AL NOLTE	9.99	0	9171
8681	1	ALABAMA PIRATES	CHEVY MALDEN	14.99	0	1825
8682	10	ALABAMA PITTSBURGH	RITA WAHLBERG	12.99	0	5652
8683	4	ALABAMA PITY	DEBBIE MARTIN	25.99	0	9423
8684	14	ALABAMA PIZZA	SOPHIA MATTHAU	13.99	0	8725
8685	3	ALABAMA PLATOON	KIM KUDROW	12.99	0	8510
8686	2	ALABAMA PLUTO	JAYNE MCKELLEN	14.99	0	3729
8687	8	ALABAMA POCUS	FRANK JOVOVICH	14.99	0	8016
8688	14	ALABAMA POLISH	HUMPHREY TURNER	9.99	0	1909
8689	16	ALABAMA POLLOCK	RENEE KINNEAR	27.99	0	6292
8690	13	ALABAMA POND	CHRISTOPHER WATSON	15.99	0	7608
8691	3	ALABAMA POSEIDON	HILARY DEGENERES	21.99	0	2797
8692	16	ALABAMA POTLUCK	PENELOPE WAYNE	14.99	0	4587
8693	2	ALABAMA POTTER	HALLE BAILEY	19.99	0	796
8694	11	ALABAMA PREJUDICE	LIZA BASINGER	18.99	0	3852
8695	2	ALABAMA PRESIDENT	GINA ODONNELL	14.99	0	4521
8696	1	ALABAMA PRIDE	MENA COSTNER	18.99	0	1842
8697	12	ALABAMA PRIMARY	CARRIE PRESLEY	19.99	0	3311
8698	16	ALABAMA PRINCESS	HALLE BRANAGH	15.99	0	4376
8699	7	ALABAMA PRIVATE	JOHNNY DICAPRIO	9.99	0	4268
8700	7	ALABAMA PRIX	CANDICE STREEP	24.99	0	1269
8701	3	ALABAMA PSYCHO	FRANK COOPER	27.99	0	774
8702	1	ALABAMA PULP	ROCK FIELD	12.99	0	8683
8703	9	ALABAMA PUNK	WILLEM REYNOLDS	27.99	0	5689
8704	6	ALABAMA PURE	ROBIN HUSTON	25.99	0	5751
8705	4	ALABAMA PURPLE	JACK TYLER	16.99	0	5475
8706	8	ALABAMA QUEEN	MINNIE SOBIESKI	25.99	0	3134
8707	14	ALABAMA QUEST	LIZA POSEY	23.99	0	4308
8708	9	ALABAMA QUILLS	DAN HOPE	20.99	0	2756
8709	2	ALABAMA RACER	OPRAH MCQUEEN	28.99	0	2640
8710	9	ALABAMA RAGE	CLARK NEWMAN	28.99	0	8218
8711	8	ALABAMA RAGING	MARISA JOLIE	13.99	0	3485
8712	9	ALABAMA RAIDERS	BRUCE CAGE	11.99	0	359
8713	10	ALABAMA RAINBOW	JOE GOLDBERG	24.99	0	8038
8714	1	ALABAMA RANDOM	JAYNE ANISTON	25.99	0	8817
8715	1	ALABAMA RANGE	KEVIN HUDSON	13.99	0	5776
8716	1	ALABAMA REAP	BELA THURMAN	23.99	0	3575
8717	1	ALABAMA REAR	JOHN MALDEN	12.99	0	3119
8718	4	ALABAMA REBEL	MERYL DRIVER	23.99	0	6065
8719	8	ALABAMA RECORDS	LUCILLE BERRY	28.99	0	5822
8720	13	ALABAMA REDEMPTION	ANJELICA WAHLBERG	16.99	0	4557
8721	15	ALABAMA REDS	GREG DAMON	9.99	0	4228
8722	6	ALABAMA REEF	AL WILSON	26.99	0	7382
8723	3	ALABAMA REIGN	ALEC FAWCETT	27.99	0	719
8724	8	ALABAMA REMEMBER	CHARLIZE HOPPER	10.99	0	184
8725	11	ALABAMA REQUIEM	UMA COOPER	24.99	0	977
8726	3	ALABAMA RESERVOIR	GARY HOPE	19.99	0	2204
8727	16	ALABAMA RESURRECTION	CUBA SMITH	29.99	0	3047
8728	12	ALABAMA REUNION	LISA STALLONE	24.99	0	5940
8729	13	ALABAMA RIDER	ANGELINA COOPER	28.99	0	4203
8730	16	ALABAMA RIDGEMONT	LAURENCE WASHINGTON	27.99	0	1078
8731	1	ALABAMA RIGHT	KIM SPACEK	15.99	0	124
8732	9	ALABAMA RINGS	ROBIN EASTWOOD	24.99	0	5112
8733	1	ALABAMA RIVER	GROUCHO WILLIAMS	22.99	0	583
8734	4	ALABAMA ROAD	DORIS HUNT	14.99	0	4853
8735	12	ALABAMA ROBBERS	INGRID GOLDBERG	14.99	0	728
8736	7	ALABAMA ROBBERY	SPENCER DRIVER	28.99	0	2665
8737	16	ALABAMA ROCK	KIRSTEN BRODY	25.99	0	8277
8738	5	ALABAMA ROCKETEER	PENELOPE SWANK	22.99	0	4612
8739	12	ALABAMA ROCKY	TIM PENN	28.99	1	3501
8740	7	ALABAMA ROLLERCOASTER	NATALIE ODONNELL	26.99	0	121
8741	15	ALABAMA ROMAN	FRANK GIBSON	26.99	0	8917
8742	2	ALABAMA ROOF	ALAN DREYFUSS	22.99	0	8545
8743	8	ALABAMA ROOM	MINNIE GOODING	14.99	0	2049
8744	12	ALABAMA ROOTS	SYLVESTER RICKMAN	23.99	0	9196
8745	1	ALABAMA ROSES	LISA CAMPBELL	24.99	1	5894
8746	13	ALABAMA ROUGE	WALTER TYLER	10.99	0	2791
8747	16	ALABAMA ROXANNE	KIM STALLONE	29.99	0	6362
8748	14	ALABAMA RUGRATS	ALAN ZELLWEGER	20.99	0	640
8749	12	ALABAMA RULES	ROBERT ALLEN	22.99	0	5412
8750	10	ALABAMA RUN	MEL PACINO	13.99	0	6775
8751	13	ALABAMA RUNAWAY	LEELEE DAVIS	24.99	0	3355
8752	1	ALABAMA RUNNER	CLARK DAY-LEWIS	21.99	0	6821
8753	4	ALABAMA RUSH	MEL AKROYD	13.99	0	9542
8754	5	ALABAMA RUSHMORE	WARREN DOUGLAS	11.99	0	6459
8755	11	ALABAMA SABRINA	GREGORY KEITEL	16.99	0	7983
8756	1	ALABAMA SADDLE	AL JOHANSSON	22.99	0	2816
8757	16	ALABAMA SAGEBRUSH	JUDE DIAZ	11.99	0	6902
8758	14	ALABAMA SAINTS	MICHAEL BENING	19.99	0	2385
8759	8	ALABAMA SALUTE	JULIA MANSFIELD	17.99	0	4585
8760	2	ALABAMA SAMURAI	WILLIAM HACKMAN	17.99	0	6972
8761	4	ALABAMA SANTA	DANIEL RUSSELL	13.99	0	4371
8762	9	ALABAMA SASSY	MICHAEL GIBSON	9.99	0	5438
8763	12	ALABAMA SATISFACTION	LIAM FISHER	17.99	0	9031
8764	11	ALABAMA SATURDAY	JUDE DOUGLAS	12.99	0	2294
8765	10	ALABAMA SATURN	LUCILLE PRESLEY	21.99	0	3824
8766	5	ALABAMA SAVANNAH	CHRISTIAN GOLDBERG	19.99	0	5818
8767	15	ALABAMA SCALAWAG	VIVIEN BOGART	21.99	0	4620
8768	3	ALABAMA SCARFACE	RALPH RYDER	25.99	0	6135
8769	11	ALABAMA SCHOOL	SIGOURNEY SMITH	12.99	0	5869
8770	7	ALABAMA SCISSORHANDS	GREGORY LEWIS	9.99	0	5159
8771	7	ALABAMA SCORPION	SIGOURNEY HOPE	21.99	0	4935
8772	3	ALABAMA SEA	LEELEE STALLONE	11.99	0	6974
8773	10	ALABAMA SEABISCUIT	JON MCDORMAND	16.99	0	6859
8774	16	ALABAMA SEARCHERS	JUDI BEATTY	27.99	0	4749
8775	8	ALABAMA SEATTLE	ANGELINA MCGREGOR	25.99	0	2118
8776	6	ALABAMA SECRET	MARLON BERGEN	13.99	0	5855
8777	12	ALABAMA SECRETARY	JAMES SARANDON	15.99	0	8918
8778	16	ALABAMA SECRETS	JUDY JOHANSSON	19.99	0	9029
8779	3	ALABAMA SENSE	WARREN STALLONE	23.99	0	1887
8780	3	ALABAMA SENSIBILITY	RITA COSTNER	13.99	0	4723
8781	7	ALABAMA SEVEN	KATE DUNST	10.99	0	1835
8782	11	ALABAMA SHAKESPEARE	WOODY DAY	11.99	0	9134
8783	16	ALABAMA SHANE	IAN KEATON	19.99	0	2790
8784	7	ALABAMA SHANGHAI	CARMEN CROWE	16.99	0	8391
8785	9	ALABAMA SHAWSHANK	AL BALE	16.99	0	9880
8786	14	ALABAMA SHEPHERD	FARRAH NEESON	17.99	0	7926
8787	10	ALABAMA SHINING	ADRIEN HAWN	20.99	0	5269
8788	8	ALABAMA SHIP	ANGELA JOHANSSON	27.99	0	520
8789	3	ALABAMA SHOCK	ED HARRIS	14.99	0	1158
8790	2	ALABAMA SHOOTIST	CHARLTON FISHER	11.99	0	3977
8791	2	ALABAMA SHOW	ANTHONY KINNEAR	17.99	0	8150
8792	4	ALABAMA SHREK	DREW IRONS	13.99	0	7414
8793	12	ALABAMA SHRUNK	ED JOVOVICH	25.99	0	2418
8794	14	ALABAMA SIDE	MARISA LANCASTER	10.99	0	4202
8795	3	ALABAMA SIEGE	NICOLE WILLIS	16.99	0	4436
8796	12	ALABAMA SIERRA	WILLIAM DAY	25.99	0	9051
8797	10	ALABAMA SILENCE	HILARY SOBIESKI	26.99	0	4318
8798	10	ALABAMA SILVERADO	UMA ROBBINS	26.99	0	3330
8799	2	ALABAMA SIMON	SIDNEY GOLDBERG	24.99	0	7226
8800	3	ALABAMA SINNERS	MEL MCQUEEN	27.99	0	7797
8801	6	ALABAMA SISTER	ZERO PALTROW	15.99	0	6261
8802	4	ALABAMA SKY	JENNIFER BULLOCK	21.99	0	4866
8803	1	ALABAMA SLACKER	ELLEN LAW	29.99	0	8049
8804	6	ALABAMA SLEEPING	CLINT HORNE	13.99	0	6322
8805	15	ALABAMA SLEEPLESS	EMILY FIENNES	21.99	0	2413
8806	7	ALABAMA SLEEPY	VIVIEN KIDMAN	17.99	0	4611
8807	1	ALABAMA SLEUTH	LAURENCE BEATTY	18.99	0	5620
8808	16	ALABAMA SLING	CARMEN PALTROW	13.99	0	5140
8809	1	ALABAMA SLIPPER	WILL AFFLECK	13.99	0	1532
8810	14	ALABAMA SLUMS	JOAN BRODY	10.99	0	6725
8811	6	ALABAMA SMILE	DARYL BRANDO	14.99	0	456
8812	12	ALABAMA SMOKING	BURT JOVOVICH	16.99	0	7731
8813	15	ALABAMA SMOOCHY	JOE WAHLBERG	9.99	0	1691
8814	9	ALABAMA SNATCH	CHRISTOPHER CAINE	19.99	0	3739
8815	11	ALABAMA SNATCHERS	JON CHASE	11.99	0	2277
8816	13	ALABAMA SNOWMAN	GREG LUGOSI	9.99	0	8417
8817	1	ALABAMA SOLDIERS	GRETA MCCONAUGHEY	12.99	0	3244
8818	15	ALABAMA SOMETHING	EDWARD STREEP	17.99	0	3739
8819	10	ALABAMA SONG	JUDY HANNAH	24.99	0	8446
8820	3	ALABAMA SONS	ADAM LEWIS	22.99	0	2547
8821	14	ALABAMA SORORITY	ROSIE KAHN	13.99	0	7134
8822	1	ALABAMA SOUP	GOLDIE LEWIS	17.99	0	2842
8823	12	ALABAMA SOUTH	CARY MOSTEL	29.99	0	25
8824	6	ALABAMA SPARTACUS	HUMPHREY MONROE	26.99	0	3178
8825	12	ALABAMA SPEAKEASY	SIGOURNEY KIDMAN	23.99	0	5970
8826	16	ALABAMA SPEED	BURT ALLEN	25.99	0	6249
8827	9	ALABAMA SPICE	DANIEL DENCH	26.99	0	9251
8828	2	ALABAMA SPIKING	LAURENCE FOSTER	14.99	0	6591
8829	5	ALABAMA SPINAL	GENE MCKELLEN	22.99	0	7204
8830	16	ALABAMA SPIRIT	ELIZABETH COOPER	27.99	0	4127
8831	8	ALABAMA SPIRITED	JACK SARANDON	20.99	0	6292
8832	4	ALABAMA SPLASH	SCARLETT BOGART	17.99	0	5016
8833	6	ALABAMA SPLENDOR	ROSIE BARRYMORE	27.99	0	1455
8834	9	ALABAMA SPOILERS	PEARL KUDROW	27.99	0	2578
8835	10	ALABAMA SPY	JADA CRONYN	26.99	0	2854
8836	5	ALABAMA SQUAD	BOB KAHN	23.99	0	6862
8837	6	ALABAMA STAGE	PENELOPE DREYFUSS	12.99	0	7103
8838	12	ALABAMA STAGECOACH	OPRAH WRAY	20.99	0	511
8839	11	ALABAMA STALLION	LENA HOPPER	18.99	0	8055
8840	12	ALABAMA STAMPEDE	WINONA WALKEN	11.99	0	378
8841	7	ALABAMA STAR	KEVIN BALE	19.99	0	6375
8842	4	ALABAMA STATE	SUSAN BALE	29.99	0	5931
8843	12	ALABAMA STEEL	LAUREN TYLER	18.99	0	4779
8844	9	ALABAMA STEERS	TIM BRODY	11.99	0	2650
8845	15	ALABAMA STEPMOM	DAN DUKAKIS	27.99	0	9683
8846	15	ALABAMA STING	ADRIEN TANDY	19.99	0	7320
8847	2	ALABAMA STOCK	PAUL LOREN	9.99	0	9980
8848	11	ALABAMA STONE	STEVE DIAZ	13.99	0	3581
8849	12	ALABAMA STORM	JOE DAVIS	22.99	0	621
8850	15	ALABAMA STORY	GROUCHO DAY-LEWIS	10.99	0	7920
8851	1	ALABAMA STRAIGHT	MARLENE BARRYMORE	10.99	0	297
8852	13	ALABAMA STRANGELOVE	LISA MONROE	20.99	0	1758
8853	10	ALABAMA STRANGER	JANE FISHER	18.99	0	1481
8854	14	ALABAMA STRANGERS	GWYNETH DENCH	15.99	0	6760
8855	7	ALABAMA STREAK	SISSY RICKMAN	24.99	0	122
8856	9	ALABAMA STREETCAR	ANNE TURNER	12.99	0	5914
8857	4	ALABAMA STRICTLY	ED REYNOLDS	26.99	0	9388
8858	16	ALABAMA SUBMARINE	EMILY THURMAN	18.99	0	8128
8859	10	ALABAMA SUGAR	ANJELICA CRUZ	28.99	0	9255
8860	10	ALABAMA SUICIDES	MERYL THURMAN	19.99	0	5422
8861	9	ALABAMA SUIT	JEFF CARREY	21.99	0	4150
8862	3	ALABAMA SUMMER	CLARK KIDMAN	17.99	0	5010
8863	6	ALABAMA SUN	HENRY FREEMAN	22.99	0	7537
8864	8	ALABAMA SUNDANCE	VIVIEN GARBO	19.99	0	4626
8865	7	ALABAMA SUNRISE	GRETA TYLER	11.99	0	9743
8866	11	ALABAMA SUNSET	CARMEN WEAVER	11.99	0	4500
8867	9	ALABAMA SUPER	WILLIAM PECK	23.99	0	3378
8868	4	ALABAMA SUPERFLY	MEL JACKMAN	21.99	0	4620
8869	6	ALABAMA SUSPECTS	RITA LANSBURY	14.99	0	1138
8870	12	ALABAMA SWARM	ALEC HUDSON	11.99	0	4505
8871	2	ALABAMA SWEDEN	HUME DEE	13.99	0	9345
8872	11	ALABAMA SWEET	MARILYN STALLONE	22.99	0	7760
8873	16	ALABAMA SWEETHEARTS	EMILY PFEIFFER	22.99	0	3834
8874	2	ALABAMA TADPOLE	TOM MINELLI	28.99	0	9889
8875	1	ALABAMA TALENTED	JEREMY NEWMAN	10.99	0	356
8876	9	ALABAMA TARZAN	EMILY STREEP	28.99	0	5961
8877	14	ALABAMA TAXI	JAYNE NORTON	19.99	0	9761
8878	5	ALABAMA TEEN	MICHELLE DRIVER	20.99	0	94
8879	15	ALABAMA TELEGRAPH	MARLENE BEATTY	27.99	1	5775
8880	14	ALABAMA TELEMARK	ELIZABETH BALE	15.99	0	253
8881	6	ALABAMA TEMPLE	SCARLETT MCKELLEN	21.99	0	9154
8882	4	ALABAMA TENENBAUMS	LEONARDO HAWKE	22.99	0	9253
8883	11	ALABAMA TEQUILA	DENNIS CRUZ	15.99	0	1571
8884	6	ALABAMA TERMINATOR	DENNIS NEESON	29.99	0	2060
8885	10	ALABAMA TEXAS	ED GUINESS	26.99	0	3546
8886	14	ALABAMA THEORY	WINONA BEATTY	24.99	0	5451
8887	11	ALABAMA THIEF	WALTER THERON	13.99	0	8768
8888	3	ALABAMA THIN	AUDREY CLOSE	16.99	0	8132
8889	9	ALABAMA TIES	JOE SPACEK	24.99	0	195
8890	16	ALABAMA TIGHTS	IAN GUINESS	13.99	0	1207
8891	9	ALABAMA TIMBERLAND	CLARK BENING	20.99	0	8501
8892	2	ALABAMA TITANIC	NEVE HAWKE	9.99	0	2699
8893	15	ALABAMA TITANS	JAMES SILVERSTONE	29.99	0	9297
8894	13	ALABAMA TOMATOES	ORLANDO PESCI	15.99	0	5911
8895	5	ALABAMA TOMORROW	WINONA HECHE	24.99	0	2001
8896	14	ALABAMA TOOTSIE	ELVIS CRONYN	9.99	0	379
8897	14	ALABAMA TORQUE	JEFF SILVERSTONE	21.99	0	969
8898	15	ALABAMA TOURIST	SPENCER RUSH	15.99	0	975
8899	4	ALABAMA TOWERS	RIVER LUGOSI	9.99	0	2946
8900	10	ALABAMA TOWN	MORGAN CRUISE	21.99	0	3522
8901	13	ALABAMA TRACY	KARL REYNOLDS	9.99	0	2598
8902	2	ALABAMA TRADING	AUDREY MOORE	20.99	0	9315
8903	11	ALABAMA TRAFFIC	MINNIE CAINE	20.99	0	4938
8904	11	ALABAMA TRAIN	BEN ODONNELL	18.99	0	9627
8905	12	ALABAMA TRAINSPOTTING	CHARLTON DUKAKIS	18.99	0	701
8906	14	ALABAMA TRAMP	ROBIN MOORE	16.99	0	6144
8907	10	ALABAMA TRANSLATION	ETHAN ROBERTS	23.99	0	5330
8908	10	ALABAMA TRAP	MATTHEW WASHINGTON	16.99	0	1216
8909	14	ALABAMA TREASURE	RIP BOGART	28.99	0	5072
8910	14	ALABAMA TREATMENT	REESE DUKAKIS	9.99	0	6727
8911	2	ALABAMA TRIP	GLENN LUGOSI	28.99	0	258
8912	9	ALABAMA TROJAN	RENEE LAW	26.99	0	1090
8913	6	ALABAMA TROOPERS	ANDY TAYLOR	9.99	0	5043
8914	3	ALABAMA TROUBLE	LENA BALE	28.99	0	1471
8915	8	ALABAMA TRUMAN	JAYNE SMITH	14.99	0	2058
8916	15	ALABAMA TURN	RAY WEAVER	14.99	0	7369
8917	5	ALABAMA TUXEDO	FRANK HAWN	10.99	0	5483
8918	4	ALABAMA TWISTED	INGRID LOREN	13.99	0	6254
8919	12	ALABAMA TYCOON	MARY PINKETT	16.99	0	6069
8920	8	ALABAMA UNBREAKABLE	JADA CHAPLIN	28.99	0	2759
8921	3	ALABAMA UNCUT	DIANE FORD	28.99	0	989
8922	11	ALABAMA UNDEFEATED	JULIA THERON	29.99	0	7519
8923	9	ALABAMA UNFAITHFUL	GOLDIE COOPER	28.99	0	9314
8924	9	ALABAMA UNFORGIVEN	MATTHEW CARREY	13.99	0	3621
8925	14	ALABAMA UNITED	JUDY WINFREY	14.99	0	9209
8926	9	ALABAMA UNTOUCHABLES	ELLEN BALE	24.99	0	8579
8927	14	ALABAMA UPRISING	NICOLAS MCGREGOR	16.99	0	7109
8928	2	ALABAMA UPTOWN	SEAN BOGART	18.99	0	2823
8929	7	ALABAMA USUAL	JADA LOREN	10.99	0	9130
8930	7	ALABAMA VACATION	SIDNEY MCDORMAND	28.99	0	7881
8931	14	ALABAMA VALENTINE	RIVER HACKMAN	11.99	0	7882
8932	16	ALABAMA VALLEY	INGRID WRAY	23.99	0	53
8933	7	ALABAMA VAMPIRE	BURT HUNT	15.99	0	1343
8934	10	ALABAMA VANILLA	MIRA EASTWOOD	9.99	0	5177
8935	15	ALABAMA VANISHED	CATE RICKMAN	25.99	0	97
8936	10	ALABAMA VANISHING	HUMPHREY KILMER	17.99	0	5488
8937	4	ALABAMA VARSITY	KATE MARX	21.99	0	8939
8938	10	ALABAMA VELVET	HALLE PFEIFFER	24.99	0	2869
8939	14	ALABAMA VERTIGO	LAURENCE MANSFIELD	21.99	0	9412
8940	2	ALABAMA VICTORY	MILLA KEATON	14.99	0	3988
8941	4	ALABAMA VIDEOTAPE	TOM TURNER	22.99	0	5815
8942	4	ALABAMA VIETNAM	DAN KELLY	24.99	0	5034
8943	11	ALABAMA VILLAIN	DREW ROBBINS	9.99	0	2543
8944	5	ALABAMA VIRGIN	RUSSELL GARCIA	27.99	0	4535
8945	14	ALABAMA VIRGINIAN	WILL BALL	20.99	0	2904
8946	15	ALABAMA VIRTUAL	DARYL KELLY	27.99	0	5249
8947	8	ALABAMA VISION	ANJELICA GOODING	22.99	0	1986
8948	3	ALABAMA VOICE	WHOOPI PRESLEY	16.99	0	4675
8949	10	ALABAMA VOLCANO	ROBERT BARRYMORE	18.99	0	7729
8950	15	ALABAMA VOLUME	RITA PINKETT	27.99	0	965
8951	3	ALABAMA VOYAGE	LUCILLE CROWE	17.99	0	8072
8952	15	ALABAMA WAGON	DAN IRONS	29.99	0	3155
8953	3	ALABAMA WAIT	AUDREY DEPP	11.99	0	8340
8954	10	ALABAMA WAKE	SHIRLEY DEGENERES	18.99	0	8030
8955	4	ALABAMA WALLS	KATHARINE MCQUEEN	9.99	0	8054
8956	2	ALABAMA WANDA	WOODY PESCI	24.99	0	368
8957	9	ALABAMA WAR	JULIANNE ASTAIRE	24.99	0	6410
8958	1	ALABAMA WARDROBE	SIGOURNEY CHAPLIN	11.99	0	5120
8959	16	ALABAMA WARLOCK	OLYMPIA THERON	26.99	0	4640
8960	11	ALABAMA WARS	BRUCE KAHN	12.99	0	6389
8961	16	ALABAMA WASH	GWYNETH MINELLI	29.99	0	4737
8962	1	ALABAMA WASTELAND	JON WALKEN	20.99	0	4858
8963	3	ALABAMA WATCH	MAE PENN	10.99	0	9214
8964	10	ALABAMA WATERFRONT	RENEE SARANDON	16.99	0	1165
8965	13	ALABAMA WATERSHIP	MADELINE DUKAKIS	28.99	0	1609
8966	9	ALABAMA WEDDING	RICHARD HUNT	28.99	0	1886
8967	7	ALABAMA WEEKEND	CANDICE HURT	27.99	0	7845
8968	6	ALABAMA WEREWOLF	JUDE DAFOE	9.99	0	3496
8969	15	ALABAMA WEST	CHEVY TAYLOR	24.99	0	8055
8970	14	ALABAMA WESTWARD	BRAD ANISTON	18.99	0	5793
8971	11	ALABAMA WHALE	ANJELICA HUNT	18.99	0	5077
8972	11	ALABAMA WHISPERER	WILLIAM REYNOLDS	24.99	0	32
8973	9	ALABAMA WIFE	DEBBIE AKROYD	9.99	0	4886
8974	7	ALABAMA WILD	GROUCHO WATSON	20.99	0	5718
8975	6	ALABAMA WILLOW	LAURENCE KAHN	18.99	0	5141
8976	1	ALABAMA WIND	WINONA MCGREGOR	10.99	0	3668
8977	10	ALABAMA WINDOW	CARY OLIVIER	20.99	0	7744
8978	10	ALABAMA WISDOM	PENELOPE WINSLET	25.99	0	7970
8979	5	ALABAMA WITCHES	NEVE HANNAH	22.99	0	4017
8980	4	ALABAMA WIZARD	STEVE DUKAKIS	25.99	0	9030
8981	5	ALABAMA WOLVES	JULIETTE REYNOLDS	15.99	0	5950
8982	11	ALABAMA WOMEN	FRANCES HECHE	25.99	1	7380
8983	9	ALABAMA WON	MIRA LEIGH	16.99	0	7315
8984	3	ALABAMA WONDERFUL	CARY MCCONAUGHEY	27.99	0	756
8985	5	ALABAMA WONDERLAND	HALLE HOFFMAN	13.99	0	1051
8986	2	ALABAMA WONKA	SANDRA KILMER	22.99	0	7117
8987	4	ALABAMA WORDS	CATE HURT	19.99	0	1367
8988	4	ALABAMA WORKER	MILLA SMITH	29.99	0	556
8989	12	ALABAMA WORKING	MATTHEW FAWCETT	26.99	0	9177
8990	15	ALABAMA WORLD	GWYNETH HORNE	14.99	0	5947
8991	7	ALABAMA WORST	CARRIE POITIER	14.99	0	9530
8992	16	ALABAMA WRATH	JAMES LUGOSI	11.99	0	6951
8993	4	ALABAMA WRONG	JULIA FOSTER	28.99	0	6866
8994	16	ALABAMA WYOMING	ZERO AFFLECK	23.99	0	1793
8995	10	ALABAMA YENTL	MARILYN PINKETT	28.99	0	2937
8996	9	ALABAMA YOUNG	ANGELA GOODING	23.99	0	4114
8997	10	ALABAMA YOUTH	ZERO LOREN	10.99	0	963
8998	13	ALABAMA ZHIVAGO	JAYNE TYLER	14.99	0	7503
8999	16	ALABAMA ZOOLANDER	OLYMPIA STALLONE	28.99	0	5876
9000	3	ALABAMA ZORRO	GINA BLOOM	25.99	0	3294
9001	2	ALADDIN ACADEMY	MINNIE LOREN	11.99	0	3362
9002	9	ALADDIN ACE	SUSAN TEMPLE	19.99	0	5957
9003	10	ALADDIN ADAPTATION	JUDI NOLTE	10.99	0	3546
9004	13	ALADDIN AFFAIR	DANIEL TURNER	20.99	0	7077
9005	3	ALADDIN AFRICAN	RENEE WOOD	18.99	0	8441
9006	13	ALADDIN AGENT	JADA SMITH	19.99	0	6809
9007	14	ALADDIN AIRPLANE	KIM HOPE	25.99	0	4921
9008	6	ALADDIN AIRPORT	CLARK LEWIS	27.99	0	1282
9009	4	ALADDIN ALABAMA	ANDY HEPBURN	17.99	0	8957
9010	2	ALADDIN ALADDIN	SHIRLEY CAGE	28.99	0	6447
9011	13	ALADDIN ALAMO	JIM HANNAH	13.99	0	3983
9012	15	ALADDIN ALASKA	ROSIE PRESLEY	18.99	0	8069
9013	15	ALADDIN ALI	HELEN TEMPLE	11.99	0	83
9014	4	ALADDIN ALICE	JANE WILLIS	14.99	0	4280
9015	3	ALADDIN ALIEN	KIRK JOLIE	10.99	0	1669
9016	12	ALADDIN ALLEY	KIRSTEN DAFOE	12.99	0	4811
9017	9	ALADDIN ALONE	DUSTIN DOUGLAS	17.99	0	7575
9018	4	ALADDIN ALTER	MAE MINELLI	21.99	0	3792
9019	10	ALADDIN AMADEUS	GREG WITHERSPOON	9.99	0	7204
9020	8	ALADDIN AMELIE	DIANE HAWN	9.99	0	6537
9021	4	ALADDIN AMERICAN	RUSSELL CLOSE	25.99	0	2534
9022	4	ALADDIN AMISTAD	KARL THURMAN	19.99	0	2458
9023	4	ALADDIN ANACONDA	SIGOURNEY JOVOVICH	27.99	0	6399
9024	5	ALADDIN ANALYZE	LIZA PACINO	21.99	0	8753
9025	6	ALADDIN ANGELS	FRANCES DAY	20.99	0	7616
9026	4	ALADDIN ANNIE	SYLVESTER HOPE	10.99	0	2513
9027	5	ALADDIN ANONYMOUS	CATE HORNE	26.99	0	4346
9028	2	ALADDIN ANTHEM	UMA CRUZ	29.99	0	453
9029	10	ALADDIN ANTITRUST	OLYMPIA FORD	13.99	0	4967
9030	2	ALADDIN ANYTHING	MINNIE DERN	17.99	0	9604
9031	3	ALADDIN APACHE	HUMPHREY AFFLECK	10.99	0	6228
9032	6	ALADDIN APOCALYPSE	BETTE GARCIA	19.99	0	397
9033	15	ALADDIN APOLLO	DUSTIN DREYFUSS	27.99	0	3133
9034	15	ALADDIN ARABIA	MARISA TAUTOU	22.99	0	5878
9035	3	ALADDIN ARACHNOPHOBIA	RUBY DAY	27.99	0	6513
9036	14	ALADDIN ARGONAUTS	MARLENE RUSSELL	13.99	0	7106
9037	14	ALADDIN ARIZONA	AUDREY DAY	28.99	0	2738
9038	16	ALADDIN ARK	KIM MCCONAUGHEY	13.99	0	8140
9039	9	ALADDIN ARMAGEDDON	MEL GOODING	12.99	0	7896
9040	13	ALADDIN ARMY	ADRIEN CROWE	21.99	0	6278
9041	5	ALADDIN ARSENIC	INGRID TAYLOR	28.99	0	2929
9042	11	ALADDIN ARTIST	JUDY WILLIAMS	23.99	0	2137
9043	16	ALADDIN ATLANTIS	ROBIN TEMPLE	20.99	0	3070
9044	6	ALADDIN ATTACKS	MENA MCGREGOR	9.99	0	7219
9045	14	ALADDIN ATTRACTION	SPENCER LOLLOBRIGIDA	26.99	0	9564
9046	8	ALADDIN AUTUMN	ROBERT HOPPER	27.99	0	9327
9047	3	ALADDIN BABY	SIGOURNEY AKROYD	23.99	0	7889
9048	15	ALADDIN BACKLASH	MATT ODONNELL	24.99	0	7654
9049	1	ALADDIN BADMAN	HILARY LOLLOBRIGIDA	24.99	0	2000
9050	8	ALADDIN BAKED	PEARL HEPBURN	16.99	0	9662
9051	5	ALADDIN BALLOON	JACK PENN	11.99	0	8006
9052	2	ALADDIN BALLROOM	RICHARD PRESLEY	29.99	0	5226
9053	12	ALADDIN BANG	DENNIS FISHER	17.99	0	4417
9054	3	ALADDIN BANGER	ALAN BERRY	20.99	0	6290
9055	13	ALADDIN BARBARELLA	ANNETTE DEE	20.99	0	3249
9056	9	ALADDIN BAREFOOT	ANGELA TEMPLE	28.99	0	6370
9057	12	ALADDIN BASIC	HILARY BERGMAN	20.99	0	8290
9058	2	ALADDIN BEACH	CHARLTON RICKMAN	14.99	0	2030
9059	12	ALADDIN BEAR	EWAN GABLE	24.99	0	730
9060	6	ALADDIN BEAST	FRED ODONNELL	18.99	0	8807
9061	13	ALADDIN BEAUTY	OPRAH POITIER	25.99	0	7678
9062	8	ALADDIN BED	ROCK HAWKE	26.99	0	8656
9063	11	ALADDIN BEDAZZLED	MADELINE ASTAIRE	26.99	0	8121
9064	1	ALADDIN BEETHOVEN	CHRISTIAN ASTAIRE	15.99	0	901
9065	6	ALADDIN BEHAVIOR	PENELOPE CAGE	23.99	0	181
9066	9	ALADDIN BENEATH	ORLANDO FINNEY	15.99	0	4440
9067	2	ALADDIN BERETS	SALLY LANSBURY	28.99	0	8137
9068	13	ALADDIN BETRAYED	ROCK BASINGER	17.99	0	1373
9069	4	ALADDIN BEVERLY	CHRIS THURMAN	17.99	0	9241
9070	8	ALADDIN BIKINI	ANNE LANSBURY	14.99	0	6205
9071	5	ALADDIN BILKO	UMA RYAN	10.99	0	615
9072	8	ALADDIN BILL	LIZA CROWE	16.99	0	114
9073	3	ALADDIN BINGO	ANNETTE TRACY	9.99	0	9317
9074	3	ALADDIN BIRCH	RITA LANSBURY	15.99	0	48
9075	4	ALADDIN BIRD	KIRK HOPKINS	14.99	0	7963
9076	15	ALADDIN BIRDCAGE	LAURENCE ALLEN	26.99	0	6926
9077	15	ALADDIN BIRDS	SHIRLEY LEIGH	20.99	0	9942
9078	9	ALADDIN BLACKOUT	SISSY BOGART	21.99	0	2192
9079	9	ALADDIN BLADE	PEARL DENIRO	16.99	0	7363
9080	6	ALADDIN BLANKET	CUBA ROBERTS	28.99	0	9099
9081	12	ALADDIN BLINDNESS	SYLVESTER WILSON	15.99	0	9947
9082	16	ALADDIN BLOOD	KIRK PENN	27.99	0	4908
9083	14	ALADDIN BLUES	LAURENCE RUSH	25.99	0	6904
9084	16	ALADDIN BOILED	TOM VOIGHT	25.99	0	4861
9085	8	ALADDIN BONNIE	ELVIS MCGREGOR	23.99	0	3255
9086	10	ALADDIN BOOGIE	FRANCES DIAZ	19.99	0	1039
9087	9	ALADDIN BOONDOCK	RIVER LAW	10.99	0	679
9088	10	ALADDIN BORN	RUSSELL FAWCETT	12.99	0	2374
9089	14	ALADDIN BORROWERS	CHEVY BENING	25.99	0	4280
9090	5	ALADDIN BOULEVARD	ANNE FINNEY	20.99	0	6047
9091	14	ALADDIN BOUND	SANDRA MARTIN	12.99	0	4355
9092	5	ALADDIN BOWFINGER	ZERO MCQUEEN	10.99	0	4356
9093	3	ALADDIN BRANNIGAN	NICOLAS DRIVER	29.99	0	8206
9094	4	ALADDIN BRAVEHEART	SHIRLEY DUKAKIS	17.99	0	7062
9095	14	ALADDIN BREAKFAST	ALEC FREEMAN	27.99	0	384
9096	8	ALADDIN BREAKING	MARILYN PINKETT	16.99	0	7668
9097	13	ALADDIN BRIDE	HUMPHREY CAMPBELL	25.99	0	1230
9098	4	ALADDIN BRIGHT	HUMPHREY GARLAND	29.99	0	8541
9099	13	ALADDIN BRINGING	CHARLIZE MANSFIELD	22.99	0	2211
9100	6	ALADDIN BROOKLYN	KIRSTEN SARANDON	17.99	0	4453
9101	8	ALADDIN BROTHERHOOD	CLINT CLOSE	10.99	0	718
9102	14	ALADDIN BUBBLE	DENZEL DUKAKIS	14.99	0	4362
9103	7	ALADDIN BUCKET	RENEE DUKAKIS	25.99	0	1649
9104	11	ALADDIN BUGSY	ORLANDO BAILEY	25.99	0	7494
9105	1	ALADDIN BULL	KIM BERGEN	21.99	0	2366
9106	1	ALADDIN BULWORTH	HUGH TURNER	13.99	0	9069
9107	5	ALADDIN BUNCH	DARYL SORVINO	19.99	0	2749
9108	15	ALADDIN BUTCH	KIRSTEN HORNE	24.99	0	8187
9109	15	ALADDIN BUTTERFLY	RUSSELL THURMAN	22.99	0	5520
9110	7	ALADDIN CABIN	LIZA NICHOLSON	29.99	0	893
9111	4	ALADDIN CADDYSHACK	ZERO DICAPRIO	21.99	0	9826
9112	8	ALADDIN CALENDAR	RITA PITT	23.99	0	9037
9113	16	ALADDIN CALIFORNIA	HALLE CHASE	20.99	0	6143
9114	6	ALADDIN CAMELOT	JUDE ROBBINS	13.99	0	1749
9115	13	ALADDIN CAMPUS	RUSSELL SOBIESKI	17.99	0	1060
9116	8	ALADDIN CANDIDATE	HARVEY WITHERSPOON	18.99	0	8467
9117	8	ALADDIN CANDLES	LEELEE BERGMAN	14.99	0	8218
9118	3	ALADDIN CANYON	WILLEM PITT	20.99	0	8598
9119	3	ALADDIN CAPER	MADELINE MINELLI	22.99	0	596
9120	14	ALADDIN CARIBBEAN	SIDNEY MCCONAUGHEY	23.99	1	6747
9121	13	ALADDIN CAROL	MARLON HUNT	12.99	0	2275
9122	1	ALADDIN CARRIE	FRANK GUINESS	21.99	0	673
9123	7	ALADDIN CASABLANCA	RICHARD SORVINO	17.99	0	921
9124	5	ALADDIN CASPER	NEVE KELLY	27.99	0	5842
9125	16	ALADDIN CASSIDY	DANIEL AKROYD	26.99	0	1991
9126	9	ALADDIN CASUALTIES	MATTHEW HUSTON	12.99	0	6146
9127	7	ALADDIN CAT	ADRIEN MOORE	23.99	0	6713
9128	13	ALADDIN CATCH	JUDI NOLTE	21.99	0	8789
9129	11	ALADDIN CAUSE	HUME FREEMAN	17.99	0	5840
9130	16	ALADDIN CELEBRITY	LEELEE CRUISE	12.99	0	2854
9131	7	ALADDIN CENTER	PARKER LANCASTER	10.99	0	4138
9132	11	ALADDIN CHAINSAW	AUDREY BRODY	23.99	0	3326
9133	6	ALADDIN CHAMBER	ALAN LOREN	26.99	0	1015
9134	12	ALADDIN CHAMPION	JEFF SMITH	11.99	0	6872
9135	12	ALADDIN CHANCE	SHIRLEY DAMON	15.99	0	9156
9136	10	ALADDIN CHAPLIN	JIM RICKMAN	16.99	0	1899
9137	13	ALADDIN CHARADE	GENE JACKMAN	26.99	0	1309
9138	3	ALADDIN CHARIOTS	MINNIE KAHN	13.99	0	8715
9139	5	ALADDIN CHASING	MICHAEL BOLGER	24.99	0	9173
9140	7	ALADDIN CHEAPER	CARMEN WILLIAMS	15.99	0	5096
9141	4	ALADDIN CHICAGO	EWAN TAYLOR	23.99	0	1003
9142	15	ALADDIN CHICKEN	LEELEE ANISTON	13.99	0	7574
9143	6	ALADDIN CHILL	ETHAN BASINGER	9.99	0	6412
9144	15	ALADDIN CHINATOWN	NICOLAS LANSBURY	21.99	0	9812
9145	9	ALADDIN CHISUM	UMA POITIER	22.99	0	2135
9146	3	ALADDIN CHITTY	BETTE DUNST	18.99	1	3238
9147	9	ALADDIN CHOCOLAT	GREG THURMAN	11.99	0	2122
9148	15	ALADDIN CHOCOLATE	EMILY HAYEK	12.99	0	5232
9149	13	ALADDIN CHRISTMAS	BEN GRANT	20.99	0	3908
9150	9	ALADDIN CIDER	CATE KIDMAN	18.99	0	2005
9151	11	ALADDIN CINCINATTI	JON FREEMAN	25.99	0	4945
9152	2	ALADDIN CIRCUS	HELEN FISHER	18.99	0	4707
9153	11	ALADDIN CITIZEN	SIGOURNEY FREEMAN	28.99	0	3609
9154	7	ALADDIN CLASH	NICOLE FAWCETT	19.99	0	7477
9155	15	ALADDIN CLEOPATRA	EWAN GOLDBERG	9.99	0	4615
9156	4	ALADDIN CLERKS	RICHARD KELLY	24.99	0	5931
9157	4	ALADDIN CLOCKWORK	SUSAN GOLDBERG	21.99	0	3776
9158	2	ALADDIN CLONES	MORGAN HOPKINS	29.99	0	2310
9159	6	ALADDIN CLOSER	KATHARINE RYDER	10.99	0	3940
9160	14	ALADDIN CLUB	PAUL DAY	11.99	0	6197
9161	10	ALADDIN CLUE	CHARLIZE JOLIE	17.99	0	4362
9162	16	ALADDIN CLUELESS	RITA HURT	27.99	0	6267
9163	5	ALADDIN CLYDE	BEN CRONYN	29.99	0	4439
9164	4	ALADDIN COAST	ED JOLIE	25.99	0	5526
9165	3	ALADDIN COLDBLOODED	PAUL HECHE	28.99	0	306
9166	9	ALADDIN COLOR	KARL BRANDO	23.99	0	7775
9167	3	ALADDIN COMA	ELLEN HUNT	28.99	0	3511
9168	10	ALADDIN COMANCHEROS	KARL MCQUEEN	22.99	0	6947
9169	2	ALADDIN COMFORTS	DANIEL TANDY	16.99	0	7865
9170	15	ALADDIN COMMAND	DENNIS RYAN	22.99	0	7511
9171	12	ALADDIN COMMANDMENTS	SANDRA DREYFUSS	13.99	0	3623
9172	1	ALADDIN CONEHEADS	ROBIN BRODY	14.99	0	2016
9173	10	ALADDIN CONFESSIONS	ROSIE MONROE	12.99	0	4781
9174	14	ALADDIN CONFIDENTIAL	GREG HAWKE	9.99	0	9741
9175	14	ALADDIN CONFUSED	PARKER MONROE	9.99	0	4962
9176	13	ALADDIN CONGENIALITY	PEARL ANISTON	22.99	0	7634
9177	1	ALADDIN CONNECTICUT	SHIRLEY DERN	26.99	0	9557
9178	1	ALADDIN CONNECTION	LIAM CAINE	27.99	0	9172
9179	6	ALADDIN CONQUERER	GOLDIE BULLOCK	24.99	0	875
9180	12	ALADDIN CONSPIRACY	NICOLAS WRAY	18.99	0	604
9181	16	ALADDIN CONTACT	BELA SINATRA	24.99	0	3246
9182	8	ALADDIN CONTROL	LAUREN JACKMAN	16.99	0	1004
9183	6	ALADDIN CONVERSATION	DUSTIN GUINESS	28.99	0	5192
9184	14	ALADDIN CORE	MARISA MOSTEL	12.99	0	8122
9185	5	ALADDIN COWBOY	RENEE BENING	9.99	0	8350
9186	2	ALADDIN CRAFT	MARLENE HUNT	12.99	0	1284
9187	8	ALADDIN CRANES	LIV OLIVIER	10.99	0	9609
9188	3	ALADDIN CRAZY	GROUCHO HAWKE	17.99	0	6439
9189	15	ALADDIN CREATURES	FRED DAVIS	20.99	0	6799
9190	6	ALADDIN CREEPERS	NICOLAS NICHOLSON	12.99	0	2632
9191	1	ALADDIN CROOKED	NEVE RICKMAN	22.99	0	9382
9192	13	ALADDIN CROSSING	MAE HANNAH	17.99	0	7136
9193	6	ALADDIN CROSSROADS	CARMEN MCDORMAND	24.99	0	4770
9194	6	ALADDIN CROW	MENA WASHINGTON	23.99	0	867
9195	6	ALADDIN CROWDS	ORLANDO TANDY	11.99	0	4545
9196	6	ALADDIN CRUELTY	DIANE BASINGER	11.99	0	1483
9197	1	ALADDIN CRUSADE	KEVIN KAHN	23.99	0	137
9198	7	ALADDIN CRYSTAL	MAE EASTWOOD	19.99	0	6527
9199	16	ALADDIN CUPBOARD	LAUREN HANNAH	23.99	0	756
9200	13	ALADDIN CURTAIN	TOM HOFFMAN	20.99	0	9801
9201	16	ALADDIN CYCLONE	ALICIA TURNER	13.99	0	7515
9202	6	ALADDIN DADDY	ELVIS BALL	27.99	0	1917
9203	15	ALADDIN DAISY	JOHNNY BRANAGH	20.99	0	5240
9204	4	ALADDIN DALMATIONS	THORA MARX	25.99	0	112
9205	14	ALADDIN DANCES	JENNIFER BARRYMORE	25.99	0	9943
9206	13	ALADDIN DANCING	SOPHIA LANCASTER	26.99	0	9082
9207	10	ALADDIN DANGEROUS	VIVIEN BRANDO	26.99	0	6713
9208	1	ALADDIN DARES	PEARL WASHINGTON	19.99	0	3965
9209	1	ALADDIN DARKNESS	ADAM ODONNELL	29.99	0	2896
9210	16	ALADDIN DARKO	GRACE FREEMAN	18.99	0	9118
9211	7	ALADDIN DARLING	JIM WATSON	15.99	0	2236
9212	4	ALADDIN DARN	GOLDIE FINNEY	12.99	0	3482
9213	14	ALADDIN DATE	EWAN CRAWFORD	22.99	0	7646
9214	1	ALADDIN DAUGHTER	JEREMY PINKETT	9.99	0	9355
9215	6	ALADDIN DAWN	FARRAH ODONNELL	23.99	0	4314
9216	10	ALADDIN DAY	HALLE LANCASTER	9.99	0	1188
9217	5	ALADDIN DAZED	JANE BRODY	21.99	0	5944
9218	16	ALADDIN DECEIVER	PAUL COSTNER	13.99	0	4717
9219	16	ALADDIN DEEP	DENNIS STREEP	18.99	0	9218
9220	7	ALADDIN DEER	LISA DAY	22.99	0	7396
9221	2	ALADDIN DELIVERANCE	FRANCES HORNE	18.99	0	1761
9222	10	ALADDIN DESERT	FRANK ROBERTS	9.99	0	6070
9223	10	ALADDIN DESIRE	PEARL FISHER	17.99	0	5893
9224	14	ALADDIN DESPERATE	JANE LANCASTER	10.99	0	3213
9225	16	ALADDIN DESTINATION	KATE GRANT	21.99	0	4200
9226	6	ALADDIN DESTINY	SHIRLEY CHAPLIN	22.99	0	3898
9227	14	ALADDIN DETAILS	CHRISTIAN DAFOE	11.99	0	5440
9228	12	ALADDIN DETECTIVE	SCARLETT STALLONE	19.99	0	4324
9229	2	ALADDIN DEVIL	WINONA BOGART	20.99	0	9912
9230	14	ALADDIN DIARY	HELEN COOPER	17.99	0	4375
9231	13	ALADDIN DINOSAUR	LEELEE BULLOCK	23.99	0	2106
9232	2	ALADDIN DIRTY	IAN LUGOSI	14.99	0	6373
9233	13	ALADDIN DISCIPLE	JODIE HAYEK	22.99	0	7129
9234	2	ALADDIN DISTURBING	RICHARD ALLEN	10.99	0	9798
9235	2	ALADDIN DIVIDE	CHARLIZE GRANT	18.99	0	9231
9236	15	ALADDIN DIVINE	ANGELINA LEWIS	19.99	0	8175
9237	12	ALADDIN DIVORCE	HUME FONDA	11.99	0	1064
9238	12	ALADDIN DOCTOR	KARL GARBO	13.99	0	4548
9239	15	ALADDIN DOGMA	JIM BRANAGH	24.99	0	87
9240	12	ALADDIN DOLLS	HILARY DEPP	27.99	0	1633
9241	13	ALADDIN DONNIE	NICK LUGOSI	26.99	0	9927
9242	11	ALADDIN DOOM	GLENN POSEY	10.99	0	8989
9243	3	ALADDIN DOORS	ELLEN MALDEN	23.99	0	2736
9244	3	ALADDIN DORADO	HARVEY PITT	22.99	0	5631
9245	11	ALADDIN DOUBLE	RIP DAFOE	9.99	0	5143
9246	3	ALADDIN DOUBTFIRE	BRUCE SWANK	28.99	0	1655
9247	15	ALADDIN DOWNHILL	SUSAN FREEMAN	14.99	0	7737
9248	3	ALADDIN DOZEN	HALLE LOLLOBRIGIDA	17.99	0	1777
9249	11	ALADDIN DRACULA	SUSAN HAYEK	10.99	0	4007
9250	10	ALADDIN DRAGON	LEONARDO NEWMAN	17.99	0	6687
9251	16	ALADDIN DRAGONFLY	JULIANNE THERON	9.99	0	2191
9252	4	ALADDIN DREAM	KIRSTEN PENN	11.99	0	9785
9253	15	ALADDIN DRIFTER	KEVIN BOGART	14.99	0	8266
9254	8	ALADDIN DRIVER	ELIZABETH CLOSE	16.99	0	2941
9255	13	ALADDIN DRIVING	WHOOPI SOBIESKI	16.99	0	6635
9256	1	ALADDIN DROP	KENNETH CRUISE	20.99	0	3517
9257	13	ALADDIN DRUMLINE	AUDREY HOFFMAN	16.99	0	311
9258	6	ALADDIN DRUMS	CARRIE HUDSON	27.99	0	6241
9259	12	ALADDIN DUCK	RALPH CRAWFORD	29.99	0	20
9260	5	ALADDIN DUDE	ROBERT FAWCETT	13.99	0	811
9261	15	ALADDIN DUFFEL	EWAN PALTROW	17.99	0	5107
9262	13	ALADDIN DUMBO	VIVIEN BALL	26.99	0	5223
9263	15	ALADDIN DURHAM	WOODY PENN	9.99	0	7258
9264	11	ALADDIN DWARFS	SOPHIA EASTWOOD	17.99	0	4476
9265	7	ALADDIN DYING	OLYMPIA JOVOVICH	14.99	0	4266
9266	6	ALADDIN DYNAMITE	CARY MARX	21.99	0	3991
9267	2	ALADDIN EAGLES	JAYNE SILVERSTONE	10.99	0	8342
9268	10	ALADDIN EARLY	KEVIN KUDROW	21.99	0	1465
9269	5	ALADDIN EARRING	JEFF CRUISE	13.99	0	7071
9270	11	ALADDIN EARTH	DENZEL BALL	17.99	0	9421
9271	14	ALADDIN EASY	KENNETH MCGREGOR	29.99	0	5838
9272	7	ALADDIN EDGE	HUGH GARBO	26.99	0	619
9273	11	ALADDIN EFFECT	LIAM BACALL	13.99	0	1652
9274	6	ALADDIN EGG	GROUCHO WALKEN	25.99	0	9736
9275	9	ALADDIN EGYPT	AL SILVERSTONE	24.99	0	3098
9276	11	ALADDIN ELEMENT	TOM BERGMAN	13.99	0	1784
9277	13	ALADDIN ELEPHANT	KATE HEPBURN	13.99	0	9709
9278	5	ALADDIN ELF	ZERO TURNER	27.99	0	6152
9279	1	ALADDIN ELIZABETH	KATHARINE HORNE	17.99	0	6883
9280	6	ALADDIN EMPIRE	JON ROBBINS	16.99	0	7273
9281	11	ALADDIN ENCINO	RENEE CLOSE	22.99	0	8551
9282	13	ALADDIN ENCOUNTERS	FAY COSTNER	16.99	0	5381
9283	6	ALADDIN ENDING	JEFF MCGREGOR	15.99	0	5577
9284	15	ALADDIN ENEMY	ALBERT KEITEL	18.99	0	2872
9285	3	ALADDIN ENGLISH	ANNE DIETRICH	22.99	0	5556
9286	7	ALADDIN ENOUGH	MIRA FORD	12.99	0	923
9287	1	ALADDIN ENTRAPMENT	EMILY RICKMAN	15.99	0	6353
9288	14	ALADDIN ESCAPE	ELVIS HAYEK	15.99	0	7544
9289	14	ALADDIN EVE	EWAN MOSTEL	27.99	0	1886
9290	3	ALADDIN EVERYONE	JESSICA DUKAKIS	13.99	0	1115
9291	13	ALADDIN EVOLUTION	JEFF FONDA	19.99	0	4098
9292	10	ALADDIN EXCITEMENT	CLARK LANSBURY	27.99	0	2839
9293	9	ALADDIN EXORCIST	MICHELLE POSEY	25.99	0	4377
9294	9	ALADDIN EXPECATIONS	BRAD WASHINGTON	25.99	0	2298
9295	16	ALADDIN EXPENDABLE	JULIA ZELLWEGER	18.99	0	4675
9296	9	ALADDIN EXPRESS	REESE BACALL	9.99	0	3175
9297	7	ALADDIN EXTRAORDINARY	SEAN CAINE	21.99	0	7634
9298	15	ALADDIN EYES	JULIA JOVOVICH	21.99	0	5777
9299	1	ALADDIN FACTORY	JUDI RYAN	11.99	0	3290
9300	6	ALADDIN FALCON	GLENN LEWIS	27.99	0	5627
9301	6	ALADDIN FAMILY	LEELEE LOLLOBRIGIDA	11.99	0	1280
9302	8	ALADDIN FANTASIA	EMILY AFFLECK	15.99	0	2732
9303	2	ALADDIN FANTASY	PENELOPE HUDSON	21.99	0	561
9304	3	ALADDIN FARGO	RUBY BERGEN	23.99	0	4386
9305	1	ALADDIN FATAL	AL KELLY	16.99	0	345
9306	15	ALADDIN FEATHERS	LISA PFEIFFER	19.99	0	1994
9307	11	ALADDIN FELLOWSHIP	DARYL FAWCETT	27.99	0	7932
9308	3	ALADDIN FERRIS	ELVIS PESCI	28.99	0	3092
9309	1	ALADDIN FEUD	HARRISON KAHN	26.99	0	5560
9310	5	ALADDIN FEVER	BEN DAY-LEWIS	15.99	0	4754
9311	6	ALADDIN FICTION	DARYL HURT	29.99	0	586
9312	3	ALADDIN FIDDLER	HALLE MARX	16.99	0	2
9313	3	ALADDIN FIDELITY	MORGAN NEWMAN	17.99	0	530
9314	12	ALADDIN FIGHT	KIRK MCGREGOR	10.99	0	7673
9315	11	ALADDIN FINDING	WINONA ROBERTS	24.99	0	5597
9316	4	ALADDIN FIRE	ANDY HECHE	17.99	0	192
9317	8	ALADDIN FIREBALL	LUCILLE KILMER	26.99	0	1311
9318	14	ALADDIN FIREHOUSE	RENEE BALL	20.99	0	4253
9319	10	ALADDIN FISH	ANJELICA COSTNER	12.99	0	5387
9320	16	ALADDIN FLAMINGOS	GEOFFREY TYLER	28.99	0	4030
9321	8	ALADDIN FLASH	ROBIN SUVARI	20.99	0	2133
9322	9	ALADDIN FLATLINERS	OLYMPIA PFEIFFER	12.99	0	6443
9323	5	ALADDIN FLIGHT	MENA GUINESS	11.99	0	1375
9324	9	ALADDIN FLINTSTONES	GARY LAW	21.99	0	5717
9325	3	ALADDIN FLOATS	JOE NICHOLSON	18.99	0	1307
9326	14	ALADDIN FLYING	WILLIAM BOLGER	23.99	0	2459
9327	15	ALADDIN FOOL	WILL CRONYN	22.99	0	5364
9328	5	ALADDIN FOREVER	TIM NEESON	29.99	0	8836
9329	2	ALADDIN FORREST	JEFF FIENNES	17.99	0	1827
9330	16	ALADDIN FORRESTER	SALMA BALE	19.99	0	4724
9331	10	ALADDIN FORWARD	LANA FONDA	21.99	0	2074
9332	14	ALADDIN FRANKENSTEIN	HILARY TURNER	26.99	0	7503
9333	6	ALADDIN FREAKY	INGRID SPACEK	14.99	0	1987
9334	3	ALADDIN FREDDY	JULIA WAHLBERG	21.99	0	4222
9335	13	ALADDIN FREEDOM	JEREMY FORD	22.99	0	9414
9336	2	ALADDIN FRENCH	ETHAN HAWN	23.99	0	2859
9337	15	ALADDIN FRIDA	DAN STREEP	15.99	0	7408
9338	1	ALADDIN FRISCO	LAURA AKROYD	18.99	0	3912
9339	11	ALADDIN FROGMEN	GEOFFREY HOPE	12.99	0	6594
9340	10	ALADDIN FRONTIER	WOODY STREEP	10.99	0	8059
9341	1	ALADDIN FROST	DIANE MCDORMAND	14.99	0	2333
9342	9	ALADDIN FUGITIVE	BELA DEE	24.99	0	7365
9343	8	ALADDIN FULL	NICOLAS LEWIS	10.99	0	258
9344	8	ALADDIN FURY	JOAN PACINO	25.99	0	5278
9345	8	ALADDIN GABLES	HARRISON IRONS	18.99	0	8730
9346	4	ALADDIN GALAXY	JON KUDROW	18.99	0	8201
9347	12	ALADDIN GAMES	ANJELICA GRANT	25.99	0	5773
9348	9	ALADDIN GANDHI	CHARLTON MCKELLEN	14.99	0	1919
9349	5	ALADDIN GANGS	SISSY COOPER	24.99	0	7816
9350	5	ALADDIN GARDEN	EMILY GOODING	22.99	0	8150
9351	9	ALADDIN GASLIGHT	GWYNETH BASINGER	9.99	0	1874
9352	14	ALADDIN GATHERING	LANA DAMON	27.99	0	7099
9353	8	ALADDIN GENTLEMEN	GREG JOHANSSON	22.99	0	427
9354	14	ALADDIN GHOST	DEBBIE BACALL	23.99	0	1516
9355	8	ALADDIN GHOSTBUSTERS	KARL BEATTY	24.99	0	3472
9356	10	ALADDIN GIANT	HUGH DEE	28.99	0	9139
9357	3	ALADDIN GILBERT	CARMEN BOGART	23.99	1	1083
9358	7	ALADDIN GILMORE	LEONARDO HORNE	24.99	0	3520
9359	13	ALADDIN GLADIATOR	HARVEY TORN	29.99	0	1558
9360	3	ALADDIN GLASS	DENNIS BOGART	23.99	0	9202
9361	1	ALADDIN GLEAMING	CHARLTON HEPBURN	18.99	0	4106
9362	6	ALADDIN GLORY	JUDI JOHANSSON	18.99	0	5006
9363	10	ALADDIN GO	WARREN MARTIN	12.99	0	443
9364	9	ALADDIN GODFATHER	UMA CAINE	28.99	0	5460
9365	2	ALADDIN GOLD	MARILYN DRIVER	14.99	0	5006
9366	4	ALADDIN GOLDFINGER	TIM AFFLECK	16.99	0	3021
9367	13	ALADDIN GOLDMINE	REESE ROBERTS	14.99	0	9905
9368	13	ALADDIN GONE	LEELEE SINATRA	24.99	1	9406
9369	13	ALADDIN GOODFELLAS	BEN KIDMAN	24.99	0	2190
9370	5	ALADDIN GORGEOUS	JUDI JOVOVICH	28.99	0	4796
9371	7	ALADDIN GOSFORD	JOE WITHERSPOON	16.99	0	9146
9372	11	ALADDIN GRACELAND	MERYL BOGART	18.99	0	9347
9373	7	ALADDIN GRADUATE	OLYMPIA CAINE	9.99	0	7534
9374	16	ALADDIN GRAFFITI	FARRAH MONROE	9.99	0	7246
9375	5	ALADDIN GRAIL	DREW MCKELLEN	25.99	0	148
9376	4	ALADDIN GRAPES	ZERO WEAVER	24.99	0	3295
9377	11	ALADDIN GREASE	JADA WASHINGTON	16.99	0	7925
9378	5	ALADDIN GREATEST	TIM SANDLER	9.99	0	8054
9379	13	ALADDIN GREEDY	JEREMY RUSSELL	10.99	0	8268
9380	13	ALADDIN GREEK	JESSICA BLANCHETT	9.99	0	24
9381	1	ALADDIN GRINCH	VIVIEN BRANAGH	9.99	0	2422
9382	6	ALADDIN GRIT	CHRISTOPHER HUSTON	25.99	0	5466
9383	10	ALADDIN GROOVE	GREGORY BLOOM	19.99	0	1724
9384	6	ALADDIN GROSSE	WALTER TOMEI	25.99	0	7867
9385	10	ALADDIN GROUNDHOG	SEAN PITT	10.99	0	7357
9386	1	ALADDIN GUMP	ROSIE RYAN	9.99	0	6817
9387	5	ALADDIN GUN	CHRISTIAN CRONYN	18.99	0	9852
9388	16	ALADDIN GUNFIGHT	BELA KINNEAR	15.99	0	1915
9389	8	ALADDIN GUNFIGHTER	BETTE GARCIA	18.99	0	420
9390	4	ALADDIN GUYS	RALPH PFEIFFER	11.99	0	5465
9391	14	ALADDIN HALF	GREG STREEP	23.99	0	1631
9392	7	ALADDIN HALL	GREG BRANDO	20.99	0	3086
9393	9	ALADDIN HALLOWEEN	RUBY KEATON	21.99	0	8970
9394	13	ALADDIN HAMLET	ELLEN FORD	27.99	0	3899
9395	15	ALADDIN HANDICAP	CANDICE BAILEY	23.99	0	9045
9396	5	ALADDIN HANGING	OLYMPIA AKROYD	21.99	0	6091
9397	13	ALADDIN HANKY	MORGAN BIRCH	11.99	0	2635
9398	7	ALADDIN HANOVER	PENELOPE CHAPLIN	14.99	0	6219
9399	3	ALADDIN HAPPINESS	WALTER LANSBURY	17.99	0	7524
9400	13	ALADDIN HARDLY	RALPH GARCIA	28.99	0	9384
9401	14	ALADDIN HAROLD	UMA FINNEY	21.99	0	6467
9402	4	ALADDIN HARPER	NATALIE NICHOLSON	28.99	0	3533
9403	3	ALADDIN HARRY	JUDI CRUISE	29.99	0	2666
9404	10	ALADDIN HATE	RIVER MATTHAU	20.99	0	2589
9405	5	ALADDIN HAUNTED	LIV SORVINO	10.99	0	6890
9406	1	ALADDIN HAUNTING	AL LOREN	29.99	0	9344
9407	10	ALADDIN HAWK	LISA FREEMAN	15.99	0	3957
9408	11	ALADDIN HEAD	LAURENCE HEPBURN	13.99	0	425
9409	8	ALADDIN HEARTBREAKERS	MARLENE WILLIAMS	14.99	0	6789
9410	9	ALADDIN HEAVEN	JUDY RUSH	12.99	0	2650
9411	14	ALADDIN HEAVENLY	RUBY TAUTOU	27.99	0	92
9412	13	ALADDIN HEAVYWEIGHTS	GROUCHO HECHE	17.99	0	6166
9413	13	ALADDIN HEDWIG	ANGELINA HOFFMAN	17.99	0	4323
9414	7	ALADDIN HELLFIGHTERS	HILARY BLOOM	10.99	0	8868
9415	13	ALADDIN HIGH	MATT TYLER	14.99	0	5249
9416	9	ALADDIN HIGHBALL	HILARY VOIGHT	17.99	0	2173
9417	7	ALADDIN HILLS	MARILYN LEWIS	24.99	0	4025
9418	6	ALADDIN HOBBIT	ROSIE RUSSELL	17.99	0	4784
9419	14	ALADDIN HOCUS	LANA MCCONAUGHEY	14.99	0	9419
9420	3	ALADDIN HOLES	RUSSELL HUNT	25.99	0	9212
9421	6	ALADDIN HOLIDAY	ROCK DUKAKIS	24.99	0	6141
9422	15	ALADDIN HOLLOW	CUBA BIRCH	21.99	0	1679
9423	16	ALADDIN HOLLYWOOD	VIVIEN DAY	26.99	0	1340
9424	5	ALADDIN HOLOCAUST	NICOLE JACKMAN	27.99	0	4550
9425	14	ALADDIN HOLY	THORA TAYLOR	23.99	0	6791
9426	10	ALADDIN HOME	WILL AFFLECK	18.99	0	6580
9427	1	ALADDIN HOMEWARD	NICOLAS MOSTEL	13.99	0	5854
9428	7	ALADDIN HOMICIDE	RENEE DEAN	16.99	0	4423
9429	8	ALADDIN HONEY	TOM GARCIA	13.99	0	6774
9430	12	ALADDIN HOOK	KEVIN BEATTY	21.99	0	2282
9431	5	ALADDIN HOOSIERS	DREW FINNEY	14.99	0	9552
9432	15	ALADDIN HOPE	LIV RYDER	23.99	0	8580
9433	5	ALADDIN HORN	BEN HAYEK	10.99	0	1391
9434	9	ALADDIN HORROR	JUDE DIAZ	18.99	0	7402
9435	2	ALADDIN HOTEL	REESE CROWE	23.99	0	5283
9436	15	ALADDIN HOURS	RUSSELL BOLGER	11.99	0	6028
9437	2	ALADDIN HOUSE	HUGH EASTWOOD	23.99	0	4243
9438	9	ALADDIN HUMAN	RUBY DEE	22.99	0	6240
9439	13	ALADDIN HUNCHBACK	SIDNEY RYDER	14.99	0	3835
9440	1	ALADDIN HUNGER	LANA FREEMAN	26.99	0	3791
9441	6	ALADDIN HUNTER	JOE TYLER	13.99	0	8600
9442	13	ALADDIN HUNTING	CHRIS BRODY	13.99	0	1416
9443	10	ALADDIN HURRICANE	HARVEY GOLDBERG	18.99	0	6685
9444	2	ALADDIN HUSTLER	JESSICA RYDER	29.99	0	6971
9445	6	ALADDIN HYDE	ANGELINA BOGART	28.99	0	632
9446	6	ALADDIN HYSTERICAL	WILLEM DIAZ	25.99	0	149
9447	11	ALADDIN ICE	CATE DIAZ	26.99	0	9566
9448	16	ALADDIN IDAHO	GOLDIE BIRCH	16.99	0	3486
9449	1	ALADDIN IDENTITY	CHARLES MIRANDA	18.99	0	2194
9450	3	ALADDIN IDOLS	GEOFFREY ZELLWEGER	13.99	0	2300
9451	5	ALADDIN IGBY	JOHNNY DENIRO	14.99	0	9519
9452	5	ALADDIN ILLUSION	DENNIS PALTROW	17.99	0	6718
9453	6	ALADDIN IMAGE	OLYMPIA JOHANSSON	23.99	0	3090
9454	1	ALADDIN IMPACT	WALTER STREEP	12.99	0	5899
9455	7	ALADDIN IMPOSSIBLE	LAURENCE JACKMAN	24.99	0	5178
9456	16	ALADDIN INCH	PARKER WOOD	18.99	0	8125
9457	7	ALADDIN INDEPENDENCE	JULIA KAHN	21.99	0	502
9458	5	ALADDIN INDIAN	KENNETH DREYFUSS	9.99	0	3855
9459	6	ALADDIN INFORMER	DREW ASTAIRE	15.99	0	5549
9460	15	ALADDIN INNOCENT	ANGELINA MCDORMAND	19.99	0	7549
9461	16	ALADDIN INSECTS	NICOLAS DUNST	24.99	0	9866
9462	10	ALADDIN INSIDER	JUDE CAINE	10.99	0	4207
9463	3	ALADDIN INSTINCT	MICHELLE BACALL	23.99	0	6843
9464	2	ALADDIN INTENTIONS	MILLA HARRIS	15.99	0	9212
9465	14	ALADDIN INTERVIEW	KATHARINE MARTIN	28.99	0	8844
9466	11	ALADDIN INTOLERABLE	CLINT BERRY	17.99	0	9207
9467	7	ALADDIN INTRIGUE	ANNE HAWKE	27.99	0	8038
9468	6	ALADDIN INVASION	ROBIN MIRANDA	9.99	0	8922
9469	12	ALADDIN IRON	FRANK HAWKE	17.99	0	75
9470	6	ALADDIN ISHTAR	LIAM LUGOSI	27.99	0	6900
9471	13	ALADDIN ISLAND	PARKER CLOSE	28.99	0	6046
9472	14	ALADDIN ITALIAN	ALAN WILSON	28.99	0	5216
9473	12	ALADDIN JACKET	CHRISTIAN CRAWFORD	20.99	0	5082
9474	8	ALADDIN JADE	SYLVESTER TRACY	24.99	0	6460
9475	13	ALADDIN JAPANESE	DREW MONROE	16.99	0	7320
9476	1	ALADDIN JASON	SISSY DRIVER	26.99	0	4678
9477	7	ALADDIN JAWBREAKER	JANE BLANCHETT	18.99	0	2977
9478	16	ALADDIN JAWS	JODIE PFEIFFER	11.99	0	6753
9479	11	ALADDIN JEDI	LAURA PFEIFFER	20.99	0	8959
9480	4	ALADDIN JEEPERS	KENNETH DAY	18.99	0	742
9481	3	ALADDIN JEKYLL	GWYNETH MCGREGOR	10.99	0	5882
9482	9	ALADDIN JEOPARDY	MEG TAUTOU	29.99	0	6821
9483	5	ALADDIN JERICHO	IAN DIAZ	24.99	0	6915
9484	7	ALADDIN JERK	INGRID BACALL	29.99	0	8858
9485	15	ALADDIN JERSEY	BRUCE RYAN	18.99	0	6840
9486	9	ALADDIN JET	GENE HANNAH	27.99	0	7583
9487	8	ALADDIN JINGLE	LIZA AFFLECK	11.99	0	9284
9488	14	ALADDIN JOON	DAN DEGENERES	13.99	0	5828
9489	15	ALADDIN JUGGLER	LISA HANNAH	16.99	0	1992
9490	4	ALADDIN JUMANJI	WOODY DUKAKIS	15.99	0	2244
9491	1	ALADDIN JUMPING	LUCILLE DENIRO	15.99	0	966
9492	2	ALADDIN JUNGLE	BRUCE LUGOSI	23.99	0	728
9493	11	ALADDIN KANE	GENE KUDROW	26.99	0	2953
9494	7	ALADDIN KARATE	MICHAEL PACINO	9.99	0	950
9495	4	ALADDIN KENTUCKIAN	HENRY DIETRICH	13.99	0	1188
9496	8	ALADDIN KICK	HALLE MCCONAUGHEY	10.99	0	4878
9497	3	ALADDIN KILL	AUDREY BAILEY	14.99	0	7997
9498	6	ALADDIN KILLER	GREGORY GOODING	22.99	0	1268
9499	16	ALADDIN KING	ROBERT MCGREGOR	22.99	0	8739
9500	12	ALADDIN KISS	CHARLES TAYLOR	11.99	0	7461
9501	4	ALADDIN KISSING	GWYNETH KIDMAN	21.99	0	3087
9502	2	ALADDIN KNOCK	GREG REYNOLDS	12.99	0	838
9503	16	ALADDIN KRAMER	JIM GARLAND	15.99	0	6794
9504	8	ALADDIN KWAI	GARY WILLIAMS	14.99	0	9568
9505	3	ALADDIN LABYRINTH	ROBIN FORD	15.99	0	9229
9506	1	ALADDIN LADY	JENNIFER PACINO	17.99	0	541
9507	12	ALADDIN LADYBUGS	RITA HANNAH	10.99	0	8461
9508	3	ALADDIN LAMBS	DENNIS KINNEAR	21.99	0	2263
9509	5	ALADDIN LANGUAGE	CUBA DUNST	21.99	0	7870
9510	9	ALADDIN LAWLESS	CARMEN PENN	16.99	0	5843
9511	5	ALADDIN LAWRENCE	FAY BALL	24.99	0	5950
9512	13	ALADDIN LEAGUE	ZERO CARREY	22.99	0	5711
9513	8	ALADDIN LEATHERNECKS	CAMERON FONDA	23.99	0	9679
9514	15	ALADDIN LEBOWSKI	EMILY DAMON	10.99	0	8364
9515	15	ALADDIN LEGALLY	KEVIN FONDA	9.99	0	5588
9516	10	ALADDIN LEGEND	LEONARDO ZELLWEGER	27.99	0	429
9517	8	ALADDIN LESSON	DAN LANCASTER	18.99	0	3907
9518	1	ALADDIN LIAISONS	MORGAN MCQUEEN	12.99	0	6505
9519	2	ALADDIN LIBERTY	SALLY DAY-LEWIS	17.99	0	6482
9520	4	ALADDIN LICENSE	WILLEM CRUISE	25.99	0	6824
9521	6	ALADDIN LIES	MEL RUSH	28.99	0	4279
9522	16	ALADDIN LIFE	WILLEM BRODY	12.99	0	1507
9523	9	ALADDIN LIGHTS	RAY MCDORMAND	14.99	0	1083
9524	15	ALADDIN LION	GOLDIE THURMAN	25.99	0	6458
9525	7	ALADDIN LOATHING	ROCK JACKMAN	17.99	0	323
9526	2	ALADDIN LOCK	RIP MALDEN	25.99	0	4660
9527	4	ALADDIN LOLA	LAURENCE JOHANSSON	12.99	0	1728
9528	6	ALADDIN LOLITA	REESE DAY-LEWIS	11.99	0	5691
9529	4	ALADDIN LONELY	JEREMY HEPBURN	20.99	0	7308
9530	4	ALADDIN LORD	DIANE MONROE	9.99	0	4858
9531	2	ALADDIN LOSE	BELA CLOSE	27.99	0	6051
9532	6	ALADDIN LOSER	BURT CARREY	28.99	0	7719
9533	2	ALADDIN LOST	ZERO MOSTEL	28.99	0	4996
9534	8	ALADDIN LOUISIANA	TIM ANISTON	28.99	0	1515
9535	11	ALADDIN LOVE	RICHARD RYAN	27.99	0	8741
9536	7	ALADDIN LOVELY	ANDY WAHLBERG	18.99	0	9806
9537	2	ALADDIN LOVER	CARRIE COSTNER	12.99	0	4567
9538	16	ALADDIN LOVERBOY	CARMEN DEE	28.99	0	9080
9539	8	ALADDIN LUCK	THORA MCKELLEN	16.99	0	5117
9540	9	ALADDIN LUCKY	FRED DENIRO	15.99	0	1458
9541	4	ALADDIN LUKE	ANTHONY KEITEL	14.99	0	8797
9542	4	ALADDIN LUST	ANJELICA BARRYMORE	16.99	0	1684
9543	13	ALADDIN MADIGAN	HUME CHASE	28.99	0	5515
9544	14	ALADDIN MADISON	CLINT KIDMAN	24.99	0	7565
9545	5	ALADDIN MADNESS	ADAM HECHE	21.99	0	1424
9546	12	ALADDIN MADRE	MARY WEST	25.99	0	6445
9547	11	ALADDIN MAGIC	MERYL HAWKE	24.99	0	9074
9548	15	ALADDIN MAGNIFICENT	ANTHONY LEIGH	15.99	0	1633
9549	14	ALADDIN MAGNOLIA	MICHAEL FINNEY	9.99	0	6032
9550	13	ALADDIN MAGUIRE	ALEC GABLE	25.99	0	7829
9551	15	ALADDIN MAIDEN	NICK MONROE	21.99	0	9316
9552	4	ALADDIN MAJESTIC	GREGORY BRANDO	28.99	0	1085
9553	14	ALADDIN MAKER	MATTHEW PENN	27.99	0	1650
9554	1	ALADDIN MALKOVICH	JOHN SUVARI	24.99	0	5705
9555	6	ALADDIN MALLRATS	SYLVESTER MOORE	17.99	0	8563
9556	3	ALADDIN MALTESE	JUDI GIBSON	28.99	0	9525
9557	14	ALADDIN MANCHURIAN	ANNETTE CRUISE	13.99	0	8940
9558	5	ALADDIN MANNEQUIN	LISA WEST	29.99	0	6228
9559	3	ALADDIN MARRIED	JODIE TYLER	22.99	0	3531
9560	4	ALADDIN MARS	AL BAILEY	11.99	0	4570
9561	16	ALADDIN MASK	ROBERT MARTIN	19.99	0	7873
9562	8	ALADDIN MASKED	WILLIAM GARBO	19.99	0	1004
9563	7	ALADDIN MASSACRE	ANJELICA STREEP	9.99	0	9013
9564	11	ALADDIN MASSAGE	RIP WILLIS	11.99	0	4838
9565	8	ALADDIN MATRIX	JULIA RUSH	18.99	0	9449
9566	15	ALADDIN MAUDE	KENNETH THERON	24.99	0	625
9567	9	ALADDIN MEET	JACK SILVERSTONE	20.99	0	9721
9568	11	ALADDIN MEMENTO	RIVER PECK	23.99	0	6440
9569	10	ALADDIN MENAGERIE	LIAM GARBO	17.99	0	1927
9570	15	ALADDIN MERMAID	WILLEM WALKEN	17.99	0	8821
9571	6	ALADDIN METAL	PARKER FONDA	27.99	0	1365
9572	16	ALADDIN METROPOLIS	VAL MCQUEEN	16.99	0	2625
9573	6	ALADDIN MICROCOSMOS	WILL RUSSELL	12.99	0	6973
9574	13	ALADDIN MIDNIGHT	ANJELICA BARRYMORE	17.99	0	5171
9575	10	ALADDIN MIDSUMMER	JAYNE FIENNES	21.99	0	8422
9576	8	ALADDIN MIGHTY	CHRISTOPHER BASINGER	13.99	0	2628
9577	6	ALADDIN MILE	SISSY THURMAN	15.99	0	603
9578	10	ALADDIN MILLION	RUBY MARTIN	20.99	0	3185
9579	4	ALADDIN MINDS	HALLE LEWIS	15.99	0	8085
9580	14	ALADDIN MINE	CARRIE MALDEN	14.99	0	8383
9581	2	ALADDIN MINORITY	SIDNEY MCQUEEN	14.99	0	8274
9582	9	ALADDIN MIRACLE	MINNIE DEGENERES	18.99	0	9717
9583	8	ALADDIN MISSION	LANA BULLOCK	16.99	0	3370
9584	11	ALADDIN MIXED	SPENCER WALKEN	9.99	0	8961
9585	14	ALADDIN MOB	JOHN BARRYMORE	29.99	0	6630
9586	13	ALADDIN MOCKINGBIRD	FRED HARRIS	23.99	0	1716
9587	9	ALADDIN MOD	HUMPHREY DEAN	13.99	0	9570
9588	4	ALADDIN MODEL	BEN CHASE	25.99	0	7608
9589	2	ALADDIN MODERN	MENA COSTNER	9.99	0	9144
9590	15	ALADDIN MONEY	WARREN BALL	17.99	0	2674
9591	2	ALADDIN MONSOON	MEG SINATRA	16.99	0	3636
9592	9	ALADDIN MONSTER	LAURENCE BAILEY	29.99	0	2508
9593	15	ALADDIN MONTEREY	HUMPHREY HURT	29.99	0	9159
9594	13	ALADDIN MONTEZUMA	BETTE GOLDBERG	18.99	0	2913
9595	6	ALADDIN MOON	GRACE FISHER	15.99	0	3483
9596	10	ALADDIN MOONSHINE	CHRISTIAN SILVERSTONE	14.99	0	6782
9597	11	ALADDIN MOONWALKER	MINNIE PINKETT	13.99	0	9841
9598	8	ALADDIN MOSQUITO	JESSICA MARX	27.99	0	7226
9599	13	ALADDIN MOTHER	BRAD GARBO	27.99	0	5028
9600	3	ALADDIN MOTIONS	ROBERT CHASE	19.99	0	5678
9601	14	ALADDIN MOULIN	HELEN BENING	9.99	0	5697
9602	12	ALADDIN MOURNING	GARY WEAVER	17.99	0	4
9603	7	ALADDIN MOVIE	LIAM MCKELLEN	27.99	0	2070
9604	10	ALADDIN MULAN	KIRK DUNST	23.99	0	3653
9605	3	ALADDIN MULHOLLAND	JULIANNE FOSTER	9.99	0	9999
9606	10	ALADDIN MUMMY	ANNETTE PACINO	29.99	0	3852
9607	9	ALADDIN MUPPET	GRACE HAYEK	26.99	0	4998
9608	14	ALADDIN MURDER	CARRIE DEAN	18.99	0	6352
9609	11	ALADDIN MUSCLE	TIM NEESON	13.99	0	1063
9610	10	ALADDIN MUSIC	JENNIFER KELLY	11.99	0	3012
9611	2	ALADDIN MUSKETEERS	ADRIEN BRODY	12.99	0	7298
9612	9	ALADDIN MUSSOLINI	CHARLTON MATTHAU	27.99	0	9852
9613	7	ALADDIN MYSTIC	DENNIS DRIVER	19.99	0	2998
9614	3	ALADDIN NAME	WHOOPI GOODING	10.99	0	3140
9615	4	ALADDIN NASH	ROSIE CRAWFORD	22.99	0	3858
9616	16	ALADDIN NATIONAL	JUDI GOODING	28.99	0	5899
9617	11	ALADDIN NATURAL	DARYL BOGART	26.99	0	6512
9618	13	ALADDIN NECKLACE	TOM GARLAND	9.99	0	6682
9619	6	ALADDIN NEIGHBORS	ANGELINA BAILEY	15.99	0	6441
9620	10	ALADDIN NEMO	RITA EASTWOOD	18.99	0	988
9621	14	ALADDIN NETWORK	JOE TEMPLE	16.99	0	289
9622	15	ALADDIN NEWSIES	CARRIE JOHANSSON	11.99	0	1086
9623	13	ALADDIN NEWTON	JODIE CAINE	24.99	0	3578
9624	7	ALADDIN NIGHTMARE	HENRY IRONS	18.99	0	5026
9625	2	ALADDIN NONE	RENEE GRANT	27.99	0	7423
9626	1	ALADDIN NOON	LIZA NEWMAN	19.99	0	4442
9627	9	ALADDIN NORTH	UMA WEAVER	22.99	0	2677
9628	12	ALADDIN NORTHWEST	HUME TAUTOU	13.99	0	5673
9629	10	ALADDIN NOTORIOUS	ANJELICA WITHERSPOON	29.99	0	8346
9630	8	ALADDIN NOTTING	DIANE KAHN	14.99	0	556
9631	1	ALADDIN NOVOCAINE	NATALIE HAWN	22.99	0	7406
9632	2	ALADDIN NUTS	MENA HAWN	9.99	0	7699
9633	5	ALADDIN OCTOBER	MAE SARANDON	23.99	0	2304
9634	5	ALADDIN ODDS	DENNIS MATTHAU	15.99	0	6407
9635	3	ALADDIN OKLAHOMA	CHARLTON BEATTY	16.99	0	5671
9636	7	ALADDIN OLEANDER	WINONA GABLE	12.99	1	8902
9637	15	ALADDIN OPEN	GARY BERRY	21.99	0	3654
9638	6	ALADDIN OPERATION	CHRISTOPHER HANNAH	29.99	0	2015
9639	4	ALADDIN OPPOSITE	RIP GARLAND	18.99	0	3971
9640	2	ALADDIN OPUS	JENNIFER STALLONE	13.99	0	7896
9641	13	ALADDIN ORANGE	CHARLES MONROE	25.99	0	1387
9642	11	ALADDIN ORDER	DENZEL PALTROW	29.99	0	3237
9643	6	ALADDIN ORIENT	MORGAN MONROE	19.99	0	8239
9644	12	ALADDIN OSCAR	DAN TAUTOU	20.99	0	8777
9645	15	ALADDIN OTHERS	MORGAN GRANT	17.99	0	9409
9646	3	ALADDIN OUTBREAK	LEELEE HAWN	15.99	0	4013
9647	8	ALADDIN OUTFIELD	BURT TEMPLE	23.99	0	4034
9648	16	ALADDIN OUTLAW	ANJELICA DAMON	24.99	0	6984
9649	9	ALADDIN OZ	KIRSTEN HOPKINS	24.99	0	8760
9650	10	ALADDIN PACIFIC	ELVIS VOIGHT	16.99	0	8849
9651	5	ALADDIN PACKER	FRED HURT	27.99	0	5076
9652	5	ALADDIN PAJAMA	HENRY DERN	16.99	0	2479
9653	13	ALADDIN PANIC	JEREMY WASHINGTON	26.99	0	1867
9654	9	ALADDIN PANKY	MAE DAFOE	11.99	0	6211
9655	16	ALADDIN PANTHER	KATE LANSBURY	14.99	0	8392
9656	3	ALADDIN PAPI	GEOFFREY COSTNER	18.99	0	1148
9657	16	ALADDIN PARADISE	HARRISON FIELD	15.99	0	3031
9658	10	ALADDIN PARIS	DUSTIN HURT	9.99	0	8913
9659	4	ALADDIN PARK	BRAD STREEP	26.99	0	370
9660	8	ALADDIN PARTY	LEELEE WALKEN	9.99	0	4884
9661	14	ALADDIN PAST	MARLON EASTWOOD	12.99	0	7014
9662	5	ALADDIN PATHS	AL NEWMAN	22.99	1	7057
9663	16	ALADDIN PATIENT	CLINT LEWIS	13.99	0	4936
9664	2	ALADDIN PATRIOT	GREG SINATRA	12.99	0	2920
9665	4	ALADDIN PATTON	DIANE CARREY	26.99	0	3937
9666	5	ALADDIN PAYCHECK	MERYL ALLEN	29.99	0	4262
9667	11	ALADDIN PEACH	BRAD HUDSON	23.99	0	950
9668	7	ALADDIN PEAK	MATT BERRY	20.99	0	2679
9669	1	ALADDIN PEARL	BETTE GABLE	17.99	0	7617
9670	11	ALADDIN PELICAN	STEVE POITIER	28.99	0	732
9671	5	ALADDIN PERDITION	BETTE SWANK	29.99	0	2691
9672	7	ALADDIN PERFECT	NEVE HUNT	19.99	0	8546
9673	10	ALADDIN PERSONAL	TIM KELLY	14.99	0	2014
9674	9	ALADDIN PET	KEVIN CAMPBELL	22.99	0	871
9675	7	ALADDIN PHANTOM	ROCK DAY-LEWIS	15.99	0	3936
9676	7	ALADDIN PHILADELPHIA	ELIZABETH HEPBURN	18.99	0	655
9677	12	ALADDIN PIANIST	KATHARINE STREEP	18.99	0	6885
9678	6	ALADDIN PICKUP	DENZEL WITHERSPOON	14.99	0	3022
9679	8	ALADDIN PILOT	JAYNE SILVERSTONE	9.99	0	9772
9680	2	ALADDIN PINOCCHIO	DANIEL STALLONE	28.99	0	3284
9681	6	ALADDIN PIRATES	OPRAH KIDMAN	21.99	0	1861
9682	11	ALADDIN PITTSBURGH	ALICIA PITT	12.99	0	4021
9683	15	ALADDIN PITY	HELEN KILMER	10.99	0	6466
9684	7	ALADDIN PIZZA	JEREMY DERN	26.99	0	9032
9685	13	ALADDIN PLATOON	NICOLE GIBSON	9.99	0	8989
9686	6	ALADDIN PLUTO	JAMES MINELLI	11.99	0	4352
9687	5	ALADDIN POCUS	CLARK TAUTOU	15.99	0	3877
9688	12	ALADDIN POLISH	THORA WASHINGTON	11.99	0	7250
9689	13	ALADDIN POLLOCK	WILLIAM HAWKE	13.99	0	2557
9690	2	ALADDIN POND	MADELINE BENING	27.99	0	9414
9691	13	ALADDIN POSEIDON	LAUREN HAWKE	12.99	0	8060
9692	11	ALADDIN POTLUCK	MATTHEW RYAN	25.99	0	7305
9693	4	ALADDIN POTTER	MARY SORVINO	11.99	0	6824
9694	14	ALADDIN PREJUDICE	BRAD ODONNELL	26.99	0	3451
9695	2	ALADDIN PRESIDENT	HUMPHREY ALLEN	23.99	0	4779
9696	11	ALADDIN PRIDE	SIDNEY MCGREGOR	13.99	0	3988
9697	1	ALADDIN PRIMARY	DAN HOPE	24.99	0	3071
9698	8	ALADDIN PRINCESS	CHARLES HESTON	11.99	0	822
9699	13	ALADDIN PRIVATE	PAUL GUINESS	27.99	0	6754
9700	4	ALADDIN PRIX	MENA DUKAKIS	22.99	0	5605
9701	2	ALADDIN PSYCHO	DAN MONROE	9.99	0	102
9702	7	ALADDIN PULP	JEREMY WALKEN	21.99	0	7024
9703	15	ALADDIN PUNK	CATE BLANCHETT	9.99	0	6880
9704	3	ALADDIN PURE	BELA WINSLET	27.99	0	2933
9705	10	ALADDIN PURPLE	LAURENCE BLOOM	14.99	0	5890
9706	14	ALADDIN QUEEN	ED STALLONE	9.99	0	1282
9707	1	ALADDIN QUEST	ANJELICA DENIRO	19.99	0	6947
9708	3	ALADDIN QUILLS	PEARL PITT	15.99	0	9714
9709	1	ALADDIN RACER	VIVIEN TYLER	10.99	0	8155
9710	7	ALADDIN RAGE	SPENCER GRANT	29.99	0	6397
9711	9	ALADDIN RAGING	JOE HURT	25.99	0	3296
9712	15	ALADDIN RAIDERS	LAURA KEATON	29.99	1	4196
9713	11	ALADDIN RAINBOW	CHRIS CRAWFORD	18.99	0	9516
9714	7	ALADDIN RANDOM	SANDRA JOVOVICH	16.99	0	6789
9715	4	ALADDIN RANGE	ANTHONY WINFREY	11.99	0	7209
9716	12	ALADDIN REAP	DANIEL JOHANSSON	13.99	0	6895
9717	9	ALADDIN REAR	DEBBIE DAY	11.99	0	2015
9718	9	ALADDIN REBEL	HELEN TAYLOR	24.99	0	8789
9719	11	ALADDIN RECORDS	HENRY POSEY	20.99	0	9788
9720	4	ALADDIN REDEMPTION	VIVIEN FINNEY	14.99	0	8925
9721	16	ALADDIN REDS	HENRY COOPER	13.99	0	6821
9722	15	ALADDIN REEF	SOPHIA WEAVER	10.99	0	1005
9723	5	ALADDIN REIGN	WILL MCGREGOR	23.99	0	3025
9724	9	ALADDIN REMEMBER	ANNE ALLEN	28.99	0	1879
9725	15	ALADDIN REQUIEM	JUDY POSEY	27.99	0	9372
9726	13	ALADDIN RESERVOIR	BRUCE BAILEY	12.99	0	4971
9727	14	ALADDIN RESURRECTION	JAYNE BRANDO	24.99	0	5229
9728	14	ALADDIN REUNION	CHARLTON JOLIE	25.99	0	4977
9729	2	ALADDIN RIDER	JUDI PFEIFFER	12.99	0	517
9730	6	ALADDIN RIDGEMONT	RENEE LOREN	27.99	0	8364
9731	13	ALADDIN RIGHT	SANDRA DAVIS	28.99	0	951
9732	7	ALADDIN RINGS	DEBBIE CRUISE	26.99	0	4163
9733	6	ALADDIN RIVER	SUSAN PRESLEY	20.99	0	902
9734	1	ALADDIN ROAD	RITA NICHOLSON	20.99	0	4808
9735	10	ALADDIN ROBBERS	ANNETTE CRUZ	17.99	0	5110
9736	4	ALADDIN ROBBERY	MORGAN TAUTOU	10.99	0	822
9737	3	ALADDIN ROCK	ETHAN CRAWFORD	17.99	0	1994
9738	13	ALADDIN ROCKETEER	WALTER HACKMAN	24.99	0	5239
9739	14	ALADDIN ROCKY	DANIEL WEAVER	22.99	0	427
9740	2	ALADDIN ROLLERCOASTER	ED BEATTY	12.99	0	3035
9741	12	ALADDIN ROMAN	CHRISTOPHER NEWMAN	17.99	0	9445
9742	8	ALADDIN ROOF	CARMEN WEAVER	25.99	0	1516
9743	16	ALADDIN ROOM	KEVIN CHASE	28.99	0	4754
9744	8	ALADDIN ROOTS	JACK PACINO	22.99	0	8988
9745	12	ALADDIN ROSES	WALTER HOPKINS	28.99	0	4059
9746	4	ALADDIN ROUGE	BELA FIENNES	17.99	0	8391
9747	6	ALADDIN ROXANNE	RALPH DAY-LEWIS	18.99	0	1310
9748	10	ALADDIN RUGRATS	FAY WEST	12.99	0	1707
9749	11	ALADDIN RULES	SCARLETT FINNEY	10.99	0	2107
9750	16	ALADDIN RUN	MARY MOSTEL	28.99	0	2943
9751	6	ALADDIN RUNAWAY	LISA SMITH	17.99	0	3415
9752	5	ALADDIN RUNNER	KIRK LEWIS	9.99	0	5491
9753	3	ALADDIN RUSH	JUDE NEESON	18.99	0	3779
9754	11	ALADDIN RUSHMORE	MICHELLE JACKMAN	19.99	0	6719
9755	12	ALADDIN SABRINA	GOLDIE KIDMAN	16.99	0	9224
9756	11	ALADDIN SADDLE	NICOLE RYDER	14.99	0	9729
9757	10	ALADDIN SAGEBRUSH	KENNETH HOPPER	12.99	0	5941
9758	12	ALADDIN SAINTS	ELVIS NEESON	13.99	0	1074
9759	10	ALADDIN SALUTE	LEONARDO POITIER	15.99	0	1658
9760	16	ALADDIN SAMURAI	MICHELLE WEST	15.99	0	1643
9761	4	ALADDIN SANTA	WARREN ZELLWEGER	29.99	0	1718
9762	16	ALADDIN SASSY	MADELINE TORN	19.99	0	1289
9763	2	ALADDIN SATISFACTION	RAY SINATRA	16.99	0	9155
9764	8	ALADDIN SATURDAY	MARY MOSTEL	10.99	0	9075
9765	4	ALADDIN SATURN	SALMA WILLIS	28.99	0	1907
9766	2	ALADDIN SAVANNAH	CUBA KEITEL	10.99	0	4629
9767	4	ALADDIN SCALAWAG	GWYNETH HUDSON	27.99	0	4437
9768	16	ALADDIN SCARFACE	ELLEN BERGMAN	25.99	0	3097
9769	12	ALADDIN SCHOOL	WILL TURNER	16.99	0	9497
9770	5	ALADDIN SCISSORHANDS	STEVE DAY	11.99	0	1930
9771	6	ALADDIN SCORPION	MINNIE DIAZ	19.99	0	2206
9772	16	ALADDIN SEA	MENA LAW	16.99	0	6583
9773	13	ALADDIN SEABISCUIT	NEVE HECHE	9.99	0	1679
9774	6	ALADDIN SEARCHERS	BELA WALKEN	15.99	0	570
9775	5	ALADDIN SEATTLE	EWAN LOLLOBRIGIDA	12.99	0	4335
9776	7	ALADDIN SECRET	MERYL BARRYMORE	10.99	0	205
9777	6	ALADDIN SECRETARY	LAUREN KINNEAR	9.99	0	160
9778	11	ALADDIN SECRETS	JEFF NEESON	17.99	0	6674
9779	9	ALADDIN SENSE	LENA BENING	22.99	0	8954
9780	12	ALADDIN SENSIBILITY	JOAN NEESON	29.99	0	1865
9781	7	ALADDIN SEVEN	DREW DEE	10.99	0	7938
9782	2	ALADDIN SHAKESPEARE	GRACE MINELLI	23.99	0	2173
9783	12	ALADDIN SHANE	SHIRLEY FAWCETT	12.99	0	5940
9784	14	ALADDIN SHANGHAI	MARLON DERN	17.99	0	470
9785	6	ALADDIN SHAWSHANK	MINNIE LOREN	25.99	0	5654
9786	16	ALADDIN SHEPHERD	REESE WEST	13.99	0	1289
9787	1	ALADDIN SHINING	PAUL CLOSE	16.99	0	4195
9788	9	ALADDIN SHIP	NATALIE LOLLOBRIGIDA	18.99	0	4220
9789	1	ALADDIN SHOCK	MEG LEIGH	23.99	1	5676
9790	12	ALADDIN SHOOTIST	CHARLIZE FIELD	18.99	0	6992
9791	1	ALADDIN SHOW	MARISA BIRCH	26.99	0	6954
9792	16	ALADDIN SHREK	SALLY DUKAKIS	24.99	0	7177
9793	3	ALADDIN SHRUNK	FRANCES CROWE	27.99	0	317
9794	5	ALADDIN SIDE	LENA MOSTEL	29.99	0	5888
9795	9	ALADDIN SIEGE	SOPHIA BLOOM	23.99	0	35
9796	7	ALADDIN SIERRA	BEN LANSBURY	9.99	0	3759
9797	12	ALADDIN SILENCE	MATTHEW FIENNES	21.99	0	3041
9798	5	ALADDIN SILVERADO	JOHNNY COSTNER	21.99	0	1225
9799	10	ALADDIN SIMON	RALPH FIENNES	13.99	0	1391
9800	13	ALADDIN SINNERS	DREW SARANDON	23.99	0	7731
9801	12	ALADDIN SISTER	GOLDIE TANDY	25.99	0	7035
9802	3	ALADDIN SKY	ALBERT MATTHAU	26.99	0	549
9803	3	ALADDIN SLACKER	DORIS JACKMAN	22.99	0	2598
9804	13	ALADDIN SLEEPING	LAURA PALTROW	20.99	0	8568
9805	12	ALADDIN SLEEPLESS	MARY PINKETT	28.99	0	1518
9806	12	ALADDIN SLEEPY	ALAN CHASE	9.99	0	9083
9807	12	ALADDIN SLEUTH	JULIANNE CAGE	24.99	0	7173
9808	13	ALADDIN SLING	DEBBIE BRODY	9.99	0	2916
9809	5	ALADDIN SLIPPER	ZERO KELLY	27.99	0	9241
9810	12	ALADDIN SLUMS	MARY RICKMAN	17.99	0	1059
9811	9	ALADDIN SMILE	ELVIS GOLDBERG	20.99	0	2217
9812	8	ALADDIN SMOKING	GRETA BULLOCK	29.99	0	3271
9813	12	ALADDIN SMOOCHY	JENNIFER NICHOLSON	28.99	0	2153
9814	4	ALADDIN SNATCH	NICOLAS WRAY	13.99	0	8231
9815	3	ALADDIN SNATCHERS	LEELEE LOLLOBRIGIDA	25.99	0	2765
9816	15	ALADDIN SNOWMAN	MARLON JOVOVICH	12.99	0	572
9817	7	ALADDIN SOLDIERS	CUBA KEITEL	24.99	0	607
9818	1	ALADDIN SOMETHING	NICK DAVIS	19.99	0	4426
9819	12	ALADDIN SONG	JANE FISHER	18.99	0	2931
9820	5	ALADDIN SONS	SCARLETT MOORE	27.99	0	8395
9821	3	ALADDIN SORORITY	GREG FONDA	26.99	0	4050
9822	14	ALADDIN SOUP	THORA TAUTOU	10.99	0	4381
9823	2	ALADDIN SOUTH	MARLENE MONROE	26.99	0	7762
9824	5	ALADDIN SPARTACUS	BRUCE THERON	24.99	0	6350
9825	1	ALADDIN SPEAKEASY	FRANCES MCQUEEN	27.99	0	7306
9826	12	ALADDIN SPEED	ANNETTE NEWMAN	10.99	0	5496
9827	8	ALADDIN SPICE	IAN GABLE	17.99	0	93
9828	14	ALADDIN SPIKING	MARY KEITEL	19.99	0	8195
9829	5	ALADDIN SPINAL	MICHELLE NEESON	17.99	0	482
9830	1	ALADDIN SPIRIT	MENA HAYEK	15.99	0	2029
9831	1	ALADDIN SPIRITED	SEAN BASINGER	11.99	0	3612
9832	11	ALADDIN SPLASH	MINNIE MCCONAUGHEY	10.99	0	1221
9833	2	ALADDIN SPLENDOR	MARILYN THERON	24.99	0	188
9834	9	ALADDIN SPOILERS	MENA MOSTEL	14.99	0	877
9835	5	ALADDIN SPY	JUDY BERGEN	29.99	0	8288
9836	4	ALADDIN SQUAD	SHIRLEY HAWN	10.99	0	166
9837	7	ALADDIN STAGE	MAE COOPER	12.99	0	6679
9838	5	ALADDIN STAGECOACH	KEVIN FAWCETT	28.99	0	9382
9839	15	ALADDIN STALLION	LEONARDO MANSFIELD	21.99	0	6517
9840	12	ALADDIN STAMPEDE	MIRA CHASE	13.99	0	948
9841	1	ALADDIN STAR	JUDI FORD	28.99	0	263
9842	16	ALADDIN STATE	DAN SORVINO	21.99	0	4260
9843	4	ALADDIN STEEL	NEVE DENCH	25.99	0	7756
9844	12	ALADDIN STEERS	HARRISON BIRCH	16.99	0	2260
9845	16	ALADDIN STEPMOM	HELEN HARRIS	23.99	0	5279
9846	13	ALADDIN STING	SANDRA MOSTEL	15.99	0	2709
9847	6	ALADDIN STOCK	BURT KIDMAN	20.99	0	848
9848	16	ALADDIN STONE	GLENN GARBO	23.99	0	4847
9849	8	ALADDIN STORM	KIRSTEN TOMEI	26.99	0	2699
9850	2	ALADDIN STORY	MEG DAY-LEWIS	18.99	0	2963
9851	16	ALADDIN STRAIGHT	WARREN PHOENIX	26.99	0	5510
9852	2	ALADDIN STRANGELOVE	BEN GRANT	13.99	0	1953
9853	5	ALADDIN STRANGER	KEVIN THERON	22.99	0	7075
9854	2	ALADDIN STRANGERS	LENA BALL	23.99	0	8283
9855	16	ALADDIN STREAK	ANGELINA WEST	22.99	0	9790
9856	15	ALADDIN STREETCAR	MINNIE GOLDBERG	27.99	0	7621
9857	8	ALADDIN STRICTLY	CHARLTON FORD	20.99	0	744
9858	12	ALADDIN SUBMARINE	WALTER SWANK	14.99	0	5330
9859	16	ALADDIN SUGAR	LAURA MATTHAU	21.99	0	4628
9860	7	ALADDIN SUICIDES	INGRID DERN	18.99	0	8182
9861	7	ALADDIN SUIT	DANIEL SINATRA	12.99	0	4207
9862	15	ALADDIN SUMMER	OPRAH CARREY	10.99	0	3123
9863	3	ALADDIN SUN	CHRISTOPHER GRANT	10.99	0	6650
9864	11	ALADDIN SUNDANCE	EWAN MINELLI	13.99	0	5750
9865	11	ALADDIN SUNRISE	ROBIN MCDORMAND	10.99	0	7180
9866	15	ALADDIN SUNSET	KARL KAHN	11.99	0	2400
9867	9	ALADDIN SUPER	HENRY LEIGH	14.99	0	556
9868	10	ALADDIN SUPERFLY	JAYNE REYNOLDS	24.99	0	1058
9869	7	ALADDIN SUSPECTS	NICOLE HUSTON	23.99	0	9640
9870	5	ALADDIN SWARM	LAURENCE FREEMAN	11.99	0	6665
9871	14	ALADDIN SWEDEN	CLARK FISHER	16.99	0	8385
9872	10	ALADDIN SWEET	HUMPHREY WAYNE	29.99	0	369
9873	1	ALADDIN SWEETHEARTS	RENEE SANDLER	19.99	0	6576
9874	10	ALADDIN TADPOLE	CATE WITHERSPOON	16.99	0	8227
9875	5	ALADDIN TALENTED	CHRISTOPHER WILLIAMS	27.99	0	6004
9876	9	ALADDIN TARZAN	THORA THERON	24.99	0	3525
9877	10	ALADDIN TAXI	FRANCES SPACEK	29.99	0	5098
9878	1	ALADDIN TEEN	GENE SWANK	26.99	0	8717
9879	8	ALADDIN TELEGRAPH	RUSSELL WASHINGTON	21.99	0	5370
9880	7	ALADDIN TELEMARK	JOHNNY LEIGH	21.99	0	5554
9881	4	ALADDIN TEMPLE	JANE AFFLECK	11.99	0	6811
9882	8	ALADDIN TENENBAUMS	JULIA FAWCETT	25.99	0	3408
9883	5	ALADDIN TEQUILA	DARYL DUNST	21.99	0	5428
9884	8	ALADDIN TERMINATOR	JOAN LUGOSI	15.99	0	7406
9885	14	ALADDIN TEXAS	GARY MCQUEEN	16.99	0	7577
9886	15	ALADDIN THEORY	ORLANDO HOPE	16.99	0	4996
9887	1	ALADDIN THIEF	RICHARD BERGEN	20.99	0	917
9888	15	ALADDIN THIN	HILARY CAMPBELL	11.99	0	5061
9889	11	ALADDIN TIES	BOB DAY	11.99	0	2947
9890	14	ALADDIN TIGHTS	THORA HAWKE	12.99	0	1708
9891	15	ALADDIN TIMBERLAND	LIV NORTON	23.99	0	2001
9892	3	ALADDIN TITANIC	EMILY BERRY	29.99	0	1185
9893	2	ALADDIN TITANS	ELLEN KELLY	18.99	0	22
9894	16	ALADDIN TOMATOES	DENZEL DIAZ	10.99	0	7652
9895	6	ALADDIN TOMORROW	CLARK DEAN	15.99	0	9473
9896	8	ALADDIN TOOTSIE	MADELINE EASTWOOD	10.99	0	6725
9897	5	ALADDIN TORQUE	NICOLE CLOSE	20.99	0	3779
9898	11	ALADDIN TOURIST	SOPHIA DEAN	28.99	0	5258
9899	15	ALADDIN TOWERS	RALPH NEESON	12.99	0	1605
9900	15	ALADDIN TOWN	HENRY BOLGER	10.99	0	7745
9901	1	ALADDIN TRACY	BELA SWANK	23.99	0	614
9902	6	ALADDIN TRADING	DIANE DAY-LEWIS	10.99	0	3721
9903	8	ALADDIN TRAFFIC	LENA HOFFMAN	16.99	0	2921
9904	15	ALADDIN TRAIN	WARREN EASTWOOD	23.99	0	6988
9905	14	ALADDIN TRAINSPOTTING	REESE GARLAND	13.99	0	1945
9906	1	ALADDIN TRAMP	ANJELICA JOHANSSON	10.99	0	9936
9907	3	ALADDIN TRANSLATION	DENZEL KAHN	16.99	0	9903
9908	12	ALADDIN TRAP	JAMES BERGMAN	16.99	0	8051
9909	11	ALADDIN TREASURE	BURT FREEMAN	21.99	0	5594
9910	5	ALADDIN TREATMENT	THORA TEMPLE	10.99	0	3851
9911	5	ALADDIN TRIP	SHIRLEY BRIDGES	16.99	0	513
9912	6	ALADDIN TROJAN	KIRK GABLE	20.99	0	1681
9913	9	ALADDIN TROOPERS	ED HUDSON	29.99	0	6878
9914	13	ALADDIN TROUBLE	ALICIA HOFFMAN	27.99	0	638
9915	8	ALADDIN TRUMAN	UMA FISHER	16.99	0	506
9916	13	ALADDIN TURN	CHRISTIAN PALTROW	22.99	0	3734
9917	12	ALADDIN TUXEDO	NATALIE GOODING	14.99	0	4491
9918	7	ALADDIN TWISTED	SUSAN HUNT	22.99	0	7242
9919	6	ALADDIN TYCOON	CHRISTIAN DEAN	17.99	0	2014
9920	8	ALADDIN UNBREAKABLE	JULIETTE LANSBURY	17.99	0	9516
9921	8	ALADDIN UNCUT	MARY NORTON	21.99	0	7098
9922	16	ALADDIN UNDEFEATED	BOB ANISTON	23.99	0	263
9923	3	ALADDIN UNFAITHFUL	JUDE OLIVIER	10.99	0	9481
9924	13	ALADDIN UNFORGIVEN	CHRISTOPHER PECK	29.99	0	2881
9925	3	ALADDIN UNITED	RUBY KUDROW	23.99	0	7778
9926	11	ALADDIN UNTOUCHABLES	JIM GOLDBERG	15.99	0	7934
9927	1	ALADDIN UPRISING	RIP WILSON	11.99	0	853
9928	3	ALADDIN UPTOWN	PENELOPE SORVINO	22.99	0	1421
9929	10	ALADDIN USUAL	RUSSELL OLIVIER	24.99	0	9523
9930	1	ALADDIN VACATION	JON SOBIESKI	27.99	0	4347
9931	11	ALADDIN VALENTINE	RIP CLOSE	11.99	0	7947
9932	15	ALADDIN VALLEY	ORLANDO IRONS	24.99	0	4351
9933	14	ALADDIN VAMPIRE	EMILY PFEIFFER	21.99	0	1689
9934	12	ALADDIN VANILLA	SANDRA WEAVER	21.99	0	5311
9935	9	ALADDIN VANISHED	GROUCHO POITIER	10.99	0	8769
9936	8	ALADDIN VANISHING	ANGELA FIELD	15.99	0	5126
9937	2	ALADDIN VARSITY	ZERO GOLDBERG	26.99	0	5930
9938	5	ALADDIN VELVET	GINA WAYNE	20.99	0	6854
9939	12	ALADDIN VERTIGO	MADELINE EASTWOOD	21.99	0	3354
9940	3	ALADDIN VICTORY	BEN HORNE	19.99	0	7265
9941	6	ALADDIN VIDEOTAPE	ANDY AKROYD	17.99	0	4862
9942	15	ALADDIN VIETNAM	SALMA HARRIS	28.99	0	9812
9943	9	ALADDIN VILLAIN	THORA LANCASTER	26.99	0	4782
9944	9	ALADDIN VIRGIN	PENELOPE SPACEK	12.99	0	6876
9945	8	ALADDIN VIRGINIAN	CHARLTON LANSBURY	20.99	0	6708
9946	5	ALADDIN VIRTUAL	MEL HACKMAN	15.99	0	9908
9947	14	ALADDIN VISION	HUGH PENN	23.99	0	6581
9948	11	ALADDIN VOICE	DENNIS CAGE	21.99	0	3218
9949	2	ALADDIN VOLCANO	CHEVY HUNT	26.99	0	5893
9950	9	ALADDIN VOLUME	CHARLIZE BOGART	23.99	0	1861
9951	6	ALADDIN VOYAGE	LAURENCE WEST	9.99	0	3870
9952	1	ALADDIN WAGON	BRUCE BOGART	17.99	0	7304
9953	2	ALADDIN WAIT	SALMA HESTON	15.99	0	8255
9954	10	ALADDIN WAKE	FRANK BLANCHETT	25.99	0	9186
9955	6	ALADDIN WALLS	ALAN HORNE	19.99	0	6804
9956	12	ALADDIN WANDA	MADELINE JOLIE	14.99	0	9182
9957	11	ALADDIN WAR	ALAN LANSBURY	25.99	0	7951
9958	8	ALADDIN WARDROBE	DREW BENING	16.99	0	2557
9959	3	ALADDIN WARLOCK	GREG WILLIS	19.99	0	2735
9960	7	ALADDIN WARS	NICK BOGART	17.99	0	8826
9961	2	ALADDIN WASH	HELEN DUKAKIS	24.99	0	9175
9962	11	ALADDIN WASTELAND	JODIE DEGENERES	23.99	0	4589
9963	8	ALADDIN WATCH	JULIA JOLIE	23.99	0	8717
9964	16	ALADDIN WATERFRONT	ROCK BASINGER	15.99	0	5714
9965	10	ALADDIN WATERSHIP	MATT WAYNE	15.99	0	2679
9966	4	ALADDIN WEDDING	KIRK HUDSON	21.99	0	1332
9967	8	ALADDIN WEEKEND	HALLE TANDY	29.99	0	3735
9968	7	ALADDIN WEREWOLF	SCARLETT AFFLECK	28.99	0	7380
9969	14	ALADDIN WEST	RALPH MOORE	22.99	0	3257
9970	4	ALADDIN WESTWARD	EMILY KELLY	27.99	0	6341
9971	3	ALADDIN WHALE	BRUCE BACALL	24.99	0	3084
9972	14	ALADDIN WHISPERER	CHRISTIAN BLOOM	13.99	0	7043
9973	10	ALADDIN WIFE	MILLA IRONS	18.99	0	4094
9974	4	ALADDIN WILD	ANTHONY DEPP	29.99	0	255
9975	6	ALADDIN WILLOW	KEVIN CAGE	21.99	0	3920
9976	4	ALADDIN WIND	JACK CROWE	15.99	0	216
9977	11	ALADDIN WINDOW	CAMERON RICKMAN	25.99	0	1749
9978	9	ALADDIN WISDOM	MARY LUGOSI	13.99	0	979
9979	11	ALADDIN WITCHES	GRETA DIETRICH	23.99	0	2601
9980	12	ALADDIN WIZARD	HILARY MANSFIELD	14.99	0	4219
9981	11	ALADDIN WOLVES	LIAM HAWN	10.99	0	5195
9982	2	ALADDIN WOMEN	FARRAH GRANT	13.99	0	2744
9983	7	ALADDIN WON	SALMA PALTROW	10.99	0	9238
9984	3	ALADDIN WONDERFUL	DANIEL LANCASTER	19.99	0	4674
9985	13	ALADDIN WONDERLAND	ANNETTE WINFREY	12.99	0	2537
9986	10	ALADDIN WONKA	MATTHEW VOIGHT	13.99	0	4187
9987	12	ALADDIN WORDS	RENEE BRIDGES	9.99	0	9987
9988	5	ALADDIN WORKER	MILLA PITT	11.99	0	6310
9989	1	ALADDIN WORKING	CUBA WILLIS	14.99	0	4359
9990	12	ALADDIN WORLD	HUMPHREY DENCH	25.99	0	6584
9991	1	ALADDIN WORST	LAURA ZELLWEGER	23.99	0	5836
9992	3	ALADDIN WRATH	MICHELLE TYLER	28.99	0	423
9993	15	ALADDIN WRONG	PENELOPE CRUISE	22.99	0	5854
9994	5	ALADDIN WYOMING	KENNETH GUINESS	18.99	0	212
9995	15	ALADDIN YENTL	EMILY GOLDBERG	15.99	0	6769
9996	16	ALADDIN YOUNG	MEG DAMON	20.99	0	8720
9997	2	ALADDIN YOUTH	RALPH BASINGER	26.99	1	7003
9998	14	ALADDIN ZHIVAGO	SIGOURNEY WALKEN	22.99	0	2206
9999	4	ALADDIN ZOOLANDER	LISA STALLONE	25.99	0	2620
10000	13	ALADDIN ZORRO	MAE CRUISE	10.99	0	8018
\.


--
-- Data for Name: reorder; Type: TABLE DATA; Schema: public; Owner: chriskl
--

COPY reorder (prod_id, date_low, quan_low, date_reordered, quan_reordered, date_expected) FROM stdin;
\.


--
-- Name: categories_pkey; Type: CONSTRAINT; Schema: public; Owner: chriskl; Tablespace: 
--

ALTER TABLE ONLY categories
    ADD CONSTRAINT categories_pkey PRIMARY KEY (category);


--
-- Name: customers_pkey; Type: CONSTRAINT; Schema: public; Owner: chriskl; Tablespace: 
--

ALTER TABLE ONLY customers
    ADD CONSTRAINT customers_pkey PRIMARY KEY (customerid);


--
-- Name: inventory_pkey; Type: CONSTRAINT; Schema: public; Owner: chriskl; Tablespace: 
--

ALTER TABLE ONLY inventory
    ADD CONSTRAINT inventory_pkey PRIMARY KEY (prod_id);


--
-- Name: orders_pkey; Type: CONSTRAINT; Schema: public; Owner: chriskl; Tablespace: 
--

ALTER TABLE ONLY orders
    ADD CONSTRAINT orders_pkey PRIMARY KEY (orderid);


--
-- Name: products_pkey; Type: CONSTRAINT; Schema: public; Owner: chriskl; Tablespace: 
--

ALTER TABLE ONLY products
    ADD CONSTRAINT products_pkey PRIMARY KEY (prod_id);


--
-- Name: ix_cust_hist_customerid; Type: INDEX; Schema: public; Owner: chriskl; Tablespace: 
--

CREATE INDEX ix_cust_hist_customerid ON cust_hist USING btree (customerid);


--
-- Name: ix_cust_username; Type: INDEX; Schema: public; Owner: chriskl; Tablespace: 
--

CREATE UNIQUE INDEX ix_cust_username ON customers USING btree (username);


--
-- Name: ix_order_custid; Type: INDEX; Schema: public; Owner: chriskl; Tablespace: 
--

CREATE INDEX ix_order_custid ON orders USING btree (customerid);


--
-- Name: ix_orderlines_orderid; Type: INDEX; Schema: public; Owner: chriskl; Tablespace: 
--

CREATE UNIQUE INDEX ix_orderlines_orderid ON orderlines USING btree (orderid, orderlineid);


--
-- Name: ix_prod_category; Type: INDEX; Schema: public; Owner: chriskl; Tablespace: 
--

CREATE INDEX ix_prod_category ON products USING btree (category);


--
-- Name: ix_prod_special; Type: INDEX; Schema: public; Owner: chriskl; Tablespace: 
--

CREATE INDEX ix_prod_special ON products USING btree (special);


--
-- Name: fk_cust_hist_customerid; Type: FK CONSTRAINT; Schema: public; Owner: chriskl
--

ALTER TABLE ONLY cust_hist
    ADD CONSTRAINT fk_cust_hist_customerid FOREIGN KEY (customerid) REFERENCES customers(customerid) ON DELETE CASCADE;


--
-- Name: fk_customerid; Type: FK CONSTRAINT; Schema: public; Owner: chriskl
--

ALTER TABLE ONLY orders
    ADD CONSTRAINT fk_customerid FOREIGN KEY (customerid) REFERENCES customers(customerid) ON DELETE SET NULL;


--
-- Name: fk_orderid; Type: FK CONSTRAINT; Schema: public; Owner: chriskl
--

ALTER TABLE ONLY orderlines
    ADD CONSTRAINT fk_orderid FOREIGN KEY (orderid) REFERENCES orders(orderid) ON DELETE CASCADE;


--
-- PostgreSQL database dump complete
--

